commit fb2f72db27b96fba73ed525d1e14a141663f82cc
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Thu Aug 1 11:17:40 2024

    Bump BASE-VER.
    
    2024-08-01  Jakub Jelinek  <jakub@redhat.com>
    
            * BASE-VER: Set to 14.2.1.

diff --git a/gcc/BASE-VER b/gcc/BASE-VER
index 07ea9fa4381..dab6a80f4a8 100644
--- a/gcc/BASE-VER
+++ b/gcc/BASE-VER
@@ -1 +1 @@
-14.2.0
+14.2.1

commit 973097d801a30385cd39a570624eefa7547f8ff3
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Thu Aug 1 10:32:54 2024

    i386: Fix up *<extract_type>_vinsert<shuffletype><extract_suf>_0 [PR115981]
    
    The r14-537 change started canonicalizing VEC_MERGE operands based on
    swap_commutative_operands_p or if they have the same precedence least
    significant bit of the third operand.
    The *<extract_type>_vinsert<shuffletype><extract_suf>_0 pattern was
    added for combine matching and no longer triggers after that change,
    as it used the reg_or_0_operand as the first operand and VEC_DUPLICATE
    as the second.
    Now, reg_or_0_operand could be a REG, SUBREG of object or CONST_VECTOR.
    REG has commutative_operand_precedence -1 or -2, SUBREG of object -3,
    CONST_VECTOR -4, while VEC_DUPLICATE has 0, so VEC_DUPLICATE will always
    go first and REG, SUBREG or CONST_VECTOR second.
    
    This patch swaps the operands so that it matches again.
    
    2024-08-01  Jakub Jelinek  <jakub@redhat.com>
    
            PR target/115981
            * config/i386/sse.md
            (*<extract_type>_vinsert<shuffletype><extract_suf>_0): Swap the
            first two VEC_MERGE operands, renumber match_operands and test
            for 0xF or 0x3 rather than 0xFFF0 or 0xFC immediate.
    
            * gcc.target/i386/avx512dq-pr90991-1.c: Add tests for no separate
            zero extension instructions.
            * gcc.target/i386/avx512dq-pr90991-2.c: Likewise.
    
    (cherry picked from commit df2b444a233e93b987adec76655ab89589b3fa10)

diff --git a/gcc/config/i386/sse.md b/gcc/config/i386/sse.md
index 1bf50726e83..073aae293d4 100644
--- a/gcc/config/i386/sse.md
+++ b/gcc/config/i386/sse.md
@@ -19124,47 +19124,47 @@
 (define_insn "*<extract_type>_vinsert<shuffletype><extract_suf>_0"
   [(set (match_operand:AVX512_VEC 0 "register_operand" "=v,x,Yv")
 	(vec_merge:AVX512_VEC
-	  (match_operand:AVX512_VEC 1 "reg_or_0_operand" "v,C,C")
 	  (vec_duplicate:AVX512_VEC
-		(match_operand:<ssequartermode> 2 "nonimmediate_operand" "vm,xm,vm"))
+	    (match_operand:<ssequartermode> 1 "nonimmediate_operand" "vm,xm,vm"))
+	  (match_operand:AVX512_VEC 2 "reg_or_0_operand" "v,C,C")
 	  (match_operand:SI 3 "const_int_operand")))]
   "TARGET_AVX512F
    && (INTVAL (operands[3])
-       == (GET_MODE_UNIT_SIZE (<MODE>mode) == 4 ? 0xFFF0 : 0xFC))"
+       == (GET_MODE_UNIT_SIZE (<MODE>mode) == 4 ? 0xF : 0x3))"
 {
   if (which_alternative == 0)
-    return "vinsert<shuffletype><extract_suf>\t{$0, %2, %1, %0|%0, %1, %2, 0}";
+    return "vinsert<shuffletype><extract_suf>\t{$0, %1, %2, %0|%0, %2, %1, 0}";
   bool egpr_used = (TARGET_APX_EGPR
-		    && x86_extended_rex2reg_mentioned_p (operands[2]));
-  const char *align_templ = egpr_used ? "vmovaps\t{%2, %x0|%x0, %2}"
-				      : "vmovdqa\t{%2, %x0|%x0, %2}";
-  const char *unalign_templ = egpr_used ? "vmovups\t{%2, %x0|%x0, %2}"
-					: "vmovdqu\t{%2, %x0|%x0, %2}";
+		    && x86_extended_rex2reg_mentioned_p (operands[1]));
+  const char *align_templ = egpr_used ? "vmovaps\t{%1, %x0|%x0, %1}"
+				      : "vmovdqa\t{%1, %x0|%x0, %1}";
+  const char *unalign_templ = egpr_used ? "vmovups\t{%1, %x0|%x0, %1}"
+					: "vmovdqu\t{%1, %x0|%x0, %1}";
   switch (<MODE>mode)
     {
     case E_V8DFmode:
-      if (misaligned_operand (operands[2], <ssequartermode>mode))
-	return "vmovupd\t{%2, %x0|%x0, %2}";
+      if (misaligned_operand (operands[1], <ssequartermode>mode))
+	return "vmovupd\t{%1, %x0|%x0, %1}";
       else
-	return "vmovapd\t{%2, %x0|%x0, %2}";
+	return "vmovapd\t{%1, %x0|%x0, %1}";
     case E_V16SFmode:
-      if (misaligned_operand (operands[2], <ssequartermode>mode))
-	return "vmovups\t{%2, %x0|%x0, %2}";
+      if (misaligned_operand (operands[1], <ssequartermode>mode))
+	return "vmovups\t{%1, %x0|%x0, %1}";
       else
-	return "vmovaps\t{%2, %x0|%x0, %2}";
+	return "vmovaps\t{%1, %x0|%x0, %1}";
     case E_V8DImode:
-      if (misaligned_operand (operands[2], <ssequartermode>mode))
-	return which_alternative == 2 ? "vmovdqu64\t{%2, %x0|%x0, %2}"
+      if (misaligned_operand (operands[1], <ssequartermode>mode))
+	return which_alternative == 2 ? "vmovdqu64\t{%1, %x0|%x0, %1}"
 				      : unalign_templ;
       else
-	return which_alternative == 2 ? "vmovdqa64\t{%2, %x0|%x0, %2}"
+	return which_alternative == 2 ? "vmovdqa64\t{%1, %x0|%x0, %1}"
 				      : align_templ;
     case E_V16SImode:
-      if (misaligned_operand (operands[2], <ssequartermode>mode))
-	return which_alternative == 2 ? "vmovdqu32\t{%2, %x0|%x0, %2}"
+      if (misaligned_operand (operands[1], <ssequartermode>mode))
+	return which_alternative == 2 ? "vmovdqu32\t{%1, %x0|%x0, %1}"
 				      : unalign_templ;
       else
-	return which_alternative == 2 ? "vmovdqa32\t{%2, %x0|%x0, %2}"
+	return which_alternative == 2 ? "vmovdqa32\t{%1, %x0|%x0, %1}"
 				      : align_templ;
     default:
       gcc_unreachable ();
diff --git a/gcc/testsuite/gcc.target/i386/avx512dq-pr90991-1.c b/gcc/testsuite/gcc.target/i386/avx512dq-pr90991-1.c
index 6c968126b7d..5d19b07bdee 100644
--- a/gcc/testsuite/gcc.target/i386/avx512dq-pr90991-1.c
+++ b/gcc/testsuite/gcc.target/i386/avx512dq-pr90991-1.c
@@ -7,6 +7,9 @@
 /* { dg-final { scan-assembler-times "vmovups\[ \t]\+\\(\[^\n\r]*\\), %xmm0" 1 } } */
 /* { dg-final { scan-assembler-times "vmovupd\[ \t]\+\\(\[^\n\r]*\\), %xmm0" 1 } } */
 /* { dg-final { scan-assembler-times "vmovdqu\[ \t]\+\\(\[^\n\r]*\\), %xmm0" 1 } } */
+/* { dg-final { scan-assembler-not "vmovaps\[ \t]\+%xmm0, %xmm0" } } */
+/* { dg-final { scan-assembler-not "vmovapd\[ \t]\+%xmm0, %xmm0" } } */
+/* { dg-final { scan-assembler-not "vmovdqa\[ \t]\+%xmm0, %xmm0" } } */
 
 #include <x86intrin.h>
 
diff --git a/gcc/testsuite/gcc.target/i386/avx512dq-pr90991-2.c b/gcc/testsuite/gcc.target/i386/avx512dq-pr90991-2.c
index 7699c3149ae..68f53189d3e 100644
--- a/gcc/testsuite/gcc.target/i386/avx512dq-pr90991-2.c
+++ b/gcc/testsuite/gcc.target/i386/avx512dq-pr90991-2.c
@@ -7,6 +7,9 @@
 /* { dg-final { scan-assembler-times "vmovups\[ \t]\+\\(\[^\n\r]*\\), %ymm0" 1 } } */
 /* { dg-final { scan-assembler-times "vmovupd\[ \t]\+\\(\[^\n\r]*\\), %ymm0" 1 } } */
 /* { dg-final { scan-assembler-times "vmovdqu\[ \t]\+\\(\[^\n\r]*\\), %ymm0" 1 } } */
+/* { dg-final { scan-assembler-not "vmovaps\[ \t]\+%ymm0, %ymm0" } } */
+/* { dg-final { scan-assembler-not "vmovapd\[ \t]\+%ymm0, %ymm0" } } */
+/* { dg-final { scan-assembler-not "vmovdqa\[ \t]\+%ymm0, %ymm0" } } */
 
 #include <x86intrin.h>
 

commit ce84abae497ec2617a2eb12f40815639235be97c
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Wed Jul 24 12:32:22 2024

    libstdc++: Fix std::vector<bool> for -std=gnu++14 -fconcepts [PR116070]
    
    This questionable combination of flags causes a number of errors. This
    one in std::vector<bool> needs to be fixed in the gcc-13 branch so I'm
    committing it separately to simplify backporting.
    
    libstdc++-v3/ChangeLog:
    
            PR libstdc++/116070
            * include/bits/stl_bvector.h: Check feature test macro before
            using is_default_constructible_v.
    
    (cherry picked from commit 5fc9c40fea2481e56bf7bcc994cb40c71e28abb8)

diff --git a/libstdc++-v3/include/bits/stl_bvector.h b/libstdc++-v3/include/bits/stl_bvector.h
index d567e26f4e4..4f1e7686a1c 100644
--- a/libstdc++-v3/include/bits/stl_bvector.h
+++ b/libstdc++-v3/include/bits/stl_bvector.h
@@ -593,7 +593,7 @@ _GLIBCXX_BEGIN_NAMESPACE_CONTAINER
 	_GLIBCXX20_CONSTEXPR
 	_Bvector_impl() _GLIBCXX_NOEXCEPT_IF(
 	  is_nothrow_default_constructible<_Bit_alloc_type>::value)
-#if __cpp_concepts
+#if __cpp_concepts && __glibcxx_type_trait_variable_templates
 	requires is_default_constructible_v<_Bit_alloc_type>
 #endif
 	: _Bit_alloc_type()

commit 9ba75a628e0214eb08673f1572c6fd06fe553525
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Wed Jul 24 12:32:22 2024

    libstdc++: Fix <ostream> and <istream> for -std=gnu++14 -fconcepts [PR116070]
    
    This questionable combination of flags causes a number of errors. The
    ones in the rvalue stream overloads need to be fixed in the gcc-14
    branch so I'm committing it separately to simplify backporting.
    
    libstdc++-v3/ChangeLog:
    
            PR libstdc++/116070
            * include/std/istream: Check feature test macro before using
            is_class_v and is_same_v.
            * include/std/ostream: Likewise.
    
    (cherry picked from commit 6c22fe418cff57dad712c4b950638e6e2d09bd9c)

diff --git a/libstdc++-v3/include/std/istream b/libstdc++-v3/include/std/istream
index 11d51d3e666..a2b207dae78 100644
--- a/libstdc++-v3/include/std/istream
+++ b/libstdc++-v3/include/std/istream
@@ -1069,7 +1069,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
   // 2328. Rvalue stream extraction should use perfect forwarding
   // 1203. More useful rvalue stream insertion
 
-#if __cpp_concepts >= 201907L
+#if __cpp_concepts >= 201907L && __glibcxx_type_trait_variable_templates
   template<typename _Is, typename _Tp>
     requires __derived_from_ios_base<_Is>
       && requires (_Is& __is, _Tp&& __t) { __is >> std::forward<_Tp>(__t); }
diff --git a/libstdc++-v3/include/std/ostream b/libstdc++-v3/include/std/ostream
index 8a21758d0a3..12be6c4fd17 100644
--- a/libstdc++-v3/include/std/ostream
+++ b/libstdc++-v3/include/std/ostream
@@ -768,7 +768,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
   // _GLIBCXX_RESOLVE_LIB_DEFECTS
   // 1203. More useful rvalue stream insertion
 
-#if __cpp_concepts >= 201907L
+#if __cpp_concepts >= 201907L && __glibcxx_type_trait_variable_templates
   // Use concepts if possible because they're cheaper to evaluate.
   template<typename _Tp>
     concept __derived_from_ios_base = is_class_v<_Tp>

commit a1e166516f994751a8c87af033b92c15fae315c3
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Fri Jul 5 21:00:04 2024

    libstdc++: Use reserved form of [[__likely__]] in <variant>
    
    We should not use [[unlikely]] before C++20, so use [[__unlikely__]]
    instead.
    
    libstdc++-v3/ChangeLog:
    
            * include/std/variant (_Variant_storage::_M_reset): Use
            __unlikely__ form of attribute instead of unlikely.
    
    (cherry picked from commit 9f1cd51766f251aafe0f1b898892f79855892729)

diff --git a/libstdc++-v3/include/std/variant b/libstdc++-v3/include/std/variant
index 748e9bae1cb..4e56134a6f7 100644
--- a/libstdc++-v3/include/std/variant
+++ b/libstdc++-v3/include/std/variant
@@ -490,7 +490,7 @@ namespace __variant
       constexpr void
       _M_reset()
       {
-	if (!_M_valid()) [[unlikely]]
+	if (!_M_valid()) [[__unlikely__]]
 	  return;
 
 	std::__do_visit<void>([](auto&& __this_mem) mutable

commit 5fcdb36fed0ef73c0dc995e0241bad72200ac8fa
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Wed Jun 12 15:53:00 2024

    libstdc++: Use __glibcxx_ranges_as_const to guard P2278R4 changes
    
    The P2278R4 additions for C++23 are currently guarded by a check for
    __cplusplus > 202002L but can use __glibcxx_ranges_as_const instead.
    
    libstdc++-v3/ChangeLog:
    
            * include/bits/ranges_base.h (const_iterator_t): Change
            preprocessor condition to use __glibcxx_ranges_as_const.
            (const_sentinel_t, range_const_reference_t): Likewise.
            (__access::__possibly_const_range, cbegin, cend, crbegin)
            (crend, cdata): Likewise.
            * include/bits/stl_iterator.h (iter_const_reference_t)
            (basic_const_iterator, const_iterator, const_sentinel)
            (make_const_iterator): Likewise.
    
    (cherry picked from commit 0755b2304bac9579fd5da337da8f861ccb1b042b)

diff --git a/libstdc++-v3/include/bits/ranges_base.h b/libstdc++-v3/include/bits/ranges_base.h
index 6597ffa532d..23c0b56ff22 100644
--- a/libstdc++-v3/include/bits/ranges_base.h
+++ b/libstdc++-v3/include/bits/ranges_base.h
@@ -513,7 +513,7 @@ namespace ranges
   template<range _Range>
     using sentinel_t = decltype(ranges::end(std::declval<_Range&>()));
 
-#if __cplusplus > 202002L
+#if __glibcxx_ranges_as_const // >= C++23
   template<range _Range>
     using const_iterator_t = const_iterator<iterator_t<_Range>>;
 
@@ -616,7 +616,7 @@ namespace ranges
     concept common_range
       = range<_Tp> && same_as<iterator_t<_Tp>, sentinel_t<_Tp>>;
 
-#if __cplusplus > 202002L
+#if __glibcxx_ranges_as_const // >= C++23
   template<typename _Tp>
     concept constant_range
       = input_range<_Tp> && std::__detail::__constant_iterator<iterator_t<_Tp>>;
@@ -624,7 +624,7 @@ namespace ranges
 
   namespace __access
   {
-#if __cplusplus > 202020L
+#if __glibcxx_ranges_as_const // >= C++23
     template<typename _Range>
       constexpr auto&
       __possibly_const_range(_Range& __r) noexcept
@@ -651,7 +651,7 @@ namespace ranges
 
     struct _CBegin
     {
-#if __cplusplus > 202002L
+#if __glibcxx_ranges_as_const // >= C++23
       template<__maybe_borrowed_range _Tp>
 	[[nodiscard]]
 	constexpr auto
@@ -679,7 +679,7 @@ namespace ranges
 
     struct _CEnd final
     {
-#if __cplusplus > 202002L
+#if __glibcxx_ranges_as_const // >= C++23
       template<__maybe_borrowed_range _Tp>
 	[[nodiscard]]
 	constexpr auto
@@ -707,7 +707,7 @@ namespace ranges
 
     struct _CRBegin
     {
-#if __cplusplus > 202002L
+#if __glibcxx_ranges_as_const // >= C++23
       template<__maybe_borrowed_range _Tp>
 	[[nodiscard]]
 	constexpr auto
@@ -735,7 +735,7 @@ namespace ranges
 
     struct _CREnd
     {
-#if __cplusplus > 202002L
+#if __glibcxx_ranges_as_const // >= C++23
       template<__maybe_borrowed_range _Tp>
 	[[nodiscard]]
 	constexpr auto
@@ -763,7 +763,7 @@ namespace ranges
 
     struct _CData
     {
-#if __cplusplus > 202002L
+#if __glibcxx_ranges_as_const // >= C++23
       template<__maybe_borrowed_range _Tp>
 	[[nodiscard]]
 	constexpr const auto*
diff --git a/libstdc++-v3/include/bits/stl_iterator.h b/libstdc++-v3/include/bits/stl_iterator.h
index 560a10a7abe..d3823057270 100644
--- a/libstdc++-v3/include/bits/stl_iterator.h
+++ b/libstdc++-v3/include/bits/stl_iterator.h
@@ -2571,7 +2571,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
 				      void>;
     };
 
-#if __cplusplus > 202020L
+#if __glibcxx_ranges_as_const // >= C++23
   template<indirectly_readable _It>
     using iter_const_reference_t
       = common_reference_t<const iter_value_t<_It>&&, iter_reference_t<_It>>;

commit 11b5ad5ba712c9c22e6eced415c839c67f617e52
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Wed Jul 10 11:29:52 2024

    libstdc++: Use direct-initialization for std::vector<bool>'s allocator [PR115854]
    
    The consensus in the standard committee is that this change shouldn't be
    necessary, and the Allocator requirements should require conversions
    between rebound allocators to be implicit. But we can make it work for
    now anyway.
    
    libstdc++-v3/ChangeLog:
    
            PR libstdc++/115854
            * include/bits/stl_bvector.h (_Bvector_base): Convert allocator
            to rebound type explicitly.
            * testsuite/23_containers/vector/allocator/115854.cc: New test.
            * testsuite/23_containers/vector/bool/allocator/115854.cc: New test.
    
    (cherry picked from commit c5efc6eca8e3eee7038ae218cf7e2dbe9ed9d82a)

diff --git a/libstdc++-v3/include/bits/stl_bvector.h b/libstdc++-v3/include/bits/stl_bvector.h
index 4f1e7686a1c..ffc7428a927 100644
--- a/libstdc++-v3/include/bits/stl_bvector.h
+++ b/libstdc++-v3/include/bits/stl_bvector.h
@@ -654,7 +654,7 @@ _GLIBCXX_BEGIN_NAMESPACE_CONTAINER
 
       _GLIBCXX20_CONSTEXPR
       _Bvector_base(const allocator_type& __a)
-      : _M_impl(__a) { }
+      : _M_impl(_Bit_alloc_type(__a)) { }
 
 #if __cplusplus >= 201103L
       _Bvector_base(_Bvector_base&&) = default;
diff --git a/libstdc++-v3/testsuite/23_containers/vector/allocator/115854.cc b/libstdc++-v3/testsuite/23_containers/vector/allocator/115854.cc
new file mode 100644
index 00000000000..6c9016b311f
--- /dev/null
+++ b/libstdc++-v3/testsuite/23_containers/vector/allocator/115854.cc
@@ -0,0 +1,10 @@
+// { dg-do compile { target c++11 } }
+
+#include <vector>
+#include <testsuite_allocator.h>
+
+__gnu_test::ExplicitConsAlloc<int> alloc;
+std::vector<int, __gnu_test::ExplicitConsAlloc<int>> v;
+std::vector<int, __gnu_test::ExplicitConsAlloc<int>> v1(alloc);
+std::vector<int, __gnu_test::ExplicitConsAlloc<int>> v2(v1, alloc);
+std::vector<int, __gnu_test::ExplicitConsAlloc<int>> v3(std::move(v1), alloc);
diff --git a/libstdc++-v3/testsuite/23_containers/vector/bool/allocator/115854.cc b/libstdc++-v3/testsuite/23_containers/vector/bool/allocator/115854.cc
new file mode 100644
index 00000000000..14b28cc3e96
--- /dev/null
+++ b/libstdc++-v3/testsuite/23_containers/vector/bool/allocator/115854.cc
@@ -0,0 +1,10 @@
+// { dg-do compile { target c++11 } }
+
+#include <vector>
+#include <testsuite_allocator.h>
+
+__gnu_test::ExplicitConsAlloc<bool> alloc;
+std::vector<bool, __gnu_test::ExplicitConsAlloc<bool>> v;
+std::vector<bool, __gnu_test::ExplicitConsAlloc<bool>> v1(alloc);
+std::vector<bool, __gnu_test::ExplicitConsAlloc<bool>> v2(v1, alloc);
+std::vector<bool, __gnu_test::ExplicitConsAlloc<bool>> v3(std::move(v1), alloc);

commit 095be59fd737093dffb5a4cb83f9e91d6840299b
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Fri Jun 7 18:44:29 2024

    libstdc++: Define __cpp_lib_ranges in <algorithm>
    
    The __cpp_lib_ranges macro is missing from <algorithm>.
    
    libstdc++-v3/ChangeLog:
    
            * include/std/algorithm: Define __glibcxx_want_ranges.
            * testsuite/25_algorithms/headers/algorithm/synopsis.cc: Check
            feature test macro in C++20 mode.
    
    (cherry picked from commit 77e84dc4e4e60ec5e7d6d1124e226452aa558108)

diff --git a/libstdc++-v3/include/std/algorithm b/libstdc++-v3/include/std/algorithm
index a4602a8807e..163e6b5dca7 100644
--- a/libstdc++-v3/include/std/algorithm
+++ b/libstdc++-v3/include/std/algorithm
@@ -67,6 +67,7 @@
 #define __glibcxx_want_constexpr_algorithms
 #define __glibcxx_want_freestanding_algorithm
 #define __glibcxx_want_parallel_algorithm
+#define __glibcxx_want_ranges
 #define __glibcxx_want_ranges_contains
 #define __glibcxx_want_ranges_find_last
 #define __glibcxx_want_ranges_fold
diff --git a/libstdc++-v3/testsuite/25_algorithms/headers/algorithm/synopsis.cc b/libstdc++-v3/testsuite/25_algorithms/headers/algorithm/synopsis.cc
index 8c61a614a47..08a47aa95c3 100644
--- a/libstdc++-v3/testsuite/25_algorithms/headers/algorithm/synopsis.cc
+++ b/libstdc++-v3/testsuite/25_algorithms/headers/algorithm/synopsis.cc
@@ -19,6 +19,14 @@
 
 #include <algorithm>
 
+#if __cplusplus >= 202002L
+#ifndef __cpp_lib_ranges
+# error "Feature test macro for ranges is missing in <algorithm>"
+#elif __cpp_lib_ranges < 201911L
+# error "Feature test macro for ranges has wrong value in <algorithm>"
+#endif
+#endif
+
 namespace std
  {
   // 25.1, non-modifying sequence operations:

commit 7d269e34a318a8c7206edd0ac388113aed3fe902
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Tue Jun 18 17:59:52 2024

    libstdc++: Make std::any_cast<void> ill-formed (LWG 3305)
    
    LWG 3305 was approved earlier this year in Tokyo. We need to give an
    error if using std::any_cast<void>, but std::any_cast<void()> is valid
    (but always returns null).
    
    libstdc++-v3/ChangeLog:
    
            * include/std/any (any_cast(any*), any_cast(const any*)): Add
            static assertion to reject void types, as per LWG 3305.
            * testsuite/20_util/any/misc/lwg3305.cc: New test.
    
    (cherry picked from commit 466ee78e3e975627440992dac67973ee314a0551)

diff --git a/libstdc++-v3/include/std/any b/libstdc++-v3/include/std/any
index 690ddc2aa57..e4709b1ce04 100644
--- a/libstdc++-v3/include/std/any
+++ b/libstdc++-v3/include/std/any
@@ -554,6 +554,12 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
   template<typename _ValueType>
     inline const _ValueType* any_cast(const any* __any) noexcept
     {
+      // _GLIBCXX_RESOLVE_LIB_DEFECTS
+      // 3305. any_cast<void>
+      static_assert(!is_void_v<_ValueType>);
+
+      // As an optimization, don't bother instantiating __any_caster for
+      // function types, since std::any can only hold objects.
       if constexpr (is_object_v<_ValueType>)
 	if (__any)
 	  return static_cast<_ValueType*>(__any_caster<_ValueType>(__any));
@@ -563,6 +569,8 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
   template<typename _ValueType>
     inline _ValueType* any_cast(any* __any) noexcept
     {
+      static_assert(!is_void_v<_ValueType>);
+
       if constexpr (is_object_v<_ValueType>)
 	if (__any)
 	  return static_cast<_ValueType*>(__any_caster<_ValueType>(__any));
diff --git a/libstdc++-v3/testsuite/20_util/any/misc/lwg3305.cc b/libstdc++-v3/testsuite/20_util/any/misc/lwg3305.cc
new file mode 100644
index 00000000000..49f5d747ab3
--- /dev/null
+++ b/libstdc++-v3/testsuite/20_util/any/misc/lwg3305.cc
@@ -0,0 +1,15 @@
+// { dg-do compile { target c++17 } }
+
+// LWG 3305. any_cast<void>
+
+#include <any>
+
+void
+test_lwg3305()
+{
+  std::any a;
+  (void) std::any_cast<const void>(&a); // { dg-error "here" }
+  const std::any a2;
+  (void) std::any_cast<volatile void>(&a2); // { dg-error "here" }
+}
+// { dg-error "static assertion failed" "" { target *-*-* } 0 }

commit 85d07df7be5fcc7326cecb9ee1ad643b89ea50d2
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Wed Jul 10 11:27:24 2024

    libstdc++: Make std::basic_format_context non-copyable [PR114387]
    
    Users are not supposed to create objects of this type, and there's no
    reason it needs to be copyable. LWG 4061 makes it non-copyable and
    non-default constructible.
    
    libstdc++-v3/ChangeLog:
    
            PR libstdc++/114387
            * include/std/format (basic_format_context): Define copy
            operations as deleted, as per LWG 4061.
            * testsuite/std/format/context.cc: New test.
    
    (cherry picked from commit d8cd8521185436ea45ed48c5dd481277e9b8a98d)

diff --git a/libstdc++-v3/include/std/format b/libstdc++-v3/include/std/format
index 48deba2bcb2..16cee0d3c74 100644
--- a/libstdc++-v3/include/std/format
+++ b/libstdc++-v3/include/std/format
@@ -3851,6 +3851,12 @@ namespace __format
       : _M_args(__args), _M_out(std::move(__out)), _M_loc(__loc)
       { }
 
+      // _GLIBCXX_RESOLVE_LIB_DEFECTS
+      // 4061. Should std::basic_format_context be
+      //       default-constructible/copyable/movable?
+      basic_format_context(const basic_format_context&) = delete;
+      basic_format_context& operator=(const basic_format_context&) = delete;
+
       template<typename _Out2, typename _CharT2, typename _Context2>
 	friend _Out2
 	__format::__do_vformat_to(_Out2, basic_string_view<_CharT2>,
@@ -3858,7 +3864,6 @@ namespace __format
 				  const locale*);
 
     public:
-      basic_format_context() = default;
       ~basic_format_context() = default;
 
       using iterator = _Out;
diff --git a/libstdc++-v3/testsuite/std/format/context.cc b/libstdc++-v3/testsuite/std/format/context.cc
new file mode 100644
index 00000000000..5cc5e9c9ba2
--- /dev/null
+++ b/libstdc++-v3/testsuite/std/format/context.cc
@@ -0,0 +1,36 @@
+// { dg-do compile { target c++20 } }
+
+#include <format>
+
+template<typename Context>
+concept format_context_reqs = std::is_destructible_v<Context>
+  && (!std::is_default_constructible_v<Context>)
+  && (!std::is_copy_constructible_v<Context>)
+  && (!std::is_move_constructible_v<Context>)
+  && (!std::is_copy_assignable_v<Context>)
+  && (!std::is_move_assignable_v<Context>)
+  && requires (Context& ctx, const Context& cctx) {
+    typename Context::iterator;
+    typename Context::char_type;
+    requires std::same_as<typename Context::template formatter_type<int>,
+			  std::formatter<int, typename Context::char_type>>;
+    { ctx.locale() } -> std::same_as<std::locale>;
+    { ctx.out() } -> std::same_as<typename Context::iterator>;
+    { ctx.advance_to(ctx.out()) } -> std::same_as<void>;
+    { cctx.arg(1) } -> std::same_as<std::basic_format_arg<Context>>;
+  };
+
+template<typename Out, typename charT>
+constexpr bool
+check(std::basic_format_context<Out, charT>*)
+{
+  using context = std::basic_format_context<Out, charT>;
+  static_assert( format_context_reqs<context> );
+  static_assert( std::is_same_v<typename context::iterator, Out> );
+  static_assert( std::is_same_v<typename context::char_type, charT> );
+  return true;
+}
+
+static_assert( check( (std::format_context*)nullptr) );
+static_assert( check( (std::wformat_context*)nullptr) );
+static_assert( check( (std::basic_format_context<char*, char>*)nullptr) );

commit a78480c4e92f6aa2e4b736fd393037df2267b7f8
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Thu Jul 25 14:52:12 2024

    libstdc++: Remove std::basic_format_args default constructor (LWG 4106)
    
    There's no valid use case for default constructing this type, so the
    committee approved removing the default constructor.
    
    libstdc++-v3/ChangeLog:
    
            * include/std/format (basic_format_args): Remove default
            constructor, as per LWG 4106.
            * testsuite/std/format/arguments/args.cc: Check it isn't default
            constructible.
    
    (cherry picked from commit 5be55447e256302324f38f04316a437909ae5847)

diff --git a/libstdc++-v3/include/std/format b/libstdc++-v3/include/std/format
index 16cee0d3c74..8f6a82a1fd4 100644
--- a/libstdc++-v3/include/std/format
+++ b/libstdc++-v3/include/std/format
@@ -3667,8 +3667,6 @@ namespace __format
 	{ return {_Format_arg::template _S_to_enum<_Args>()...}; }
 
     public:
-      basic_format_args() noexcept = default;
-
       template<typename... _Args>
 	basic_format_args(const _Store<_Args...>& __store) noexcept;
 
diff --git a/libstdc++-v3/testsuite/std/format/arguments/args.cc b/libstdc++-v3/testsuite/std/format/arguments/args.cc
index eba129ff894..16ca71caecb 100644
--- a/libstdc++-v3/testsuite/std/format/arguments/args.cc
+++ b/libstdc++-v3/testsuite/std/format/arguments/args.cc
@@ -3,6 +3,10 @@
 #include <format>
 #include <testsuite_hooks.h>
 
+// LWG 4106. basic_format_args should not be default-constructible
+static_assert( ! std::is_default_constructible_v<std::format_args> );
+static_assert( ! std::is_default_constructible_v<std::wformat_args> );
+
 template<typename Ctx, typename T>
 bool equals(std::basic_format_arg<Ctx> fmt_arg, T expected) {
   return std::visit_format_arg([=](auto arg_val) {

commit d8e564539f20a409302e6a692188ce4f5eedab68
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Mon Jun 10 15:08:16 2024

    libstdc++: Fix std::tr2::dynamic_bitset shift operations [PR115399]
    
    The shift operations for dynamic_bitset fail to zero out words where the
    non-zero bits were shifted to a completely different word.
    
    For a right shift we don't need to sanitize the unused bits in the high
    word, because we know they were already clear and a right shift doesn't
    change that.
    
    libstdc++-v3/ChangeLog:
    
            PR libstdc++/115399
            * include/tr2/dynamic_bitset (operator>>=): Remove redundant
            call to _M_do_sanitize.
            * include/tr2/dynamic_bitset.tcc (_M_do_left_shift): Zero out
            low bits in words that should no longer be populated.
            (_M_do_right_shift): Likewise for high bits.
            * testsuite/tr2/dynamic_bitset/pr115399.cc: New test.
    
    (cherry picked from commit bd3a312728fbf8c35a09239b9180269f938f872e)

diff --git a/libstdc++-v3/include/tr2/dynamic_bitset b/libstdc++-v3/include/tr2/dynamic_bitset
index 0e4e8894287..274c4f6a138 100644
--- a/libstdc++-v3/include/tr2/dynamic_bitset
+++ b/libstdc++-v3/include/tr2/dynamic_bitset
@@ -815,10 +815,7 @@ namespace tr2
       operator>>=(size_type __pos)
       {
 	if (__builtin_expect(__pos < this->_M_Nb, 1))
-	  {
-	    this->_M_do_right_shift(__pos);
-	    this->_M_do_sanitize();
-	  }
+	  this->_M_do_right_shift(__pos);
 	else
 	  this->_M_do_reset();
 	return *this;
diff --git a/libstdc++-v3/include/tr2/dynamic_bitset.tcc b/libstdc++-v3/include/tr2/dynamic_bitset.tcc
index 63ba6f285c7..5aac7d88ee3 100644
--- a/libstdc++-v3/include/tr2/dynamic_bitset.tcc
+++ b/libstdc++-v3/include/tr2/dynamic_bitset.tcc
@@ -60,8 +60,7 @@ namespace tr2
 	      this->_M_w[__wshift] = this->_M_w[0] << __offset;
 	    }
 
-	  //// std::fill(this->_M_w.begin(), this->_M_w.begin() + __wshift,
-	  ////          static_cast<_WordT>(0));
+	  std::fill_n(this->_M_w.begin(), __wshift, _WordT(0));
 	}
     }
 
@@ -88,8 +87,7 @@ namespace tr2
 	      this->_M_w[__limit] = this->_M_w[_M_w.size()-1] >> __offset;
 	    }
 
-	  ////std::fill(this->_M_w.begin() + __limit + 1, this->_M_w.end(),
-	  ////          static_cast<_WordT>(0));
+	  std::fill_n(this->_M_w.end() - __wshift, __wshift, _WordT(0));
 	}
     }
 
diff --git a/libstdc++-v3/testsuite/tr2/dynamic_bitset/pr115399.cc b/libstdc++-v3/testsuite/tr2/dynamic_bitset/pr115399.cc
new file mode 100644
index 00000000000..e626e4a5d15
--- /dev/null
+++ b/libstdc++-v3/testsuite/tr2/dynamic_bitset/pr115399.cc
@@ -0,0 +1,37 @@
+// { dg-do run { target c++11 } }
+
+// PR libstdc++/115399
+// std::tr2::dynamic_bitset shift behaves differently from std::bitset
+
+#include <tr2/dynamic_bitset>
+#include <testsuite_hooks.h>
+
+void
+test_left_shift()
+{
+  std::tr2::dynamic_bitset<> b(65);
+  b[0] = 1;
+  auto b2 = b << 64;
+  VERIFY(b2[64] == 1);
+  VERIFY(b2[0] == 0);
+  b <<= 64;
+  VERIFY( b2 == b );
+}
+
+void
+test_right_shift()
+{
+  std::tr2::dynamic_bitset<> b(65);
+  b[64] = 1;
+  auto b2 = b >> 64;
+  VERIFY(b2[64] == 0);
+  VERIFY(b2[0] == 1);
+  b >>= 64;
+  VERIFY( b2 == b );
+}
+
+int main()
+{
+  test_left_shift();
+  test_right_shift();
+}

commit 8d52ae39b9d80b5f4e27294960752a57211020aa
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Thu Jun 20 17:13:10 2024

    libstdc++: Initialize base in test allocator's constructor
    
    This fixes a warning from one of the test allocators:
    warning: base class 'class std::allocator<__gnu_test::copy_tracker>' should be explicitly initialized in the copy constructor [-Wextra]
    
    libstdc++-v3/ChangeLog:
    
            * testsuite/util/testsuite_allocator.h (tracker_allocator):
            Initialize base class in copy constructor.
    
    (cherry picked from commit e2fb245b07f489ed5bfd9a945e0053b4a3211245)

diff --git a/libstdc++-v3/testsuite/util/testsuite_allocator.h b/libstdc++-v3/testsuite/util/testsuite_allocator.h
index b7739f13ca3..2f9c453cbd1 100644
--- a/libstdc++-v3/testsuite/util/testsuite_allocator.h
+++ b/libstdc++-v3/testsuite/util/testsuite_allocator.h
@@ -154,7 +154,7 @@ namespace __gnu_test
       tracker_allocator()
       { }
 
-      tracker_allocator(const tracker_allocator&)
+      tracker_allocator(const tracker_allocator& a) : Alloc(a)
       { }
 
       ~tracker_allocator()

commit c79e73e7eda6c6c113ad4a6a88d798ef2da917fd
Author: Deev Patel <dkp10000@gmail.com>
Date:   Thu Jun 6 12:53:25 2024

    libstdc++: Add missing constexpr to __atomic_impl::__clear_padding
    
    This is called from the std::atomic<floating-point-type> constructor,
    which needs to be usable in constant expressions.
    
    libstdc++-v3/ChangeLog:
    
            * include/bits/atomic_base.h (__atomic_impl::__clear_padding):
            Add missing constexpr specifier.
            * testsuite/29_atomics/atomic_float/constinit.cc: New test.
    
    Co-authored-by: Jonathan Wakely <jwakely@redhat.com>
    (cherry picked from commit ae91b5dd14920ff9671db8ff80c0d763d25f977f)

diff --git a/libstdc++-v3/include/bits/atomic_base.h b/libstdc++-v3/include/bits/atomic_base.h
index dd360302f80..3a23c7881cd 100644
--- a/libstdc++-v3/include/bits/atomic_base.h
+++ b/libstdc++-v3/include/bits/atomic_base.h
@@ -968,7 +968,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
       }
 
     template<typename _Tp>
-      _GLIBCXX_ALWAYS_INLINE _Tp*
+      _GLIBCXX_ALWAYS_INLINE _GLIBCXX14_CONSTEXPR _Tp*
       __clear_padding(_Tp& __val) noexcept
       {
 	auto* __ptr = std::__addressof(__val);
diff --git a/libstdc++-v3/testsuite/29_atomics/atomic_float/constinit.cc b/libstdc++-v3/testsuite/29_atomics/atomic_float/constinit.cc
new file mode 100644
index 00000000000..6b3f4f76b4c
--- /dev/null
+++ b/libstdc++-v3/testsuite/29_atomics/atomic_float/constinit.cc
@@ -0,0 +1,3 @@
+// { dg-do compile { target c++20 } }
+#include <atomic>
+constinit std::atomic<float> a(0.0f);

commit c6372417e50bf4d094dac720b5f091c0d4aa7e2d
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Wed May 22 19:38:36 2024

    libstdc++: Add [[nodiscard]] to some std::locale functions
    
    libstdc++-v3/ChangeLog:
    
            * include/bits/locale_classes.h (locale::combine)
            (locale::name, locale::operator==, locale::operator!=)
            (locale::operator(), locale::classic): Add nodiscard
            attribute.
            * include/bits/locale_classes.tcc (has_facet, use_facet):
            Likewise.
            * testsuite/22_locale/locale/cons/12438.cc: Add dg-warning for
            nodiscard diagnostic.
            * testsuite/22_locale/locale/cons/2.cc: Cast use_facet
            expression to void, to suppress diagnostic.
            * testsuite/22_locale/locale/cons/unicode.cc: Likewise.
            * testsuite/22_locale/locale/operations/2.cc: Add dg-warning.
    
    (cherry picked from commit fd1a674ff5f37e74fbbdcdb85d78399e963eb401)

diff --git a/libstdc++-v3/include/bits/locale_classes.h b/libstdc++-v3/include/bits/locale_classes.h
index a2e94217006..50a748066f1 100644
--- a/libstdc++-v3/include/bits/locale_classes.h
+++ b/libstdc++-v3/include/bits/locale_classes.h
@@ -240,6 +240,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
      *  @throw  std::runtime_error if __other has no facet of type _Facet.
     */
     template<typename _Facet>
+      _GLIBCXX_NODISCARD
       locale
       combine(const locale& __other) const;
 
@@ -248,7 +249,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
      *  @brief  Return locale name.
      *  @return  Locale name or "*" if unnamed.
     */
-    _GLIBCXX_DEFAULT_ABI_TAG
+    _GLIBCXX_NODISCARD _GLIBCXX_DEFAULT_ABI_TAG
     string
     name() const;
 
@@ -269,6 +270,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
      *  @return  True if other and this refer to the same locale instance, are
      *		 copies, or have the same name.  False otherwise.
     */
+    _GLIBCXX_NODISCARD
     bool
     operator==(const locale& __other) const throw();
 
@@ -279,6 +281,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
      *  @param  __other  The locale to compare against.
      *  @return  ! (*this == __other)
     */
+    _GLIBCXX_NODISCARD
     bool
     operator!=(const locale& __other) const throw()
     { return !(this->operator==(__other)); }
@@ -300,6 +303,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
      *  @return  True if collate<_Char> facet compares __s1 < __s2, else false.
     */
     template<typename _Char, typename _Traits, typename _Alloc>
+      _GLIBCXX_NODISCARD
       bool
       operator()(const basic_string<_Char, _Traits, _Alloc>& __s1,
 		 const basic_string<_Char, _Traits, _Alloc>& __s2) const;
@@ -321,6 +325,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
     /**
      *  @brief  Return reference to the C locale.
     */
+    _GLIBCXX_NODISCARD
     static const locale&
     classic();
 
diff --git a/libstdc++-v3/include/bits/locale_classes.tcc b/libstdc++-v3/include/bits/locale_classes.tcc
index 63097582dec..6d3de23e8c0 100644
--- a/libstdc++-v3/include/bits/locale_classes.tcc
+++ b/libstdc++-v3/include/bits/locale_classes.tcc
@@ -162,6 +162,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
    *  @return  true if @p __loc contains a facet of type _Facet, else false.
   */
   template<typename _Facet>
+    _GLIBCXX_NODISCARD
     inline bool
     has_facet(const locale& __loc) throw()
     {
@@ -191,6 +192,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wdangling-reference"
   template<typename _Facet>
+    _GLIBCXX_NODISCARD
     inline const _Facet&
     use_facet(const locale& __loc)
     {
diff --git a/libstdc++-v3/testsuite/22_locale/locale/cons/12438.cc b/libstdc++-v3/testsuite/22_locale/locale/cons/12438.cc
index 7ff3a487745..4838e1ba693 100644
--- a/libstdc++-v3/testsuite/22_locale/locale/cons/12438.cc
+++ b/libstdc++-v3/testsuite/22_locale/locale/cons/12438.cc
@@ -45,7 +45,7 @@ void test01(int iters)
 	  locale loc2 = locale("");
 	  VERIFY( !has_facet<MyFacet>(loc2) );
 	  
-	  loc1.combine<MyFacet>(loc2);
+	  loc1.combine<MyFacet>(loc2); // { dg-warning "nodiscard" "" { target c++17 } }
 	  VERIFY( false );
 	}
       catch (std::runtime_error&)
diff --git a/libstdc++-v3/testsuite/22_locale/locale/cons/2.cc b/libstdc++-v3/testsuite/22_locale/locale/cons/2.cc
index 12478dbfdc2..dce150effea 100644
--- a/libstdc++-v3/testsuite/22_locale/locale/cons/2.cc
+++ b/libstdc++-v3/testsuite/22_locale/locale/cons/2.cc
@@ -68,7 +68,7 @@ void test01()
     { VERIFY( false ); }
 
   try 
-    { use_facet<gnu_facet>(loc02); }
+    { (void) use_facet<gnu_facet>(loc02); }
   catch(bad_cast& obj)
     { VERIFY( true ); }
   catch(...)
diff --git a/libstdc++-v3/testsuite/22_locale/locale/cons/unicode.cc b/libstdc++-v3/testsuite/22_locale/locale/cons/unicode.cc
index 24af4142cd9..98d744de91e 100644
--- a/libstdc++-v3/testsuite/22_locale/locale/cons/unicode.cc
+++ b/libstdc++-v3/testsuite/22_locale/locale/cons/unicode.cc
@@ -79,7 +79,7 @@ void test01()
     { VERIFY( false ); }
 
   try 
-    { use_facet<gnu_facet>(loc13); }
+    { (void) use_facet<gnu_facet>(loc13); }
   catch(bad_cast& obj)
     { VERIFY( true ); }
   catch(...)
diff --git a/libstdc++-v3/testsuite/22_locale/locale/operations/2.cc b/libstdc++-v3/testsuite/22_locale/locale/operations/2.cc
index 899535137ba..917adecac56 100644
--- a/libstdc++-v3/testsuite/22_locale/locale/operations/2.cc
+++ b/libstdc++-v3/testsuite/22_locale/locale/operations/2.cc
@@ -48,7 +48,7 @@ void test02()
   // Derivation, MF check.
   locale loc_gnu(loc_c, new gnu_collate);
   gnu_count = 0;
-  loc_gnu(s01, s02);
+  loc_gnu(s01, s02); // { dg-warning "nodiscard" "" { target c++17 } }
   VERIFY( gnu_count == 1 );
 }
 

commit fb8da401213dd23b098400d641ca527e09d59c9e
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Fri Aug 2 02:23:49 2024

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 2de0bedcd49..d828c55306f 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,14 @@
+2024-08-01  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2024-08-01  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/115981
+	* config/i386/sse.md
+	(*<extract_type>_vinsert<shuffletype><extract_suf>_0): Swap the
+	first two VEC_MERGE operands, renumber match_operands and test
+	for 0xF or 0x3 rather than 0xFFF0 or 0xFC immediate.
+
 2024-08-01  Release Manager
 
 	* GCC 14.2.0 released.
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 5b64322fc60..ba6415cbd75 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240801
+20240802
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 65a87525570..794d365f469 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,13 @@
+2024-08-01  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2024-08-01  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/115981
+	* gcc.target/i386/avx512dq-pr90991-1.c: Add tests for no separate
+	zero extension instructions.
+	* gcc.target/i386/avx512dq-pr90991-2.c: Likewise.
+
 2024-08-01  Release Manager
 
 	* GCC 14.2.0 released.
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index 2cb6f88ab5a..5687e8fc11a 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,142 @@
+2024-08-01  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-05-22  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/bits/locale_classes.h (locale::combine)
+	(locale::name, locale::operator==, locale::operator!=)
+	(locale::operator(), locale::classic): Add nodiscard
+	attribute.
+	* include/bits/locale_classes.tcc (has_facet, use_facet):
+	Likewise.
+	* testsuite/22_locale/locale/cons/12438.cc: Add dg-warning for
+	nodiscard diagnostic.
+	* testsuite/22_locale/locale/cons/2.cc: Cast use_facet
+	expression to void, to suppress diagnostic.
+	* testsuite/22_locale/locale/cons/unicode.cc: Likewise.
+	* testsuite/22_locale/locale/operations/2.cc: Add dg-warning.
+
+2024-08-01  Deev Patel  <dkp10000@gmail.com>
+
+	Backported from master:
+	2024-06-08  Deev Patel  <dkp10000@gmail.com>
+		    Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/bits/atomic_base.h (__atomic_impl::__clear_padding):
+	Add missing constexpr specifier.
+	* testsuite/29_atomics/atomic_float/constinit.cc: New test.
+
+2024-08-01  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-06-21  Jonathan Wakely  <jwakely@redhat.com>
+
+	* testsuite/util/testsuite_allocator.h (tracker_allocator):
+	Initialize base class in copy constructor.
+
+2024-08-01  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-06-12  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/115399
+	* include/tr2/dynamic_bitset (operator>>=): Remove redundant
+	call to _M_do_sanitize.
+	* include/tr2/dynamic_bitset.tcc (_M_do_left_shift): Zero out
+	low bits in words that should no longer be populated.
+	(_M_do_right_shift): Likewise for high bits.
+	* testsuite/tr2/dynamic_bitset/pr115399.cc: New test.
+
+2024-08-01  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-07-25  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/std/format (basic_format_args): Remove default
+	constructor, as per LWG 4106.
+	* testsuite/std/format/arguments/args.cc: Check it isn't default
+	constructible.
+
+2024-08-01  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-07-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/114387
+	* include/std/format (basic_format_context): Define copy
+	operations as deleted, as per LWG 4061.
+	* testsuite/std/format/context.cc: New test.
+
+2024-08-01  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-06-21  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/std/any (any_cast(any*), any_cast(const any*)): Add
+	static assertion to reject void types, as per LWG 3305.
+	* testsuite/20_util/any/misc/lwg3305.cc: New test.
+
+2024-08-01  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-06-08  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/std/algorithm: Define __glibcxx_want_ranges.
+	* testsuite/25_algorithms/headers/algorithm/synopsis.cc: Check
+	feature test macro in C++20 mode.
+
+2024-08-01  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-07-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/115854
+	* include/bits/stl_bvector.h (_Bvector_base): Convert allocator
+	to rebound type explicitly.
+	* testsuite/23_containers/vector/allocator/115854.cc: New test.
+	* testsuite/23_containers/vector/bool/allocator/115854.cc: New test.
+
+2024-08-01  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-06-13  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/bits/ranges_base.h (const_iterator_t): Change
+	preprocessor condition to use __glibcxx_ranges_as_const.
+	(const_sentinel_t, range_const_reference_t): Likewise.
+	(__access::__possibly_const_range, cbegin, cend, crbegin)
+	(crend, cdata): Likewise.
+	* include/bits/stl_iterator.h (iter_const_reference_t)
+	(basic_const_iterator, const_iterator, const_sentinel)
+	(make_const_iterator): Likewise.
+
+2024-08-01  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-07-06  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/std/variant (_Variant_storage::_M_reset): Use
+	__unlikely__ form of attribute instead of unlikely.
+
+2024-08-01  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-07-24  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/116070
+	* include/std/istream: Check feature test macro before using
+	is_class_v and is_same_v.
+	* include/std/ostream: Likewise.
+
+2024-08-01  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-07-24  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/116070
+	* include/bits/stl_bvector.h: Check feature test macro before
+	using is_default_constructible_v.
+
 2024-08-01  Release Manager
 
 	* GCC 14.2.0 released.

commit 1287b4abc67a915ef6b63fb0753a0bea41de47f1
Author: Patrick Palka <ppalka@redhat.com>
Date:   Thu Jul 18 03:02:52 2024

    c++: prev declared hidden tmpl friend inst [PR112288]
    
    When partially instantiating a previously declared hidden template
    friend definition (at class template scope) such as slot_allocated in
    the first testcase below, tsubst_friend_function needs to go through
    all existing specializations thereof and make them point to the new
    definition.
    
    But when the previous declaration was also at class template scope,
    old_decl is not the most general template, instead it's the partial
    instantiation, and since instantiations are relative to the most general
    template, old_decl's DECL_TEMPLATE_INSTANTIATIONS is empty.  So we
    to consistently use the most general template here.  And when adjusting
    DECL_TI_ARGS to match, only the innermost template arguments should be
    preserved; the outer ones should correspond to the new definition.
    
    Otherwise we fail a checking-only sanity check in instantiate_decl in
    the first testcase, and in the second/third we end up emitting multiple
    definitions of the template friend instantiation, resulting in a link
    failure.
    
            PR c++/112288
    
    gcc/cp/ChangeLog:
    
            * pt.cc (tsubst_friend_function): When adjusting existing
            specializations after defining a previously declared template
            friend, consider the most general template and correct
            DECL_TI_ARGS adjustment.
    
    gcc/testsuite/ChangeLog:
    
            * g++.dg/template/friend80.C: New test.
            * g++.dg/template/friend81.C: New test.
            * g++.dg/template/friend81a.C: New test.
    
    Reviewed-by: Jason Merrill <jason@redhat.com>
    (cherry picked from commit 30dd420a06ad7d2adf4a672d176caee632f8168a)

diff --git a/gcc/cp/pt.cc b/gcc/cp/pt.cc
index 80d0ca6d0dd..713946a1ff1 100644
--- a/gcc/cp/pt.cc
+++ b/gcc/cp/pt.cc
@@ -11582,6 +11582,7 @@ tsubst_friend_function (tree decl, tree args)
 	    ;
 	  else
 	    {
+	      tree old_template = most_general_template (old_decl);
 	      tree new_template = TI_TEMPLATE (new_friend_template_info);
 	      tree new_args = TI_ARGS (new_friend_template_info);
 
@@ -11619,7 +11620,7 @@ tsubst_friend_function (tree decl, tree args)
 		  /* Reassign any specializations already in the hash table
 		     to the new more general template, and add the
 		     additional template args.  */
-		  for (t = DECL_TEMPLATE_INSTANTIATIONS (old_decl);
+		  for (t = DECL_TEMPLATE_INSTANTIATIONS (old_template);
 		       t != NULL_TREE;
 		       t = TREE_CHAIN (t))
 		    {
@@ -11632,15 +11633,15 @@ tsubst_friend_function (tree decl, tree args)
 
 		      decl_specializations->remove_elt (&elt);
 
-		      DECL_TI_ARGS (spec)
-			= add_outermost_template_args (new_args,
-						       DECL_TI_ARGS (spec));
+		      tree& spec_args = DECL_TI_ARGS (spec);
+		      spec_args = add_outermost_template_args
+			(new_args, INNERMOST_TEMPLATE_ARGS (spec_args));
 
 		      register_specialization
-			(spec, new_template, DECL_TI_ARGS (spec), true, 0);
+			(spec, new_template, spec_args, true, 0);
 
 		    }
-		  DECL_TEMPLATE_INSTANTIATIONS (old_decl) = NULL_TREE;
+		  DECL_TEMPLATE_INSTANTIATIONS (old_template) = NULL_TREE;
 		}
 	    }
 
diff --git a/gcc/testsuite/g++.dg/template/friend80.C b/gcc/testsuite/g++.dg/template/friend80.C
new file mode 100644
index 00000000000..5c417e12dd0
--- /dev/null
+++ b/gcc/testsuite/g++.dg/template/friend80.C
@@ -0,0 +1,25 @@
+// PR c++/112288
+// { dg-do compile { target c++11 } }
+
+template<class T>
+struct slot {
+  template<class U>
+  friend constexpr bool slot_allocated(slot<T>, U);
+};
+
+template<class T>
+struct allocate_slot {
+  template<class U>
+  friend constexpr bool slot_allocated(slot<T>, U) { return true; }
+};
+
+template<class T, bool = slot_allocated(slot<T>{}, 42)>
+constexpr int next(int) { return 1; }
+
+template<class T>
+constexpr int next(...) { return (allocate_slot<T>{}, 0); }
+
+// slot_allocated<slot<int>, int>() not defined yet
+static_assert(next<int>(0) == 0, "");
+// now it's defined, need to make existing spec point to defn or else ICE
+static_assert(next<int>(0) == 1, "");
diff --git a/gcc/testsuite/g++.dg/template/friend81.C b/gcc/testsuite/g++.dg/template/friend81.C
new file mode 100644
index 00000000000..5d3a2889c0f
--- /dev/null
+++ b/gcc/testsuite/g++.dg/template/friend81.C
@@ -0,0 +1,28 @@
+// PR c++/112288
+// { dg-do link }
+
+template<class T> struct A;
+template<class T> struct B;
+
+A<int>* a;
+B<int>* b;
+
+template<class T>
+struct B {
+  template<class U>
+  friend int f(A<T>*, B*, U);
+};
+
+template struct B<int>; // f declared
+int n = f(a, b, 0); // f<int> specialized
+
+template<class T>
+struct A {
+  template<class U>
+  friend int f(A*, B<T>*, U) { return 42; }
+};
+
+template struct A<int>; // f defined, need to make existing f<int> point to defn
+int m = f(a, b, 0); // reuses existing specialization f<int>
+
+int main() { }
diff --git a/gcc/testsuite/g++.dg/template/friend81a.C b/gcc/testsuite/g++.dg/template/friend81a.C
new file mode 100644
index 00000000000..4557fd3c03a
--- /dev/null
+++ b/gcc/testsuite/g++.dg/template/friend81a.C
@@ -0,0 +1,30 @@
+// PR c++/112288
+// { dg-do link }
+// A version of friend81.C where A and B have a different number of template
+// parameters.
+
+template<class T> struct A;
+template<class T, class = void> struct B;
+
+A<int>* a;
+B<int>* b;
+
+template<class T, class>
+struct B {
+  template<class U>
+  friend int f(A<T>*, B*, U);
+};
+
+template struct B<int>; // f declared
+int n = f(a, b, 0); // f<int> specialized
+
+template<class T>
+struct A {
+  template<class U>
+  friend int f(A*, B<T>*, U) { return 42; }
+};
+
+template struct A<int>; // f defined, need to make existing f<int> point to defn
+int m = f(a, b, 0); // reuses existing specialization f<int>
+
+int main() { }

commit e548a881a4540378151f6195e47e8413fe75a0d6
Author: Patrick Palka <ppalka@redhat.com>
Date:   Tue Jul 23 17:37:31 2024

    c++: missing SFINAE during alias CTAD [PR115296]
    
    During the alias CTAD transformation, if substitution failed for some
    guide we should just silently discard the guide.  We currently do
    discard the guide, but not silently, as in the below testcase which
    we diagnose forming a too-large array type when transforming the
    user-defined deduction guides.
    
    This patch fixes this by using complain=tf_none instead of
    tf_warning_or_error throughout alias_ctad_tweaks.
    
            PR c++/115296
    
    gcc/cp/ChangeLog:
    
            * pt.cc (alias_ctad_tweaks): Use complain=tf_none instead of
            tf_warning_or_error.
    
    gcc/testsuite/ChangeLog:
    
            * g++.dg/cpp2a/class-deduction-alias23.C: New test.
    
    Reviewed-by: Jason Merrill <jason@redhat.com>
    (cherry picked from commit f70281222df432a7bec1271904c5ebefd7f2c934)

diff --git a/gcc/cp/pt.cc b/gcc/cp/pt.cc
index 713946a1ff1..13907858273 100644
--- a/gcc/cp/pt.cc
+++ b/gcc/cp/pt.cc
@@ -30369,7 +30369,7 @@ alias_ctad_tweaks (tree tmpl, tree uguides)
 			  (INNERMOST_TEMPLATE_PARMS (fullatparms)));
     }
 
-  tsubst_flags_t complain = tf_warning_or_error;
+  tsubst_flags_t complain = tf_none;
   tree aguides = NULL_TREE;
   tree atparms = INNERMOST_TEMPLATE_PARMS (fullatparms);
   unsigned natparms = TREE_VEC_LENGTH (atparms);
diff --git a/gcc/testsuite/g++.dg/cpp2a/class-deduction-alias23.C b/gcc/testsuite/g++.dg/cpp2a/class-deduction-alias23.C
new file mode 100644
index 00000000000..117212c67de
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp2a/class-deduction-alias23.C
@@ -0,0 +1,19 @@
+// PR c++/115296
+// { dg-do compile { target c++20 } }
+
+using size_t = decltype(sizeof(0));
+
+template<class T, size_t N = size_t(-1)>
+struct span { span(T); };
+
+template<class T, size_t N>
+span(T(&)[N]) -> span<T, N>; // { dg-bogus "array exceeds maximum" }
+
+template<class T, size_t N>
+requires (sizeof(T[N]) != 42) // { dg-bogus "array exceeds maximum" }
+span(T*) -> span<T, N>;
+
+template<class T>
+using array_view = span<T>;
+
+array_view x = 0;

commit 241f710c851aa6a8627c3ddba1e126d8e503e1b0
Author: Patrick Palka <ppalka@redhat.com>
Date:   Tue Jul 23 19:16:14 2024

    c++: normalizing ttp constraints [PR115656]
    
    Here we normalize the constraint same_as<T, bool> for the first
    time during ttp coercion of B / UU, specifically constraint subsumption
    checking.  During this normalization the set of in-scope template
    parameters i.e. current_template_parms is empty, which we rely on
    during normalization of the ttp constraints since we pass in_decl=NULL_TREE
    to norm_info.  And this tricks the satisfaction cache into thinking that
    the satisfaction value of same_as<T, bool> is independent of its template
    parameters, and we incorrectly conflate the satisfaction value with
    T = bool vs T = long and accept the specialization A<long, B>.
    
    Since is_compatible_template_arg rewrites the ttp's constraints to
    be in terms of the argument template's parameters, and since it's
    the only caller of weakly_subsumes, the latter funcion can instead
    pass in_decl=tmpl to avoid relying on current_template_parms.  This
    patch implements this, and in turns renames weakly_subsumes to
    ttp_subsumes to reflect that this predicate is now hardcoded for this
    one caller.
    
            PR c++/115656
    
    gcc/cp/ChangeLog:
    
            * constraint.cc (weakly_subsumes): Pass in_decl=tmpl to
            get_normalized_constraints_from_info.  Rename to ...
            (ttp_subsumes): ... this.
            * cp-tree.h (weakly_subsumes): Rename to ...
            (ttp_subsumes): ... this.
            * pt.cc (is_compatible_template_arg): Adjust after renaming.
    
    gcc/testsuite/ChangeLog:
    
            * g++.dg/cpp2a/concepts-ttp7.C: New test.
    
    Reviewed-by: Jason Merrill <jason@redhat.com>
    (cherry picked from commit 2861eb34e30973cb991a7964af7cfeae014a98b0)

diff --git a/gcc/cp/constraint.cc b/gcc/cp/constraint.cc
index 8a3b5d80ba7..b6c6a5e2330 100644
--- a/gcc/cp/constraint.cc
+++ b/gcc/cp/constraint.cc
@@ -3610,13 +3610,14 @@ strictly_subsumes (tree ci, tree tmpl)
   return subsumes (n1, n2) && !subsumes (n2, n1);
 }
 
-/* Returns true when the constraints in CI subsume the
-   associated constraints of TMPL.  */
+/* Returns true when the template template parameter constraints in CI
+   subsume the associated constraints of the template template argument
+   TMPL.  */
 
 bool
-weakly_subsumes (tree ci, tree tmpl)
+ttp_subsumes (tree ci, tree tmpl)
 {
-  tree n1 = get_normalized_constraints_from_info (ci, NULL_TREE);
+  tree n1 = get_normalized_constraints_from_info (ci, tmpl);
   tree n2 = get_normalized_constraints_from_decl (tmpl);
 
   return subsumes (n1, n2);
diff --git a/gcc/cp/cp-tree.h b/gcc/cp/cp-tree.h
index ed637015a93..3f607313db6 100644
--- a/gcc/cp/cp-tree.h
+++ b/gcc/cp/cp-tree.h
@@ -8606,7 +8606,7 @@ extern tree find_template_parameters		(tree, tree);
 extern bool equivalent_constraints              (tree, tree);
 extern bool equivalently_constrained            (tree, tree);
 extern bool strictly_subsumes			(tree, tree);
-extern bool weakly_subsumes			(tree, tree);
+extern bool ttp_subsumes			(tree, tree);
 extern int more_constrained                     (tree, tree);
 extern bool at_least_as_constrained             (tree, tree);
 extern bool constraints_equivalent_p            (tree, tree);
diff --git a/gcc/cp/pt.cc b/gcc/cp/pt.cc
index 13907858273..ea4a6c9bf53 100644
--- a/gcc/cp/pt.cc
+++ b/gcc/cp/pt.cc
@@ -8504,7 +8504,7 @@ is_compatible_template_arg (tree parm, tree arg, tree args)
         return false;
     }
 
-  return weakly_subsumes (parm_cons, arg);
+  return ttp_subsumes (parm_cons, arg);
 }
 
 // Convert a placeholder argument into a binding to the original
diff --git a/gcc/testsuite/g++.dg/cpp2a/concepts-ttp7.C b/gcc/testsuite/g++.dg/cpp2a/concepts-ttp7.C
new file mode 100644
index 00000000000..2ce884b995c
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp2a/concepts-ttp7.C
@@ -0,0 +1,12 @@
+// PR c++/115656
+// { dg-do compile { target c++20 } }
+
+template<class T, class U> concept same_as = __is_same(T, U);
+
+template<same_as<bool> T, template<same_as<bool>> class UU>
+struct A { };
+
+template<same_as<bool>> class B;
+
+A<bool, B> a1;
+A<long, B> a2; // { dg-error "constraint failure" }

commit 59e3934346f4546d7ef4fc82d300644b52bcefb0
Author: Patrick Palka <ppalka@redhat.com>
Date:   Thu Jul 25 15:02:13 2024

    libstdc++: fix uses of explicit object parameter [PR116038]
    
    The type of an implicit object parameter is always the current class.
    For an explicit object parameter however, its deduced type can be a
    derived class of the current class.  So when combining multiple
    implicit-object overloads into a single explicit-object overload we need
    to account for this possibility.  For example when accessing a member of
    the current class through an explicit object parameter, it may now be a
    derived class from which the member is not accessible, as in the below
    testcases.
    
    This pitfall is discussed[1] in the deducing this paper.  The general
    solution is to cast the explicit object parameter to (a reference to)
    the current class rather than e.g. using std::forward which preserves
    the deduced type.
    
    This patch corrects the existing problematic uses of explicit object
    parameters in the library, all of which forward the parameter via
    std::forward, to instead cast the parameter to the current class via
    our __like_t alias template.  Note that unlike the paper's like_t,
    ours always returns a reference so we can just write
    
      __like_t<Self, B>(self)
    
    instead of
    
      (_like_t<Self, B>&&)self
    
    as the paper does.
    
    [1]: https://wg21.link/P0847#name-lookup-within-member-functions (and the
    section after that)
    
            PR libstdc++/116038
    
    libstdc++-v3/ChangeLog:
    
            * include/std/functional (_Bind_front::operator()): Use __like_t
            instead of std::forward when forwarding __self.
            (_Bind_back::operator()): Likewise.
            * include/std/ranges (_Partial::operator()): Likewise.
            (_Pipe::operator()): Likewise.
            * testsuite/20_util/function_objects/bind_back/116038.cc: New test.
            * testsuite/20_util/function_objects/bind_front/116038.cc: New test.
            * testsuite/std/ranges/adaptors/116038.cc: New test.
    
    Reviewed-by: Jonathan Wakely <jwakely@redhat.com>
    (cherry picked from commit 1066a95aa33eee2d2bd9c8324f34dedb967f338c)

diff --git a/libstdc++-v3/include/std/functional b/libstdc++-v3/include/std/functional
index 99364286a72..7788a963757 100644
--- a/libstdc++-v3/include/std/functional
+++ b/libstdc++-v3/include/std/functional
@@ -944,7 +944,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
 	noexcept(is_nothrow_invocable_v<__like_t<_Self, _Fd>,
 					__like_t<_Self, _BoundArgs>..., _CallArgs...>)
 	{
-	  return _S_call(std::forward<_Self>(__self), _BoundIndices(),
+	  return _S_call(__like_t<_Self, _Bind_front>(__self), _BoundIndices(),
 			 std::forward<_CallArgs>(__call_args)...);
 	}
 #else
@@ -1072,7 +1072,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
 	noexcept(is_nothrow_invocable_v<__like_t<_Self, _Fd>,
 					_CallArgs..., __like_t<_Self, _BoundArgs>...>)
 	{
-	  return _S_call(std::forward<_Self>(__self), _BoundIndices(),
+	  return _S_call(__like_t<_Self, _Bind_back>(__self), _BoundIndices(),
 			 std::forward<_CallArgs>(__call_args)...);
 	}
 
diff --git a/libstdc++-v3/include/std/ranges b/libstdc++-v3/include/std/ranges
index afce818376b..59a25153620 100644
--- a/libstdc++-v3/include/std/ranges
+++ b/libstdc++-v3/include/std/ranges
@@ -1032,7 +1032,7 @@ namespace views::__adaptor
 	    return _Adaptor{}(std::forward<_Range>(__r),
 			      std::forward<decltype(__args)>(__args)...);
 	  };
-	  return std::apply(__forwarder, std::forward<_Self>(__self)._M_args);
+	  return std::apply(__forwarder, __like_t<_Self, _Partial>(__self)._M_args);
 	}
 #else
       template<typename _Range>
@@ -1081,7 +1081,10 @@ namespace views::__adaptor
 	requires __adaptor_invocable<_Adaptor, _Range, __like_t<_Self, _Arg>>
 	constexpr auto
 	operator()(this _Self&& __self, _Range&& __r)
-	{ return _Adaptor{}(std::forward<_Range>(__r), std::forward<_Self>(__self)._M_arg); }
+	{
+	  return _Adaptor{}(std::forward<_Range>(__r),
+			    __like_t<_Self, _Partial>(__self)._M_arg);
+	}
 #else
       template<typename _Range>
 	requires __adaptor_invocable<_Adaptor, _Range, const _Arg&>
@@ -1184,8 +1187,8 @@ namespace views::__adaptor
 	constexpr auto
 	operator()(this _Self&& __self, _Range&& __r)
 	{
-	  return (std::forward<_Self>(__self)._M_rhs
-		  (std::forward<_Self>(__self)._M_lhs
+	  return (__like_t<_Self, _Pipe>(__self)._M_rhs
+		  (__like_t<_Self, _Pipe>(__self)._M_lhs
 		   (std::forward<_Range>(__r))));
 	}
 #else
diff --git a/libstdc++-v3/testsuite/20_util/function_objects/bind_back/116038.cc b/libstdc++-v3/testsuite/20_util/function_objects/bind_back/116038.cc
new file mode 100644
index 00000000000..ed392b1434e
--- /dev/null
+++ b/libstdc++-v3/testsuite/20_util/function_objects/bind_back/116038.cc
@@ -0,0 +1,27 @@
+// PR libstdc++/116038
+// { dg-do compile { target c++23 } }
+
+#include <functional>
+#include <utility>
+
+struct A { };
+struct B { };
+
+template<class... Ts>
+struct overloaded : private Ts... {
+  overloaded(Ts...);
+  using Ts::operator()...;
+};
+
+int apply_a(A, int);
+int apply_b(B, int);
+
+int main() {
+  overloaded o = { std::bind_back(apply_a, 1),
+		   std::bind_back(apply_b, 2) };
+  A a;
+  o(a);
+  std::as_const(o)(a);
+  std::move(o)(a);
+  std::move(std::as_const(o))(a);
+}
diff --git a/libstdc++-v3/testsuite/20_util/function_objects/bind_front/116038.cc b/libstdc++-v3/testsuite/20_util/function_objects/bind_front/116038.cc
new file mode 100644
index 00000000000..3bf1226375b
--- /dev/null
+++ b/libstdc++-v3/testsuite/20_util/function_objects/bind_front/116038.cc
@@ -0,0 +1,27 @@
+// PR libstdc++/116038
+// { dg-do compile { target c++20 } }
+
+#include <functional>
+#include <utility>
+
+struct A { };
+struct B { };
+
+template<class... Ts>
+struct overloaded : private Ts... {
+  overloaded(Ts...);
+  using Ts::operator()...;
+};
+
+int apply_a(int, A);
+int apply_b(int, B);
+
+int main() {
+  overloaded o = { std::bind_front(apply_a, 1),
+		   std::bind_front(apply_b, 2) };
+  A a;
+  o(a);
+  std::as_const(o)(a);
+  std::move(o)(a);
+  std::move(std::as_const(o))(a);
+}
diff --git a/libstdc++-v3/testsuite/std/ranges/adaptors/116038.cc b/libstdc++-v3/testsuite/std/ranges/adaptors/116038.cc
new file mode 100644
index 00000000000..1afdf3d06d1
--- /dev/null
+++ b/libstdc++-v3/testsuite/std/ranges/adaptors/116038.cc
@@ -0,0 +1,29 @@
+// PR libstdc++/116038
+// { dg-do compile { target c++20 } }
+
+#include <ranges>
+#include <utility>
+
+struct A { };
+struct B { };
+
+template<class... Ts>
+struct overloaded : private Ts... {
+  overloaded(Ts...);
+  using Ts::operator()...;
+};
+
+int x[5];
+struct integralish { operator int() const; } i;
+
+int main() {
+  overloaded o1 = { std::views::drop(i) };
+  o1(x);
+  std::move(o1)(x);
+  std::as_const(o1)(x);
+
+  overloaded o2 = { std::views::drop(i) | std::views::take(i) };
+  o2(x);
+  std::move(o2)(x);
+  std::as_const(o1)(x);
+}

commit 37e54ffd2a0a18eec23c90bdf438c01a0393328a
Author: Patrick Palka <ppalka@redhat.com>
Date:   Fri Jul 26 01:00:23 2024

    c++: alias of alias tmpl with dependent attrs [PR115897]
    
    As a follow-up to r15-2047-g7954bb4fcb6fa8, we also need to consider
    dependent attributes when recursing into a non-template alias that names
    a dependent alias template specialization (and so STF_STRIP_DEPENDENT
    is set), otherwise in the first testcase below we undesirably strip B
    all the way to T instead of to A<T>.
    
    We also need to move the typedef recursion case of strip_typedefs up to
    get checked before the compound type recursion cases.  Otherwise for C
    below (which ultimately aliases T*) we end up stripping it to T* instead
    of to A<T*> because the POINTER_TYPE recursion dominates the typedef
    recursion.  It also means we issue an unexpected extra error in the
    third testcase below.
    
    Ideally we would also want to consider dependent attributes on
    non-template aliases, so that we accept the second testcase below, but
    making that work correctly would require broader changes to e.g.
    structural_comptypes.
    
            PR c++/115897
    
    gcc/cp/ChangeLog:
    
            * tree.cc (strip_typedefs): Move up the typedef recursion case.
            Never strip a dependent alias template-id that has dependent
            attributes.
    
    gcc/testsuite/ChangeLog:
    
            * g++.dg/cpp0x/alias-decl-78.C: New test.
            * g++.dg/cpp0x/alias-decl-79.C: New test.
            * g++.dg/cpp0x/alias-decl-pr92206-1a.C: New test.
    
    Reviewed-by: Jason Merrill <jason@redhat.com>
    (cherry picked from commit 9bcad238837e2100978cd839c343c488f72e1d4a)

diff --git a/gcc/cp/tree.cc b/gcc/cp/tree.cc
index 41fdf67f757..d90244609c8 100644
--- a/gcc/cp/tree.cc
+++ b/gcc/cp/tree.cc
@@ -1607,11 +1607,32 @@ strip_typedefs (tree t, bool *remove_attributes /* = NULL */,
   if (t == TYPE_CANONICAL (t))
     return t;
 
-  if (!(flags & STF_STRIP_DEPENDENT)
-      && dependent_alias_template_spec_p (t, nt_opaque))
-    /* DR 1558: However, if the template-id is dependent, subsequent
-       template argument substitution still applies to the template-id.  */
-    return t;
+  if (typedef_variant_p (t))
+    {
+      if ((flags & STF_USER_VISIBLE)
+	  && !user_facing_original_type_p (t))
+	return t;
+
+      if (alias_template_specialization_p (t, nt_opaque))
+	{
+	  if (dependent_alias_template_spec_p (t, nt_opaque)
+	      && (!(flags & STF_STRIP_DEPENDENT)
+		  || any_dependent_type_attributes_p (DECL_ATTRIBUTES
+						      (TYPE_NAME (t)))))
+	    /* DR 1558: However, if the template-id is dependent, subsequent
+	       template argument substitution still applies to the template-id.  */
+	    return t;
+	}
+      else
+	/* If T is a non-template alias or typedef, we can assume that
+	   instantiating its definition will hit any substitution failure,
+	   so we don't need to retain it here as well.  */
+	flags |= STF_STRIP_DEPENDENT;
+
+      result = strip_typedefs (DECL_ORIGINAL_TYPE (TYPE_NAME (t)),
+			       remove_attributes, flags);
+      goto stripped;
+    }
 
   switch (TREE_CODE (t))
     {
@@ -1805,23 +1826,9 @@ strip_typedefs (tree t, bool *remove_attributes /* = NULL */,
     }
 
   if (!result)
-    {
-      if (typedef_variant_p (t))
-	{
-	  if ((flags & STF_USER_VISIBLE)
-	      && !user_facing_original_type_p (t))
-	    return t;
-	  /* If T is a non-template alias or typedef, we can assume that
-	     instantiating its definition will hit any substitution failure,
-	     so we don't need to retain it here as well.  */
-	  if (!alias_template_specialization_p (t, nt_opaque))
-	    flags |= STF_STRIP_DEPENDENT;
-	  result = strip_typedefs (DECL_ORIGINAL_TYPE (TYPE_NAME (t)),
-				   remove_attributes, flags);
-	}
-      else
-	result = TYPE_MAIN_VARIANT (t);
-    }
+    result = TYPE_MAIN_VARIANT (t);
+
+stripped:
   /*gcc_assert (!typedef_variant_p (result)
 	      || dependent_alias_template_spec_p (result, nt_opaque)
 	      || ((flags & STF_USER_VISIBLE)
diff --git a/gcc/testsuite/g++.dg/cpp0x/alias-decl-78.C b/gcc/testsuite/g++.dg/cpp0x/alias-decl-78.C
new file mode 100644
index 00000000000..a52c0622e46
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp0x/alias-decl-78.C
@@ -0,0 +1,34 @@
+// PR c++/115897
+// { dg-do compile { target c++11 } }
+
+template<class T, class U>
+struct is_same { static constexpr bool value = __is_same(T, U); };
+
+#if __cpp_variable_templates
+template<class T, class U>
+constexpr bool is_same_v = __is_same(T, U);
+#endif
+
+template<class T>
+using A [[gnu::vector_size(16)]] = T;
+
+template<class T>
+void f() {
+  using B = A<T>;
+  static_assert(!is_same<T, B>::value, "");
+#if __cpp_variable_templates
+  static_assert(!is_same_v<T, B>, "");
+#endif
+};
+
+template<class T>
+void g() {
+  using C = A<T*>;
+  static_assert(!is_same<T*, C>::value, "");
+#if __cpp_variable_templates
+  static_assert(!is_same_v<T*, C>, "");
+#endif
+};
+
+template void f<float>();
+template void g<float>();
diff --git a/gcc/testsuite/g++.dg/cpp0x/alias-decl-79.C b/gcc/testsuite/g++.dg/cpp0x/alias-decl-79.C
new file mode 100644
index 00000000000..e0f07475cc1
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp0x/alias-decl-79.C
@@ -0,0 +1,37 @@
+// PR c++/115897
+// { dg-do compile { target c++11 } }
+
+template<class T, class U>
+struct is_same { static constexpr bool value = __is_same(T, U); };
+
+#if __cpp_variable_templates
+template<class T, class U>
+constexpr bool is_same_v = __is_same(T, U);
+#endif
+
+template<class T> struct A;
+
+template<class T>
+void f() {
+  using B [[gnu::vector_size(16)]] = T;
+  static_assert(!is_same<T, B>::value, "");        // { dg-bogus "" "" { xfail *-*-* } }
+  static_assert(!is_same<A<T>, A<B>>::value, "");  // { dg-bogus "" "" { xfail *-*-* } }
+#if __cpp_variable_templates
+  static_assert(!is_same_v<T, B>, "");             // { dg-bogus "" "" { xfail c++14 } }
+  static_assert(!is_same_v<A<T>, A<B>>, "");       // { dg-bogus "" "" { xfail c++14 } }
+#endif
+};
+
+template<class T>
+void g() {
+  using C [[gnu::vector_size(16)]] = T*;
+  static_assert(!is_same<T*, C>::value, "");       // { dg-bogus "" "" { xfail *-*-* } }
+  static_assert(!is_same<A<T*>, A<C>>::value, ""); // { dg-bogus "" "" { xfail *-*-* } }
+#if __cpp_variable_templates
+  static_assert(!is_same_v<T*, C>, "");            // { dg-bogus "" "" { xfail c++14 } }
+  static_assert(!is_same_v<A<T*>, A<C>>, "");      // { dg-bogus "" "" { xfail c++14 } }
+#endif
+};
+
+template void f<float>();
+template void g<float>();
diff --git a/gcc/testsuite/g++.dg/cpp0x/alias-decl-pr92206-1a.C b/gcc/testsuite/g++.dg/cpp0x/alias-decl-pr92206-1a.C
new file mode 100644
index 00000000000..09781f68bb6
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp0x/alias-decl-pr92206-1a.C
@@ -0,0 +1,10 @@
+// A version of alias-decl-pr92206-1.C where alias2 is a compound type.
+// { dg-require-effective-target c++11 }
+
+template<typename> struct A {};
+template<typename T1, typename T2 = typename T1::value> using alias1 = A<T1>;
+template<typename T> class B {
+  using alias2 = alias1<A<T>>*; // { dg-error {no type named 'value'} }
+  A<alias2> a; // { dg-bogus {no type named 'value'} }
+};
+B<int> b;

commit 81db6857686c2d7932949afb948419a575bc0b3f
Author: Patrick Palka <ppalka@redhat.com>
Date:   Mon Jul 29 22:37:19 2024

    c++: generic lambda in default template argument [PR88313]
    
    Here we're rejecting the generic lambda inside the default template
    argument ultimately because auto_is_implicit_function_template_parm_p
    doesn't get set during parsing of the lambda's parameter list, due
    to the !processing_template_parmlist restriction.  But when parsing a
    lambda parameter list we should always set that flag regardless of where
    the lambda appears.  This patch makes sure of this via a local lambda_p
    flag.
    
            PR c++/88313
    
    gcc/cp/ChangeLog:
    
            * parser.cc (cp_parser_lambda_declarator_opt): Pass
            lambda_p=true to cp_parser_parameter_declaration_clause.
            (cp_parser_direct_declarator): Pass lambda_p=false to
            to cp_parser_parameter_declaration_clause.
            (cp_parser_parameter_declaration_clause): Add bool lambda_p
            parameter.  Consider lambda_p instead of current_class_type
            when setting parser->auto_is_implicit_function_template_parm_p.
            Don't consider processing_template_parmlist.
            (cp_parser_requirement_parameter_list): Pass lambda_p=false
            to cp_parser_parameter_declaration_clause.
    
    gcc/testsuite/ChangeLog:
    
            * g++.dg/cpp2a/lambda-targ6.C: New test.
    
    Reviewed-by: Jason Merrill <jason@redhat.com>
    (cherry picked from commit 72a7ab891ae0061841c4eb641ef6ab7719bf0369)

diff --git a/gcc/cp/parser.cc b/gcc/cp/parser.cc
index 7e81c1010c4..00cf128522a 100644
--- a/gcc/cp/parser.cc
+++ b/gcc/cp/parser.cc
@@ -2598,7 +2598,7 @@ static tree cp_parser_type_id_1
 static void cp_parser_type_specifier_seq
   (cp_parser *, cp_parser_flags, bool, bool, cp_decl_specifier_seq *);
 static tree cp_parser_parameter_declaration_clause
-  (cp_parser *, cp_parser_flags);
+  (cp_parser *, cp_parser_flags, bool);
 static tree cp_parser_parameter_declaration_list
   (cp_parser *, cp_parser_flags, auto_vec<tree> *);
 static cp_parameter_declarator *cp_parser_parameter_declaration
@@ -11867,7 +11867,7 @@ cp_parser_lambda_declarator_opt (cp_parser* parser, tree lambda_expr)
       /* Parse parameters.  */
       param_list
 	= cp_parser_parameter_declaration_clause
-	    (parser, CP_PARSER_FLAGS_TYPENAME_OPTIONAL);
+	    (parser, CP_PARSER_FLAGS_TYPENAME_OPTIONAL, /*lambda_p=*/true);
 
       /* Default arguments shall not be specified in the
 	 parameter-declaration-clause of a lambda-declarator.  */
@@ -23903,7 +23903,8 @@ cp_parser_direct_declarator (cp_parser* parser,
 
 	      /* Parse the parameter-declaration-clause.  */
 	      params
-		= cp_parser_parameter_declaration_clause (parser, flags);
+		= cp_parser_parameter_declaration_clause (parser, flags,
+							  /*lambda_p=*/false);
 	      const location_t parens_end
 		= cp_lexer_peek_token (parser->lexer)->location;
 
@@ -25252,13 +25253,17 @@ function_being_declared_is_template_p (cp_parser* parser)
 
    The parser flags FLAGS is used to control type-specifier parsing.
 
+   LAMBDA_P is true if this is the parameter-declaration-clause of
+   a lambda-declarator.
+
    Returns a representation for the parameter declarations.  A return
    value of NULL indicates a parameter-declaration-clause consisting
    only of an ellipsis.  */
 
 static tree
 cp_parser_parameter_declaration_clause (cp_parser* parser,
-					cp_parser_flags flags)
+					cp_parser_flags flags,
+					bool lambda_p)
 {
   tree parameters;
   cp_token *token;
@@ -25267,15 +25272,15 @@ cp_parser_parameter_declaration_clause (cp_parser* parser,
   auto cleanup = make_temp_override
     (parser->auto_is_implicit_function_template_parm_p);
 
-  if (!processing_specialization
-      && !processing_template_parmlist
-      && !processing_explicit_instantiation
-      /* default_arg_ok_p tracks whether this is a parameter-clause for an
-         actual function or a random abstract declarator.  */
-      && parser->default_arg_ok_p)
-    if (!current_function_decl
-	|| (current_class_type && LAMBDA_TYPE_P (current_class_type)))
-      parser->auto_is_implicit_function_template_parm_p = true;
+  if (lambda_p
+      || (!processing_specialization
+	  && !processing_template_parmlist
+	  && !processing_explicit_instantiation
+	  /* default_arg_ok_p tracks whether this is a parameter-clause for an
+	     actual function or a random abstract declarator.  */
+	  && parser->default_arg_ok_p
+	  && !current_function_decl))
+    parser->auto_is_implicit_function_template_parm_p = true;
 
   /* Peek at the next token.  */
   token = cp_lexer_peek_token (parser->lexer);
@@ -31472,7 +31477,8 @@ cp_parser_requirement_parameter_list (cp_parser *parser)
     return error_mark_node;
 
   tree parms = (cp_parser_parameter_declaration_clause
-		(parser, CP_PARSER_FLAGS_TYPENAME_OPTIONAL));
+		(parser, CP_PARSER_FLAGS_TYPENAME_OPTIONAL,
+		 /*lambda_p=*/false));
 
   if (!parens.require_close (parser))
     return error_mark_node;
diff --git a/gcc/testsuite/g++.dg/cpp2a/lambda-targ6.C b/gcc/testsuite/g++.dg/cpp2a/lambda-targ6.C
new file mode 100644
index 00000000000..51728a040e2
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp2a/lambda-targ6.C
@@ -0,0 +1,15 @@
+// PR c++/88313
+// { dg-do compile { target c++20 } }
+
+template<int N = [](auto x) { return x; }(42)>
+constexpr int f() { return N; }
+
+template<auto F = [](auto x) { return x; }>
+constexpr auto g() { return F; }
+
+template<class T = decltype([](auto x) { return x; })>
+constexpr int h(T t = {}) { return t(42); }
+
+static_assert(f() == 42);
+static_assert(g()(42) == 42);
+static_assert(h() == 42);

commit 79d32baea4a94dd1d4e267a0e172fb15c238fb37
Author: Yang Yujie <yangyujie@loongson.cn>
Date:   Tue Jul 23 04:04:26 2024

    LoongArch: Remove gawk extension from a generator script.
    
    gcc/ChangeLog:
    
            * config/loongarch/genopts/gen-evolution.awk: Do not use
            "length()" to compute the size of an array.
    
    (cherry picked from commit c48f38288fb17b70784ae5e71cb741e664da023a)

diff --git a/gcc/config/loongarch/genopts/gen-evolution.awk b/gcc/config/loongarch/genopts/gen-evolution.awk
index 4d105afa906..1c8004e4146 100644
--- a/gcc/config/loongarch/genopts/gen-evolution.awk
+++ b/gcc/config/loongarch/genopts/gen-evolution.awk
@@ -1,4 +1,4 @@
-#!/usr/bin/gawk
+#!/usr/bin/awk -f
 #
 # A simple script that generates loongarch-evolution.h
 # from genopts/isa-evolution.in
@@ -94,8 +94,9 @@ function gen_cpucfg_useful_idx()
         idx_bucket[cpucfg_word[i]] = 1
 
     delete idx_list
+    j = 1
     for (i in idx_bucket)
-        idx_list[length(idx_list)-1] = i+0
+        idx_list[j++] = i+0
     delete idx_bucket
 
     asort (idx_list)
@@ -108,7 +109,7 @@ function gen_cpucfg_useful_idx()
     print ""
 
     printf ("static constexpr int N_CPUCFG_WORDS = %d;\n",
-            idx_list[length(idx_list)] + 1)
+            idx_list[j - 1] + 1)
 
     delete idx_list
 }

commit 30f4fa3f53e4c1476b4cb771f8d006c03804788a
Author: Haochen Jiang <haochen.jiang@intel.com>
Date:   Thu Jul 25 10:16:05 2024

    i386: Add non-optimize prefetchi intrins
    
    Under -O0, with the "newly" introduced intrins, the variable will be
    transformed as mem instead of the origin symbol_ref. The compiler will
    then treat the operand as invalid and turn the operation into nop, which
    is not expected. Use macro for non-optimize to keep the variable as
    symbol_ref just as how prefetch intrin does.
    
    gcc/ChangeLog:
    
            * config/i386/prfchiintrin.h
            (_m_prefetchit0): Add macro for non-optimized option.
            (_m_prefetchit1): Ditto.
    
    gcc/testsuite/ChangeLog:
    
            * gcc.target/i386/prefetchi-1b.c: New test.

diff --git a/gcc/config/i386/prfchiintrin.h b/gcc/config/i386/prfchiintrin.h
index dfca89c7d16..d6580e504c0 100644
--- a/gcc/config/i386/prfchiintrin.h
+++ b/gcc/config/i386/prfchiintrin.h
@@ -37,6 +37,7 @@
 #define __DISABLE_PREFETCHI__
 #endif /* __PREFETCHI__ */
 
+#ifdef __OPTIMIZE__
 extern __inline void
 __attribute__((__gnu_inline__, __always_inline__, __artificial__))
 _m_prefetchit0 (void* __P)
@@ -50,6 +51,14 @@ _m_prefetchit1 (void* __P)
 {
   __builtin_ia32_prefetchi (__P, 2);
 }
+#else
+#define _m_prefetchit0(P)	\
+  __builtin_ia32_prefetchi(P, 3);
+
+#define _m_prefetchit1(P)	\
+  __builtin_ia32_prefetchi(P, 2);
+
+#endif
 
 #ifdef __DISABLE_PREFETCHI__
 #undef __DISABLE_PREFETCHI__
diff --git a/gcc/testsuite/gcc.target/i386/prefetchi-1b.c b/gcc/testsuite/gcc.target/i386/prefetchi-1b.c
new file mode 100644
index 00000000000..93139554d3c
--- /dev/null
+++ b/gcc/testsuite/gcc.target/i386/prefetchi-1b.c
@@ -0,0 +1,26 @@
+/* { dg-do compile { target { ! ia32 } } } */
+/* { dg-options "-mprefetchi -O0" } */
+/* { dg-final { scan-assembler-times "\[ \\t\]+prefetchit0\[ \\t\]+bar\\(%rip\\)" 1 } } */
+/* { dg-final { scan-assembler-times "\[ \\t\]+prefetchit1\[ \\t\]+bar\\(%rip\\)" 1 } } */
+
+#include <x86intrin.h>
+
+int
+bar (int a)
+{
+  return a + 1;
+}
+
+int
+foo1 (int b)
+{
+  _m_prefetchit0 (bar);
+  return bar (b) + 1;
+}
+
+int
+foo2 (int b)
+{
+  _m_prefetchit1 (bar);
+  return bar (b) + 1;
+}

commit a295076bee293aa3112c615f9af7a27231816a36
Author: liuhongt <hongtao.liu@intel.com>
Date:   Wed Jul 24 05:29:23 2024

    Refine constraint "Bk" to define_special_memory_constraint.
    
    For below pattern, RA may still allocate r162 as v/k register, try to
    reload for address with leaq __libc_tsd_CTYPE_B@gottpoff(%rip), %rsi
    which result a linker error.
    
    (set (reg:DI 162)
         (mem/u/c:DI
           (const:DI (unspec:DI
                     [(symbol_ref:DI ("a") [flags 0x60]  <var_decl 0x7f621f6e1c60 a>)]
                     UNSPEC_GOTNTPOFF))
    
    Quote from H.J for why linker issue an error.
    >What do these do:
    >
    >        leaq    __libc_tsd_CTYPE_B@gottpoff(%rip), %rax
    >        vmovq   (%rax), %xmm0
    >
    >From x86-64 TLS psABI:
    >
    >The assembler generates for the x@gottpoff(%rip) expressions a R X86
    >64 GOTTPOFF relocation for the symbol x which requests the linker to
    >generate a GOT entry with a R X86 64 TPOFF64 relocation. The offset of
    >the GOT entry relative to the end of the instruction is then used in
    >the instruction. The R X86 64 TPOFF64 relocation is pro- cessed at
    >program startup time by the dynamic linker by looking up the symbol x
    >in the modules loaded at that point. The offset is written in the GOT
    >entry and later loaded by the addq instruction.
    >
    >The above code sequence looks wrong to me.
    
    gcc/ChangeLog:
    
            PR target/116043
            * config/i386/constraints.md (Bk): Refine to
            define_special_memory_constraint.
    
    gcc/testsuite/ChangeLog:
    
            * gcc.target/i386/pr116043.c: New test.
    
    (cherry picked from commit bc1fda00d5f20e2f3e77a50b2822562b6e0040b2)

diff --git a/gcc/config/i386/constraints.md b/gcc/config/i386/constraints.md
index 7508d7a58bd..b760e7c221a 100644
--- a/gcc/config/i386/constraints.md
+++ b/gcc/config/i386/constraints.md
@@ -187,7 +187,7 @@
   "@internal Vector memory operand."
   (match_operand 0 "vector_memory_operand"))
 
-(define_memory_constraint "Bk"
+(define_special_memory_constraint "Bk"
   "@internal TLS address that allows insn using non-integer registers."
   (and (match_operand 0 "memory_operand")
        (not (match_test "ix86_gpr_tls_address_pattern_p (op)"))))
diff --git a/gcc/testsuite/gcc.target/i386/pr116043.c b/gcc/testsuite/gcc.target/i386/pr116043.c
new file mode 100644
index 00000000000..76553496c10
--- /dev/null
+++ b/gcc/testsuite/gcc.target/i386/pr116043.c
@@ -0,0 +1,33 @@
+/* { dg-do compile } */
+/* { dg-options "-mavx512bf16 -O3" } */
+/* { dg-final { scan-assembler-not {(?n)lea.*@gottpoff} } } */
+
+extern __thread int a, c, i, j, k, l;
+int *b;
+struct d {
+  int e;
+} f, g;
+char *h;
+
+void m(struct d *n) {
+  b = &k;
+  for (; n->e; b++, n--) {
+    i = b && a;
+    if (i)
+      j = c;
+  }
+}
+
+char *o(struct d *n) {
+  for (; n->e;)
+    return h;
+}
+
+int q() {
+  if (l)
+    return 1;
+  int p = *o(&g);
+  m(&f);
+  m(&g);
+  l = p;
+}

commit 14fa2b2ae7f49dee5e7e7469243e281e48d925b9
Author: Andrew Pinski <quic_apinski@quicinc.com>
Date:   Thu Aug 1 19:33:34 2024

    forwprop: Don't add uses to dce list if debug statement [PR116156]
    
    The problem here is that when forwprop does a copy prop, into a statement,
    we mark the uses of that statement as possibly need to be removed. But it just
    happened that statement was a debug statement, there will be a difference when
    compiling with debuging info turned on vs off; this is not expected.
    So the fix is not to add the old use to dce list to process if it was a debug
    statement.
    
    Bootstrapped and tested on x86_64-linux-gnu with no regressions.
    
            PR tree-optimization/116156
    
    gcc/ChangeLog:
    
            * tree-ssa-forwprop.cc (pass_forwprop::execute): Don't add
            uses if the statement was a debug statement.
    
    gcc/testsuite/ChangeLog:
    
            * c-c++-common/torture/pr116156-1.c: New test.
    
    Signed-off-by: Andrew Pinski <quic_apinski@quicinc.com>

diff --git a/gcc/testsuite/c-c++-common/torture/pr116156-1.c b/gcc/testsuite/c-c++-common/torture/pr116156-1.c
new file mode 100644
index 00000000000..10f938ef4e5
--- /dev/null
+++ b/gcc/testsuite/c-c++-common/torture/pr116156-1.c
@@ -0,0 +1,30 @@
+/* { dg-additional-options "-fcompare-debug" } */
+/* PR tree-optimization/116156 */
+
+/* Forwprop used to delete an unused statement
+   but only with debug statements around. */
+
+struct jpeg_compress_struct {
+  int X_density;
+};
+void gg();
+int h(const char*,const char*) __attribute((pure));
+int h1(const char*) __attribute((pure));
+int f1() __attribute__((returns_twice));
+void real_save_jpeg(char **keys, char *values) {
+  struct jpeg_compress_struct cinfo;
+  int x_density = 0;
+  while (*keys)
+  {
+    if (h1(*keys) == 0)
+      gg();
+    if (h1(*keys) == 0)  {
+      if (!*values)
+        x_density = -1;
+      if (x_density <= 0)
+        gg();
+    }
+  }
+  if (f1())
+    cinfo.X_density = x_density;
+}
diff --git a/gcc/tree-ssa-forwprop.cc b/gcc/tree-ssa-forwprop.cc
index abf71f0d3a0..692e96604b8 100644
--- a/gcc/tree-ssa-forwprop.cc
+++ b/gcc/tree-ssa-forwprop.cc
@@ -3919,7 +3919,8 @@ pass_forwprop::execute (function *fun)
 	      tree val = fwprop_ssa_val (use);
 	      if (val && val != use)
 		{
-		  bitmap_set_bit (simple_dce_worklist, SSA_NAME_VERSION (use));
+		  if (!is_gimple_debug (stmt))
+		    bitmap_set_bit (simple_dce_worklist, SSA_NAME_VERSION (use));
 		  if (may_propagate_copy (use, val))
 		    {
 		      propagate_value (usep, val);
@@ -3959,12 +3960,13 @@ pass_forwprop::execute (function *fun)
 		    if (gimple_cond_true_p (cond)
 			|| gimple_cond_false_p (cond))
 		      cfg_changed = true;
-		  /* Queue old uses for simple DCE.  */
-		  for (tree use : uses)
-		    if (TREE_CODE (use) == SSA_NAME
-			&& !SSA_NAME_IS_DEFAULT_DEF (use))
-		      bitmap_set_bit (simple_dce_worklist,
-				      SSA_NAME_VERSION (use));
+		  /* Queue old uses for simple DCE if not debug statement.  */
+		  if (!is_gimple_debug (stmt))
+		    for (tree use : uses)
+		      if (TREE_CODE (use) == SSA_NAME
+			  && !SSA_NAME_IS_DEFAULT_DEF (use))
+			bitmap_set_bit (simple_dce_worklist,
+					SSA_NAME_VERSION (use));
 		}
 
 	      if (changed || substituted_p)

commit 21e2d27fd46c804192273a8960707de95467e5bc
Author: Joseph Myers <josmyers@redhat.com>
Date:   Fri Aug 2 23:13:59 2024

    Update gcc .po files
    
            * be.po, da.po, de.po, el.po, es.po, fi.po, fr.po, hr.po, id.po,
            ja.po, nl.po, ru.po, sr.po, sv.po, tr.po, uk.po, vi.po, zh_CN.po,
            zh_TW.po: Update.

diff --git a/gcc/po/be.po b/gcc/po/be.po
index 9afcc33902f..7ed840da35b 100644
--- a/gcc/po/be.po
+++ b/gcc/po/be.po
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 3.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
 "PO-Revision-Date: 2002-05-17 15:54+0200\n"
 "Last-Translator: Ales Nyakhaychyk <nyakhaychyk@i18n.linux.by>\n"
 "Language-Team: Belarusian <i18n@tut.by>\n"
@@ -415,7 +415,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr ""
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 msgid "shared and mdll are not compatible"
 msgstr ""
 
@@ -19420,16 +19420,16 @@ msgstr "нераспазнаны выбар \"-%s\""
 msgid "insn does not satisfy its constraints:"
 msgstr ""
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr ""
 
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 msgid "created and used with different settings of %<-fpic%>"
 msgstr ""
 
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 msgid "created and used with different settings of %<-fpie%>"
 msgstr ""
 
@@ -19790,7 +19790,7 @@ msgstr ""
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
@@ -19809,9 +19809,9 @@ msgstr "Нерэчаісны выбар \"%s\""
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, fuzzy, c-format
 #| msgid "invalid string constant `%E'"
 msgid "invalid vector constant"
@@ -19834,7 +19834,7 @@ msgstr "немагчымы апэратар '%s'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "нерэчаісная назва рэгістра `%s'"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, fuzzy, c-format
 msgid "missing operand"
 msgstr "прапушчан ініцыялізатар"
@@ -19865,93 +19865,93 @@ msgstr "нерэчаісны адрас"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr ""
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, fuzzy, c-format
 msgid "invalid %%J value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, c-format
 msgid "invalid %%r value"
 msgstr "нерэчаіснае значэньне %%r"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, c-format
 msgid "invalid %%R value"
 msgstr "нерэчаіснае значэньне %%R"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, c-format
 msgid "invalid %%N value"
 msgstr "нерэчаіснае значэньне %%N"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, c-format
 msgid "invalid %%P value"
 msgstr "нерэчаіснае значэньне %%P"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, c-format
 msgid "invalid %%h value"
 msgstr "нерэчаіснае значэньне %%h"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, c-format
 msgid "invalid %%L value"
 msgstr "нерэчаіснае значэньне %%L"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, c-format
 msgid "invalid %%m value"
 msgstr "нерэчаіснае значэньне %%m"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, c-format
 msgid "invalid %%M value"
 msgstr "нерэчаіснае значэньне %%M"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, c-format
 msgid "invalid %%U value"
 msgstr "нерэчаіснае значэньне %%U"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, c-format
 msgid "invalid %%s value"
 msgstr "нерэчаіснае значэньне %%v"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, c-format
 msgid "invalid %%C value"
 msgstr "нерэчаіснае значэньне %%C"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, c-format
 msgid "invalid %%E value"
 msgstr "нерэчаіснае значэньне %%E"
 
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, c-format
 msgid "unknown relocation unspec"
 msgstr ""
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, c-format
 msgid "invalid %%xn code"
 msgstr "нерэчаіснае значэньне %%xn"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid operand address"
@@ -20046,36 +20046,36 @@ msgstr "нерэчаісны %%-код"
 msgid "unrecognized supposed constant"
 msgstr "нераспазнаны выбар \"-%s\""
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, fuzzy, c-format
 #| msgid "invalid %%f operand"
 msgid "invalid shift operand"
 msgstr "нерэчаісны %%f аперанд"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, fuzzy, c-format
 msgid "predicated Thumb instruction"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr ""
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -20083,121 +20083,121 @@ msgstr "Нерэчаісны выбар \"%s\""
 msgid "invalid operand for code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, c-format
 msgid "instruction never executed"
 msgstr ""
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr ""
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr ""
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr ""
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr ""
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 msgid "bad address, not an I/O address:"
 msgstr ""
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 msgid "bad address, not a constant:"
 msgstr ""
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 msgid "bad address, not (reg+disp):"
 msgstr ""
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 msgid "bad address, not post_inc or pre_dec:"
 msgstr ""
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr ""
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 msgid "internal compiler error.  Unknown mode:"
 msgstr ""
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 #, fuzzy
 msgid "invalid insn:"
 msgstr "Нерэчаісны выбар %s"
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 msgid "incorrect insn:"
 msgstr ""
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 msgid "unknown move insn:"
 msgstr ""
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 msgid "bad shift insn:"
 msgstr ""
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 msgid "internal compiler error.  Incorrect shift:"
 msgstr ""
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 #, fuzzy
 #| msgid "unsupported version"
 msgid "unsupported fixed-point conversion"
 msgstr "непадтрымліваемая версія"
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 msgid "variable"
 msgstr ""
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 #, fuzzy
 msgid "function parameter"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 #, fuzzy
 #| msgid "structure"
 msgid "structure field"
 msgstr "структура"
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 #, fuzzy
 #| msgid "return type of `%s' is not `int'"
 msgid "return type of function"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 msgid "pointer"
 msgstr ""
 
@@ -20236,7 +20236,7 @@ msgstr "непадтрымліваемая версія"
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -20560,48 +20560,48 @@ msgstr ""
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, fuzzy, c-format
 msgid "invalid operand code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, fuzzy, c-format
 #| msgid "invalid %%c operand"
 msgid "invalid constraints for operand"
 msgstr "нерэчаісны %%c аперанд"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 #, fuzzy
 msgid "unknown insn mode"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
 msgstr ""
 
@@ -20637,7 +20637,7 @@ msgstr "нерэчаісны %%-код"
 msgid "invalid %%P operand"
 msgstr "нерэчаісны %%-код"
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, c-format
 msgid "invalid %%p value"
 msgstr ""
@@ -20666,29 +20666,29 @@ msgstr ""
 msgid "invalid addressing mode"
 msgstr ""
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, fuzzy, c-format
 msgid "'%%%c' is not a valid operand prefix"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, fuzzy, c-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of '%%%c'"
@@ -20721,7 +20721,7 @@ msgid "post-increment address is not a register"
 msgstr ""
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 msgid "bad address"
 msgstr "дрэнны адрас"
 
@@ -20892,7 +20892,7 @@ msgstr "нераспазнаны адрас"
 msgid "unsupported memory expression:"
 msgstr "непадтрымліваемая версія"
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, fuzzy, c-format
 #| msgid "invalid %%c operand"
 msgid "invalid vector operand"
@@ -20943,251 +20943,251 @@ msgstr ""
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 msgid "bad move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, fuzzy, c-format
 #| msgid "invalid %%Q value"
 msgid "invalid %%A value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, fuzzy, c-format
 msgid "invalid %%D value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, fuzzy, c-format
 #| msgid "invalid %%Q value"
 msgid "invalid %%e value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, c-format
 msgid "invalid %%O value"
 msgstr "нерэчаіснае значэньне %%O"
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, fuzzy, c-format
 #| msgid "invalid %%Q value"
 msgid "invalid %%t value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, c-format
 msgid "invalid %%V value"
 msgstr "нерэчаіснае значэньне %%V"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, fuzzy, c-format
 #| msgid "invalid %%x/X value"
 msgid "invalid %%x value"
 msgstr "нерэчаіснае значэньне %%x/X"
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, c-format
 msgid "invalid %%z value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 #, fuzzy
 #| msgid "too few arguments to function"
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Стварыць код для DLL"
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr ""
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, fuzzy, c-format
 msgid "cannot decompose address"
 msgstr "невядомая назва рэгістра: %s"
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 #, fuzzy
 #| msgid "too few arguments to function"
 msgid "vector argument passed to unprototyped function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -21382,12 +21382,12 @@ msgstr ""
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr ""
@@ -21400,7 +21400,7 @@ msgstr ""
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -21409,7 +21409,7 @@ msgstr ""
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr ""
@@ -21417,7 +21417,7 @@ msgstr ""
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr ""
@@ -21428,29 +21428,29 @@ msgstr ""
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr ""
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr ""
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr ""
@@ -21460,17 +21460,17 @@ msgstr ""
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr ""
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr ""
@@ -21479,8 +21479,8 @@ msgstr ""
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr ""
@@ -21490,17 +21490,17 @@ msgid "expected %<.%>"
 msgstr ""
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr ""
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr ""
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr ""
@@ -21508,32 +21508,32 @@ msgstr ""
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr ""
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr ""
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, gcc-internal-format
 msgid "expected %<else%>"
 msgstr ""
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr ""
 
@@ -21541,7 +21541,7 @@ msgstr ""
 msgid "(anonymous)"
 msgstr ""
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr ""
@@ -21556,21 +21556,21 @@ msgstr ""
 msgid "candidate:"
 msgstr ""
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 msgid "  after user-defined conversion:"
 msgstr ""
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr ""
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr ""
 
@@ -21831,7 +21831,7 @@ msgstr ""
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 msgid "candidates are:"
 msgstr ""
 
@@ -21880,50 +21880,50 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr ""
 
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
 
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 #, fuzzy
 #| msgid "too many arguments to function"
 msgid "in argument to unary !"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -22002,7 +22002,7 @@ msgstr ""
 msgid "Deleted feature:"
 msgstr ""
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 msgid "array assignment"
 msgstr ""
 
@@ -22202,11 +22202,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 msgid "assignment"
 msgstr ""
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 msgid "pointer assignment"
 msgstr ""
 
@@ -22386,47 +22386,47 @@ msgstr ""
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -22435,11 +22435,11 @@ msgstr ""
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr ""
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
@@ -22454,12 +22454,12 @@ msgstr ""
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -22468,81 +22468,81 @@ msgstr ""
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, c-format
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, c-format
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, c-format
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
@@ -22564,15 +22564,15 @@ msgstr ""
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 msgid "Loop variable has been modified"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 msgid "DO step value is zero"
 msgstr ""
 
@@ -22649,7 +22649,7 @@ msgid "expected boolean type"
 msgstr ""
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, gcc-internal-format
 msgid "expected integer"
 msgstr ""
@@ -22717,7 +22717,7 @@ msgstr "няма аргументаў"
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments"
@@ -23375,7 +23375,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr ""
@@ -23838,8 +23838,8 @@ msgstr ""
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
@@ -23857,7 +23857,7 @@ msgstr "\"%s\" атрыбут ігнарыруецца"
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr ""
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments specified for %qE attribute"
@@ -23868,7 +23868,7 @@ msgstr "памылковая колькасьць аргументаў, зада
 msgid "expected %i or more, found %i"
 msgstr ""
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "expected %i, found %i"
 msgstr ""
@@ -23935,12 +23935,12 @@ msgstr ""
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -23949,7 +23949,7 @@ msgstr ""
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -23972,8 +23972,8 @@ msgstr "\"%s\" атрыбут ігнарыруецца"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%D'"
 msgid "previous declaration of %qD"
@@ -24085,7 +24085,7 @@ msgstr "немагчыма знайсьці файл для кляса %s"
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr ""
@@ -24195,7 +24195,7 @@ msgstr "аргумент для \"%s\" прапушчан"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, gcc-internal-format
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
@@ -24217,7 +24217,7 @@ msgstr ""
 msgid "target format does not support infinity"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, fuzzy, gcc-internal-format
 #| msgid "`va_start' used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
@@ -24225,40 +24225,40 @@ msgstr ""
 "`va_start' выкарыстоўвываецца ў функцыі з нязьменнай\n"
 "           колькасьцю аргументаў"
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, fuzzy, gcc-internal-format
 #| msgid "`__builtin_next_arg' called without an argument"
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "\"__buitin_next_arg\" выклікаецца без аргумента"
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr ""
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, fuzzy, gcc-internal-format
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, gcc-internal-format
 msgid "last argument of %qD is not integer constant between 0 and 3"
 msgstr ""
@@ -25328,13 +25328,13 @@ msgstr ""
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, fuzzy, gcc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "%q+F used but never defined"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -25901,7 +25901,7 @@ msgstr ""
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr ""
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, gcc-internal-format
 msgid "%qs failed"
 msgstr ""
@@ -25931,17 +25931,17 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, gcc-internal-format
 msgid "call to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, gcc-internal-format
 msgid "call to %qs declared with attribute warning: %s"
 msgstr ""
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
 msgstr ""
@@ -25977,7 +25977,7 @@ msgstr ""
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -26148,7 +26148,7 @@ msgstr ""
 msgid "%s signal terminated program %s"
 msgstr "Выкарыстоўвываць альтэрнатыўныя назвы рэгістраў"
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, fuzzy, gcc-internal-format
 msgid "unrecognized command-line option %qs"
 msgstr "нераспазнаны выбар \"-%s\""
@@ -26414,7 +26414,7 @@ msgstr "параметр \"%s\" ініцыялізаваны"
 msgid "multilib exclusions %qs is invalid"
 msgstr ""
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr ""
@@ -26725,22 +26725,22 @@ msgstr ""
 msgid "%qD specified bound %E equals source length"
 msgstr ""
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, gcc-internal-format
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr ""
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr ""
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s not supported for variable length aggregates"
 msgstr ""
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
@@ -26781,16 +26781,16 @@ msgid "function returns address of local variable"
 msgstr ""
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, fuzzy, gcc-internal-format
@@ -26803,366 +26803,366 @@ msgstr "выклікана адсюль"
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, gcc-internal-format
 msgid "referenced argument declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, gcc-internal-format
 msgid "directive argument %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgid_plural "%qE output %wu bytes into a destination of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 msgid "%qE argument %Z overlaps destination object %qE"
 msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 msgid "%qE argument %Z may overlap destination object %qE"
 msgid_plural "%qE arguments %Z may overlap destination object %qE"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, gcc-internal-format
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, gcc-internal-format
 msgid "null destination pointer"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, gcc-internal-format
 msgid "null format string"
 msgstr ""
@@ -27904,12 +27904,12 @@ msgstr ""
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
@@ -28675,7 +28675,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -29019,17 +29019,17 @@ msgstr ""
 msgid "mismatching definition"
 msgstr ""
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr ""
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, gcc-internal-format
 msgid "IPA modref summary is missing in input file"
 msgstr ""
@@ -30105,74 +30105,74 @@ msgstr ""
 msgid "error closing optimization records %qs"
 msgstr ""
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, gcc-internal-format
 msgid "command-line option %qs is not supported by this configuration"
 msgstr ""
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr ""
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "argument to %qs should be a non-negative integer"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is not between %d and %d"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param option: %s"
 msgid "invalid argument in option %qs"
 msgstr "нерэчаісны выбар --param : %s"
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr ""
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, gcc-internal-format
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr ""
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument in option %qs"
 msgstr "нераспазнаны выбар \"-%s\""
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, fuzzy, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "-pipe не падтрымліваецца."
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is bigger than %d"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, gcc-internal-format
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
 msgstr ""
@@ -30249,8 +30249,8 @@ msgstr ""
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, gcc-internal-format
 msgid "%qs is incompatible with %qs"
 msgstr ""
@@ -30974,7 +30974,7 @@ msgstr ""
 msgid "register of %qD used for multiple global register variables"
 msgstr ""
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr ""
@@ -31429,42 +31429,42 @@ msgstr ""
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, fuzzy, gcc-internal-format
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, fuzzy, gcc-internal-format
 msgid "nested functions not supported on this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, fuzzy, gcc-internal-format
 msgid "nested function trampolines not supported on this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, fuzzy, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, fuzzy, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, fuzzy, gcc-internal-format
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, fuzzy, gcc-internal-format
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC target%> is not supported for this machine"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
@@ -32593,82 +32593,82 @@ msgstr ""
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr ""
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr ""
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr ""
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr ""
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr ""
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr ""
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr ""
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr ""
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr ""
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr ""
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr ""
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr ""
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, gcc-internal-format
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr ""
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr "выклікана адсюль"
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, fuzzy, gcc-internal-format
 msgid "called from this function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, gcc-internal-format
 msgid "inlining failed in call to %q+F: %s"
 msgstr ""
@@ -32723,27 +32723,27 @@ msgstr "нявернае выкарыстанне \"restict\""
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, fuzzy, gcc-internal-format
 msgid "in a call to non-static member function %qD"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, fuzzy, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, fuzzy, gcc-internal-format
 msgid "in a call to function %qD declared %qs"
 msgstr "Нерэчаісны выбар \"%s\""
@@ -32948,7 +32948,7 @@ msgstr "прапушчан ініцыялізатар"
 msgid "%qs may be used uninitialized"
 msgstr ""
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, fuzzy, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
@@ -33181,7 +33181,7 @@ msgstr ""
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -33196,122 +33196,122 @@ msgstr ""
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr ""
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr ""
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, gcc-internal-format
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, gcc-internal-format
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr ""
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr ""
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr ""
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr ""
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr ""
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr ""
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, gcc-internal-format
 msgid "%qD is unavailable: %s"
 msgstr ""
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, gcc-internal-format
 msgid "%qD is unavailable"
 msgstr ""
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, gcc-internal-format
 msgid "%qE is unavailable: %s"
 msgstr ""
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, gcc-internal-format
 msgid "%qE is unavailable"
 msgstr ""
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, gcc-internal-format, gfc-internal-format
 msgid "type is unavailable: %s"
 msgstr ""
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, gcc-internal-format
 msgid "type is unavailable"
 msgstr ""
@@ -33336,263 +33336,263 @@ msgstr ""
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr ""
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type %s is not an opaque type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is not with opaque mode"
 msgstr ""
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr ""
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr ""
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, gcc-internal-format
 msgid "main variant is not defined"
 msgstr ""
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' has non-integer type"
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "памер масіва `%D' не цэлалікавы тып"
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr ""
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -33811,7 +33811,7 @@ msgstr "атрыбуты секцыі не падтрымліваюцца для
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr ""
@@ -34016,7 +34016,7 @@ msgstr "\"%s\" атрыбут ігнарыруецца"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr ""
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr ""
@@ -34205,7 +34205,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be specified for local variables"
 msgstr "\"%s\" атрыбут ігнарыруецца"
@@ -34522,7 +34522,7 @@ msgstr ""
 msgid "%qE argument is not a function"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
@@ -35032,7 +35032,7 @@ msgstr ""
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr ""
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, gcc-internal-format
 msgid "invalid application of %qs to a void type"
 msgstr ""
@@ -35164,9 +35164,9 @@ msgstr ""
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, fuzzy, gcc-internal-format
@@ -35174,8 +35174,8 @@ msgstr ""
 msgid "too few arguments to function %qE"
 msgstr "не хапае аргументаў у функцыі"
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, fuzzy, gcc-internal-format
@@ -35304,170 +35304,170 @@ msgstr "не магу атрымаць адрас бітавага поля \"%s
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of array is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, gcc-internal-format
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr ""
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr ""
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "incorrect number of arguments to function %qE"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr ""
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, gcc-internal-format
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr ""
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, gcc-internal-format
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr ""
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr ""
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr ""
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, fuzzy, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "адмоўны памер масіва "
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "адмоўны памер масіва "
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -36101,7 +36101,7 @@ msgstr ""
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr ""
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, fuzzy, gcc-internal-format
 msgid "%<_BitInt(%d)%> is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
@@ -36182,7 +36182,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr ""
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -36237,7 +36237,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -36253,17 +36253,17 @@ msgstr ""
 msgid "%qE is not initialized"
 msgstr "прапушчан ініцыялізатар"
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "аргумент для \"%s\" прапушчан"
@@ -36273,7 +36273,7 @@ msgstr "аргумент для \"%s\" прапушчан"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "нерэчаісны ініцыялізатар"
@@ -36358,7 +36358,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -36369,7 +36369,7 @@ msgstr ""
 msgid "%qD is not a function argument"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
@@ -36970,7 +36970,7 @@ msgid "wrong type argument to %s"
 msgstr "не хапае аргументаў у функцыі"
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -37910,35 +37910,35 @@ msgstr ""
 
 #: c-family/c-warn.cc:3832
 #, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3836
+#: c-family/c-warn.cc:3839
 #, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr ""
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr ""
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr ""
@@ -38152,117 +38152,117 @@ msgstr ""
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, gcc-internal-format
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, gcc-internal-format
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, gcc-internal-format
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, gcc-internal-format
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr ""
@@ -38664,12 +38664,12 @@ msgstr ""
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr ""
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr ""
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr ""
@@ -39236,7 +39236,7 @@ msgstr ""
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
@@ -39313,12 +39313,12 @@ msgid "unknown tuning option (%s)"
 msgstr "невядомая назва рэгістра: %s\n"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
@@ -39329,7 +39329,7 @@ msgid "specify a system register with a small string length"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "Нерэчаісны выбар %s"
@@ -39510,9 +39510,9 @@ msgstr ""
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
@@ -39565,18 +39565,18 @@ msgid "virtual function multiversioning not supported"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
@@ -39589,8 +39589,8 @@ msgstr ""
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported simdlen %wd"
@@ -39601,7 +39601,7 @@ msgstr "непадтрымліваемая версія"
 msgid "GCC does not currently support return type %qT for simd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
@@ -39611,7 +39611,7 @@ msgstr ""
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr ""
@@ -39701,8 +39701,8 @@ msgstr ""
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr ""
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr ""
@@ -39824,18 +39824,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -39951,7 +39951,7 @@ msgid "argument of %qE attribute is missing"
 msgstr "аргумент для \"-%s\" прапушчан"
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr ""
@@ -39971,23 +39971,23 @@ msgstr "\"%s\" звычайна функцыя"
 msgid "argument of %qE attribute ignored"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr ""
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr ""
@@ -40233,7 +40233,7 @@ msgstr "ISO C не падтрымлівае комлексныя цэлалік
 msgid "target CPU does not support unaligned accesses"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, fuzzy, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
@@ -40283,7 +40283,7 @@ msgstr ""
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr ""
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr ""
@@ -40389,7 +40389,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -40429,42 +40429,42 @@ msgstr ""
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr ""
@@ -40472,23 +40472,23 @@ msgstr ""
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "невядомая назва рэгістра: %s"
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "-pipe не падтрымліваецца"
@@ -40542,164 +40542,164 @@ msgstr ""
 msgid "unknown core architecture %qs specified with %qs"
 msgstr ""
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe is not supported"
 msgid "%<-fpic%> is not supported"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe is not supported"
 msgid "%<-fPIC%> is not supported"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe is not supported"
 msgid "%<-fpie%> is not supported"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe is not supported"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr ""
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "%qs function cannot have arguments"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "%qs function cannot return a value"
 msgstr "функцыя не вяртае тып string"
 
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, gcc-internal-format
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr ""
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, gcc-internal-format
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr ""
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr ""
 
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, gcc-internal-format
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr ""
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr ""
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr ""
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, gcc-internal-format
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr ""
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, gcc-internal-format
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr ""
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, gcc-internal-format
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr ""
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr ""
@@ -40708,42 +40708,42 @@ msgstr ""
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, gcc-internal-format
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr ""
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr ""
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr ""
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr ""
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr ""
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr ""
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -40884,7 +40884,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr ""
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, fuzzy, gcc-internal-format
@@ -41515,8 +41515,8 @@ msgstr "першым аргументам \"%s\" павінен быць \"int\"
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s does not support %s"
 msgid "code model %s does not support PIC mode"
@@ -41584,255 +41584,255 @@ msgstr ""
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, fuzzy, gcc-internal-format
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, fuzzy, gcc-internal-format
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, fuzzy, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, fuzzy, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, fuzzy, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, gcc-internal-format
 msgid "bad value %qs for %<-march=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr ""
@@ -41840,291 +41840,291 @@ msgstr ""
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr ""
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr ""
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, fuzzy, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
@@ -42316,46 +42316,46 @@ msgstr ""
 msgid "non-integer operand used with operand code %<z%>"
 msgstr ""
 
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, gcc-internal-format
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr ""
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr ""
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr ""
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr ""
@@ -42375,8 +42375,8 @@ msgstr ""
 msgid "malformed %<#pragma builtin%>"
 msgstr ""
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, fuzzy, gcc-internal-format
 msgid "invalid argument of %qE attribute"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -42432,13 +42432,13 @@ msgstr ""
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr ""
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument of `__builtin_args_info' must be constant"
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, fuzzy, gcc-internal-format
 msgid "failed to expand built-in function"
 msgstr "Не генерыраваць сімвальныя інструкцыі"
@@ -42564,17 +42564,17 @@ msgstr ""
 msgid "%qs cannot be used for compiling a shared library"
 msgstr ""
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be specified for register variables"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, gcc-internal-format
 msgid "multiple %qE attribute"
 msgstr ""
@@ -42678,12 +42678,12 @@ msgstr ""
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, fuzzy, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
@@ -42724,7 +42724,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr ""
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr ""
@@ -42764,135 +42764,135 @@ msgstr ""
 msgid "argument to %qE attribute is not intstack"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, gcc-internal-format
 msgid "cannot handle inconsistent calls to %qs"
 msgstr ""
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr ""
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr ""
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr ""
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, gcc-internal-format
 msgid "built-in function %qE not supported for MIPS16"
 msgstr ""
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs does not support MIPS16 code"
 msgstr "%s не падтрымлівае %s"
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr ""
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, gcc-internal-format
 msgid "MIPS16 %<-mxgot%> code"
 msgstr ""
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, gcc-internal-format
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr ""
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, gcc-internal-format
 msgid "MSA MIPS16 code"
 msgstr ""
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, gcc-internal-format
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr ""
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported combination: %s"
 msgstr "непадтрымліваемая версія"
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, gcc-internal-format
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr ""
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, gcc-internal-format
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr ""
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, gcc-internal-format
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "%s не падтрымлівае %s"
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr ""
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr ""
@@ -42902,119 +42902,119 @@ msgstr ""
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, gcc-internal-format
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr ""
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, gcc-internal-format
 msgid "unsupported combination: %qs%s %s"
 msgstr ""
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported combination: %qs %s"
 msgstr "непадтрымліваемая версія"
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, gcc-internal-format
 msgid "cannot generate position-independent code for %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, gcc-internal-format
 msgid "position-independent code requires %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr ""
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr ""
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr "%s не падтрымлівае %s"
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, gcc-internal-format
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr ""
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, gcc-internal-format
 msgid "%qs must be used with %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, gcc-internal-format
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr ""
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr ""
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support DSP instructions"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, gcc-internal-format
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr ""
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, gcc-internal-format
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr ""
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, fuzzy, gcc-internal-format
 msgid "%qs requires branch-likely instructions"
 msgstr "Не генерыраваць сімвальныя інструкцыі"
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support the synci instruction"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr ""
@@ -43894,57 +43894,57 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, gcc-internal-format
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, gcc-internal-format
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, gcc-internal-format
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> attribute"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, gcc-internal-format
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, gcc-internal-format
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> attribute"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -44004,173 +44004,193 @@ msgstr ""
 msgid "capture by copy of RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, gcc-internal-format
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, gcc-internal-format
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, gcc-internal-format
 msgid "no matching function call to %qE with empty arguments"
 msgstr ""
 
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, gcc-internal-format
 msgid "this operation requires the RVV ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, fuzzy, gcc-internal-format
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, gcc-internal-format
 msgid "%s %qT requires the V ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, gcc-internal-format
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, gcc-internal-format
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, gcc-internal-format
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, gcc-internal-format
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr ""
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, gcc-internal-format
 msgid "function attribute %qs requires the V ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr ""
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, fuzzy, gcc-internal-format
 msgid "%qs applied to non-RVV type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, gcc-internal-format
 msgid "%qs requires an integer constant"
 msgstr ""
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr ""
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, gcc-internal-format
 msgid "code model %qs with %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, gcc-internal-format
 msgid "rv64e requires lp64e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr ""
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr ""
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name for `%s'"
 msgid "%qs is not a valid base register in %qs"
 msgstr "нерэчаісная назва рэгістра `%s'"
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr ""
@@ -44424,32 +44444,32 @@ msgstr ""
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, gcc-internal-format
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, gcc-internal-format
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
@@ -44489,31 +44509,24 @@ msgstr "нявернае выкарыстанне \"restict\""
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, gcc-internal-format
-msgid "%qs requires the ELFv2 ABI"
-msgstr ""
-
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, fuzzy, gcc-internal-format
 #| msgid "%s is too large"
 msgid "stack frame too large"
 msgstr "%s - вельмі вялікі"
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported number of nops before function entry (%u)"
 msgstr ""
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use register sb"
 msgid "%qs uses register r29"
 msgstr "Не выкарыстоўваць рэгістра sb"
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
@@ -44639,109 +44652,119 @@ msgstr ""
 msgid "unknown option for %<%s=%s%>"
 msgstr "невядомая назва рэгістра: %s\n"
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4837
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4855
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "нерэчаіснае выкарыстаньне `%D'"
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, fuzzy, gcc-internal-format
 #| msgid "%s=%s is too large"
 msgid "%s%qs%s is not allowed"
 msgstr "%s=%s вельмі вялікі"
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr ""
@@ -44786,7 +44809,7 @@ msgstr ""
 msgid "builtin %qs can only be used on vector types"
 msgstr ""
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -44857,230 +44880,230 @@ msgstr ""
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr ""
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `__builtin_args_info' out of range"
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr "аргумент `__builtin_args_info' выйшаў за межы"
 
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr ""
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher"
 msgstr ""
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher"
 msgstr ""
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr ""
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr ""
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr ""
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr ""
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, fuzzy, gcc-internal-format
 #| msgid "size of `%s' is %d bytes"
 msgid "frame size of %qs is %wd bytes"
 msgstr "памер \"%s\" - %d байт"
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr ""
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr ""
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr ""
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, gcc-internal-format
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, gcc-internal-format
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, fuzzy, gcc-internal-format
 #| msgid "invalid string constant `%E'"
 msgid "invalid cc output constraint: %qs"
 msgstr "`%E' - нерэчаісная нязьменная тыпу string"
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe is not supported"
 msgid "multiple cc output constraints not supported"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, gcc-internal-format
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr ""
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, gcc-internal-format
 msgid "invalid type for cc output constraint"
 msgstr ""
@@ -45506,8 +45529,8 @@ msgstr "\"%s\" атрыбут ігнарыруецца"
 msgid "attribute %qs applies to array types only"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -45586,7 +45609,7 @@ msgstr ""
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr ""
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr ""
@@ -45821,7 +45844,7 @@ msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэк
 msgid "declaration of %qD shadows a parameter"
 msgstr ""
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -45831,7 +45854,7 @@ msgstr ""
 msgid "declaration of %qD shadows a previous local"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, fuzzy, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
@@ -45899,7 +45922,7 @@ msgstr "\"%s\" не абвешчан (першае выкарыстанне ў 
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(Аб кожным неабвешчаным ідэнтыфікатары паведамляецца"
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
@@ -45936,7 +45959,7 @@ msgstr ""
 msgid "duplicate label declaration %qE"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "паўтарэнне \"%s\""
@@ -45971,7 +45994,7 @@ msgstr ""
 msgid "%qE defined as wrong kind of tag"
 msgstr ""
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr ""
@@ -46117,12 +46140,12 @@ msgstr "ISO C89 не падтрымлівае \"long long\""
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, gcc-internal-format
 msgid "%<omp::%s%> not allowed to be specified in this context"
 msgstr ""
@@ -46133,7 +46156,7 @@ msgstr ""
 msgid "%q+D is usually a function"
 msgstr "`%s' - звычайна функцыя"
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for `%s'"
 msgid "no previous declaration for %qD"
@@ -46213,7 +46236,7 @@ msgstr ""
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -46403,7 +46426,7 @@ msgstr ""
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
@@ -46466,7 +46489,7 @@ msgstr ""
 msgid "declaration of type name as array of functions"
 msgstr ""
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, fuzzy, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -46580,7 +46603,7 @@ msgstr ""
 msgid "function definition has qualified void return type"
 msgstr "функцыя не вяртае тып string"
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -46709,7 +46732,7 @@ msgstr ""
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, fuzzy, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "тып параметра \"%s\" не аб'яўлены"
@@ -46816,7 +46839,7 @@ msgstr ""
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr ""
@@ -46908,17 +46931,17 @@ msgstr "перанакіраванне stdout: %s"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, gcc-internal-format
 msgid "%qT defined in underspecified object initializer"
 msgstr ""
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -46950,474 +46973,474 @@ msgstr ""
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr ""
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, gcc-internal-format
 msgid "union has no members"
 msgstr ""
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr ""
 
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr ""
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr ""
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, gcc-internal-format
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr ""
 
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, fuzzy, gcc-internal-format
 #| msgid "%s is too large"
 msgid "type %qT is too large"
 msgstr "%s - вельмі вялікі"
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, gcc-internal-format
 msgid "type punning toggles scalar storage order"
 msgstr ""
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr ""
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, gcc-internal-format
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr ""
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, fuzzy, gcc-internal-format
 msgid "redefinition of struct or union %qT"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "redeclaration of %<enum %E%>"
 msgstr "абвяшчэньне `%#D'"
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr ""
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, gcc-internal-format
 msgid "enumeration values exceed range of %qs"
 msgstr ""
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, fuzzy, gcc-internal-format
 msgid "conflicting redefinition of enum %qT"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr ""
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, gcc-internal-format
 msgid "enumerator value outside the range of underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, gcc-internal-format
 msgid "enumerator value outside the range of %qs"
 msgstr ""
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr ""
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr ""
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr ""
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, fuzzy, gcc-internal-format
 #| msgid "return type of `%s' is not `int'"
 msgid "return type defaults to %<int%>"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr ""
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, fuzzy, gcc-internal-format
 #| msgid "no previous prototype for `%s'"
 msgid "no previous prototype for %qD"
 msgstr "няма папярэдняга прататыпа для \"%s\""
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, fuzzy, gcc-internal-format
 #| msgid "return type of `%s' is not `int'"
 msgid "return type of %qD is not %<int%>"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is usually a function"
 msgid "%qD is normally a non-static function"
 msgstr "`%s' - звычайна функцыя"
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr ""
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr ""
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr ""
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr ""
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr ""
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr ""
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr ""
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr ""
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "number of arguments doesn%'t match prototype"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "prototype declaration"
 msgstr "пустое абвяшчэньне"
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "parameter %qD set but not used"
 msgstr "адмеціна `%D' вызначана, але не выкарыстоўваецца"
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C89 не падтрымлівае \"long long\""
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "duplicate %qE declaration specifier"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, gcc-internal-format
 msgid "%qs used with %<auto%>"
 msgstr ""
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, gcc-internal-format
 msgid "%<auto%> used with %<constexpr%>"
 msgstr ""
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, fuzzy, gcc-internal-format
 #| msgid "`long long long' is too long for GCC"
 msgid "%<long long long%> is too long for GCC"
 msgstr "`long long long' - вельмі доўга для GCC"
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support `long long'"
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C89 не падтрымлівае `long long'"
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qE"
 msgstr "паўтарэньне `%s'"
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, fuzzy, gcc-internal-format
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, fuzzy, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr ""
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%qE is not at beginning of declaration"
@@ -47425,147 +47448,147 @@ msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, gcc-internal-format
 msgid "%qE used with %<constexpr%>"
 msgstr ""
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s не падтрымлівае %s"
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C90 does not support %qE"
 msgstr "%s не падтрымлівае %s"
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr ""
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr ""
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, gcc-internal-format
 msgid "%<typedef%> used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, gcc-internal-format
 msgid "%qE used with %<extern%>"
 msgstr ""
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, gcc-internal-format
 msgid "%qE used with %qs"
 msgstr ""
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr ""
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, gcc-internal-format
 msgid "%<constexpr%> used with %qE"
 msgstr ""
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не падтрымлівае просты \"complex\" у значэнні \"double complex\""
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, gcc-internal-format
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr ""
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
@@ -47595,7 +47618,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr ""
@@ -47606,8 +47629,8 @@ msgstr ""
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr ""
@@ -47648,9 +47671,9 @@ msgstr ""
 msgid "unknown type name %qE"
 msgstr "невядомая назва рэгістра: %s"
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration specifiers"
@@ -47682,7 +47705,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "\"%s\" атрыбут ігнарыруецца"
@@ -47703,7 +47726,7 @@ msgstr ""
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, gcc-internal-format
 msgid "%<assume%> attribute not followed by %<;%>"
 msgstr ""
@@ -47795,7 +47818,7 @@ msgstr ""
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
@@ -47871,10 +47894,10 @@ msgstr "параметр \"%s\" ініцыялізаваны"
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
@@ -48026,7 +48049,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr ""
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr ""
@@ -48036,8 +48059,8 @@ msgstr ""
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs attribute argument"
 msgstr ""
@@ -48214,12 +48237,12 @@ msgstr "ISO C не дазваляе пусты ізыходны файл"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr ""
@@ -48370,7 +48393,7 @@ msgstr "ISO C не падтрымлівае комлексныя цэлалік
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, gcc-internal-format
 msgid "expected expression"
 msgstr ""
@@ -48696,12 +48719,12 @@ msgstr ""
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr ""
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, fuzzy, gcc-internal-format
 msgid "missing property attribute"
 msgstr "прапушчан ініцыялізатар"
@@ -48711,57 +48734,57 @@ msgstr "прапушчан ініцыялізатар"
 msgid "unknown property attribute %<%s%s%>"
 msgstr ""
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr ""
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr ""
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr ""
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr ""
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -48771,25 +48794,25 @@ msgstr ""
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr ""
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
@@ -48805,64 +48828,64 @@ msgstr ""
 msgid "expected %<)%> or %<,%>"
 msgstr ""
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "\"%s\" звычайна функцыя"
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, gcc-internal-format
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr ""
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, gcc-internal-format
 msgid "expected constant logical expression"
 msgstr ""
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr ""
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr ""
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses"
 msgstr "вельмі шмат уваходзячых файлаў"
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -48885,22 +48908,22 @@ msgstr ""
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr ""
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr ""
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr ""
@@ -48910,96 +48933,96 @@ msgstr ""
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr ""
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr ""
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many %<static%> arguments"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "unexpected argument"
 msgstr "няма аргументаў"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr ""
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, gcc-internal-format
 msgid "too many %<self%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, gcc-internal-format
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr ""
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr ""
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr ""
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%-code"
 msgid "invalid schedule kind"
@@ -49010,22 +49033,22 @@ msgstr "нерэчаісны %%-код"
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr ""
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, gcc-internal-format
 msgid "expected %<allocator%> or %<align%>"
 msgstr ""
@@ -49036,22 +49059,22 @@ msgstr ""
 msgid "duplicate %qs modifier"
 msgstr "паўтарэньне `%s'"
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, gcc-internal-format
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr ""
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, gcc-internal-format
 msgid "multiple linear modifiers"
 msgstr ""
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, gcc-internal-format
 msgid "multiple %<step%> modifiers"
 msgstr ""
@@ -49071,66 +49094,66 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr ""
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "нерэчаісны %%d аперанд"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid doacross kind"
 msgstr "нерэчаісная маска"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, gcc-internal-format
 msgid "too many %<always%> modifiers"
 msgstr ""
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, gcc-internal-format
 msgid "too many %<close%> modifiers"
 msgstr ""
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<present%> modifiers"
 msgstr "вельмі шмат уваходзячых файлаў"
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "нерэчаісная маска"
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr ""
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, gcc-internal-format
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr ""
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, gcc-internal-format
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr ""
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -49145,89 +49168,89 @@ msgstr "Нерэчаісны выбар %s"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr ""
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, gcc-internal-format
 msgid "expected an OpenACC clause"
 msgstr ""
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%qs is not valid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, gcc-internal-format
 msgid "expected an OpenMP clause"
 msgstr ""
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr ""
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr ""
@@ -49242,7 +49265,7 @@ msgstr ""
 msgid "expected function name"
 msgstr ""
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD does not refer to a function"
@@ -49253,22 +49276,22 @@ msgstr "`%D' - гэта ня функцыя,"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
@@ -49294,7 +49317,7 @@ msgstr ""
 msgid "modified here"
 msgstr "'O' мадыфікатар"
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, gcc-internal-format
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
 msgstr ""
@@ -49334,111 +49357,111 @@ msgstr ""
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr ""
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr ""
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr ""
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many atomic clauses"
 msgstr "вельмі шмат уваходзячых файлаў"
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr ""
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, gcc-internal-format
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, gcc-internal-format
 msgid "%qs clause requires %qs clause"
 msgstr ""
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, gcc-internal-format
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr ""
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, gcc-internal-format
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr ""
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr ""
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, gcc-internal-format
 msgid "unexpected %<else%>"
 msgstr ""
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, gcc-internal-format
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr ""
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr ""
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr ""
@@ -49448,27 +49471,27 @@ msgstr ""
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr ""
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr ""
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr ""
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr ""
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr ""
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -49478,163 +49501,163 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr ""
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr ""
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr ""
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr ""
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, gcc-internal-format
 msgid "not enough nested loops"
 msgstr ""
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr ""
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr ""
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, gcc-internal-format
 msgid "expected trait selector name"
 msgstr ""
 
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, gcc-internal-format
 msgid "unknown selector %qs for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, gcc-internal-format
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr ""
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, gcc-internal-format
 msgid "%<score%> argument must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, gcc-internal-format
 msgid "%<score%> argument must be non-negative"
 msgstr ""
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr ""
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
@@ -49642,291 +49665,291 @@ msgstr ""
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, gcc-internal-format
 msgid "%<requires%> selector is not supported yet"
 msgstr ""
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, gcc-internal-format
 msgid "expected context selector set name"
 msgstr ""
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr ""
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "variant %qD is not a function"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, gcc-internal-format
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr ""
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, gcc-internal-format
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr ""
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr ""
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr ""
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, gcc-internal-format
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr ""
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, gcc-internal-format
 msgid "expected %<declare%> or %<assumes%>"
 msgstr ""
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, gcc-internal-format
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr ""
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr ""
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr ""
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr ""
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, gcc-internal-format
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, gcc-internal-format
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, gcc-internal-format
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr ""
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, gcc-internal-format
 msgid "expected %qs or %qs"
 msgstr ""
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, gcc-internal-format
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr ""
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr ""
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, gcc-internal-format
 msgid "expected at least one assumption clause"
 msgstr ""
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, gcc-internal-format
 msgid "expected directive name"
 msgstr ""
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr ""
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, fuzzy, gcc-internal-format
 msgid "unknown assumption clause %qs"
 msgstr "невядомая назва рэгістра: %s\n"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, gcc-internal-format
 msgid "expected assumption clause"
 msgstr ""
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, gcc-internal-format
 msgid "no closing brace"
 msgstr ""
@@ -50068,7 +50091,7 @@ msgstr ""
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr ""
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr ""
@@ -50098,7 +50121,7 @@ msgstr ""
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -50214,17 +50237,17 @@ msgstr ""
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr ""
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr ""
@@ -50249,7 +50272,7 @@ msgstr ""
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -50544,7 +50567,7 @@ msgstr ""
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
@@ -50718,7 +50741,7 @@ msgstr ""
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -50918,12 +50941,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -50933,7 +50956,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr ""
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr ""
@@ -50964,7 +50987,7 @@ msgstr "памер масіва \"%s\" адмоўны"
 msgid "initializer element is not computable at load time"
 msgstr ""
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
@@ -50979,7 +51002,7 @@ msgstr ""
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
@@ -51070,7 +51093,7 @@ msgstr ""
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
@@ -51111,7 +51134,7 @@ msgstr "ISO C не падтрымлівае \"goto *expr;\""
 msgid "computed goto must be pointer type"
 msgstr ""
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function declared %<noreturn%> has a %<return%> statement"
@@ -51167,7 +51190,7 @@ msgstr ""
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -51213,27 +51236,27 @@ msgstr ""
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr ""
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr ""
@@ -51305,29 +51328,29 @@ msgstr ""
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr ""
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
@@ -51338,85 +51361,85 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr ""
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr ""
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr ""
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr ""
@@ -51426,17 +51449,17 @@ msgstr ""
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr ""
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr ""
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, fuzzy, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
@@ -51446,32 +51469,32 @@ msgstr ""
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr ""
@@ -51501,7 +51524,7 @@ msgstr ""
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -51511,17 +51534,17 @@ msgstr ""
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
 msgstr ""
@@ -51536,23 +51559,23 @@ msgstr ""
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, gcc-internal-format
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -51564,32 +51587,32 @@ msgstr ""
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr ""
@@ -51609,7 +51632,7 @@ msgstr ""
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr ""
@@ -51619,7 +51642,7 @@ msgstr ""
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr ""
@@ -51629,77 +51652,77 @@ msgstr ""
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr ""
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported map expression %qE"
 msgstr "непадтрымліваемая версія"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
@@ -51714,22 +51737,22 @@ msgstr ""
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr ""
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
@@ -51739,38 +51762,38 @@ msgstr ""
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
@@ -52044,14 +52067,14 @@ msgstr "пераўтварэньне з `%T' у `%T'"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr ""
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -52361,561 +52384,561 @@ msgstr ""
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr ""
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, fuzzy, gcc-internal-format
 #| msgid "return type of `%s' is not `int'"
 msgid "return type of %qD is not %qs"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, gcc-internal-format
 msgid "no match for call to %<%T::operator[] (%A)%>"
 msgstr ""
 
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, gcc-internal-format
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr ""
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr ""
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, fuzzy, gcc-internal-format
 #| msgid "impossible operator '%s'"
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "немагчымы апэратар '%s'"
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "declared protected here"
 msgstr "выклікана адсюль"
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr ""
 
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, fuzzy, gcc-internal-format
 #| msgid "  from here"
 msgid "  declared here"
 msgstr " адсюль"
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr ""
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr ""
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr ""
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr ""
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 #, fuzzy
 #| msgid "converting from `%T' to `%T'"
 msgid "invalid conversion from %qH to %qI"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr ""
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr ""
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, fuzzy, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr ""
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr ""
 
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr ""
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr ""
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, gcc-internal-format
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr ""
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 msgid "cannot convert %qH to %qI"
 msgstr ""
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr ""
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, gcc-internal-format
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr ""
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, gcc-internal-format
 msgid "try making the operator a %<const%> member function"
 msgstr ""
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 #, fuzzy
 #| msgid "converting from `%T' to `%T'"
 msgid "  for conversion from %qH to %qI"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr ""
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr ""
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr ""
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, gcc-internal-format
 msgid "possibly dangling reference to a temporary"
 msgstr ""
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr ""
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, gcc-internal-format
 msgid "explicit conversion function was not considered"
 msgstr ""
@@ -52961,7 +52984,7 @@ msgid "%q#D cannot be overloaded with %q#D"
 msgstr ""
 
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %q#D"
@@ -53385,7 +53408,7 @@ msgstr ""
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "redefinition of %q#T"
@@ -53518,7 +53541,7 @@ msgstr ""
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
@@ -53559,7 +53582,7 @@ msgstr ""
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr ""
@@ -53577,7 +53600,7 @@ msgstr ""
 msgid "%q+E is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -53598,7 +53621,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, fuzzy, gcc-internal-format
 #| msgid "can't initialize friend function `%s'"
@@ -53647,7 +53670,7 @@ msgstr ""
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -53775,18 +53798,18 @@ msgstr ""
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -53794,474 +53817,474 @@ msgstr ""
 msgid "%qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr ""
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr ""
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr ""
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr ""
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr ""
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr ""
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr ""
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr ""
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr ""
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr ""
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, fuzzy, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "allocated here"
 msgstr "выклікана адсюль"
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
 msgstr ""
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "%qD used in its own initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%q#D is not const"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr ""
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, gcc-internal-format
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, gcc-internal-format
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, gcc-internal-format
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, gcc-internal-format
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr ""
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr ""
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr ""
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, fuzzy, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "use of %qD"
 msgstr "нерэчаіснае выкарыстаньне `%D'"
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr ""
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr ""
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr ""
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr ""
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, gcc-internal-format
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, gcc-internal-format
 msgid "pointed-to object declared here"
 msgstr ""
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr ""
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr ""
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr ""
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, fuzzy, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, gcc-internal-format
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr ""
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
@@ -54984,7 +55007,7 @@ msgstr "аргумент `__builtin_args_info' павінен быць канс
 msgid "no suspend point info for %qD"
 msgstr ""
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -55005,23 +55028,23 @@ msgstr ""
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr ""
@@ -55041,68 +55064,68 @@ msgstr ""
 msgid "%qD was promoted to an immediate function"
 msgstr ""
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr ""
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, gcc-internal-format
 msgid "call to consteval function %qE is not a constant expression"
 msgstr ""
 
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, gcc-internal-format
 msgid "pack expansion of %qE attribute"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, gcc-internal-format
 msgid "use fold expression in the attribute argument instead"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
@@ -55144,7 +55167,7 @@ msgstr ""
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -55532,7 +55555,7 @@ msgstr "папярэдняе абвяшчэньне `%D'"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "гэта папярэдняе абвяшчэньне"
 
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %qD"
@@ -55677,8 +55700,8 @@ msgstr "няма папярэдняга аб'яўлення для \"%s\""
 msgid "%q#D previously defined here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, fuzzy, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
@@ -55754,54 +55777,39 @@ msgstr "нехапае аргументаў у функцыі \"%s\""
 msgid "previous specification in %q#D here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:2285
-#, fuzzy, gcc-internal-format
-msgid "declaration %qD conflicts with builtin"
-msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
-
-#: cp/decl.cc:2288
-#, fuzzy, gcc-internal-format
-msgid "declaration %qD conflicts with import"
-msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
-
-#: cp/decl.cc:2289
-#, fuzzy, gcc-internal-format
-msgid "import declared %q#D here"
-msgstr "няма папярэдняга аб'яўлення для \"%s\""
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration `%#D'"
 msgid "conflicting exporting for declaration %qD"
 msgstr "канфлікт з папярэднім абвяшчэньнем `%#D'"
 
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, gcc-internal-format
 msgid "previously declared here without exporting"
 msgstr ""
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "previous definition of %qD here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr ""
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr ""
@@ -55814,46 +55822,46 @@ msgstr ""
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, fuzzy, gcc-internal-format
 #| msgid "section of `%s' conflicts with previous declaration"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "redefinition of %q#D"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, fuzzy, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, fuzzy, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -55861,2535 +55869,2535 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "redeclaration of %q#D"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr ""
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, fuzzy, gcc-internal-format
 msgid "jump to label %qD"
 msgstr "паўтарэнне \"%s\""
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr ""
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr ""
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, gcc-internal-format
 msgid "  from here"
 msgstr " адсюль"
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr ""
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr ""
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, fuzzy, gcc-internal-format
 msgid "  enters statement expression"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, gcc-internal-format
 msgid "  enters %<consteval if%> statement"
 msgstr ""
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "  does not destroy %qD"
 msgstr "%s не падтрымлівае %s"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, gcc-internal-format
 msgid "  does not clean up handled exception"
 msgstr ""
 
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr ""
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, fuzzy, gcc-internal-format
 msgid "%qD is a function, not a type"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr ""
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr ""
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr ""
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr ""
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr ""
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr ""
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qD"
 msgstr "прапушчан памер масіва ў `%D'"
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qD"
 msgstr "нулявы памер масіва `%D'"
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, fuzzy, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr ""
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "Не магу знайсці дэкларацыю інтэрфейса для \"%s\""
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr ""
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr ""
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "%<declare variant%> on deleted %qD"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, fuzzy, gcc-internal-format
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr ""
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr ""
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr ""
 
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr ""
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr ""
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qT"
 msgstr "прапушчан памер масіва ў `%D'"
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qT"
 msgstr "нулявы памер масіва `%D'"
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a function concept cannot be constrained"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr ""
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, gcc-internal-format
 msgid "constrained non-template friend declaration must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr ""
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr ""
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, gcc-internal-format
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, gcc-internal-format
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, fuzzy, gcc-internal-format
 msgid "explicit object parameter declared here"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr ""
 
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr ""
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, fuzzy, gcc-internal-format
 #| msgid "`main' must return `int'"
 msgid "%<::main%> must return %<int%>"
 msgstr "`main' павінна вяртаць `int'"
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr ""
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a variable concept cannot be constrained"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' has non-integer type"
 msgid "size of array %qD has non-integral type %qT"
 msgstr "памер масіва `%D' не цэлалікавы тып"
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr ""
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr ""
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as array of void"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr ""
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr ""
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr ""
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr ""
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr ""
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr ""
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr ""
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr ""
 
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qE as non-member"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as parameter"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "пустое абвяшчэнне"
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не падтрымлівае просты \"complex\" у значэнні \"double complex\""
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ не падтрымлівае \"long long\""
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr ""
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr ""
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr ""
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, gcc-internal-format
 msgid "%qs specified with typedef-name %qD"
 msgstr ""
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr ""
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr ""
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "complex invalid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr ""
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr ""
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr ""
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "multiple storage classes in declaration of %qs"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "attribute ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr ""
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, gcc-internal-format
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, gcc-internal-format
 msgid "a function type cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, gcc-internal-format
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, gcc-internal-format
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr ""
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, gcc-internal-format
 msgid "the type of an explicit object member function is a regular function type"
 msgstr ""
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "valid explicit object parameter declared here"
 msgstr ""
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qs declared as function returning a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, gcc-internal-format
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr ""
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, gcc-internal-format
 msgid "%qD cannot be an explicit object member function"
 msgstr ""
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "Не магу знайсці файл для класа %s."
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "%<explicit%> outside class declaration"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr ""
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr ""
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "Не магу знайсці дэкларацыю пратакола для \"%s\""
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr ""
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `::'"
 msgid "invalid use of %<::%>"
 msgstr "нерэчаіснае выкарыстаньне `::'"
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "declaration of %qD as member of %qT"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr ""
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, fuzzy, gcc-internal-format
 #| msgid "[cannot find %s]"
 msgid "%qD cannot be %qs"
 msgstr "[нельга знайсці %s]"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, fuzzy, gcc-internal-format
 #| msgid "can't initialize friend function `%s'"
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr ""
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr ""
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "%qD must have no arguments"
 msgstr "няма аргументаў"
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, fuzzy, gcc-internal-format
 #| msgid "this is a previous declaration"
 msgid "%qD has a previous declaration here"
 msgstr "гэта папярэдняе абвяшчэньне"
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, fuzzy, gcc-internal-format
 #| msgid "this is a previous declaration"
 msgid "%qT has a previous declaration here"
 msgstr "гэта папярэдняе абвяшчэньне"
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -58401,116 +58409,101 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr ""
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "redeclaration of %qT as a non-template"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, gcc-internal-format
-msgid "cannot declare %qD in a different module"
-msgstr ""
-
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, fuzzy, gcc-internal-format
-msgid "previously declared here"
-msgstr "няма папярэдняга аб'яўлення для \"%s\""
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "паўтарэнне \"restrict\""
 
-#: cp/decl.cc:16984
-#, gcc-internal-format
-msgid "cannot declare %qD in different module"
-msgstr ""
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -58519,83 +58512,83 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "multiple definition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr ""
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "не знойдзен клас \"%s\""
 
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, gcc-internal-format
 msgid "using %qs"
 msgstr ""
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -58650,7 +58643,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr "метка \"%s\" ужываецца, але не вызначана"
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "пустое абвяшчэнне"
@@ -58660,7 +58653,7 @@ msgstr "пустое абвяшчэнне"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr ""
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -58845,64 +58838,64 @@ msgstr ""
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr ""
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, gcc-internal-format
 msgid "%qT has a base %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, gcc-internal-format
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, gcc-internal-format
 msgid "%qT has a base %qT which has internal linkage"
 msgstr ""
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, gcc-internal-format
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr ""
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but not defined"
 msgstr ""
@@ -58911,107 +58904,107 @@ msgstr ""
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr ""
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, fuzzy, gcc-internal-format
 #| msgid "section of `%s' conflicts with previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous mangling %q#D"
 msgstr "папярэдняе абвяшчэньне `%D'"
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, gcc-internal-format
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "inline function %qD used but never defined"
 msgstr "адмеціна `%D' выкарыстоўвываецца, але ня вызначана"
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q#D"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, gcc-internal-format
 msgid "...following parameter %P which has a default argument"
 msgstr ""
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, fuzzy, gcc-internal-format
 msgid "implicitly-declared %qD is deprecated"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr ""
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -59117,7 +59110,7 @@ msgstr "памер \"%s\" - %d байт"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr ""
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr ""
@@ -59127,7 +59120,7 @@ msgstr ""
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr ""
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr ""
@@ -59152,47 +59145,47 @@ msgstr ""
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr ""
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, gcc-internal-format
 msgid "  in thrown expression"
 msgstr ""
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, gcc-internal-format
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr ""
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, gcc-internal-format
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr ""
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, gcc-internal-format
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr ""
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, gcc-internal-format
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr ""
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, gcc-internal-format
 msgid "for type %qT"
 msgstr ""
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, gcc-internal-format
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr ""
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr ""
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
 msgstr ""
@@ -59460,12 +59453,12 @@ msgstr ""
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "\"%s\" мае незавершаны тып"
@@ -59480,12 +59473,12 @@ msgstr ""
 msgid "invalid pointer to bit-field %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -59681,52 +59674,52 @@ msgstr ""
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr ""
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr ""
@@ -60098,225 +60091,272 @@ msgstr ""
 msgid "encapsulation is malformed"
 msgstr ""
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, fuzzy, gcc-internal-format
 msgid "conflicting global module declaration %#qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "existing declaration %#qD"
 msgstr "у абвяшчэньні  `%D'"
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, gcc-internal-format
 msgid "definition of %qD does not match"
 msgstr ""
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "existing definition %qD"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, gcc-internal-format
 msgid "... this enumerator %qD"
 msgstr ""
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, gcc-internal-format
 msgid "enumerator %qD does not match ..."
 msgstr ""
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr ""
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr ""
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr ""
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, gcc-internal-format
 msgid "recursive lazy load"
 msgstr ""
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr ""
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, gcc-internal-format
 msgid "module %qs declared here"
 msgstr ""
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, gcc-internal-format
 msgid "indirect import %qs is not already loaded"
 msgstr ""
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr ""
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr ""
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, gcc-internal-format
 msgid "macro definitions of %qE corrupted"
 msgstr ""
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, gcc-internal-format
 msgid "inconsistent imported macro definition %qE"
 msgstr ""
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr ""
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr ""
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, gcc-internal-format
 msgid "compiled module file is %qs"
 msgstr ""
 
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, gcc-internal-format, gfc-internal-format
 msgid "compiled module is %sversion %s"
 msgstr ""
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, gcc-internal-format, gfc-internal-format
 msgid "compiler is %sversion %s%s%s"
 msgstr ""
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, gcc-internal-format
 msgid "module %qs found"
 msgstr ""
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr ""
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr ""
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr ""
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr ""
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, gcc-internal-format
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr ""
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, fuzzy, gcc-internal-format
 msgid "fixed tree mismatch"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, gcc-internal-format
 msgid "interface partition is not exported"
 msgstr ""
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module cluster %u: %s"
 msgstr ""
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module: %s"
 msgstr ""
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr ""
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr ""
 
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr ""
 
-#: cp/module.cc:19283
+#: cp/module.cc:19117
+#, fuzzy, gcc-internal-format
+msgid "declaration %qD conflicts with builtin"
+msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
+
+#: cp/module.cc:19122
+#, gcc-internal-format
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr ""
+
+#: cp/module.cc:19125
+#, gcc-internal-format
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr ""
+
+#: cp/module.cc:19130
+#, gcc-internal-format
+msgid "import declared attached to module %qs"
+msgstr ""
+
+#: cp/module.cc:19134
+#, gcc-internal-format
+msgid "import declared in global module"
+msgstr ""
+
+#: cp/module.cc:19140
+#, fuzzy, gcc-internal-format
+msgid "conflicting declaration of %qD in module %qs"
+msgstr "паўторнае абвяшчэнне меткі \"%s\""
+
+#: cp/module.cc:19143
+#, gcc-internal-format
+msgid "conflicting declaration of %qD in global module"
+msgstr ""
+
+#: cp/module.cc:19148
+#, fuzzy, gcc-internal-format
+#| msgid "previous declaration of `%D'"
+msgid "previously declared in module %qs"
+msgstr "папярэдняе абвяшчэньне `%D'"
+
+#: cp/module.cc:19152
+#, fuzzy, gcc-internal-format
+#| msgid "previous declaration of `%D'"
+msgid "previously declared in global module"
+msgstr "папярэдняе абвяшчэньне `%D'"
+
+#: cp/module.cc:19404
 #, gcc-internal-format
 msgid "reading CMI %qs"
 msgstr ""
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, gcc-internal-format
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, gcc-internal-format
 msgid "during load of pendings for %<%E%s%E%>"
 msgstr ""
@@ -60328,399 +60368,399 @@ msgstr ""
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr ""
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, gcc-internal-format
 msgid "module already declared"
 msgstr ""
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, gcc-internal-format
 msgid "module already imported"
 msgstr ""
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, gcc-internal-format
 msgid "module %qs imported here"
 msgstr ""
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown Compiled Module Interface: %s"
 msgstr ""
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr ""
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr ""
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr ""
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, gcc-internal-format
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr ""
 
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, gcc-internal-format
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr ""
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr ""
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr ""
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, gcc-internal-format
 msgid "you should use the %<-%s%> option"
 msgstr ""
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name for `%s'"
 msgid "invalid header name %qs"
 msgstr "нерэчаісная назва рэгістра `%s'"
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, fuzzy, gcc-internal-format
 msgid "invalid module name %qs"
 msgstr "Нерэчаісны выбар %s"
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr ""
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, fuzzy, gcc-internal-format
 #| msgid "error writing to %s"
 msgid "writing CMI %qs"
 msgstr "памылка запісу ў %s"
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, gcc-internal-format
 msgid "not writing module %qs due to errors"
 msgstr ""
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to write compiled module: %s"
 msgstr ""
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown header kind %qs"
 msgstr "невядомая назва рэгістра: %s"
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, gcc-internal-format
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr ""
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr ""
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration `%#D'"
 msgid "%q#D conflicts with a previous declaration"
 msgstr "канфлікт з папярэднім абвяшчэньнем `%#D'"
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, fuzzy, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "дэструктару неабходны \"%#D\""
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, fuzzy, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, fuzzy, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %q#D shadows a parameter"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr ""
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr ""
 
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr ""
 
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr ""
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, gcc-internal-format
 msgid "exporting %q#D that does not have external linkage"
 msgstr ""
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, gcc-internal-format
 msgid "%q#D declared here with no linkage"
 msgstr ""
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, gcc-internal-format
 msgid "%q#D declared here with internal linkage"
 msgstr ""
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, gcc-internal-format
 msgid "%q#D declared here with module linkage"
 msgstr ""
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr ""
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr ""
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr ""
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr ""
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, fuzzy, gcc-internal-format
 #| msgid "%s: Not a directory"
 msgid "%qT is not a direct base of %qT"
 msgstr "%s: не дырэкторыя"
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "using-declaration may not name namespace %qD"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "дэструктару неабходны \"%#D\""
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr ""
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qD attribute directive ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr ""
 
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr ""
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr ""
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr ""
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr ""
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, gcc-internal-format
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, fuzzy, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "YYDEBUG не вызначан."
 
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr ""
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous definition here"
 msgid "reachable %s definition here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -60745,7 +60785,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -60992,7 +61032,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
@@ -61174,7 +61214,7 @@ msgstr ""
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr ""
@@ -61229,7 +61269,7 @@ msgstr ""
 msgid "template-id not allowed for destructor in C++20"
 msgstr ""
 
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, gcc-internal-format
 msgid "remove the %qs"
 msgstr ""
@@ -61249,7 +61289,7 @@ msgstr ""
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "\"%s\" мае незавершаны тып"
@@ -61300,7 +61340,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -61338,7 +61378,7 @@ msgstr ""
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr ""
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of %qD"
@@ -61364,7 +61404,7 @@ msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr ""
@@ -61514,8 +61554,8 @@ msgstr ""
 msgid "capture of non-variable %qE"
 msgstr ""
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
@@ -61556,7 +61596,7 @@ msgstr "памылковая колькасьць аргументаў, зада
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr ""
@@ -61684,7 +61724,7 @@ msgstr ""
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected selection-statement"
@@ -61749,7 +61789,7 @@ msgstr ""
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected iteration-statement"
@@ -61776,7 +61816,7 @@ msgstr ""
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
@@ -62059,12 +62099,12 @@ msgstr ""
 msgid "cannot expand initializer for member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -62710,7 +62750,7 @@ msgstr "невыкарыстаемы параметр \"%s\""
 msgid "%qT not permitted in template argument"
 msgstr ""
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%T'"
@@ -62892,12 +62932,12 @@ msgstr "папярэдняе вызначэньне `%#T'"
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, gcc-internal-format
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr ""
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
@@ -63099,37 +63139,37 @@ msgstr ""
 msgid "expression must be enclosed in parentheses"
 msgstr ""
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr ""
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr ""
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr ""
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "невыкарыстаемы параметр \"%s\""
@@ -63138,445 +63178,445 @@ msgstr "невыкарыстаемы параметр \"%s\""
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, gcc-internal-format
 msgid "template-id not allowed for constructor in C++20"
 msgstr ""
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "-pipe не падтрымліваецца."
 
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "пустое абвяшчэнне"
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, gcc-internal-format
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qD specifier"
 msgstr "паўтарэньне `%s'"
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, gcc-internal-format
 msgid "%qD specifier conflicts with %qs"
 msgstr ""
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, gcc-internal-format
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr ""
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ не падтрымлівае \"long long\""
 
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qD"
 msgstr "паўтарэньне `%s'"
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qs"
 msgstr "паўтарэньне `%s'"
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr ""
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr ""
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr ""
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr ""
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr ""
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, fuzzy, gcc-internal-format
 #| msgid "unregistered operator %s"
 msgid "expected %<operator%>"
 msgstr "нераспазнаны аператар %s"
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr ""
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr ""
 
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr ""
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr ""
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr ""
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr ""
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr ""
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr ""
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr ""
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr ""
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr ""
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr ""
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr ""
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr ""
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr ""
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr ""
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mode for gen_tst_reg"
 msgid "invalid type for instance variable"
 msgstr "нерэчаісны рэжым для gen_tst_reg"
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid type for property"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr ""
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, gcc-internal-format
 msgid "expected integer expression list"
 msgstr ""
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr ""
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr ""
@@ -63585,12 +63625,12 @@ msgstr ""
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr ""
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
@@ -63600,134 +63640,134 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr ""
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr ""
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr ""
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr ""
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, gcc-internal-format
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr ""
 
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, gcc-internal-format
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr ""
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr ""
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr ""
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -63757,7 +63797,7 @@ msgstr ""
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
@@ -63773,28 +63813,28 @@ msgstr "папярэдняе вызначэньне `%#T'"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "specialization of alias template %qD"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "ініцыялізацыя"
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "from definition of %q#D"
@@ -63802,143 +63842,143 @@ msgstr "папярэдняе вызначэньне `%#T'"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr ""
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr ""
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr ""
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "ініцыялізацыя"
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "прапушчан прабел пасля нумара \"%.*s\""
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "прапушчан прабел пасля нумара \"%.*s\""
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, fuzzy, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, fuzzy, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, fuzzy, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "ініцыялізацыя"
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD is not a template function"
@@ -63952,157 +63992,157 @@ msgstr "`%D' - гэта ня функцыя,"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "у функцыі \"%s\":"
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr ""
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "friend declaration here"
 msgstr "у абвяшчэньні  `%D'"
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr ""
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr ""
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr ""
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "too many arguments for partial specialization %qT"
 msgstr "вельмі шмат аргумэнтаў у функцыі `%s'"
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr ""
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
@@ -64111,47 +64151,47 @@ msgstr "нехапае аргументаў у функцыі \"%s\""
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -64161,509 +64201,509 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "template definition of non-template %q#D"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD with different constraints"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "нявернае выкарыстанне \"restict\""
 msgstr[1] "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "няма папярэдняга аб'яўлення для \"%s\""
 msgstr[1] "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, gcc-internal-format
 msgid "redeclared here"
 msgstr ""
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr ""
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D with different constraints"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr ""
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr ""
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr ""
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr ""
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr ""
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "in template argument for type %qT"
 msgstr "звычайны аргумэнт для `%#D' мае тып `%T'"
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr ""
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr ""
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of destructor %qE as a type"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr ""
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr ""
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, fuzzy, gcc-internal-format
 msgid "provided for %qD"
 msgstr "дэструктару неабходны \"%#D\""
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr ""
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr ""
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr ""
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr ""
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr ""
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr ""
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr ""
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, gcc-internal-format, gfc-internal-format
 msgid "mismatched argument pack lengths (%d vs %d)"
 msgstr ""
@@ -64681,307 +64721,307 @@ msgstr ""
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid parameter type %qT"
 msgstr "нерэчаісны тып парамэтра `%T'"
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "in declaration %q+D"
 msgstr "у абвяшчэньні  `%D'"
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function returning an array"
 msgstr "функцыя не вяртае тып string"
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr ""
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "template argument for %qD uses local type %qT"
 msgstr "звычайны аргумэнт для `%#D' мае тып `%T'"
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 msgid "%s %#qS"
 msgstr ""
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -64993,164 +65033,164 @@ msgstr ""
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr ""
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a concept cannot be constrained"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr ""
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr ""
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr ""
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "ініцыялізацыя"
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -65359,631 +65399,631 @@ msgstr "тып параметра \"%s\" не аб'яўлены"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr ""
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, gcc-internal-format
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr ""
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr ""
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, fuzzy, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, gcc-internal-format
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr ""
 
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, gcc-internal-format
 msgid "use explicit object parameter %qs instead"
 msgstr ""
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, gcc-internal-format
 msgid "name the explicit object parameter"
 msgstr ""
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr ""
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, gcc-internal-format
 msgid "invalid use of %<this%> before it is valid"
 msgstr ""
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of %<this%> after it is valid"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr ""
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, gcc-internal-format
 msgid "%<auto{x}%> cannot be constrained"
 msgstr ""
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, gcc-internal-format
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "Нерэчаісная спецыфікацыя! Памылка ў cc."
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr ""
 
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr ""
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr ""
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is out of range"
 msgstr ""
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr ""
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, gcc-internal-format
 msgid "pointer-to-member mapping %qE not supported"
 msgstr ""
 
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, gcc-internal-format
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr ""
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr ""
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr ""
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr ""
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr ""
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr ""
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr ""
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr ""
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, gcc-internal-format
 msgid "%<filter%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr ""
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr ""
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr ""
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr ""
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr ""
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, gcc-internal-format
 msgid "static assertion failed: %.*s"
 msgstr ""
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr ""
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr ""
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr ""
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr ""
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr ""
@@ -65991,1169 +66031,1169 @@ msgstr ""
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr ""
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr ""
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid " declared here"
 msgstr "выклікана адсюль"
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, fuzzy, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "Клас \"%s\" ужо існуе"
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD is not public"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, gcc-internal-format
 msgid "%qD is mutable"
 msgstr ""
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr ""
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr ""
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, fuzzy, gcc-internal-format
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr ""
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr ""
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr ""
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "сімвальная канстанта вельмі доўгая"
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr ""
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, gcc-internal-format
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr ""
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr ""
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr ""
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr ""
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr ""
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr ""
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr ""
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr ""
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr ""
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD is not a member template function"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr ""
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr ""
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "вельмі шмат аргументаў у функцыі \"%s\""
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to member function %q#D"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to member function %q#D"
 msgstr "не хапае аргументаў у функцыі"
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to function %q#D"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to function %q#D"
 msgstr "не хапае аргументаў у функцыі"
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "вельмі шмат аргументаў у функцыі \"%s\""
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, gcc-internal-format
 msgid "the address %qE will never be NULL"
 msgstr ""
 
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr ""
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr ""
 
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr ""
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr ""
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr ""
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr ""
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr ""
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr ""
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr ""
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, gcc-internal-format
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, fuzzy, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "не магу атрымаць адрас бітавага поля \"%s\""
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids an empty source file"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr ""
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr ""
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, fuzzy, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 #, fuzzy
 #| msgid "converting from `%T' to `%T'"
 msgid "converting from %qH to %qI"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, gcc-internal-format
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, gcc-internal-format
 msgid "moving %qE of type %qT to itself"
 msgstr ""
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr ""
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "Нерэчаісны выбар %s"
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 msgid "cannot convert %qH to %qI in default argument"
 msgstr ""
 
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr ""
 
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 msgid "cannot convert %qH to %qI in initialization"
 msgstr ""
 
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 msgid "cannot convert %qH to %qI in return"
 msgstr ""
 
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 msgid "cannot convert %qH to %qI in assignment"
 msgstr ""
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, gcc-internal-format
 msgid "returning pointer to temporary"
 msgstr ""
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr ""
 
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, fuzzy, gcc-internal-format
 msgid "redundant move in initialization"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, gcc-internal-format
 msgid "not eliding copy on return from %qD"
 msgstr ""
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr ""
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -67382,156 +67422,156 @@ msgstr ""
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr ""
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr ""
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr ""
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, gcc-internal-format
 msgid "initializer-string for %qT is too long"
 msgstr ""
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, gcc-internal-format
 msgid "remove %<{ }%> around initializer"
 msgstr ""
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' has non-integer type"
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "памер масіва `%D' не цэлалікавы тып"
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr ""
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "\"%s\" мае незавершаны тып"
@@ -68520,7 +68560,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr ""
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid string constant `%E'"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -69848,7 +69888,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -70064,7 +70104,7 @@ msgstr ""
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr ""
@@ -70867,7 +70907,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
@@ -71675,12 +71715,12 @@ msgstr ""
 msgid "are_identical_variables: Bad type"
 msgstr ""
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr ""
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr ""
@@ -71930,273 +71970,273 @@ msgstr ""
 msgid "check_init_expr(): Unknown expression type"
 msgstr ""
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr ""
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr ""
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, gcc-internal-format
 msgid "Specification function %qs at %L must be PURE"
 msgstr ""
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr ""
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, gcc-internal-format
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr ""
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr ""
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr ""
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr ""
 
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, gcc-internal-format
 msgid "check_restricted(): Unknown expression type"
 msgstr ""
 
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, gcc-internal-format
 msgid "Function %qs at %L must be PURE"
 msgstr ""
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr ""
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr ""
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr ""
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr ""
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr ""
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal assignment to external procedure at %L"
 msgstr ""
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr ""
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr ""
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr ""
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr ""
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr ""
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
@@ -72204,192 +72244,192 @@ msgstr ""
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr ""
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr ""
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, gcc-internal-format, gfc-internal-format
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr ""
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr ""
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr ""
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr ""
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, gcc-internal-format
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, gcc-internal-format
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr ""
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -72410,8 +72450,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr ""
@@ -72492,7 +72532,7 @@ msgstr ""
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -72627,12 +72667,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -73504,7 +73544,7 @@ msgstr "пераўтварэньне з `%T' у `%T'"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr ""
@@ -74057,7 +74097,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -74227,6 +74267,11 @@ msgstr ""
 msgid "check_charlen_present(): length not set"
 msgstr ""
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr ""
+
 #: fortran/match.cc:118
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
@@ -74628,7 +74673,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr ""
@@ -75151,82 +75196,82 @@ msgstr ""
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr ""
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr ""
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr ""
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr ""
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr ""
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr ""
 
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr ""
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr ""
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -76651,8 +76696,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -79019,12 +79064,12 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -79144,7 +79189,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -79545,278 +79590,284 @@ msgstr ""
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, gcc-internal-format
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr ""
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "invalid parameter type `%T'"
+msgid "Invalid array reference at %L"
+msgstr "нерэчаісны тып парамэтра `%T'"
+
+#: fortran/resolve.cc:6433
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -79825,284 +79876,284 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -80110,212 +80161,212 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, gcc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -80323,1002 +80374,1002 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "String length at %L is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr ""
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr ""
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr ""
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr ""
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant character length at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr ""
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' defined but not used"
 msgid "Label %d at %L defined but not used"
 msgstr "адмеціна `%s' вызначана, але ня выкарыстоўваецца"
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' defined but not used"
 msgid "Label %d at %L defined but cannot be used"
 msgstr "адмеціна `%s' вызначана, але ня выкарыстоўваецца"
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -81871,330 +81922,330 @@ msgstr ""
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr "\"%s\" атрыбут ігнарыруецца"
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, gcc-internal-format
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr ""
+
+#: fortran/symbol.cc:508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr ""
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr ""
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, gcc-internal-format
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr ""
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr ""
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "\"%s\" звычайна функцыя"
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr "\"%s\" атрыбут ігнарыруецца"
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, gcc-internal-format
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr ""
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr ""
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr ""
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr ""
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr ""
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr ""
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr ""
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr ""
 
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr ""
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr ""
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr ""
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -82224,24 +82275,24 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -82429,38 +82480,38 @@ msgstr ""
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, fuzzy, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "Unknown argument list function at %L"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -82471,17 +82522,17 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr ""
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr ""
@@ -82622,7 +82673,7 @@ msgstr ""
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr ""
@@ -83001,6 +83052,11 @@ msgstr "\"%s\" не абвешчан (першае выкарыстанне ў 
 msgid "function %qD redeclared as variable"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
+#: lto/lto-symtab.cc:865
+#, fuzzy, gcc-internal-format
+msgid "previously declared here"
+msgstr "няма папярэдняга аб'яўлення для \"%s\""
+
 #: lto/lto.cc:174
 #, gcc-internal-format
 msgid "%<lto_obj_file_open()%> failed"
@@ -84262,7 +84318,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr ""
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, gcc-internal-format
 msgid "non-objective-c type %qT cannot be caught"
 msgstr ""
@@ -84272,7 +84328,7 @@ msgstr ""
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr ""
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, gcc-internal-format
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
 msgstr ""
diff --git a/gcc/po/da.po b/gcc/po/da.po
index 19cd9e94a49..73665b24f1d 100644
--- a/gcc/po/da.po
+++ b/gcc/po/da.po
@@ -137,7 +137,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc-9.1-b20190203\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
 "PO-Revision-Date: 2019-02-14 11:00+0200\n"
 "Last-Translator: Joe Hansen <joedalton2@yahoo.dk>\n"
 "Language-Team: Danish <dansk@dansk-gruppen.dk>\n"
@@ -545,7 +545,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr "-C og -o er indbyrdes uforenelige"
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 msgid "shared and mdll are not compatible"
 msgstr "shared og mdll er indbyrdes uforenelige"
 
@@ -20756,18 +20756,18 @@ msgstr "ukendt instruktion:"
 msgid "insn does not satisfy its constraints:"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "oprettet og brugt med en anden indstilling for »%s«"
 
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "oprettet og brugt med forskellige indstillinger for -fpic"
 
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 #, fuzzy
 #| msgid "created and used with different settings of -fpie"
 msgid "created and used with different settings of %<-fpie%>"
@@ -21091,7 +21091,7 @@ msgstr "længdemodifikation i strfmon-formatering"
 msgid "<command-line>"
 msgstr "<kommandolinje>"
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, fuzzy, c-format
 #| msgid "Unsupported operand for code '%c'"
 msgid "unsupported operand for code '%c'"
@@ -21111,9 +21111,9 @@ msgstr "ugyldig operand for »%%%c«"
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector constant"
@@ -21136,7 +21136,7 @@ msgstr "ugyldig operand for »%%%c«"
 msgid "incompatible register operand for '%%%c'"
 msgstr "ugyldig operand for »%%%c«"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, c-format
 msgid "missing operand"
 msgstr "manglende operand"
@@ -21168,93 +21168,93 @@ msgstr "ugyldig adresseringstilstand"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "ugyldige operander til binær %s"
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "»%%&« brugt uden nogle lokale dynamiske TLS-referencer"
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, c-format
 msgid "invalid %%J value"
 msgstr "ugyldig %%J-værdi"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, c-format
 msgid "invalid %%r value"
 msgstr "ugyldig %%r-værdi"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, c-format
 msgid "invalid %%R value"
 msgstr "ugyldig %%R-værdi"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, c-format
 msgid "invalid %%N value"
 msgstr "ugyldig %%N-værdi"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, c-format
 msgid "invalid %%P value"
 msgstr "ugyldig %%P-værdi"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, c-format
 msgid "invalid %%h value"
 msgstr "ugyldig %%h-værdi"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, c-format
 msgid "invalid %%L value"
 msgstr "ugyldig %%L-værdi"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, c-format
 msgid "invalid %%m value"
 msgstr "ugyldig %%m-værdi"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, c-format
 msgid "invalid %%M value"
 msgstr "ugyldig %%M-værdi"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, c-format
 msgid "invalid %%U value"
 msgstr "ugyldig %%U-værdi"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, c-format
 msgid "invalid %%s value"
 msgstr "ugyldig %%s-værdi"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, c-format
 msgid "invalid %%C value"
 msgstr "ugyldig %%C-værdi"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, c-format
 msgid "invalid %%E value"
 msgstr "ugyldig %%E-værdi"
 
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "ukendt relokaliserings-unspec"
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ugyldig %%xn-kode"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, c-format
 msgid "invalid operand address"
 msgstr "ugyldig operandadresse"
@@ -21351,37 +21351,37 @@ msgstr "ugyldig UNSPEC som operand: %d"
 msgid "unrecognized supposed constant"
 msgstr "ukendt formodet konstant"
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, c-format
 msgid "invalid shift operand"
 msgstr "ugyldig skift-operand"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, fuzzy, c-format
 #| msgid "Generate char instructions"
 msgid "predicated Thumb instruction"
 msgstr "Generér char-instruktioner"
 
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, fuzzy, c-format
 #| msgid "ret instruction not implemented"
 msgid "predicated instruction in conditional sequence"
 msgstr "ret-instruktion ikke implementeret"
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Ikke understøttet operand for koden »%c«"
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -21389,123 +21389,123 @@ msgstr "Ikke understøttet operand for koden »%c«"
 msgid "invalid operand for code '%c'"
 msgstr "ugyldig operand for koden »%c«"
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, c-format
 msgid "instruction never executed"
 msgstr "instruktion aldrig udført"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "forældet Maverick-formatkode »%c«"
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "ugyldig konvertering fra %<__fpreg%>"
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 #, fuzzy
 #| msgid "invalid conversion to type `%T' from type `%T'"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "adresseoperand kræver begrænsning for X-, Y- eller Z-register"
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "operander til %T/%t skal være reg + const_int:"
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 msgid "bad address, not an I/O address:"
 msgstr "ugyldig adresse, ikke en I/O-adresse:"
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 msgid "bad address, not a constant:"
 msgstr "ugyldig adresse, ikke en konstant:"
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 msgid "bad address, not (reg+disp):"
 msgstr "ugyldig adresse, ikke (reg+disp):"
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "ugyldig adresse, ikke post_inc eller pre_dec:"
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr "intern oversætterfejl - ugyldig adresse:"
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "Ikke understøttet kode »%c« for fast-punkt:"
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 msgid "internal compiler error.  Unknown mode:"
 msgstr "intern oversætterfejl - ugyldig tilstand:"
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 msgid "invalid insn:"
 msgstr "ugyldig instruktion:"
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 msgid "incorrect insn:"
 msgstr "ukorrekt instruktion:"
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 msgid "unknown move insn:"
 msgstr "ukendt flytteinstruktion:"
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 msgid "bad shift insn:"
 msgstr "ugyldig skifteinstruktion:"
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "intern oversætterfejl - ukorrekt skift:"
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 msgid "unsupported fixed-point conversion"
 msgstr "fast-punkt-konvertering er ikke understøttet"
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 msgid "variable"
 msgstr ""
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 #, fuzzy
 #| msgid "a parameter"
 msgid "function parameter"
 msgstr "en parameter"
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 #, fuzzy
 #| msgid "structure"
 msgid "structure field"
 msgstr "struktur"
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 #, fuzzy
 #| msgid "declaration of `%s' as array of functions"
 msgid "return type of function"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 #, fuzzy
 #| msgid "pointer"
 msgid "pointer"
@@ -21547,7 +21547,7 @@ msgstr "uventet operand"
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -21874,55 +21874,55 @@ msgstr "operand er ikke et heltal, ugyldig operandkode »R«"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operand er ikke et specifikt heltal, ugyldig operandkode »r«"
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ugyldig operandkode »%c«"
 
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ugyldige begrænsninger for operand"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector immediate"
 msgstr "ugyldig konstant:"
 
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 msgid "unknown insn mode"
 msgstr "ukendt instruktionstilstand"
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr "ugyldig konvertering fra %<__fpreg%>"
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr "ugyldig konvertering fra %<__fpreg%>"
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr "ugyldig konvertering til %<__fpreg%>"
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 #, fuzzy
 #| msgid "invalid conversion to type `%T' from type `%T'"
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
 msgstr ""
 
@@ -21953,7 +21953,7 @@ msgstr "ugyldig operation på %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "ugyldig %%P-operand"
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, c-format
 msgid "invalid %%p value"
 msgstr "ugyldig %%p-værdi"
@@ -21980,29 +21980,29 @@ msgstr "kan ikke bruge ikke-gp relativ absolut adresse"
 msgid "invalid addressing mode"
 msgstr "ugyldig adresseringstilstand"
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, c-format
 msgid "'%%%c' is not a valid operand prefix"
 msgstr "»%%%c« er ikke et gyldigt operandpræfiks"
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "ugyldig brug af »%%%c«"
@@ -22034,7 +22034,7 @@ msgid "post-increment address is not a register"
 msgstr "postfiks forøgelsesadresse er ikke et register"
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 msgid "bad address"
 msgstr "ugyldig adresse"
 
@@ -22203,7 +22203,7 @@ msgstr "ikke-understøttet kombination: %s"
 msgid "unsupported memory expression:"
 msgstr "fast-punkt-konvertering er ikke understøttet"
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, fuzzy, c-format
 #| msgid "invalid %%r operand"
 msgid "invalid vector operand"
@@ -22266,257 +22266,257 @@ msgstr "-mquad-memory-atomic kræver 64-bit tilstand"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "-mquad-memory er ikke tilgængelig i lilleendet tilstand"
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 #, fuzzy
 #| msgid "bad operand"
 msgid "bad move"
 msgstr "ugyldig operand"
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%A value"
 msgstr "ugyldig %%J-værdi"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%D value"
 msgstr "ugyldig %%D-værdi"
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, c-format
 msgid "invalid %%e value"
 msgstr "ugyldig %%e-værdi"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, c-format
 msgid "invalid %%f value"
 msgstr "ugyldig %%f-værdi"
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, c-format
 msgid "invalid %%F value"
 msgstr "ugyldig %%F-værdi"
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, c-format
 msgid "invalid %%G value"
 msgstr "ugyldig %%G-værdi"
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, c-format
 msgid "invalid %%j code"
 msgstr "ugyldig %%j-kode"
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, c-format
 msgid "invalid %%J code"
 msgstr "ugyldig %%J-kode"
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, c-format
 msgid "invalid %%k value"
 msgstr "ugyldig %%k-værdi"
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, c-format
 msgid "invalid %%K value"
 msgstr "ugyldig %%K-værdi"
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, c-format
 msgid "invalid %%O value"
 msgstr "ugyldig %%O-værdi"
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, c-format
 msgid "invalid %%q value"
 msgstr "ugyldig %%q-værdi"
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%t value"
 msgstr "ugyldig %%J-værdi"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, c-format
 msgid "invalid %%T value"
 msgstr "ugyldig %%T-værdi"
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, c-format
 msgid "invalid %%u value"
 msgstr "ugyldig %%u-værdi"
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, c-format
 msgid "invalid %%v value"
 msgstr "ugyldig %%v-værdi"
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%V value"
 msgstr "ugyldig %%J-værdi"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, c-format
 msgid "invalid %%x value"
 msgstr "ugyldig %%x-værdi"
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, c-format
 msgid "invalid %%z value"
 msgstr "ugyldig %%z-værdi"
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ugyldig %%y-værdi, prøv at brug »Z«-begrænsningen"
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 #, fuzzy
 #| msgid "Use hardware floating point instructions"
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-parameter sendt til funktion uden prototype"
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 msgid "Could not generate addis value for fusion"
 msgstr "Kunne ikke generere addis-værdi for fusion"
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Kunne ikke generere indlæsning/lagring af forskydning for fusion"
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 msgid "Bad GPR fusion"
 msgstr "Ugyldig GPR-fusion"
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "ugyldig konvertering fra %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "ugyldig konvertering til %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "ugyldig konvertering fra %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "ugyldig konvertering til %<__fpreg%>"
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "symbolske hukommelsesreferencer er kun understøttet på z10 eller senere"
 
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, c-format
 msgid "cannot decompose address"
 msgstr "Kan ikke nedbryde adresse"
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "ugyldig sammenligningsoperator til »E«-ændring"
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "ugyldig reference til »J«-uddataændring"
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "ugyldig adresse til »O«-uddataændring"
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "ugyldig adresse til »R«-uddataændring"
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "hukommelsesreference forventet til »S«-uddataændring"
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "ugyldig adresse for »S«-uddatamodifikation"
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "register eller hukommelsesudtryk forventet til »N«-uddataændring"
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "register eller hukommelsesudtryk forventet til »M«-uddataændring"
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "ugyldig konstant til uddataændringen »%c«"
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "ugyldig konstant - prøv at bruge en uddataændring"
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "ugyldig konstantvektor for uddataændringen »%c«"
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "ugyldigt udtryk - prøv at brug en uddataændring"
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "ugyldig udtryk til uddataændringen »%c«"
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 msgid "vector argument passed to unprototyped function"
 msgstr "vektorparameter sendt til funktion uden prototype"
 
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 msgid "types differ in signedness"
 msgstr "typer er forskellige i signedness"
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 msgid "binary operator does not support two vector bool operands"
 msgstr "binær operator understøtter ikke tovektor bool-operand"
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 msgid "binary operator does not support vector bool operand"
 msgstr "binær operator understøtter ikke vektor bool-operand"
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "binær operator understøtter ikke at blande vektor bool med kommatals vektor-operand"
 
@@ -22711,12 +22711,12 @@ msgstr "({anonym})"
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> forventet"
@@ -22729,7 +22729,7 @@ msgstr "%<;%> forventet"
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -22738,7 +22738,7 @@ msgstr "%<;%> forventet"
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> forventet"
@@ -22746,7 +22746,7 @@ msgstr "%<)%> forventet"
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> forventet"
@@ -22757,29 +22757,29 @@ msgstr "%<;%>, %<,%> eller %<)%> forventet"
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> forventet"
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> forventet"
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> forventet"
@@ -22789,17 +22789,17 @@ msgstr "%<{%> forventet"
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> forventet"
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> forventet"
@@ -22808,8 +22808,8 @@ msgstr "%<while%> forventet"
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> forventet"
@@ -22819,17 +22819,17 @@ msgid "expected %<.%>"
 msgstr "%<.%> forventet"
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> forventet"
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> forventet"
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> eller %<)%> forventet"
@@ -22837,33 +22837,33 @@ msgstr "%<,%> eller %<)%> forventet"
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> forventet"
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> forventet"
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<delete%>"
 msgid "expected %<else%>"
 msgstr "forventede %<delete%>"
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> eller %<}%> forventet"
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr ""
 
@@ -22871,7 +22871,7 @@ msgstr ""
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> forventet"
@@ -22888,24 +22888,24 @@ msgstr "forventet etiket"
 msgid "candidate:"
 msgstr "kandidat 1:"
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 #, fuzzy
 #| msgid "Enable use of DB instruction"
 msgid "  after user-defined conversion:"
 msgstr "Aktivér brug af DB-instruktioner"
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "candidate%s: %+#D"
 msgstr[1] "candidate%s: %+#D"
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr "kandidat 1:"
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr "kandidat 2:"
 
@@ -23181,7 +23181,7 @@ msgstr ""
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 #, fuzzy
 msgid "candidates are:"
 msgstr "candidate%s: %+#D"
@@ -23242,50 +23242,50 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "forkert parametertype til unært minus"
 
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "forkert parametertype til unært plus"
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "forkert parametertype til bitkomplement"
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "forkert parametertype til abs"
 
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "forkert parametertype til konjugation"
 
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "forkert parametertype til unært plus"
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -23365,7 +23365,7 @@ msgstr ""
 msgid "Deleted feature:"
 msgstr ""
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 #, fuzzy
 #| msgid "assignment"
 msgid "array assignment"
@@ -23593,11 +23593,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 msgid "assignment"
 msgstr "tildeling"
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 #, fuzzy
 #| msgid "assignment"
 msgid "pointer assignment"
@@ -23791,49 +23791,49 @@ msgstr ""
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "ugyldigt udtryk som operand"
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -23842,11 +23842,11 @@ msgstr ""
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr ""
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
@@ -23861,12 +23861,12 @@ msgstr ""
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -23875,82 +23875,82 @@ msgstr ""
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, fuzzy, c-format
 #| msgid "too few arguments to function `%s'"
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "for få parametre til funktionen '%s'"
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, c-format
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, c-format
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, c-format
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
@@ -23976,17 +23976,17 @@ msgstr ""
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 #, fuzzy
 #| msgid "output pipe has been closed"
 msgid "Loop variable has been modified"
 msgstr "uddataledningen er blevet lukket"
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 msgid "DO step value is zero"
 msgstr ""
 
@@ -24069,7 +24069,7 @@ msgid "expected boolean type"
 msgstr "forventet boolesk type"
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "uventet operand"
@@ -24142,7 +24142,7 @@ msgstr "ikke nok parametre"
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "for mange parametre"
@@ -24846,7 +24846,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "-g er kun understøttet ved brug af GAS på denne processor,"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error at '%s' token"
 msgid "Syntax error in %s statement at %C"
@@ -25313,8 +25313,8 @@ msgstr "dataområdet '%s' er i modstrid med tidligere erklæring"
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
 msgid "previous declaration here"
@@ -25334,7 +25334,7 @@ msgstr "egenskabsdirektivet '%s' ignoreret"
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr "egenskabsdirektivet '%s' ignoreret"
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments specified for %qE attribute"
@@ -25346,7 +25346,7 @@ msgstr "forkert antal parametre angivet til egenskaben '%s'"
 msgid "expected %i or more, found %i"
 msgstr "forventede %<return%>"
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %<,%>"
 msgid "expected %i, found %i"
@@ -25416,12 +25416,12 @@ msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -25430,7 +25430,7 @@ msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -25454,8 +25454,8 @@ msgstr "egenskaben '%s' ignoreret"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "uforenelig egenskab '%s' ignoreret"
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "tidligere erklæring af %qD"
@@ -25570,7 +25570,7 @@ msgstr "kan ikke læse funktionsprofil fra %s."
 msgid "offset %qwi outside bounds of constant string"
 msgstr "forskydning udenfor grænserne af konstant streng"
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%qE declared here"
@@ -25692,7 +25692,7 @@ msgstr "ugyldig typeparameter"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, fuzzy, gcc-internal-format
 #| msgid "invalid arg to `__builtin_frame_address'"
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
@@ -25717,48 +25717,48 @@ msgstr "den anden paramter til '__builtin_longjmp' skal være 1"
 msgid "target format does not support infinity"
 msgstr "målprocessoren understøtter ikke uendelig"
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, fuzzy, gcc-internal-format
 #| msgid "`va_start' used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "`va_start' benyttet i en funktion med fast antal parametre"
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `va_start'"
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "for mange parametre til funktionen 'va_start'"
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, fuzzy, gcc-internal-format
 #| msgid "`__builtin_next_arg' called without an argument"
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "`__builtin_next_arg' kaldt uden en parameter"
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "forkert antal parametre angivet til egenskaben '%s'"
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, fuzzy, gcc-internal-format
 #| msgid "second parameter of `va_start' not last named argument"
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "den anden parameter til 'va_start' er ikke den sidste navngivne parameter"
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not an integer constant"
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr "parameteren til egenskaben '%s' er ikke en heltalskonstant"
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "last argument of %qD is not integer constant between 0 and 3"
@@ -26899,12 +26899,12 @@ msgstr ""
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F brugt, men aldrig defineret"
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F erklæret %<static%>, men aldrig defineret"
@@ -27500,7 +27500,7 @@ msgstr "typeomtvingelse passer ikke til funktionstype"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "typeomtvingelse passer ikke til funktionstype"
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, fuzzy, gcc-internal-format
 #| msgid "options enabled: "
 msgid "%qs failed"
@@ -27532,17 +27532,17 @@ msgstr "Generér kode til en C400"
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, fuzzy, gcc-internal-format
 msgid "call to %qs declared with attribute error: %s"
 msgstr "funktionen '%s' omerklæret med egenskaben noinline"
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, fuzzy, gcc-internal-format
 msgid "call to %qs declared with attribute warning: %s"
 msgstr "funktionen '%s' omerklæret med egenskaben noinline"
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
 msgstr ""
@@ -27582,7 +27582,7 @@ msgstr "stort heltal forkortes underforstået til type uden fortegn"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "sammenligning er altid %d på grund af den begrænsede rækkevidde af bitfeltet"
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -27770,7 +27770,7 @@ msgstr ""
 msgid "%s signal terminated program %s"
 msgstr "%s:%d:   instantieret fra '%s'\n"
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, fuzzy, gcc-internal-format
 msgid "unrecognized command-line option %qs"
 msgstr "ignorerer kommandolinjetilvalget '%s'"
@@ -28050,7 +28050,7 @@ msgstr "skabelonsparameter %d er ugyldig"
 msgid "multilib exclusions %qs is invalid"
 msgstr ""
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr ""
@@ -28380,23 +28380,23 @@ msgstr "højreskiftsantal er negativ"
 msgid "%qD specified bound %E equals source length"
 msgstr "højreskiftsantal er negativ"
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr "fleksibelt tabelmedlem ikke i slutningen af struktur"
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr ""
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mn is not supported for linux targets"
 msgid "%s not supported for variable length aggregates"
 msgstr "-mn er ikke understøttet for Linux-målarkitekturer"
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "%s not supported on this target"
@@ -28440,16 +28440,16 @@ msgid "function returns address of local variable"
 msgstr "funktion returnerer adressen på en lokal variabel"
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, fuzzy, gcc-internal-format
@@ -28462,328 +28462,328 @@ msgstr "  '%#D' erklæret her"
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to %s"
 msgid "%<%.*s%> directive argument is null"
 msgstr "forkert parametertype til %s"
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "referenced argument declared here"
 msgstr "  '%#D' erklæret her"
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to %s"
 msgid "directive argument %qE"
 msgstr "forkert parametertype til %s"
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, fuzzy, gcc-internal-format
 #| msgid "disable pass %s for functions in the range of [%u, %u]"
 msgid "directive argument in the range [%E, %E]"
 msgstr "deaktiver videregivelse %s for funktioner i intervallet [%u, %u]"
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgid_plural "%qE output %wu bytes into a destination of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 #, fuzzy
 #| msgid "no arguments for spec function"
 msgid "%qE argument %Z overlaps destination object %qE"
@@ -28791,44 +28791,44 @@ msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] "ingen parametre til specifikationsfunktion"
 msgstr[1] "ingen parametre til specifikationsfunktion"
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 msgid "%qE argument %Z may overlap destination object %qE"
 msgid_plural "%qE arguments %Z may overlap destination object %qE"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, gcc-internal-format
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, fuzzy, gcc-internal-format
 #| msgid "pointer"
 msgid "null destination pointer"
 msgstr "henvisning"
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, fuzzy, gcc-internal-format
 #| msgid "null format string"
 msgid "null format string"
@@ -29654,12 +29654,12 @@ msgstr "ugyldig henvisningstilstand '%s'"
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%qD declared here"
@@ -30486,7 +30486,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of attribute %<fallthrough%>"
@@ -30859,17 +30859,17 @@ msgstr "ingen filer angivet med -fdump-translation-unit"
 msgid "mismatching definition"
 msgstr "manglende startværdi"
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, fuzzy, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr "Ugyldig erklæring"
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, gcc-internal-format
 msgid "IPA modref summary is missing in input file"
 msgstr ""
@@ -31996,80 +31996,80 @@ msgstr "fejl ved skrivning til %s: %m"
 msgid "error closing optimization records %qs"
 msgstr "Udfør krydsspringsoptimering"
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "der mangler en parameter til tilvalget '-%s'"
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr "parameter til '%s' skal være en 2 bit-konstant uden fortegn"
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer"
 msgstr "parameter til '%s' skal være en 2 bit-konstant uden fortegn"
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-functions=%d is not between 1 and %d"
 msgid "argument to %qs is not between %d and %d"
 msgstr "-malign-functions=%d er ikke mellem 1 og %d"
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid argument in option %qs"
 msgstr "ugyldig typeparameter"
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr ""
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-26 and -mapcs-32 may not be used together"
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr "-mapcs-26 og -mapcs-32 kan ikke bruges på samme tid"
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument in option %qs"
 msgstr "ignorerer kommandolinjetilvalget '%s'"
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %qs are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, fuzzy, gcc-internal-format
 #| msgid "switch \"%s\" is no longer supported"
 msgid "switch %qs is no longer supported"
 msgstr "tilvalget '%s' understøttes ikke længere"
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute larger than %d"
 msgid "argument to %qs is bigger than %d"
 msgstr "parameter til %qE-egenskaben er større end %d"
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, gcc-internal-format
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
 msgstr ""
@@ -32145,8 +32145,8 @@ msgstr "parameter til '%s' skal være en 2 bit-konstant uden fortegn"
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "%qs is incompatible with %qs"
@@ -32926,7 +32926,7 @@ msgstr "en global registervariabel følger en funktionsdefinition"
 msgid "register of %qD used for multiple global register variables"
 msgstr "register for %qD brugt til flere globale registervariabler"
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "er i konflikt med %qD"
@@ -33398,47 +33398,47 @@ msgstr "sektion for alias %q+D skal matche sektion for dens målarkitektur"
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "__builtin_saveregs understøttes ikke af denne målarkitektur"
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, gcc-internal-format
 msgid "nested functions not supported on this target"
 msgstr "-indlejrede funktioner er ikke understøttet på denne målarkitektur"
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, gcc-internal-format
 msgid "nested function trampolines not supported on this target"
 msgstr "indlejrede funktionstrampoliner er ikke understøttet på denne målarkitektur"
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "global constructors not supported on this target"
 msgstr "stakgrænser understøttes ikke på målarkitekturen"
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "global destructors not supported on this target"
 msgstr "stakgrænser understøttes ikke på målarkitekturen"
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute is not supported on this machine"
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "målarkitekturegenskab er ikke understøttet på denne maskine"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute is not supported on this machine"
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "målarkitekturegenskab er ikke understøttet på denne maskine"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "%<#pragma GCC target%> is not supported for this machine"
@@ -34681,84 +34681,84 @@ msgstr ""
 msgid "BB %i has incorrect fallthru edge"
 msgstr "forkert instruktion i fald-gennem-kant"
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr ""
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr ""
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr ""
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr ""
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr ""
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr ""
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr ""
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr ""
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr ""
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr ""
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr ""
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr ""
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, fuzzy, gcc-internal-format
 #| msgid "%Jinlining failed in call to '%F': %s"
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr "%Jindlejring mislykkedes i kald til '%F': %s"
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr "kaldt herfra"
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "called from this function"
 msgstr "kald af ikke-funktion '%D'"
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, fuzzy, gcc-internal-format
 #| msgid "%Jinlining failed in call to '%F': %s"
 msgid "inlining failed in call to %q+F: %s"
@@ -34817,28 +34817,28 @@ msgstr "ugyldig vektortype for egenskaben '%s'"
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr "ugyldig brug af '%D"
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, fuzzy, gcc-internal-format
 msgid "in a call to non-static member function %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "in a call to built-in function %qD"
 msgstr "for mange parametre til funktionen '%s'"
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, fuzzy, gcc-internal-format
 msgid "in a call to function %qD declared %qs"
 msgstr "Ugyldig erklæring"
@@ -35055,7 +35055,7 @@ msgstr "manglende startværdi"
 msgid "%qs may be used uninitialized"
 msgstr "'%s' bliver måske brugt uden at have en startværdi i denne funktion"
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%qD was declared here"
@@ -35297,7 +35297,7 @@ msgstr ""
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -35312,131 +35312,131 @@ msgstr ""
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "en tabel af funktioner giver ikke mening"
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "en funktions returtype kan ikke være en funktion"
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "træ-kontrol: %s, har %s i %s, ved %s:%d"
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "træ-kontrol: forventede ingen af %s, har %s i %s, ved %s:%d"
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "træ-kontrol: forventede klasse %qs, har %qs (%s) i %s, ved %s:%d"
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "træ-kontrol: forventede ikke klasse %qs, har %qs (%s) i %s, ved %s:%d"
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr "træ-kontrol: forventede omp_clause %s, har %s i %s, ved %s:%d"
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "træ-kontrol: forventede træ som indeholder %qs-struktur, har %qs i %s, ved %s:%d"
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr "trækontrol: tilgik udtrykstræ %d af tree_int_cst med %d udtrykstræer i %s, ved %s:%d"
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr "trækontrol: tilgik udtrykstræ %d af tree_vec med %d udtrykstræer i %s, ved %s:%d"
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "trækontrol: tilgik operand %d af %s med %d operander i %s, ved %s:%d"
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "trækontrol: tilgik operand %d af omp_clause %s med %d operander i %s, ved %s:%d"
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD er forældet: %s"
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD  er forældet"
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE er forældet: %s"
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE er forældet"
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "type er forældet: %s"
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "type er forældet"
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a namespace"
 msgid "%qD is unavailable: %s"
 msgstr "'%D' er ikke et navnerum"
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a namespace"
 msgid "%qD is unavailable"
 msgstr "'%D' er ikke et navnerum"
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a namespace"
 msgid "%qE is unavailable: %s"
 msgstr "'%D' er ikke et navnerum"
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a namespace"
 msgid "%qE is unavailable"
 msgstr "'%D' er ikke et navnerum"
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "options enabled: "
 msgid "type is unavailable: %s"
 msgstr "tilvalg slået til: "
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a namespace"
 msgid "type is unavailable"
@@ -35462,283 +35462,283 @@ msgstr "'%D' er ikke et navnerum"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TREE_TYPE"
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr "typevariants TREE_TYPE"
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TREE_TYPE"
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr "typevariants TREE_TYPE"
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, gcc-internal-format
 msgid "and field"
 msgstr "og felt"
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TREE_TYPE"
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr "typevariants TREE_TYPE"
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TREE_TYPE"
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr "typevariants TREE_TYPE"
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, fuzzy, gcc-internal-format
 #| msgid "type's TREE_TYPE"
 msgid "type%'s %<TREE_TYPE%>"
 msgstr "types TREE_TYPE"
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "type er ikke forenelig med dens variant"
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%T' is not a template type"
 msgid "type %s is not an opaque type"
 msgstr "'%T' er ikke en skabelonstype"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type `%D' is not a direct base of `%T'"
 msgid "type %s is not with opaque mode"
 msgstr "typen '%D' er ikke en direkte stamklasse til '%T'"
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr ""
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr ""
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, fuzzy, gcc-internal-format
 #| msgid "Main variant is not defined"
 msgid "main variant is not defined"
 msgstr "Hovedvariant er ikke defineret"
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr "TYPE_BINFO type er ikke TYPE_MAIN_VARIANT"
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CANONICAL is not compatible"
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr "TYPE_CANONICAL er ikke kompatibel"
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CANONICAL is not compatible"
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr "TYPE_CANONICAL er ikke kompatibel"
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr "TYPE_VFIELD er ikke FIELD_DECL eller TREE_LIST"
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr "TYPE_NEXT_PTR_TO er ikke POINTER_TYPE"
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr "TYPE_NEXT_REF_TO er ikke REFERENCE_TYPE"
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_BINFO is not TREE_BINFO"
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr "TYPE_BINFO er ikke TREE_BINFO"
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr "TYPE_BINFO type er ikke TYPE_MAIN_VARIANT"
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, fuzzy, gcc-internal-format
 #| msgid "Array TYPE_DOMAIN is not integer type"
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "Tabellen TYPE_DOMAIN er ikke af en heltalstype"
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_FIELDS defined in incomplete type"
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "TYPE_FIELDS er defineret i en ufuldstændig type"
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, fuzzy, gcc-internal-format
 #| msgid "Wrong tree in TYPE_FIELDS list"
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr "Forkert træ i TYPE_FIELDS-liste"
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, fuzzy, gcc-internal-format
 #| msgid "wrong TYPE_CACHED_VALUES entry"
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr "forkert TYPE_CACHED_VALUES-element"
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, fuzzy, gcc-internal-format
 #| msgid "Wrong tree in TYPE_FIELDS list"
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr "Forkert træ i TYPE_FIELDS-liste"
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -35970,7 +35970,7 @@ msgstr "aliasdefinitioner er ikke understøttet i denne konfiguration; ignoreret
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "synlighedsegenskab er ikke understøttet i denne konfiguration; ignoreret"
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr ""
@@ -36197,7 +36197,7 @@ msgstr "'%s' brugt, men aldrig defineret"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "'%s' brugt, men aldrig defineret"
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
@@ -36399,7 +36399,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for local variables"
 msgstr "%qE-attribut kan ikke angives for lokale variabler"
@@ -36754,7 +36754,7 @@ msgstr "-march=%s er ikke forenelig med den valgte ABI"
 msgid "%qE argument is not a function"
 msgstr "ingen parametre til specifikationsfunktion"
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, fuzzy, gcc-internal-format
 #| msgid "second token after #line is not a string"
 msgid "deprecated message is not a string"
@@ -37319,7 +37319,7 @@ msgstr "new kan ikke bruges på en funktionstype"
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr "new kan ikke bruges på en funktionstype"
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of `%s' to a void type"
 msgid "invalid application of %qs to a void type"
@@ -37468,9 +37468,9 @@ msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, fuzzy, gcc-internal-format
@@ -37478,8 +37478,8 @@ msgstr "standardparameter givet til %d. parameter for '%#D'"
 msgid "too few arguments to function %qE"
 msgstr "for få parametre til funktionen"
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, fuzzy, gcc-internal-format
@@ -37621,193 +37621,193 @@ msgstr "forsøg på at finde adressen af bitfeltstrukturmedlemmet '%D'"
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of array is too large"
 msgstr "størrelsen af tabellen '%s' er for stor"
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of `%s'"
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "typen af den %d. parameter i '%s' passer ikke"
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, fuzzy, gcc-internal-format
 #| msgid "%s makes pointer from integer without a cast"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "%s opretter en henvisningsvariabel ud fra et heltal uden en typeomtvingning"
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, fuzzy, gcc-internal-format
 #| msgid "left argument must be a slice"
 msgid "both arguments must be compatible"
 msgstr "venstre parameter skal være en skive"
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "incorrect number of arguments to function %qE"
 msgstr "for få parametre til funktionen '%s'"
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "argument %d of %qE must be a pointer type"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of `%+D'"
 msgid "size mismatch in argument %d of %qE"
 msgstr "i overbringelse af parameter %P af '%+D'"
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, fuzzy, gcc-internal-format
 #| msgid "cast from `%T' to `%T' discards qualifiers from pointer target type"
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr "typeomtvingning fra '%T' til '%T' kasserer modifikationer på henvisningsmålets type"
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, fuzzy, gcc-internal-format
 #| msgid "cast from `%T' to `%T' discards qualifiers from pointer target type"
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr "typeomtvingning fra '%T' til '%T' kasserer modifikationer på henvisningsmålets type"
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of `%s'"
 msgid "invalid memory model argument %d of %qE"
 msgstr "ugyldig typeparameter '%s'"
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, fuzzy, gcc-internal-format
 #| msgid "accumulator number is out of bounds"
 msgid "index value is out of bound"
 msgstr "akkumulatortal er uden for det gyldig interval"
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "den indbyggede funktion '%s' er erklæret som noget der ikke er en funktion"
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "size of array %qE is not a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "størrelsen af tabel er negativ"
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "størrelsen af tabel er negativ"
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr "højreskiftsantal er negativ"
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr "højreskiftsantal er negativ"
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "højreskiftsantal er negativ"
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "size of array exceeds maximum object size %qE"
 msgstr "højreskiftsantal er negativ"
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -38498,7 +38498,7 @@ msgstr "heltalskonstanten er for stor til typen '%s'"
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr "heltalskonstanten er for stor til typen '%s'"
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "%<_BitInt(%d)%> is not supported on this target"
@@ -38590,7 +38590,7 @@ msgstr "muligvis begyndelsen af uafsluttet strengkonstant"
 msgid "traditional C rejects string constant concatenation"
 msgstr "traditionel C tillader ikke strengsammensætning"
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -38647,7 +38647,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "typedef-navn kan ikke klassemodificeres"
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid type for iteration variable %qE"
@@ -38665,19 +38665,19 @@ msgstr "ugyldig vektortype for egenskaben '%s'"
 msgid "%qE is not initialized"
 msgstr "manglende startværdi"
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, fuzzy, gcc-internal-format
 #| msgid "missing '(' after predicate"
 msgid "missing controlling predicate"
 msgstr "manglende '(' efter udsagn"
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid control expression"
 msgid "invalid controlling predicate"
 msgstr "Ugyldigt kontroludtryk"
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, fuzzy, gcc-internal-format
 #| msgid "missing ')' in expression"
 msgid "missing increment expression"
@@ -38688,7 +38688,7 @@ msgstr "manglende ')' i udtryk"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid control expression"
 msgid "invalid increment expression"
@@ -38780,7 +38780,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -38791,7 +38791,7 @@ msgstr ""
 msgid "%qD is not a function argument"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qE in %qs clause"
@@ -39453,7 +39453,7 @@ msgid "wrong type argument to %s"
 msgstr "forkert parametertype til %s"
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -40491,35 +40491,35 @@ msgstr "sammenligning mellem '%#T' og '%#T'"
 
 #: c-family/c-warn.cc:3832
 #, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3836
+#: c-family/c-warn.cc:3839
 #, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr ""
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr ""
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr ""
@@ -40750,121 +40750,121 @@ msgstr "-mregparm=%d er ikke mellem 0 og %d"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, gcc-internal-format
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, gcc-internal-format
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, gcc-internal-format
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, fuzzy, gcc-internal-format
 #| msgid "-mcpu=%s conflicts with -march=%s"
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr "-mcpu=%s er i konflikt med tilvalget -march=%s"
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, fuzzy, gcc-internal-format
 #| msgid "-mcpu=%s conflicts with -march=%s"
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr "-mcpu=%s er i konflikt med tilvalget -march=%s"
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, gcc-internal-format
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, fuzzy, gcc-internal-format
 #| msgid "type of `%E' is unknown"
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "typen af '%E' er ukendt"
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr ""
@@ -41309,13 +41309,13 @@ msgstr "uventede bivirkninger i adresse"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "uventede bivirkninger i adresse"
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires a string constant argument"
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%qE-egenskaben kræver et strengkonstant som parameter"
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of #pragma GCC java_exceptions"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
@@ -41952,7 +41952,7 @@ msgstr ""
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
@@ -42036,12 +42036,12 @@ msgid "unknown tuning option (%s)"
 msgstr "ukendt specifikationsfunktion '%s'"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
@@ -42053,7 +42053,7 @@ msgid "specify a system register with a small string length"
 msgstr "Angiv registerallokeringsordnen"
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%s understøtter ikke %s"
@@ -42259,9 +42259,9 @@ msgstr "målarkitektursystem understøtter ikke %qs-fejlsøgningsformatet"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "\"%s\" er ikke defineret"
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "attribute %<target%> argument not a string"
@@ -42322,19 +42322,19 @@ msgid "virtual function multiversioning not supported"
 msgstr "stakgrænseudtryk understøttes ikke"
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
@@ -42348,8 +42348,8 @@ msgstr ""
 msgid "lane %wd out of range %wd - %wd"
 msgstr "linjenummer er uden for det gyldige interval"
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported simdlen %wd"
@@ -42361,7 +42361,7 @@ msgstr "versionen er ikke understøttet"
 msgid "GCC does not currently support return type %qT for simd"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported return type %qT for simd"
@@ -42373,7 +42373,7 @@ msgstr "ubenyttede parametre i formatering med $"
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd"
@@ -42475,8 +42475,8 @@ msgstr "L%d-mellemlagersventetid ukendt for %s"
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "ugyldig værdi '%s' for -mmemory-latency"
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr "ugyldig indbygget fcode"
@@ -42606,18 +42606,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -42750,7 +42750,7 @@ msgid "argument of %qE attribute is missing"
 msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qE attribute allows only an integer constant argument"
@@ -42774,26 +42774,26 @@ msgstr "egenskaben '%s' kan kun anvendes sammen med funktionstyper"
 msgid "argument of %qE attribute ignored"
 msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute only applies to variables"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 invalid in this context"
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "Sætning ved %0 er ugyldig i denne kontekst"
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown %<asm%> flag output %qs"
 msgstr "ukendt registernavn: %s"
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for make function"
 msgid "invalid type for %<asm%> flag output"
@@ -43055,7 +43055,7 @@ msgstr "målprocessoren understøtter ikke THUMB-instruktioner"
 msgid "target CPU does not support unaligned accesses"
 msgstr "målprocessoren understøtter ikke interarbejde"
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -43111,7 +43111,7 @@ msgstr "strukturstørrelsesgrænse kan kun sættes til 8 eller 32"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "-mapcs-stack-check og -mno-apcs-frame er indbyrdes uforenelige"
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
@@ -43225,7 +43225,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -43270,44 +43270,44 @@ msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktionstyper"
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, fuzzy, gcc-internal-format
 #| msgid "line number out of range"
 msgid "%s %wd out of range %wd - %wd"
 msgstr "linjenummer er uden for det gyldige interval"
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "kan ikke beregne virkelig placering af stakkede parametre"
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "ingen lave registre er tilgængelige til at modtage værdier fra høje registre"
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "afbrydelsesservicerutiner kan ikke kodes i Thumb-tilstand"
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -43316,24 +43316,24 @@ msgstr "ugyldig vektortype for egenskaben '%s'"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "ukendt registernavn: %s"
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, fuzzy, gcc-internal-format
 #| msgid "address mode %qs not supported in the %s bit mode"
 msgid "%<asm%> flags not supported in thumb1 mode"
@@ -43395,174 +43395,174 @@ msgstr "Kendte MCU-arkitekturer:"
 msgid "unknown core architecture %qs specified with %qs"
 msgstr "Finjustér justering til en given chip- eller processorversion"
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe is not supported"
 msgid "%<-fpic%> is not supported"
 msgstr "-pipe understøttes ikke"
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe is not supported"
 msgid "%<-fPIC%> is not supported"
 msgstr "-pipe understøttes ikke"
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe is not supported"
 msgid "%<-fpie%> is not supported"
 msgstr "-pipe understøttes ikke"
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe is not supported"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe understøttes ikke"
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional and -ansi are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-traditional og -ansi er indbyrdes uforenelige"
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, fuzzy, gcc-internal-format
 #| msgid "`-%c' option must have argument"
 msgid "%qs function cannot have arguments"
 msgstr "tilvalget '-%c' skal have en parameter"
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "%qs function cannot return a value"
 msgstr "funktion kan ikke indbygges"
 
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, gcc-internal-format
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr ""
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, gcc-internal-format
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Number of registers used to pass integer arguments"
 msgid "fixed register %s used to pass parameter to function"
 msgstr "Antallet af registre der skal bruges til at overbringe heltalsparametre"
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr ""
 
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "sektionsegenskaber understøttes ikke på denne målarkitektur"
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute does not apply to types"
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr "egenskaben '%s' kan ikke anvendes på typer"
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute on non-volatile variable"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, fuzzy, gcc-internal-format
 #| msgid "inline functions not supported for this return value type"
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "integrerede funktioner understøttes ikke for denne returværditype"
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, fuzzy, gcc-internal-format
 #| msgid "code model `%s' not supported in the %s bit mode"
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "kodemodellen %s er ikke understøttet i %s bit-tilstand"
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, gcc-internal-format
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, fuzzy, gcc-internal-format
 #| msgid "only uninitialized variables can be placed in the .noinit section"
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr "kun variabler uden startværdi kan placeres i .noinit-sektionen"
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, fuzzy, gcc-internal-format
 #| msgid "only initialized variables can be placed into program memory area"
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr "kun variabler med startværdi kan placeres i programhukommelsesområdet"
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, fuzzy, gcc-internal-format
 #| msgid "only initialized variables can be placed into program memory area"
 msgid "uninitialized variable %q+D put into program memory area"
@@ -43572,46 +43572,46 @@ msgstr "kun variabler med startværdi kan placeres i programhukommelsesområdet"
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' incompatible attribute ignored"
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "uforenelig egenskab '%s' ignoreret"
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, fuzzy, gcc-internal-format
 #| msgid "MCU `%s' supported for assembler only"
 msgid "architecture %qs supported for assembler only"
 msgstr "MCU '%s' understøttes kun for maskinkode"
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr ""
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "case label does not reduce to an integer constant"
 msgid "%s expects a compile time integer constant"
 msgstr "case-etiketten kan ikke reduceres til en heltalskonstant"
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -43766,7 +43766,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, fuzzy, gcc-internal-format
@@ -44471,8 +44471,8 @@ msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "kodemodellen %s understøtter ikke PIC-tilstand"
@@ -44540,282 +44540,282 @@ msgstr "intet klassenavn angivet med '-%s'"
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "kodemodellen %s er ikke understøttet i PIC-tilstand"
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, fuzzy, gcc-internal-format
 #| msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "strateginavnet %qs angivet for tilvalget %qs er ikke understøttet for 32-bit kode"
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, fuzzy, gcc-internal-format
 #| msgid "-mips%d not supported"
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "-mips%d er ikke understøttet"
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, fuzzy, gcc-internal-format
 #| msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr "strateginavnet %qs angivet for tilvalget %qs er ikke understøttet for 32-bit kode"
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mcmodel= understøttes ikke på 32 bit-systemer"
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, fuzzy, gcc-internal-format
 #| msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "strateginavnet %qs angivet for tilvalget %qs er ikke understøttet for 32-bit kode"
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "adressetilstanden %qs er ikke understøttet i %s bit-tilstand"
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is not supported in C++"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "-traditional understøttes ikke i C++"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is not supported in C++"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "-traditional understøttes ikke i C++"
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is not supported in C++"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "-traditional understøttes ikke i C++"
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "-mapcs-stack-check og -mno-apcs-frame er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "kodemodellen %qs er ikke understøttet i %s bit-tilstand"
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "kodemodellen %qs er ikke understøttet i x32-tilstand"
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, fuzzy, gcc-internal-format
 #| msgid "-masm=intel not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-masm=intel understøttes ikke af denne konfiguration"
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i bit-tilstand er ikke oversat med ind"
 
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "den valgte processor understøtter ikke x86-64-instruktionssættet"
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "ugyldig værdi (%s) til tilvalget -mcpu="
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -mcpu="
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d er ikke mellem 0 og %d"
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr ""
@@ -44823,315 +44823,315 @@ msgstr ""
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr ""
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "-fprefetch-loop-arrays understøttes ikke på målarkitekturen"
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d er ikke mellem %d og 12"
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d er ikke mellem %d og 12"
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "profilering understøttes ikke endnu"
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE-instruktionssæt deaktiveret, bruger 387-beregninger"
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387-instruktionssæt deaktiveret, bruger SSE-beregninger"
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown cpu: -mcpu=%s"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs er ikke et gyldigt tilvalg til præprocessoren"
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs er ikke et gyldigt tilvalg til præprocessoren"
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs er ikke et gyldigt tilvalg til præprocessoren"
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr ""
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%s-instruktioner er ikke tilladt i %s-tjenesterutinen"
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "%s-instruktioner er ikke tilladt i %s-tjenesterutinen"
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "%s-instruktioner er ikke tilladt i %s-tjenesterutinen"
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall og regparm er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE-egenskaben kræver en heltalskonstant som parameter"
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "parameter til %qE-egenskaben er større end %d"
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall og fastcall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE-egenskaben bruges til ikke-klasse metode"
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "uforenelig egenskab '%s' ignoreret"
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE-egenskaben kræver et strengkonstant som parameter"
 
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "afbrydelsesservicerutiner kan ikke kodes i Thumb-tilstand"
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
@@ -45335,49 +45335,49 @@ msgstr "ikke-understøttet operandstørrelse for udvidede registre"
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "ugyldig operandtype brugt med operandkoden »Z«"
 
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, fuzzy, gcc-internal-format
 #| msgid "no low registers available for popping high registers"
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr "ingen lave registre er tilgængelige til at modtage værdier fra høje registre"
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr ""
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr ""
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, fuzzy, gcc-internal-format
 #| msgid "Tune alignment for the specified chip or CPU version"
 msgid "unknown architecture specific memory model"
 msgstr "Finjustér justering til en given chip- eller processorversion"
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, fuzzy, gcc-internal-format
 #| msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
@@ -45399,8 +45399,8 @@ msgstr ""
 msgid "malformed %<#pragma builtin%>"
 msgstr "forkert udformet '#pragma builtin'"
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, gcc-internal-format
 msgid "invalid argument of %qE attribute"
 msgstr "ugyldig parameter for egenskaben %qE"
@@ -45460,12 +45460,12 @@ msgstr "PRINT_OPERAND: Ukendt tegnsætning »%c«"
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr "PRINT_OPERAND nul-henvisning"
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, fuzzy, gcc-internal-format
 #| msgid "field `%s' declared as a function"
 msgid "failed to expand built-in function"
@@ -45597,19 +45597,19 @@ msgstr "-march=%s er ikke forenelig med den valgte ABI"
 msgid "%qs cannot be used for compiling a shared library"
 msgstr "%s kan ikke bruges i asm her"
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr "%qE-attribut kan ikke angives for lokale variabler"
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for register variables"
 msgstr "%qE-attribut kan ikke angives for lokale variabler"
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate ConstantValue attribute for field '%s'"
 msgid "multiple %qE attribute"
@@ -45724,12 +45724,12 @@ msgstr "sektionsegenskaben er ikke tilladt for '%s'"
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr "interrupt_thread er kun tilgængelig på fido"
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "stakgrænseudtryk understøttes ikke"
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, fuzzy, gcc-internal-format
 #| msgid "-fcheck-pointer-bounds is not supported for this target"
 msgid "%<-fexcess-precision=16%> is not supported on this target"
@@ -45774,7 +45774,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr ""
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires a string constant argument"
 msgid "%qE attribute requires a string argument"
@@ -45819,138 +45819,138 @@ msgstr ""
 msgid "argument to %qE attribute is not intstack"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, fuzzy, gcc-internal-format
 #| msgid "can not handle inconsistent calls to `%s'"
 msgid "cannot handle inconsistent calls to %qs"
 msgstr "kan ikke håndtere inkonsistente kald af '%s'"
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr ""
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr ""
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr ""
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function `%s' not currently supported"
 msgid "built-in function %qE not supported for MIPS16"
 msgstr "den indbyggede funktion '%s' understøttes i øjeblikket ikke"
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs does not support MIPS16 code"
 msgstr "%s understøtter ikke %s"
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr ""
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, gcc-internal-format
 msgid "MIPS16 %<-mxgot%> code"
 msgstr ""
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, gcc-internal-format
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr ""
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, fuzzy, gcc-internal-format
 #| msgid "Generate MC code"
 msgid "MSA MIPS16 code"
 msgstr "Generér MC-kode"
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, gcc-internal-format
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr ""
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported combination: %s"
 msgstr "ikke-understøttet kombination: %s"
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, fuzzy, gcc-internal-format
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr "-mips%d er i konflikt med de andre arkitekturtilvalg som angiver en MIPS%d-processor"
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr "%<-mgp64%> brugt med en 32-bit processor"
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, gcc-internal-format
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr "%<-mgp32%> brugt med et 64-bit ABI"
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, fuzzy, gcc-internal-format
 #| msgid "-mgp64 used with a 32-bit ABI"
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr "-mgp64 benyttet med et 32 bit-ABI"
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "fældetilstand understøttes ikke på Unicos/Mk"
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr ""
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr ""
@@ -45960,129 +45960,129 @@ msgstr ""
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, gcc-internal-format
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr "målprocessoren understøtter ikke THUMB-instruktioner"
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr "målprocessoren understøtter ikke THUMB-instruktioner"
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr "arkitekturen %qs understøtter ikke ulige enkelpræcision registre"
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported combination: %qs%s %s"
 msgstr "ikke-understøttet kombination: %s"
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported combination: %qs %s"
 msgstr "ikke-understøttet kombination: %s"
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, gcc-internal-format
 msgid "cannot generate position-independent code for %qs"
 msgstr "kan ikke oprette placeringsuafhængig kode for %qs"
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, fuzzy, gcc-internal-format
 msgid "position-independent code requires %qs"
 msgstr "Generér placeringsuafhængig kode, om muligt"
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr ""
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr "%s understøtter ikke %s"
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr "fældetilstand understøttes ikke på Unicos/Mk"
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, gcc-internal-format
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr ""
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, fuzzy, gcc-internal-format
 #| msgid "-frepo must be used with -c"
 msgid "%qs must be used with %qs"
 msgstr "-frepo skal bruges med -c"
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, fuzzy, gcc-internal-format
 #| msgid "may not use both -mfp64 and -msingle-float"
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr "-mfp64 og -msingle-float er indbyrdes uforenelige"
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr "målprocessoren understøtter ikke THUMB-instruktioner"
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr ""
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "the %qs architecture does not support DSP instructions"
 msgstr "målprocessoren understøtter ikke THUMB-instruktioner"
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, fuzzy, gcc-internal-format
 #| msgid "may not use both -mfp64 and -msingle-float"
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr "-mfp64 og -msingle-float er indbyrdes uforenelige"
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, fuzzy, gcc-internal-format
 #| msgid "may not use both -mfp64 and -msingle-float"
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr "-mfp64 og -msingle-float er indbyrdes uforenelige"
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, fuzzy, gcc-internal-format
 #| msgid "Use bit-field instructions"
 msgid "%qs requires branch-likely instructions"
 msgstr "Benyt bitfeltinstruktioner"
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, fuzzy, gcc-internal-format
 #| msgid "this target does not support the -mabi switch"
 msgid "the %qs architecture does not support the synci instruction"
 msgstr "denne målarkitektur understøtter ikke tilvalget -mabi"
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr "MIPS16-funktionsprofilering"
@@ -47031,61 +47031,61 @@ msgstr "%qE-egenskaben kræver et strengkonstant som parameter"
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "ragelse i slutningen af '#pragma options'"
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, gcc-internal-format
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, gcc-internal-format
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute is not supported on this machine"
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr "målarkitekturegenskab er ikke understøttet på denne maskine"
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, fuzzy, gcc-internal-format
 #| msgid "malformed spec function name"
 msgid "malformed %<target()%> attribute"
 msgstr "forkert udformet specifikationsfunktionsnavn"
 
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%s accepterer kun 1 parameter"
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_trap not supported by this target"
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr "__builtin_trap understøttes ikke på denne målarkitektur"
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "malformed %<target(\"%s\")%> attribute"
@@ -47155,187 +47155,211 @@ msgstr "kan ikke allokere et objekt af typen '%T'"
 msgid "capture by copy of RVV type %qT"
 msgstr "kan ikke %s en henvisning til en ufuldstændig type '%T'"
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, fuzzy, gcc-internal-format
+#| msgid "a -ifile option requires a -map option"
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, fuzzy, gcc-internal-format
+#| msgid "a -ifile option requires a -map option"
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, fuzzy, gcc-internal-format
+#| msgid "a -ifile option requires a -map option"
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, fuzzy, gcc-internal-format
+#| msgid "a -ifile option requires a -map option"
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to `%D(%A)'"
 msgid "no matching function call to %qE with empty arguments"
 msgstr "ingen passende funktion for kald til '%D(%A)'"
 
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "ukendt værdi %qs for -mtune"
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, gcc-internal-format
 msgid "this operation requires the RVV ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr "AltiVec-parameter sendt til funktion uden prototype"
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the Xtensa NSA option"
 msgid "%s %qT requires the V ISA extension"
 msgstr "Benyt ikke Xtensa-NSA-indstillingen"
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, gcc-internal-format
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, gcc-internal-format
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, gcc-internal-format
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, gcc-internal-format
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr ""
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "function attribute %qs requires the V ISA extension"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr ""
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, fuzzy, gcc-internal-format
 #| msgid "`sizeof' applied to incomplete type `%T'"
 msgid "%qs applied to non-RVV type %qT"
 msgstr "'sizeof' benyttet på en ufuldstændig type '%T'"
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires an integer constant argument"
 msgid "%qs requires an integer constant"
 msgstr "%qE-egenskaben kræver en heltalskonstant som parameter"
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support APCS-32"
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr "målprocessoren understøtter ikke APCS-32"
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs with %qs"
 msgstr "kodemodellen %qs er ikke understøttet i %s bit-tilstand"
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, gcc-internal-format
 msgid "rv64e requires lp64e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr ""
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "--resource påkræver -o"
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d er ikke mellem %d og 12"
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qs is not a valid base register in %qs"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%s understøtter ikke %s"
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, fuzzy, gcc-internal-format
 #| msgid "`-%c' option must have argument"
 msgid "%qs function cannot have different interrupt type"
 msgstr "tilvalget '-%c' skal have en parameter"
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr ""
@@ -47617,37 +47641,37 @@ msgstr "%s accepterer kun 1 parameter"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s accepterer kun 1 parameter"
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, fuzzy, gcc-internal-format
 #| msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl er forældet for lilleendet; brug opgave for ikke justerede indlæsninger og lagre"
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, fuzzy, gcc-internal-format
 #| msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr er forældet for lilleendet; brug opgave for ikke justerede indlæsninger og lagre"
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, fuzzy, gcc-internal-format
 #| msgid "cast from `%T' to `%T' discards qualifiers from pointer target type"
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr "typeomtvingning fra '%T' til '%T' kasserer modifikationer på henvisningsmålets type"
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "ugyldigt register i instruktionen"
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
@@ -47690,33 +47714,25 @@ msgstr "'%D' er ikke en funktionsskabelon"
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, fuzzy, gcc-internal-format
-#| msgid "Use EABI"
-msgid "%qs requires the ELFv2 ABI"
-msgstr "Benyt EABI"
-
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, fuzzy, gcc-internal-format
 #| msgid "stack frame too big"
 msgid "stack frame too large"
 msgstr "stakramme for stor"
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "unsupported number of nops before function entry (%u)"
 msgstr "for få parametre til funktionen '%s'"
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, fuzzy, gcc-internal-format
 #| msgid "-mips%d does not support 64 bit fp registers"
 msgid "%qs uses register r29"
 msgstr "-mips%d understøtter ikke 64-bit kommatalsregistre"
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
@@ -47855,115 +47871,125 @@ msgstr "kan ikke bruge %qs som et kald-brugt register"
 msgid "unknown option for %<%s=%s%>"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4837
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4855
 #, fuzzy, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%s har ingen %s"
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "ingen profilering af 64 bit-kode for denne ABI"
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of `this', which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "kan ikke tage adressen af 'this' som er et højreværdiudtryk"
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "complex ugyldig for '%s'"
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "ugyldig parametertype '%T'"
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "%s%qs%s is not allowed"
 msgstr "\"%s\" er ikke defineret"
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "stakgrænseudtryk understøttes ikke"
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "type %<__vector_pair%> requires the %qs option"
@@ -48010,7 +48036,7 @@ msgstr ""
 msgid "builtin %qs can only be used on vector types"
 msgstr "'%D' kan kun angives for funktioner"
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument `%s'"
 msgid "constant value required for builtin %qF argument %d"
@@ -48091,247 +48117,247 @@ msgstr "'%s' er forældet"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "konstant parameter uden for det gyldige interval for '%s'"
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for `%s'"
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr "konstant parameter uden for det gyldige interval for '%s'"
 
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for `%s'"
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr "konstant parameter uden for det gyldige interval for '%s'"
 
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for `%s'"
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr "konstant parameter uden for det gyldige interval for '%s'"
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "Builtin %qF requires z14 or higher"
 msgstr "--resource påkræver -o"
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "Builtin %qF requires z15 or higher"
 msgstr "--resource påkræver -o"
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "unresolved overloaded builtin"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, fuzzy, gcc-internal-format
 #| msgid "bad builtin fcode"
 msgid "bad builtin icode"
 msgstr "ugyldig indbygget fcode"
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "invalid argument %d for builtin %qF"
 msgstr "for mange parametre til funktionen"
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, fuzzy, gcc-internal-format
 #| msgid "Total size of local variables exceeds architecture limit."
 msgid "total size of local variables exceeds architecture limit"
 msgstr "Total størrelse af lokale variable overstiger arkitekturgrænsen."
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr ""
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr ""
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsize of '%D' is %d bytes"
 msgid "frame size of %qs is %wd bytes"
 msgstr "%Jstørrelsen af '%D' er %d byte"
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr ""
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "funktionen '%s' kan ikke erklæres 'mutable'"
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, fuzzy, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "kodemodellen %s er ikke understøttet i PIC-tilstand"
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware vector support not available on %s"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, fuzzy, gcc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, fuzzy, gcc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "-f%s er ikke understøttet: ignoreret"
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "parameter til '%s' skal være en 2 bit-konstant uden fortegn"
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_trap not supported by this target"
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "__builtin_trap understøttes ikke på denne målarkitektur"
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constant"
 msgid "invalid cc output constraint: %qs"
 msgstr "ugyldig konstant:"
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, fuzzy, gcc-internal-format
 #| msgid "inline float constants not supported on this host"
 msgid "multiple cc output constraints not supported"
 msgstr "integrerede kommatalskonstanter er ikke understøttede på denne vært"
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, fuzzy, gcc-internal-format
 #| msgid "asm-specifier for variable `%s' conflicts with asm clobber list"
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr "asm-anvisning for variablen '%s' strider mod asm-overskrivelsesliste"
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for cc output constraint"
@@ -48815,8 +48841,8 @@ msgstr "%s har ingen %s"
 msgid "attribute %qs applies to array types only"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "tom værdi er ikke ignoreret som den burde være"
@@ -48897,7 +48923,7 @@ msgstr ""
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr "'%D' er allerede erklæret i dette navnerum"
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, fuzzy, gcc-internal-format
 msgid "originally defined here"
 msgstr "  oprindelig definition er her"
@@ -49143,7 +49169,7 @@ msgstr "erklæring af '%s' skygger for en tidligere lokal variabel"
 msgid "declaration of %qD shadows a parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a global declaration"
 msgid "declaration of %qD shadows a global declaration"
@@ -49155,7 +49181,7 @@ msgstr "erklæring af '%s' skygger for en global erklæring"
 msgid "declaration of %qD shadows a previous local"
 msgstr "erklæring af '%s' skygger for en tidligere lokal variabel"
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
 msgid "shadowed declaration is here"
@@ -49234,7 +49260,7 @@ msgstr "'%s' er ikke erklæret (først benyttet i denne funktion)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(et kaldenavn der ikke er erklæret, rapporteres kun én gang per funktion)"
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, fuzzy, gcc-internal-format
 #| msgid "label %s referenced outside of any function"
 msgid "label %qE referenced outside of any function"
@@ -49274,7 +49300,7 @@ msgstr "overløb i konstant udtryk"
 msgid "duplicate label declaration %qE"
 msgstr "etiketten '%s' er blevet erklæret mere end én gang"
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%D'"
 msgid "duplicate label %qD"
@@ -49313,7 +49339,7 @@ msgstr "overløb i konstant udtryk"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE defineret som forkert slags mærke"
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qE attribute applied to %qD with void return type"
@@ -49466,12 +49492,12 @@ msgstr "ISO C90 understøtter ikke %<[*]%> arrayerklæringer"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, fuzzy, gcc-internal-format
 msgid "%<omp::%s%> not allowed to be specified in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
@@ -49481,7 +49507,7 @@ msgstr "'%D' blev ikke erklæret i dette virkefelt"
 msgid "%q+D is usually a function"
 msgstr "%q+D er normalt en funktion"
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "ingen tidligere erklæring af '%s'"
@@ -49565,7 +49591,7 @@ msgstr "kan ikke anbringe et objekt med et volatile-felt i et register"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "konstant '%D' uden startværdi"
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -49779,7 +49805,7 @@ msgstr "lagringsklasse angivet for parameter '%s'"
 msgid "storage class specified for unnamed parameter"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "lagringsklasse angivet for typenavn"
@@ -49850,7 +49876,7 @@ msgstr "'%s' erklæret som en tabel af funktioner"
 msgid "declaration of type name as array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "ugyldig brug af struktur med fleksibelt tabelmedlem"
@@ -49970,7 +49996,7 @@ msgstr "typenavn er erklæret som en funktion, der returnerer en array"
 msgid "function definition has qualified void return type"
 msgstr "funktiondefinition har kvalificeret void-returtype"
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typemodifikationer ignoreret i funktionsreturtypen"
@@ -50110,7 +50136,7 @@ msgstr "ISO C forbyder const eller volatile funktionstyper"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "datamedlem må ikke have variabelt ændret type '%T'"
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable or field %qE declared void"
@@ -50229,7 +50255,7 @@ msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, fuzzy, gcc-internal-format
 #| msgid "function declaration isn't a prototype"
 msgid "function declaration isn%'t a prototype"
@@ -50329,18 +50355,18 @@ msgstr "indlejret omdefinering af '%s'"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "indlejret omdefinering af '%s'"
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, fuzzy, gcc-internal-format
 #| msgid "unknown field `%s' specified in initializer"
 msgid "%qT defined in underspecified object initializer"
 msgstr "ukendt felt '%s' angivet i startværdi"
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "erklæring erklærer ikke noget"
@@ -50373,373 +50399,373 @@ msgstr ""
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, fuzzy, gcc-internal-format
 #| msgid "named members"
 msgid "union has no named members"
 msgstr "navngivne medlemmer"
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, fuzzy, gcc-internal-format
 msgid "union has no members"
 msgstr "anonym sammensat type uden medlemmer"
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, fuzzy, gcc-internal-format
 #| msgid "named members"
 msgid "struct has no named members"
 msgstr "navngivne medlemmer"
 
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, fuzzy, gcc-internal-format
 #| msgid "%s has no member named `%s'"
 msgid "struct has no members"
 msgstr "%s har intet medlem ved navn '%s'"
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "fleksibelt tabelmedlem i union"
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, fuzzy, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "fleksibelt tabelmedlem ikke i slutningen af struktur"
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "fleksibelt tabelmedlem i union"
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, fuzzy, gcc-internal-format
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr "fleksibelt tabelmedlem ikke i slutningen af struktur"
 
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, fuzzy, gcc-internal-format
 #| msgid "%s is too large"
 msgid "type %qT is too large"
 msgstr "%s er for stor"
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, fuzzy, gcc-internal-format
 msgid "type punning toggles scalar storage order"
 msgstr "ukendt registernavn '%s'"
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union kan ikke ikke gøres gennemsigtig"
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, fuzzy, gcc-internal-format
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr "omdefinering af '%s'"
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `struct %s'"
 msgid "redefinition of struct or union %qT"
 msgstr "omdefinering af 'struct %s'"
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of `%s'"
 msgid "nested redefinition of %<enum %E%>"
 msgstr "indlejret omdefinering af '%s'"
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of `enum %s'"
 msgid "redeclaration of %<enum %E%>"
 msgstr "omerklæring af 'enum %s'"
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "enum-værdier overstige rækkevidden af det største heltal"
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration values exceed range of largest integer"
 msgid "enumeration values exceed range of %qs"
 msgstr "enum-værdier overstige rækkevidden af det største heltal"
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of `%s'"
 msgid "conflicting redefinition of enum %qT"
 msgstr "indlejret omdefinering af '%s'"
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "enum-værdier for store"
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "enumerator value outside the range of underlying type"
 msgstr "tabelindeks er ikke et heltal"
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "enumerator value outside the range of %qs"
 msgstr "tabelindeks er ikke et heltal"
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of `int'"
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr "ISO C begrænser enum-værdier til rækkevidden af 'int'"
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "inline funktion '%s' givet egenskaben noinline"
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "returtypen er en ufuldstændig type"
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, fuzzy, gcc-internal-format
 #| msgid "return type defaults to `int'"
 msgid "return type defaults to %<int%>"
 msgstr "returtypen antages at være 'int'"
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, fuzzy, gcc-internal-format
 #| msgid "field `%s' declared as a function"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "feltet '%s' er erklæret som en funktion"
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, fuzzy, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "ingen tidligere prototype for '%s'"
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "'%s' blev brugt uden en prototype før dens definition"
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "'%s' blev brugt uden en erklæring før dens definition"
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "returtypen til '%s' er ikke 'int'"
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, fuzzy, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "'%s' er normalt en ikke-statisk funktion"
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, fuzzy, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "kan ikke bruge '::' i parametererklæring"
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "traditionel C tillader ikke ISO C-functionsdefinitioner"
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, fuzzy, gcc-internal-format
 #| msgid "traditional C rejects ISO C style function definitions"
 msgid "old-style function definition"
 msgstr "traditionel C tillader ikke ISO C-functionsdefinitioner"
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, fuzzy, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "parameternavn mangler fra parameterliste"
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "'%D' er erklæret som en ven"
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "flere parametre ved navn '%s'"
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter %qD declared with void type"
 msgstr "parameteren '%D' erklæret void"
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, fuzzy, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "typen til '%s' antages at være 'int'"
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, fuzzy, gcc-internal-format
 #| msgid "parameter has incomplete type"
 msgid "parameter %qD has incomplete type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, fuzzy, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "erklæring af parameteren '%s', men ingen sådan parameter"
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, fuzzy, gcc-internal-format
 #| msgid "number of arguments doesn't match prototype"
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "antallet af parametre passer ikke til prototypen"
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, fuzzy, gcc-internal-format
 #| msgid "number of arguments doesn't match prototype"
 msgid "number of arguments doesn%'t match prototype"
 msgstr "antallet af parametre passer ikke til prototypen"
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, fuzzy, gcc-internal-format
 msgid "prototype declaration"
 msgstr "tom erklæring"
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, fuzzy, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "den forfremmede parameter '%s' passer ikke til prototypen"
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, fuzzy, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "den forfremmede parameter '%s' passer ikke til prototypen"
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "parameteren '%s' passer ikke til prototypen"
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "parameteren '%s' passer ikke til prototypen"
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "parameter %qD set but not used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "begyndelseserklæring i 'for'-løkke benyttet uden for C99-tilstand"
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 understøtter ikke %<[*]%> arrayerklæringer"
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "erklæring af '%s' der er en statisk variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, fuzzy, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "'struct %s' erklæret i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, fuzzy, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "'union %s' erklæret i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, fuzzy, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "'enum %s' erklæret i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, fuzzy, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "erklæring af '%s' der ikke er en variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of unit `%s'"
 msgid "duplicate %qE declaration specifier"
 msgstr "gentaget erklæring af enheden '%s'"
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "multiple storage classes in declaration specifiers"
 msgstr "flere lagringsklasser optræder i erklæringen af '%s'"
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%qs used with %<auto%>"
@@ -50747,124 +50773,124 @@ msgstr "%s brugt med '%%%c' %s-formatering"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "%<auto%> used with %<constexpr%>"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, fuzzy, gcc-internal-format
 #| msgid "two or more data types in declaration of `%s'"
 msgid "two or more data types in declaration specifiers"
 msgstr "mere end én datatype i erklæringen af '%s'"
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, fuzzy, gcc-internal-format
 #| msgid "`long long long' is too long for GCC"
 msgid "%<long long long%> is too long for GCC"
 msgstr "'long long long' er for langt for GCC"
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `long long'"
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 understøtter ikke 'long long'"
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qE"
 msgstr "'%s' optræder mere end én gang"
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "%<__int%d%> is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `long long'"
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr "ISO C90 understøtter ikke 'long long'"
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "fixed-point types not supported for this target"
 msgstr "-fdata-sections understøttes ikke på målarkitekturen"
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr ""
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' fails to be a typedef or built in type"
 msgid "%qE fails to be a typedef or built in type"
 msgstr "'%s' er hverken en typedef eller en indbygget type"
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%qE is not at beginning of declaration"
@@ -50872,157 +50898,157 @@ msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "%qE used with %<constexpr%>"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s understøtter ikke %s"
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `long long'"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 understøtter ikke 'long long'"
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, fuzzy, gcc-internal-format
 #| msgid "`__thread' before `extern'"
 msgid "%<__thread%> before %<extern%>"
 msgstr "'__thread' før 'extern'"
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, fuzzy, gcc-internal-format
 #| msgid "`__thread' before `static'"
 msgid "%<__thread%> before %<static%>"
 msgstr "'__thread' før 'static'"
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, fuzzy, gcc-internal-format
 #| msgid "typedef declared %<auto%>"
 msgid "%<typedef%> used with %<auto%>"
 msgstr "typedef erklæret %<auto%>"
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "%qE used with %<extern%>"
 msgstr "forventede %<decltype%>"
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%qE used with %qs"
 msgstr "%s brugt med '%%%c' %s-formatering"
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%qs used with %qE"
 msgstr "%s brugt med '%%%c' %s-formatering"
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%<constexpr%> used with %qE"
 msgstr "%s brugt med '%%%c' %s-formatering"
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C understøtter ikke at blot 'complex' betyder 'double complex'"
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, fuzzy, gcc-internal-format
 #| msgid "left argument must be a slice"
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr "venstre parameter skal være en skive"
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr "ISO C++ understøtter ikke 'long long'"
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "venstreskiftsantal er negativ"
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "venstreskiftsantal er negativ"
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "højreskiftsantal er negativ"
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "venstreskiftsantal er større end bredden af typen"
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "højreskiftsantal er større end bredden af typen"
@@ -51055,7 +51081,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "  anden type her"
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, fuzzy, gcc-internal-format
 #| msgid "garbage at end of #line"
 msgid "expected end of line"
@@ -51067,8 +51093,8 @@ msgstr "ragelse i slutningen af #line"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C forbyder en tom kildefil"
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr ""
@@ -51112,9 +51138,9 @@ msgstr "'%D' har intet medlem ved navn '%E'"
 msgid "unknown type name %qE"
 msgstr "ukendt registernavn: %s"
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of unit `%s'"
 msgid "expected declaration specifiers"
@@ -51148,7 +51174,7 @@ msgstr "sektionsegenskaben er ikke tilladt for '%s'"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "prefix attributes are ignored for methods"
@@ -51170,7 +51196,7 @@ msgstr "uventet operand"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "sektionsegenskaben er ikke tilladt for '%s'"
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, fuzzy, gcc-internal-format
 msgid "%<assume%> attribute not followed by %<;%>"
 msgstr "sektionsegenskaben er ikke tilladt for '%s'"
@@ -51268,7 +51294,7 @@ msgstr "startværdien for den statiske variabel er ikke en konstant"
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, fuzzy, gcc-internal-format
 #| msgid "verification error at PC=%d"
 msgid "static assertion failed"
@@ -51348,10 +51374,10 @@ msgstr "skabelonsparameter %d er ugyldig"
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "uventet operand"
@@ -51516,7 +51542,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr ""
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr ""
@@ -51526,8 +51552,8 @@ msgstr ""
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs attribute argument"
 msgstr ""
@@ -51712,12 +51738,12 @@ msgstr "ISO C forbyder udeladelse af den midterste del af et '?:'-udtryk"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -51882,7 +51908,7 @@ msgstr "ISO C90 understøtter ikke komplekse typer"
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "expected expression"
@@ -52236,13 +52262,13 @@ msgstr "Klasse- eller grænsefladeerklæring forventet"
 msgid "no type or storage class may be specified here,"
 msgstr "lagringsklasse angivet for typenavn"
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, fuzzy, gcc-internal-format
 #| msgid "readonly property can not be set"
 msgid "empty property attribute list"
 msgstr "skrivebeskyttet egenskab kan ikke angives"
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, fuzzy, gcc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing property attribute"
@@ -52254,60 +52280,60 @@ msgstr "manglende Code-egenskab"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "%<,%> eller %<)%> forventet"
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected %qE selector name"
 msgstr "tom krop i en else-sætning"
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr ""
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma once in main file"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "'#pragma once' i hovedfil"
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -52317,25 +52343,25 @@ msgstr ""
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
@@ -52353,73 +52379,73 @@ msgstr "udsagn skal være et kaldenavn"
 msgid "expected %<)%> or %<,%>"
 msgstr "%<,%> eller %<)%> forventet"
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a namespace"
 msgid "%qD is not a variable"
 msgstr "'%D' er ikke et navnerum"
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a pointer-to-object type"
 msgid "%qD is not a pointer variable"
 msgstr "'%T' er ikke af en henvisning til objekt-type"
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "sammenlign mellem signed og unsigned heltalsudtryk"
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<::%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "forventede %<:%> or %<::%>"
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, fuzzy, gcc-internal-format
 #| msgid "']' expected, invalid type expression"
 msgid "expected constant logical expression"
 msgstr "']' forventet, ugyldigt typeudtryk"
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "forventede %<catch%>"
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses without modifier"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -52443,24 +52469,24 @@ msgstr ""
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "%<priority%> value must be non-negative"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, fuzzy, gcc-internal-format
 #| msgid "']' expected, invalid type expression"
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "']' forventet, ugyldigt typeudtryk"
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
@@ -52472,106 +52498,106 @@ msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%qs expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "%qs value must be positive"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments"
 msgid "too many %<static%> arguments"
 msgstr "for mange parametre"
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "unexpected argument"
 msgstr "uventet operand"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "parameteren til egenskaben '%s' er ikke en heltalskonstant"
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<self%> clauses"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, fuzzy, gcc-internal-format
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr "uventet operand"
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<new%>"
 msgid "expected %<concurrent%>"
 msgstr "forventede %<new%>"
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "sammenlign mellem signed og unsigned heltalsudtryk"
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "chunk size value must be positive"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ugyldig roteringsinstruktion"
@@ -52581,22 +52607,22 @@ msgstr "ugyldig roteringsinstruktion"
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr ""
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<allocator%> or %<align%>"
@@ -52608,24 +52634,24 @@ msgstr "%<,%> eller %<)%> forventet"
 msgid "duplicate %qs modifier"
 msgstr "duplikere %qs"
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr "sammenlign mellem signed og unsigned heltalsudtryk"
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple linear modifiers"
 msgstr "mere end én 'virtual'-angivelse"
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple %<step%> modifiers"
@@ -52646,70 +52672,70 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "ugyldig %%d-operand"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid doacross kind"
 msgstr "ugyldig maske"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<always%> modifiers"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<close%> modifiers"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<present%> modifiers"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "ugyldig maske"
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr ""
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<::%>"
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr "forventede %<:%> or %<::%>"
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, gcc-internal-format
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr ""
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ugyldig roteringsinstruktion"
@@ -52726,92 +52752,92 @@ msgstr "ugyldig roteringsinstruktion"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<;%>, %<,%> eller %<)%> forventet"
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected EOF while reading source file %s.\n"
 msgid "expected an OpenACC clause"
 msgstr "Stødt på slutningen af kildefilen %s tidligere end forventet.\n"
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%s understøtter ikke %s"
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, fuzzy, gcc-internal-format
 msgid "expected an OpenMP clause"
 msgstr "uventet operand"
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a global declaration"
 msgid "array section in %<#pragma acc declare%>"
 msgstr "erklæring af '%s' skygger for en global erklæring"
 
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma once in main file"
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "'#pragma once' i hovedfil"
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr ""
@@ -52827,7 +52853,7 @@ msgstr "'%#D' kan ikke erklæres"
 msgid "expected function name"
 msgstr "forventet funktion"
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD does not refer to a function"
@@ -52838,24 +52864,24 @@ msgstr "'%D' er ikke en medlemsskabelonfunktion"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
@@ -52882,7 +52908,7 @@ msgstr ""
 msgid "modified here"
 msgstr "'%s' tidligere defineret her"
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
@@ -52923,121 +52949,121 @@ msgstr ""
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr ""
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "%<;%>, %<,%> eller %<)%> forventet"
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many atomic clauses"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many memory order clauses"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "%qs clause requires %qs clause"
 msgstr "--resource påkræver -o"
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, fuzzy, gcc-internal-format
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr "'%s' er erklæret inline efter dens definition"
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, gcc-internal-format
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr ""
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr "ugyldig #pragma %s"
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<delete%>"
 msgid "unexpected %<else%>"
 msgstr "forventede %<delete%>"
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr "ugyldig #pragma %s"
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ugyldig #pragma %s"
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand for 'p' modifier"
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ugyldig operand til 'p'-ændring"
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr ""
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
@@ -53047,30 +53073,30 @@ msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr ""
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "%<;%>, %<,%> eller %<)%> forventet"
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -53080,176 +53106,176 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<::%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "forventede %<:%> or %<::%>"
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<#pragma omp section%> eller %<}%> forventet"
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of automaton `%s'"
 msgid "expected iteration declaration or initialization"
 msgstr "gentaget erklæring af automaten '%s'"
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, fuzzy, gcc-internal-format
 #| msgid "not enough arguments"
 msgid "not enough nested loops"
 msgstr "ikke nok parametre"
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, fuzzy, gcc-internal-format
 #| msgid "')' or term expected"
 msgid "for statement expected"
 msgstr "')' eller term forventet"
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected %<point%>"
 msgstr "uventet operand"
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected trait selector name"
 msgstr "tom krop i en else-sætning"
 
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown selector %qs for context selector set %qs"
 msgstr "ukendt værdi %qs for -mtune"
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type `%T' does not have member `%D'"
 msgid "selector %qs does not accept any properties"
 msgstr "ufuldstændig type '%T' har ikke medlemmet '%D'"
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified inside a class"
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr "'%D' kan kun angives inden i en klasse"
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, fuzzy, gcc-internal-format
 msgid "%<score%> argument must be constant integer expression"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "%<score%> argument must be non-negative"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, fuzzy, gcc-internal-format
 #| msgid "_Pragma takes a parenthesized string literal"
 msgid "expected identifier or string literal"
 msgstr "_Pragma tager en strengkonstant med paranteser omkring"
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, fuzzy, gcc-internal-format
 #| msgid "']' expected, invalid type expression"
 msgid "property must be constant integer expression"
 msgstr "']' forventet, ugyldigt typeudtryk"
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
@@ -53257,307 +53283,307 @@ msgstr ""
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, fuzzy, gcc-internal-format
 #| msgid "code model `large' not supported yet"
 msgid "%<requires%> selector is not supported yet"
 msgstr "kodemodellen 'large' er ikke understøttet endnu"
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected context selector set name"
 msgstr "tom krop i en else-sætning"
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<match%>"
 msgstr "forventede %<catch%>"
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "variant %qD is not a function"
 msgstr "'%s' er ikke en funktion,"
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, fuzzy, gcc-internal-format
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "-f%s og -msdata=%s er indbyrdes uforenelige"
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, gcc-internal-format
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "uventet operand"
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr "uventet operand"
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr ""
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr ""
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%> or %<assumes%>"
 msgstr "uventet operand"
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a global declaration"
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr "erklæring af '%s' skygger for en global erklæring"
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr ""
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, fuzzy, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "uventet operand"
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr "%<;%>, %<,%> eller %<)%> forventet"
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %qs or %qs"
 msgstr "%<,%> eller %<)%> forventet"
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr ""
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr ""
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, gcc-internal-format
 msgid "expected at least one assumption clause"
 msgstr ""
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, fuzzy, gcc-internal-format
 #| msgid "expected function"
 msgid "expected directive name"
 msgstr "forventet funktion"
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr ""
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown assumption clause %qs"
 msgstr "ukendt registernavn: %s"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, fuzzy, gcc-internal-format
 #| msgid "expected function"
 msgid "expected assumption clause"
 msgstr "forventet funktion"
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, fuzzy, gcc-internal-format
 #| msgid "%<transaction_may_cancel_outer%> function call not within outer transaction or %<transaction_may_cancel_outer%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "%<transaction_may_cancel_outer%> funktionskald er ikke inden for ydre transaktion eller %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "no closing brace"
@@ -53710,7 +53736,7 @@ msgstr "forsøg på at følge en 'void *'-henvisning"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "værdien der er påført et indeks, er hverken en tabel eller en henvisningsvariabel"
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "tabelindeks er ikke et heltal"
@@ -53743,7 +53769,7 @@ msgstr "'%D' erklæret som en reference, men bliver ikke tildelt en startværdi"
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -53874,19 +53900,19 @@ msgstr ""
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "for få parametre til funktionen"
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweak declaration of '%D' after first use results in unspecified behavior"
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "%Jsvag erklæring af '%D' efter første brug resulterer i ikke-defineret opførsel"
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "sammenligning mellem henvisningsvariabel og heltal"
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, fuzzy, gcc-internal-format
 #| msgid "casting `%T' to `%T' does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -53914,7 +53940,7 @@ msgstr "henvisning til en funktion benyttet i subtraktion"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "beregninger udført på en henvisning til en ufuldstændig type"
 
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -54249,7 +54275,7 @@ msgstr "typeomtvingelse fra henvisning til heltal af en anden størrelse"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "typeomtvingelse fra heltal til henvisning af en anden størrelse"
@@ -54450,7 +54476,7 @@ msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "return type might be a candidate for a format attribute"
@@ -54685,12 +54711,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "klargøring af fleksibelt tabelmedlem"
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
@@ -54702,7 +54728,7 @@ msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 msgid "array of inappropriate type initialized from string constant"
 msgstr "char-tabel får tildelt startværdi fra en bred streng"
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ugyldig brug af en tabel der ikke kan optræde som en venstreværdi"
@@ -54734,7 +54760,7 @@ msgstr "startværdielement er ikke en konstant"
 msgid "initializer element is not computable at load time"
 msgstr "startværdielement kan ikke beregnes ved indlæsningstidspunktet"
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "objekt af typen '%T' med variabel størrelse må ikke tildeles en startværdi"
@@ -54750,7 +54776,7 @@ msgid "braces around scalar initializer"
 msgstr "krøllede paranteser omkring skalarstartværdi"
 
 # RETMIG: eller er det fleksibel tabel-medlem
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "klargøring af fleksibelt tabelmedlem i en indlejret kontekst"
@@ -54846,7 +54872,7 @@ msgstr "for mange elementer i struct-startværdi"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "ikke-statisk klargøring af fleksibelt tabelmedlem"
@@ -54888,7 +54914,7 @@ msgstr "ISO C forbyder 'goto *udtryk;'"
 msgid "computed goto must be pointer type"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, fuzzy, gcc-internal-format
 #| msgid "function declared `noreturn' has a `return' statement"
 msgid "function declared %<noreturn%> has a %<return%> statement"
@@ -54951,7 +54977,7 @@ msgstr "'default'-etiket befinder sig ikke inden i en switch-sætning"
 msgid "break statement not within loop or switch"
 msgstr "break-sætning befinder sig ikke i en løkke- eller switch-konstruktion"
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -54999,30 +55025,30 @@ msgstr "adressen af '%D' vil altid være 'true'"
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "comparing vectors with different element types"
 msgstr "operander til ?: har forskellige typer"
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, fuzzy, gcc-internal-format
 #| msgid "operand constraints for `asm' differ in number of alternatives"
 msgid "comparing vectors with different number of elements"
 msgstr "operandbegrænsninger til 'asm' har forskellige antal alternativer"
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types `%#T' and `%#T'"
 msgid "comparison between types %qT and %qT"
 msgstr "sammenligning mellem typerne '%#T' og '%#T'"
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
@@ -55102,31 +55128,31 @@ msgstr "værdi af union-type angivet hvor skalar er påkrævet"
 msgid "used vector type where scalar is required"
 msgstr "værdi af struct-type angivet hvor skalar er påkrævet"
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "for mange inddatafiler"
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %qs clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %qs clause"
@@ -55139,90 +55165,90 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected EOF while reading source file %s.\n"
 msgid "expected single pointer in %qs clause"
 msgstr "Stødt på slutningen af kildefilen %s tidligere end forventet.\n"
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "Intern oversætterfejl i %s ved %s:%d."
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "for array function parameter length expression must be specified"
 msgstr "udsagn skal være et kaldenavn"
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE does not have pointer or array type"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, fuzzy, gcc-internal-format
 #| msgid "throwing NULL, which has integral, not pointer type"
 msgid "iterator %qD has neither integral nor pointer type"
@@ -55234,19 +55260,19 @@ msgstr "kaster NULL som har en heltals-, ikke en henvisningstype"
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, fuzzy, gcc-internal-format
 #| msgid "parameter has incomplete type"
 msgid "iterator %qD has const qualified type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%#D' with non-integral type"
 msgid "iterator step with non-integral type"
 msgstr "bitfelt '%#D' med en ikke-heltalstype"
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
@@ -55256,37 +55282,37 @@ msgstr ""
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "begin expression refers to outer iterator %qD"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "end expression refers to outer iterator %qD"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "step expression refers to outer iterator %qD"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected pointer in %qs clause"
 msgstr "uventet operand"
 
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<inscan%> %<reduction%> clause with array section"
@@ -55322,7 +55348,7 @@ msgstr "bitfeltet '%s' er af en ufuldstændig type"
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "ugyldig returtype for funktionen '%#D'"
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "brug af '%D' er tvetydigt"
@@ -55332,17 +55358,17 @@ msgstr "brug af '%D' er tvetydigt"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
 msgstr ""
@@ -55357,26 +55383,26 @@ msgstr ""
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in clause %qs"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in motion clauses"
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr "%qD fremgår mere end en gang i motion-klausuller"
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -55388,34 +55414,34 @@ msgstr ""
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -55437,7 +55463,7 @@ msgstr "%<_Atomic%> %qD i %<aligned%>-klausul"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<depend%> clause"
 msgid "%qE is not a variable in %<nontemporal%> clause"
@@ -55449,7 +55475,7 @@ msgstr "%qE er ikke en variable i %<depend%>-klausul"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qD fremgår mere end en gang i map-klausuller"
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %<allocate%> clause"
@@ -55461,78 +55487,78 @@ msgstr "'%s' er et ugyldigt klassenavn"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qD fremgår mere end en gang i map-klausuller"
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr ""
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<depend%> clause"
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr "%qE er ikke en variable i %<depend%>-klausul"
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported map expression %qE"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD fremgår mere end en gang i motion-klausuller"
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD fremgår mere end en gang i map-klausuller"
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD har ikke en mappable-type i %qs-klausul"
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE er hverken en variabel eller et funktionsnavn i klausul %qs"
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
@@ -55549,23 +55575,23 @@ msgstr "grundoperanden til '->' er ikke en henvisning"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses on a task construct"
 msgstr "for mange inddatafiler"
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
@@ -55575,39 +55601,39 @@ msgstr ""
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
@@ -55915,14 +55941,14 @@ msgstr "  for konvertering fra '%T' til '%T'"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  for konvertering fra '%T' til '%T'"
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -56261,624 +56287,624 @@ msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvi
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "enum- og ikke enum-type i betinget udtryk"
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, fuzzy, gcc-internal-format
 #| msgid "no `%D(int)' declared for postfix `%s', trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "ingen '%D(int)' erklæret for suffiks '%s', prøver præfiksoperatoren i stedet"
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, fuzzy, gcc-internal-format
 #| msgid "no `%D(int)' declared for postfix `%s', trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "ingen '%D(int)' erklæret for suffiks '%s', prøver præfiksoperatoren i stedet"
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "returtypen til '%s' er ikke 'int'"
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between `%#T' and `%#T'"
 msgid "comparison between %q#T and %q#T"
 msgstr "sammenligning mellem '%#T' og '%#T'"
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to `(%T) (%A)'"
 msgid "no match for call to %<%T::operator[] (%A)%>"
 msgstr "ingen passende fundet for kald til '(%T) (%A)'"
 
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, fuzzy, gcc-internal-format
 #| msgid "call of `(%T) (%A)' is ambiguous"
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr "kald af '(%T) (%A)' er tvetydigt"
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%#D'"
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "underforstået erklæring af funktionen '%#D'"
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function `%#D'"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "underforstået erklæring af funktionen '%#D'"
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr ""
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, fuzzy, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "ingen passende 'operator delete' for '%T'"
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "i denne kontekst"
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "declared private here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "i denne kontekst"
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "declared protected here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, fuzzy, gcc-internal-format
 #| msgid "`%+#D' is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "'%+#D' er ikke tilgængelig"
 
 # %s bliver til returnering eller tildeling eller noget i den retning
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, fuzzy, gcc-internal-format
 #| msgid "passing NULL used for non-pointer %s %P of `%D'"
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "overbringelse af NULL benyttet for ikke-henvisnings%s %P af '%D'"
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "  declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, fuzzy, gcc-internal-format
 #| msgid "%s to non-pointer type `%T' from NULL"
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "%s til ikke-henvisningstypen '%T' fra NULL"
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of `%s'"
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "typen af den %d. parameter i '%s' passer ikke"
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "konverterer NULL til en ikke-henvisningstype"
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, fuzzy, gcc-internal-format
 #| msgid "  initializing argument %P of `%D'"
 msgid "  initializing argument %P of %qD"
 msgstr "  ved klargøring af parameteren %P til '%D'"
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for `%T'"
 msgid "too many braces around initializer for %qT"
 msgstr "krøllede paranteser omkring skalarstartværdi for '%T'"
 
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 #, fuzzy
 #| msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr "ISO C++ tillader ikke %<alignof%> med en ikke-type"
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr ""
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 #, fuzzy
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "ugyldig konvertering fra '%T' til '%T'"
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 #, fuzzy
 #| msgid "invalid conversion from `%T' to `%T'"
 msgid "invalid conversion from %qH to %qI"
 msgstr "ugyldig konvertering fra '%T' til '%T'"
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 #, fuzzy
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 #, fuzzy
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 #, fuzzy
 #| msgid "passing `%T' as `this' argument of `%#D' discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "videregivelse af '%T' som 'this'-parameteren til '%#D' forkaster modifikationer"
 
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "kan ikke klargøre '%T' fra %T'"
 
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, fuzzy, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "kan ikke erklære feltet '%D' til at være af typen '%T'"
 
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, fuzzy, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "kan ikke klargøre '%T' fra %T'"
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "konvertering fra NaN til unsigned int"
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type `%#T' through `...'"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "kan ikke modtage objekter af en ikke-POD type '%#T' gennem '...'"
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "omdefinering af standardparameter for '%#D'"
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "standardparameter for parameter af typen '%T' har typen '%T'"
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr ""
 
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' as `this' argument of `%#D' discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "videregivelse af '%T' som 'this'-parameteren til '%#D' forkaster modifikationer"
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, fuzzy, gcc-internal-format
 #| msgid "  in call to `%D'"
 msgid "  in call to %qD"
 msgstr "  i kald af '%D'"
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "'%T' er en utilgængelig stamklasse til '%T'"
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, fuzzy, gcc-internal-format
 #| msgid "#include nested too deeply"
 msgid "; use assignment instead"
 msgstr "#include indlejret for dybt"
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "; use value-initialization instead"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, fuzzy, gcc-internal-format
 #| msgid "#include nested too deeply"
 msgid "; use copy-assignment instead"
 msgstr "#include indlejret for dybt"
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "; use copy-initialization instead"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%#qT declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function `%s'"
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr "parameter der ikke er et kommatal, til funktionen '%s'"
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "ingen passende funktion for kald til '%T::%D(%A)%#V'"
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "ingen passende funktion for kald til '%T::%D(%A)%#V'"
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to non-function %qD"
 msgstr "kald af ikke-funktion '%D'"
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call destructor `%T::~%T' without object"
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "kan ikke kalde destruktionsfunktion '%T::~%T' uden objekt"
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to `%D(%A)'"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "ingen passende funktion for kald til '%D(%A)'"
 
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, fuzzy, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "kald af flertydig '%D(%A)' er tvetydigt"
 
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "returnerer en værdi fra en konstruktionsfunktion"
 
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "returnerer en værdi fra en destruktionsfunktion"
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call member function `%D' without object"
 msgid "cannot call member function %qD without object"
 msgstr "kan ikke kalde medlemsfunktionen '%D' uden et objekt"
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' chooses `%T' over `%T'"
 msgid "passing %qT chooses %qT over %qT"
 msgstr "videregivelse af '%T' vælger '%T' frem for '%T'"
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, fuzzy, gcc-internal-format
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr "ifølge ISO C++ er '%D' og '%D' tvetydigt selvom den værste konvertering for førstnævnte er bedre end den værste konvertering for den sidstnævnte"
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, fuzzy, gcc-internal-format
 #| msgid "destructors must be member functions"
 msgid "try making the operator a %<const%> member function"
 msgstr "destruktionsfunktioner skal være medlemmer"
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, fuzzy, gcc-internal-format
 #| msgid "choosing `%D' over `%D'"
 msgid "choosing %qD over %qD"
 msgstr "vælger '%D' frem for '%D'"
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 #, fuzzy
 #| msgid "  for conversion from `%T' to `%T'"
 msgid "  for conversion from %qH to %qI"
 msgstr "  for konvertering fra '%T' til '%T'"
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  fordi konverteringssekvensen for parameteren er bedre"
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "standardparameter angivet i eksplicit specialisering"
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr "candidate%s: %+#D"
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr "candidate%s: %+#D"
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ifølge ISO C++ er '%D' og '%D' tvetydigt selvom den værste konvertering for førstnævnte er bedre end den værste konvertering for den sidstnævnte"
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 #, fuzzy
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "possibly dangling reference to a temporary"
 msgstr "returnerer reference til midlertidig variabel"
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr ""
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, fuzzy, gcc-internal-format
 #| msgid "%s: definition of function `%s' not converted\n"
 msgid "explicit conversion function was not considered"
@@ -56932,7 +56958,7 @@ msgstr "'%#D' og '%#D' kan ikke flertydiggøres"
 
 # hænger sammen med næste tekst
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %q#D"
@@ -57413,7 +57439,7 @@ msgstr "fleksibelt tabelmedlem i ellers tom struktur"
 msgid "next member %q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `%#T'"
 msgid "redefinition of %q#T"
@@ -57563,7 +57589,7 @@ msgstr "ugyldig returtype for medlemsfunktionen '%#D'"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
@@ -57606,7 +57632,7 @@ msgstr ""
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr ""
@@ -57625,7 +57651,7 @@ msgstr "tom erklæring"
 msgid "%q+E is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing `void *' pointer"
@@ -57649,7 +57675,7 @@ msgstr "brugerdefineret '%D' evaluerer altid begge parametre"
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
@@ -57701,7 +57727,7 @@ msgstr "'%T' er en tvetydig stamklasse til '%T'"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
@@ -57845,20 +57871,20 @@ msgstr "tabelindeks er ikke et heltal"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "accessing uninitialized array element"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing `void *' pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "forsøg på at følge en 'void *'-henvisning"
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -57867,514 +57893,514 @@ msgstr "forsøg på at følge en 'void *'-henvisning"
 msgid "%qE is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "accessing uninitialized member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "-indlejrede funktioner er ikke understøttet på denne målarkitektur"
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "allocated here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
 msgstr ""
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "%qD used in its own initializer"
 msgstr "for mange elementer i union-startværdi"
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%q#D is not const"
 msgstr "'%s' er ikke en funktion,"
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, fuzzy, gcc-internal-format
 #| msgid "`%+#D' is private"
 msgid "%q#D is volatile"
 msgstr "'%+#D' er privat"
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, fuzzy, gcc-internal-format
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr ""
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr ""
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline assembly is not a constant expression"
 msgstr "startværdielement er ikke en konstant"
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "use of %qD"
 msgstr "ugyldig brug af '%D"
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr ""
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr ""
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr ""
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr ""
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, gcc-internal-format
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "enum- og ikke enum-type i betinget udtryk"
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "pointed-to object declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, fuzzy, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "uventet operand"
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "den indbyggede funktion '%s' er erklæret som noget der ikke er en funktion"
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "uventet adresseudtryk"
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast of an rvalue expression of type `%T' to type `%T'"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "ugyldig reinterpret_cast af et højreværdiudtryk fra typen '%T' til typen '%T'"
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast from type `%T' to type `%T'"
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "ugyldig reinterpret_cast fra typen '%T' til typen '%T'"
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "new-expression is not a constant expression before C++20"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' declared static in union"
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "feltet '%D' er erklæret statisk i union"
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' declared static in union"
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "feltet '%D' er erklæret statisk i union"
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "tabelindekset i startværdien er ikke en konstant"
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unexpected type for `id' (%s)"
 msgid "unexpected AST of kind %s"
@@ -59171,7 +59197,7 @@ msgstr "en tredje parameter til '__builtin_prefetch' skal være en konstant"
 msgid "no suspend point info for %qD"
 msgstr "ingen tidligere prototype for '%s'"
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -59194,23 +59220,23 @@ msgstr "henvisningsvariabler er ikke tilladt som case-værdier"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "Advar når en variabel ikke benyttes"
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, fuzzy, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
@@ -59231,77 +59257,77 @@ msgstr ""
 msgid "%qD was promoted to an immediate function"
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor"
 msgid "taking address of an immediate function %qD"
 msgstr "tager adressen på en destruktionsfunktion"
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "call to consteval function %qE is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, fuzzy, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qE attribute"
 msgid "pack expansion of %qE attribute"
 msgstr "ugyldig parameter for egenskaben %qE"
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid expression statement"
 msgid "use fold expression in the attribute argument instead"
 msgstr "Ugyldig udtrykssætning"
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD is not a type"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or union type"
 msgid "%qD is not a class type"
 msgstr "'%T' er ikke af en klasse- eller union-type"
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
@@ -59350,7 +59376,7 @@ msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "konvertering fra '%T' til '%T' forkaster modifikationer"
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, fuzzy, gcc-internal-format
 #| msgid "casting `%T' to `%T' does not dereference pointer"
 msgid "casting %qT to %qT does not dereference pointer"
@@ -59786,7 +59812,7 @@ msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "erklæring af '%D' som %s"
 
 # hænger sammen med næste tekst
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %qD"
@@ -59949,8 +59975,8 @@ msgstr "tidligere ikke-funktionserklæring '%#D'"
 msgid "%q#D previously defined here"
 msgstr "'%#D' tidligere defineret her"
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' previously declared here"
 msgid "%q#D previously declared here"
@@ -60038,58 +60064,40 @@ msgstr "standardparameter givet til %d. parameter for '%#D'"
 msgid "previous specification in %q#D here"
 msgstr "efter tidligere specifikation i '%#D'"
 
-#: cp/decl.cc:2285
-#, fuzzy, gcc-internal-format
-#| msgid "conflicts with built-in declaration `%#D'"
-msgid "declaration %qD conflicts with builtin"
-msgstr "strider mod indbygget erklæring '%#D'"
-
-#: cp/decl.cc:2288
-#, fuzzy, gcc-internal-format
-#| msgid "conflicts with built-in declaration `%#D'"
-msgid "declaration %qD conflicts with import"
-msgstr "strider mod indbygget erklæring '%#D'"
-
-#: cp/decl.cc:2289
-#, fuzzy, gcc-internal-format
-#| msgid "  first declared as `%#D' here"
-msgid "import declared %q#D here"
-msgstr "  først erklæret som '%#D' her"
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, fuzzy, gcc-internal-format
 msgid "conflicting exporting for declaration %qD"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously declared here"
 msgid "previously declared here without exporting"
 msgstr "'%s' tidligere erklæret her"
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "tidligere definition her"
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "tidligere erklæring af '%#D' her"
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' declared virtual inside a union"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "funktionen '%D' erklæret virtual inden i en union"
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of `%D' in same scope"
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "overflødig omerklæring af '%D' i samme virkefelt"
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of `%s'"
 msgid "deleted definition of %qD is not first declaration"
@@ -60103,48 +60111,48 @@ msgstr "indlejret omdefinering af '%s'"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %D after first use"
 msgid "explicit specialization of %qD after first use"
 msgstr "eksplicit specialisering af %D efter første brug"
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "dataområdet '%s' er i modstrid med tidligere erklæring"
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `%#T'"
 msgid "redefinition of %q#D"
 msgstr "omdefinering af '%#T'"
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' conflicts with previous using declaration `%#D'"
 msgid "%qD conflicts with used function"
 msgstr "'%#D' strider mod tidligere using-erklæring '%#D'"
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%q#D not declared in class"
 msgstr "'%D' ikke erklæret"
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -60152,837 +60160,837 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "trådlokal erklæring af '%s' følger ikke-trådlokal erklæring"
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "ikke-trådlokal erklæring af '%s' følger trådlokal erklæring"
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "redeclaration of %q#D"
 msgstr "omerklæring af '%#D'"
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of `%s' in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "overflødig omerklæring af '%s' i samme virkefelt"
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, fuzzy, gcc-internal-format
 #| msgid "a previous local"
 msgid "previous label"
 msgstr "en tidligere lokal variabel"
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, gcc-internal-format
 msgid "jump to label %qD"
 msgstr "spring til etiketten %qD"
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr "spring til case-etiket"
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr ""
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  herfra"
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of `%#D'"
 msgid "  crosses initialization of %q#D"
 msgstr "  krydser klargøring af '%#D'"
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  går ind i try-blok"
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  går ind i catch-blok"
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters OpenMP structured block"
 msgstr "  går ind i try-blok"
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "  enters statement expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, fuzzy, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "uventet operand"
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, fuzzy, gcc-internal-format
 msgid "  enters %<consteval if%> statement"
 msgstr "uventet operand"
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "  does not destroy %qD"
 msgstr "%s understøtter ikke %s"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, fuzzy, gcc-internal-format
 msgid "  does not clean up handled exception"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of `%#D'"
 msgid "  skips initialization of %q#D"
 msgstr "  springer over klargøring af '%#D'"
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "'%D' benyttet uden skabelonsparametre"
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%qD is a function, not a type"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' is not a template"
 msgid "%q#T is not a class"
 msgstr "'%#T' er ikke en skabelon"
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, fuzzy, gcc-internal-format
 #| msgid "no class template named `%#T' in `%#T'"
 msgid "no class template named %q#T in %q#T"
 msgstr "ingen klasseskabelon ved navn '%#T' i '%#T'"
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, fuzzy, gcc-internal-format
 #| msgid "no type named `%#T' in `%#T'"
 msgid "no type named %q#T in %q#T"
 msgstr "ingen type ved navn '%#T' i '%#T'"
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, fuzzy, gcc-internal-format
 #| msgid "call of `(%T) (%A)' is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "kald af '(%T) (%A)' er tvetydigt"
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, fuzzy, gcc-internal-format
 #| msgid "`%D::%D' is not a template"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "'%D::%D' er ikke en skabelon"
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameters do not match template %qD"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, fuzzy, gcc-internal-format
 #| msgid "-falign-labels=%d is not supported"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "-falign-labels=%d understøttes ikke"
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "'%#D' er ugyldig; en anonym union kan kun have ikke-statiske datamedlemmer"
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is deprecated and may be removed"
 msgid "this flexibility is deprecated and will be removed"
 msgstr "-traditional er forældet og kan blive fjernet"
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous struct not inside named type"
 msgid "anonymous struct with base classes"
 msgstr "anonym struct er ikke inden i en navngiven type"
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with constructor not allowed in anonymous aggregate"
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "medlemmet '%#D' med konstruktionsfunktion er ikke tilladt i anonym sammensat type"
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with destructor not allowed in anonymous aggregate"
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "medlemmet '%#D' med destruktionsfunktion er ikke tilladt i anonym sammensat type"
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, fuzzy, gcc-internal-format
 #| msgid "member %#D' with copy assignment operator not allowed in anonymous aggregate"
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "medlemmet '%#D' med kopitildelingsoperator er ikke tilladt i anonym sammensat type"
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, fuzzy, gcc-internal-format
 #| msgid "forward declaration of `%#T'"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "forhåndserklæring af '%#T'"
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "flere typer i én erklæring"
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type `%T'"
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "omerklæring af indbygget type i C++ '%T'"
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "manglende typenavn i typedef-erklæring"
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ forbyder anonyme strukturer"
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "'%D' kan kun angives for funktioner"
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "'%D' kan kun angives for funktioner"
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified inside a class"
 msgid "%<friend%> can only be specified inside a class"
 msgstr "'%D' kan kun angives inden i en klasse"
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for constructors"
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "'%D' kan kun angives for konstruktionsfunktioner"
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "a storage class can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "'%D' kan kun angives for objekter og funktioner"
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "tom erklæring"
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter list used in explicit instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "skabelonsparameterliste benyttet i eksplicit instantiering"
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
 # init dækker over værditildeling her - samme for de næste mange
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, fuzzy, gcc-internal-format
 #| msgid "typedef `%D' is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef '%D' bliver tildelt en værdi (benyt __typeof__ i stedet)"
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' has `extern' and is initialized"
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "erklæringen af '%#D' indeholder 'extern' og variablen bliver tildelt en startværdi"
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "'auto' er påhæftet funktionsdefinitionen"
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "'%#D' er ikke et statisk medlem af '%#T'"
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "non-member-template declaration of %qD"
 msgstr "skabelonserklæring af '%#D'"
 
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "does not match member template declaration here"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not permit `%T::%D' to be defined as `%T::%D'"
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ tillader ikke '%T::%D' at blive defineret som '%T::%D'"
 
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "duplicate initialization of %qD"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr ""
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, fuzzy, gcc-internal-format
 #| msgid "variable `%#D' has initializer but incomplete type"
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variablen '%#D' bliver tildelt en startværdi, men er af en ufuldstændig type"
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array `%#D' have incomplete type"
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementer i tabellen '%#D' er af en ufuldstændig type"
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, fuzzy, gcc-internal-format
 #| msgid "aggregate `%#D' has incomplete type and cannot be defined"
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "den sammensatte type '%#D' er af en ufuldstændig type og kan ikke defineres"
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as reference but not initialized"
 msgid "%qD declared as reference but not initialized"
 msgstr "'%D' erklæret som en reference, men bliver ikke tildelt en startværdi"
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "ikke-trivielle udpegede startværdier er ikke understøttet"
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "startværdien giver ikke størrelsen af %qD"
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "tabelstørrelsen mangler i %qD"
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "nulstørrelsestabel %qD"
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "lagringsstørrelsen af %qD er ikke kendt"
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of `%D' isn't constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "lagringsstørrelsen af '%D' er ikke konstant"
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data `%#D' are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "semantikken for indlejret funktionsstatisk data '%#D' er forkert (du ender med flere kopier)"
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data `%#D' are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "semantikken for indlejret funktionsstatisk data '%#D' er forkert (du ender med flere kopier)"
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "  du kan arbejde dig rundt om dette ved at fjerne startværdien"
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const `%D'"
 msgid "uninitialized %<const %D%>"
 msgstr "konstant '%D' uden startværdi"
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "typen '%T' har ingen destruktionsfunktion"
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for virtual method `%D'"
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "ugyldig startværdi til virtuel medlemsfunktion '%D'"
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for `%T' must be brace-enclosed"
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "startværdi for '%T' skal være indesluttet i krøllede paranteser"
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' is ambiguous"
 msgid "request for member %qD is ambiguous"
 msgstr "forespørgsel efter medlemmet '%D' er tvetydigt"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "%qT has no non-static data member named %qD"
 msgstr "'%T' har intet ikke-statisk medlem ved navn '%D'"
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of `%T'"
 msgid "%qD is not a direct member of %qT"
 msgstr "'%D' er ikke et medlem af '%T'"
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "ugyldig startværdi"
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in aggregate initializer"
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "for mange elementer i startværdi til sammensat type"
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "for mange startværdier for %qT"
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for `%T'"
 msgid "braces around scalar initializer for type %qT"
 msgstr "krøllede paranteser omkring skalarstartværdi for '%T'"
 
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for `%T'"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "krøllede paranteser omkring skalarstartværdi for '%T'"
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, fuzzy, gcc-internal-format
 #| msgid "missing braces around initializer"
 msgid "missing braces around initializer for %qT"
 msgstr "krøllede paranteser mangler omkring startværdien"
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding has incomplete type %qT"
 msgstr "forsøg på at følge en henvisning til en variabel af en ufuldstændig type"
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array `%#D' have incomplete type"
 msgid "elements of array %q#T have incomplete type"
 msgstr "elementer i tabellen '%#D' er af en ufuldstændig type"
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ISO C89 forbyder sammensatte konstanter"
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "'%D' er af en ufuldstændig type"
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "scalar object %qD requires one element in initializer"
 msgstr "for mange elementer i union-startværdi"
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be initialized by constructor, not by `{...}'"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "'%D' skal klargøres af en konstruktionsfunktion, ikke af '{...}'"
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, fuzzy, gcc-internal-format
 #| msgid "_Pragma takes a parenthesized string literal"
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "_Pragma tager en strengkonstant med paranteser omkring"
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "tildeling af startværdi er ugyldig for statisk medlem med konstruktionsfunktion"
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ forbyder tildeling af startværdi i klasse til ikke-konstant statisk medlem '%D'"
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ forbyder tildeling af startværdi i klasse til ikke-konstant statisk medlem '%D'"
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(en klargøring uden for klassens erklæring er nødvendig)"
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' with uninitialized const fields"
 msgid "reference %qD is initialized with itself"
 msgstr "medlem '%D' med konstante felter uden startværdi"
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "could not find variant declaration"
 msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s `%+#D'"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "for få parametre til %s '%+#D'"
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "using-erklæring for destruktionsfunktion"
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++17 tillader ikke %<register%>-lagerklasseangivelse"
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %s `%s'"
 msgid "%<register%> storage class specifier used"
 msgstr "lagringsklasse angivet for %s '%s'"
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' has `extern' and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "erklæringen af '%#D' indeholder 'extern' og variablen bliver tildelt en startværdi"
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member (did you forget the `&' ?)"
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "ugyldig brug af medlem (glemte du en '&'?)"
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, fuzzy, gcc-internal-format
 #| msgid "return type `%#T' is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "returtype '%#T' er ufuldstændig"
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "et objekt af variabel størrelse må ikke tildeles en startværdi"
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, fuzzy, gcc-internal-format
 #| msgid "shadowing previous type declaration of `%#D'"
 msgid "shadowing previous type declaration of %q#D"
 msgstr "skygger for tidligere typeerklæring af '%#D'"
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, fuzzy, gcc-internal-format
 #| msgid "function `%#D' is initialized like a variable"
 msgid "function %q#D is initialized like a variable"
 msgstr "funktionen '%#D' bliver tildelt en startværdi som en variabel"
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at `%D' because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  kan ikke bruge forældet binding til '%D' fordi den har en destruktionsfunktion"
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "forsøg på at følge en henvisning til en variabel af en ufuldstændig type"
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array `%s'"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "%u name provided for structured binding"
@@ -60990,2030 +60998,2030 @@ msgid_plural "%u names provided for structured binding"
 msgstr[0] "lagringsklasse angivet for strukturfelt '%s'"
 msgstr[1] "lagringsklasse angivet for strukturfelt '%s'"
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array `%s'"
 msgid "cannot decompose variable length vector %qT"
 msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "in initialization of structured binding variable %qD"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot decompose union type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "forsøg på at følge en henvisning til en variabel af en ufuldstændig type"
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of `%D'"
 msgid "initializer fails to determine size of %qT"
 msgstr "startværdien giver ikke størrelsen af '%D'"
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qT"
 msgstr "tabelstørrelsen mangler i '%D'"
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qT"
 msgstr "nulstørrelsestabel '%D'"
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, fuzzy, gcc-internal-format
 #| msgid "destructor for alien class `%T' cannot be a member"
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "destruktionsfunktionen for den fremmede klasse '%T' kan ikke være et medlem"
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, fuzzy, gcc-internal-format
 #| msgid "constructor for alien class `%T' cannot be a member"
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruktionsfunktionen for den fremmede klasse '%T' kan ikke være et medlem"
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "'%D' erklæret som 'virtual' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "'%D' er erklæret som en ven"
 
 # %s bliver omsat til typen
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as an `inline' %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "'%D' erklæret som 'inline' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as an `inline' %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "'%D' erklæret som 'inline' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "%q+D declared as a friend"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared with an exception specification"
 msgid "%q+D declared with an exception specification"
 msgstr "'%D' erklæret med en undtagelsesspecifikation"
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' not in a namespace surrounding `%D'"
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "erklæring af '%D' er ikke i et navnerum der omgiver '%D'"
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, fuzzy, gcc-internal-format
 #| msgid "static member function `%#D' declared with type qualifiers"
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statisk medlemsfunktion '%#D' erklæret med typemodifikationer"
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, fuzzy, gcc-internal-format
 #| msgid "Java method '%D' has non-Java return type `%T'"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java-metoden '%D' har har en returtype '%T' som ikke er fra Java"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, fuzzy, gcc-internal-format
 #| msgid "node is alias but not definition"
 msgid "concept %qD has no definition"
 msgstr "node er alias men ikke definition"
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "a function concept cannot be constrained"
 msgstr "funktion kan ikke indbygges"
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "constraints on a non-templated function"
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "constrained non-template friend declaration must be a definition"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, fuzzy, gcc-internal-format
 #| msgid "defining explicit specialization `%D' in friend declaration"
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "definering af eksplicit specialisering '%D' i friend-erklæring"
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-id `%D' in declaration of primary template"
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ugyldig brug af skabelons-id '%D' i erklæring af primær skabelon"
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, fuzzy, gcc-internal-format
 #| msgid "`inline' is not allowed in declaration of friend template specialization `%D'"
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "'inline' er ikke tilladt i erklæring venneskabelonsspecialisering '%D'"
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "kan ikke erklære %<::main%> som en skabelon"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "kan ikke erklære %<::main%> som indlejret"
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "kan ikke erklære '::main' som statisk"
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be static"
 msgid "cannot declare %<::main%> to be static"
 msgstr "kan ikke erklære '::main' som statisk"
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type `%T' declared `friend'"
 msgid "explicit object parameter declared here"
 msgstr "skabelonsparametertypen '%T' erklæret 'friend'"
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "skabelon med C-kædning"
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, fuzzy, gcc-internal-format
 #| msgid "#%s with invalid argument"
 msgid "%qD has invalid argument list"
 msgstr "#%s med ugyldig parameter"
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "'%D' skal være en ikke-statisk medlemsfunktion"
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, fuzzy, gcc-internal-format
 #| msgid "`main' must return `int'"
 msgid "%<::main%> must return %<int%>"
 msgstr "'main' skal returnere typen 'int'"
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared `%D'"
 msgid "definition of implicitly-declared %qD"
 msgstr "definition af underforstået-erklæret '%D'"
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared `%D'"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "definition af underforstået-erklæret '%D'"
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "'%#D' tidligere defineret her"
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, fuzzy, gcc-internal-format
 #| msgid "no `%#D' member function declared in class `%T'"
 msgid "no %q#D member function declared in class %qT"
 msgstr "ingen medlemsfunktion '%#D' erklæret i klassen '%T'"
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "kan ikke erklære '::main' som en skabelon"
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "concept must be defined at namespace scope"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "et objekt af variabel størrelse må ikke tildeles en startværdi"
 
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ forbyder tildeling af startværdi i klasse til ikke-konstant statisk medlem '%D'"
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids initialization of member constant `%D' of non-integral type `%T'"
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ forbyder tildeling af startværdi til medlemskonstant '%D' af en ikke-heltallig type"
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "størrelsen af tabellen '%D' er ikke af en heltalstype"
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "størrelsen af tabel er ikke af en heltalstype"
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array `%D'"
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ forbyder tabellen '%D' med størrelsen nul"
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ forbyder tabel med størrelsen nul"
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array `%D'"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ forbyder tabellen '%D' med variabel størrelse"
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ forbyder tabel med variabel størrelse"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "tabeldimension for stor"
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating array of template placeholder type %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "'%s' erklæret som en tabel af void"
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of void"
 msgstr "opretter tabel af '%T'"
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "creating array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of references"
 msgstr "opretter tabel af '%T'"
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "creating array of function members"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "erklæring af '%D' som flerdimensional tabel skal have grænser for alle dimensioner pånær den første"
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "flerdimensional tabel skal have grænser for alle dimensioner pånær den første"
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when a variable is unused"
 msgid "variable-length array of %<auto%>"
 msgstr "Advar når en variabel ikke benyttes"
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "angivelse af returneringstypen til konstruktionsfunktion er ugyldigt"
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "angivelse af returneringstypen til destruktionsfunktion er ugyldigt"
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, fuzzy, gcc-internal-format
 #| msgid "return type specified for `operator %T'"
 msgid "return type specified for %<operator %T%>"
 msgstr "returtype angivet for 'operator %T'"
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "angivelse af returneringstypen til destruktionsfunktion er ugyldigt"
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "unavngiven variabel eller felt erklæret void"
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variabel eller felt erklæret void"
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, fuzzy, gcc-internal-format
 #| msgid "%s as integer rather than floating due to prototype"
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%s som heltal i stedet for kommatal på grund af prototypen"
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D'"
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ugyldig brug af medlemmet '%D'"
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, fuzzy, gcc-internal-format
 #| msgid "invalid definition of qualified type `%T'"
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ugyldig definition af modificeret type '%T'"
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D'"
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ugyldig brug af medlemmet '%D'"
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "declaration of %qE as non-member"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, fuzzy, gcc-internal-format
 #| msgid "declarator-id missing; using reserved word `%D'"
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "erklærer-id mangler; bruger reserveret ord '%D'"
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `register'"
 msgid "function definition does not declare parameters"
 msgstr "'register' er påhæftet funktionsdefinitionen"
 
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "declaration of %qD as non-function"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "erklæring af '%D' som %s"
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, fuzzy, gcc-internal-format
 #| msgid "both long and short specified for `%s'"
 msgid "both %qs and %qs specified"
 msgstr "både long og short er angivet for '%s'"
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "navnerum '%D' ikke tilladt i using-erklæring"
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, fuzzy, gcc-internal-format
 #| msgid "two or more data types in declaration of `%s'"
 msgid "two or more data types in declaration of %qs"
 msgstr "mere end én datatype i erklæringen af '%s'"
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C understøtter ikke at blot 'complex' betyder 'double complex'"
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids declaration of `%s' with no type"
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ forbyder erklæring af '%s' uden en type"
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_trap not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_trap understøttes ikke på denne målarkitektur"
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ understøtter ikke 'long long'"
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, fuzzy, gcc-internal-format
 #| msgid "signed and unsigned given together for `%s'"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "signed og unsigned er begge angivet for '%s'"
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, fuzzy, gcc-internal-format
 #| msgid "long and short specified together for `%s'"
 msgid "%<long%> and %<short%> specified together"
 msgstr "long og short er begge angivet for '%s'"
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%qs specified with %qT"
 msgstr "%s brugt med '%%%c' %s-formatering"
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%qs specified with typedef-name %qD"
 msgstr "%s brugt med '%%%c' %s-formatering"
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "%qs specified with %<decltype%>"
 msgstr "forventede %<decltype%>"
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%qs specified with %<typeof%>"
 msgstr "%s brugt med '%%%c' %s-formatering"
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "complex invalid for %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "medlemmet '%D' kan ikke afklæres både virtual og static"
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "medlemmet '%D' kan ikke afklæres både virtual og static"
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef-erklæringer er ugyldig i parametererklæringer"
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for template parameter %qs"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for parameter %qs"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a parameter cannot be declared %qs"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "virtual angivet uden for klasseerklæring"
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, fuzzy, gcc-internal-format
 #| msgid "forward declaration of `%#T'"
 msgid "structured binding declaration cannot be %qs"
 msgstr "forhåndserklæring af '%#T'"
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "Ugyldig erklæring"
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "funktionen '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' cannot be declared friend"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "funktionen '%D' kan ikke erklæres friend"
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' cannot be declared friend"
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "funktionen '%D' kan ikke erklæres friend"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "multiple storage classes in declaration of %qs"
 msgstr "flere lagringsklasser optræder i erklæringen af '%s'"
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %s `%s'"
 msgid "storage class specified for %qs"
 msgstr "lagringsklasse angivet for %s '%s'"
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, fuzzy, gcc-internal-format
 #| msgid "nested function `%s' declared `extern'"
 msgid "nested function %qs declared %<extern%>"
 msgstr "indlejret funktion '%s' er erklæret 'extern'"
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, fuzzy, gcc-internal-format
 #| msgid "top-level declaration of `%s' specifies `auto'"
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "erklæring af '%s' på øverste niveau angiver 'auto'"
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope `%s' implicitly auto and declared `__thread'"
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "'%s' i funktionsvirkefelt underforstået auto og erklæret '__thread'"
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "lagringsklasseanvisninger er ugyldige i vennefunktionserklæringer"
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "attribute ignored"
 msgstr "egenskaben '%s' ignoreret"
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "flere lagringsklasser optræder i erklæringen af '%s'"
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, fuzzy, gcc-internal-format
 msgid "remove parentheses"
 msgstr "uventet operand"
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "a function type cannot have an explicit object parameter"
 msgstr "funktion kan ikke indbygges"
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr ""
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, gcc-internal-format
 msgid "the type of an explicit object member function is a regular function type"
 msgstr ""
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type `%T' declared `friend'"
 msgid "valid explicit object parameter declared here"
 msgstr "skabelonsparametertypen '%T' erklæret 'friend'"
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "requires-clause on return type"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "ugyldig brug af '%D"
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "typemodifikationer ignoreret i funktionsreturtypen"
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning a function"
 msgid "%qs declared as function returning a function"
 msgstr "'%s' er erklæret som en funktion der returnerer en funktion"
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning an array"
 msgid "%qs declared as function returning an array"
 msgstr "'%s' er erklæret som en funktion der returnerer en tabel"
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "destruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "destructors may not be cv-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be `%s'"
 msgid "constructors may not be cv-qualified"
 msgstr "konstruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "destructors may not be ref-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "constructors may not be ref-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function `%s' in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "kan ikke definere vennefunktion '%s' i en lokal klassedefinition"
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "an explicit object member function cannot be %<static%>"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be a nonstatic member function"
 msgid "%qD cannot be an explicit object member function"
 msgstr "'%D' skal være en ikke-statisk medlemsfunktion"
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruktionsfunktioner må ikke have parametre"
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to `%#T'"
 msgid "cannot declare pointer to %q#T"
 msgstr "kan ikke erklære henvisning til '%#T'"
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to `%#T'"
 msgid "cannot declare reference to %q#T"
 msgstr "kan ikke erklære reference til '%#T'"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to `%#T' member"
 msgid "cannot declare pointer to %q#T member"
 msgstr "kan ikke erklære henvisning til medlemmet '%#T'"
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare references to references"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "kan ikke erklære referencer til referencer"
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' used as a declarator"
 msgid "template-id %qD used as a declarator"
 msgstr "skabelons-id '%D' benyttet som erklærer"
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "medlemsfunktioner er underforstået venner af deres klasse"
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification `%T::' on member `%s' ignored"
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "ekstra modifikation '%T::' af medlemmet '%s' ignoreret"
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%T::%s' within `%T'"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlemsfunktion '%T::%s' inde i '%T'"
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%T::%s' within `%T'"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlemsfunktion '%T::%s' inde i '%T'"
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member `%T::%s' within `%T'"
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlem '%T::%s' inde i '%T'"
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, fuzzy, gcc-internal-format
 #| msgid "data member may not have variably modified type `%T'"
 msgid "data member may not have variably modified type %qT"
 msgstr "datamedlem må ikke have variabelt ændret type '%T'"
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, fuzzy, gcc-internal-format
 #| msgid "parameter may not have variably modified type `%T'"
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter må ikke have variabelt ændret type '%T'"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "virtual angivet uden for klasseerklæring"
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, fuzzy, gcc-internal-format
 #| msgid "defining explicit specialization `%D' in friend declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "definering af eksplicit specialisering '%D' i friend-erklæring"
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be `explicit'"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "kun erklæringer af konstruktionsfunktioner kan være 'explicit'"
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, fuzzy, gcc-internal-format
 #| msgid "non-member `%s' cannot be declared `mutable'"
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "'%s' som ikke er medlem, kan ikke erklæres 'mutable'"
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, fuzzy, gcc-internal-format
 #| msgid "non-object member `%s' cannot be declared `mutable'"
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "'%s' som ikke er objektmedlem, kan ikke erklæres 'mutable'"
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "funktionen '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, fuzzy, gcc-internal-format
 #| msgid "static `%s' cannot be declared `mutable'"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "static '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "const `%s' cannot be declared `mutable'"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "const '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "referencen %qs kan ikke erklæres %<mutable%>"
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef erklæret %<auto%>"
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-navn kan ikke være en indlejret-navn-specifikation"
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ forbyder indlejret type %qD med samme navn som den omgivende klasse"
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> angivet for friend class-erklæring"
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend-erklæring kræver klasseangivelse, dvs. %<friend class %T::%D%>"
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend-erklæring kræver klasseangivelse, dvs. %<friend %#T%>"
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "forsøg på at gøre klassen %qT til ven af det globale virkningsfelt"
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ugyldige modifikationer for ikke-medlemsfunktionstype"
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, fuzzy, gcc-internal-format
 #| msgid "abstract declarator `%T' used as declaration"
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakt erklærer '%T' benyttet som erklæring"
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use `::' in parameter declaration"
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "kan ikke bruge '::' i parametererklæring"
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter `%D' to be of type `%T'"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "kan ikke erklære parameteren '%D' til at være af typen '%T'"
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter declared %<auto%>"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-name '%E' in a declarator"
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ugyldig brug af skabelonsnavn '%E' i erklæring"
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "'%T' har intet ikke-statisk medlem ved navn '%D'"
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C90 understøtter ikke fleksible tabelmedlemmer"
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 understøtter ikke fleksible tabelmedlemmer"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `::'"
 msgid "invalid use of %<::%>"
 msgstr "ugyldig brug af '::'"
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function `%#D' conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "erklæring af C-funktionen '%#D' strider mod"
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "funktionen '%D' erklæret virtual inden i en union"
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "'%D' kan ikke erklæres virtual eftersom den altid er statisk"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' shadows a member of `this'"
 msgid "declaration of %qD as member of %qT"
 msgstr "erklæring af '%s' skygger for et medlem af 'this'"
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a destructor cannot be %qs"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a constructor cannot be %<concept%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "kan ikke åbne %s"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "specialisering af underforstået erklæret speciel medlemsfunktion"
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "variabel eller felt erklæret void"
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "feltet '%D' er af en ufuldstændig type"
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, fuzzy, gcc-internal-format
 #| msgid "name `%T' has incomplete type"
 msgid "name %qT has incomplete type"
 msgstr "navnet '%T' er af en ufuldstændig type"
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is neither function nor member function; cannot be declared friend"
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "'%s' er hverken en almindelig funktion eller en medlemsfunktion; kan ikke erklæres som friend"
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "'%s' er hverken en almindelig funktion eller en medlemsfunktion; kan ikke erklæres som friend"
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "static data member %qE declared %qs"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "non-static data member %qE declared %qs"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `auto' invalid for function `%s'"
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "lagringsklassen 'auto' er ugyldig for funktionen '%s'"
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `register' invalid for function `%s'"
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "lagringsklassen 'register' er ugyldig for funktionen '%s'"
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `__thread' invalid for function `%s'"
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "lagringsklassen '__thread' er ugyldig for funktionen '%s'"
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `__thread' invalid for function `%s'"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "lagringsklassen '__thread' er ugyldig for funktionen '%s'"
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr "'%D' kan kun angives for funktioner"
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, fuzzy, gcc-internal-format
 #| msgid "type specifier `%s' not allowed after struct or class"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "typeangivelsen '%s' er ikke tilladt efter struct eller class"
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, fuzzy, gcc-internal-format
 #| msgid "virtual non-class function `%s'"
 msgid "virtual non-class function %qs"
 msgstr "virtuel funktion '%s' tilhører ikke en klasse"
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, fuzzy, gcc-internal-format
 #| msgid "method definition not in class context"
 msgid "%qs defined in a non-class scope"
 msgstr "metodedefinitionen optræder ikke i en klassekontekst"
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "%qs declared in a non-class scope"
 msgstr "using-erklæring for ikke-medlem ved klassevirkefelt"
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%D' to have static linkage"
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "kan ikke erklære medlemsfunktion '%D' til at have statisk kædning"
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "kan ikke erklære en funktion for static inden i en anden funktion"
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, fuzzy, gcc-internal-format
 #| msgid "`static' may not be used when defining (as opposed to declaring) a static data member"
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "'static' må ikke bruges ved definering (i modsætning til erklæring) af et statisk datamedlem"
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "static member %qD declared %<register%>"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, fuzzy, gcc-internal-format
 #| msgid "cannot explicitly declare member `%#D' to have extern linkage"
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "kan ikke eksplicit erklære medlemmet '%#D' til at have extern-kædning"
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' initialized and declared `extern'"
 msgid "%qs initialized and declared %<extern%>"
 msgstr "'%s' bliver tildelt en startværdi og er samtidig erklæret 'extern'"
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' has both `extern' and initializer"
 msgid "%qs has both %<extern%> and initializer"
 msgstr "'%s' er erklæret 'extern', men bliver tildelt en startværdi"
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, fuzzy, gcc-internal-format
 #| msgid "default argument `%E' uses local variable `%D'"
 msgid "default argument %qE uses %qD"
 msgstr "standardparameter '%E' bruger lokal variabel '%D'"
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, fuzzy, gcc-internal-format
 #| msgid "default argument `%E' uses local variable `%D'"
 msgid "default argument %qE uses local variable %qD"
 msgstr "standardparameter '%E' bruger lokal variabel '%D'"
 
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `virtual' in template declaration of `%#D'"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ugyldig brug af 'virtual' i skabelonserklæring af '%#D'"
 
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-name '%E' in a declarator"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "ugyldig brug af skabelonsnavn '%E' i erklæring"
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "ugyldig parametertype '%T'"
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' invalidly declared method type"
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameteren '%D' er på ugyldig vis erklæret som af en medlemsfunktionstype"
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' includes %s to array of unknown bound `%T'"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameteren '%D' inkluderer %s til tabel med ukendt grænse '%T'"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' includes %s to array of unknown bound `%T'"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parameteren '%D' inkluderer %s til tabel med ukendt grænse '%T'"
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constructor; you probably meant `%T (const %T&)'"
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ugyldig konstruktionsfunktion; du mente sandsynligvis '%T (const %T&)'"
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "%qD may not be declared within a namespace"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "'%D' skal være en ikke-statisk medlemsfunktion"
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be a nonstatic member function"
 msgid "%qD must be a member function"
 msgstr "'%D' skal være en ikke-statisk medlemsfunktion"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers only available with -std=c++11 or -std=gnu++11"
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "ikkestatisk datamedlemsstartværdier er kun tilgængelige med -std=c++11 eller -std=gnu++11"
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be either a non-static member function or a non-member function"
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "'%D' skal enten være en ikke-statisk medlemsfunktion eller ikke en medlemsfunktion"
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must have an argument of class or enumerated type"
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "'%D' skal have en parameter af en klasse- eller enum-type"
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ forbyder flertydiggørelse af operatoren ?:"
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qD must not have variable number of arguments"
 msgstr "'%D' skal tage mod én eller to parametre"
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "'%D' skal tage mod nul eller én parameter"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "'%D' skal tage mod én eller to parametre"
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' must take `int' as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfiks '%D' skal tage mod 'int' som parameter"
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' must take `int' as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfiks '%D' skal tage mod 'int' som den anden parameter"
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "'%s' skal tage mod to parametre"
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "'%s' skal tage mod én parameter"
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "'%s' skal tage mod to parametre"
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "%qD cannot have default arguments"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined `%D' always evaluates both arguments"
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "brugerdefineret '%D' evaluerer altid begge parametre"
 
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, fuzzy, gcc-internal-format
 #| msgid "prefix `%D' should return `%T'"
 msgid "prefix %qD should return %qT"
 msgstr "præfiks '%D' skal returnere '%T'"
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' should return `%T'"
 msgid "postfix %qD should return %qT"
 msgstr "postfiks '%D' skal returnere '%T'"
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' should return by value"
 msgid "%qD should return by value"
 msgstr "'%D' skal returnere pr. værdi (ikke reference)"
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter `%T' after `%s'"
 msgid "using template type parameter %qT after %qs"
 msgstr "bruger skabelonstypeparameter '%D' efter '%s'"
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization `%D' for `%+D'"
 msgid "using alias template specialization %qT after %qs"
 msgstr "tvetydig skabelonsspecialisering '%D' for '%+D'"
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, fuzzy, gcc-internal-format
 #| msgid "using typedef-name `%D' after `%s'"
 msgid "using typedef-name %qD after %qs"
 msgstr "bruger typedef-navn '%D' efter '%s'"
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "tidligere erklæring som '%#D'"
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "'%#D' omerklæret som %C"
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "dette er en tidligere erklæring"
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "'%#D' omerklæret som %C"
@@ -63025,127 +63033,109 @@ msgstr "'%#D' omerklæret som %C"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, fuzzy, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qT is not a template"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, fuzzy, gcc-internal-format
 #| msgid "use of enum `%#D' without previous declaration"
 msgid "use of enum %q#D without previous declaration"
 msgstr "brug af enum '%#D' uden tidligere erklæring"
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration `%#D' declares a non-template function"
 msgid "redeclaration of %qT as a non-template"
 msgstr "friend-erklæring '%#D' erklærer en ikke-skabelonsfunktion"
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare `%D' to be a bit-field type"
-msgid "cannot declare %qD in a different module"
-msgstr "kan ikke erklære '%D' til at være en bitfeltstype"
-
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, fuzzy, gcc-internal-format
-#| msgid "`%s' previously declared here"
-msgid "previously declared here"
-msgstr "'%s' tidligere erklæret her"
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, fuzzy, gcc-internal-format
 #| msgid "derived union `%T' invalid"
 msgid "derived union %qT invalid"
 msgstr "nedarvet union '%T' ugyldig"
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in the class %T"
 msgid "%qT defined with multiple direct bases"
 msgstr "'%D' er allerede defineret i klassen '%T'"
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, fuzzy, gcc-internal-format
 #| msgid "type `%D' is not a direct or virtual base of `%T'"
 msgid "%qT defined with direct virtual base"
 msgstr "typen '%D' er ikke en direkte eller en virtuel stamklasse til '%T'"
 
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, fuzzy, gcc-internal-format
 #| msgid "base type `%T' fails to be a struct or class type"
 msgid "base type %qT fails to be a struct or class type"
 msgstr "stamklassetype '%T' er hverken en struct- eller class-type"
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, fuzzy, gcc-internal-format
 #| msgid "recursive type `%T' undefined"
 msgid "recursive type %qT undefined"
 msgstr "rekursiv type '%T' ikke defineret"
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate base type `%T' invalid"
 msgid "duplicate base type %qT invalid"
 msgstr "stamklassetype '%T' optræder mere end én gang"
 
-#: cp/decl.cc:16984
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare %s to references"
-msgid "cannot declare %qD in different module"
-msgstr "kan ikke erklære %s til referencer"
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "tidligere definition her"
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -63155,93 +63145,93 @@ msgstr "parameter til '%s' skal være en 2 bit-konstant"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of `int'"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C begrænser enum-værdier til rækkevidden af 'int'"
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in enumeration values at `%D'"
 msgid "overflow in enumeration values at %qD"
 msgstr "enum-værdier for store ved '%D'"
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "flere definitioner af %q#T"
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, fuzzy, gcc-internal-format
 #| msgid "return type `%#T' is incomplete"
 msgid "return type %q#T is incomplete"
 msgstr "returtype '%#T' er ufuldstændig"
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, fuzzy, gcc-internal-format
 #| msgid "`operator=' should return a reference to `*this'"
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "'operator=' bør returnere en reference til '*this'"
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in class `%T'"
 msgid "%qD is already defined in class %qT"
 msgstr "'%D' er allerede defineret i klassen '%T'"
 
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "using %qs"
 msgstr "fejl ved lukning af %s: %m"
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -63301,7 +63291,7 @@ msgstr "kan ikke udføre delete på en funktion; kun henvisninger til objekter e
 msgid "deleting %qT is undefined"
 msgstr "benyttelse af delete på '%T' er ikke defineret"
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "template declaration of %q#D"
@@ -63313,7 +63303,7 @@ msgstr "skabelonserklæring af '%#D'"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, fuzzy, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
@@ -63525,65 +63515,65 @@ msgstr "destruktionsfunktioner skal være medlemmer"
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "den første parameter til 'operator delete' skal være af typen '%T'"
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr ""
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, gcc-internal-format
 msgid "%qT has a base %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, gcc-internal-format
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, gcc-internal-format
 msgid "%qT has a base %qT which has internal linkage"
 msgstr ""
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, gcc-internal-format
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%F' declared `static' but never defined"
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr "%J'%F' erklæret 'static', men aldrig defineret"
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%F' declared `static' but never defined"
 msgid "%q#D, declared using an unnamed type, is used but not defined"
@@ -63593,118 +63583,118 @@ msgstr "%J'%F' erklæret 'static', men aldrig defineret"
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%#D' with %L linkage"
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "tidligere erklæring af '%#D' med %L-kædning"
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%#D' with %L linkage"
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "tidligere erklæring af '%#D' med %L-kædning"
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "'%#D' refererer ikke til den ikkemodificerede type, so den bruges ikke til sammenkædning"
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%F' declared `static' but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%J'%F' erklæret 'static', men aldrig defineret"
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%F' declared `static' but never defined"
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr "%J'%F' erklæret 'static', men aldrig defineret"
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%#D' with %L linkage"
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "tidligere erklæring af '%#D' med %L-kædning"
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "strider mod tidligere erklæring '%#D'"
 
 # hænger sammen med næste tekst
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous mangling %q#D"
 msgstr "tidligere erklæring '%D'"
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, gcc-internal-format
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, fuzzy, gcc-internal-format
 #| msgid "inline function `%D' used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "indbygget funktion '%D' benyttet, men aldrig defineret"
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, fuzzy, gcc-internal-format
 #| msgid "default argument missing for parameter %P of `%+#D'"
 msgid "default argument missing for parameter %P of %q#D"
 msgstr "standardparameter mangler for parameter %P  i '%+#D'"
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "...following parameter %P which has a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, fuzzy, gcc-internal-format
 #| msgid "class %qE is deprecated"
 msgid "implicitly-declared %qD is deprecated"
 msgstr "klassen %qE er forældet"
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "konverterer NULL til en ikke-henvisningstype"
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "use of deleted function %qD"
 msgstr "sizeof benyttet på en funktionstype"
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, fuzzy, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, fuzzy, gcc-internal-format
 #| msgid "use of template qualifier outside template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -63827,7 +63817,7 @@ msgstr "brug af '%D' er tvetydigt"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of `%T'"
 msgid "%qD is not a member of %qT"
@@ -63839,7 +63829,7 @@ msgstr "'%D' er ikke et medlem af '%T'"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "'%D' er ikke et medlem af '%T'"
@@ -63865,53 +63855,53 @@ msgstr "håndtering af undtagelser er slået fra, angiv -fexceptions for at slå
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr "kaster NULL som har en heltals-, ikke en henvisningstype"
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, gcc-internal-format
 msgid "  in thrown expression"
 msgstr "  i kastet udtryk"
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter `%D' to be of type `%T'"
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr "kan ikke erklære parameteren '%D' til at være af typen '%T'"
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create type information for type `%T' because its size is variable"
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr "kan ikke oprette typeinformation for typen '%T' fordi dens størrelse er variabel"
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create type information for type `%T' because its size is variable"
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr "kan ikke oprette typeinformation for typen '%T' fordi dens størrelse er variabel"
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, fuzzy, gcc-internal-format
 #| msgid "exception of type `%T' will be caught"
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr "undtagelse af typen '%T' vil blive fanget"
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, fuzzy, gcc-internal-format
 #| msgid "operand is r0"
 msgid "for type %qT"
 msgstr "operanden er r0"
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, fuzzy, gcc-internal-format
 #| msgid "`...' handler must be the last handler for its try block"
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr "håndteringen '...' skal være den sidste håndtering i try-blokken"
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr ""
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
 msgstr ""
@@ -64217,12 +64207,12 @@ msgstr "typen '%D' er ikke en direkte eller en virtuel stamklasse til '%T'"
 msgid "type %qT is not a direct base of %qT"
 msgstr "typen '%D' er ikke en direkte stamklasse til '%T'"
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or union type"
 msgid "%qT is not a class type"
@@ -64240,12 +64230,12 @@ msgstr "ufuldstændig type '%T' har ikke medlemmet '%D'"
 msgid "invalid pointer to bit-field %qD"
 msgstr "ugyldig henvisning til bitfeltet '%D'"
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
@@ -64450,54 +64440,54 @@ msgstr ""
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to references"
 msgid "cannot capture %qE by reference"
 msgstr "kan ikke erklære %s til referencer"
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "capture by copy of incomplete type %qT"
 msgstr "kan ikke %s en henvisning til en ufuldstændig type '%T'"
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr ""
@@ -64903,240 +64893,291 @@ msgstr "forventet skabelon-id for typen"
 msgid "encapsulation is malformed"
 msgstr ""
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, fuzzy, gcc-internal-format
 msgid "conflicting global module declaration %#qD"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "existing declaration %#qD"
 msgstr "i erklæringen '%D'"
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, fuzzy, gcc-internal-format
 #| msgid "extern declaration of `%#D' doesn't match"
 msgid "definition of %qD does not match"
 msgstr "extern-erklæring af '%#D' passer ikke med"
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "existing definition %qD"
 msgstr "manglende startværdi"
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of `enum %s'"
 msgid "... this enumerator %qD"
 msgstr "omerklæring af 'enum %s'"
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, fuzzy, gcc-internal-format
 #| msgid "extern declaration of `%#D' doesn't match"
 msgid "enumerator %qD does not match ..."
 msgstr "extern-erklæring af '%#D' passer ikke med"
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr ""
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr ""
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr ""
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "recursive lazy load"
 msgstr "omdefinering af standardparameter for '%#D'"
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr ""
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "module %qs declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of voids"
 msgid "indirect import %qs is not already loaded"
 msgstr "'%s' erklæret som en tabel af void"
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr ""
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr ""
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, fuzzy, gcc-internal-format
 msgid "macro definitions of %qE corrupted"
 msgstr "tidligere definition her"
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, fuzzy, gcc-internal-format
 #| msgid "inconsistent instance variable specification"
 msgid "inconsistent imported macro definition %qE"
 msgstr "inkonsistent instansvariabelangivelse"
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr ""
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr ""
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file `%s': %s\n"
 msgid "compiled module file is %qs"
 msgstr "%s: kan ikke slette filen '%s': %s\n"
 
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Display the compiler's version"
 msgid "compiled module is %sversion %s"
 msgstr "Vis oversætterens version"
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collect2 version %s\n"
 msgid "compiler is %sversion %s%s%s"
 msgstr "collect2-version %s\n"
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, fuzzy, gcc-internal-format
 #| msgid "no symbol table found"
 msgid "module %qs found"
 msgstr "ingen symboltabel fundet"
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr ""
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr ""
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr ""
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr ""
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, gcc-internal-format
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr ""
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, fuzzy, gcc-internal-format
 #| msgid "function attribute mismatch"
 msgid "fixed tree mismatch"
 msgstr "forskellige funktionsattributter"
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "interface partition is not exported"
 msgstr "stakgrænseudtryk understøttes ikke"
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module cluster %u: %s"
 msgstr ""
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "failed to read compiled module: %s"
 msgstr "kunne ikke finde klassen '%s'"
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr ""
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr ""
 
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr ""
 
-#: cp/module.cc:19283
+#: cp/module.cc:19117
+#, fuzzy, gcc-internal-format
+#| msgid "conflicts with built-in declaration `%#D'"
+msgid "declaration %qD conflicts with builtin"
+msgstr "strider mod indbygget erklæring '%#D'"
+
+#: cp/module.cc:19122
+#, fuzzy, gcc-internal-format
+#| msgid "asm declaration conflicts with previous rename"
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr "asm-erklæring er i konflikt med tidligere omdøbelse"
+
+#: cp/module.cc:19125
+#, gcc-internal-format
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr ""
+
+#: cp/module.cc:19130
+#, gcc-internal-format
+msgid "import declared attached to module %qs"
+msgstr ""
+
+#: cp/module.cc:19134
+#, gcc-internal-format
+msgid "import declared in global module"
+msgstr ""
+
+#: cp/module.cc:19140
+#, fuzzy, gcc-internal-format
+#| msgid "declaration of template `%#D'"
+msgid "conflicting declaration of %qD in module %qs"
+msgstr "erklæring af skabelon '%#D'"
+
+#: cp/module.cc:19143
+#, fuzzy, gcc-internal-format
+#| msgid "conflicts with new declaration with %L linkage"
+msgid "conflicting declaration of %qD in global module"
+msgstr "strider mod ny erklæring af med %L-kædning"
+
+#: cp/module.cc:19148
+#, fuzzy, gcc-internal-format
+#| msgid "`%s' previously declared here"
+msgid "previously declared in module %qs"
+msgstr "'%s' tidligere erklæret her"
+
+#: cp/module.cc:19152
+#, fuzzy, gcc-internal-format
+#| msgid "`%s' previously declared here"
+msgid "previously declared in global module"
+msgstr "'%s' tidligere erklæret her"
+
+#: cp/module.cc:19404
 #, fuzzy, gcc-internal-format
 #| msgid "creating %s"
 msgid "reading CMI %qs"
 msgstr "opretter %s"
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, gcc-internal-format
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown cpu: -mcpu=%s"
 msgid "during load of pendings for %<%E%s%E%>"
@@ -65149,432 +65190,432 @@ msgstr "Ukendt processor: -mcpu=%s"
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr ""
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, fuzzy, gcc-internal-format
 #| msgid "Symbols have a leading underscore"
 msgid "module already declared"
 msgstr "Symboler har en indledende understreg"
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, fuzzy, gcc-internal-format
 #| msgid "Symbols have a leading underscore"
 msgid "module already imported"
 msgstr "Symboler har en indledende understreg"
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "module %qs imported here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown punctuation '%c'"
 msgid "unknown Compiled Module Interface: %s"
 msgstr "ukendt tegnsætning »%c«"
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr ""
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr ""
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr ""
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, fuzzy, gcc-internal-format
 #| msgid "while writing precompiled header"
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr "under skrivning af præoversat inkluderingsfil"
 
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, fuzzy, gcc-internal-format
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr "Aktivér stakprøvning"
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr ""
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr ""
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the Xtensa SEXT option"
 msgid "you should use the %<-%s%> option"
 msgstr "Benyt ikke Xtensa-SEXT-indstillingen"
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid header name %qs"
 msgstr "ugyldig »--param«-værdi %qs"
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, fuzzy, gcc-internal-format
 #| msgid "invalid macro name `%s'"
 msgid "invalid module name %qs"
 msgstr "ugyldigt makronavn '%s'"
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr ""
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, fuzzy, gcc-internal-format
 msgid "writing CMI %qs"
 msgstr "fejl ved skrivning til %s"
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, fuzzy, gcc-internal-format
 msgid "not writing module %qs due to errors"
 msgstr "Fejl ved skrivning af uddatafilen %s.\n"
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "failed to write compiled module: %s"
 msgstr "kunne ikke finde klassen '%s'"
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown header kind %qs"
 msgstr "ukendt registernavn: %s"
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "strider mod tidligere erklæring '%#D'"
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' hides constructor for `%#T'"
 msgid "%q#D hides constructor for %q#D"
 msgstr "'%#D' skjuler konstruktionsfunktion for '%#T'"
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, fuzzy, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "Generér ikke kode til at kontrollere undtagelsesspecifikationer"
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' invalidly declared method type"
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "parameteren '%D' er på ugyldig vis erklæret som af en medlemsfunktionstype"
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "declaration of %q#D shadows a parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' shadows a member of `this'"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "erklæring af '%s' skygger for et medlem af 'this'"
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, fuzzy, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, gcc-internal-format
 msgid "exporting %q#D that does not have external linkage"
 msgstr ""
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%q#D declared here with no linkage"
 msgstr "  '%#D' erklæret her"
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared here (not in a function)"
 msgid "%q#D declared here with internal linkage"
 msgstr "'%s' ikke erklæret her (ikke i en funktion)"
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%q#D declared here with module linkage"
 msgstr "  '%#D' erklæret her"
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' names constructor"
 msgid "%<%T%s%D%> names destructor"
 msgstr "'%D' navngiver en konstruktionsfunktion"
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "using-erklæring for ikke-medlem ved klassevirkefelt"
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, fuzzy, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "using-erklæring for destruktionsfunktion"
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "using-erklæring for ikke-medlem ved klassevirkefelt"
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, fuzzy, gcc-internal-format
 #| msgid "type `%D' is not a direct base of `%T'"
 msgid "%qT is not a direct base of %qT"
 msgstr "typen '%D' er ikke en direkte stamklasse til '%T'"
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "using-erklæring for destruktionsfunktion"
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' names constructor"
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "'%D' navngiver en konstruktionsfunktion"
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' not in a namespace surrounding `%D'"
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "erklæring af '%D' er ikke i et navnerum der omgiver '%D'"
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate type qualifiers in %s declaration"
 msgid "explicit qualification in declaration of %qD"
 msgstr "dobbelte typemodifikationer i %s-erklæring"
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' should have been declared inside `%D'"
 msgid "%qD should have been declared inside %qD"
 msgstr "'%D' skulle have været erklæret inden i '%D'"
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "egenskabsdirektivet '%s' ignoreret"
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr ""
 
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' cannot be declared"
 msgid "the macro %qs had not yet been defined"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "it was later defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, fuzzy, gcc-internal-format
 #| msgid "switch \"%s\" is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "tilvalget '%s' understøttes ikke længere"
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, fuzzy, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, fuzzy, gcc-internal-format
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "cannot nest more than %d namespaces"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%D' is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, fuzzy, gcc-internal-format
 #| msgid "namespace alias `%D' not allowed here, assuming `%D'"
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "navnerumsalias '%D' er ikke tilladt her, antager '%D'"
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "%qD defined here"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' conflicts with previous using declaration `%#D'"
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "'%#D' strider mod tidligere using-erklæring '%#D'"
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "tidligere definition her"
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -65600,7 +65641,7 @@ msgstr "kaldenavnet '%s' er i modstrid med den interne navngivningsstrategi i GN
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
@@ -65869,7 +65910,7 @@ msgstr "skabelonsparameter %d er ugyldig"
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
@@ -66064,7 +66105,7 @@ msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "expected primary-expression"
@@ -66123,7 +66164,7 @@ msgstr "skabelonsparameter %d er ugyldig"
 msgid "template-id not allowed for destructor in C++20"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, gcc-internal-format
 msgid "remove the %qs"
 msgstr ""
@@ -66144,7 +66185,7 @@ msgstr "skabelons-id '%D' benyttet som erklærer"
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD is not a template"
@@ -66197,7 +66238,7 @@ msgstr "new kan ikke bruges på en referencetype"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to bit-complement"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -66235,7 +66276,7 @@ msgstr "new kan ikke bruges på en referencetype"
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr ""
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of %qD"
@@ -66262,7 +66303,7 @@ msgstr "ISO C++ tillader ikke %<alignof%> med en ikke-type"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in a new-expression"
 msgid "types may not be defined in %qs expressions"
@@ -66427,8 +66468,8 @@ msgstr "en startværdi der ikke er tom, tildeles til en tabel med tomme elemente
 msgid "capture of non-variable %qE"
 msgstr "%s af variablen '%s' der kun må læses"
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%q#D declared here"
@@ -66473,7 +66514,7 @@ msgstr "standardparameter givet til %d. parameter for '%#D'"
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr ""
@@ -66613,7 +66654,7 @@ msgstr "ugyldig venstreværdi i asm-sætning"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected selection-statement"
@@ -66682,7 +66723,7 @@ msgstr "udtrykket er af en ufuldstændig type"
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "uventet operand"
@@ -66711,7 +66752,7 @@ msgstr "skabelonsparameter %d er ugyldig"
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ forbyder beregnede goto'er"
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "uventet operand"
@@ -67016,12 +67057,12 @@ msgstr "kun konstruktionsfunktioner har stamklasseklargøringer"
 msgid "cannot expand initializer for member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -67720,7 +67761,7 @@ msgstr "skabelonsparameter er påkrævet for '%T'"
 msgid "%qT not permitted in template argument"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%T'"
@@ -67912,12 +67953,12 @@ msgstr "tidligere definition af '%#T'"
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, gcc-internal-format
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr ""
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "uventet operand"
@@ -68134,40 +68175,40 @@ msgstr "skabelonsparameter %d er ugyldig"
 msgid "expression must be enclosed in parentheses"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr ""
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, fuzzy, gcc-internal-format
 #| msgid "asm template is not a string constant"
 msgid "result type is not a plain type-constraint"
 msgstr "asm-sætning er ikke en strengkonstant"
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "angivet justering er ikke en konstant"
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of `%D'"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ugyldig omerklæring af '%D'"
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
@@ -68176,464 +68217,464 @@ msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, fuzzy, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "for mange skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "template-id not allowed for constructor in C++20"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "--driver understøttes ikke længere"
 
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for `%D' found"
 msgid "no matching concept for template-introduction"
 msgstr "ingen passende skabelon for '%D' fundet"
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, fuzzy, gcc-internal-format
 #| msgid "invalid declaration of member template `%#D' in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "ugyldig erklæring af medlemsskabelon '%#D' i lokal klasse"
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "skabelon med C-kædning"
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization here"
 msgid "invalid explicit specialization"
 msgstr "eksplicit specialisering her"
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "template declaration of %<typedef%>"
 msgstr "skabelonserklæring af '%#D'"
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "erklæring erklærer ikke noget"
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization here"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "eksplicit specialisering her"
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "'>>' skulle have været '> >' i skabelonsklassenavn"
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, fuzzy, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "'>>' skulle have været '> >' i skabelonsklassenavn"
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, fuzzy, gcc-internal-format
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr "'>>' skulle have været '> >' i skabelonsklassenavn"
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "ugyldig stamklasseangivelse"
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "duplicate %qD specifier"
 msgstr "mere end én 'virtual'-angivelse"
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, fuzzy, gcc-internal-format
 #| msgid "section type conflict with %qD"
 msgid "%qD specifier conflicts with %qs"
 msgstr "afsnitstypekonflikt med %qD"
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> før %qD"
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr "%s brugt med '%%%c' %s-formatering"
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 understøtter ikke %<long long%>"
 
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "duplikere %qD"
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "duplikere %qs"
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "forventede %<new%>"
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "forventede %<delete%>"
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "forventede %<return%>"
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "forventede %<extern%>"
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "forventede %<static_assert%>"
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "forventede %<decltype%>"
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "forventede %<operator%>"
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "forventede %<class%>"
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "forventede %<template%>"
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "forventede %<namespace%>"
 
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "forventede %<using%>"
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "forventede %<asm%>"
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "forventede %<try%>"
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "forventede %<catch%>"
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "forventede %<throw%>"
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<auto%>"
 msgstr "forventede %<catch%>"
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "forventede %<__label__%>"
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "forventede %<@try%>"
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "forventede %<@synchronized%>"
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "forventede %<@throw%>"
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "forventede %<__transaction_atomic%>"
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "forventede %<__transaction_relaxed%>"
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "%<@end%> forventet"
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "forventede %<::%>"
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "forventede %<...%>"
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "forventede %<*%>"
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "forventede %<~%>"
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "forventede %<:%> or %<::%>"
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' tag used in naming `%#T'"
 msgid "%qs tag used in naming %q#T"
 msgstr "'%s'-mærke benyttet i navngivning af '%#T'"
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T var tidligere erklæret her"
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to `%#T'"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "kan ikke erklære reference til '%#T'"
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "'%D' ikke erklæret"
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "uventet operand"
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "%qT defined as %qs here"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, fuzzy, gcc-internal-format
 #| msgid "  first declared as `%#D' here"
 msgid "%qT first declared as %qs here"
 msgstr "  først erklæret som '%#D' her"
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD omerklæret med anden adgang"
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "%Hslutningen af filen læst inden i standardparameter"
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, fuzzy, gcc-internal-format
 #| msgid "Class or interface declaration expected"
 msgid "objective-c++ method declaration is expected"
 msgstr "Klasse- eller grænsefladeerklæring forventet"
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name `%s' for register variable"
 msgid "invalid type for instance variable"
 msgstr "ugyldigt registernavn '%s' for registervariabel"
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, fuzzy, gcc-internal-format
 #| msgid "Identifier expected"
 msgid "identifier expected after %<@protocol%>"
 msgstr "Kaldenavn forventet"
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "'%s'-egenskaben ignoreret for '%s'"
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "ugyldig typeparameter"
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown property attribute %qE"
 msgstr "ukendt registernavn: %s"
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "expected integer expression list"
 msgstr "uventet adresseudtryk"
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid identifier `%s'"
 msgid "invalid reduction-identifier"
 msgstr "ugyldigt kaldenavn '%s'"
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "new kan ikke bruges på en referencetype"
@@ -68642,13 +68683,13 @@ msgstr "new kan ikke bruges på en referencetype"
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma vtable no longer supported"
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "'#pragma vtable' understøttes ikke længere"
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
@@ -68658,140 +68699,140 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "typedef-navn kan ikke klassemodificeres"
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "iteration variable %qD should not be reduction"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr ""
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr ""
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "ugyldig startværdi"
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected side-effects in address"
 msgid "expected id-expression (arguments)"
 msgstr "uventede bivirkninger i adresse"
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a global declaration"
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "erklæring af '%s' skygger for en global erklæring"
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma map, ignored"
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "forkert udformet '#pragma map' - ignoreret"
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, fuzzy, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr "profilering understøttes ikke endnu"
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, fuzzy, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -68824,7 +68865,7 @@ msgstr "omgivende klasseskabeloner er ikke eksplicit specialiserede"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "specialisering af %qD skal fremstå ved navnerumsanvendelsesområde"
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "specialisering af %qD i andet navnerum"
@@ -68841,31 +68882,31 @@ msgstr "  i forhold til definition af %q#D"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "ugyldig brug af skabelonstypeparameter"
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "specialization of alias template %qD"
 msgstr "erklæring af skabelon '%#D'"
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template `%T'"
 msgid "explicit specialization of non-template %qT"
 msgstr "eksplicit specialisering af '%T' der ikke er en skabelon"
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of `%T' after instantiation"
 msgid "specialization of %qT after instantiation"
 msgstr "specialisering af '%T' efter instantiering"
 
 # hænger sammen med foregående tekst, derfor ikke 'fra'
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q#D"
 msgid "from definition of %q#D"
@@ -68873,162 +68914,162 @@ msgstr "  i forhold til definition af %q#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, fuzzy, gcc-internal-format
 #| msgid "specialization `%T' after instantiation `%T'"
 msgid "specialization %qT after instantiation %qT"
 msgstr "specialisering af '%T' efter instantiering '%T'"
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, fuzzy, gcc-internal-format
 #| msgid "template specialization with C linkage"
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "skabelonsspecialisering med C-kædning"
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "specialization of %qD after instantiation"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%qD is not a function template"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD is not a variable template"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization `%D' for `%+D'"
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "tvetydig skabelonsspecialisering '%D' for '%+D'"
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %D after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "eksplicit specialisering af %D efter første brug"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %D after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "eksplicit specialisering af %D efter første brug"
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' in declaration of primary template"
 msgid "template-id %qE in declaration of primary template"
 msgstr "skabelons-id '%D' i erklæring af primær skabelon"
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "skabelonsparameterliste benyttet i eksplicit instantiering"
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "definition angivet for eksplicit instantiering"
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of `%D'"
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "for mange skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, fuzzy, gcc-internal-format
 #| msgid "too few template parameter lists in declaration of `%D'"
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "eksplicit specialisering følger ikke efter 'template <>'"
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template `%T'"
 msgid "explicit specialization declared %<concept%>"
 msgstr "eksplicit specialisering af '%T' der ikke er en skabelon"
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%D' of function template"
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "partiel specialisering '%D' af funktionsskabelon"
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%D' of function template"
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "partiel specialisering '%D' af funktionsskabelon"
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "standardparameter angivet i eksplicit specialisering"
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD is not a template function"
@@ -69042,157 +69083,157 @@ msgstr "'%D' er ikke en medlemsskabelonfunktion"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "specialisering af underforstået erklæret speciel medlemsfunktion"
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, fuzzy, gcc-internal-format
 #| msgid "no member function `%D' declared in `%T'"
 msgid "no member function %qD declared in %qT"
 msgstr "ingen medlemsfunktion '%D' erklæret i '%T'"
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
 msgid "friend declaration here"
 msgstr "tidligere erklæring af '%#D' her"
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template `%T'"
 msgid "explicit specialization of function concept %qD"
 msgstr "eksplicit specialisering af '%T' der ikke er en skabelon"
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, fuzzy, gcc-internal-format
 #| msgid "        `%D'"
 msgid "        %qD"
 msgstr "        '%D'"
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "        `%D'"
 msgid "        %s"
 msgstr "        '%D'"
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type `%T' declared `friend'"
 msgid "template parameter %qD declared here"
 msgstr "skabelonsparametertypen '%T' erklæret 'friend'"
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "specialization of variable concept %q#D"
 msgstr "erklæring af skabelon '%#D'"
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "skabelonsparametre der ikke bruges i partiel specialisering:"
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%T' does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "den partielle specialisering '%T' specialiserer ikke nogen skabelonsparametre"
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%T' does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "den partielle specialisering '%T' specialiserer ikke nogen skabelonsparametre"
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments for partial specialization %qT"
 msgstr "for mange parametre til funktionen"
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%T' does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "den partielle specialisering '%T' specialiserer ikke nogen skabelonsparametre"
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%D'"
 msgid "primary template %qD"
 msgstr "etiketten '%D' optræder mere end én gang"
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
 # flertalsform unødvendig
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, fuzzy, gcc-internal-format
 #| msgid "type `%T' of template argument `%E' depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -69200,19 +69241,19 @@ msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "typen '%T' af skabelonsparameteren '%E' afhænger af skabelonsparameter"
 msgstr[1] "typen '%T' af skabelonsparameteren '%E' afhænger af skabelonsparameter"
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, fuzzy, gcc-internal-format
 #| msgid "no default argument for `%D'"
 msgid "no default argument for %qD"
@@ -69222,53 +69263,53 @@ msgstr "ingen standardparameter til '%D'"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "skabelonsparametre der ikke bruges i partiel specialisering:"
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type `%T' has type `%T'"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "standardparameter for parameter af typen '%T' har typen '%T'"
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "template %qD declared"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "skabelonsklasse uden et navn"
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -69278,71 +69319,71 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "invalid template declaration of %qD"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, fuzzy, gcc-internal-format
 #| msgid "template definition of non-template `%#D'"
 msgid "template definition of non-template %q#D"
 msgstr "skabelonsdefinition af ikke-skabelon '%#D'"
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, fuzzy, gcc-internal-format
 #| msgid "expected %d levels of template parms for `%#D', got %d"
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "forvented %d niveauer af skabelonsparametre for '%#D', modtog %d"
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#D'"
 msgid "got %d template parameters for %q#D"
 msgstr "modtog %d skabelonsparametre for '%#D'"
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#T'"
 msgid "got %d template parameters for %q#T"
 msgstr "modtog %d skabelonsparametre for '%#T'"
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  men %d påkrævet"
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "omgivende klasseskabeloner er ikke eksplicit specialiserede"
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD with different constraints"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template type"
 msgid "%qT is not a template type"
 msgstr "'%T' er ikke en skabelonstype"
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, fuzzy, gcc-internal-format
 #| msgid "too few template parameter lists in declaration of `%D'"
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -69350,7 +69391,7 @@ msgid_plural "redeclared with %d template parameters"
 msgstr[0] "'%D' benyttet uden skabelonsparametre"
 msgstr[1] "'%D' benyttet uden skabelonsparametre"
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
 msgid "previous declaration %qD used %d template parameter"
@@ -69358,496 +69399,496 @@ msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "tidligere erklæring af '%#D' her"
 msgstr[1] "tidligere erklæring af '%#D' her"
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter `%#D'"
 msgid "template parameter %q+#D"
 msgstr "skabelonsparameter '%#D'"
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as `%#D'"
 msgid "redeclared here as %q#D"
 msgstr "omerklæret her som '%#D'"
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "redeclared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "  oprindelig definition er her"
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D with different constraints"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "den skal være adressen af en funktion med ekstern kædning"
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "den skal være adressen af en funktion med ekstern kædning"
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, fuzzy, gcc-internal-format
 #| msgid "it must be a pointer-to-member of the form `&X::Y'"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "den skal være en henvisning til medlem på formen '&X::Y'"
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of `%T'"
 msgid "because it is a member of %qT"
 msgstr "'%D' er ikke et medlem af '%T'"
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#D'"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "modtog %d skabelonsparametre for '%#D'"
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types `%#T' and `%#T'"
 msgid "  mismatched types %qT and %qT"
 msgstr "sammenligning mellem typerne '%#T' og '%#T'"
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
 # flertalsform unødvendig
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "skabelonsparameter '%E' involverer skabelonsparameter"
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type `%T' to type `%T'"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "kan ikke konvertere typen '%T' til typen '%T'"
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is an ambiguous base of `%T'"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "'%T' er en tvetydig stamklasse til '%T'"
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, fuzzy, gcc-internal-format
 #| msgid "type `%T' is not derived from type `%T'"
 msgid "  %qT is not derived from %qT"
 msgstr "typen '%T' er ikke nedarvet fra typen '%T'"
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "kan ikke %s en henvisning til en ufuldstændig type '%T'"
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "  template argument %qE does not match %qE"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "the address of %qD is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring attributes in template argument %qE"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of destructor %qE as a type"
 msgstr "ugyldig brug af 'restrict'"
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, fuzzy, gcc-internal-format
 #| msgid "to refer to a type member of a template parameter, use `typename %E'"
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "benyt 'typename %E' for at referere til et typemedlem af en skabelonsparameter"
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a constant of type `%T', got `%T'"
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  forventede en konstant af typen '%T', modtog '%T'"
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type `%T' has type `%T'"
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "standardparameter for parameter af typen '%T' har typen '%T'"
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  forventede en klasseskabelon, modtog '%T'"
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%E'"
 msgid "  expected a type, got %qE"
 msgstr "  forventede en type, modtog '%E'"
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%T'"
 msgid "  expected a type, got %qT"
 msgstr "  forventede en type, modtog '%T'"
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a class template, got `%T'"
 msgid "  expected a class template, got %qT"
 msgstr "  forventede en klasseskabelon, modtog '%T'"
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type `%D', got `%D'"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  forventede en skabelon af typen '%D', modtog '%D'"
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%E'"
 msgid "  expected %qD but got %qD"
 msgstr "  forventede en type, modtog '%E'"
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument `%E' to `%T'"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "kunne ikke konvertere skabelonsparameteren '%E' til '%T'"
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, fuzzy, gcc-internal-format
 #| msgid "provided for `%D'"
 msgid "provided for %qD"
 msgstr "angivet for '%D'"
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of `%#D'"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%q#D is not a function template"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, fuzzy, gcc-internal-format
 #| msgid "non-template type `%T' used as a template"
 msgid "non-template type %qT used as a template"
 msgstr "ikke-skabelonstype '%T' benyttet som skabelon"
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, fuzzy, gcc-internal-format
 #| msgid "for template declaration `%D'"
 msgid "for template declaration %q+D"
 msgstr "til skabelonserklæring '%D'"
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, fuzzy, gcc-internal-format
 #| msgid "internal gcc abort"
 msgid "template constraint failure for %qD"
 msgstr "intern GCC-afbrydelse"
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "use of invalid variable template %qE"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "score argument must be constant integer expression"
 msgstr "sammenlign mellem signed og unsigned heltalsudtryk"
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "score argument must be non-negative"
 msgstr "%s-roteringsantal er negativt"
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "fleksibelt tabelmedlem i union"
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "omdefinering af standardparameter for '%#D'"
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member function of non-class type `%T'"
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "opretter henvisning til medlemsfunktion af typen '%T' der ikke er en klasse"
 
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "comparison between types `%#T' and `%#T'"
 msgid "mismatched argument pack lengths (%d vs %d)"
@@ -69866,346 +69907,346 @@ msgstr "sammenligning mellem typerne '%#T' og '%#T'"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "variable %qD has function type"
 msgstr "sizeof benyttet på en funktionstype"
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid parameter type %qT"
 msgstr "ugyldig parametertype '%T'"
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "in declaration %q+D"
 msgstr "i erklæringen '%D'"
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, fuzzy, gcc-internal-format
 #| msgid "function returns an aggregate"
 msgid "function returning an array"
 msgstr "funktion returnerer en værdi af en sammensat type"
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning a function"
 msgid "function returning a function"
 msgstr "'%s' er erklæret som en funktion der returnerer en funktion"
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "danner reference til void"
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "forming pointer to reference type %qT"
 msgstr "danner %s til referencetypen '%T'"
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "forming reference to reference type %qT"
 msgstr "danner %s til referencetypen '%T'"
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "forming pointer to qualified function type %qT"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "forming reference to qualified function type %qT"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "creating pointer to member of non-class type %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating pointer to member reference type %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating pointer to member of type void"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of %qT"
 msgstr "opretter tabel af '%T'"
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class, struct, or union type"
 msgid "%qT is not a class, struct, or union type"
 msgstr "'%T' er ikke en class-, struct- eller union-type"
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "unavngiven klargøring af '%T' som ikke har nogen stamklasser"
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%s' in template"
 msgid "use of %qs in template"
 msgstr "brug af '%s' i skabelon"
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "den modificerede type '%T' passer ikke til destruktionsfunktionsnavnet '~%T'"
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, fuzzy, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "'%D' benyttes som en type, men er ikke defineret som en type"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, fuzzy, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "  (benyt 'typename %T::%D' hvis det er hvad du mener)"
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "startværdielement er ikke en konstant"
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "ugyldig brug af void-udtryk"
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer in lambda init-capture"
 msgstr "en startværdi der ikke er tom, tildeles til en tabel med tomme elementer"
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "'%s' ikke erklæret her (ikke i en funktion)"
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to __builtin_choose_expr not a constant"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "første parameter til '__builtin_choose_expr' skal være en konstant"
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "forkert antal parametre angivet til egenskaben '%s'"
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qT is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qD is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, fuzzy, gcc-internal-format
 #| msgid "missing static field `%s'"
 msgid "using invalid field %qD"
 msgstr "manglende statisk felt '%s'"
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "skabelonsparameter '%T' benytter anonym type"
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "template argument for %qD uses local type %qT"
 msgstr "standardparameter for '%#D' har typen '%T'"
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, fuzzy, gcc-internal-format
 #| msgid "  trying to instantiate `%D'"
 msgid "  trying to instantiate %qD"
 msgstr "  ved forsøg på at instantiere '%D'"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template `%#D'"
 msgid "explicit instantiation of non-template %q#D"
 msgstr "eksplicit instantiering af ikke-skabelon '%#D'"
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "erklæring af skabelon '%#D'"
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template `%T'"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "eksplicit specialisering af '%T' der ikke er en skabelon"
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "'%#D' er ikke et statisk medlem af '%#T'"
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for `%D' found"
 msgid "no matching template for %qD found"
 msgstr "ingen passende skabelon for '%D' fundet"
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "eksplicit instantiering af '%T' der ikke er en skabelonstype"
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D'"
 msgid "explicit instantiation of %q#D"
 msgstr "eksplicit instantiering af '%#D'"
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate explicit instantiation of `%#D'"
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "'%#D' er blevet eksplicit instantieret mere end én gang"
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of `extern' on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ forbyder brugen af 'extern' ved eksplicitte instantieringer"
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "storage class %qD applied to template instantiation"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template `%#D'"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "eksplicit instantiering af ikke-skabelon '%#D'"
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "explicit instantiation of non-template type %qT"
 msgstr "eksplicit instantiering af '%T' der ikke er en skabelonstype"
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#T' before definition of template"
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "eksplicit instantiering af '%T' før definering af skabelonen"
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of `%s' on explicit instantiations"
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ forbyder brugen af '%s ved eksplicitte instantieringer"
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate explicit instantiation of `%#T'"
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "'%#T' er blevet eksplicit instantieret mere end én gang"
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %D after first use"
 msgid "exception specification of %qD depends on itself"
@@ -70218,184 +70259,184 @@ msgstr "eksplicit specialisering af %D efter første brug"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%D' but no definition available"
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eksplicit instantiering af '%D', men ingen definition tilgængelig"
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' is not a valid type for a template constant parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "'%#T' er ikke en gyldig type for en skabelonsparameterkonstant "
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid template non-type parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "'%#T' er ikke en gyldig type for en skabelonsparameterkonstant "
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be constrained"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "'%T' er ikke et navnerum"
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, fuzzy, gcc-internal-format
 #| msgid "definition of `%#T' inside template parameter list"
 msgid "concept %qE has multiple template parameter lists"
 msgstr "definition af '%#T' inden i skabelonsparameterliste"
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, fuzzy, gcc-internal-format
 #| msgid "#include nested too deeply"
 msgid "use %qD directly instead"
 msgstr "#include indlejret for dybt"
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "funktion overvejes ikke for indbygning"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "Ugyldig erklæring"
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Ugyldig metodeerklæring, returtype påkrævet"
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "ugyldig standardparameter i skabelon"
@@ -70624,697 +70665,697 @@ msgstr "typen af asm-operanden '%E' kunne ikke afgøres"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "begyndelseserklæring i 'for'-løkke benyttet uden for C99-tilstand"
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D' in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "ugyldig brug af medlemmet '%D' i statisk medlemsfunktion"
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D' in static member function"
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr "ugyldig brug af medlemmet '%D' i statisk medlemsfunktion"
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D' in static member function"
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr "ugyldig brug af medlemmet '%D' i statisk medlemsfunktion"
 
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, fuzzy, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "cannot call a concept as a function"
 msgstr "'%E' kan ikke bruges som en funktion"
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, fuzzy, gcc-internal-format
 #| msgid "`this' is unavailable for static member functions"
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr "'this' er ikke tilgængelig for statiske medlemsfunktioner"
 
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, fuzzy, gcc-internal-format
 #| msgid "used %d template parameter%s instead of %d"
 msgid "use explicit object parameter %qs instead"
 msgstr "benyttede %d skabelonsparameter%s i stedet for %d"
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "name the explicit object parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, fuzzy, gcc-internal-format
 #| msgid "`this' is unavailable for static member functions"
 msgid "%<this%> is unavailable for static member functions"
 msgstr "'this' er ikke tilgængelig for statiske medlemsfunktioner"
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `this' at top level"
 msgid "invalid use of %<this%> before it is valid"
 msgstr "ugyldig brug af 'this' ved øverste niveau"
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `this' at top level"
 msgid "invalid use of %<this%> after it is valid"
 msgstr "ugyldig brug af 'this' ved øverste niveau"
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `this' in non-member function"
 msgid "invalid use of %<this%> in non-member function"
 msgstr "ugyldig brug af 'this' i ikke-medlemsfunktion"
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `this' at top level"
 msgid "invalid use of %<this%> at top level"
 msgstr "ugyldig brug af 'this' ved øverste niveau"
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ugyldige modifikationer for ikke-medlemsfunktionstype"
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "den modificerede type '%T' passer ikke til destruktionsfunktionsnavnet '~%T'"
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not of type `%T'"
 msgid "%qE is not of type %qT"
 msgstr "'%E' er ikke af typen '%T'"
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "%<auto{x}%> cannot be constrained"
 msgstr "funktion kan ikke indbygges"
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, fuzzy, gcc-internal-format
 #| msgid "template type parameters must use the keyword `class' or `typename'"
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "skabelonstypeparametre skal begynde med 'class' eller 'typename'"
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "ugyldig brug af skabelonstypeparameter"
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "ugyldig brug af skabelonstypeparameter"
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, fuzzy, gcc-internal-format
 #| msgid "definition of `%#T' inside template parameter list"
 msgid "definition of %q#T inside template parameter list"
 msgstr "definition af '%#T' inden i skabelonsparameterliste"
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, fuzzy, gcc-internal-format
 #| msgid "invalid definition of qualified type `%T'"
 msgid "invalid definition of qualified type %qT"
 msgstr "ugyldig definition af modificeret type '%T'"
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "ugyldig stamklasseangivelse"
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, fuzzy, gcc-internal-format
 #| msgid "protected member `%#D' in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "beskyttet medlem '%#D' i en anonym union"
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qD is not captured"
 msgstr "'%D' ikke erklæret"
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "brug af %s fra indeholdende funktion"
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s from containing function"
 msgid "use of parameter from containing function"
 msgstr "brug af %s fra indeholdende funktion"
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s from containing function"
 msgid "use of parameter outside function body"
 msgstr "brug af %s fra indeholdende funktion"
 
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, fuzzy, gcc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "use of class template %qT as expression"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' is ambiguous in multiple inheritance lattice"
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "forespørgsel efter medlemmet '%D' er tvetydigt i det multiple nedarvningsnet"
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, fuzzy, gcc-internal-format
 #| msgid "type of `%E' is unknown"
 msgid "type of %qE is unknown"
 msgstr "typen af '%E' er ukendt"
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template type"
 msgid "%qT is not an enumeration type"
 msgstr "'%T' er ikke en skabelonstype"
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr "angivet justering er ikke en konstant"
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr ""
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, fuzzy, gcc-internal-format
 #| msgid "hex escape sequence out of range"
 msgid "%<__type_pack_element%> index is out of range"
 msgstr "den hexadecimale undvigesekvens er uden for det gyldige interval"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "lagringsklasseanvisninger er ugyldige i parametererklæringer"
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, fuzzy, gcc-internal-format
 #| msgid "trampolines not supported"
 msgid "pointer-to-member mapping %qE not supported"
 msgstr "trampoliner understøttes ikke"
 
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, fuzzy, gcc-internal-format
 #| msgid "invalid return type for function `%#D'"
 msgid "%qE has const type for %<reduction%>"
 msgstr "ugyldig returtype for funktionen '%#D'"
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, gcc-internal-format
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr ""
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in clause %qs"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<gang%> static expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "%<gang%> static value must be positive"
 msgstr "%s-roteringsantal er negativt"
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<gang%> num expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<vector%> length expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<worker%> num expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "%<vector%> length value must be positive"
 msgstr "angivet justering er ikke en potens af 2"
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, fuzzy, gcc-internal-format
 #| msgid "left argument must be a slice"
 msgid "%<worker%> num value must be positive"
 msgstr "venstre parameter skal være en skive"
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in map clauses"
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD fremgår mere end en gang i map-klausuller"
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in map clauses"
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD fremgår mere end en gang i map-klausuller"
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "template %qE in clause %qs"
 msgstr "for mange inddatafiler"
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<grainsize%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<priority%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<hint%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<filter%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, fuzzy, gcc-internal-format
 #| msgid "slice end must be integer"
 msgid "%<tile%> argument needs integral type"
 msgstr "skive-slutning skal være heltal"
 
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr ""
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr ""
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr ""
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr ""
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, fuzzy, gcc-internal-format
 #| msgid "verification error at PC=%d"
 msgid "static assertion failed: %.*s"
 msgstr "verifikationsfejl ved PC=%d"
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "erklæring uden static af '%s' følger static-erklæring"
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, fuzzy, gcc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr ""
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr ""
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, fuzzy, gcc-internal-format
 #| msgid "`__builtin_next_arg' called without an argument"
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr "`__builtin_next_arg' kaldt uden en parameter"
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD is not a class or alias template"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
 # flertalsform unødvendig
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "skabelonsparameter '%E' involverer skabelonsparameter"
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported arg to `__builtin_return_address'"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -71323,1315 +71364,1315 @@ msgstr "ikke-understøttet parameter til '__builtin_return_address'"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, fuzzy, gcc-internal-format
 #| msgid "`%V' qualifiers cannot be applied to `%T'"
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "modifikationerne '%V' kan ikke anvendes på '%T'"
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "statement-expression in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid " declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%T' has incomplete type"
 msgid "base class %qT is not public"
 msgstr "stamklasse '%T' er af en ufuldstændig type"
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qD is not public"
 msgstr "'%D' ikke erklæret"
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a namespace"
 msgid "%qD is mutable"
 msgstr "'%D' er ikke et navnerum"
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD has a non-structural type"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to Java class definitions"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "egenskaben '%s' kan kun anvendes med Java-klassedefinitioner"
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qE attribute takes no arguments"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "den udbedte init_priority er ikke en heltalskonstant"
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, fuzzy, gcc-internal-format
 #| msgid "can only use `%s' attribute on file-scope definitions of objects of class type"
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "kan kun bruge egenskaben '%s' på filvirkefeltsdefinitioner af objekter af klassetype"
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is out of range"
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "den udbedte init_priority er uden for det gyldige interval"
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is reserved for internal use"
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "den udbedte init_priority er reserveret til intern brug"
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as %s"
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "erklæring af '%D' som %s"
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "the %qE attribute requires arguments"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "'%T::%D' er ikke en gyldig erklærer"
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a valid expression"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "'%T' er ikke et gyldigt udtryk"
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to function types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktionstyper"
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, fuzzy, gcc-internal-format
 #| msgid "comparison is always false due to limited range of data type"
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr "sammenligning er altid falsk på grund af den begrænsede rækkevidde af datatypen"
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, fuzzy, gcc-internal-format
 #| msgid "two `u's in integer constant"
 msgid "zero as null pointer constant"
 msgstr "to 'u'-endelser i heltalskonstant"
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, fuzzy, gcc-internal-format
 #| msgid "lang_* check: failed in %s, at %s:%d"
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "lang_*-kontrol: mislykkedes i %s, ved %s:%d"
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types `%T' and `%T' lacks a cast"
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types `%T' and `%T' lacks a cast"
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types `%T' and `%T' lacks a cast"
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type `void *' and pointer-to-function"
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ forbyder %s mellem henvisning af typen 'void *' og henvisning til funktion"
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type `void *' and pointer-to-function"
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ forbyder %s mellem henvisning af typen 'void *' og henvisning til funktion"
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type `void *' and pointer-to-function"
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ forbyder %s mellem henvisning af typen 'void *' og henvisning til funktion"
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, fuzzy, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, fuzzy, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "operander til ?: har forskellige typer"
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "operander til ?: har forskellige typer"
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of `%s' to a member function"
 msgid "invalid application of %qs to a member function"
 msgstr "ugyldig brug af '%s' på en medlemsfunktion"
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ugyldig anvendelse af '%s' på en void-type"
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ forbyder anvendelse af 'sizeof' på et udtryk af en funktionstype"
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "ugyldig anvendelse af '%s' på en void-type"
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ forbyder anvendelse af 'sizeof' på et udtryk af en funktionstype"
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "størrelsen af tabel er ikke af en heltalstype"
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to `%T'"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "forældet konvertering fra strengkonstant til '%T'"
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to `%T'"
 msgid "deprecated conversion from string constant to %qT"
 msgstr "forældet konvertering fra strengkonstant til '%T'"
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' in `%E', which is of non-aggregate type `%T'"
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "forespørgsel efter medlemmet '%D' i '%E' som er af en ikke-sammensat type '%T'"
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' in `%E', which is of non-class type `%T'"
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "forespørgsel efter medlemmet '%D' i '%E' som er af en ikke-klassetype '%T'"
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member `%D' of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ugyldig tilgang til ikke-statisk datamedlem '%D' af NULL-objekt"
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "den modificerede type '%T' passer ikke til destruktionsfunktionsnavnet '~%T'"
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%q#T has no member named %qE"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, fuzzy, gcc-internal-format
 #| msgid "`%D::%D' is not a member of `%T'"
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "'%D::%D' er ikke et medlem af '%T'"
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "'%D' er ikke et medlem af '%T'"
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD is not a member template function"
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a pointer-to-object type"
 msgid "%qT is not a pointer-to-object type"
 msgstr "'%T' er ikke af en henvisning til objekt-type"
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%s' on pointer to member"
 msgid "invalid use of array indexing on pointer to member"
 msgstr "ugyldig brug af '%s' på henvisning til medlem"
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%s' on pointer to member"
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "ugyldig brug af '%s' på henvisning til medlem"
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%s' on pointer to member"
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "ugyldig brug af '%s' på henvisning til medlem"
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "indeks mangler i tabelopslag"
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, fuzzy, gcc-internal-format
 #| msgid "subscripting array declared `register'"
 msgid "subscripting array declared %<register%>"
 msgstr "indeksering af tabel som er erklæret 'register'"
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "værdien der er påført et indeks, er hverken en tabel eller en henvisningsvariabel"
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, fuzzy, gcc-internal-format
 #| msgid "object missing in use of `%E'"
 msgid "object missing in use of %qE"
 msgstr "objekt mangler i brug af '%E'"
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids calling `::main' from within program"
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ forbyder kald af '::main' inde fra programmet"
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, fuzzy, gcc-internal-format
 #| msgid "must use .* or ->* to call pointer-to-member function in `%E (...)'"
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "brug .* eller ->* i kald af henvisning til medlemsfunktion i '%E (...)'"
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "%qE cannot be used as a function"
 msgstr "'%E' kan ikke bruges som en funktion"
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "'%E' kan ikke bruges som en funktion"
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "'%E' kan ikke bruges som en funktion"
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "too many arguments to constructor %q#D"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s `%+#D'"
 msgid "too few arguments to constructor %q#D"
 msgstr "for få parametre til %s '%+#D'"
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to member function %q#D"
 msgstr "for mange parametre til funktionen"
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to member function %q#D"
 msgstr "for få parametre til funktionen"
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to function %q#D"
 msgstr "for mange parametre til funktionen"
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to function %q#D"
 msgstr "for få parametre til funktionen"
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "too many arguments to method %q#D"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s `%+#D'"
 msgid "too few arguments to method %q#D"
 msgstr "for få parametre til %s '%+#D'"
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "for mange parametre til funktionen"
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "for få parametre til funktionen"
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameteren '%s' er af en ufuldstændig type"
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, fuzzy, gcc-internal-format
 msgid "the address %qE will never be NULL"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr ""
 
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr "operander til ?: har forskellige typer"
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types `%T' and `%T' lacks a cast"
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr "operander til ?: har forskellige typer"
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types `%T' and `%T' lacks a cast"
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, fuzzy, gcc-internal-format
 #| msgid "complex arguments must have floating-point type"
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr "komplekse parametre skal have kommatalstype"
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, fuzzy, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "overløb i konstant udtryk"
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of `%T' to `%T'"
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr "uforenelige typer i tildeling af '%T' til '%T'"
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, fuzzy, gcc-internal-format
 #| msgid "assuming cast to type `%T' from overloaded function"
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "antager typeomtvingning til typen '%T' fra flertydig funktion"
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL benyttet i udregning"
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ forbyder sammenligning mellem henvisningsvariabel og heltal"
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "ordnet sammenligning af henvisning med heltallet nul"
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "uordnet sammenligning af ikke-kommatalsparameter"
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "konvertering fra NaN til unsigned int"
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands of types `%T' and `%T' to binary `%O'"
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ugyldige operander af typerne '%T' og '%T' til binær '%O'"
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids using pointer of type `void *' in subtraction"
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ forbyder brug af henvisning af typen 'void *' i fratrækning"
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ forbyder brug af henvisning til funktion i fratrækning"
 
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ forbyder brug af henvisning til medlemsfunktion i fratrækning"
 
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ugyldig brug af en henvisning til en ufuldstændig type i henvisningsberegning"
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor"
 msgid "taking address of constructor %qD"
 msgstr "tager adressen på en destruktionsfunktion"
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor"
 msgid "taking address of destructor %qD"
 msgstr "tager adressen på en destruktionsfunktion"
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' to form a pointer-to-member-function.  Use a qualified-id."
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ugyldig brug af '%E' til at danne en henvisning til medlemsfunktion; benyt et kaldenavn med klassepræfiks"
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesis around '%E' cannot be used to form a pointer-to-member-function"
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "paranteser omkring '%E' kan ikke bruges til at danne en henvisning til medlemsfunktion"
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ forbyder at tage adressen på en ikke-modificeret, ikke-statisk medlemsfunktion for at danne en henvisning til medlemsfunktion; brug '&%T::%D'"
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr "ISO C++ forbyder at tage adressen på en ikke-modificeret, ikke-statisk medlemsfunktion for at danne en henvisning til medlemsfunktion; brug '&%T::%D'"
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say `&%T::%D'"
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ forbyder at tage adressen på en bundet medlemsfunktion for at danne en henvisning til medlemsfunktion; brug '&%T::%D'"
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say `&%T::%D'"
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr "ISO C++ forbyder at tage adressen på en bundet medlemsfunktion for at danne en henvisning til medlemsfunktion; brug '&%T::%D'"
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with `&%E')"
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr "(en henvisning til medlem kan kun dannes med '&%E')"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "tager adressen på midlertidig variabel"
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking address of function `::main'"
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ forbyder at tage adressen på funktionen '::main'"
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create pointer to reference member `%D'"
 msgid "cannot create pointer to reference member %qD"
 msgstr "kan ikke oprette henvisning til reference medlemmet '%D'"
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field `%s'"
 msgid "attempt to take address of bit-field"
 msgstr "kan ikke finde adressen af bitfeltet '%s'"
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "tager adressen på midlertidig variabel"
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ forbyder %s af en enum"
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ forbyder %s af en enum"
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "kan ikke %s en henvisning til en ufuldstændig type '%T'"
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "kan ikke %s en henvisning til en ufuldstændig type '%T'"
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type `%T'"
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ forbyder %s af en henvisning af typen '%T'"
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type `%T'"
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ forbyder %s af en henvisning af typen '%T'"
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, fuzzy, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr "ISO C forbyder brug af typeomtvingningsudtryk som venstreværdier"
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of `this', which is an rvalue expression"
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "kan ikke tage adressen af 'this' som er et højreværdiudtryk"
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable `%s' requested"
 msgid "address of explicit register variable %qD requested"
 msgstr "forespørgsel efter adressen af registervariablen '%s'"
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, fuzzy, gcc-internal-format
 #| msgid "address requested for `%D', which is declared `register'"
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "adresse forespurgt for '%D' som er erklæret 'register'"
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast fra typen '%T' til typen '%T' fjerner konstanthed"
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, fuzzy, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast fra typen '%T' til typen '%T' fjerner konstanthed"
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from `%T' to `%T' casts away const (or volatile)"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast fra '%T' til '%T' fjerner const (eller volatile)"
 
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "skabelonsparameter '%T' benytter lokal type '%T'"
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "typemodifikationer ignoreret i funktionsreturtypen"
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type `%T' to type `%T'"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "ugyldig static_cast fra typen '%T' til typen '%T'"
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, fuzzy, gcc-internal-format
 #| msgid "return type `%#T' is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "returtype '%#T' er ufuldstændig"
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 #, fuzzy
 #| msgid "converting from `%T' to `%T'"
 msgid "converting from %qH to %qI"
 msgstr "konvertering fra '%T' til '%T'"
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast of an rvalue expression of type `%T' to type `%T'"
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "ugyldig reinterpret_cast af et højreværdiudtryk fra typen '%T' til typen '%T'"
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 #, fuzzy
 #| msgid "reinterpret_cast from `%T' to `%T' loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "reinterpret_cast fra '%T' til '%T' mister præcision"
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 #, fuzzy
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "%s mellem forskellige henvisningstyper '%T' og '%T' mangler en typeomtvingelse"
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 #, fuzzy
 #| msgid "cast from `%T' to `%T' increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "typeomtvingning fra '%T' til '%T' forøger den påkrævede justering af målets type"
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ forbyder sammenligninger mellem henvisning til funktion og henvisning til objekt"
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type `%T' to type `%T'"
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ugyldig const_cast fra typen '%T' til typen '%T'"
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type `%T', which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ugyldig brug af const_cast med typen '%T' som ikke er en henvisnings-, reference- eller en henvisning til datamedlem-type"
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type `%T', which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "ugyldig brug af const_cast med typen '%T' som er en henvisning eller reference til funktion"
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type `%T' to type `%T'"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type `%T' to type `%T'"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "ugyldig const_cast fra typen '%T' til typen '%T'"
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting to an array type `%T'"
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ forbyder omtvingelse af typen til en tabeltype '%T'"
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "invalid cast to function type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%E' from type `%T' to type `%T'"
 msgid "moving %qE of type %qT to itself"
 msgstr "kan ikke konvertere '%E' fra typen '%T' til typen '%T'"
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, fuzzy, gcc-internal-format
 #| msgid "  in evaluation of `%Q(%#T, %#T)'"
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  i evaluering af '%Q(%#T, %#T)'"
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "tabelindekset i startværdien er ikke en konstant"
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of `%T' to `%T'"
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "uforenelige typer i tildeling af '%T' til '%T'"
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, fuzzy, gcc-internal-format
 #| msgid "bad array initializer"
 msgid "array used as initializer"
 msgstr "ugyldig tildeling af startværdi til tabel"
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "invalid array assignment"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   i henvisning til medlemsfunktion-omdannelse"
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, fuzzy, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "henvisning til medlem-omdannelse via den virtuelle stamklasse '%T' af '%T'"
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   i henvisning til medlem-omdannelse"
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion to type `%T' from type `%T'"
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' for argument `%P' to `%D'"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "kan ikke konvertere '%T' til '%T' for parameter '%P' til '%D'"
 
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI in return"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 #, fuzzy
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of `%+D'"
 msgid "in passing argument %P of %qD"
 msgstr "i overbringelse af parameter %P af '%+D'"
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "returnerer reference til midlertidig variabel"
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "returning pointer to temporary"
 msgstr "returnerer reference til midlertidig variabel"
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable `%D' returned"
 msgid "reference to local variable %qD returned"
 msgstr "reference til den lokale variabel '%D' returneret"
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable `%D' returned"
 msgid "address of label %qD returned"
 msgstr "adresse af den lokale variabel '%D' returneret"
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable `%D' returned"
 msgid "address of local variable %qD returned"
 msgstr "adresse af den lokale variabel '%D' returneret"
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, fuzzy, gcc-internal-format
 #| msgid "too many 'l' suffixes in integer constant"
 msgid "redundant move in return statement"
 msgstr "for mange 'l'-endelser i heltalskonstant"
 
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, fuzzy, gcc-internal-format
 #| msgid "too many 'l' suffixes in integer constant"
 msgid "redundant move in initialization"
 msgstr "for mange 'l'-endelser i heltalskonstant"
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "returnerer en værdi fra en destruktionsfunktion"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "kan ikke returnere fra en håndtering af en funktions-try-blok i en konstruktionsfunktion"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "returnerer en værdi fra en konstruktionsfunktion"
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "'return' uden nogen værdi i en funktion der ikke returnerer void"
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "manglende startværdi"
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, fuzzy, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "'return' uden nogen værdi i en funktion der ikke returnerer void"
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, fuzzy, gcc-internal-format
 #| msgid "`operator new' must not return NULL unless it is declared `throw()' (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "'operator new' må ikke returnere NULL medmindre den er erklæret 'throw()' (eller -fcheck-new er benyttet)"
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for `%#D'"
 msgid "not eliding copy on return from %qD"
 msgstr "ugyldig kovariant returneringstype for '%#D'"
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr ""
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -72888,183 +72929,183 @@ msgstr "flertydig funktion uden kontekstuelle typeoplysninger"
 msgid "insufficient contextual information to determine type"
 msgstr "utilstrækkelige kontekstuelle oplysninger til at afgøre typen"
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, fuzzy, gcc-internal-format
 #| msgid "constructor syntax used, but no constructor declared for type `%T'"
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "konstruktionsfunktionsyntaks benyttet, men ingen konstruktionsfunktion er erklæret for typen '%T'"
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 #, fuzzy
 #| msgid "conversion of `%E' from `%T' to `%T' is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "konvertering af '%E' fra '%T' til '%T' er tvetydigt"
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 #, fuzzy
 #| msgid "conversion of `%E' from `%T' to `%T' is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "konvertering af '%E' fra '%T' til '%T' er tvetydigt"
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, fuzzy, gcc-internal-format
 #| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "startværdistrengen til char-tabellen er for lang"
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "krøllede paranteser omkring skalarstartværdi"
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "missing initializer for member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' is uninitialized reference"
 msgid "member %qD is uninitialized reference"
 msgstr "medlemmet '%D' er en reference uden startværdi"
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "medlemmet '%D' er en reference uden startværdi"
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, fuzzy, gcc-internal-format
 #| msgid "no field `%D' in union being initialized"
 msgid "no field %qD found in union being initialized"
 msgstr "intet felt '%D' i union der tildeles startværdi"
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "indeksværdi i stedet for feltnavn i union-startværdi"
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "fundet en henvisningsefterfølgelse der går i ring"
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of `->' has non-pointer type `%T'"
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "grundoperanden til '->' har en ikke-henvisningstype '%T'"
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, fuzzy, gcc-internal-format
 #| msgid "result of `operator->()' yields non-pointer result"
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "resultatet af 'operator->()' er ikke en henvisning"
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of `->' is not a pointer"
 msgid "base operand of %<->%> is not a pointer"
 msgstr "grundoperanden til '->' er ikke en henvisning"
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a member pointer, since it is of type `%T'"
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "'%E' kan ikke bruges som en medlemshenvisning eftersom udtrykkets type er '%T'"
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply member pointer `%E' to `%E', which is of non-aggregate type `%T'"
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "kan ikke anvende medlemshenvisning '%E' på '%E' som er af den ikke-sammensatte type '%T'"
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, fuzzy, gcc-internal-format
 #| msgid "member type `%T::' incompatible with object type `%T'"
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "medlemstypen '%T::' uforenelige med objekttypen '%T'"
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "functional cast to array type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "funktion kan ikke indbygges"
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, fuzzy, gcc-internal-format
 #| msgid "default-initialization of `%#D', which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "standardklargøring af '%#D' som er af en referencetype"
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, fuzzy, gcc-internal-format
 #| msgid "call to function `%D' which throws incomplete type `%#T'"
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "kald af en funktion '%D' som kaster en ufuldstændig type '%#T'"
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, fuzzy, gcc-internal-format
 #| msgid "call to function which throws incomplete type `%#T'"
 msgid "call to function which throws incomplete type %q#T"
@@ -74124,7 +74165,7 @@ msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid suffix on integer constant"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -75512,7 +75553,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -75743,7 +75784,7 @@ msgstr ""
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in `%T'"
 msgid "Component %qs at %C already declared at %L"
@@ -76587,7 +76628,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
@@ -77440,12 +77481,12 @@ msgstr ""
 msgid "are_identical_variables: Bad type"
 msgstr ""
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr ""
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr ""
@@ -77703,282 +77744,282 @@ msgstr ""
 msgid "check_init_expr(): Unknown expression type"
 msgstr ""
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr ""
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, gcc-internal-format
 msgid "Specification function %qs at %L must be PURE"
 msgstr ""
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, fuzzy, gcc-internal-format
 #| msgid "double quoted strings not allowed in #if expressions"
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr "strenge med dobbelte anførselstegn er ikke tilladte i #if-udtryk"
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr ""
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr ""
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, gcc-internal-format
 msgid "check_restricted(): Unknown expression type"
 msgstr ""
 
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, gcc-internal-format
 msgid "Function %qs at %L must be PURE"
 msgstr "Funktion %qs ved %L skal være PURE"
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr ""
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr ""
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr ""
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr ""
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr "%qs ved %L er ikke en VÆRDI"
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal assignment to external procedure at %L"
 msgstr ""
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incompatible types in assignment of `%T' to `%T'"
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "uforenelige typer i tildeling af '%T' til '%T'"
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incompatible types in assignment of `%T' to `%T'"
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "uforenelige typer i tildeling af '%T' til '%T'"
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr ""
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr ""
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, fuzzy, gcc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr ""
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
@@ -77986,196 +78027,196 @@ msgstr ""
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr ""
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "pointer/integer type mismatch in conditional expression"
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "henvisnings- og heltalstype i betingelsesudtrykket passer ikke sammen"
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr ""
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, fuzzy, gcc-internal-format
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, gcc-internal-format
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr ""
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -78198,8 +78239,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "creating array of `%T'"
 msgid "Creating array temporary at %L"
@@ -78284,7 +78325,7 @@ msgstr ""
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -78423,12 +78464,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -79337,7 +79378,7 @@ msgstr "konvertering fra NaN til int"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "kunne ikke konvertere '%E' til '%T'"
@@ -79934,7 +79975,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -80114,6 +80155,11 @@ msgstr "heltalsoverløb i udtryk"
 msgid "check_charlen_present(): length not set"
 msgstr ""
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr ""
+
 #: fortran/match.cc:118
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
@@ -80543,7 +80589,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
@@ -81095,91 +81141,91 @@ msgstr "Mystisk tal i FORMAT-sætning ved %0"
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "SELECT RANK statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected CASE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in CASE specification at %C"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected RANK statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr ""
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in RANK specification at %C"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -82675,8 +82721,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -85133,12 +85179,12 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "Label %d referenced at %L is never defined"
@@ -85265,7 +85311,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "'%D' erklærer ikke en skabelonstype"
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -85681,288 +85727,294 @@ msgstr ""
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, fuzzy, gcc-internal-format
 #| msgid "Null element at %0 for array reference at %1"
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr "Nulelement ved %0 for tabelreference ved %1"
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is deprecated"
 msgid "Using variable %qs at %L is deprecated"
 msgstr "'%s' er forældet"
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Null element at %0 for array reference at %1"
+msgid "Invalid array reference at %L"
+msgstr "Nulelement ved %0 for tabelreference ved %1"
+
+#: fortran/resolve.cc:6433
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Error in typebound call at %L"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "\"%s\" after # is not a positive integer"
 msgid "%s at %L must be integer"
 msgstr "\"%s\" efter # er ikke et positivt heltal"
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, fuzzy, gcc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -85971,291 +86023,291 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" cannot be used as a macro name as it is an operator in C++"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "\"%s\" kan ikke bruges som et makronavn da det er en operator i C++"
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Selector at %L cannot be NULL()"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter `%s' has incomplete type"
 msgid "Selector at %L has no type"
 msgstr "parameteren '%s' er af en ufuldstændig type"
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "'%s' skal tage mod én parameter"
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -86263,221 +86315,221 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In construct"
 msgid "FORALL construct at %L"
 msgstr "I konstruktionen"
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, gcc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "Pointer procedure assignment at %L"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, fuzzy, gcc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid string constant `%E'"
 msgid "Invalid NULL at %L"
 msgstr "ugyldig strengkonstant '%E'"
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%s' declared void"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "parameteren '%s' erklæret void"
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -86485,1019 +86537,1019 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer at %0 too large"
 msgid "String length at %L is too large"
 msgstr "Heltal ved %0 for stort"
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fstat %s"
 msgid "%s at %L"
 msgstr "fejl ved egenskabsundersøgelse af filen %s"
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "funktion kan ikke indbygges"
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object of type `%T' may not be initialized"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "objekt af typen '%T' med variabel størrelse må ikke tildeles en startværdi"
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "Interface of %qs at %L must be explicit"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "'%s' skal tage mod én parameter"
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr ""
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "'%#D' kan ikke erklæres"
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "uforenelig afledt type i PARAMETER ved %L"
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "CLASS-variablen %qs ved %L kan ikke have PARAMETER-attributten"
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No specification for implied-DO iterator `%A' at %0"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Ingen angivelse af underforstået DO-iterator '%A' ved %0"
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expecting definable entity near %L"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, fuzzy, gcc-internal-format
 #| msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "CLASS-variablen %qs ved %L kan ikke have PARAMETER-attributten"
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "Non-constant character length at %L in DATA statement"
 msgstr "tabelindekset i startværdien er ikke en konstant"
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "Label %d at %L defined but not used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "Label %d at %L defined but cannot be used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in method specification"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -88061,345 +88113,345 @@ msgstr ""
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "`%s' attribute only applies to variables"
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr "egenskaben '%s' kan kun anvendes på variabler"
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, gcc-internal-format
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr ""
+
+#: fortran/symbol.cc:508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in BLOCK DATA program unit at %1"
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr "Sætning ved %0 er ugyldig  i BLOCK DATA-programenhed ved %1"
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr ""
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, fuzzy, gcc-internal-format
 #| msgid "External procedure `%A' is passed as actual argument at %0 but not explicitly declared EXTERNAL"
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr "Ekstern procedure '%A' er overbragt som faktisk parameter ved %0, men ikke eksplicit erklæret EXTERNAL"
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr ""
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "%s attribute applied to %s %s at %L"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "`%s' attribute only applies to variables"
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr "egenskaben '%s' kan kun anvendes på variabler"
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, gcc-internal-format
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr ""
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr ""
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr ""
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate ConstantValue attribute for field '%s'"
 msgid "Duplicate %s attribute specified at %L"
 msgstr "mere end én ConstantValue-egenskab for feltet '%s'"
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate ConstantValue attribute for field '%s'"
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr "mere end én ConstantValue-egenskab for feltet '%s'"
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr ""
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement or attribute at %1 cannot be specified along with SAVE statement or attribute at %0"
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "SAVE-sætning eller -egenskab ved %1 kan ikke angives sammen med SAVE-sætning eller -egenskab ved %0"
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate ConstantValue attribute for field '%s'"
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "mere end én ConstantValue-egenskab for feltet '%s'"
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate ConstantValue attribute for field '%s'"
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "mere end én ConstantValue-egenskab for feltet '%s'"
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement or attribute at %1 cannot be specified along with SAVE statement or attribute at %0"
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr "SAVE-sætning eller -egenskab ved %1 kan ikke angives sammen med SAVE-sætning eller -egenskab ved %0"
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "dataområdet '%s' er i modstrid med tidligere erklæring"
 
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr ""
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, fuzzy, gcc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Etiket %A er allerede defineret ved %1 ved omdefinering ved %0"
 
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%D' is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of type `%T'"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "'%D' er ikke et medlem af typen '%T'"
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of type `%T'"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "'%D' er ikke et medlem af typen '%T'"
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Labeled DO statement at %L"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -88432,24 +88484,24 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -88644,40 +88696,40 @@ msgstr "Returnér værdier fra funktioner i fpu-registre"
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ISO C90 forbids variable-size array `%s'"
 msgid "Cannot compute the length of the char array at %L."
 msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, fuzzy, gcc-internal-format
 #| msgid "unknown insn mode"
 msgid "Unknown intrinsic op"
 msgstr "ukendt instruktionstilstand"
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "Unknown argument list function at %L"
 msgstr "for få parametre til funktionen '%s'"
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -88688,17 +88740,17 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr ""
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "The event variable at %L shall not be coindexed"
@@ -88853,7 +88905,7 @@ msgstr ""
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr ""
@@ -89247,6 +89299,12 @@ msgstr "feltet '%s' er erklæret som en funktion"
 msgid "function %qD redeclared as variable"
 msgstr "funktionen '%s' omerklæret som inline"
 
+#: lto/lto-symtab.cc:865
+#, fuzzy, gcc-internal-format
+#| msgid "`%s' previously declared here"
+msgid "previously declared here"
+msgstr "'%s' tidligere erklæret her"
+
 #: lto/lto.cc:174
 #, fuzzy, gcc-internal-format
 #| msgid "lto_obj_file_open() failed"
@@ -90585,7 +90643,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr ""
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, fuzzy, gcc-internal-format
 #| msgid "non-object member `%s' cannot be declared `mutable'"
 msgid "non-objective-c type %qT cannot be caught"
@@ -90596,7 +90654,7 @@ msgstr "'%s' som ikke er objektmedlem, kan ikke erklæres 'mutable'"
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr ""
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, gcc-internal-format
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
 msgstr ""
diff --git a/gcc/po/de.po b/gcc/po/de.po
index 5b7e75a269a..5aaa4a2b591 100644
--- a/gcc/po/de.po
+++ b/gcc/po/de.po
@@ -8,10 +8,10 @@
 # Roland Illig <roland.illig@gmx.de>, 2015, 2017-2024.
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 14.1.0\n"
+"Project-Id-Version: gcc 14.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
-"PO-Revision-Date: 2024-05-09 16:32+0200\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
+"PO-Revision-Date: 2024-08-01 19:25+0200\n"
 "Last-Translator: Roland Illig <roland.illig@gmx.de>\n"
 "Language-Team: German <translation-team-de@lists.sourceforge.net>\n"
 "Language: de\n"
@@ -20,7 +20,7 @@ msgstr ""
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
 "X-Bugs: Report translation errors to the Language-Team address.\n"
-"X-Generator: Poedit 3.4.2\n"
+"X-Generator: Poedit 3.4.4\n"
 "X-Poedit-Bookmarks: -1,-1,-1,6017,-1,-1,-1,-1,-1,-1\n"
 
 #: cif-code.def:39
@@ -387,7 +387,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr "»-march=…« und »-mcpu=…« dürfen nicht zusammen angegeben werden"
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 msgid "shared and mdll are not compatible"
 msgstr "shared und mdll sind unverträglich"
 
@@ -19182,16 +19182,16 @@ msgstr "unerkennbarer Befehl:"
 msgid "insn does not satisfy its constraints:"
 msgstr "Befehl erfüllt nicht seine Bedingungen:"
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "erzeugt und mit anderen Einstellungen von »%s« verwendet"
 
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "erzeugt und mit anderen Einstellungen von %<-fpic%> verwendet"
 
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 msgid "created and used with different settings of %<-fpie%>"
 msgstr "erzeugt und mit anderen Einstellungen von %<-fpie%> verwendet"
 
@@ -19512,7 +19512,7 @@ msgstr "Längenmodifizierer im strfmon-Format"
 msgid "<command-line>"
 msgstr "<Kommandozeile>"
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "Operand für Code »%c« nicht unterstützt"
@@ -19531,9 +19531,9 @@ msgstr "ungültiger Operand für »%%%c«"
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, c-format
 msgid "invalid vector constant"
 msgstr "ungültige Vektorkonstante"
@@ -19553,7 +19553,7 @@ msgstr "unverträglicher Operand für »%%%c«"
 msgid "incompatible register operand for '%%%c'"
 msgstr "unverträglicher Registeroperand für »%%%c«"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, c-format
 msgid "missing operand"
 msgstr "fehlender Operand"
@@ -19582,93 +19582,93 @@ msgstr "ungültiger Adressierungsmodus"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "GNU- und SVE-Vektoren können nicht in einer binären Operation kombiniert werden"
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "»%%&« ohne lokale dynamische TLS-Referenzen verwendet"
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, c-format
 msgid "invalid %%J value"
 msgstr "ungültiger %%J-Wert"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, c-format
 msgid "invalid %%r value"
 msgstr "ungültiger %%r-Wert"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, c-format
 msgid "invalid %%R value"
 msgstr "ungültiger %%R-Wert"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, c-format
 msgid "invalid %%N value"
 msgstr "ungültiger %%N-Wert"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, c-format
 msgid "invalid %%P value"
 msgstr "ungültiger %%P-Wert"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, c-format
 msgid "invalid %%h value"
 msgstr "ungültiger %%h-Wert"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, c-format
 msgid "invalid %%L value"
 msgstr "ungültiger %%L-Wert"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, c-format
 msgid "invalid %%m value"
 msgstr "ungültiger %%m-Wert"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, c-format
 msgid "invalid %%M value"
 msgstr "ungültiger %%M-Wert"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, c-format
 msgid "invalid %%U value"
 msgstr "ungültiger %%U-Wert"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, c-format
 msgid "invalid %%s value"
 msgstr "ungültiger %%s-Wert"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, c-format
 msgid "invalid %%C value"
 msgstr "ungültiger %%C-Wert"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, c-format
 msgid "invalid %%E value"
 msgstr "ungültiger %%E-Wert"
 
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "unbekannte Adressverschiebungs-Unspec"
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ungültiger %%xn-Code"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, c-format
 msgid "invalid operand address"
 msgstr "ungültige Operandenadresse"
@@ -19761,35 +19761,35 @@ msgstr "ungültiges UNSPEC als Operand: %d"
 msgid "unrecognized supposed constant"
 msgstr "unerkannte vermutete Konstante"
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, c-format
 msgid "invalid shift operand"
 msgstr "ungültiger Schiebeoperand"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "bedingter Thumb-Befehl"
 
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "bedingter Befehl in bedingter Sequenz"
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Operand für Code »%c« nicht unterstützt"
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -19797,113 +19797,113 @@ msgstr "Operand für Code »%c« nicht unterstützt"
 msgid "invalid operand for code '%c'"
 msgstr "ungültiger Operand für Code »%c«"
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, c-format
 msgid "instruction never executed"
 msgstr "Befehl wird niemals ausgeführt"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "veralteter Maverick-Formatcode »%c«"
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "ungültige Umwandlung von Typ %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "ungültige Umwandlung in Typ %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "Operation nicht erlaubt auf Typ %<bfloat16_t%>"
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "Adressoperand erfordert Beschränkung für X-, Y- oder Z-Register"
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "Operanden für %T/%t müssen reg + const_int sein:"
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 msgid "bad address, not an I/O address:"
 msgstr "falsche Adresse, keine E/A-Adresse:"
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 msgid "bad address, not a constant:"
 msgstr "falsche Adresse, keine Konstante:"
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 msgid "bad address, not (reg+disp):"
 msgstr "Falsche Adresse, nicht (reg+disp):"
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "Falsche Adresse, nicht post_inc oder pre_dec:"
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr "Interner Compiler-Fehler. Falsche Adresse:"
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "Code »%c« für Festkomma nicht unterstützt:"
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 msgid "internal compiler error.  Unknown mode:"
 msgstr "Interner Compiler-Fehler. Unbekannter Modus:"
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 msgid "invalid insn:"
 msgstr "Ungültiger Befehl:"
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 msgid "incorrect insn:"
 msgstr "Falscher Befehl:"
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 msgid "unknown move insn:"
 msgstr "Falscher Kopierbefehl:"
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 msgid "bad shift insn:"
 msgstr "Falscher Schiebe-Befehl:"
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "Interner Compiler-Fehler. Falsche Verschiebung:"
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 msgid "unsupported fixed-point conversion"
 msgstr "Festkommaumwandlung nicht unterstützt"
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 msgid "variable"
 msgstr "Variable"
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 msgid "function parameter"
 msgstr "Funktionsparameter"
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 msgid "structure field"
 msgstr "Strukturfeld"
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 msgid "return type of function"
 msgstr "Rückgabetyp für Funktion"
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 msgid "pointer"
 msgstr "Zeiger"
 
@@ -19939,7 +19939,7 @@ msgstr "nicht unterstützter Operand"
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -20258,46 +20258,46 @@ msgstr "Operand ist keine Ganzzahl, ungültiger Operandencode »R«"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "Operand ist keine bestimmte Ganzzahl, ungültiger Operandencode »R«"
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ungültiger Operandencode »%c«"
 
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ungültige Bedingungen für Operand"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, c-format
 msgid "invalid vector immediate"
 msgstr "ungültiger Vektordirektwert"
 
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 msgid "unknown insn mode"
 msgstr "unbekannter Befehlsmodus"
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr "ungültige Umwandlung von Typ %<__bf16%> ohne Option %<-msse2%>"
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr "ungültige Umwandlung von Typ %<_Float16%> ohne Option %<-msse2%>"
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr "ungültige Umwandlung in Typ %<__bf16%> ohne Option %<-msse2%>"
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr "ungültige Umwandlung in Typ %<_Float16%> ohne Option %<-msse2%>"
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr "Operation nicht erlaubt auf Typ %<__bf16%> ohne Option %<-msse2%>"
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
 msgstr "Operation nicht erlaubt auf Typ %<_Float16%> ohne Option %<-msse2%>"
 
@@ -20328,7 +20328,7 @@ msgstr "ungültige Operation auf %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "ungültiger %%P-Operand"
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, c-format
 msgid "invalid %%p value"
 msgstr "ungültiger %%p-Wert"
@@ -20355,29 +20355,29 @@ msgstr "Nicht-GP-relative absolute Adresse kann nicht verwendet werden"
 msgid "invalid addressing mode"
 msgstr "ungültiger Adressierungsmodus"
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, c-format
 msgid "'%%%c' is not a valid operand prefix"
 msgstr "»%%%c« ist kein gültiger Operandenpräfix"
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "ungültige Verwendung von »%%%c«"
@@ -20409,7 +20409,7 @@ msgid "post-increment address is not a register"
 msgstr "Post-Increment-Adresse ist kein Register"
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 msgid "bad address"
 msgstr "Falsche Adresse"
 
@@ -20567,7 +20567,7 @@ msgstr "nicht unterstützte konstante Adresse:"
 msgid "unsupported memory expression:"
 msgstr "nicht unterstützter Speicherausdruck:"
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, c-format
 msgid "invalid vector operand"
 msgstr "ungültiger Vektoroperand"
@@ -20615,242 +20615,242 @@ msgstr "%<-mquad-memory-atomic%> benötigt 64-Bit-Modus"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "%<-mquad-memory%> ist im Little-Endian-Modus nicht verfügbar"
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 msgid "bad move"
 msgstr "ungültige Bewegung"
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 msgid "Bad 128-bit move"
 msgstr "Falsche 128-Bit-Verschiebung"
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, c-format
 msgid "invalid %%A value"
 msgstr "ungültiger %%A-Wert"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%D value"
 msgstr "ungültiger %%D-Wert"
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, c-format
 msgid "invalid %%e value"
 msgstr "ungültiger %%e-Wert"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, c-format
 msgid "invalid %%f value"
 msgstr "ungültiger %%f-Wert"
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, c-format
 msgid "invalid %%F value"
 msgstr "ungültiger %%F-Wert"
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, c-format
 msgid "invalid %%G value"
 msgstr "ungültiger %%G-Wert"
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, c-format
 msgid "invalid %%j code"
 msgstr "ungültiger %%j-Code"
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, c-format
 msgid "invalid %%J code"
 msgstr "ungültiger %%J-Code"
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, c-format
 msgid "invalid %%k value"
 msgstr "ungültiger %%k-Wert"
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, c-format
 msgid "invalid %%K value"
 msgstr "ungültiger %%K-Wert"
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, c-format
 msgid "invalid %%O value"
 msgstr "ungültiger %%O-Wert"
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, c-format
 msgid "invalid %%q value"
 msgstr "ungültiger %%q-Wert"
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, c-format
 msgid "invalid %%t value"
 msgstr "ungültiger %%t-Wert"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, c-format
 msgid "invalid %%T value"
 msgstr "ungültiger %%T-Wert"
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, c-format
 msgid "invalid %%u value"
 msgstr "ungültiger %%u-Wert"
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, c-format
 msgid "invalid %%v value"
 msgstr "ungültiger %%v-Wert"
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, c-format
 msgid "invalid %%V value"
 msgstr "ungültiger %%V-Wert"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, c-format
 msgid "invalid %%x value"
 msgstr "ungültiger %%x-Wert"
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, c-format
 msgid "invalid %%z value"
 msgstr "ungültiger %%z-Wert"
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ungültiger %%y-Wert, bitte »Z«-Bedingung probieren"
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Unerlaubtes Mischen von IEEE-128-Bit- und IBM-128-Bit-Gleitkommatypen"
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-Argument an Funktion ohne Prototyp übergeben"
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 msgid "Could not generate addis value for fusion"
 msgstr "Addis-Wert für Fusion kann nicht erzeugt werden"
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Lade-/Speicheroffset für Fusion kann nicht generiert werden"
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 msgid "Bad GPR fusion"
 msgstr "Falsche GPR-Fusion"
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "ungültige Umwandlung von Typ %<__vector_quad%>"
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "ungültige Umwandlung in Typ %<__vector_quad%>"
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "ungültige Umwandlung von %<__vector_pair%>"
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "ungültige Umwandlung in %<__vector_pair%>"
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "symbolische Speicherreferenzen werden nur auf z10 oder neuer unterstützt"
 
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, c-format
 msgid "cannot decompose address"
 msgstr "Adresse kann nicht zerlegt werden"
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "ungültiger Vergleichsoperator für Ausgabemodifizierer »E«"
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "ungültige Referenz für Ausgabemodifizierer »J«"
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "ungültige Adresse für Ausgabemodifizierer »O«"
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "ungültige Adresse für Ausgabemodifizierer »R«"
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "Speicherreferenz für Ausgabemodifizierer »S« erwartet"
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "ungültige Adresse für Ausgabemodifizierer »S«"
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "Register oder Speicherausdruck für Ausgabemodifizierer »N« erwartet"
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "Register oder Speicherausdruck für Ausgabemodifizierer »M« erwartet"
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "ungültige Konstante für Ausgabemodifizierer »%c«"
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "Ungültige Konstante – anderen Ausgabemodifizierer probieren"
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "ungültiger konstanter Vektor für Ausgabemodifizierer »%c«"
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "ungültiger Ausdruck – anderen Ausgabemodifizierer probieren"
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "ungültiger Ausdruck für Ausgabemodifizierer »%c«"
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 msgid "vector argument passed to unprototyped function"
 msgstr "Vektor-Argument an Funktion ohne Prototyp übergeben"
 
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 msgid "types differ in signedness"
 msgstr "Typen unterscheiden sich im Vorzeichenbesitz"
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 msgid "binary operator does not support two vector bool operands"
 msgstr "binärer Operator unterstützt keine zwei bool-Vektor-Operanden"
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 msgid "binary operator does not support vector bool operand"
 msgstr "Binärer Operator unterstützt Boolean-Vektor-Argument nicht"
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "binärer Operator unterstützt nicht, dass bool-Vektor mit Gleitkommavektor vermischt wird"
 
@@ -21041,12 +21041,12 @@ msgstr "({anonym})"
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> erwartet"
@@ -21059,7 +21059,7 @@ msgstr "%<;%> erwartet"
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -21068,7 +21068,7 @@ msgstr "%<;%> erwartet"
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> erwartet"
@@ -21076,7 +21076,7 @@ msgstr "%<)%> erwartet"
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> erwartet"
@@ -21087,29 +21087,29 @@ msgstr "%<;%>, %<,%> oder %<)%> erwartet"
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> erwartet"
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> erwartet"
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> erwartet"
@@ -21119,17 +21119,17 @@ msgstr "%<{%> erwartet"
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> erwartet"
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> erwartet"
@@ -21138,8 +21138,8 @@ msgstr "%<while%> erwartet"
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> erwartet"
@@ -21149,17 +21149,17 @@ msgid "expected %<.%>"
 msgstr "%<.%> erwartet"
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> erwartet"
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> erwartet"
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> oder %<)%> erwartet"
@@ -21167,32 +21167,32 @@ msgstr "%<,%> oder %<)%> erwartet"
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> erwartet"
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> erwartet"
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, gcc-internal-format
 msgid "expected %<else%>"
 msgstr "%<else%> erwartet"
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> oder %<}%> erwartet"
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr "<Meldung nicht zur Compilierzeit bekannt>"
 
@@ -21200,7 +21200,7 @@ msgstr "<Meldung nicht zur Compilierzeit bekannt>"
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> erwartet"
@@ -21215,21 +21215,21 @@ msgstr "Sprungmarke erwartet"
 msgid "candidate:"
 msgstr "Kandidat:"
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 msgid "  after user-defined conversion:"
 msgstr "  nach benutzerdefinierter Umwandlung:"
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "Kandidat ist:"
 msgstr[1] "Kandidaten sind:"
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr "Kandidat 1:"
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr "Kandidat 2:"
 
@@ -21461,7 +21461,7 @@ msgstr "%r%s:%d:%d:%R   in %<constexpr%>-Ersetzung von %qs"
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%R   in %<constexpr%>-Ersetzung von %qs"
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 msgid "candidates are:"
 msgstr "Kandidaten sind:"
 
@@ -21505,48 +21505,48 @@ msgstr "Umformung verwirft Konstantheit"
 msgid "source type is not polymorphic"
 msgstr "Quellentyp ist nicht polymorph"
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "Argument falschen Typs für unäres Minus"
 
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "Argument falschen Typs für unäres Plus"
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "Argument falschen Typs für Bit-Komplement"
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "Argument falschen Typs für abs"
 
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "Argument falschen Typs für Konjugation"
 
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 msgid "in argument to unary !"
 msgstr "in Argument für unäres !"
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 msgid "no pre-increment operator for type"
 msgstr "kein Präinkrementoperator für Typ"
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 msgid "no post-increment operator for type"
 msgstr "kein Postinkrementoperator für Typ"
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 msgid "no pre-decrement operator for type"
 msgstr "kein Prädekrementoperator für Typ"
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 msgid "no post-decrement operator for type"
 msgstr "kein Postdekrementoperator für Typ"
 
@@ -21631,7 +21631,7 @@ msgstr "Veraltete Funktion:"
 msgid "Deleted feature:"
 msgstr "Gelöschte Funktion:"
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 msgid "array assignment"
 msgstr "Array-Zuweisung"
 
@@ -21824,11 +21824,11 @@ msgstr "Block-IF"
 msgid "implied END DO"
 msgstr "impliziertes END DO"
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 msgid "assignment"
 msgstr "Zuweisung"
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 msgid "pointer assignment"
 msgstr "Zeigerzuweisung"
 
@@ -21988,47 +21988,47 @@ msgstr "Operand des Benutzeroperators %%<%s%%> bei %%L ist %s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanden des Benutzeroperators %%<%s%%> bei %%L sind %s/%s"
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 msgid "Loop variable"
 msgstr "Schleifenvariable"
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 msgid "iterator variable"
 msgstr "Iteratorvariable"
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 msgid "Start expression in DO loop"
 msgstr "Anfangs-Ausdruck in DO-Schleife"
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 msgid "End expression in DO loop"
 msgstr "End-Ausdruck in DO-Schleife"
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 msgid "Step expression in DO loop"
 msgstr "Schrittausdruck in DO-Schleife"
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE Objekt"
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 msgid "ALLOCATE object"
 msgstr "ALLOCATE Objekt"
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 msgid "STAT variable"
 msgstr "STAT-Variable"
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 msgid "ERRMSG variable"
 msgstr "ERRMSG-Variable"
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 msgid "item in READ"
 msgstr "Element in READ"
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 msgid "ACQUIRED_LOCK variable"
 msgstr "Variable ACQUIRED_LOCK"
 
@@ -22037,11 +22037,11 @@ msgstr "Variable ACQUIRED_LOCK"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "Unterschiedliche CHARACTER-Längen (%ld/%ld) in Feldkonstruktor"
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Ganzzahlüberlauf bei der Berechnung des zu reservierenden Speichers"
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "Der Wert des Parameters PDT LEN »%s« stimmt nicht mit dem in der Dummy-Deklaration überein"
@@ -22056,12 +22056,12 @@ msgstr "Effektive Zeichenkettenlänge passt nicht zur deklarierten für Scheinar
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Effektive Zeichenkettenlänge ist kürzer als die deklarierte für Scheinargument »%s« (%ld/%ld)"
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Ziel für neue Rangabbildung ist zu klein (%ld < %ld)"
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 msgid "Assignment of scalar to unallocated array"
 msgstr "Zuweisung von Skalar zu unalloziertem Array"
 
@@ -22070,81 +22070,81 @@ msgstr "Zuweisung von Skalar zu unalloziertem Array"
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Ungleiche Zeichenlängen (%ld/%ld) in %s"
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr "POS-Argument (%ld) außerhalb des Bereichs 0:%ld in intrinsischem BTEST"
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "POS-Argument (%ld) außerhalb des Bereichs 0:%ld in intrinsischem »%s«"
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr "POS-Argument (%ld) außerhalb des Bereichs 0:%ld in intrinsischem IBITS"
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr "LEN-Argument (%ld) außerhalb des Bereichs 0:%ld in intrinsischem IBITS"
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsischem IBITS"
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, c-format
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "SHIFT-Argument (%ld) außerhalb des Bereichs 0:%ld in intrinsischem »%s«"
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr "SHIFT-Argument (%ld) außerhalb des Bereichs -%ld:%ld in intrinsischem ISHFT"
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr "SIZE-Argument (%ld) außerhalb des Bereichs 1:%ld in intrinsischem ISHFTC"
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr "SIZE-Argument (%ld) außerhalb des Bereichs -%ld:%ld in intrinsischem ISHFTC"
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Argument NCOPIES des intrinsischen REPEAT ist negativ (sein Wert ist %ld)"
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "Argument NCOPIES des intrinsischen REPEAT ist zu groß"
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, c-format
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "FROMPOS-Argument (%ld) außerhalb des Bereichs 0:%d in intrinsischem MVBITS"
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "LEN-Argument (%ld) außerhalb des Bereichs 0:%d in intrinsischem MVBITS"
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, c-format
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "TOPOS-Argument (%ld) außerhalb des Bereichs 0:%d in intrinsischem MVBITS"
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsischem MVBITS"
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsischem MVBITS"
@@ -22166,15 +22166,15 @@ msgstr "Zugewiesene Marke ist keine Zielmarke"
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Ungültige Bildanzahl %d in SYNC IMAGES"
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr "Schleife läuft endlos"
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 msgid "Loop variable has been modified"
 msgstr "Schleifenvariable wurde geändert"
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 msgid "DO step value is zero"
 msgstr "DO-Schrittwert ist Null"
 
@@ -22250,7 +22250,7 @@ msgid "expected boolean type"
 msgstr "boolescher Typ erwartet"
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "Ganzzahl erwartet"
@@ -22313,7 +22313,7 @@ msgstr "Nicht genug Argumente"
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "zu viele Argumente"
@@ -22937,7 +22937,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "%<-mrelax%> wird nur für RTP PIC unterstützt"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Syntaxfehler in Anweisung %s bei %C"
@@ -23373,8 +23373,8 @@ msgstr "Attribut %qE steht mit Attribut %qs in Konflikt; wird ignoriert"
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "vorherige Deklaration hier"
@@ -23391,7 +23391,7 @@ msgstr "Attribut-Direktive %qE ignoriert"
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr "Attribut-Direktive im Bereich %<%E::%E%> ignoriert"
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, gcc-internal-format
 msgid "wrong number of arguments specified for %qE attribute"
 msgstr "Falsche Anzahl an Argumenten für das Attribut %qE angegeben"
@@ -23401,7 +23401,7 @@ msgstr "Falsche Anzahl an Argumenten für das Attribut %qE angegeben"
 msgid "expected %i or more, found %i"
 msgstr "%i oder mehr erwartet, %i gefunden"
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "expected %i, found %i"
 msgstr "%i erwartet, %i gefunden"
@@ -23468,12 +23468,12 @@ msgstr "Typattribute ignoriert, nachdem Typ bereits definiert ist"
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -23482,7 +23482,7 @@ msgstr "Typattribute ignoriert, nachdem Typ bereits definiert ist"
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -23504,8 +23504,8 @@ msgstr "Attribut %qE wird ignoriert"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "Attribut %<target%> fehlt für multiversioniertes %qD"
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "vorherige Deklaration von %qD"
@@ -23614,7 +23614,7 @@ msgstr "Funktionsprofil aus %s kann nicht gelesen werden"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "Offset %qwi ist außerhalb der Grenzen der konstanten Zeichenkette"
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE ist hier deklariert"
@@ -23719,7 +23719,7 @@ msgstr "ungültiges Argument 0 für %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, gcc-internal-format
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "ungültige Verwendung von %<__builtin_va_arg_pack ()%>"
@@ -23741,42 +23741,42 @@ msgstr "Zweites Argument für %<__builtin_longjmp%> muss 1 sein"
 msgid "target format does not support infinity"
 msgstr "Zielformat unterstützt nicht »unendlich«"
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> in Funktion mit fester Parameteranzahl verwendet"
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "falsche Anzahl der Argumente für Funktion %<va_start%>"
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> ohne Argument gerufen"
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "falsche Anzahl der Argumente für Funktion %<__builtin_next_arg%>"
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "Zweiter Parameter von %<va_start%> ist nicht letztgenanntes Argument"
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "undefiniertes Verhalten, wenn zweiter Parameter von %<va_start%> mit %<register%>-Speicherklasse deklariert wird"
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, gcc-internal-format
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr "erstes Argument von %qD muss ein Zeiger, das zweite eine Ganzzahlkonstante sein"
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, gcc-internal-format
 msgid "last argument of %qD is not integer constant between 0 and 3"
 msgstr "letztes Argument von %qD ist keine Ganzzahlkonstante zwischen 0 und 3"
@@ -24823,12 +24823,12 @@ msgstr "Attribut %<weakref%> ignoriert, da Variable bereits initialisiert ist"
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F verwendet, aber nirgendwo definiert"
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F als %<static%> deklariert, aber nirgendwo definiert"
@@ -25377,7 +25377,7 @@ msgstr "%<region_array%> passt nicht zum %<region_tree%>"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "%<lp_array%> passt nicht zum %<region_tree%>"
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, gcc-internal-format
 msgid "%qs failed"
 msgstr "%qs fehlgeschlagen"
@@ -25408,17 +25408,17 @@ msgstr "umgekehrte Speicherreihenfolge für »%smode«"
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr "Schreiben von %wu Bit Daten außerhalb der Grenzen des Zielobjekts, Daten wurden auf %wu Bit abgeschnitten"
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, gcc-internal-format
 msgid "call to %qs declared with attribute error: %s"
 msgstr "Aufruf von %qs mit Attributfehler deklariert: %s"
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, gcc-internal-format
 msgid "call to %qs declared with attribute warning: %s"
 msgstr "Aufruf von %qs mit Attributwarnung deklariert: %s"
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
 msgstr "der Compiler geht davon aus, dass kein vorzeichenbehafteter Überlauf auftritt, und vereinfacht daher %<X - Y %s 0%> zu %<X %s 0%>"
@@ -25453,7 +25453,7 @@ msgstr "große Festkommakonstante implizit auf Festkommatypen abgeschnitten"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "Vergleich ist immer %d wegen Breite des Bitfeldes"
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn Bereichsprüfung vereinfacht wird"
@@ -25616,7 +25616,7 @@ msgstr "Verarbeitungszeiten konnten nicht ermittelt werden: %m"
 msgid "%s signal terminated program %s"
 msgstr "Signal %s hat Programm %s beendet"
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, gcc-internal-format
 msgid "unrecognized command-line option %qs"
 msgstr "nicht erkannte Kommandozeilenoption %qs"
@@ -25878,7 +25878,7 @@ msgstr "Multilib-Spezifikation %qs ist ungültig"
 msgid "multilib exclusions %qs is invalid"
 msgstr "Multilib-Ausschlüsse %qs sind ungültig"
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "Multilib-select %qs %qs ist ungültig"
@@ -26178,22 +26178,22 @@ msgstr "durch %qD angegebene Grenze %E überschreitet die Größe %E des Zielobj
 msgid "%qD specified bound %E equals source length"
 msgstr "%qD angegebene Grenze %E ist genau die Größe der Quelle"
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, gcc-internal-format
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr "flexibles Arrayelement %qD hat keine wohldefinierten Paddingbits für %qs"
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr "PDP11-Bitfeld-Verarbeitung wird in %qs nicht unterstützt"
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s not supported for variable length aggregates"
 msgstr "%s wird für Aggregattypen mit variabler Länge nicht unterstützt"
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "%s not supported on this target"
 msgstr "%s wird auf diesem Ziel nicht unterstützt"
@@ -26234,16 +26234,16 @@ msgid "function returns address of local variable"
 msgstr "Funktion liefert Adresse einer lokalen Variablen zurück"
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, gcc-internal-format
@@ -26255,366 +26255,366 @@ msgstr "hier deklariert"
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr "%<nonnull%>-Argument %qD wird mit NULL verglichen"
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr "%qE-Ausgabe könnte vor dem letzten Formatzeichen abgeschnitten sein"
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr "%qE-Ausgabe ist vor dem letzten Formatzeichen abgeschnitten"
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr "%qE könnte ein abschließendes NUL hinter das Ende des Ziels schreiben"
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr "%qE schreibt ein abschließendes NUL hinter das Ende des Ziels"
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] "%<%.*s%>-Direktive schreibt %wu Byte in eine Region der Größe %wu"
 msgstr[1] "%<%.*s%>-Direktive schreibt %wu Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von %wu Byte in eine Region der Größe %wu"
 msgstr[1] "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von %wu Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von %wu Byte in eine Region der Größe %wu"
 msgstr[1] "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von %wu Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von bis zu %wu Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von bis zu %wu Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr "%<%.*s%>-Direktive schreibt bis zu %wu Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von wahrscheinlich %wu oder mehr Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von wahrscheinlich %wu oder mehr Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr "%<%.*s%>-Direktive schreibt wahrscheinlich %wu oder mehr Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von %wu bis %wu Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von %wu bis %wu Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr "%<%.*s%>-Direktive schreibt zwischen %wu und %wu Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von %wu oder mehr Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von %wu oder mehr Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr "%<%.*s%>-Direktive schreibt %wu oder mehr Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] "%<%.*s%>-Direktive schreibt %wu Byte in eine Region der Größe zwischen %wu und %wu"
 msgstr[1] "%<%.*s%>-Direktive schreibt %wu Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von %wu Byte in eine Region der Größe zwischen %wu und %wu"
 msgstr[1] "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von %wu Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von %wu Byte in eine Region der Größe zwischen %wu und %wu"
 msgstr[1] "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von %wu Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von bis zu %wu Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von bis zu %wu Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-Direktive schreibt bis zu %wu Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von wahrscheinlich %wu oder mehr Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von wahrscheinlich %wu oder mehr Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-Direktive schreibt wahrscheinlich %wu oder mehr Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben zwischen %wu und %wu Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von %wu bis %wu Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-Direktive schreibt zwischen %wu und %wu Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von %wu oder mehr Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von %wu oder mehr Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-Direktive schreibt %wu oder mehr Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr "Argument %<%.*s%> für Direktive ist null"
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr "Ausgabe der %<%.*s%>-Direktive von %wu Bytes überschreitet die minimal erforderliche Größe von 4095"
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr "Ausgabe der %<%.*s%>-Direktive zwischen %wu und %wu Bytes überschreitet die minimal erforderliche Größe von 4095"
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr "Ausgabe der %<%.*s%>-Direktive zwischen %wu und %wu Bytes könnte die minimal erforderliche Größe von 4095 überschreiten"
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr "Ausgabe der Direktive %<%.*s%> übersteigt mit %wu Bytes %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr "Ausgabe der Direktive %<%.*s%> zwischen %wu und %wu Bytes übersteigt %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "Ausgabe der %<%.*s%>-Direktive von %wu Bytes macht das Ergebnis größer als %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "Ausgabe der %<%.*s%>-Direktive zwischen %wu und %wu Bytes macht das Ergebnis größer als %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr "Ausgabe der %<%.*s%>-Direktive zwischen %wu und %wu Bytes könnte das Ergebnis größer als %<INT_MAX%> machen"
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr "Argument der Direktive %<%.*s%> ist keine nul-terminierte Zeichenkette"
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, gcc-internal-format
 msgid "referenced argument declared here"
 msgstr "das referenzierte Argument wird hier deklariert"
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] "angenommen, dass die Ausgabe der Direktive %wu Byte groß ist"
 msgstr[1] "angenommen, dass die Ausgabe der Direktive %wu Bytes groß ist"
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "Direktiven-Argument %qE"
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr "Direktiven-Argument im Bereich [%E, %E]"
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr "das Intervall [%E, %E] wird für das Argument der Direktive verwendet"
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgid_plural "%qE output %wu bytes into a destination of size %wu"
 msgstr[0] "%qE hat %wu Byte in ein Ziel der Größe %wu ausgegeben"
 msgstr[1] "%qE hat %wu Byte in ein Ziel der Größe %wu ausgegeben"
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr "%qE hat zwischen %wu und %wu Bytes in das Ziel der Größe %wu ausgegeben"
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr "%qE hat %wu oder mehr Bytes (angenommen %wu) in das Ziel der Größe %wu ausgegeben"
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr "%qE hat %wu oder mehr Bytes in das Ziel der Größe %wu ausgegeben"
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
 msgstr[0] "%qE hat %wu Byte ausgegeben"
 msgstr[1] "%qE hat %wu Bytes ausgegeben"
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes"
 msgstr "%qE hat zwischen %wu und %wu Bytes ausgegeben"
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr "%qE hat %wu oder mehr Bytes (angenommen %wu) ausgegeben"
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes"
 msgstr "%qE hat %wu oder mehr Bytes ausgegeben"
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr "Breite für %<%.*s%>-Direktive außerhalb des zulässigen Bereichs"
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr "Genauigkeit der %<%.*s%>-Direktive außerhalb des zulässigen Bereichs"
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr "Im Aufruf von %qE überlappen sich die Argumente %Z und vielleicht %Z mit dem Zielobjekt %qE"
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 msgid "%qE argument %Z overlaps destination object %qE"
 msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] "%qE Argument %Z überlappt das Zielobjekt %qE"
 msgstr[1] "%qE Argumente %Z überlappen das Zielobjekt %qE"
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 msgid "%qE argument %Z may overlap destination object %qE"
 msgid_plural "%qE arguments %Z may overlap destination object %qE"
 msgstr[0] "%qE Argument %Z überlappt möglicherweise das Zielobjekt %qE"
 msgstr[1] "%qE Argumente %Z überlappen möglicherweise das Zielobjekt %qE"
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr "Zielobjekt, auf das durch %<restrict%>-qualifiziertes Argument 1 verwiesen wird, wurde hier deklariert"
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr "angegebene Grenze %wu überschreitet maximale Objektgröße %wu"
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr "angegebene Grenze %wu überschreitet %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, gcc-internal-format
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr "angegebene Bereichsgrenze [%wu, %wu] überschreitet %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, gcc-internal-format
 msgid "null destination pointer"
 msgstr "Zielzeiger ist NULL"
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr "angegebene Grenze %wu überschreitet die Größe %wu des Zielobjekts"
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, gcc-internal-format
 msgid "null format string"
 msgstr "NULL-Formatzeichenkette"
@@ -27351,12 +27351,12 @@ msgstr "baumelnder Zeiger auf %qD wird verwendet"
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD ist hier deklariert"
@@ -28119,7 +28119,7 @@ msgstr "Token %u hat %<x-location == %u%>"
 msgid "token %u has %<y-location == %u%>"
 msgstr "Token %u hat %<y-location == %u%>"
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "ungültige Verwendung des Attributs %<fallthrough%>"
@@ -28463,17 +28463,17 @@ msgstr "Name %qs wird in einer anderen Übersetzungseinheit mit unterschiedliche
 msgid "mismatching definition"
 msgstr "abweichende Definition"
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr "ungültige »fnsummary« in LTO-Datenstrom"
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr "IPA-Inline-Zusammenfassung fehlt in Eingabedatei"
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, gcc-internal-format
 msgid "IPA modref summary is missing in input file"
 msgstr "IPA-modref-Zusammenfassung fehlt in Eingabedatei"
@@ -29536,72 +29536,72 @@ msgstr "Fehler beim Schreiben der Optimierungsdatensätze in %qs: %s"
 msgid "error closing optimization records %qs"
 msgstr "Fehler beim Schließen der Datei für Optimierungsdatensätze %qs"
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, gcc-internal-format
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "Kommandozeilenoption %qs wird von dieser Konfiguration nicht unterstützt"
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "fehlendes Argument für %qs"
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr "Argument für %qs sollte eine nicht-negative Ganzzahl sein, optional gefolgt von einer Größeneinheit"
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer"
 msgstr "Argument von %qs sollte eine nicht-negative Ganzzahl sein"
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, gcc-internal-format
 msgid "argument to %qs is not between %d and %d"
 msgstr "Argument von %qs ist nicht zwischen %d und %d"
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, gcc-internal-format
 msgid "invalid argument in option %qs"
 msgstr "ungültiges Argument in Option %qs"
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr "%qs ist in derselben Option mehrfach angegeben"
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, gcc-internal-format
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr "%qs und %qs schließen sich gegenseitig aus und können nicht zusammen angegeben werden"
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, gcc-internal-format
 msgid "unrecognized argument in option %qs"
 msgstr "nicht erkanntes Kommandozeilenargument in Option %qs"
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %qs sind: %s; meinten Sie %qs?"
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "gültige Argumente für %qs sind: %s"
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "Schalter %qs wird nicht mehr unterstützt"
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, gcc-internal-format
 msgid "argument to %qs is bigger than %d"
 msgstr "Argument für %qs ist größer als %d"
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, gcc-internal-format
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
 msgstr "ungültige %<COLLECT_GCC_OPTIONS%>"
@@ -29675,8 +29675,8 @@ msgstr "Argument von %<-O%> sollte eine nicht-negative Ganzzahl, %<g%>, %<s%>, %
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, gcc-internal-format
 msgid "%qs is incompatible with %qs"
 msgstr "%qs ist mit %qs unverträglich"
@@ -30400,7 +30400,7 @@ msgstr "globale Registervariable folgt einer Funktionsdefinition"
 msgid "register of %qD used for multiple global register variables"
 msgstr "Register von %qD für mehrere globale Registervariablen verwendet"
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "Konflikt mit %qD"
@@ -30878,42 +30878,42 @@ msgstr "Abschnitt des Aliases %q+D muss zum Abschnitt seines Ziels passen"
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "%<__builtin_saveregs%> wird von diesem Ziel nicht unterstützt"
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, gcc-internal-format
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "Argument %qs wird für %qs auf diesem Ziel nicht unterstützt"
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, gcc-internal-format
 msgid "nested functions not supported on this target"
 msgstr "geschachtelte Funktionen werden auf diesem Ziel nicht unterstützt"
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, gcc-internal-format
 msgid "nested function trampolines not supported on this target"
 msgstr "-ffunction-sections wird für dieses Ziel nicht unterstützt"
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "globale Konstruktoren werden für dieses Ziel nicht unterstützt"
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "globale Destruktoren werden für dieses Ziel nicht unterstützt"
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, gcc-internal-format
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "%<target%>-Attribut wird auf dieser Maschine nicht unterstützt"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, gcc-internal-format
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "%<target_version%>-Attribut wird auf dieser Maschine nicht unterstützt"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, gcc-internal-format
 msgid "%<#pragma GCC target%> is not supported for this machine"
 msgstr "%<#pragma GCC target%> wird für diese Maschine nicht unterstützt"
@@ -32050,82 +32050,82 @@ msgstr "Interner Compilerfehler: BB %i has incorrect edge"
 msgid "BB %i has incorrect fallthru edge"
 msgstr "Interner Compilerfehler: BB %i has incorrect fallthru edge"
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr "die Funktion %q+F kann nie kopiert werden, da sie ein nichtlokales »goto« empfängt"
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr "die Funktion %q+F kann nie kopiert werden, da sie die Adresse einer lokalen Marke in statischer Variablen speichert"
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr "die Funktion %q+F kann nie »inline« sein, da sie alloca verwendet (zum Aufheben: Attribut »always_inline« verwenden)"
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr "die Funktion %q+F kann nie »inline« sein, da sie setjmp verwendet"
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr "die Funktion %q+F kann nie »inline« sein, da sie eine variable Argumentliste verwendet"
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr "die Funktion %q+F kann nie »inline« sein, da sie »setjmp-longjmp«-Ausnahmebehandlung verwendet"
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr "die Funktion %q+F kann nie »inline« sein, da sie ein nichtlokales »goto« enthält"
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr "die Funktion %q+F kann nie »inline« sein, da sie %<__builtin_return%> oder %<__builtin_apply_args%> verwendet"
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr "die Funktion %q+F kann nie »inline« sein, da sie ein berechnetes »goto« enthält"
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr "die Funktion %q+F kann nie »inline« sein, da sie ein Argument vom Typ Array variabler Länge hat"
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr "die Funktion %q+F kann nie inline sein, da dies mit %<-fno-inline%> unterdrückt wird"
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr "Funktion %q+F kann nie inline sein, da sie mit inline in Konflikt stehende Attribute hat"
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, gcc-internal-format
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr "Inlining beim Aufruf von %q+F mit %<always_inline%> fehlgeschlagen: %s"
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr "von hier aufgerufen"
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, gcc-internal-format
 msgid "called from this function"
 msgstr "von dieser Funktion aus aufgerufen"
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, gcc-internal-format
 msgid "inlining failed in call to %q+F: %s"
 msgstr "»inline« beim Aufruf von %q+F gescheitert: %s"
@@ -32180,27 +32180,27 @@ msgstr "invalid fn spec attribute \"%s\""
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr "invalid fn spec attribute \"%s\" arg %i"
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr "Zeiger %qs ist null"
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, gcc-internal-format
 msgid "in a call to non-static member function %qD"
 msgstr "in einem Aufruf der nicht-statischen Elementfunktion %qD"
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr "Argument %u ist null, aber nichtnull wird erwartet"
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "in einem Aufruf der eingebauten Funktion %qD"
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, gcc-internal-format
 msgid "in a call to function %qD declared %qs"
 msgstr "in einem Aufruf der Funktion %qD, die als %qs deklariert ist"
@@ -32405,7 +32405,7 @@ msgstr "%qs ist nicht initialisiert, wird aber benutzt"
 msgid "%qs may be used uninitialized"
 msgstr "%qs könnte uninitialisiert verwendet werden"
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD wurde hier deklariert"
@@ -32651,7 +32651,7 @@ msgstr "Vektorbedingung wird stückweise ausgeweitet"
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "Vektorumverteilungsoperation wird stückweise ausgeweitet"
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr "Vektorisierung für eine SIMD-Schleife nicht durchgeführt"
@@ -32666,122 +32666,122 @@ msgstr "non-constant element in constant CONSTRUCTOR"
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr "side-effects element in no-side-effects CONSTRUCTOR"
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "Arrays von Funktionen sind sinnlos"
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "Rückgabetyp der Funktion kann keine Funktion sein"
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "tree check: %s, have %s in %s, at %s:%d"
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "tree check: expected none of %s, have %s in %s, at %s:%d"
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, gcc-internal-format
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, gcc-internal-format
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD ist veraltet: %s"
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD ist veraltet"
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE ist veraltet: %s"
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE ist veraltet"
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "Typ ist veraltet: %s"
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "Typ ist veraltet"
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, gcc-internal-format
 msgid "%qD is unavailable: %s"
 msgstr "%qD ist nicht verfügbar: %s"
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, gcc-internal-format
 msgid "%qD is unavailable"
 msgstr "%qD ist nicht verfügbar"
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, gcc-internal-format
 msgid "%qE is unavailable: %s"
 msgstr "%qE ist nicht verfügbar: %s"
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, gcc-internal-format
 msgid "%qE is unavailable"
 msgstr "%qE ist nicht verfügbar"
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, gcc-internal-format, gfc-internal-format
 msgid "type is unavailable: %s"
 msgstr "Typ ist nicht verfügbar: %s"
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, gcc-internal-format
 msgid "type is unavailable"
 msgstr "Typ ist nicht verfügbar"
@@ -32806,262 +32806,262 @@ msgstr "Typ ist nicht verfügbar"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr "Interner Compilerfehler: type variant differs by %s"
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr "Interner Compilerfehler: type variant has different %<TYPE_SIZE_UNIT%>"
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr "Interner Compilerfehler: type variant%'s %<TYPE_SIZE_UNIT%>"
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr "Interner Compilerfehler: type%'s %<TYPE_SIZE_UNIT%>"
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr "Interner Compilerfehler: type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr "Interner Compilerfehler: type variant has different %<TYPE_VFIELD%>"
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr "Interner Compilerfehler: type variant has different %<TYPE_BINFO%>"
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr "Interner Compilerfehler: type variant%'s %<TYPE_BINFO%>"
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr "Interner Compilerfehler: type%'s %<TYPE_BINFO%>"
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr "Interner Compilerfehler: type variant has different %<TYPE_FIELDS%>"
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "Interner Compilerfehler: first mismatch is field"
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, gcc-internal-format
 msgid "and field"
 msgstr "Interner Compilerfehler: and field"
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr "Interner Compilerfehler: type variant has different %<TREE_TYPE%>"
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr "Interner Compilerfehler: type variant%'s %<TREE_TYPE%>"
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr "Interner Compilerfehler: type%'s %<TREE_TYPE%>"
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "Interner Compilerfehler: type is not compatible with its variant"
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is not an opaque type"
 msgstr "Typ %s ist kein undurchsichtiger Ausdruck"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is not with opaque mode"
 msgstr "Typ %s ist nicht im undurchsichtigen Modus"
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr "Typ %s unterscheidet sich durch %<TYPE_MODE%>"
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr "Typ %s unterscheidet sich durch %<TYPE_SIZE%>"
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr "Typ %s unterscheidet sich durch %<TYPE_ALIGN%>"
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr "Typ %s unterscheidet sich durch %<TYPE_USER_ALIGN%>"
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, gcc-internal-format
 msgid "main variant is not defined"
 msgstr "Interner Compilerfehler: main variant is not defined"
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr "Interner Compilerfehler: %<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr "Interner Compilerfehler: %<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr "Interner Compilerfehler: %<TYPE_CANONICAL%> is not compatible"
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr "Interner Compilerfehler: %<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr "Interner Compilerfehler: %<TYPE_CANONICAL%> of main variant is not main variant"
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr "Interner Compilerfehler: %<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr "Interner Compilerfehler: %<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr "Interner Compilerfehler: %<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr "Interner Compilerfehler: %<TYPE_BINFO%> is not %<TREE_BINFO%>"
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr "Interner Compilerfehler: %<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr "Interner Compilerfehler: %<TYPE_METHOD_BASETYPE%> is not record nor union"
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr "Interner Compilerfehler: %<TYPE_OFFSET_BASETYPE%> is not record nor union"
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr "Interner Compilerfehler: %<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr "Interner Compilerfehler: %<TYPE_MAX_VALUE_RAW%> non-NULL"
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr "Interner Compilerfehler: %<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr "Interner Compilerfehler: enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr "Interner Compilerfehler: enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr "Interner Compilerfehler: enum value name is not %<IDENTIFIER_NODE%>"
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "Interner Compilerfehler: array %<TYPE_DOMAIN%> is not integer type"
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "Interner Compilerfehler: %<TYPE_FIELDS%> defined in incomplete type"
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr "Interner Compilerfehler: wrong tree in %<TYPE_FIELDS%> list"
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr "Interner Compilerfehler: %<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr "Interner Compilerfehler: %<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr "Interner Compilerfehler: wrong %<TYPE_CACHED_VALUES%> entry"
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr "Interner Compilerfehler: %<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr "Interner Compilerfehler: wrong entry in %<TYPE_ARG_TYPES%> list"
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr "Interner Compilerfehler: %<TYPE_VALUES_RAW%> field is non-NULL"
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr "Interner Compilerfehler: %<TYPE_CACHED_VALUES_P%> is set while it should not be"
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr "Interner Compilerfehler: %<TYPE_METHOD_BASETYPE%> is not main variant"
@@ -33276,7 +33276,7 @@ msgstr "Alias-Definitionen werden in dieser Konfiguration nicht unterstützt"
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "Sichtbarkeitsattribute werden in dieser Konfiguration nicht unterstützt; ignoriert"
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr "%+qD ohne %<retain%>-Attribut und %qD mit %<retain%>-Attribut liegen in einem Abschnitt mit demselben Namen"
@@ -33478,7 +33478,7 @@ msgstr "Attribut %qE ignoriert, da %qD keine Variable ist"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "Attribut %qE ignoriert, da %qD keine lokale Variable ist"
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "Attribut %qE wirkt sich nur auf öffentliche Objekte aus"
@@ -33660,7 +33660,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr "Attribut %qE wird ignoriert, da es sich nicht auf eine Variable bezieht"
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for local variables"
 msgstr "Attribut %qE kann nicht für lokale Variablen angegeben werden"
@@ -33975,7 +33975,7 @@ msgstr "%qD ist mit %qD unverträglich"
 msgid "%qE argument is not a function"
 msgstr "Argument %qE ist keine Funktion"
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "Veraltete Meldung ist keine Zeichenkette"
@@ -34483,7 +34483,7 @@ msgstr "ISO-C++ erlaubt kein auf Funktionstypen angewendetes %<alignof%>"
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr "ISO-C erlaubt kein auf Funktionstypen angewendetes %<_Alignof%>"
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, gcc-internal-format
 msgid "invalid application of %qs to a void type"
 msgstr "Ungültige Anwendung von %qs auf einen void-Typen"
@@ -34614,17 +34614,17 @@ msgstr "Attribut %<fallthrough%> ist mehrfach angegeben"
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "%<fallthrough%>-Attribut mit einem Parameter angegeben"
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "Zu wenige Argumente für Funktion %qE"
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, gcc-internal-format
@@ -34748,166 +34748,166 @@ msgstr "Versuch, die Adresse des Bitfeldstrukturelements %qD zu ermitteln"
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "Index %E markiert einen Offset größer als die Größe von %qT"
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "Arraygröße ist zu groß"
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "Operandentyp %qT ist inkompatibel mit Argument %d von %qE"
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, gcc-internal-format
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "als Argument 1 wurde entweder ein Zeigertyp oder ein Ganzzahltyp erwartet"
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr "die beiden Argumente müssen kompatibel sein"
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "Falsche Anzahl der Argumente für Funktion %qE"
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "Argument 1 von %qE muss ein Nicht-Void-Zeigertyp sein"
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr "Argument 1 von %qE muss ein Zeiger auf einen vollständigen Typen sein"
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "Argument 1 von %qE muss ein Zeiger auf Typen konstanter Größe sein"
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "Argument 1 von %qE muss ein Zeiger auf Objekt breiter als Null sein"
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "Argument %d von %qE muss eine Zeigertyp sein"
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "Argument %d von %qE muss ein Zeiger auf Typen konstanter Größe sein"
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "Argument %d von %qE darf kein Zeiger auf eine Funktion sein"
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "Unpassende Größe in Argument %d von %qE"
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr "Argument %d von %qE darf kein Zeiger auf einen %<const%>-Typen sein"
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, gcc-internal-format
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr "Argument %d von %qE entfernt Kennzeichner %<const%>"
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr "Argument %d von %qE darf kein Zeiger auf einen %<volatile%>-Typen sein"
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, gcc-internal-format
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr "Argument %d von %qE entfernt Kennzeichner %<volatile%>"
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "Nicht-Ganzzahlargument %d für Speichermodell von %qE"
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "ungültiges Argument %d für Speichermodell von %qE"
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr "dieses Ziel definiert keine Spekulationsbarriere; das erzeugte Programm wird trotzdem korrekt laufen, aber irrige Spekulationen sind möglicherweise nicht eingeschränkt"
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "Indexwert ist außerhalb der Grenzen"
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "Umwandlung von Skalar %qT in Vektor %qT führt zum Abschneiden"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "eingebaute Funktion %qE muss direkt aufgerufen werden"
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr "Größe des Arrays %qE ist kein konstanter Ausdruck"
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr "Größe des Arrays ist kein konstanter Ausdruck"
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr "Größe %qE des Arrays %qE ist negativ"
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, gcc-internal-format
 msgid "size %qE of array is negative"
 msgstr "Größe %qE des Arrays ist negativ"
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr "Größe %qE des Arrays %qE übersteigt maximale Objektgröße %E"
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr "Größe %qE des Arrays überschreitet maximale Objektgröße %qE"
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "Größe des Arrays %qE übersteigt maximale Objektgröße %E"
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr "Größe des Arrays übersteigt maximale Objektgröße %qE"
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr "Umgebungsvariable %qs muss ganzzahlig sein und zwischen 0 und %wd liegen"
@@ -35531,7 +35531,7 @@ msgstr "Ganzzahlkonstante ist zu groß für %<unsigned _BitInt(%d)%>-Typ"
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr "Ganzzahlkonstante ist zu groß für %<_BitInt(%d)%>-Typ"
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, gcc-internal-format
 msgid "%<_BitInt(%d)%> is not supported on this target"
 msgstr "%<_BitInt(%d)%> wird für dieses Ziel nicht unterstützt"
@@ -35611,7 +35611,7 @@ msgstr "nicht unterstützte Nicht-Standard-Verkettung von Zeichenkettenliteralen
 msgid "traditional C rejects string constant concatenation"
 msgstr "traditionelles C weist Zeichenkettenkonstantenverkettung zurück"
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr "%<#pragma omp critical%> mit %<hint%>-Klausel erfordert einen Namen, außer wenn %<omp_sync_hint_none%> verwendet wird"
@@ -35667,7 +35667,7 @@ msgstr "%<depobj%>-Abhängigkeitstyp in %<depend%>-Klausel von %<depobj%> angege
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "%<iterator%>-Modifizierer darf nicht bei einem %<depobj%>-Konstrukt angegeben sein"
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ungültiger Typ für Schleifenvariable %qE"
@@ -35682,17 +35682,17 @@ msgstr "%<_Atomic%>-Iterationsvariable %qE"
 msgid "%qE is not initialized"
 msgstr "%qE ist nicht initialisiert"
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Steuerprädikat fehlt"
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Steuerprädikat ungültig"
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "Erhöhungsausdruck fehlt"
@@ -35702,7 +35702,7 @@ msgstr "Erhöhungsausdruck fehlt"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr "Erhöhung ist weder konstant 1 noch konstant -1 für die %<!=%>-Bedingung"
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Erhöhungsausdruck ungültig"
@@ -35787,7 +35787,7 @@ msgstr "ungültiger %<task%>-Reduktionsmodifizierer in Konstrukt, das nicht mit
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr "%<inscan%>-%<reduction%>-Klausel bei Konstruktion außer %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr "%qD ist in %<allocate%>-Klausel angegeben, aber nicht in einer expliziten Privatisierungs-Klausel"
@@ -35797,7 +35797,7 @@ msgstr "%qD ist in %<allocate%>-Klausel angegeben, aber nicht in einer explizite
 msgid "%qD is not a function argument"
 msgstr "%qD ist kein Funktionsargument"
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "Bitfeld %qE in %qs-Klausel"
@@ -36389,7 +36389,7 @@ msgid "wrong type argument to %s"
 msgstr "Argument falschen Typs für %s"
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -37313,35 +37313,35 @@ msgstr "Vergleich zwischen zwei Arrays"
 
 #: c-family/c-warn.cc:3832
 #, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
-msgstr "verwenden Sie das unäre %<+%>, das Operanden zu Zeigern degradiert, oder %<&%D[0] %s &%D[0]%>, um die Adressen zu vergleichen"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
+msgstr "das unäre %<+%> verwenden, das Operanden zu Zeigern oder zu %<&%s%E%s[0] %s &%s%E%s[0]%> degradiert, um die Adressen zu vergleichen"
 
-#: c-family/c-warn.cc:3836
+#: c-family/c-warn.cc:3839
 #, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
-msgstr "verwenden Sie %<&%D[0] %s &%D[0]%>, um die Adressen zu vergleichen"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
+msgstr "%<&%s%E%s[0] %s &%s%E%s[0]%> verwenden, um die Adressen zu vergleichen"
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr "das Ergebnis von %<%wu ^ %wu%> ist %wu; meinten Sie %<1 << %wu%> (%wu)?"
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr "das Ergebnis von %<%wu ^ %wu%> ist %wu; meinten Sie %<1LL << %wu%>?"
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr "das Ergebnis von %<%wu ^ %wu%> ist %wu; meinten Sie Potenzbildung?"
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr "das Ergebnis von %<%wu ^ %wu%> ist %wu; meinten Sie %<1e%wu%>?"
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr "Sie können diese Warnung unterdrücken, indem Sie eine hexadezimale Konstante verwenden (%wx statt %wd)"
@@ -37552,122 +37552,122 @@ msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 3
 msgstr "für die Option %<-mcache-block-size=X%> sind nur die Werte 4, 8, 16, 32, 64, 128, 256 oder 512 gültig"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99291
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr "%<-march=%s%>: Erweiterung %qs kommt mehr als einmal vor"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99291
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr "%<-march=%s%>: Erweiterung %qs ist eine nicht unterstützte Einbuchstaben-Erweiterung"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99291
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr "%<-march=%s%>: die Erweiterung %qs beginnt mit %<z%>, ist aber eine nicht unterstützte Standarderweiterung"
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr "%<-march=%s%>: Erweiterung %qs beginnt mit %<s%>, ist aber eine nicht unterstützte Standard-Supervisor-Erweiterung"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99291
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr "%<-march=%s%>: Erweiterung %qs beginnt mit %<x%>, ist jedoch eine nicht unterstützte Nicht-Standard-Erweiterung"
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, gcc-internal-format
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr "%<-march=%s%>: nach %<%dp%> muss eine Zahl stehen"
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr "%<-march=%s%>: für %<%s%dp%dp?%> wird Versionsnummer mit mehr als 2 Stufen nicht unterstützt"
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr "%<-march=%s%>: ISA-Zeichenkette muss mit %<rv32%> oder %<rv64%> anfangen"
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr "%<-march=%s%>: rv%de ist keine gültige Basis-ISA"
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr "Version von %<g%> wird weggelassen, bitte geben Sie die Version für die individuelle Erweiterung an"
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr "%<-march=%s%>: erste ISA-Teilmenge muss %<e%>, %<i%> oder %<g%> sein"
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, gcc-internal-format
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr "%<-march=%s%>: Die Erweiterung %<%c%> ist keine einbuchstabige Erweiterung."
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99291
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr "%<-march=%s%>: Erweiterung zcf wird nur in rv32 unterstützt"
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr "%<-march=%s%>: z*inx ist mit Gleitkommaerweiterungen unverträglich"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99291
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, gcc-internal-format
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr "%<-march=%s%>: Erweiterung h erfordert Erweiterung i"
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr "%<-march=%s%>: zcd steht im Konflikt mit zcmt"
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr "%<-march=%s%>: zcd steht im Konflikt mit zcmp"
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr "%<-march=%s%>: xtheadvector steht im Konflikt mit der Vektorerweiterung oder ihren Untererweiterungen"
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "%<-march=%s%>: Name von %s muss mehr als 1 Buchstabe sein"
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr "%<-march=%s%>: %s müssen durch %<_%> getrennt sein"
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, gcc-internal-format
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr "%<-march=%s%>: i, e oder g muss die erste Erweiterung sein"
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "%<-mcpu=%s%>: unbekannte CPU"
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr "Keine Menge von geeigneten Multibibliotheken für %<-march=%s%>/%<-mabi=%s%> gefunden"
@@ -38067,12 +38067,12 @@ msgstr "64-Bit-Adresse erwartet, aber Argument 1 hat %d Bit"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "64-Bit-Adresse erwartet, aber Argument 2 hat %d Bit"
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC aarch64%> erfordert eine Zeichenkette als Parameter"
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "unbekannte Option %qs für %<#pragma GCC aarch64%>"
@@ -38636,7 +38636,7 @@ msgstr "die Parameterübergabe für das Argument vom Typ %qT hat sich in GCC 14.
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "die Parameterübergabe für das Argument vom Typ %qT hat sich in GCC 9.1 geändert"
@@ -38712,13 +38712,13 @@ msgid "unknown tuning option (%s)"
 msgstr "unbekannte Tuning-Option »%s«"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr "die Optionen %<-mstack-protector-guard=global%> und %<-mstack-protector-guard-offset=%s%> sind unverträglich"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90153
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr "wenn %<-mstack-protector-guard=sysreg%> angegeben ist, müssen sowohl %<-mstack-protector-guard-offset%> als auch %<-mstack-protector-guard-reg%> angegeben werden"
@@ -38730,7 +38730,7 @@ msgid "specify a system register with a small string length"
 msgstr "Systemregister mit einem kurzem Namen angeben"
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs ist in %qs kein gültiger Offset"
@@ -38915,9 +38915,9 @@ msgstr "Pragma oder Attribut %<target(\"%s\")%> erlaubt keine negierte Form"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "Pragma oder Attribut %<target(\"%s=%s\")%> ist nicht gültig"
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "Argument für Attribut %<target%> ist keine Zeichenkette"
@@ -38969,18 +38969,18 @@ msgid "virtual function multiversioning not supported"
 msgstr "Multiversionierung virtueller Funktionen wird nicht unterstützt"
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "Multiversionierung erfordert %<ifunc%>, was auf diesem Ziel nicht unterstützt wird"
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr "die Parameterübergabe für das Argument vom Typ %qT mit %<[[no_unique_address]]%>-Elementen hat sich %{in GCC 10.1%} geändert"
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr "die Parameterübergabe für das Argument vom Typ %qT hat sich, sofern C++17 aktiviert ist, so geändert, dass es C++14 %{in GCC 10.1%} entspricht"
 
@@ -38993,8 +38993,8 @@ msgstr "die Parameterübergabe für das Argument vom Typ %qT hat sich %{mit GCC
 msgid "lane %wd out of range %wd - %wd"
 msgstr "Spur %wd ist außerhalb des Wertebereiches %wd bis %wd"
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "nicht unterstützte simdlen %wd"
@@ -39004,7 +39004,7 @@ msgstr "nicht unterstützte simdlen %wd"
 msgid "GCC does not currently support return type %qT for simd"
 msgstr "GCC bietet derzeit keine Unterstützung für Rückgabetyp %qT für SIMD-Funktionen"
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "nicht unterstützter Rückgabetyp %qT für SIMD"
@@ -39014,7 +39014,7 @@ msgstr "nicht unterstützter Rückgabetyp %qT für SIMD"
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr "GCC bietet derzeit keine Unterstützung für Parametertyp %qT für SIMD-Funktionen"
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "nicht unterstützter Argumenttyp %qT für SIMD"
@@ -39104,8 +39104,8 @@ msgstr "L%d Cache-Wartezeit unbekannt für %s"
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "falscher Wert %qs für %<-mmemory-latency%>"
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr "Falscher eingebauter fcode"
@@ -39225,18 +39225,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "Argument des Attributes %qE ist weder »ilink« oder »firq«"
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -39350,7 +39350,7 @@ msgid "argument of %qE attribute is missing"
 msgstr "Argument des Attributs %qE fehlt"
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "Attribut %qE erlaubt nur eine Ganzzahlkonstante als Argument"
@@ -39370,23 +39370,23 @@ msgstr "Attribut %qE kann nur auf Typen angewandt werden"
 msgid "argument of %qE attribute ignored"
 msgstr "Argument des Attributs %qE wird ignoriert"
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "Attribut %qE bezieht sich nur auf Variablen"
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "Alternativen sind in %<asm%>-Flag-Ausgabe nicht erlaubt"
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr "unbekannte Ausgabe %qs des %<asm%>-Schalters"
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "ungültiger Typ für %<asm%>-Schalter-Ausgabe"
@@ -39630,7 +39630,7 @@ msgstr "Ziel-CPU unterstützt keine THUMB-Befehle"
 msgid "target CPU does not support unaligned accesses"
 msgstr "Ziel-CPU unterstützt keine unausgerichteten Zugriffe"
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr "Diese Architektur unterstützt keine Befehle mit Sprungschutz"
@@ -39680,7 +39680,7 @@ msgstr "Grenze für Strukturgröße kann nur auf 8 oder 32 gesetzt werden"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC ist mit %<-msingle-pic-base%> unverträglich"
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "Der FDPIC-Modus wird im Thumb-1-Modus nicht unterstützt"
@@ -39786,7 +39786,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr "Argument vom Typ %qT ist zusammen mit %<-mgeneral-regs-only%> nicht erlaubt"
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "die Parameterübergabe für das Argument vom Typ %qT hat sich in GCC 7.1 geändert"
@@ -39826,43 +39826,43 @@ msgstr "Attribut %qE wirkt sich nicht auf Funktionen mit »static«-Bindung aus"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "Attribut %qE kann nur auf Basistypen von Funktionszeiger angewandt werden"
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr "Zugriff auf threadlokalen Speicher wird derzeit mit %<-mpure-code%> oder %<-mslow-flash-data%> nicht unterstützt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79871
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "»%s« %wd ist außerhalb des gültigen Bereichs von %wd bis %wd"
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "Wirkliche Stelle des gestapelten Parameters kann nicht berechnet werden"
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Unexpected thumb1 far jump"
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "keine unteren Register für das Hervorholen der hohen Register verfügbar"
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "Interrupt-Dienst-Routinen können nicht im »Thumb-1«-Modus codiert werden"
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "%<-fstack-check=specific%> für Thumb-1"
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "ungültige FPU für Zielattribut oder -pragma %qs"
@@ -39870,22 +39870,22 @@ msgstr "ungültige FPU für Zielattribut oder -pragma %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "automatische FPU-Auswahl ist hier momentan nicht erlaubt"
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "Ungültige Architektur für Zielattribut oder -pragma %qs"
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "Unbekanntes Zielattribut oder -pragma %qs"
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "%<asm%>-Schalter werden im Thumb1-Modus nicht unterstützt"
@@ -39939,159 +39939,159 @@ msgstr "Unterstützte Kernarchitekturen:%s"
 msgid "unknown core architecture %qs specified with %qs"
 msgstr "Unbekannte Kernarchitektur %qs in %qs angegeben"
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, gcc-internal-format
 msgid "%<-fpic%> is not supported"
 msgstr "%<-fpic%> wird nicht unterstützt"
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, gcc-internal-format
 msgid "%<-fPIC%> is not supported"
 msgstr "%<-fPIC%> wird nicht unterstützt"
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, gcc-internal-format
 msgid "%<-fpie%> is not supported"
 msgstr "%<-fpie%> wird nicht unterstützt"
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, gcc-internal-format
 msgid "%<-fPIE%> is not supported"
 msgstr "%<-fPIE%> wird nicht unterstützt"
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "Funktionsattribute %qs und %qs schließen sich gegenseitig aus"
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "Funktion %qs kann keine Argumente haben"
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "Funktion %qs kann keinen Wert zurückgeben"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79883
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, gcc-internal-format
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs scheint ein falsch geschriebener %qs-Handler zu sein, das Präfix %<__vector%> fehlt"
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr "%qs ist in der AVR-LibC ein reservierter Bezeichner. Erwägen Sie %<#include <avr/interrupt.h>%> vor der Benutzung des Makros %qs"
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, gcc-internal-format
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr "%qs ist in der AVR-LibC ein veralteter Bezeichner. Erwägen Sie %<#include <avr/interrupt.h>%> oder %<#include <compat&deprecated.h>%> vor der Benutzung des Makros %qs"
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr "%<builtin_return_address%> enthält nur 2 Adressbytes"
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr "Zeigeroffset von Symbol könnte falsch sein"
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr "Zugriff auf Datenspeicher mit Programmspeicheradresse"
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr "Zugriff auf Programmspeicher mit Datenspeicheradresse"
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr "festes Register %s zur Parameterübergabe an Funktion verwendet"
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "Schreibzugriff auf Adressraum %qs wird nicht unterstützt"
 
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "Attribut %qE kann nur für »static«-Variablen verwendet werden"
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "Attribut %qE wird nur für reduzierte Tiny-Kerne unterstützt"
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, gcc-internal-format
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr "Adresse von Attribut %qE außerhalb des gültigen Bereichs 0x%x%s0x%x"
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr "sowohl »%s« als auch das %qE-Attribut geben die Adresse an"
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "Attribut %qE an nicht-»volatile«-Variable"
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "Adressräume werden auf reduzierten Tiny-Kernen nicht unterstützt"
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "Adressraum %qs wird auf Geräten mit Flashspeicher bis zu %d KiB nicht unterstützt"
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr "Zeiger auf Adressraum %qs muss in %qT konstant sein"
 
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr "Zeiger auf Adressraum %qs muss in %s %q+D konstant sein"
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, gcc-internal-format
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr "variablen %q+D, die mit dem %qs-Attribut markiert ist, muss im statischen Speicher verortet sein"
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr "Variable %q+D muss konstant sein, um mit %qs in Nur-Lese-Abschnitt gelegt zu werden"
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, gcc-internal-format
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr "statische Attributdeklaration %qs für %q+D erfordert eine Adresse"
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr "Nur uninitialisierte Variablen können im %<.noinit%>-Bereich platziert werden"
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, gcc-internal-format
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr "dynamisch initialisierte Variable %q+D in Programmspeicherbereich platziert"
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "nicht initialisierte Variable %q+D in Programmspeicherbereich platziert"
@@ -40100,42 +40100,42 @@ msgstr "nicht initialisierte Variable %q+D in Programmspeicherbereich platziert"
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, gcc-internal-format
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr "die Variable %q+D mit dem Attribut %qs darf keinen Initialisierer haben"
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%q+D hat unverträgliche Attribute %qs und %qs"
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr "Architektur %qs wird nur für Assemblierung unterstützt"
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "Umwandlung von Adressraum %qs in Adressraum %qs"
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "%s erwartet eine Ganzzahlkonstante zur Kompilierzeit"
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%s erwartet eine Long-Ganzzahlkonstante als erstes Argument zur Kompilierzeit"
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr "Rundung auf %d Bits hat keinen Effekt für Festkommawert mit %d Bit Nachkommaanteil"
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr "Rundungsergebnis wird immer 0 sein"
@@ -40271,7 +40271,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "indirekter Aufruf in Funktion, das wird von eBPF nicht unterstützt"
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, gcc-internal-format
@@ -40890,8 +40890,8 @@ msgstr "Das Argument zum eingebauten %<xabort%> ein 8-Bit-Direktwert sein"
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr "Funktionsversionen können nicht als %<gnu_inline%> markiert werden, Körper müssen generiert werden"
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "Codemodell %s unterstützt keinen PIC-Modus"
@@ -40957,255 +40957,255 @@ msgstr "zu viele Größenbereiche in Option %qs angegeben"
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "Unbekannter Parameter für Option %<-mtune-ctrl%>: %s"
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "Intel-MCU-psABI wird im %s-Modus nicht unterstützt"
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> ist veraltet; stattdessen entsprechend %<-mtune=k8%> oder %<-mtune=generic%> verwenden"
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> ist veraltet; stattdessen entsprechend %<target(\"tune=k8\")%> oder %<target(\"tune=generic\")%> verwenden"
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr "Unterstützung von %<-mtune=knl%> wird in GCC 15 entfernt"
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr "Unterstützung für %<target(\"tune=knl\")%> wird in GCC 15 entfernt"
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr "Unterstützung von %<-mtune=knm%> wird in GCC 15 entfernt"
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr "Unterstützung für %<target(\"tune=knm\")%> wird in GCC 15 entfernt"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "%<-mstringop-strategy=rep_8byte%> wird für 32-Bit-Code nicht unterstützt"
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, gcc-internal-format
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "%<-mapxf%> wird für 32-Bit-Code nicht unterstützt"
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, gcc-internal-format
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr "%<-mapx-features=%> wird für 32-Bit-Code nicht unterstützt"
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "%<-muintr%> wird für 32-Bit-Code nicht unterstützt"
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "%<-mlam=%>-Option: [u48|u57] wird für 32-Bit-Code nicht unterstützt"
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "Adressmodus %qs wird im %s-Bit-Modus nicht unterstützt"
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-mabi=ms%> wird in der X32-ABI nicht unterstützt"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "%<-mabi=%s%> wird nicht zusammen mit %<-fsanitize=address%> unterstützt"
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "%<-mabi=%s%> wird nicht zusammen mit %<-fsanitize=kernel-address%> unterstützt"
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "%<-mabi=%s%> wird nicht zusammen mit %<-fsanitize=thread%> unterstützt"
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr "%<-mlam=u48%> ist nicht kompatibel mit hardwareunterstütztem AddressSanitizer, stattdessen wird %<-mlam=u57%> verwendet"
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "Codemodell %qs wird im %s-Bit-Modus nicht unterstützt"
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "Codemodell %qs wird im x32-Modus nicht unterstützt"
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "%<-masm=intel%> wird in dieser Konfiguration nicht unterstützt"
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-Bit-Modus nicht einkompiliert"
 
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "%<generic%>-CPU kann nur für %<-mtune=%>-Schalter verwendet werden"
 
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "%<generic%>-CPU kann nur für %<target(\"tune=\")%>-Schalter verwendet werden"
 
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "die CPU %<intel%> kann nur für den Schalter %<-mtune=%> verwendet werden"
 
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "die CPU %<intel%> kann nur für das Attribut %<target(\"tune=\")%> verwendet werden"
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "Die ausgewählte CPU unterstützt nicht den x86-64-Befehlssatz"
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr "Unterstützung für %<-march=knl%> wird in GCC 15 entfernt"
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr "Unterstützung für %<target(\"arch=knl\")%> wird in GCC 15 entfernt"
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr "Unterstützung für %<-march=knm%> wird in GCC 15 entfernt"
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr "Unterstützung für %<target(\"arch=knm\")%> wird in GCC 15 entfernt werden"
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, gcc-internal-format
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "falscher Wert %qs für Schalter %<-march=%>"
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "unbekannter Wert %qs für Attribut %<target(\"arch=\")%>"
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<-march=%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<target(\"arch=\")%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "gültige Argumente für %<-march=%> sind: %s"
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "gültige Argumente für %<target(\"arch=\")%> sind: %s"
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "falscher Wert %qs für Schalter %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "falscher Wert %qs für Attribut %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<-mtune=%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<target(\"tune=\")%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "gültige Argumente für %<-mtune=%> sind: %s"
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "gültige Argumente für %<target(\"tune=\")%> sind: %s"
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "%<-mregparm%> wird im 64-Bit-Modus ignoriert"
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "%<-mregparm%> wird für Intel-MCU-psABI ignoriert"
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "%<-mregparm=%d%> liegt nicht zwischen 0 und %d"
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "%<-m96bit-long-double%> ist nicht mit diesem Ziel kompatibel"
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> wird im 64-Bit-Modus ignoriert"
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> wird im 64-Bit-Modus ignoriert"
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr "%<-mno-evex512%> oder %<-mno-avx512XXX%> kann AVX10-Befehle nicht deaktivieren, wenn AVX10.1-512 verfügbar ist"
@@ -41213,290 +41213,290 @@ msgstr "%<-mno-evex512%> oder %<-mno-avx512XXX%> kann AVX10-Befehle nicht deakti
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr "Die Verwendung von %<-mevex512%> ohne aktivierte AVX512-Funktionen zusammen mit AVX10.1 aktiviert keine AVX512- oder AVX10.1-512-Funktionen und verwendet 256 als maximale Vektorgröße"
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr "Vektorgrößenkonflikte zwischen AVX10.1 und AVX512, als maximale Vektorgröße wird 512 verwendet"
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr "%<-mno-avx512XXX%> kann AVX10-Anweisungen nicht deaktivieren, wenn AVX10 verfügbar ist"
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> können AVX512-Anweisungen nicht deaktivieren, wenn %<-mavx512XXX%> gewählt ist"
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "%<-mpreferred-stack-boundary%> wird für dieses Ziel nicht unterstützt"
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> liegt nicht zwischen %d und %d"
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "%<-mincoming-stack-boundary=%d%> liegt nicht zwischen %d und 12"
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%<-mnop-mcount%> ist nicht mit diesem Ziel kompatibel"
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "%<-mnop-mcount%> ist für %<-fPIC%> nicht implementiert"
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> verwendet, ohne dass SSE eingeschaltet ist"
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> verwendet, ohne dass SSE eingeschaltet ist"
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE-Befehlssatz ausgeschaltet, es wird 387-Arithmetik verwendet"
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387-Befehlssatz ausgeschaltet, es wird SSE-Arithmetik verwendet"
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "Stapel-Überprüfung erfordert %<-maccumulate-outgoing-args%> für Korrektheit"
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "Stapel-Überprüfung erfordert %<target(\"accumulate-outgoing-args\")%> für Korrektheit"
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "feststehendes ebp-Register erfordert %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "feststehendes ebp-Register erfordert %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "%<-mfentry%> wird für 32 Bit in Kombination mit %<-fpic%> nicht unterstützt"
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%<-mno-fentry%> ist nicht mit SEH verträglich"
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "%<-mcall-ms2sysv-xlogues%> wird derzeit nicht zusammen mit SEH unterstützt"
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "unbekannte Option für %<-mrecip=%s%>"
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs ist keine gültige Zahl in %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs ist kein gültiger Offset in %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs ist kein gültiges Basisregister in %<-mstack-protector-guard-reg=%>"
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr "%<-fcf-protection=full%> wird von %<-fhardened%> nicht aktiviert, da es in der Befehlszeile angegeben wurde"
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%<-fcf-protection%> ist nicht mit diesem Ziel kompatibel"
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "die Attribute %<interrupt%> und %<naked%> sind nicht kompatibel"
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "Attribute %qs und %qs sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr "Nur das DWARF-Debugformat ist für Interrupt-Service-Routinen unterstützt"
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> und %<-mcmodel=large%> sind nicht kompatibel"
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mindirect-branch%> und %<-fcf-protection%> sind nicht kompatibel"
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> und %<-mcmodel=large%> sind nicht kompatibel"
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mfunction-return%> und %<-fcf-protection%> sind nicht kompatibel"
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%s-Befehle sind in Exception-Serviceroutine nicht erlaubt"
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "%s-Befehle sind in Interrupt-Serviceroutine nicht erlaubt"
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "%s-Befehle sind in Funktionen mit %<no_caller_saved_registers%>-Attribut nicht erlaubt"
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "Attribute fastcall und regparm sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "Attribute regparam und thiscall sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "Attribut %qE benötigt eine Ganzzahlkonstante als Argument"
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "Argument für Attribut %qE ist größer als %d"
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "Attribute fastcall und cdecl sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "Attribute fastcall und stdcall sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "Attribute fastcall und thiscall sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "Attribute stdcall und cdecl sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "Attribute stdcall und fastcall sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "Attribute stdcall und thiscall sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "Attribute cdecl und thiscall sind nicht verträglich"
 
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "Attribut %qE wird für Nicht-Klassen-Methode verwendet"
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-inkompatibles Attribut wird ignoriert"
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "Attribut %qE nur für 32 Bit verfügbar"
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "Argument des Attributes %qE ist weder Null noch Eins"
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "Attribut %qE erfordert eine Zeichenkettenkonstante als Argument"
 
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "Argument des Attributes %qE ist nicht (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "in Interrupt-Service-Routinen sollte das erste Argument ein Zeiger sein"
 
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "in Interrupt-Service-Routinen sollte das zweite Argument vom Typ %qs sein"
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "Interrupt-Service-Routine darf nur ein Zeiger- und ein optionales Ganzzahl-Argument haben"
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "Interrupt-Service-Routine muss den Rückgabetyp %<void%> haben"
@@ -41689,46 +41689,46 @@ msgid "non-integer operand used with operand code %<z%>"
 msgstr "Nicht-Ganzzahl-Operand mit Operandencode %<z%> verwendet"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90164
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr "das ABI zum Übergeben von leeren Klassen (%qT) als Parametern hat sich mit %<-fabi-version=12%> (GCC 8) geändert"
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr "die Ausrichtung von %<_Atomic %T%>-Feldern wurde mit %{GCC 11.1%} geändert"
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, gcc-internal-format
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr "kein Register für die Profilerstellung von %<-mcmodel=large%s%> verfügbar"
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "Profiling von %<-mcmodel=large%> wird mit PIC nicht unterstützt"
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr "%<__bfloat16%> ist seit GCC 13.1 von typedef %<short%> zum echten %<__bf16%> umdefiniert, Vorsicht bei impliziter Konvertierung zwischen %<__bf16%> und %<short%>; hier kann ein explizites Bitcast nötig sein"
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "Unbekanntes architekturspezifisches Speichermodell"
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr "%<HLE_ACQUIRE%> wird mit %<ACQUIRE%> oder stärkerem Speichermodell nicht verwendet"
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr "%<HLE_RELEASE%> wird mit %<RELEASE%> oder stärkerem Speichermodell nicht verwendet"
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr "%<-fexcess-precision=16%> ist nicht mit %<-mfpmath=387%> kompatibel"
@@ -41748,8 +41748,8 @@ msgstr "Definition des statischen Datenelementes %q+D einer »dllimport«-ierten
 msgid "malformed %<#pragma builtin%>"
 msgstr "Falsch geformtes %<#pragma builtin%>"
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, gcc-internal-format
 msgid "invalid argument of %qE attribute"
 msgstr "ungültiges Argument für Attribut %qE"
@@ -41804,12 +41804,12 @@ msgstr "%<PRINT_OPERAND%>: Unbekanntes Satzzeichen %<%c%>"
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr "%<PRINT_OPERAND%> Null-Zeiger"
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "Argument %d der eingebauten Funktion muss eine Konstante aus dem Bereich %d bis %d sein"
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, gcc-internal-format
 msgid "failed to expand built-in function"
 msgstr "eingebaute Funktion konnte nicht expandiert werden"
@@ -41935,17 +41935,17 @@ msgstr "Codemodell %qs ist inkompatibel zu %s"
 msgid "%qs cannot be used for compiling a shared library"
 msgstr "%qs kann nicht zum Übersetzen einer gemeinsam genutzten Bibliothek verwendet werden"
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr "Attribut %qE kann nicht für threadlokale Variablen angegeben werden"
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for register variables"
 msgstr "Attribut %qE kann nicht für Register-Variablen angegeben werden"
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, gcc-internal-format
 msgid "multiple %qE attribute"
 msgstr "doppeltes Attribut %qE"
@@ -42046,12 +42046,12 @@ msgstr "mehrere Interruptattribute sind nicht erlaubt"
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr "%<interrupt_thread%> ist nur auf Fido verfügbar"
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "Ausdruck der Stapelgrenze wird nicht unterstützt"
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not supported on this target"
 msgstr "%<-fexcess-precision=16%> wird auf diesem Ziel nicht unterstützt"
@@ -42092,7 +42092,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr "%<-mxl-multiply-high%> erfordert %<-mno-xl-soft-mul%>"
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "Attribut %qE erfordert eine Zeichenkettenkonstante als Argument"
@@ -42132,132 +42132,132 @@ msgstr "Interruptvektor für %qE-Attribut ist nicht %<vector=(sw0|sw1|hw0|hw1|hw
 msgid "argument to %qE attribute is not intstack"
 msgstr "Argument des Attributes %qE ist nicht »intstack«"
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr "die ABI für die Übergabe eines Wertes, der Felder mit Null-Breite vor einem benachbarten 64-Bit-Gleitkommafeld enthält, wurde %{mit GCC 12.1%} geändert"
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr "die ABI für die Rückgabe eines Wertes, der Bit-Felder mit der Breite Null enthält, aber ansonsten ein Aggregat mit nur einem oder zwei Fließkomma-Feldern ist, wurde %{mit GCC 12.1%} geändert"
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr "die ABI für die Rückgabe eines Wertes, der leere C++17-Basen enthält, aber ansonsten ein Aggregat mit nur einem oder zwei Fließkomma-Feldern ist, wurde %{mit GCC 12.1%} geändert"
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, gcc-internal-format
 msgid "cannot handle inconsistent calls to %qs"
 msgstr "inkonsistente Aufrufe von %qs können nicht behandelt werden"
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr "das %<interrupt%>-Attribut erfordert einen MIPS32r2-Prozessor oder neuer"
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr "Interrupthandler können keine MIPS16-Funktionen sein"
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr "%<-fstack-check=specific%> nicht für MIPS16 implementiert"
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, gcc-internal-format
 msgid "built-in function %qE not supported for MIPS16"
 msgstr "eingebaute Funktion %qE nicht für MIPS16 unterstützt"
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, gcc-internal-format
 msgid "%qs does not support MIPS16 code"
 msgstr "%qs unterstützt keinen MIPS16-Code"
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr "MIPS16 PIC für ABIs außer o32 und o64"
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, gcc-internal-format
 msgid "MIPS16 %<-mxgot%> code"
 msgstr "MIPS16 %<-mxgot%> Code"
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, gcc-internal-format
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr "%<hard-float%> MIPS16-Code für andere ABIs als o32 und o64"
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, gcc-internal-format
 msgid "MSA MIPS16 code"
 msgstr "MSA-MIPS16-Code"
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, gcc-internal-format
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr "MIPS16 erfordert %<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported combination: %s"
 msgstr "nicht unterstützte Kombination: %s"
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, gcc-internal-format
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr "%<-%s%> steht in Konflikt mit den anderen Architekturoptionen, die einen %s-Prozessor angeben"
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, gcc-internal-format
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr "%<-march=%s%> ist mit dem ausgewählten ABI unverträglich"
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr "%<-mgp64%> mit einem 32-Bit-Prozessor verwendet"
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, gcc-internal-format
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr "%<-mgp32%> mit einem 64-Bit-ABI verwendet"
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr "%<-mgp64%> mit einem 32-Bit-ABI verwendet"
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "die Architektur %qs unterstützt %<-mfp32%> nicht"
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr "%<-mgp32%> und %<-mfp64%> können nur kombiniert werden, wenn das Ziel die Befehle mfhc1 und mthc1 unterstützt"
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr "%<-mgp32%> und %<-mfp64%> können nur kombiniert werden, wenn o32-ABI verwendet wird"
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr "%<-mfpxx%> kann nur mit dem o32-ABI verwendet werden"
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr "%<-march=%s%> erfordert %<-mfp32%>"
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr "%<-mfpxx%> erfordert %<-mlra%>"
@@ -42267,117 +42267,117 @@ msgstr "%<-mfpxx%> erfordert %<-mlra%>"
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, gcc-internal-format
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr "die Kombination von %qs und %qs ist mit %qs unverträglich"
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, gcc-internal-format
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr "die Architektur %qs unterstützt keine Befehle mit Sprungwahrscheinlichkeit"
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, gcc-internal-format
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr "die Architektur %qs unterstützt die Befehle »madd« und »msub« nicht"
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr "die Architektur %qs unterstützt keine ungeraden Register für einfache Genauigkeit"
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, gcc-internal-format
 msgid "unsupported combination: %qs%s %s"
 msgstr "nicht unterstützte Kombination: %qs%s %s"
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, gcc-internal-format
 msgid "unsupported combination: %qs %s"
 msgstr "nicht unterstützte Kombination: %qs %s"
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, gcc-internal-format
 msgid "cannot generate position-independent code for %qs"
 msgstr "für %qs kann kein lageunabhängiger Code erzeugt werden"
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, gcc-internal-format
 msgid "position-independent code requires %qs"
 msgstr "lageunabhängiger Code erfordert %qs"
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr "%<-mno-gpopt%> erfordert %<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr "Kleindatenzugriffe für %qs nicht möglich"
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr "die Architektur %qs unterstützt %<-m%s=legacy%> nicht"
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr "die Architektur %qs unterstützt %<-m%s=2008%>"
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, gcc-internal-format
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr "%<-mips3d%> erfordert %<-mpaired-single%>"
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, gcc-internal-format
 msgid "%qs must be used with %qs"
 msgstr "%qs muss mit %qs verwendet werden"
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, gcc-internal-format
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr "%<-mmsa%> muss zusammen mit %<-mfp64%> und %<-mhard-float%> verwendet werden"
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, gcc-internal-format
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr "die Architektur %qs unterstützt keine paarweisen Einzel-Befehle"
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr "%qs erfordert ein Ziel, das den %qs-Befehl unterstützt"
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, gcc-internal-format
 msgid "the %qs architecture does not support DSP instructions"
 msgstr "die Architektur %qs unterstützt keine DSP-Befehle"
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, gcc-internal-format
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr "%<-mloongson-mmi%> muss zusammen mit %<-mhard-float%> verwendet werden"
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, gcc-internal-format
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr "%<-mloongson-ext2%> muss zusammen mit %<-mloongson-ext%> verwendet werden"
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, gcc-internal-format
 msgid "%qs requires branch-likely instructions"
 msgstr "%qs erfordert sprungwahrscheinliche Befehle"
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, gcc-internal-format
 msgid "the %qs architecture does not support the synci instruction"
 msgstr "die Architektur %qs unterstützt nicht den synci-Befehl"
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr "Profiling für mips16-Funktionen"
@@ -43252,59 +43252,59 @@ msgstr "%<#pragma riscv intrinsic%> erfordert eine Zeichenkette als Parameter"
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "unbekannte Option %qs für %<#pragma riscv intrinsic%>"
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr "unerwartete Architektur für %<target()%>-Attribut: muss mit + oder rv beginnen"
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr "unerwartete Architektur für %<target()%>-Attribut: Fehlerhafte Zeichenfolge %<%s%> gefunden"
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, gcc-internal-format
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr "%<target()%>-Attribut: Architektur erscheint mehr als einmal"
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, gcc-internal-format
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr "%<target()%>-Attribut: CPU erscheint mehr als einmal"
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr "%<target()%>-Attribut: unbekannte CPU %qs"
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, gcc-internal-format
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr "%<target()%>-Attribut: tune erscheint mehr als einmal"
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr "%<Ziel()%>-Attribut: unbekanntes TUNE %qs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79868
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, gcc-internal-format
 msgid "malformed %<target()%> attribute"
 msgstr "falsch geformtes %<target()%>-Attribut"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79868
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, gcc-internal-format
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "Attribut %<target(\"%s\")%> akzeptiert keine Argumente"
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, gcc-internal-format
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr "Unbekanntes Attribut %<target(\"%s\")%>"
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> attribute"
 msgstr "falsch geformtes Attribut %<target(\"%s\")%>"
@@ -43364,172 +43364,192 @@ msgstr "der RVV-Typ %qT kann weder geworfen noch gefangen werden"
 msgid "capture by copy of RVV type %qT"
 msgstr "der RVV-Typ %qT kann nicht durch Kopieren gefangen werden"
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, gcc-internal-format
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr "Eingebaute Funktion %qE erfordert die ISA-Erweiterung zvfhmin oder zvfh"
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr "Eingebaute Funktion %qE erfordert die ISA-Erweiterung zve32f, zve64f, zve64d oder v"
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr "Eingebaute Funktion %qE erfordert die ISA-Erweiterung zve64d oder v"
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr "Eingebaute Funktion %qE erfordert die ISA-Erweiterung zve64x, zve64f, zve64d oder v"
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, gcc-internal-format
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr "Eingebaute Funktion %qE erfordert die ISA-Erweiterung %qs"
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, gcc-internal-format
 msgid "no matching function call to %qE with empty arguments"
 msgstr "kein passender Funktionsaufruf für %qE mit leeren Argumenten"
 
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "unbekannte CPU %qs für %<-mtune%>"
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, gcc-internal-format
 msgid "this operation requires the RVV ISA extension"
 msgstr "diese Operation erfordert die RVV-ISA-Erweiterung"
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr "Sie können RVV mit der Befehlszeilenoption %<-march%>, oder mit dem Attribut %<target%> oder Pragma aktivieren"
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI für abgeflachte Struktur mit Bit-Feldern der Länge 0 hat wurde mit GCC 10 geändert"
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, gcc-internal-format
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr "der RVV-Typ %qT kann nur an prototypisierte Funktionen übergeben werden"
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, gcc-internal-format
 msgid "%s %qT requires the V ISA extension"
 msgstr "%s %qT benötigt die V-ISA-Erweiterung"
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, gcc-internal-format
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr "%s %qT benötigt die ISA-Erweiterung zve64x, zve64f, zve64d oder v"
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, gcc-internal-format
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr "%s %qT benötigt die ISA-Erweiterung zvfhmin oder zvfh"
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, gcc-internal-format
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr "%s %qT benötigt die ISA-Erweiterung zve32f, zve64f, zve64d oder v"
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, gcc-internal-format
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr "%s %qT benötigt die ISA-Erweiterung zve64d oder v"
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr "%s %qT benötigt mindestens die Vektorlänge %qd, aber %qd ist gegeben"
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, gcc-internal-format
 msgid "function attribute %qs requires the V ISA extension"
 msgstr "Funktionsattribut %qs erfordert die ISA-Erweiterung V"
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "Argument des Attributs %qE muss %<\"user\"%>, %<\"supervisor\"%> oder %<\"machine\"%> sein"
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr "%qs wird nur unterstützt, wenn %<-mrvv-vector-bits=zvl%> angegeben ist"
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, gcc-internal-format
 msgid "%qs applied to non-RVV type %qT"
 msgstr "%qs angewendet auf Nicht-RVV-Typ %qT"
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, gcc-internal-format
 msgid "%qs requires an integer constant"
 msgstr "%qs erfordert eine konstante Ganzzahl"
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr "ungültige RVV-Vektorgröße %qd, erwartete Größe ist %qd basierend auf LMUL des Typs und %qs"
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "%<-mdiv%> erfordert %<-march%>, um die %<M%>-Erweiterung zu ermitteln"
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr "Der aktuelle RISC-V-GCC unterstützt keine VLEN größer als 4096bit für die Erweiterung »V«"
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr "Der aktuelle RISC-V-GCC unterstützt RVV im Big-Endian-Modus nicht"
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, gcc-internal-format
 msgid "code model %qs with %qs"
 msgstr "Codemodell %qs mit %qs"
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "die angeforderte ABI erfordert %<-march%>, um die %qc-Erweiterung zu ermitteln"
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr "rv32e erfordert die ilp32e-ABI"
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, gcc-internal-format
 msgid "rv64e requires lp64e ABI"
 msgstr "rv64e erfordert lp64e-ABI"
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr "z*inx erfordert ABI ilp32, ilp32e, lp64 oder lp64e"
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "ABI erfordert %<-march=rv%d%>"
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> muss zwischen %d und %d liegen"
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr "%<-mriscv-attribute%> RISC-V-ELF-Attribut erfordert GNU as 2.32 [%<-mriscv-attribute%>]"
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs ist in %qs kein gültiges Basisregister"
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs ist in %qs keine gültige Zahl"
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qs-Funktion kann keine andere Interrupt-Art haben"
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr "vl-Register für %qs kann auf diesem Ziel nicht alloziert werden"
@@ -43779,32 +43799,32 @@ msgstr "Eingebaute Funktion %qs akzeptiert genau 2 Argumente"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "Eingebaute Funktion %qs akzeptiert genau 3 Argumente"
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "%<vec_lvsl%> ist für Little-Endian veraltet; verwenden Sie Zuweisungen für unausgerichtete Speicherzugriffe"
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "%<vec_lvsr%> ist für Little-Endian veraltet; verwenden Sie Zuweisungen für unausgerichtete Speicherzugriffe"
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, gcc-internal-format
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr "Übergabe des Arguments %d von %qE entfernt Kennzeichner %qs von Zeiger-Zieltyp"
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "ungültige Parameterkombination für AltiVec-spezifisches intrinsisches %qs"
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, gcc-internal-format
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr "überladene eingebaute Funktion %qs ist durch die eingebaute Funktion %qs umgesetzt"
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%qs wird von dieser Compiler-Konfiguration nicht unterstützt"
@@ -43844,29 +43864,22 @@ msgstr "ungültige Verwendung des MMA-Operanden vom Typ %qs als Parameter einer
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-Vektor per Referenz übergegeben: Nicht-Standard-ABI-Erweiterung ohne Kompatibilitätsgarantie"
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, gcc-internal-format
-msgid "%qs requires the ELFv2 ABI"
-msgstr "%qs erfordert das ELFv2-ABI"
-
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "Stapelrahmen zu groß"
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported number of nops before function entry (%u)"
 msgstr "nicht unterstützte Anzahl von NOPs vor Funktionsanfang (%u)"
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%qs verwendet Register r29"
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "Stapelrahmen größer als 2G wird für %<-fsplit-stack%> nicht unterstützt"
@@ -43991,107 +44004,117 @@ msgstr "%qs erfordert ein gültiges Basisregister"
 msgid "unknown option for %<%s=%s%>"
 msgstr "unbekannte Option für %<%s=%s%>"
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr "%<-mrop-protect%> erfordert %<-mcpu=power8%> oder höher"
+
+#: config/rs6000/rs6000.cc:4837
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr "%<-mrop-protect%> erfordert das ELFv2-ABI"
+
+#: config/rs6000/rs6000.cc:4855
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs ist veraltet und wird unter keinen Umständen empfohlen"
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr "%qs ist ein undurchsichtiger Typ, und Sie können ihn nicht auf andere Werte setzen"
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "kein Profiling von 64-bit-Code für dieses ABI"
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "Bei Verwendung der Option %qs kann die Adresse von geschachtelten Funktionen nicht verwendet werden"
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "Verwendung von %<long double%> in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "Verwendung boolescher Typen in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "Verwendung von %<complex%> in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "Verwendung dezimaler Gleitkommatypen in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "Verwendung von %<long%> in AltiVec-Typen ist für 64-Bit-Code ohne %qs ungültig"
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "Verwendung von %<long%> in AltiVec-Typen ist veraltet; %<int%> verwenden"
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "Verwendung von %<long long%> in AltiVec-Typen ist ohne %qs ungültig"
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "Verwendung von %<double%> in AltiVec-Typen ist ohne %qs ungültig"
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "ungültige CPU %qs für %s%qs%s"
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s ist nicht erlaubt"
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s ist ungültig"
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> schaltet %<-m%s%> aus"
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "das Attribut %<target_clones%> erfordert GLIBC (2.23 oder neuer), die Hardware-Fähigkeits-Bits exportiert"
 
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Multiversionierung virtueller Funktionen wird nicht unterstützt"
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr "das Ergebnis des Befehls xxspltidp ist für denormalisierte Eingabewerte undefiniert"
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "Typ %<__vector_quad%> erfordert die Option %qs"
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr "Typ %<__vector_pair%> erfordert die Option %qs"
@@ -44138,7 +44161,7 @@ msgstr "RX-FPU-Befehle unterstützen keine NaNs und Unendlichkeiten"
 msgid "builtin %qs can only be used on vector types"
 msgstr "das eingebaute %qs kann nur mit Vektortypen verwendet werden"
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "Konstanter Wert erwartet für Argument %2$d der eingebauten Funktion %1$qF"
@@ -44208,227 +44231,227 @@ msgstr "%qs-Matchingvariante ist veraltet"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "Konstantes Argument %d für eingebaute %qF liegt außerhalb des Wertebereiches für Zieltyp"
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr "konstantes Argument %d für eingebautes %qF ist ungültig (%s)"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90180
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr "konstantes Argument %d für eingebaute %qF liegt außerhalb des Bereichs 0 bis %wu"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79846
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr "konstantes Argument %d für eingebaute %qF liegt außerhalb des Bereichs %wd bis %wd"
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr "eingebaute %qF wird nur mit %<-mhtm%> unterstützt (standardmäßig für %<-march=zEC12%> und höher eingeschaltet)"
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr "eingebaute %qF wird nur mit %<-mvx%> unterstützt (standardmäßig für %<-march=z13%> und höher eingeschaltet)"
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher"
 msgstr "Eingebaute %qF erfordert z14 oder höher"
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher"
 msgstr "Eingebaute %qF erfordert z15 oder höher"
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "unaufgelöste überladene eingebaute Funktion"
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "Falscher eingebauter ICode"
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "Ungültiges Argument %d für eingebaute Funktion %qF"
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "das angeforderte %qE-Attribut ist kein kommaseparierter Paar von nichtnegativen ganzzahligen Konstanten, oder es ist zu groß (maximal %d)"
 
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "Argument für %qE ist nicht (keep|thunk|thunk-extern)"
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "Gesamtgröße der lokalen Variablen übersteigt Grenze der Architektur"
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr "Rahmengröße der Funktion %qs ist %wd Bytes, das ist größer als die benutzerdefinierte Stapelgrenze von %d Bytes; eine bedingungslose Falle wird gesetzt"
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr "Rahmengröße der Funktion %qs ist %wd Bytes, das ist mehr als die Hälfte der Stapelgröße; die dynamische Prüfung wäre nicht zuverlässig; für diese Funktion wird keine Prüfcode generiert"
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "Rahmengröße von %qs ist %wd Bytes"
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs verwendet dynamische Stapelanforderung"
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr "die Parameterübergabe für das Argument vom Typ %qT mit Bitfeldern der Breite 0 hat sich in GCC 12 geändert"
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "auf s390 können geschachtelte Funktionen mit %<-mfentry%> nicht im Profiling verwendet werden"
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-Bit-ABI nicht unterstützt im ESA/390-Modus"
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr "thunk-inline wird nur mit %<-mindirect-branch-jump%> unterstützt"
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "Hardware-Vektorunterstützung ist auf %s nicht verfügbar"
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "Hardware-Vektorunterstützung ist mit %<-msoft-float%> nicht verfügbar"
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr "Dezimale Hardware-Gleitkommabefehle sind auf %s nicht verfügbar"
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, gcc-internal-format
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr "Dezimale Hardware-Gleitkommabefehle sind im ESA/390-Modus nicht verfügbar"
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr "%<-mhard-dfp%> kann nicht in Verbindung mit %<-msoft-float%> verwendet werden"
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "die Kombination aus %<-mbackchain%>, %<-mpacked-stack%> und %<-mhard-float%> wird nicht unterstützt"
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "Stapelgröße muss größer als der Stapel-Überwachungswert sein"
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "Stapelgröße darf nicht größer als 64k sein"
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "%<-mstack-guard%> bringt %<-mstack-size%> mit sich"
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr "%<-mtpf-trace-hook-prologue-check%> erfordert eine Ganzzahl im Bereich von 0 bis 4095"
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr "%<-mtpf-trace-hook-prologue-target%> erfordert eine Ganzzahl im Bereich von 0 bis 4095"
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr "%<-mtpf-trace-hook-epilogue-check%> erfordert eine Ganzzahl im Bereich von 0 bis 4095"
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr "%<-mtpf-trace-hook-epilogue-target%> erfordert eine Ganzzahl im Bereich von 0 bis 4095"
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%<-mfentry%> wird nur auf 64-Bit-CPUs unterstützt"
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "Argumente von %qs sollten nicht-negative Ganzzahlen sein"
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "Argument für %qs ist zu groß (max. %d)"
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr "%<-mno-pic-data-is-text-relative%> kann nur zusammen mit %<-fpic%>/%<-fPIC%> verwendet werden"
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, gcc-internal-format
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr "beim Attribut %<target%> ist das Argument %qs unbekannt"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "Wert %qs wird von Attribut %<target%> nicht unterstützt"
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, gcc-internal-format
 msgid "invalid cc output constraint: %qs"
 msgstr "ungültige cc-Ausgabebeschränkung: %qs"
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, gcc-internal-format
 msgid "multiple cc output constraints not supported"
 msgstr "mehrere cc-Ausgabebeschränkungen nicht unterstützt"
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, gcc-internal-format
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr "%<asm%>-Spezifizierer für cc-Ausgabe steht in Konflikt mit %<asm%>-Clobber-Liste"
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, gcc-internal-format
 msgid "invalid type for cc output constraint"
 msgstr "ungültiger Typ für cc-Ausgabebeschränkung"
@@ -44850,8 +44873,8 @@ msgstr "Attribut %qE hat keinen Effekt"
 msgid "attribute %qs applies to array types only"
 msgstr "Attribut %qs bezieht sich nur auf Arraytypen"
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void-Wert nicht ignoriert wie es sein sollte"
@@ -44926,7 +44949,7 @@ msgstr "Typ des Arrays %q+D vervollständigt Unverträglichkeit mit impliziter I
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr "%qE wurde in diesem Gültigkeitsbereich bereits deklariert und ist unvollständig deklariert"
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "ursprünglich hier definiert"
@@ -45158,7 +45181,7 @@ msgstr "Deklaration von %q+D überdeckt eine vorhergehende Nicht-Variable"
 msgid "declaration of %qD shadows a parameter"
 msgstr "Deklaration von %qD überdeckt einen Parameter"
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "Deklaration von %qD überdeckt eine globale Deklaration"
@@ -45168,7 +45191,7 @@ msgstr "Deklaration von %qD überdeckt eine globale Deklaration"
 msgid "declaration of %qD shadows a previous local"
 msgstr "Deklaration von %qD überdeckt einen vorhergehenden lokalen Bezeichner"
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "verdeckte Deklaration ist hier"
@@ -45233,7 +45256,7 @@ msgstr "%qE nicht deklariert (erste Verwendung in dieser Funktion)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "jeder nicht deklarierte Bezeichner wird nur einmal für jede Funktion, in der er vorkommt, gemeldet"
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "Marke %qE außerhalb einer Funktion referenziert"
@@ -45268,7 +45291,7 @@ msgstr "Sprung in Anweisungs-Ausdruck"
 msgid "duplicate label declaration %qE"
 msgstr "Doppelte Markendeklaration %qE"
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "doppelte Marke %qD"
@@ -45303,7 +45326,7 @@ msgstr "switch springt in Anweisungs-Ausdruck"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE als falsche Symbolart definiert"
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "Attribut %qE auf %qD mit Rückgabetyp »void« angewendet"
@@ -45445,12 +45468,12 @@ msgstr "ISO-C90 unterstützt %<[*]%>-Arraydeklaratoren nicht"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> außerhalb des Bereichs des Funktionsprototypen nicht erlaubt"
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, gcc-internal-format
 msgid "%<omp::%s%> not allowed to be specified in this context"
 msgstr "%<omp::%s%> darf in diesem Kontext nicht angegeben werden"
@@ -45460,7 +45483,7 @@ msgstr "%<omp::%s%> darf in diesem Kontext nicht angegeben werden"
 msgid "%q+D is usually a function"
 msgstr "%q+D ist üblicherweise eine Funktion"
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "keine vorherige Deklaration für %qD"
@@ -45536,7 +45559,7 @@ msgstr "Objekt mit volatile-Feld kann nicht in Register geladen werden"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "nicht initialisiertes %<const %qD%> ist in C++ ungültig"
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D in »declare target«-Direktive hat keinen zuordenbaren Typ"
@@ -45721,7 +45744,7 @@ msgstr "Speicherklasse für Parameter %qE angegeben"
 msgid "storage class specified for unnamed parameter"
 msgstr "Speicherklasse für unbenannten Parameter angegeben"
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "Speicherklasse für Typnamen angegeben"
@@ -45784,7 +45807,7 @@ msgstr "Deklaration von %qE als Array von Funktionen"
 msgid "declaration of type name as array of functions"
 msgstr "Deklaration eines Typnamen als Array von Funktionen"
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "ungültige Verwendung einer Struktur mit flexiblem Arrayelement"
@@ -45890,7 +45913,7 @@ msgstr "Typname als Funktion, die ein Array zurückgibt, deklariert"
 msgid "function definition has qualified void return type"
 msgstr "Funktionsdefinition hat qualifizierten void-Rückgabetypen"
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "Typkennzeichner an Funktions-Rückgabewert ignoriert"
@@ -46017,7 +46040,7 @@ msgstr "ISO-C verbietet const- oder volatile-Funktionstypen"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "Ein Element einer Struktur oder Union kann nicht variabel modifizierten Typ haben"
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "Variable oder Feld %qE als »void« deklariert"
@@ -46122,7 +46145,7 @@ msgstr "nicht geschachtelte Funktion mit variabel modifiziertem Typen"
 msgid "object with variably modified type must have no linkage"
 msgstr "Objekt mit variabel geändertem Typ darf keine Bindung haben"
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "Funktionsdeklaration ist kein Prototyp"
@@ -46212,17 +46235,17 @@ msgstr "Verschachtelte Redefinition von %<union %E%>"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "Verschachtelte Redefinition von %<struct %E%>"
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "Typdefinition in Ausdruck %qs ist in C++ ungültig"
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, gcc-internal-format
 msgid "%qT defined in underspecified object initializer"
 msgstr "%qT wurde in unvollständig angegebenem Objektinitialisierer definiert"
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "Deklaration deklariert nichts"
@@ -46252,596 +46275,596 @@ msgstr "leere Struktur hat Größe 0 in C, aber 1 in C++"
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr "leere Union hat Größe 0 in C, aber 1 in C++"
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "Union hat keine benannten Elemente"
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "Union hat keine Elemente"
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "struct hat keine benannten Elemente"
 
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct hat keine Elemente"
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexibles Arrayelement in Union"
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "flexibles Arrayelement nicht am Ende von struct"
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "flexibles Arrayelement in einer Struktur ohne benannte Elemente"
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, gcc-internal-format
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr "Struktur, die ein flexibles Arrayelement enthält, ist nicht am Ende einer anderen Struktur"
 
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "Typ %qT ist zu groß"
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, gcc-internal-format
 msgid "type punning toggles scalar storage order"
 msgstr "Typumgehung schaltet die Reihenfolge der Skalarspeicherung um"
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union kann nicht transparent gemacht werden"
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, gcc-internal-format
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr "Redefinition des Struktur- oder Vereinigungstyps %qT mit variabel modifiziertem Typ"
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, gcc-internal-format
 msgid "redefinition of struct or union %qT"
 msgstr "Redefinition von Struktur- oder Vereinigungstyp %qT"
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "Verschachtelte Redefinition von %<enum %E%>"
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "Redeklaration von %<enum %E%>"
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr "%<enum%> deklariert aber ohne festen zugrundeliegenden Typen definiert"
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "angegebener Modus zu klein für Aufzählungswerte"
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "Aufzählungswerte überschreiten Wertebereich des größten Ganzzahltypen"
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, gcc-internal-format
 msgid "enumeration values exceed range of %qs"
 msgstr "Aufzählungswerte überschreiten Wertebereich von %qs"
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, gcc-internal-format
 msgid "conflicting redefinition of enum %qT"
 msgstr "widersprüchliche Redefinition des Aufzählungstyps %qT"
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "Aufzählungswert für %qE ist keine Ganzzahlkonstante"
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "Aufzählungswert für %qE ist kein Ganzzahlkonstantenausdruck"
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "Überlauf in Aufzählungswerten"
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, gcc-internal-format
 msgid "enumerator value outside the range of underlying type"
 msgstr "Aufzählungswert ist außerhalb des Gültigkeitsbereichs des zugrundeliegenden Typen"
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, gcc-internal-format
 msgid "enumerator value outside the range of %qs"
 msgstr "Aufzählungswert ist außerhalb des Gültigkeitsbereichs von %qs"
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr "ISO C vor C23 beschränkt Aufzählungswerte auf den Bereich von %<int%>"
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "der inline-Funktion %qD wurde das Attribut %qs gegeben"
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "Rückgabetyp ist unvollständig"
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "Rückgabetyp ist auf %<int%> voreingestellt"
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "%q+D ist als variadische Funktion ohne Prototyp definiert"
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "kein vorheriger Prototyp für %qD"
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD wurde vor seiner Definition ohne Prototyp verwendet"
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD wurde vor seiner Definition ohne Deklaration verwendet"
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "Rückgabetyp von %qD ist nicht %<int%>"
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "%<_Atomic%>-qualifizierter Rückgabetyp von %qD"
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD ist normalerweise eine nicht-statische Funktion"
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "Parameterdeklarationen alten Stils in Prototyp-Funktionsdeklaration"
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "traditionelles C weist Funktionsdefinitionen im ISO-C-Stil zurück"
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr "ISO-C unterstützt das Weglassen von Parameternamen in Funktionsdefinitionen erst ab C23"
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "Funktionsdefinition im alten Stil"
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "Parametername fehlt in Parameterliste"
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD als Nicht-Parameter deklariert"
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "mehrere Parameter wurden %qD genannt"
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "Parameter %qD als void deklariert"
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "Typ von %qD ist auf %<int%> voreingestellt"
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "Parameter %qD hat unvollständigen Typen"
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "Deklaration für nicht vorhandenen Parameter %qD"
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "Anzahl der Argumente passt nicht zum eingebauten Prototypen"
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "Anzahl der Argumente passt nicht zum Prototypen"
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "Prototyp-Deklaration"
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "weitergegebenes Argument %qD passt nicht zu eingebautem Prototypen"
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "weitergegebenes Argument %qD passt nicht zum Prototypen"
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "Argument %qD passt nicht zu eingebautem Prototypen"
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "Argument %qD passt nicht zum Prototypen"
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "keine return-Anweisung in nicht void zurückgebender Funktion"
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "Parameter %qD gesetzt, jedoch nicht verwendet"
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "Anfangsdeklarationen in %<for%>-Schleifen sind nur im C99- oder C11-Modus erlaubt"
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "die Option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> oder %<-std=gnu11%> verwenden, um den Code zu übersetzen"
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "Deklarationen im Initialisierungsteil einer %<for%>-Schleife werden von ISO C90 nicht unterstützt; ab ISO C99 geht es"
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "Deklaration der »static«-Variablen %qD in Anfangsdeklaration einer %<for%>-Schleife"
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "Deklaration der %<extern%>-Variablen %qD in Anfangsdeklaration einer %<for%>-Schleife"
 
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> in Anfangsdeklaration einer %<for%>-Schleife deklariert"
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> in Anfangsdeklaration einer %<for%>-Schleife deklariert"
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> in Anfangsdeklaration einer %<for%>-Schleife deklariert"
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "Deklaration der Nicht-Variablen %qD in Anfangsdeklaration einer %<for%>-Schleife"
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "Inkompatible Adressraumkennzeichen %qs und %qs"
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "Doppelter Deklarationsspezifizierer %qE"
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "mehrere Speicherklassen in Deklaration"
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, gcc-internal-format
 msgid "%qs used with %<auto%>"
 msgstr "%qs mit %<auto%> verwendet"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, gcc-internal-format
 msgid "%<auto%> used with %<constexpr%>"
 msgstr "%<auto%> mit %<constexpr%> verwendet"
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "zwei oder mehr Datentypen in Deklaration"
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> ist für GCC zu lang"
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO-C90 unterstützt nicht %<long long%>"
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO-C90 unterstützt keine komplexen Typen"
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO-C unterstützt keine sättigenden Typen"
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "doppeltes %qE"
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO-C unterstützt die Typen %<__int%d%> nicht"
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> wird für dieses Ziel nicht unterstützt"
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO-C90 unterstützt keine booleschen Typen"
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr "ISO-C unterstützt den Typen %<_Float%d%s%> erst ab C23"
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<_Float%d%s%> wird für dieses Ziel nicht unterstützt"
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr "ISO-C unterstützt dezimale Gleitkommazahlen erst ab C23"
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "Festkommatypen werden für dieses Ziel nicht unterstützt"
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO-C unterstützt keine Ganzzahltypen"
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, gcc-internal-format
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr "%<_BitInt%>-Argument ist kein konstanter Ganzzahlausdruck"
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr "%<_BitInt%>-Argument %qE ist kein positiver konstanter Ganzzahlausdruck"
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr "%<_BitInt%>-Argument %qE ist größer als %<BITINT_MAXWIDTH%> %qd"
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "Nachschlagen von %qD würde in C++ ein Feld, keinen Typen zurückgeben"
 
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE ist kein typedef oder eingebauter Typ"
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE ist nicht am Anfang einer Deklaration"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE mit %<auto%> verwendet"
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE mit %<register%> verwendet"
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE mit %<typedef%> verwendet"
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, gcc-internal-format
 msgid "%qE used with %<constexpr%>"
 msgstr "%qE mit %<constexpr%> verwendet"
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO-C99 unterstützt nicht %qE"
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO-C90 unterstützt nicht %qE"
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> vor %<extern%>"
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> vor %<static%>"
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, gcc-internal-format
 msgid "%<typedef%> used with %<auto%>"
 msgstr "%<typedef%> mit %<auto%> verwendet"
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, gcc-internal-format
 msgid "%qE used with %<extern%>"
 msgstr "%qE mit %<extern%> verwendet"
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, gcc-internal-format
 msgid "%qE used with %qs"
 msgstr "%qE mit %qs verwendet"
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "doppeltes %<_Thread_local%> oder %<__thread%>"
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs mit %qE verwendet"
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, gcc-internal-format
 msgid "%<constexpr%> used with %qE"
 msgstr "%<constexpr%> mit %qE verwendet"
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> ohne %<_Fract%> oder %<_Accum%> verwendet"
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO-C unterstützt nicht %<double complex%> bedeutendes einfaches %<complex%>"
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, gcc-internal-format
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr "ISO C unterstützt %<auto%>-Typinferenz erst ab C23"
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr "%<__auto_type%> gefolgt von %<[[]]%>-Attributen"
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO-C unterstützt keine komplexen Ganzzahltypen"
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, gcc-internal-format
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr "Argument für %<signed _BitInt%> muss mindestens 2 sein"
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, gcc-internal-format
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr "ISO-C unterstützt %<%s_BitInt(%d)%> erst ab C23"
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "%<#pragma omp declare reduction%>-Kombinierer verweist auf Variable %qD, die weder %<omp_out%> noch %<omp_in%> ist"
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "%<#pragma omp declare reduction%>-Initialisierung verweist auf Variable %qD, die weder %<omp_priv%> noch %<omp_orig%> ist"
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "left shift of negative value"
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "Links-Schiebe-Weite ist negativ"
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "Rechts-Schiebe-Weite ist negativ"
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "Links-Schiebe-Weite >= Breite des Typs"
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "Rechts-Schiebe-Weite >= Breite des Typs"
@@ -46871,7 +46894,7 @@ msgstr "Konfliktmarker für Versionskontrolle in Datei"
 msgid "to match this %qs"
 msgstr "andere Fundstelle von %qs ist hier"
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "Zeilenende erwartet"
@@ -46881,8 +46904,8 @@ msgstr "Zeilenende erwartet"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO-C verbietet eine leere Quelldatei"
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr "%qs ohne entsprechendes %qs"
@@ -46922,9 +46945,9 @@ msgstr "Unbekannter Typname %qE; meinten Sie %qs?"
 msgid "unknown type name %qE"
 msgstr "unbekannter Typname: %qE"
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "Deklarationsspezifizierer erwartet"
@@ -46954,7 +46977,7 @@ msgstr "%<fallthrough%>-Attribut auf höchster Ebene"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, Bezeichner oder %<(%> erwartet"
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "Präfixattribute werden für Methoden ignoriert"
@@ -46974,7 +46997,7 @@ msgstr "unerwartetes Attribut"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "%<fallthrough%>-Attribut ohne darauffolgendes %<;%>"
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, gcc-internal-format
 msgid "%<assume%> attribute not followed by %<;%>"
 msgstr "%<assume%>-Attribut ohne darauffolgendes %<;%>"
@@ -47065,7 +47088,7 @@ msgstr "Ausdruck in statischer Behauptung ist nicht konstant"
 msgid "static assertion failed: %E"
 msgstr "statische Behauptung gescheitert: %E"
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "statische Behauptung gescheitert"
@@ -47136,10 +47159,10 @@ msgstr "Leeres Enum ist ungültig"
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "Bezeichner erwartet"
@@ -47290,7 +47313,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr "innere Schleifen müssen mit der %<reduction%>-%<inscan%>-Klausel perfekt verschachtelt sein"
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr "Vermischung von OpenMP-Direktiven mit Attribut- und Pragma-Syntax in ein und derselben Anweisung"
@@ -47300,8 +47323,8 @@ msgstr "Vermischung von OpenMP-Direktiven mit Attribut- und Pragma-Syntax in ein
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr "OpenMP-Attribut %<omp::decl%> an einer Anweisung"
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs attribute argument"
 msgstr "unbekannter OpenMP-Direktiven-Name im Argument des Attributs %qs"
@@ -47475,12 +47498,12 @@ msgstr "ISO-C verbietet das Weglassen des mittleren Terms eines %<?:%>-Ausdrucke
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr "Division %<sizeof (%T) / sizeof (%T)%> berechnet nicht die Anzahl der Feldelemente"
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "der Operand des ersten %<sizeof%> wurde hier deklariert"
@@ -47627,7 +47650,7 @@ msgstr "ISO-C90 unterstützt den vordefinierten Bezeichner %<__func__%> nicht"
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, gcc-internal-format
 msgid "expected expression"
 msgstr "Ausdruck erwartet"
@@ -47947,12 +47970,12 @@ msgstr "Methodendeklaration in Objective-C erwartet"
 msgid "no type or storage class may be specified here,"
 msgstr "hier darf kein Typ oder Speicherklasse angegeben werden,"
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr "leere Liste von Eigenschaftsattributen"
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, gcc-internal-format
 msgid "missing property attribute"
 msgstr "Eigenschaftsattribut fehlt"
@@ -47962,57 +47985,57 @@ msgstr "Eigenschaftsattribut fehlt"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "unbekanntes Eigenschaftsattribut %<%s%s%>"
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "unbekanntes Eigenschaftsattribut"
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "nach dem Objective-C-Attribut %qE wird ein %<=%> erwartet"
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr "Selektorname für %qE erwartet"
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr "Methodennamen von Settern müssen mit %<:%> aufhören"
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> erfordert einen Zuweisungsausdruck, der zu einer nichtnegativen Ganzzahlkonstante kleiner als %u evaluiert"
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr "dazwischenliegender Code darf keine OpenMP-Direktiven enthalten"
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> darf nur im Datei-Gültigkeitsbereich auftreten"
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp scan%> darf nur in einem Schleifenkonstrukt mit %<inscan%>-%<reduction%>-Klausel verwendet werden"
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> darf nur in %<#pragma omp sections%>-Konstrukt verwendet werden"
@@ -48022,25 +48045,25 @@ msgstr "%<#pragma omp section%> darf nur in %<#pragma omp sections%>-Konstrukt v
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr "%<#pragma %s%> darf nur im Gültigkeitsbereich einer Datei verwendet werden"
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for-, while- oder do-Anweisung erwartet"
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> muss zuerst kommen"
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "zu viele %qs-Klauseln"
@@ -48055,63 +48078,63 @@ msgstr "Ausdruck muss ganzzahlig sein"
 msgid "expected %<)%> or %<,%>"
 msgstr "%<)%> oder %<,%> erwartet"
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD ist keine Variable"
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD ist keine Zeigervariable"
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "Collapse-Argument erfordert positiven konstanten Ganzzahlausdruck"
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> oder %<present%> erwartet"
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, gcc-internal-format
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr "%<none%>, %<shared%>, %<private%> oder %<firstprivate%> erwartet"
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, gcc-internal-format
 msgid "expected constant logical expression"
 msgstr "Interner Fehler: expected constant logical expression"
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<data%>, %<update%>, %<enter%> oder %<exit%> erwartet"
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<data%> erwartet"
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "zu viele %<if%>-Klauseln mit %qs-Modifizierer"
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "zu viele %<if%>-Klauseln"
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "zu viele %<if%>-Klauseln ohne Modifizierer"
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "wenn eine der %<if%>-Klauseln einen Modifizierer verwendet, müssen alle %<if%>-Klauseln Modifizierer verwenden"
@@ -48134,22 +48157,22 @@ msgstr "Wert von %<num_threads%> muss positiv sein"
 msgid "%<num_tasks%> value must be positive"
 msgstr "Wert von %<num_tasks%> muss positiv sein"
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "Wert von %<grainsize%> muss positiv sein"
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "Wert von %<priority%> muss positiv sein"
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "konstanter Ganzzahlausdruck mit gültigem sync-hint-Wert erwartet"
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "%<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> oder %<default%> erwartet"
@@ -48159,94 +48182,94 @@ msgstr "%<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> oder
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr "%<scalar%>, %<aggregate%>, %<pointer%> oder %<all%> erwartet"
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "zu viele %<defaultmap%>-Klauseln mit %qs-Kategorie"
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "zu viele %<defaultmap%>-Klauseln mit nicht angegebener Kategorie"
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "%qs-Ausdruck muss ganzzahlig sein"
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "Wert %qs muss positiv sein"
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "zu viele %<static%>-Argumente"
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "unerwartetes Argument"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%<tile%>-Argument muss eine positive, ganzzahlige Konstante sein"
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, gcc-internal-format
 msgid "too many %<self%> clauses"
 msgstr "zu viele %<self%>-Klauseln"
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, gcc-internal-format
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr "%<reproducible%> oder %<unconstrained%> erwartet"
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "%<concurrent%> erwartet"
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "%<teams%>, %<parallel%> oder %<thread%> erwartet"
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "Argument für %<ordered%> muss ein positiver, ganzzahliger Ausdruck sein"
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> oder Bezeichner erwartet"
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "widersprüchliche Modifizierer %<monotonic%> und %<nonmonotonic%> angegeben"
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "Ablauf %<runtime%> akzeptiert keinen Parameter %<chunk_size%>"
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "Ablauf %<auto%> akzeptiert keinen Parameter %<chunk_size%>"
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "Wert der Chunkgröße muss positiv sein"
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ungültige Ablaufart"
@@ -48256,22 +48279,22 @@ msgstr "ungültige Ablaufart"
 msgid "%<num_teams%> value must be positive"
 msgstr "Wert von %<num_teams%> muss positiv sein"
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr "untere Grenze %qE von %<num_teams%> ist größer als obere Grenze %qE"
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "Wert von %<thread_limit%> muss positiv sein"
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "Ausdruck für %<aligned%>-Klausel erfordert positiven konstanten Ganzzahlausdruck"
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, gcc-internal-format
 msgid "expected %<allocator%> or %<align%>"
 msgstr "%<allocator%> oder %<align%> erwartet"
@@ -48281,22 +48304,22 @@ msgstr "%<allocator%> oder %<align%> erwartet"
 msgid "duplicate %qs modifier"
 msgstr "doppelter %qs-Modifizierer"
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr "Allokationsausdruck in %<allocate%>-Klausel ist vom Typ %qT statt des erwarteten %<omp_allocator_handle_t%>"
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, gcc-internal-format
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr "in der %<allocate%>-Klausel muss das Argument des %<align%>-Modifizierers eine positive konstante Zweierpotenz eines ganzzahligen Ausdrucks sein"
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, gcc-internal-format
 msgid "multiple linear modifiers"
 msgstr "mehrere »linear«-Modifizierer"
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, gcc-internal-format
 msgid "multiple %<step%> modifiers"
 msgstr "mehrere %<step%>-Modifizierer"
@@ -48317,62 +48340,62 @@ msgid "%<simdlen%> clause expression must be positive constant integer expressio
 msgstr "Ausdruck der %<simdlen%>-Klausel erfordert positiven konstanten Ganzzahlausdruck"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79924
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "Modifizierer %<iterator%> ist unverträglich mit %qs"
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ungültige Abhängigkeitsart"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, gcc-internal-format
 msgid "invalid doacross kind"
 msgstr "ungültige »doacross«-Art"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, gcc-internal-format
 msgid "too many %<always%> modifiers"
 msgstr "zu viele %<always%>-Modifizierer"
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, gcc-internal-format
 msgid "too many %<close%> modifiers"
 msgstr "zu viele %<close%>-Modifizierer"
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, gcc-internal-format
 msgid "too many %<present%> modifiers"
 msgstr "zu viele %<present%>-Modifizierer"
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr "%<map%>-Klausel mit einem anderen map-type-Modifikator als %<always%>, %<close%> oder %<present%>"
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "ungültige Zuordnungsart"
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr "%<ancestor%>-Gerätemodifikator, dem keine %<requires%>-Direktive mit %<reverse_offload%>-Klausel vorausgeht"
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, gcc-internal-format
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr "%<ancestor%> oder %<device_num%> erwartet"
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, gcc-internal-format
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr "der Ausdruck der %<device%>-Klausel muss den Wert %<1%> haben"
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ungültige »dist_schedule«-Art"
@@ -48387,88 +48410,88 @@ msgstr "ungültige »proc_bind«-Art"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<host%>, %<nohost%> oder %<any%> erwartet"
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr "Ereignishandle in %<detach%>-Klausel ist vom Typ %qT statt des erwarteten %<omp_event_handle_t%>"
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, gcc-internal-format
 msgid "expected an OpenACC clause"
 msgstr "OpenACC-Klausel erwartet"
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs ist für %qs ungültig"
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr "Klauseln in %<simd%>-Eigenschaft sollten durch %<,%> getrennt werden"
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs muss die erste Klausel von %qs sein"
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, gcc-internal-format
 msgid "expected an OpenMP clause"
 msgstr "OpenMP-Klausel erwartet"
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "keine gültigen Klauseln in %<#pragma acc declare%> angegeben"
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "Arrayabschnitt in %<#pragma acc declare%>"
 
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "In %<#pragma acc declare link%> muss %qD eine globale Variable sein"
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "ungültige OpenACC-Klausel im Datei-Gültigkeitsbereich"
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "ungültige Verwendung der %<extern%>-Variable %qD in %<#pragma acc declare%>"
 
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "ungültige Verwendung der %<global%>-Variable %qD in %<#pragma acc declare%>"
 
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "%qD muss eine Variable sein, die im selben Gültigkeitsbereich wie %<#pragma acc declare%> deklariert ist"
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "Variable %qD wird in %<#pragma acc declare%> mehr als einmal verwendet"
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "hinter %<#pragma acc %s%> wird %<data%> erwartet"
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> hat keine Datenverschiebeklausel"
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr "das %<host_data%>-Konstrukt erfordert eine %<use_device%>-Klausel"
@@ -48483,7 +48506,7 @@ msgstr "%qE wurde nicht deklariert"
 msgid "expected function name"
 msgstr "Funktionsname erwartet"
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD bezeichnet keine Funktion"
@@ -48493,22 +48516,22 @@ msgstr "%qD bezeichnet keine Funktion"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> muss direkt vor einer Funktionsdeklaration oder -definition auftreten"
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> muss direkt vor einer Deklaration oder Definition einer einzelnen Funktion auftreten"
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> muss vor Verwendung angewendet werden"
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> muss vor Definition angewendet werden"
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> muss mindestens eine %<device%>- oder %<host%>- or %<self%>-Klausel enthalten"
@@ -48533,7 +48556,7 @@ msgstr "die in der %<allocator%>-Klausel verwendete Variable %qD darf zwischen d
 msgid "modified here"
 msgstr "hier verändert"
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, gcc-internal-format
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
 msgstr "in der %<align%>-Klausel muss das Argument eine positive konstante Zweierpotenz eines ganzzahligen Ausdrucks sein"
@@ -48573,110 +48596,110 @@ msgstr "die %<allocator%>-Klausel erfordert einen vordefinierten Allokator, da %
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr "%<#pragma omp allocate%> wird für statische Variablen wie %qD noch nicht unterstützt"
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "eine der Klauseln %<read%>, %<write%>, %<update%> oder %<capture%> erwartet"
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr "%<seq_cst%>, %<acquire%> oder %<relaxed%> erwartet"
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "eine der Klauseln %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> oder %<hint%> erwartet"
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "zu viele atomare Klauseln"
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "zu viele Speicherreihenfolge-Klauseln"
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, gcc-internal-format
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr "Klausel %qs ist unverträglich mit den Klauseln %<read%> oder %<write%>"
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, gcc-internal-format
 msgid "%qs clause requires %qs clause"
 msgstr "%qs-Klausel erfordert %qs-Klausel"
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr "%<#pragma omp atomic write%> inkompatibel mit %<acquire%>-Klausel, die implizit von einer %<requires%>-Direktive bereitgestellt wird"
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr "%<#pragma omp atomic read%> inkompatibel mit %<release%>-Klausel, die implizit von einer %<requires%>-Direktive bereitgestellt wird"
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr "%<#pragma omp atomic read%> ist unverträglich mit der Klausel %<release%>"
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr "%<#pragma omp atomic write%> ist unverträglich mit der Klausel %<acquire%>"
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, gcc-internal-format
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr "in der %<if%>-Bedingung wird ein Vergleich mit %<==%> erwartet"
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, gcc-internal-format
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr "in der %<if%>-Bedingung wird ein Vergleich mit %<==%>, %<<%> oder %<>%> erwartet"
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr "ungültige Form von %<#pragma omp atomic compare%>"
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, gcc-internal-format
 msgid "unexpected %<else%>"
 msgstr "unerwartetes %<else%> gefunden"
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, gcc-internal-format
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr "ungültige Form von %<#pragma omp atomic compare%>"
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ungültige Form von %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ungültiger Operator für %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr "%<weak%>-Klausel erfordert atomaren Gleichheitsvergleich"
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> verwendet zwei unterschiedliche Ausdrücke für Speicher"
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "Ausdruck %<depobj%> ist kein lvalue-Ausdruck"
@@ -48686,27 +48709,27 @@ msgstr "Ausdruck %<depobj%> ist kein lvalue-Ausdruck"
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr "%<destroy%>-Ausdruck ist kein Lvalue-Ausdruck"
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr "der %<destroy%>-Ausdruck %qE sollte mit dem %<depobj%>-Argument %qE identisch sein"
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr "%<in%>, %<out%>, %<inout%>, %<mutexinoutset%> oder %<inoutset%> erwartet"
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "eine der Klauseln %<depend%>, %<destroy%> oder %<update%> erwartet"
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "%<seq_cst%>, %<acq_rel%>, %<release%> oder %<acquire%> erwartet"
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr "%<flush%>-Liste wurde zusammen mit Speicherreihenfolge-Klausel angegeben"
@@ -48716,163 +48739,163 @@ msgstr "%<flush%>-Liste wurde zusammen mit Speicherreihenfolge-Klausel angegeben
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> oder Zeilenende erwartet"
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr "%<[[omp::directive(%s)]]%> muss das einzige angegebene Attribut in einer Anweisung sein"
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr "%<#pragma omp scan%> mit 0 vorhergehenden ausführbaren Anweisungen"
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "%<inclusive%>- oder %<exclusive%>-Klausel erwartet"
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<#pragma omp scan%> erwartet"
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr "%<#pragma omp scan%> mit 0 nachfolgenden ausführbaren Anweisungen"
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "Schleifendeklaration oder Initialisierung erwartet"
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, gcc-internal-format
 msgid "not enough nested loops"
 msgstr "nicht genügend geschachtelte Schleifen"
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "%<ordered%>-Klauselparameter ist weniger als %<collapse%>"
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "für Anweisung erwartet"
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "Schleifenvariable %qD sollte nicht »firstprivate« sein"
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> mit %qs-Klausel darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> hinter %qs erwartet"
 
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> erwartet"
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> mit Zuordnungstyp außer %<to%>, %<from%>, %<tofrom%> oder %<alloc%> an %<map%>-Klausel"
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp target data%> muss mindestens eine %<map%>-, %<use_device_ptr%>- oder %<use_device_addr%>-Klausel enthalten"
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> muss mindestens eine %<from%>- oder %<to%>-Klausel enthalten"
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> mit Zuordnungstyp außer %<to%>, %<tofrom%> oder %<alloc%> an %<map%>-Klausel"
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> muss mindestens eine %<map%>-Klausel enthalten"
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> mit Zuordnungstyp außer %<from%>, %<tofrom%>, %<release%> oder %<delete%> an %<map%>-Klausel"
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> muss mindestens eine %<map%>-Klausel enthalten"
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> mit Zuordnungstyp außer %<to%>, %<from%>, %<tofrom%> oder %<alloc%> an %<map%>-Klausel"
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp declare %s%> muss von einer Funktionsdeklaration oder -definition oder einem weiteren %<#pragma omp declare %s%> gefolgt werden"
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> muss vor der Deklaration oder Definition einer Funktion auftreten"
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "Name des Merkmalsselektors erwartet"
 
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, gcc-internal-format
 msgid "unknown selector %qs for context selector set %qs"
 msgstr "unbekannter Selektor %qs für Kontextselektormenge %qs"
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "Selektor %qs akzeptiert keine Eigenschaften"
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, gcc-internal-format
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr "%<score%> kann nicht in Traits in der Trait-Selektor-Menge %qs angegeben werden"
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, gcc-internal-format
 msgid "%<score%> argument must be constant integer expression"
 msgstr "das %<score%>-Argument muss ein konstanter ganzzahliger Ausdruck sein"
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, gcc-internal-format
 msgid "%<score%> argument must be non-negative"
 msgstr "das %<score%>-Argument darf nicht negativ sein"
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "Bezeichner oder Zeichenkettenliteral erwartet"
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "Eigenschaft muss ein konstanter ganzzahliger Ausdruck sein"
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "Eigenschaften für %<simd%>-Selektor dürfen nicht in %<metadirective%> angegeben werden"
@@ -48880,290 +48903,290 @@ msgstr "Eigenschaften für %<simd%>-Selektor dürfen nicht in %<metadirective%>
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, gcc-internal-format
 msgid "%<requires%> selector is not supported yet"
 msgstr "der %<requires%>-Selektor wird noch nicht unterstützt"
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, gcc-internal-format
 msgid "expected context selector set name"
 msgstr "Name der Kontextselektormenge erwartet"
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "%<match%> erwartet"
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, gcc-internal-format
 msgid "variant %qD is not a function"
 msgstr "Variante %qD ist keine Funktion"
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "Variante %qD und Basis %qD haben unverträgliche Typen"
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr "die Variante %qD ist eine eingebaute"
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "hinter %<#pragma omp declare %s%> muss direkt eine Funktionsdeklaration oder -definition stehen"
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "hinter %<#pragma omp declare %s%> muss direkt eine einzelne Funktionsdeklaration oder -definition stehen"
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr "%qD ist sowohl in %<link%>- als auch %qs-Klauseln des Deklarationsziels angegeben"
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr "%qD ist sowohl im Deklarationsziel %<link%> als auch in %<to%>- oder %<enter%>-Klauseln angegeben"
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr "Direktive mit nur %<device_type%>- oder %<indirect%>-Klauseln"
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, gcc-internal-format
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr "die %<device_type%>-Klausel muss 'any' angeben, wenn sie mit einer %<indirect%>-Klausel verwendet wird"
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> erwartet"
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, gcc-internal-format
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr "%<declare target%> oder %<assumes%> erwartet"
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr "%<#pragma omp end declare target%> ohne zugehöriges %<#pragma omp declare target%> oder %<#pragma omp begin declare target%>"
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr "%qs beginnt in der Attributsyntax, wird aber mit %qs in der Pragmasyntax abgeschlossen"
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, gcc-internal-format
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr "%qs beginnt in der Pragmasyntax, wird aber mit %qs in der Attributsyntax abgeschlossen"
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, gcc-internal-format
 msgid "expected %<declare%> or %<assumes%>"
 msgstr "%<declare%> oder %<assumes%> erwartet"
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr "%<#pragma omp declare reduction%> darf nur im Datei- oder Block-Gültigkeitsbereich auftreten"
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr "vordefinierter arithmetischer Typ in %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr "Funktions- oder Arraytyp in %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, gcc-internal-format
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr "%<_Atomic%>-qualifizierter Typ in %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr "mit const, volatile oder restrict qualifizierter Typ in %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr "Redeklaration von %qs %<#pragma omp declare reduction%> für Typ %qT"
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "vorheriges %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr "%<omp_priv%> oder Funktionsname erwartet"
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "Funktionsname und %<(%> erwartet"
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "eins der Argumente für den Initialisierungsaufruf sollte %<&omp_priv%> sein"
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%<simd%>, %<reduction%>, %<target%> oder %<variant%> erwartet"
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr "%<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> oder %<seq_cst%> erwartet"
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr "eine der Klauseln %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> oder %<atomic_default_mem_order%> erwartet"
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr "%qs-Klausel wird lexikalisch nach dem ersten Zielkonstrukt oder nach der ersten Auslagerungs-API verwendet"
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr "mehr als eine %<atomic_default_mem_order%>-Klausel in einer einzigen Übersetzungseinheit"
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr "%<atomic_default_mem_order%>-Klausel wird lexikalisch nach dem ersten %<atomic%>-Konstrukt ohne Speicherreihenfolge-Klausel verwendet"
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr "%<pragma omp requires%> erfordert mindestens eine Klausel"
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, gcc-internal-format
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr "Typ %qT mit Größe 0 in %<reduction%>-Klausel"
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, gcc-internal-format
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "Typ %qT mit variabler Länge in %<reduction%>-Klausel"
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, gcc-internal-format
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr "eine der Klauseln %<at%>, %<severity%> oder %<message%> erwartet"
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, gcc-internal-format
 msgid "expected %qs or %qs"
 msgstr "%qs oder %qs erwartet"
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, gcc-internal-format
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr "%<#pragma omp error%> mit %<at(execution)%>-Klausel darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr "%<#pragma omp error%> gefunden: %s"
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr "%<#pragma omp error%> gefunden"
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, gcc-internal-format
 msgid "expected at least one assumption clause"
 msgstr "mindestens eine Annahme-Klausel erwartet"
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, gcc-internal-format
 msgid "expected directive name"
 msgstr "Name einer Direktive erwartet"
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr "unbekannter OpenMP-Direktiven-Name im Argument der %qs-Klausel"
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr "%<%s%s%s%s%s%>-Direktive wird sowohl in %<absent%>- als auch %<contains%>-Klauseln erwähnt"
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr "%<%s%s%s%s%s%>-Direktive wird mehrfach in %qs-Klauseln erwähnt"
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, gcc-internal-format
 msgid "unknown assumption clause %qs"
 msgstr "unbekanntes Annahme-Klausel %qs"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, gcc-internal-format
 msgid "expected assumption clause"
 msgstr "Annahme-Klausel erwartet"
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE nach erster Verwendung als %<threadprivate%> deklariert"
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automatische Variable %qE kann nicht %<threadprivate%> sein"
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE hat unvollständigen Typen"
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> ohne eingeschaltete Unterstützung für transaktionsbasierten Speicher"
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> innerhalb eines %<__transaction_relaxed%>"
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "Funktionsaufruf von %<__transaction_cancel%> nicht innerhalb von äußerer %<__transaction_atomic%>- oder %<transaction_may_cancel_outer%>-Funktion"
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> nicht innerhalb von %<__transaction_atomic%>"
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, gcc-internal-format
 msgid "no closing brace"
 msgstr "fehlende schließende geschweifte Klammer"
@@ -49305,7 +49328,7 @@ msgstr "Dereferenzierung eines %<void *%>-Zeigers"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indizierter Wert ist weder Array noch Zeiger noch Vektor"
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "Arrayindex ist keine Ganzzahl"
@@ -49335,7 +49358,7 @@ msgstr "unvollständig angegebenes %qD wird in seinem Initialisierer referenzier
 msgid "enum constant defined here"
 msgstr "enum-Konstante hier definiert"
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> auf Array-Funktionsparameter %qE gibt die Größe von %qT zurück"
@@ -49448,17 +49471,17 @@ msgstr "implizite Umwandlung von %qT in %qT bei Übergabe von Argument an Funkti
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "zu wenige Argumente für eingebaute Funktion %qE, %u erwartet"
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "Vergleich mit Zeichenkettenliteral führt zu unspezifiziertem Verhalten"
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "Vergleich zwischen Zeiger und '\\0'"
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "wollten Sie vielleicht den Zeiger dereferenzieren?"
@@ -49483,7 +49506,7 @@ msgstr "Zeiger auf eine Funktion in Subtraktion verwendet"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "Arithmetik mit Zeiger auf unvollständigen Typen"
 
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "Arithmetik mit Zeiger auf leeres Aggregat"
@@ -49776,7 +49799,7 @@ msgstr "Typkonvertierung von Zeiger auf Ganzzahl anderer Breite"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "Typumwandlung von Funktionsaufruf des Typs %qT in unpassenden Typen %qT"
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "Typkonvertierung in Zeiger von Ganzzahl anderer Breite"
@@ -49948,7 +49971,7 @@ msgstr "Links-Zuweisung könnte Kandidat für Formatattribut sein"
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "Linke-Initialisierung könnte Kandidat für Formatattribut sein"
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "Rückgabetyp könnte Kandidat für Formatattribut sein"
@@ -50148,12 +50171,12 @@ msgstr "%<constexpr%>-Initialisierer für einen reellen Typen hat komplexen Typ"
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr "%<constexpr%>-Initialisierer für einen binären Gleitkommatypen hat dezimalen Typ"
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "Initialisierung eines flexiblen Array-Elements"
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "Array von %qT kann nicht aus einem Zeichenkettenliteral mit Typ %<Array von %T%> initialisiert werden"
@@ -50163,7 +50186,7 @@ msgstr "Array von %qT kann nicht aus einem Zeichenkettenliteral mit Typ %<Array
 msgid "array of inappropriate type initialized from string constant"
 msgstr "Array unpassenden Typs mit Zeichenkettenkonstante initialisiert"
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ungültige Verwendung eines Nicht-L-Wert-Arrays"
@@ -50194,7 +50217,7 @@ msgstr "Initialisierungselement ist kein konstanter Ausdruck"
 msgid "initializer element is not computable at load time"
 msgstr "Initialisierungs-Element ist zur Lade-Zeit nicht berechenbar"
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "opake Vektortypen können nicht initialisiert werden"
@@ -50209,7 +50232,7 @@ msgstr "zusätzliche geschweifte Klammern am Ende der Initialisierung"
 msgid "braces around scalar initializer"
 msgstr "geschweifte Klammern um Skalar-Initialisierung"
 
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "Initialisierung eines flexiblen Array-Elements in geschachteltem Kontext"
@@ -50299,7 +50322,7 @@ msgstr "Elementüberschreitung in struct-Initialisierung"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "positionelle Initialisierung eines Feldes in %<struct%>, die mit dem %<designated_init%>-Attribut deklariert wurde"
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "nicht-statische Initialisierung eines flexiblen Arrayelements"
@@ -50339,7 +50362,7 @@ msgstr "ISO-C verbietet %<goto *expr;%>"
 msgid "computed goto must be pointer type"
 msgstr "das berechnete Goto muss von einem Zeigertyp sein"
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "als %<noreturn%> deklarierte Funktion hat %<return%>-Anweisung"
@@ -50394,7 +50417,7 @@ msgstr "%<default%>-Marke nicht innerhalb einer switch-Anweisung"
 msgid "break statement not within loop or switch"
 msgstr "break-Anweisung nicht innerhalb einer Schleife oder »switch«"
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -50440,27 +50463,27 @@ msgstr "der Vergleich wird immer als %<false%> ausgewertet, da die Adresse von %
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr "der Vergleich wird immer als %<true%> ausgewertet, da die Adresse von %qE niemals NULL sein wird"
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "Vergleich von Vektoren mit verschiedenen Element-Typen"
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "Vergleich von Vektoren mit unterschiedlicher Elementanzahl"
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "Vergleich zwischen den Typen %qT und %qT"
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "kein ganzzahliger Typ mit derselben Größe wie %qT gefunden"
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "Vergleich von Gleitkomma mit %<==%> oder %<!=%> ist unsicher"
@@ -50532,29 +50555,29 @@ msgstr "Wert eines union-Typs anstelle des geforderten Skalars verwendet"
 msgid "used vector type where scalar is required"
 msgstr "Vektortyp verwendet, wo Skalars benötigt wird"
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> muss eine der Klauseln %<parallel%>, %<for%>, %<sections%> oder %<taskgroup%> angeben"
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "Klauselmodifizierer %<cancel%> %<if%> erwartet"
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> muss eine der Klauseln %<parallel%>, %<for%>, %<sections%> oder %<taskgroup%> angeben"
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD in %qs-Klausel muss eine Variable sein"
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE in %qs-Klausel muss eine Variable sein"
@@ -50565,85 +50588,85 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%>-Deklaration %qD in %qs-Klausel"
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD in %qs-Klausel ist eine threadprivate Variable"
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "Untere Grenze %qE des Arrayabschnitts muss Ganzzahltyp haben"
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "Länge %qE des Arrayabschnitts muss Ganzzahltyp haben"
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "einelnen Zeiger in %qs-Klausel erwartet"
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "Arrayabschnitt der Länge 0 in %qs-Klausel"
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "für Arraytyp mit unbekannten Grenzen muss ein Längenausdruck angegeben werden"
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "negative untere Grenze in Arrayabschnitt in %qs-Klausel"
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "Arrayabschnitt mit negativer Länge in %qs-Klausel"
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "untere Grenze %qE geht über Abschnittsgröße in %qs-Klausel hinaus"
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "Länge %qE geht über Abschnittsgröße in %qs-Klausel hinaus"
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "obere Grenze %qE geht über Abschnittsgröße in %qs-Klausel hinaus"
 
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr "für Funktionsparameter vom Typ Array muss die Länge angegeben sein"
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "für Zeigertyp muss der Längenausdruck angegeben werden"
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "Arrayabschnitt ist in %qs-Klausel nicht zusammenhängend"
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE hat weder Zeiger- noch Arraytyp"
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "Typ des Iterators %qD ist weder ganzzahlig noch ein Zeiger"
@@ -50653,17 +50676,17 @@ msgstr "Typ des Iterators %qD ist weder ganzzahlig noch ein Zeiger"
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "Iterator %qD hat %<_Atomic%>-qualifizierten Typ"
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr "Iterator %qD hat %<const%>-qualifizierten Typ"
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "Iterator-Schrittweite mit nichtganzzahligem Typ"
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr "Iterator %qD hat Schrittweite 0"
@@ -50673,32 +50696,32 @@ msgstr "Iterator %qD hat Schrittweite 0"
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr "Typ des Iterators %qD verweist auf äußeren Iterator %qD"
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr "Anfangsausdruck verweist auf äußeren Iterator %qD"
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr "Endausdruck verweist auf äußeren Iterator %qD"
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr "Ausdruck für die Schrittweite verweist auf äußeren Iterator %qD"
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr "Zeiger in %qs-Klausel erwartet"
 
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "die Klausel %<inscan%> darf nicht zusammen mit nicht-%<inscan%>-%<reduction%> am selben Konstrukt vorkommen"
 
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr "%<inscan%>-%<reduction%>-Klausel mit Arrayabschnitt"
@@ -50728,7 +50751,7 @@ msgstr "Typ %qT mit variabler Größe in %qs-Klausel"
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE hat ungültigen Typ für %<reduction(%s)%>"
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "benutzerdefinierte Reduktion für %qE nicht gefunden"
@@ -50738,17 +50761,17 @@ msgstr "benutzerdefinierte Reduktion für %qE nicht gefunden"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "Elementtyp variabler Länge in %<reduction%>-Klausel eines Arrays"
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "%<nowait%>-Klausel darf nicht zusammen mit %<copyprivate%> verwendet werden"
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE muss für %<copyin%> %<threadprivate%> sein"
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
 msgstr "Modifizierer sollte an %<simd%>- oder %<for%>-Konstrukten nicht in %<linear%>-Klausel angegeben werden, außer wenn OpenMP 5.2 verwendet wird"
@@ -50763,23 +50786,23 @@ msgstr "»linear«-Klausel auf Variable vom Typ %qT angewendet, die weder Ganzza
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "%<_Atomic%> %qD in %<linear%>-Klausel"
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "Schrittweite %qE der %<linear%>-Klausel muss konstant oder ein Parameter sein"
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE ist in Klausel %qs keine Variable"
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, gcc-internal-format
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr "%qD kommt mehr als einmal in Datenfreigabeklauseln vor"
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD tritt in Reduktionsklauseln mehrfach auf"
@@ -50791,32 +50814,32 @@ msgstr "%qE tritt in dieser Datenklausel mehrfach auf"
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD tritt in Datenklausel mehrfach auf"
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD tritt in Daten- und Zuordnungsklauseln mehrfach auf"
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE ist in Klausel %<firstprivate%> keine Variable"
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE ist in Klausel %<lastprivate%> keine Variable"
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE ist %<aligned%>-Klausel keine Variable"
@@ -50836,7 +50859,7 @@ msgstr "%<_Atomic%> %qD in %<aligned%>-Klausel"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE tritt in %<aligned%>-Klausel mehrfach auf"
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE ist in %<nontemporal%>-Klausel keine Variable"
@@ -50846,7 +50869,7 @@ msgstr "%qE ist in %<nontemporal%>-Klausel keine Variable"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE tritt in %<nontemporal%>-Klausel mehrfach auf"
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qE in %<allocate%>-Klausel ist keine Variable"
@@ -50856,76 +50879,76 @@ msgstr "%qE in %<allocate%>-Klausel ist keine Variable"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE kommt mehr als einmal in %<allocate%>-Klauseln vor"
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr "%<depend%>-Klausel mit %<depobj%>-Abhängigkeitstyp auf Arrayabschnitt"
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr "%<omp_all_memory%> wird mit %<depend%>-Art außer %<out%> oder %<inout%> verwendet"
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr "%qE ist weder ein lvalue-Ausdruck noch ein Arrayabschnitt in %qs-Klausel"
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr "%qE hat nicht den Typ %<omp_depend_t%>, in der %<depend%>-Klausel mit %<depobj%>-Abhängigkeitstyp"
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr "%qE sollte einen anderen Typ haben als %<omp_depend_t%>, in der %<depend%>-Klausel mit von %<depobj%> verschiedenem Abhängigkeitstyp"
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "Arrayabschnitt in %qs-Klausel hat keinen zuordenbaren Typ"
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, gcc-internal-format
 msgid "unsupported map expression %qE"
 msgstr "nicht unterstützter Map-Ausdruck %qE"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD tritt in Bewegungsklausel mehrfach auf"
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD tritt in Zuordnungsklauseln mehrfach auf"
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD in %qs-Klausel hat keinen zuordenbaren Typ"
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE in %qs-Klausel ist weder Variablen- noch Funktionsname"
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE tritt in derselben %<declare target%>-Direktive mehrfach auf"
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD in %<uniform%>-Klausel ist kein Argument"
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE in %<uniform%>-Klausel ist kein Argument"
@@ -50940,22 +50963,22 @@ msgstr "Variable %qs muss ein Zeiger sein"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "Variable %qs ist weder Zeiger noch Array"
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "%<order%>-Klausel darf nicht zusammen mit %<ordered%> verwendet werden"
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr "zu viele %qs-Klauseln an einem Task-Konstrukt"
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "%<inbranch%>-Klausel ist inkompatibel mit %<notinbranch%>"
 
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE ist vorbestimmt %qs für %qs"
@@ -50965,38 +50988,38 @@ msgstr "%qE ist vorbestimmt %qs für %qs"
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "%<const%>-qualifiziertes %qE darf nur in %<shared%>- oder %<firstprivate%>-Klauseln vorkommen"
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "%<simdlen%>-Klauselwert ist größer als %<safelen%>-Klauselwert"
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "%<nonmonotonic%>-Planungsmodifizierer zusammen mit %<ordered%>-Klausel angegeben"
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "%qs-Klausel darf nicht zusammen mit %<inscan%>-%<reduction%>-Klausel verwendet werden"
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "%<linear%>-Klauselschritt ist ein Parameter %qD, der nicht in der %<uniform%>-Klausel angegeben ist"
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "%<nogroup%>-Klausel darf nicht zusammen mit %<reduction%>-Klausel verwendet werden"
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr "%<detach%>-Klausel darf nicht zusammen mit %<mergeable%>-Klausel verwendet werden"
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr "das Ereignishandle einer %<detach%>-Klausel sollte nicht in einer data-sharing-Klausel sein"
@@ -51262,14 +51285,14 @@ msgstr "  keine bekannte Umwandlung von %qH nach %qI"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  keine bekannte Umwandlung für Argument %d von %qH nach %qI"
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  Kandidat erwartet mindestens %d Argument, %d angegeben"
 msgstr[1] "  Kandidat erwartet mindestens %d Argumente, %d angegeben"
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -51580,553 +51603,553 @@ msgstr "Bedingungsausdruck zwischen Gleitkommatyp %qT und Aufzählungstyp %qT is
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "Aufzählungs- und Nicht-Aufzählungstyp in bedingtem Ausdruck"
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "kein %<%D(int)%> für Suffix %qs deklariert, stattdessen wird Präfixoperator versucht"
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "kein %<%D(int)%> für Suffix %qs deklariert"
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr "in C++20 ruft dieser Vergleich die aktuelle Funktion rekursiv mit vertauschten Argumenten auf"
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "Rückgabetyp von %qD ist nicht %qs"
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr "als umgeschriebener Kandidat für den Vergleich von %qT und %qT verwendet"
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "Vergleich zwischen %q#T und %q#T"
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, gcc-internal-format
 msgid "no match for call to %<%T::operator[] (%A)%>"
 msgstr "keine Übereinstimmung für den Aufruf von %<%T::operator[] (%A)%>"
 
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, gcc-internal-format
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr "Aufruf von %<%T::operator[] (%A)%> ist mehrdeutig"
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr "Exceptionaufräumen für dieses Placement-New wählt delete-Operator für Nicht-Placement"
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD ist eine übliche (nicht-placement) Deallokationsfunktion in C++14 (oder mit %<-fsized-deallocation%>)"
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD ist eine gewöhnliche (nicht-Platzierungs) Deallokationsfunktion"
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "keine passende Freigabefunktion für %qD"
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr "das zerstörende Delete für %qD kann nicht verwendet werden, um den zugewiesenen Speicher freizugeben, wenn die Initialisierung fehlschlägt, weil das Objekt noch nicht konstruiert ist"
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "kein geeignetes %<operator %s%> für %qT"
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "%q#D ist in diesem Zusammenhang »private«"
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "hier als »private« deklariert"
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%q#D ist in diesem Zusammenhang »protected«"
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "hier als »protected« deklariert"
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D ist in diesem Zusammenhang unzugänglich"
 
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "Übergabe von NULL an Nicht-Zeiger-Argument %P von %qD"
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, gcc-internal-format
 msgid "  declared here"
 msgstr "  hier deklariert"
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "Konvertierung in Nicht-Zeiger-Typ %qT von NULL"
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "%<false%> wird für Argument %P von %qD in Zeigertyp umgewandelt"
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "%<false%> wird in Zeigertyp %qT umgewandelt"
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  Argument %P von %qD wird initialisiert"
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Umwandlungen in Arrays mit unbekannten Grenzen sind erst mit %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "zu viele geschweifte Klammern um Initialisierung für %qT"
 
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "Umwandlung von %qH nach %qI erfordert direkte Initialisierung"
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr "ISO C++ erlaubt keine Konvertierung in %qH von %qI mit größerem Konvertierungsrang"
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr "ISO C++ erlaubt keine Konvertierung in %qH aus %qI mit ungeordnetem Konvertierungsrang"
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "ungültige benutzerdefinierte Umwandlung von %qH in %qI"
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 msgid "invalid conversion from %qH to %qI"
 msgstr "ungültige Umwandlung von %qH in %qI"
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "Umwandlung in %qT von Initialisierungsliste würde expliziten Konstruktor %qD verwenden"
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "in C++11 und neuer kann ein Defaultkonstruktor explizit sein"
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "rvalue-Referenz vom Typ %qH kann nicht an lvalue vom Typ %qI gebunden werden"
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr "nicht-konstante lvalue-Referenz vom Typ %qH kann nicht an Wert vom Typ %qI gebunden werden"
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "nicht-konstante lvalue-Referenz vom Typ %qH kann nicht an rvalue vom Typ %qI gebunden werden"
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "kann keine Lvalue-Referenz vom Typ %qH an einen Rvalue vom Typ %qI binden"
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "Referenz vom Typ %qH kann nicht an %qI gebunden werden, da die Arraygrenzen sich unterscheiden"
 
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "das Binden der Referenz vom Typ %qH an %qI streicht Qualifizierer"
 
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "das Bitfeld %qE kann nicht mit %qT verbunden werden"
 
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "das gepackte Feld %qE kann nicht mit %qT verbunden werden"
 
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "der R-Wert %qE kann nicht mit %qT verbunden werden"
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "implizite Umwandlung von %qH in %qI bei Übergabe von Argument an Funktion"
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr "enum %qT mit eingeschränkter Sichtbarkeit wird vor %<-fabi-version=6%> als Typ %qT, später jedoch als %qT durch %<...%> übergeben"
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "Das Übergeben des nicht trivial-kopierbaren Typs %q#T über %<...%> ist »conditionally-supported« ([expr.call] 5.2.2/7)"
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "Referenztyp %qT kann nicht über %<...%> empfangen werden"
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "Das Übergeben des nicht trivial-kopierbaren Typs %q#T über %<...%> ist »conditionally-supported« ([expr.call] 5.2.2/7)"
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "rekursive Auswertung des Standardarguments für %q#D"
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "Aufruf von %qD verwendet das Standardargument für Parameter %P, der noch nicht definiert wurde"
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "Argument des Funktionsaufrufs könnte Kandidat für Formatattribut sein"
 
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "Verwendung einer multiversionierten Funktion ohne Standardargument"
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr "verwenden Sie %<-fdiagnostics-all-candidates%>, um die in Frage kommenden Kandidaten anzuzeigen"
 
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "Die Übergabe von %qT als %<this%>-Argument streicht Qualifizierer"
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  in Aufruf von %qD"
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT ist keine erreichbare Basis von %qT"
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "Argumente werden an Auslassungspunkte des geerbten Konstruktors %qD übergeben"
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "Zuweisung von temporärer %<initializer_list%> führt nicht dazu, dass die Lebenszeit des zugrundeliegenden Arrays ausgeweitet wird"
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr "%qD Schreibzugriff auf ein Objekt des Typs %#qT ohne triviale Kopierzuweisung"
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%qD Schreiben in ein Objekt des nichttrivialen Typs %#qT%s"
 
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr "%qD Schreibzugriff auf ein Objekt des Typs %#qT mit Element %qs %qD"
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr "%qD Schreibzugriff auf ein Objekt des Typs %#qT, das einen Zeiger auf Datenelement enthält%s"
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr "; verwenden Sie stattdessen eine Zuweisung oder Wertinitialisierung"
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "; verwenden Sie stattdessen eine Zuweisung"
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "; verwenden Sie stattdessen eine Wertinitialisierung"
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD Säubern eines Objekts des Typs %#qT ohne triviale Kopierzuweisung%s"
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD Säubern eines Objekts von nichttrivialem Typ %#qT%s"
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr "%qD Säubern eines Objekts des Typs %#qT, das einen Zeiger auf Datenelement enthält%s"
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "; verwenden Sie stattdessen eine Kopierzuweisung oder Kopierinitialisierung"
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr "; verwenden Sie stattdessen eine Kopierzuweisung"
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "; verwenden Sie stattdessen eine Kopierinitialisierung"
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD Schreibzugriff auf ein Objekt des Typs %#qT ohne triviale Kopierzuweisung%s"
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "%qD Schreiben in ein Objekt des nichttrivial kopierbaren Typs %#qT%s"
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr "%qD Schreibzugriff auf ein Objekt mit einem gelöschten Kopierkonstruktor"
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr "%qD Kopieren eines Objekts mit nichttrivialem Typ %#qT aus einem Array von %#qT"
 
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr "%qD Kopieren eines Objekts des Typs %#qT mit Element %qs %qD aus einem Array von %#qT; verwenden Sie eine Zuweisung oder Kopierinitialisierung stattdessen"
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr "%qD Schreiben in ein Objekt eines nichttrivialen Typen %#qT lässt %wu Bytes unverändert"
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr "%qD Schreiben in ein Objekt eines nichttrivialen Typen %#qT lässt %wu Byte unverändert"
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "%qD Verschieben eines Objekts des nichttrivial kopierbaren Typs %#qT; verwenden Sie stattdessen %<new%> oder %<delete%>"
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr "%qD Verschieben eines Objekts des Typs %#qT mit gelöschtem Kopierkonstruktor; verwenden Sie stattdessen %<new%> und %<delete%>"
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr "%qD Verschieben eines Objekts des Typs %#qT mit gelöschtem Destruktor"
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr "%qD Verschieben eines Objekts des nichttrivialen Typs %#qT und Größe %E in eine Region der Größe %E"
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT wird hier deklariert"
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, gcc-internal-format
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr "Argument %u in Aufruf von %qE darf kein Zeiger auf nicht-trivial kopierbaren Typ %qT sein"
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "Konstruktor verweist auf sich selbst"
 
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 msgid "cannot convert %qH to %qI"
 msgstr "%qH kann nicht nach %qI umgewandelt werden"
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "keine passende Funktion für Aufruf von %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "keine passende Funktion für Aufruf von %<%T::%s%E(%A)%#V%>"
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "Aufruf der Nicht-Funktion %qD"
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "Konstruktor %<%T::%D%> kann nicht direkt aufgerufen werden"
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "um eine funktionsartige Umwandlung zu erreichen, entfernen Sie das redundante %<::%D%>"
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "keine passende Funktion für Aufruf von %<%s(%A)%>"
 
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "Aufruf des überladenen %<%s(%A)%> ist mehrdeutig"
 
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "pure virtuelle %q#D aus nichtstatischem Datenelement-Initialisierer heraus aufgerufen"
 
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "pure virtuelle %q#D aus Konstruktor heraus aufgerufen"
 
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "pure virtuelle %q#D aus Destruktor heraus aufgerufen"
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "Elementfunktion %qD kann nicht ohne Objekt aufgerufen werden"
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "Übergabe von %qT wählt %qT statt %qT"
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, gcc-internal-format
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr "C++20 besagt, dass diese mehrdeutig sind, auch wenn der zweite umgekehrt ist:"
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, gcc-internal-format
 msgid "try making the operator a %<const%> member function"
 msgstr "versuchen Sie, den Operator in eine %<const%>-Memberfunktion umzuwandeln"
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "Wahl von %qD statt %qD"
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 msgid "  for conversion from %qH to %qI"
 msgstr "  für Umwandlung von %qH in %qI"
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  denn die Umwandlungsfolge für das Argument ist besser"
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "Zuordnungsfehler der Standardargumente in Überladungsauflösung"
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " Kandidat 1: %q#F"
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " Kandidat 2: %q#F"
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ besagt, dass diese mehrdeutig sind, auch wenn die schlechteste Umwandlung für das erste besser ist als die schlechteste Umwandlung für das zweite:"
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "eine vorübergehende Bindung an %qD besteht nur, bis der Konstruktor beendet ist"
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "ungültige Initialisierung einer nicht-konstanten Referenz des Typs %qH von rvalue des Typs %qI"
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "ungültige Initialisierung einer Referenz des Typs %qH von Ausdruck des Typs %qI"
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, gcc-internal-format
 msgid "possibly dangling reference to a temporary"
 msgstr "möglicherweise baumelnde Referenz auf temporäres Objekt"
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr "das temporäre Objekt wurde am Ende des vollständigen Ausdrucks %qE zerstört"
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, gcc-internal-format
 msgid "explicit conversion function was not considered"
 msgstr "explizite Umwandlungsfunktion wurde nicht berücksichtigt"
@@ -52172,7 +52195,7 @@ msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q#D kann nicht mit %q#D überladen werden"
 
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "vorherige Deklaration von %q#D"
@@ -52593,7 +52616,7 @@ msgstr "flexibles Arrayelement %qD in ansonsten leerem %q#T"
 msgid "next member %q#D declared here"
 msgstr "nächstes Feld %q#D hier deklariert"
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "Redefinition von %q#T"
@@ -52724,7 +52747,7 @@ msgstr "ungültiger Typ für Parameter %d der %<constexpr%>-Funktion %q+#D"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr "Lambdas sind erst ab C++17 implizit %<constexpr%>"
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<constexpr%>-Destruktoren sind erst ab %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
@@ -52765,7 +52788,7 @@ msgstr "Körper der %<constexpr%>-Funktion %qD ist keine Rückgabeanweisung"
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%qD ist nicht als %<constexpr%>-Funktion verwendbar, denn:"
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr "%qE wird außerhalb seiner Lebensdauer zerstört"
@@ -52783,7 +52806,7 @@ msgstr "Kontrollfluss für %<constexpr%>-Aufruf fällt hinten aus der Funktion"
 msgid "%q+E is not a constant expression"
 msgstr "%q+E ist kein Konstantenausdruck"
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -52804,7 +52827,7 @@ msgstr "%qE wird zu »false« ausgewertet"
 msgid "failed %<assume%> attribute assumption"
 msgstr "%<assume%>-Attribut-Annahme fehlgeschlagen"
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, gcc-internal-format
 msgid "call to internal function %qE"
@@ -52851,7 +52874,7 @@ msgstr "%qT ist eine mehrdeutige Basisklasse des dynamischen Typen %qT seines Op
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr "der dynamische Typ %qT des Operanden hat keine eindeutige öffentliche Basisklasse %qT"
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -52979,18 +53002,18 @@ msgstr "Arrayindexwert %qE ist außerhalb der Grenzen des Arraytyps %qT"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "Arrayindex %qE ist ungleich 0 und wird mit Array vom Typ %qT mit unbekannten Grenzen verwendet"
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "Zugriff auf uninitialisiertes Arrayelement"
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "Dereferenzierung eines Nullzeigers in %qE"
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -52998,469 +53021,469 @@ msgstr "Dereferenzierung eines Nullzeigers in %qE"
 msgid "%qE is not a constant expression"
 msgstr "%qE ist kein Konstantenausdruck"
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "veränderliches %qD ist in konstantem Ausdruck nicht verwendbar"
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "Zugriff auf uninitialisiertes Element %qD"
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "Zugriff auf Element %qD statt auf initialisiertes Element %qD in Konstantenausdruck"
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT ein union-Typ ist"
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT einen union-Typen enthält"
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT ein Zeigertyp ist"
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT einen Zeigertyp enthält"
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT ein Referenztyp ist"
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT einen Referenztypen enthält"
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT ein Zeiger-auf-Element-Typ ist"
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT einen Zeiger-auf-Element-Typen enthält"
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT %<volatile%> ist"
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "%qs ist kein konstanter Ausdruck, da %qT ein %<volatile%>-Teilobjekt enthält"
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "%qs kann auf diesem Ziel nicht als konstanter Ausdruck ausgewertet werden"
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr "%qs kann nicht als konstanter Ausdruck ausgewertet werden, da der Typ zu groß ist"
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr "%qs kann nicht als konstanter Ausdruck ausgewertet werden, da das Argument nicht codiert werden kann"
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "%qs greift auf das uninitialisierte Byte an Offset %d zu"
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "%qs kann nicht als konstanter Ausdruck ausgewertet werden, da das Argument nicht interpretiert werden kann"
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "auf Wert von %qE wird über ein %qT GL-Wert in Konstantenausdruck zugegriffen"
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "angeforderter Speicher wird in konstantem Ausdruck verwendet, nachdem er wieder freigegeben wurde"
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, gcc-internal-format
 msgid "allocated here"
 msgstr "wurde hier deklariert"
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
 msgstr "Zugriff auf %qE außerhalb seiner Lebensdauer"
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "der Wert von uninitialisiertem Speicher ist in konstantem Ausdruck nicht verwendbar"
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "der Wert von %qD ist in konstantem Ausdruck nicht verwendbar"
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD in seiner eigenen Initialisierung verwendet"
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D ist nicht konstant"
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D ist volatile"
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD wurde nicht mit konstantem Ausdruck initialisiert"
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD wurde nicht als %<constexpr%> definiert"
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD hat keinen Ganzzahl- oder Aufzählungstyp"
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, gcc-internal-format
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr "die Änderung des zugewiesenen Speichers nach der Freigabe ist kein konstanter Ausdruck"
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, gcc-internal-format
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr "Modifikation von %qE außerhalb seiner Lebenszeit ist kein konstanter Ausdruck"
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, gcc-internal-format
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr "das Zerstören von %qE außerhalb der aktuellen Auswertung ist kein konstanter Ausdruck"
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, gcc-internal-format
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr "Modifikation von %qE von außerhalb der aktuellen Auswertung ist kein konstanter Ausdruck"
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr "Änderung des aktiven Elements einer union von %qD zu %qD ist vor C++20 kein konstanter Ausdruck"
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr "%qD beginnt seine Lebensdauer nicht implizit, da %qT keinen nicht gelöschten trivialen Standardkonstruktor hat; verwenden Sie stattdessen %<std::construct_at%>"
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr "die Initialisierung von %qD erfordert einen Ausdruck für den Memberzugriff als linken Operanden der Zuweisung"
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "Änderung des aktiven Elements einer union von %qD zu %qD während der Initialisierung"
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "Anweisung ist kein Konstantenausdruck"
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "Anzahl der Schleifendurchläufe in %<constexpr%> überschreitet Höchstwert %d (%<-fconstexpr-loop-limit=%> verwenden, um diesen zu erhöhen)"
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "Inline-Assembler ist kein konstanter Ausdruck"
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr "in einer %<constexpr%>-Funktion in C++20 darf Inline-Assemblercode nur vorkommen, wenn er nicht im Auswertungspfad liegt"
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, gcc-internal-format
 msgid "use of %qD"
 msgstr "Verwendung von %qD"
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr "der Wert kann zwischen Compiler-Versionen oder mit verschiedenen %<-mtune%> oder %<-mcpu%> Flags variieren"
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr "wenn diese Verwendung Teil eines öffentlichen ABI ist, ändern Sie sie so, dass stattdessen eine konstante Variable verwendet wird, die Sie definieren"
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr "der Vorgabewert für die aktuelle CPU-Feineinstellung ist %d Bytes"
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr "Sie können diesen Wert mit %<--param hardware_destructive_interference_size=%d%> stabilisieren, oder diese Warnung mit %<-Wno-interference-size%> deaktivieren"
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Wert %qE vom Typ %qT ist kein Konstantenausdruck"
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "Anzahl der Evaluierungsoperationen in %<constexpr%> überschreitet Höchstwert %wd (%<-fconstexpr-ops-limit=%> verwenden, um diesen zu erhöhen)"
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr "der Programmfluss geht durch die Definition von %qD mit thread-lokaler Speicherdauer"
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, gcc-internal-format
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "der Programmfluss geht durch die Definition von %qD mit statischer Speicherdauer"
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "Zwischenergebnis des nicht-literalen Typs %qT in konstantem Ausdruck"
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "Ein %<reinterpret_cast%> ist kein konstanter Ausdruck"
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "Umwandlung von Zeigertyp %qT in arithmetischen Typ %qT in Konstantenausdruck"
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr "der Cast von %qT ist in einem konstanten Ausdruck nicht zulässig, da der Typ %qT, auf den gezeigt wird, %qT nicht ähnlich ist"
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, gcc-internal-format
 msgid "pointed-to object declared here"
 msgstr "der Typ, auf den gezeigt wird, ist hier deklariert"
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr "der Cast von %qT ist in einem konstanten Ausdruck nicht zulässig, da %qE nicht auf ein Objekt zeigt"
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr "der Cast von %qT ist in einem konstanten Ausdruck vor C++26 nicht erlaubt"
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "%qE ist kein konstanter Ausdruck, solange die Klasse %qT noch unvollständig ist"
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> ist kein Konstantenausdruck"
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "Ausdruck %qE ist kein Konstantenausdruck"
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> ist kein Konstantenausdruck"
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "Vertragsbedingung ist false in konstantem Ausdruck"
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "unerwartete Template-ID %qE"
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr "Funktionskonzept muss aufgerufen werden"
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "Adresse des Aufrufs von %qs ist kein konstanter Ausdruck"
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "unexpected expression %qE of kind %s"
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE ist kein Konstantenausdruck, da er auf veränderliche Teilobjekte von %qT verweist"
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE ist kein Konstantenausdruck, da er auf eine unvollständig initialisierte Variable verweist"
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qE ist kein konstanter Ausdruck, da er auf das Ergebnis von %<operator new%> verweist"
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qE ist kein konstanter Ausdruck, da der angeforderte Speicher nicht vollständig freigegeben wurde"
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr "unmittelbare Auswertung liefert die Adresse der unmittelbaren Funktion %qD"
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, gcc-internal-format
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr "Konstantenauswertung liefert Adresse der unmittelbaren Funktion %qD"
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "Umwandlung lvalue-in-rvalue eines volatile-lvalue %qE mit Typ %qT"
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "Lambda-Einfangen von %qE ist kein konstanter Ausdruck"
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "da er als glvalue verwendet wird"
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "%<reinterpret_cast%> von Ganzzahl zu Zeiger"
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "Adresse eines Objektes %qE mit thread-lokalem oder automatischem Speicher ist kein konstanter Ausdruck"
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "Verwendung von %<this%> in Konstantenausdruck"
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Lambda-Ausdruck ist erst ab C++17 ein konstanter Ausdruck"
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "new-expression ist erst ab C++20 ein konstanter Ausdruck"
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "virtuelle Funktionen können erst mit C++20 %<constexpr%> sein"
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "%<typeid%> ist kein konstanter Ausdruck, da %qE polymorphen Typ hat"
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Umwandlung in Nicht-Ganzzahltyp %qT in konstantem Ausdruck"
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "%qD in %<constexpr%>-Kontext als %<thread_local%> definiert"
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "%qD in %<constexpr%>-Kontext als %<static%> definiert"
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "Division durch Null ist kein konstanter Ausdruck"
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> ist kein Konstantenausdruck"
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "keiner der Zweige des %<if%> ist ein Konstantenausdruck"
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "nicht konstante Arrayinitialisierung"
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "Definition einer Sprungmarke innerhalb einer %<constexpr%>-Funktion ist erst ab %<-std=c++2b%> oder %<-std=gnu++2b%> verfügbar"
 
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "unerwarteter AST der Art %s"
@@ -54172,7 +54195,7 @@ msgstr "das Richtungsargument für %<__builtin_coro_promise%> muss eine Konstant
 msgid "no suspend point info for %qD"
 msgstr "keine Informationen zum Aufschiebepunkt für %qD"
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr "%qE wird von %qT bereitgestellt, ist aber nicht mit der Funktionssignatur %qD verwendbar"
@@ -54192,23 +54215,23 @@ msgstr "await-Ausdrücke sind in Handlern nicht erlaubt"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "Arrays mit variabler Länge werden in Koroutinen noch nicht unterstützt"
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr "%qE wird von %qT bereitgestellt, aber %qE ist nicht mit %<throw()%> oder %<noexcept%> gekennzeichnet"
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr "%qE ist mit %<throw()%> oder %<noexcept%> markiert, aber %qT liefert kein brauchbares %<get_return_object_on_allocation_failure%>"
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr "%qE wird von %qT bereitgestellt, aber %<std::nothrow%> wurde nicht gefunden"
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr "ein Rückgabeobjekt vom Typ %qT kann nicht mit einem r-Wert vom Typ %<void%> initialisiert werden"
@@ -54228,68 +54251,68 @@ msgstr "%qD wurde in eine unmittelbare Funktion umgewandelt, da ihr Rumpf einen
 msgid "%qD was promoted to an immediate function"
 msgstr "%qD wurde zu einer unmittelbaren Funktion befördert"
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "Adresse der direkten Funktion %qD wird genommen"
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, gcc-internal-format
 msgid "call to consteval function %qE is not a constant expression"
 msgstr "Aufruf der consteval-Funktion %qE ist kein konstanter Ausdruck"
 
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%<throw%> wird immer %<terminate%> aufrufen"
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "in C++11 sind Destruktoren standardmäßig %<noexcept%>"
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr "in C++11 ruft dieses %<throw%> %<terminate%> auf, da Destruktoren standardmäßig %<noexcept%> sind"
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "Attribut %qE wird nach dem früheren %qE ignoriert"
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, gcc-internal-format
 msgid "pack expansion of %qE attribute"
 msgstr "Packungsexpansion des Attributs %qE"
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, gcc-internal-format
 msgid "use fold expression in the attribute argument instead"
 msgstr "verwenden Sie stattdessen einen fold-Ausdruck im Attributargument"
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD ist kein Typ"
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qD ist kein Klassentyp"
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qD hat nicht den Typ %<const char *%>"
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%qD hat keinen Ganzzahltyp"
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr "%<std::source_location::__impl%> enthält nicht nur nicht-statische Datenelemente %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> und %<_M_column%>"
@@ -54330,7 +54353,7 @@ msgstr "Umwandlung in nicht-konstanten Referenztyp %q#T von R-Wert des Typs %qT"
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "Umwandlung von %qH in %qI löscht Qualifizierer"
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "Umwandlung von %qT in %qT dereferenziert nicht den Zeiger"
@@ -54714,7 +54737,7 @@ msgstr "von vorheriger Deklaration %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "Redeklaration %qD unterscheidet sich in %qs von vorheriger Deklaration"
 
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "vorherige Deklaration %qD"
@@ -54854,8 +54877,8 @@ msgstr "vorherige Deklaration von %<pragma omp declare reduction%>"
 msgid "%q#D previously defined here"
 msgstr "%q#D wurde bereits hier definiert"
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q#D wurde bereits hier deklariert"
@@ -54930,52 +54953,37 @@ msgstr "Standardargument für Parameter %d von %q#D angegeben"
 msgid "previous specification in %q#D here"
 msgstr "bisherige Spezifikation in %q+#D hier"
 
-#: cp/decl.cc:2285
-#, gcc-internal-format
-msgid "declaration %qD conflicts with builtin"
-msgstr "Deklaration %qD widerspricht der eingebauten Deklaration"
-
-#: cp/decl.cc:2288
-#, gcc-internal-format
-msgid "declaration %qD conflicts with import"
-msgstr "Deklaration %qD widerspricht dem Import"
-
-#: cp/decl.cc:2289
-#, gcc-internal-format
-msgid "import declared %q#D here"
-msgstr "der Import hat %q#D hier deklariert"
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, gcc-internal-format
 msgid "conflicting exporting for declaration %qD"
 msgstr "in Konflikt stehender Export für Deklaration %qD"
 
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, gcc-internal-format
 msgid "previously declared here without exporting"
 msgstr "vorher hier ohne Export deklariert"
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "vorherige Definition von %qD war hier"
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "vorherige Deklaration von %qD war hier"
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "Funktion %qD wurde als %<[[noreturn]]%> deklariert, das weicht von der ersten Deklaration ab"
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "redundante Redeklaration von %qD im selben Gültigkeitsbereich"
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr "gelöschte Definition von %qD ist nicht die erste Deklaration"
@@ -54988,44 +54996,44 @@ msgstr "gelöschte Definition von %qD ist nicht die erste Deklaration"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "explizite Spezialisierung von %qD nach erster Verwendung"
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%qD: Sichtbarkeitsattribut ignoriert, da es in Konflikt mit vorheriger Deklaration steht"
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "Redefinition von %q#D"
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD steht mit verwendeter Funktion in Konflikt"
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D nicht in Klasse deklariert"
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D mit Attribut %<gnu_inline%> »inline« redeklariert"
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D ohne Attribut %<gnu_inline%> »inline« redeklariert"
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr "Vergleichsoperator %q+D mit Standardimplementierung nach der ersten Deklaration [class.compare.default]"
@@ -55033,2502 +55041,2502 @@ msgstr "Vergleichsoperator %q+D mit Standardimplementierung nach der ersten Dekl
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "Redeklaration des »friend« %q#D kann keine Standardtemplateargumente haben"
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "Thread-lokale Deklaration von %q#D folgt nicht-Thread-lokaler Deklaration"
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "Nicht-Thread-lokale Deklaration von %q#D folgt Thread-lokaler Deklaration"
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "Redeklaration von %q#D"
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "redundante Redeklaration von %<constexpr%>static-Datenmember %qD"
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "lokale Sprungmarke %qE steht in Konflikt mit bestehender Sprungmarke"
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, gcc-internal-format
 msgid "previous label"
 msgstr "vorherige Sprungmarke"
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, gcc-internal-format
 msgid "jump to label %qD"
 msgstr "Sprung zur Marke %qD"
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr "Sprung zur case-Marke"
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr "  als ein mögliches Ziel des berechneten goto"
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  von hier"
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  beendet OpenMP-strukturierten Block"
 
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  überschneidet Initialisierung von %q#D"
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr "  betritt %<try%>-Block"
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "  betritt %<catch%>-Block"
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  tritt in OpenMP-strukturierten Block ein"
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "  synchronisierte oder atomare Anweisung wird betreten"
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, gcc-internal-format
 msgid "  enters statement expression"
 msgstr "  betritt den Anweisungsausdruck"
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "  betritt %<constexpr if%>-Anweisung"
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, gcc-internal-format
 msgid "  enters %<consteval if%> statement"
 msgstr "  betritt %<consteval if%>-Anweisung"
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, gcc-internal-format
 msgid "  does not destroy %qD"
 msgstr "  zerstört %qD nicht"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, gcc-internal-format
 msgid "  does not clean up handled exception"
 msgstr "  bereinigt die behandelte Ausnahme nicht"
 
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  überspringt Initialisierung von %q#D"
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "%qD wird ohne Template-Argumente verwendet"
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, gcc-internal-format
 msgid "%qD is a function, not a type"
 msgstr "%qD ist eine Funktion, kein Typ"
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T ist keine Klasse"
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "kein Klassentemplate namens %q#T in %q#T"
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "kein Typ namens %q#T in %q#T"
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "Nachschlagen von %qT in %qT ist nicht eindeutig"
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> benennt %q#T, was kein Klassentemplate ist"
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> benennt %q#D, das ist jedoch kein Typ"
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "Template-Parameter passen nicht zum Template %qD"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "%<-faligned-new=%d%> ist keine Zweierpotenz"
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr "%<--param destructive-interference-size=%d%> ist kleiner als %d"
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr "%<--param destructive-interference-size=%d%> ist kleiner als %<--param l1-cache-line-size=%d%>"
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr "%<--param constructive-interference-size=%d%> ist kleiner als %d"
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr "%<--param constructive-interference-size=%d%> ist größer als %<--param l1-cache-line-size=%d%>"
 
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D ungültig; eine anonyme Union kann nur nicht-statische Datenelemente haben"
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "diese Flexibilität ist veraltet und wird demnächst entfernt"
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr "anonyme Struktur mit Basisklassen"
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "Element %q+#D mit Konstruktor in anonymem Aggregat nicht erlaubt"
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "Element %q+#D mit Destruktor in anonymem Aggregat nicht erlaubt"
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "Element %q+#D mit Zuweisungsoperator ist in anonymem Aggregt nicht erlaubt"
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "Attribut in Deklaration von %q#T ignoriert"
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "Attribut für %q#T muss dem Schlüsselwort %qs folgen"
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "mehrere Typen in einer Deklaration"
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "Redeklaration des eingebauten C++-Typs %qT"
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> kann nur für Variablen oder Funktionsdeklarationen angegeben werden"
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "fehlender Typname in typedef-Deklaration"
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO-C++ verbietet anonyme structs"
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> kann nur für Funktionen angegeben werden"
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> kann nur für Funktionen angegeben werden"
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> kann nur innerhalb einer Klasse angegeben werden"
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> kann nur für Konstruktoren angegeben werden"
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "eine Speicherklasse kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> kann nur für Objekte und Funktionen angegeben werden"
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> wurde in dieser Deklaration ignoriert"
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%qs kann nicht für Typdeklarationen verwendet werden"
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "Attribut in expliter Instanziierung %q#T ignoriert"
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "auf explizite Instanziierung kann kein Attribut angewendet werden"
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "auf Klassentyp %qT angewandte Attribute außerhalb einer Definition werden ignoriert"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "auf abhängigen Typ %qT angewandte Attribute ohne zugehörige Deklaration werden ignoriert"
 
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD ist initialisiert (stattdessen %qs verwenden)"
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "Deklaration von %q#D hat %<extern%> und ist initialisiert"
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "Definition von %q#D ist als %<dllimport%> markiert"
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D ist kein static-Datenelement von %q#T"
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "Nichtelement-Templatedeklaration von %qD"
 
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "entspricht nicht der Element-Templatedeklaration hier"
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO-C++ erlaubt nicht, %<%T::%D%> als %<%T::%D%> zu definieren"
 
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "doppelte Initialisierung von %qD"
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "Deklaration von %q#D außerhalb einer Klasse ist keine Definition"
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr "extern-Deklaration %q#D mit Gültigkeitsbereich Block darf nicht an ein benanntes Modul angehängt werden"
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%qD kann in einer %qs-Funktion erst ab %<-std=c++2b%> oder %<-std=gnu++2b%> als %<thread_local%> definiert werden"
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%qD kann in einer %qs-Funktion erst ab %<-std=c++2b%> oder %<-std=gnu++2b%> als %<static%> definiert werden"
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "Variable %q#D hat Initialisierung, aber unvollständigen Typ"
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "Elemente des Arrays %q#D haben unvollständigen Typ"
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "Aggregat %q#D hat unvollständigen Typ und kann nicht definiert werden"
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD als Referenz deklariert, aber nicht initialisiert"
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "Name in benannter Initialisierung im GNU-Stil für ein Array verwendet"
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "Name %qD in benannter Initialisierung im GNU-Stil für ein Array verwendet"
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "nicht-trivial markierte Initialisierungen nicht unterstützt"
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "C99-Designator %qE ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "Initialisierung gibt nicht die Größe von %qD an"
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "Arraygröße fehlt in %qD"
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "Array %qD der Größe null"
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "Speichergröße von %qD ist unbekannt"
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "Speichergröße von %qD ist nicht konstant"
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "Entschuldigung: Semantik der Inline-Variable %q#D ist falsch (mehrere Kopien wären die Folge)"
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "Entschuldigung: Semantik von static-Variable %q#D in inline-Funktion ist falsch (mehrere Kopien wären die Folge)"
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "dies kann durch das Löschen der Initialisierung umgangen werden"
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "nicht initialisiertes %<const %D%>"
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "uninitialisierte Variable %qD in %<constexpr%>-Funktion"
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "uninitialisierte Variable %qD in %<constexpr%>-Kontext"
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T hat keinen benutzerdefinierten Default-Konstruktor"
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "Konstruktor ist nicht benutzerdefiniert, da er im Klassenkörper ausdrücklich standardisiert ist"
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "und der implizit definierte Konstruktor initialisiert %q#D nicht"
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "Ungültiger Typ %qT als Initialisierung für einen Vektor des Typs %qT"
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "Initialisierung für %qT muss geklammert sein"
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> in benannter Initialisierung im GNU-Stil für Klasse %qT verwendet"
 
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "Abfrage des Elementes %qD ist mehrdeutig"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT hat kein nicht-statisches Datenelement namens %qD"
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD ist kein direktes Element von %qT"
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "ungültige Initialisierung für %q#D"
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99-Bezeichner %qE außerhalb von Aggregatinitialisierung"
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "zu viele Initialisierer für %qT"
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "geschweifte Klammern um skalare Initialisierung für Typ %qT"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90182
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "zu viele geschweifte Klammern um skalare Initialisierung für Typ %qT"
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "geschweifte Klammern fehlen um Initialisierung für %qT"
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "Strukturierte Bindung hat unvollständigen Typen %qT"
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "Elemente des Arrays %q#T haben unvollständigen Typ"
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "zusammengesetztes Literal variabler Größe"
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D hat unvollständigen Typ"
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "skalares Objekt %qD erfordert ein Element in Initialisierung"
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "in C++98 muss %qD mit Konstruktor initialisiert werden, nicht mit %<{...}%>"
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "Array %qD mit geklammerter Zeichenkettenkonstante %qE initialisiert"
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "Initialisierung ungültig für statisches Element mit Konstruktor"
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "Initialisierung des nicht konstanten statischen Elements %qD in der Klasse ist ungültig"
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "Initialisierung des nicht konstanten statischen Elements %qD in der Klasse ist ungültig"
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(eine Initialisierung außerhalb der Klasse ist erforderlich)"
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "Referenz %qD wird mit sich selbst initialisiert"
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "Variantendeklaration nicht gefunden"
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%<declare variant%> für Konstruktor %qD"
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "%<declare variant%> für Destruktor %qD"
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "%<declare variant%> an %qD mit Vorgabewert"
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr "%<declare variant%> an gelöschter %qD"
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%<declare variant%> an virtueller %qD"
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "Zuweisung (nicht Initialisierung) in Deklaration"
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO-C++17 erlaubt Speicherklassenangabe %<register%> nicht"
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "%<register%>-Speicherklassenangabe verwendet"
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "Deklaration von %q#D hat keine Initialisierung"
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "Initialisierung für %<decltype(auto) %D%> hat Funktionstyp; %<()%> vergessen?"
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, gcc-internal-format
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "deduzierter Typ %qT für %qD ist unvollständig"
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "Variablenkonzept hat keine Initialisierung"
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "vorherige Typdeklaration von %q#D wird überschattet"
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "Attribut %<constinit%> kann nur für Variablen verwendet werden, die »static« oder threadlokel sind"
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "Funktion %q#D ist wie eine Variable initialisiert"
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da er ein unbenanntes Strukturelement hat"
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da er ein unbenanntes Unionelement hat"
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "unzugreifbares Element %qD von %qT kann nicht dekomponiert werden"
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da sowohl er als auch seine Basisklasse %qT nichtstatische Datenelemente haben"
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da seine Basisklassen %qT und %qT nichtstatische Datenelemente haben"
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "Strukturierte Bindung verweist auf unvollständigen Typen %qT"
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "Array mit variabler Länge %qT kann nicht dekomponiert werden"
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%u Name für strukturelle Bindung angegeben"
 msgstr[1] "%u Namen für strukturelle Bindung angegeben"
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] "nur %u Name für strukturelle Bindung angegeben"
 msgstr[1] "nur %u Namen für strukturelle Bindung angegeben"
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] "während %qT in %wu Element zerlegt wird"
 msgstr[1] "während %qT in %wu Elemente zerlegt wird"
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "Vektor %qT variabler Länge kann nicht zerlegt werden"
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "während %qT in %E Elemente zerlegt wird"
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr "%<std::tuple_element<%u, %T>::type%> ist %<void%>"
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "in Initialisierung der Variable %qD für strukturierte Bindung"
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "Union-Typ %qT kann nicht dekomponiert werden"
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "nicht-Array-nicht-Klassentyp %qT kann nicht dekomponiert werden"
 
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "Lambda-Abschluss-Typ %qT kann nicht dekomponiert werden"
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "Strukturierte Bindung verweist auf unvollständigen Klassentypen %qT"
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "Klassentyp %qT ohne nicht-static-Datenelemente kann nicht dekomponiert werden"
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "nicht-lokale %<__thread%>-Variable %qD erfordert dynamische Initialisierung"
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "nicht-lokale %<__thread%>-Variable %qD hat einen nicht-trivialen Destruktor"
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "%<thread_local%> in C++11 erlaubt dynamische Initialisierung und Zerstörung"
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "Initialisierung gibt nicht die Größe von %qT an"
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "Arraygröße fehlt in %qT"
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "Array %qT der Größe null"
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "Destruktor für fremde Klasse %qT kann kein Element sein"
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "Konstruktor für fremde Klasse %qT kann kein Element sein"
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD als eine %<virtual%> Variable deklariert"
 
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Variablendeklaration"
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD als ein %<virtual%> Parameter deklariert"
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD als ein %<inline%> Parameter deklariert"
 
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Parameterdeklaration"
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD als ein %<virtual%> Typ deklariert"
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD als ein %<inline%> Typ deklariert"
 
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Typdeklaration"
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD als ein %<virtual%> Feld deklariert"
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD als ein %<inline%> Feld deklariert"
 
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Felddeklaration"
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D als »friend« deklariert"
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D mit einer Ausnahmespezifikation deklariert"
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "Deklaration von %qD ist nicht in einem Namensbereich um %qT"
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statische Elementfunktion %q#D mit Typqualifizierern deklariert"
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "Konzept %q#D mit Funktionsparametern deklariert"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "Konzept %q#D mit hergeleitetem Rückgabetyp deklariert"
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Konzept %q#D mit nicht-%<bool%>-Rückgabetyp %qT"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "Konzept %qD hat keine Definition"
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "ein Funktionskonzept kann nicht eingeschränkt werden"
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "Einschränkungen auf einer Funktion, die kein Template hat"
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, gcc-internal-format
 msgid "constrained non-template friend declaration must be a definition"
 msgstr "eingeschränkte Nicht-Template-friend-Deklaration muss eine Definition sein"
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr "friend-Funktionstemplate mit Einschränkungen, die von äußeren Templateparametern abhängen, muss eine Definition sein"
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "Definition der expliziten Spezialisierung %qD in friend-Deklaration"
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ungültige Verwendung der Template-ID %qD in Deklaration des ursprünglichen Templates"
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "Standardargumente sind nicht in Deklaration der friend-Template-Spezialisierung %qD erlaubt"
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> ist nicht in Deklaration der friend-Template-Spezialisierung %qD erlaubt"
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "»friend«-Deklaration von %qD gibt Defaultargumente an und ist keine Definition"
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "%<::main%> kann nicht als Template deklariert werden"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "%<::main%> kann nicht inline deklariert werden"
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "%<::main%> kann nicht als %qs deklariert werden"
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "%<::main%> kann nicht statisch deklariert werden"
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "Nicht-Elementfunktion %qD kann nicht CV-Qualifizierer haben"
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "statische Elementfunktion %qD kann nicht CV-Qualifizierer haben"
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, gcc-internal-format
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr "explizite Objekt-Member-Funktion %qD kann keine CV-Qualifizierer haben"
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "Nicht-Elementfunktion %qD kann keinen ref-Qualifizierer haben"
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "statische Elementfunktion %qD kann keinen ref-Qualifizierer haben"
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, gcc-internal-format
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr "explizite Objekt-Member-Funktion %qD kann keinen ref-qualifier haben"
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, gcc-internal-format
 msgid "explicit object parameter declared here"
 msgstr "expliziter Objektparameter wird hier deklariert"
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "Herleitungshinweis %qD muss im selben Gültigkeitsbereich wie %qT deklariert sein"
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "Herleitungshinweis %qD muss denselben Zugriff wie %qT haben"
 
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "Herleitungshinweis %qD darf keinen Funktionskörper haben"
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "literaler Operator mit C-Bindung"
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD hat ungültige Argumentliste"
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "Ganzzahl-Suffix %qs durch Implementierung überdeckt"
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "Gleitkomma-Suffix %qs durch Implementierung überdeckt"
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "Literale Operator-Suffixe ohne vorangehendes %<_%> sind für zukünftige Standardisierungen reserviert"
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD muss eine Nicht-Elementfunktion sein"
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> muss %<int%> zurückgeben"
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "Definition des implizit deklarierten %qD"
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "Definition des explizit standardisierten %q+D"
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D wurde hat hier ausdrücklichen Standardwert bekommen"
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "keine Elementfunktion %q#D in Klasse %qT deklariert"
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%<::main%> kann nicht als globale Variable deklariert werden"
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "eine Nicht-Template-Variable kann nicht %<concept%> sein"
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr "Konzept muss im Gültigkeitsbereich des Namensbereiches definiert werden"
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "Konzept muss Typ %<bool%> haben"
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "ein Variablenkonzept kann nicht eingeschränkt werden"
 
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "Initialisierung innerhalb der Klasse des statischen Datenelements %q#D mit unvollständigem Typ"
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> erforderlich für Initialisierung innerhalb der Klasse des statischen Datenelements %q#D mit nicht eingebautem Typ"
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "Initialisierung innerhalb der Klasse des statischen Datenelements %q#D mit nicht eingebautem Typ"
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ungültige Initialisierung innerhalb der Klasse des statischen Datenelements vom nicht eingebauten Typen %qT"
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO-C++ verbietet Initialisierung des nicht konstanten statischen Elements %qD in der Klasse"
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO-C++ verbietet Initialisierung der Elementkonstante %qD vom nicht eingebauten Typen %qT"
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "Arraygröße von %qD hat nicht-ganzzahligen Typen %qT"
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "Arraygröße hat nicht-ganzzahligen Typen %qT"
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "Größe des Arrays %qD ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "Größe des Arrays ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO-C++ verbietet Array %qD der Größe null"
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO-C++ verbietet Array der Größe null"
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO-C++ verbietet Array %qD variabler Länge"
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO-C++ verbietet Array variabler Länge"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "Array %qD variabler Länge wird verwendet"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "Array variabler Größe wird verwendet"
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "Überlauf in Arraygröße"
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%qD ist als Array vom Template-Platzhaltertyp %qT deklariert"
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr "Array des Template-Platzhaltertyps %qT wird erzeugt"
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "Deklaration von %qD als Array von voids"
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "Array von void wird erzeugt"
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "Deklaration von %qD als Array von Funktionen"
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "Array von Funktionen wird erzeugt"
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "Deklaration von %qD als Array von Referenzen"
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "Feld von Referenzen wird erzeugt"
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "Deklaration von %qD als Feld von Funktionselementen"
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "Feld von Funktionselementen wird erzeugt"
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "Deklaration von %qD als multidimensionales Feld muss für alle Dimensionen außer der ersten Grenzen haben"
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "multidimensionales Feld muss für alle Dimensionen außer der ersten Grenzen haben"
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr "Array variabler Größe von %<auto%>"
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "Angabe des Rückgabetyps für Konstruktor ist ungültig"
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "Qualifizierer sind bei Konstruktordeklarationen nicht erlaubt"
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "Angabe des Rückgabetyps für Destruktor ist ungültig"
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "Qualifizierer sind bei Destruktordeklarationen nicht erlaubt"
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "Rückgabetyp für %<operator %T%> angegeben"
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "Qualifizierer sind bei Deklaration von %<operator %T%> nicht erlaubt"
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "Rückgabetyp für Herleitungshinweis angegeben"
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "Qualifizierer sind bei Deklaration von Herleitungshinweis nicht erlaubt"
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "Template-Template-Parameter %qT in Deklaration von Ableitungshinweis"
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "%<decl-specifier%> in Deklaration von Ableitungshinweis"
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "unbenannte Variable oder Feld als »void« deklariert"
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "Variable oder Feld als »void« deklariert"
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "%<inline%>-Spezifizierer ungültig für Variable %qD mit Gültigkeitsbereich Block"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "»inline«-Variablen sind nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT als Typ statt als einfaches %<decltype(auto)%>"
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "%<decltype(auto)%> darf nicht CV-qualifiziert sein"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ungültige Verwendung des qualifizierten Namens %<::%D%>"
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ungültige Verwendung des qualifizierten Namens %<%T::%D%>"
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ungültige Verwendung des qualifizierten Namens %<%D::%D%>"
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%q#T ist weder Klasse noch Namensbereich"
 
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "Deklaration von %qE als Nicht-Funktion"
 
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "Deklaration von %qE als Nicht-Element"
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "Deklarator-ID fehlt: reserviertes Wort %qD wird verwendet"
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "Funktionsdefinition deklariert keine Parameter"
 
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "Deklaration von %qD als Nicht-Funktion"
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "Deklaration von %qD als %<typedef%>"
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "Deklaration von %qD als Parameter"
 
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr "sowohl %qs als auch %qs angegeben"
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%qs kann nicht in einer typedef-Deklaration auftreten"
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr "höchstens einer der Spezifizierer %<constinit%> und %<constexpr%> kann verwendet werden"
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "zwei oder mehr Datentypen in Deklaration von %qs"
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO-C++ unterstützt nicht, dass einfaches %<complex%> %<double complex%> bedeutet"
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO-C++ verbietet Deklaration von %qs ohne Typ"
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> wird von diesem Ziel nicht unterstützt"
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO-C++ unterstützt %<__int%d%> für %qs nicht"
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> und %<unsigned%> gleichzeitig angegeben"
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> und %<short%> gleichzeitig angegeben"
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qs mit %qT angegeben"
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, gcc-internal-format
 msgid "%qs specified with typedef-name %qD"
 msgstr "%qs mit typedef-name %qD angegeben"
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs mit %<decltype%> angegeben"
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qs mit %<typeof%> angegeben"
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex ungültig für %qs"
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr "fehlende Template-Argumentliste nach %qE; für die Deduktion muss auf den Template-Platzhalter eine einfache Deklarator-ID folgen"
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "Element %qD kann nicht gleichzeitig %<virtual%> und %<static%> sein"
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Element %qD kann erst mit %<-std=c++20%> oder %<-std=gnu++20%> gleichzeitig %<virtual%> und %<constexpr%> sein"
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "»typedef«-Deklaration in Parameterdeklaration ungültig"
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "Speicherklasse für Template-Parameter %qs angegeben"
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "Speicherklasse für Parameter %qs angegeben"
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "ein Parameter kann nicht als %qs deklariert sein"
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> außerhalb einer Klassendeklaration"
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %qs deklariert werden"
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "strukturierte Bindungsdeklarationen können erst ab %<-std=c++20%> oder %<-std=gnu++20%> %qs sein"
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "%<volatile%>-qualifizierte strukturierte Bindung ist veraltet"
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<auto%> (C++98) deklariert werden"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "Deklaration für strukturierte Bindung darf nicht vom Typen %qT sein"
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "Typ muss cv-qualifizierter %<auto%> oder Referenz auf cv-qualifizierten %<auto%> sein"
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "Deklaration für strukturierte Bindung darf nicht vom eingeschränkten %<auto%>-Typen %qT sein"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "mehrere Speicherklassen in Deklaration von %qs"
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "Speicherklasse %qs angegeben"
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "geschachtelte Funktion %qs als %<extern%> deklariert"
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "Deklaration höchster Ebene von %qs gibt %<auto%> an"
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "Funktions-Gültigkeitsbereich %qs ist implizit auto und deklarierte %<__thread%>"
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "Speicherklassenangaben sind in friend-Funktionsdeklarationen ungültig"
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "Attribut wird ignoriert"
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "ein Attribut, das sich auf eine Typspezifizierung bezieht, wird ignoriert"
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "unnötige Klammern in Deklaration von %qs"
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr "entfernen Sie die Klammern"
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, gcc-internal-format
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "explizite Objekt-Member-Funktion ist erst ab %<-std=c++23%> oder %<-std=gnu++23%> verfügbar"
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, gcc-internal-format
 msgid "a function type cannot have an explicit object parameter"
 msgstr "ein Funktionstyp kann keinen expliziten Objektparameter haben"
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, gcc-internal-format
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr "ein Zeiger auf einen Funktionstyp kann keinen expliziten Objektparameter haben"
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, gcc-internal-format
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr "ein Zeiger auf einen Memberfunktionstyp kann keinen expliziten Objektparameter haben"
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr "der Typ eines Zeigers auf eine explizite Objekt-Member-Funktion ist ein normaler Funktionszeiger-Typ"
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, gcc-internal-format
 msgid "the type of an explicit object member function is a regular function type"
 msgstr "der Typ einer expliziten Objekt-Member-Funktion ist ein normaler Funktionstyp"
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr "nur der erste Parameter einer Memberfunktion kann als expliziter Objektparameter deklariert werden"
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "valid explicit object parameter declared here"
 msgstr "gültiger expliziter Objektparameter wird hier deklariert"
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "»requires«-Klausel für Rückgabetyp"
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "Funktion %qs verwendet Typspezifikation %<auto%> ohne folgenden Rückgabetypen"
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "hergeleiteter Rückgabetyp nur mit %<-std=c++14%> oder %<-std=gnu++14%> verfügbar"
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "virtuelle Funktionen kann keinen hergeleiteten Rückgabetyp haben"
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "Funktion %qs mit folgendem Rückgabetypen hat %qT als seinen Typ statt einfaches %<auto%>"
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "Funktion %qs mit nachgestelltem Rückgabetyp hat %<decltype(auto)%> als Typ statt einfachem %<auto%>"
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "ungültige Verwendung von %<decltype(auto)%>"
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "hergeleiteter Klassentyp %qD in Rückgabetyp von Funktion"
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "Herleitungshinweis für %qT muss angehängten Rückgabetyp haben"
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "angehängter Rückgabetyp %qT den Ableitungshinweises ist keine Spezialisierung von %qT"
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "nachgestellter Rückgabetyp nur mit %<-std=c++11%> oder %<-std=gnu++11%> verfügbar"
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "Funktion %qs mit folgendem Rückgabetypen nicht mit Typspezifikation %<auto%> deklariert"
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "eine Umwandlungsfunktion darf keinen angehängten Rückgabetyp haben"
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "%<volatile%>-qualifizierter Rückgabetyp ist veraltet"
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs als Funktion, die eine Funktion zurückgibt, deklariert"
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs als Funktion, die ein Feld zurückgibt, deklariert"
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<constinit%> ist am Rückgabetyp einer Funktion nicht erlaubt"
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "Destruktor kann keine statische Elementfunktion sein"
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "Konstruktor kann keine statische Elementfunktion sein"
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "Destruktoren dürfen nicht CV-qualifiziert sein"
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "Konstruktoren dürfen nicht CV-qualifiziert sein"
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "Destruktoren dürfen nicht ref-qualifiziert sein"
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "Konstruktoren dürfen nicht ref-qualifiziert sein"
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "Konstruktoren dürfen nicht als %<virtual%> deklariert sein"
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "virtuelle Funktionen können keine friends sein"
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-Deklaration nicht in Klassendefinition"
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "%<friend%>-Funktion %qs kann nicht in einer lokalen Klassendefinition definiert werden"
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr "Definition der Freundfunktion %qs kann keinen Namen haben, der mit %<::%> qualifiziert ist"
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr "Definition der Freundfunktion %qs kann keinen Namen haben, der mit %<%D::%> qualifiziert ist"
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, gcc-internal-format
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr "eine Funktion, die kein Member ist, kann keinen expliziten Objektparameter haben"
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr "eine explizite Objekt-Member-Funktion kann nicht %<virtual%> sein"
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<static%>"
 msgstr "eine explizite Objekt-Member-Funktion kann nicht %<static%> sein"
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, gcc-internal-format
 msgid "%qD cannot be an explicit object member function"
 msgstr "%qD kann keine explizite Objektelementfunktion sein"
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "Destruktoren dürfen keine Parameter haben"
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "Zeiger auf %q#T kann nicht deklariert werden"
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "Referenz auf %q#T kann nicht deklariert werden"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "Zeiger auf Element %q#T kann nicht deklariert werden"
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "Referenz auf qualifizierten Funktionstypen %qT kann nicht deklariert werden"
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "Zeiger auf qualifizierten Funktionstypen %qT kann nicht deklariert werden"
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "Referenz auf %q#T kann nicht deklariert werden, da letzteres weder Typedef noch Templatetyp-Argument ist"
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "Template-ID %qD als Deklarator verwendet"
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "Elementfunktionen sind implizite »friends« ihrer Klasse"
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "zusätzliche Qualifizierung %<%T::%> an Element %qs"
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "Elementfunktion %<%T::%s%> kann nicht innerhalb von %qT definiert werden"
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "Elementfunktion %<%T::%s%> kann nicht innerhalb von %qT deklariert werden"
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "Element %<%T::%s%> kann nicht in %qT deklariert werden"
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "Nicht-Parameter %qs kann kein Parameterpack sein"
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "Datenelement darf nicht variabel modifizierten Typ %qT haben"
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "Parameter darf nicht variabel modifizierten Typ %qT haben"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> außerhalb einer Klassendeklaration"
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> in »friend«-Deklaration"
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "nur Deklarationen von Konstruktoren und Umwandlungsoperatoren können %<explicit%> sein"
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "Nicht-Element %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "Nicht-Objekt-Element %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "Funktion %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "%qs ist %<static%> und darf daher nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "%qs ist %<const%> und darf daher nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "Referenz %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "mit %<typedef%> definierte Funktion darf keinen Rumpf %<{ … }%> haben"
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "mit %<typedef%> definierte Elementfunktion darf keinen Rumpf %<{ … }%> haben"
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<auto%> ist in Aliasdeklaration nicht erlaubt"
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "»typedef« als %<auto%> deklariert"
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "requires-clause an Typedef"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-Name darf kein Spezifizierer mit geschachteltem Namen sein"
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO-C++ verbietet geschachtelten Typen %qD mit gleichem Namen wie umschließende Klasse"
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> für friend-Klassen-Deklaration angegeben"
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "Template-Parameter können keine »friends« sein"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend-Deklaration erfordert Klassenschlüssel, d.h. %<friend class %T::%D%>"
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend-Deklaration erfordert Klassenschlüssel, d.h. %<friend %#T%>"
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "Versuch, die Klasse %qT zu einem »friend« des globalen Gültigkeitsbereiches zu machen"
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ungültige Qualifizierer an Nicht-Element-Funktionstyp"
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "requires-clause an type-id"
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakter Deklarator %qT als Deklaration verwendet"
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "»requires«-Klausel in Deklaration von Nichtfunktionstyp %qT"
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "%<::%> kann nicht in Parameterdeklaration verwendet werden"
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "Parameter kann nicht mit %<decltype(auto)%> deklariert werden"
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr "fehlende Template-Argumentliste nach %qE; Template-Platzhalter ist in Parameter nicht erlaubt"
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr "oder verwenden Sie %<auto%> für ein abgekürztes Funktionstemplate"
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<auto%>-Parameter darf in diesem Kontext nicht verwendet werden"
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "Parameter als %<auto%> deklariert"
 
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ungültige Verwendung des Template-Namens %qE ohne eine Argumentliste"
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "nicht-statisches Datenelement mit Platzhalter %qT deklariert"
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO-C++ verbietet flexibles Arrayelement %qs"
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO-C++ verbietet flexible Arrayelemente"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ungültige Verwendung von %<::%>"
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "Deklaration der Funktion %qD in ungültigem Kontext"
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "Funktion %qD wurde innerhalb einer Union als %<virtual%> deklariert"
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD kann nicht als %<virtual%> deklariert werden, da es immer statisch ist"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "Qualifizierten Namen in Friend-Deklaration für Destruktor %qD erwartet"
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "Deklaration von %qD als Element %qT"
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "ein Destruktor kann nicht %qs sein"
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "Qualifizierten Namen in Friend-Deklaration für Konstruktor %qD erwartet"
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "ein Konstruktor kann nicht %<concept%> sein"
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "ein Konzept kann keine Elementfunktion sein"
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%qD kann nicht %qs sein"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "Spezialisierung des Variablentemplates %qD als Funktion deklariert"
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "Variablentemplate hier deklariert"
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "Feld %qD hat unvollständigen Typen %qT"
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "Name %qT hat unvollständigen Typen"
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE ist weder eine Funktion noch Elementfunktion; kann nicht als »friend« deklariert werden"
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "unbenanntes Feld ist weder eine Funktion noch Elementfunktion; kann nicht als %<friend%> deklariert werden"
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr "ein Attribut, das zu einer »friend«-Deklaration gehört, die keine Definition ist, wird ignoriert"
 
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "statisches Datenelement %qE als %qs deklariert"
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "statisches Datenelement %qD (%<constexpr%>) muss Initialisierung haben"
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "nicht-statisches Datenelement %qE als %qs deklariert"
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "Speicherklasse %<auto%> ungültig für Funktion %qs"
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "Speicherklasse %<register%> ungültig für Funktion %qs"
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "Speicherklasse %<__thread%> ungültig für Funktion %qs"
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "Speicherklasse %<thread_local%> ungültig für Funktion %qs"
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, gcc-internal-format
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr "%<constinit%>-Angabe ungültig für Funktion %qs"
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-Spezifikation in %qs ist außerhalb einer Klassendefinition nicht erlaubt"
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> ist für außerhalb des globalen Gültigkeitsbereiches deklarierte Funktion %qs ungültig"
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<inline%> ungültig für außerhalb des globalen Gültigkeitsbereiches deklarierte Funktion %qs"
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuelle Nicht-Klassen-Funktion %qs"
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs nicht in Klassen-Gültigkeitsbereich definiert"
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs in einem Nicht-Klassen-Gültigkeitsbereich definiert"
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "Elementfunktion %qD kann nicht deklariert werden, statische Bindung zu haben"
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "statische Funktion innerhalb anderer Funktion kann nicht deklariert werden"
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> darf nicht bei der Definition (im Gegensatz zu Deklaration) eines statischen Datenelementes verwendet werden"
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statisches Element %qD als %<register%> deklariert"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "Element %q#D kann nicht explizit deklariert werden, externe Bindung zu haben"
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "Deklaration der %<constexpr%>-Variable %qD ist keine Definition"
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "eine Variable kann nicht als %<consteval%> deklariert sein"
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initialisiert und als %<extern%> deklariert"
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs hat sowohl %<extern%> als auch Initialisierung"
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "Standardargument %qE verwendet %qD"
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "Standardargument %qE verwendet lokale Variable %qD"
 
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ungültige Verwendung von cv-qualifiziertem Typ %qT in Parameterdeklaration"
 
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "ungültige Verwendung von Typ %<void%> in Parameterdeklaration"
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "%<volatile%>-qualifizierter Parameter ist veraltet"
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "Parameter %qD deklariert ungültigerweise Methodentyp"
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "Parameter %qD bezieht Zeiger auf Feld mit unbekannter Grenze %qT ein"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "Parameter %qD bezieht Referenz auf Feld mit unbekannter Grenze %qT ein"
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ungültiger Konstruktor; wahrscheinlich war %<%T (const %T&)%> gemeint"
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD darf nicht innerhalb eines Namensbereiches definiert werden"
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD darf nicht als »static« deklariert werden"
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "%qD muss eine nichtstatische Elementfunktion sein"
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "%qD muss eine Memberfunktion sein"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "%qD darf erst ab %<-std=c++23%> oder %<-std=gnu++23%> eine statische Memberfunktion sein"
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD muss entweder eine nichtstatische Elementfunktion oder eine Nicht-Element-Funktion sein"
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD muss ein Argument von einem Klassen- oder Aufzählungstyp haben"
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO-C++ verbietet Überladen von %<operator ?:%>"
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "»%qD« darf keine variable Argumentanzahl haben"
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD muss entweder null oder ein Argument nehmen"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD muss entweder ein oder zwei Argumente nehmen"
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "Suffix-%qD muss %<int%> als sein Argument nehmen"
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "Suffix-%qD muss %<int%> als sein zweites Argument nehmen"
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD darf keine Argumente nehmen"
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD muss genau ein Argument nehmen"
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD muss genau zwei Argumente nehmen"
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD kann keine Standardargumente haben"
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "Umwandlung von %qT in %<void%> wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "Umwandlung von %qT in Referenz auf gleichen Typ wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "Umwandlung von %qT in gleichen Typ wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "Umwandlung von %qT in Referenz auf Basisklasse %qT wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "Umwandlung von %qT in Basisklasse %qT wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "benutzerdefiniertes %qD wertet immer beide Argumente aus"
 
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "Präfix-%qD sollte %qT zurückgeben"
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "Suffix-%qD sollte %qT zurückgeben"
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD sollte Wert zurückgeben"
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "Templatetyp-Parameter %qT wird nach %qs verwendet"
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "Templatespezialisierung alias %qT hinter %qs wird verwendet"
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "typedef-Name %qD wird nach %qs verwendet"
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD hat eine vorherige Deklaration hier"
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT als %qs verwendet"
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT hat hier eine vorherige Deklaration"
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT als enum verwendet"
@@ -57540,115 +57548,100 @@ msgstr "%qT als enum verwendet"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "Template-Argument für %<%s %T%> benötigt"
 
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "Referenz auf %qD ist mehrdeutig"
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr "Klassentemplate %qD als Nicht-Template redeklariert"
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD hat den gleichen Namen wie die Klasse, in der es deklariert wurde"
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT ist kein Template"
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "Sie könnten ein explizites %<%T::%> hinzufügen"
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "Verwendung des enum %q#D ohne vorherige Deklaration"
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "Redeklaration von %qT als Nicht-Template"
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, gcc-internal-format
-msgid "cannot declare %qD in a different module"
-msgstr "%qD kann nicht in einem anderen Modul deklariert sein"
-
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, gcc-internal-format
-msgid "previously declared here"
-msgstr "vorher hier deklariert"
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "abgeleitete Union %qT ist ungültig"
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT ist mit mehreren direkten Basisklassen definiert"
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT ist mit direkter virtueller Basisklasse definiert"
 
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "Basistyp %qT ist kein struct- oder Klassentyp"
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiver Typ %qT nicht definiert"
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "doppelter Basistyp %qT ungültig"
 
-#: cp/decl.cc:16984
-#, gcc-internal-format
-msgid "cannot declare %qD in different module"
-msgstr "%qD kann nicht in einem anderen Modul deklariert sein"
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "falsche Zuordnung zwischen innerhalb und außerhalb eines Gültigkeitsbereiches in enum %q#T"
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "vorherige Definition hier"
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "falsche Zuordnung des zugrunde liegenden Typs in enum %q#T"
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "anderer zugrunde liegender Typ in enum %q#T"
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "zugrunde liegender Typ %qT von %qT muss ein ganzzahliger Typ sein"
@@ -57657,82 +57650,82 @@ msgstr "zugrunde liegender Typ %qT von %qT muss ein ganzzahliger Typ sein"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "kein Ganzzahltyp kann alle Aufzählungswerte für %qT darstellen"
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "Aufzählungswert für %qD muss ganzzahligen oder Aufzählungstyp ohne Gültigkeitsbereich haben"
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "Aufzählungswert für %qD ist keine Ganzzahlkonstante"
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "erhöhter Aufzählungswert ist zu groß für %<unsigned long%>"
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "erhöhter Aufzählungswert ist zu groß für %<long%>"
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "Überlauf in Aufzählungswerten bei %qD"
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "Aufzählungswert %qE ist außerhalb des Gültigkeitsbereichs des zugrundeliegenden Typen %qT"
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "mehrfache Definition von %q#T"
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "Rückgabetyp %q#T ist unvollständig"
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> sollte eine Referenz auf %<*this%> zurückgeben"
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "keine return-Anweisungen in %qT zurückgebender Funktion"
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "nur einfacher Rückgabetyp %<auto%> kann zu %<void%> hergeleitet werden"
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "eine %<constexpr%>-Funktion, die etwas Anderes als %<void%> zurückgibt, muss eine return-Anweisung enthalten"
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD ist bereits in Klasse %qT definiert"
 
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, gcc-internal-format
 msgid "using %qs"
 msgstr "%qs wird verwendet"
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "Verwendung von %qD vor Herleitung von %<auto%>"
@@ -57787,7 +57780,7 @@ msgstr "Eine Funktion kann nicht gelöscht werden. Nur Zeiger auf Objekte sind g
 msgid "deleting %qT is undefined"
 msgstr "Löschen von %qT ist nicht definiert"
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "Templatedeklaration von %q#D"
@@ -57797,7 +57790,7 @@ msgstr "Templatedeklaration von %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "angegebene Template-Parameterlisten passen nicht zu Templateparametern von %qD"
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "Destruktor %qD als Element-Template deklariert"
@@ -57981,64 +57974,64 @@ msgstr "der zerstörende %<operator delete%> muss eine übliche Deallozierungsfu
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> nimmt Typ %qT als ersten Parameter"
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr "%qT hat ein Feld %q#D, dessen Typ keine Bindung hat"
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT hat ein Feld %qD, dessen Typ vom Typ %qT abhängt, der wiederum keine Bindung hat"
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr "%qT hat ein Feld %q#D, dessen Typ keine Bindung hat"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr "%qT hat ein Feld %q#D, dessen Typ den anonymen Namensbereich verwendet"
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT mit bedeutenderer Sichtbarkeit als der Typ seines Feldes %qD deklariert"
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, gcc-internal-format
 msgid "%qT has a base %qT which has no linkage"
 msgstr "%qT hat eine Basis %qT, die keine Bindung hat"
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, gcc-internal-format
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr "%qT hat eine Basis %qT, die von Typ %qT abhängt, der wiederum keine Bindung hat"
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, gcc-internal-format
 msgid "%qT has a base %qT which has internal linkage"
 msgstr "%qT hat eine Basis %qT, die interne Bindung hat"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, gcc-internal-format
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr "%qT hat eine Basis %qT, die den anonymen Namensraum verwendet"
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT mit bedeutenderer Sichtbarkeit als seine Basis %qT deklariert"
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr "%q#D (durch einen unbenannten Typen deklariert) wird verwendet, aber nirgends definiert"
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but not defined"
 msgstr "%q#D (durch einen unbenannten Typen deklariert) wird verwendet, aber nirgends definiert"
@@ -58047,104 +58040,104 @@ msgstr "%q#D (durch einen unbenannten Typen deklariert) wird verwendet, aber nir
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "unbenannter Typ ohne Bindung wird verwendet, um Variable %q#D mit Bindung zu deklarieren"
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "unbenannter Typ ohne Bindung wird verwendet, um Funktion %q#D mit Bindung zu deklarieren"
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q#D verweist nicht auf den unqualifizierten Typen und wird daher nicht zum Binden verwendet"
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q#D (durch lokalen Typen %qT deklariert) wird verwendet, aber nirgends definiert"
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr "%q#D (durch lokalen Typen %qT deklariert) wird verwendet, aber nicht hier definiert"
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "Typ %qT ohne Bindung verwendet, um Variable %q#D mit Bindung zu deklarieren"
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "Typ %qT ohne Bindung für Funktionsdeklaration %q#D mit Bindung deklariert"
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "Mangeln von %q#D als %qE steht mit einer vorherigen Mangelung in Konflikt"
 
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "vorherige Mangelung von %q#D"
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, gcc-internal-format
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr "Eine spätere Option %<-fabi-version=%> (oder =0) verhindert diesen Fehler mit einer Änderung im Mangeln"
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr "das Programm sollte auch %qD definieren"
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "inline-Funktion %qD verwendet, aber nirgendwo definiert"
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q#D"
 msgstr "Standardargument fehlt für Parameter %P von %q#D"
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, gcc-internal-format
 msgid "...following parameter %P which has a default argument"
 msgstr "... folgt auf Parameter %P, der ein Defaultargument hat"
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, gcc-internal-format
 msgid "implicitly-declared %qD is deprecated"
 msgstr "implizit deklariertes %qD ist veraltet"
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr "da %qT vom Benutzer bereitgestelltes %qD hat"
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "Lambda, das %<...%> verwendendet, wird in Funktionszeiger umgewandelt"
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "gelöschte Funktion %qD wird verwendet"
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "Verwendung der Funktion %qD mit nicht erfüllten Einschränkungen"
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "Verwendung von eingebautem Parameterpack %qD außerhalb eines Templates"
@@ -58249,7 +58242,7 @@ msgstr "Referenz auf %<%T::%D%> ist mehrdeutig"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD ist kein Element von %qT; meinten Sie %qs?"
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD ist kein Element von %qT"
@@ -58259,7 +58252,7 @@ msgstr "%qD ist kein Element von %qT"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD ist kein Element von %qD; meinten Sie %qs?"
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD ist kein Element von %qD"
@@ -58284,47 +58277,47 @@ msgstr "Ausnahmebehandlung ausgeschaltet, %<-fexceptions%> schaltet sie ein"
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr "wirft NULL, was ganzzahlig, aber kein Zeigertyp ist"
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, gcc-internal-format
 msgid "  in thrown expression"
 msgstr "  in geworfenem Ausdruck"
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, gcc-internal-format
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr "%<catch%>-Parameter kann nicht als R-Wert-Referenztyp %qT deklariert werden"
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, gcc-internal-format
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr "Ausdruck vom Typ %qT kann nicht geworfen werden, da Typen mit variabler Größe beteiligt sind"
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, gcc-internal-format
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr "Exception vom Typ %qT kann nicht gefangen werden, da Typen mit variabler Größe beteiligt sind"
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, gcc-internal-format
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr "Ausnahme des Typs %qT wird bereits von einem früheren Exceptionhandler verarbeitet"
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, gcc-internal-format
 msgid "for type %qT"
 msgstr "für Typ %qT"
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, gcc-internal-format
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr "%<...%>-Behandler muss der letzte Behandler für seinen »try«-Block sein"
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr "noexcept-Ausdruck wird wegen Aufruf von %qD zu %<false%> ausgewertet"
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
 msgstr "aber %qD wirft nicht; vielleicht sollte sie als %<noexcept%> deklariert werden"
@@ -58591,12 +58584,12 @@ msgstr "Typ %qT ist keine direkte oder virtuelle Basis von %qT"
 msgid "type %qT is not a direct base of %qT"
 msgstr "Typ %qT ist keine direkte Basis von %qT"
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "Array muss mit Initialisierung mit umgebenden geschweiften Klammern initialisiert werden"
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT ist kein Klassentyp"
@@ -58611,12 +58604,12 @@ msgstr "unvollständiger Typ %qT hat kein Element %qD"
 msgid "invalid pointer to bit-field %qD"
 msgstr "ungültiger Zeiger auf Bitfeld %qD"
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "ungültige Verwendung der nicht-statischen Elementfunktion %qD"
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ungültige Verwendung des nicht-statischen Datenelementes %qD"
@@ -58811,52 +58804,52 @@ msgstr "Löschen des Objekts mit abstraktem Klassentyp %qT mit nicht-virtuellem
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "Löschen des Objekts mit polymorphem Klassentyp %qT mit nicht-virtuellem Destruktor bewirkt möglicherweise undefiniertes Verhalten"
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "Typ für Vektor-»delete« ist weder Zeiger- noch Arraytyp"
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr "Array mit Laufzeitgrenzen kann nicht durch Kopie eingefangen werden, sondern nur über eine Referenz"
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr "Einfangen des variabel geänderten Typs %qT, der kein N3639-Array mit Laufzeitgrenzen ist"
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr "da der Arrayelementtyp %qT variable Größe hat"
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "%qE kann nicht per Referenz aufgefangen werden"
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "Einfangen per Kopie von unvollständigem Typ %qT"
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr "Versuch, %qD in Instanziierung eines generischen Lambdas einzufangen"
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr "implizites Einfangen von %qE via %<[=]%> ist in C++20 veraltet"
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr "fangen Sie %<this%> oder %<*this%> explizit ein"
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> wurde für diese Lambda-Funktion nicht aufgefangen"
@@ -59230,225 +59223,270 @@ msgstr "unerwartete Angaben im ELF-Header"
 msgid "encapsulation is malformed"
 msgstr "Fehler im ELF-Header"
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, gcc-internal-format
 msgid "conflicting global module declaration %#qD"
 msgstr "widersprüchliche globale Moduldeklaration %#qD"
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, gcc-internal-format
 msgid "existing declaration %#qD"
 msgstr "bestehende Deklaration %#qD"
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, gcc-internal-format
 msgid "definition of %qD does not match"
 msgstr "Definition von %qD stimmt nicht überein"
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, gcc-internal-format
 msgid "existing definition %qD"
 msgstr "bestehende Definition %qD"
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, gcc-internal-format
 msgid "... this enumerator %qD"
 msgstr "... diesem Aufzählungswert %qD"
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, gcc-internal-format
 msgid "enumerator %qD does not match ..."
 msgstr "der Aufzählungswert %qD passt nicht zu ..."
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr "zusätzliche Aufzählungswerte, die mit %qD beginnen"
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr "Aufzählungsbereich unterscheidet sich"
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr "%q#D verweist auf eine Einheit %q#D mit interner Verlinkung"
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, gcc-internal-format
 msgid "recursive lazy load"
 msgstr "rekursives verzögertes Laden"
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr "ein Modul kann nicht in seinen eigenen Bereich importiert werden"
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, gcc-internal-format
 msgid "module %qs declared here"
 msgstr "das Modul %qs ist hier deklariert"
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, gcc-internal-format
 msgid "indirect import %qs is not already loaded"
 msgstr "der indirekte Import %qs ist noch nicht geladen"
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr "der Import %qs hat eine falsche CRC-Prüfsumme"
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr "weitere importierte Quellencodestellen können nicht dargestellt werden"
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr "%<#define %E%> wird nicht exportiert, da es ein Schlüsselwort ist"
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, gcc-internal-format
 msgid "macro definitions of %qE corrupted"
 msgstr "Makrodefinitionen von %qE sind kaputt"
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, gcc-internal-format
 msgid "inconsistent imported macro definition %qE"
 msgstr "inkonsistente importierte Makrodefinition %qE"
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr "%<#undef %E%>"
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr "%<#define %s%>"
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, gcc-internal-format
 msgid "compiled module file is %qs"
 msgstr "die compilierte Moduldatei ist %qs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=104552
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, gcc-internal-format, gfc-internal-format
 msgid "compiled module is %sversion %s"
 msgstr "das kompilierte Modul ist %sVersion %s"
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, gcc-internal-format, gfc-internal-format
 msgid "compiler is %sversion %s%s%s"
 msgstr "der Compiler ist %sVersion %s%s%s"
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, gcc-internal-format
 msgid "module %qs found"
 msgstr "Modul %qs gefunden"
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr "Headermodul erwartet, Modul %qs gefunden"
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr "Modul %qs erwartet, Headermodul gefunden"
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr "CRC-Fehler in Modul %qs"
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr "Ziel und Gastgeber sind %qs:%qs, erwartet werden jedoch %qs:%qs"
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr "Sprachdialekt ist %qs, erwartet wird jedoch %qs"
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, gcc-internal-format
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr "Modul enthält OpenMP, verwenden Sie %<-fopenmp%>, um es einzuschalten"
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, gcc-internal-format
 msgid "fixed tree mismatch"
 msgstr "reparierte Bäume sind unverträglich"
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, gcc-internal-format
 msgid "interface partition is not exported"
 msgstr "Schnittstellenpartition wird nicht exportiert"
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module cluster %u: %s"
 msgstr "Fehler beim Lesen des kompilierten Modul-Clusters %u: %s"
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module: %s"
 msgstr "Fehler beim Lesen des kompilierten Modus: %s"
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr "erwägen Sie die Verwendung von %<-fno-module-lazy%>, die Erhöhung des Wertes von %<-param-lazy-modules=%u%> oder die Erhöhung der prozessspezifischen Dateideskriptorgrenze"
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr "Importe müssen gebaut werden, bevor sie importiert werden können"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=104552#c26
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr "Zurück auf Los? (siehe https://gcc.gnu.org/bugzilla/show_bug.cgi?id=104552#c26)"
 
-#: cp/module.cc:19283
+#: cp/module.cc:19117
+#, gcc-internal-format
+msgid "declaration %qD conflicts with builtin"
+msgstr "Deklaration %qD widerspricht der eingebauten Deklaration"
+
+#: cp/module.cc:19122
+#, gcc-internal-format
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr "Neudeklaration von %qD in Modul %qs widerspricht dem Import"
+
+#: cp/module.cc:19125
+#, gcc-internal-format
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr "Neudeklaration von %qD in globalem Modul widerspricht dem Import"
+
+#: cp/module.cc:19130
+#, gcc-internal-format
+msgid "import declared attached to module %qs"
+msgstr "der hier deklarierte Import wird an das Modul %qs angehängt"
+
+#: cp/module.cc:19134
+#, gcc-internal-format
+msgid "import declared in global module"
+msgstr "in globalem Modul deklarierter Import"
+
+#: cp/module.cc:19140
+#, gcc-internal-format
+msgid "conflicting declaration of %qD in module %qs"
+msgstr "widersprüchliche Deklaration von %qD in Modul %qs"
+
+#: cp/module.cc:19143
+#, gcc-internal-format
+msgid "conflicting declaration of %qD in global module"
+msgstr "widersprüchliche Deklaration von %qD in globalem Modul"
+
+#: cp/module.cc:19148
+#, gcc-internal-format
+msgid "previously declared in module %qs"
+msgstr "vorher in Modul %qs deklariert"
+
+#: cp/module.cc:19152
+#, gcc-internal-format
+msgid "previously declared in global module"
+msgstr "vorher im globalen Modul deklariert"
+
+#: cp/module.cc:19404
 #, gcc-internal-format
 msgid "reading CMI %qs"
 msgstr "CMI %qs wird gelesen"
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E%>"
 msgstr "Fehler beim Laden der Bindung %<%E%s%E%>"
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr "Fehler beim Laden der Bindung %<%E%s%E@%s%>"
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr "beim Lesen der Bindung %<%E%s%E%>"
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr "beim Lesen der Bindung %<%E%s%E@%s%>"
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, gcc-internal-format
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr "Fehler beim Laden der ausstehenden Einheiten für %<%E%s%E%>"
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, gcc-internal-format
 msgid "during load of pendings for %<%E%s%E%>"
 msgstr "beim Laden der ausstehenden Einheiten für %<%E%s%E%>"
@@ -59460,392 +59498,392 @@ msgstr "beim Laden der ausstehenden Einheiten für %<%E%s%E%>"
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr "Import eines benannten Moduls %qs innerhalb eines Sprachverlinkungsblocks"
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, gcc-internal-format
 msgid "module already declared"
 msgstr "das Modul wurde bereits deklariert"
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, gcc-internal-format
 msgid "module already imported"
 msgstr "das Modul wurde bereits importiert"
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, gcc-internal-format
 msgid "module %qs imported here"
 msgstr "das Modul %qs wurde hier importiert"
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown Compiled Module Interface: %s"
 msgstr "unbekannte Schnittstelle des compilierten Moduls (CMI): %s"
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr "Fehler beim Bestimmen der %<#include%>-Übersetzung von %s: %s"
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr "%<include %s%> wurde übersetzt zu »import«"
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr "%<include %s%> wurde textuell verarbeitet"
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, gcc-internal-format
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr "C++-Module sind nicht kompatibel mit vorkompilierten Headern"
 
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, gcc-internal-format
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr "C++-Module sind nicht mit der traditionellen Vorverarbeitung kompatibel"
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr "Debug-Ausgabe von Makros kann bei Modulen unvollständig sein"
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr "Modulabhängigkeiten erfordern Vorverarbeitung"
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, gcc-internal-format
 msgid "you should use the %<-%s%> option"
 msgstr "Sie sollten die Option %<-%s%> verwenden"
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, gcc-internal-format
 msgid "invalid header name %qs"
 msgstr "ungültiger Headername %qs"
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, gcc-internal-format
 msgid "invalid module name %qs"
 msgstr "ungültiger Modulname %qs"
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr "%<-fmodule-only%> wird für Nicht-Schnittstelle verwendet"
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, gcc-internal-format
 msgid "writing CMI %qs"
 msgstr "CMI %qs wird geschrieben"
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, gcc-internal-format
 msgid "not writing module %qs due to errors"
 msgstr "Modul %qs kann aufgrund von Fehlern nicht geschrieben werden"
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to write compiled module: %s"
 msgstr "Fehler beim Schreiben des kompilierten Moduls: %s"
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, gcc-internal-format
 msgid "unknown header kind %qs"
 msgstr "unbekannte Header-Art %qs"
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, gcc-internal-format
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr "namensunabhängige Deklarationen sind erst ab %<-std=c++2c%> oder %<-std=gnu++2c%> verfügbar"
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "Neudeklaration von %q#D mit unterschiedlichen Templateparametern"
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D steht mit vorheriger Deklaration in Konflikt"
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D verdeckt Konstruktor für %q#D"
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "in Konflikt stehende Deklaration %q#D mit Bindung für die Sprache \"C\""
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "durch andere Ausnahmespezifikationen"
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "Lambdaparameter %qD war vorher als Einfänger deklariert"
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "Deklaration von %q#D überdeckt einen Parameter"
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "Deklaration von %qD überdeckt ein Element von %qT"
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "Friend-Deklaration %qD in lokaler Klasse ohne vorherige Deklaration"
 
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %<%s(%E)%> %p %d"
 
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d"
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, gcc-internal-format
 msgid "exporting %q#D that does not have external linkage"
 msgstr "%q#D wird exportiert, hat jedoch keine externe Bindung"
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, gcc-internal-format
 msgid "%q#D declared here with no linkage"
 msgstr "%q#D wird hier ohne Bindung deklariert"
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, gcc-internal-format
 msgid "%q#D declared here with internal linkage"
 msgstr "%q#D wird hier mit interner Bindung deklariert"
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, gcc-internal-format
 msgid "%q#D declared here with module linkage"
 msgstr "%q#D wird hier mit Modulbindung deklariert"
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T%s%D%> benennt Destruktor"
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "»using«-Deklaration für Nicht-Element im Gültigkeitsbereich der Klasse"
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<using%> mit Gültigkeitsbereich in enum-Typ %q#T ist erst ab %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qT ist weder eine Klasse, noch ein Namensbereich oder eine Aufzählung"
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "eine Using-Deklaration, die nicht-Member ist, benennt den Konstruktor von %qT"
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "%<using%>-Deklaration für Element außerhalb des Gültigkeitsbereichs der Klasse"
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, gcc-internal-format
 msgid "%qT is not a direct base of %qT"
 msgstr "%qT ist keine direkte Basis von %qT"
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr "meinten Sie %<using enum %T::%D%>?"
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "%qD wurde nicht innerhalb von %qD deklariert"
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "%<using%>-Deklaration darf den Namensraum %qD nicht benennen"
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> benennt Konstruktor in %qT"
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "Deklaration von %qD nicht in einem Namensbereich um %qD"
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "explizite Qualifizierung in Deklaration von %qD"
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD sollte innerhalb von %qD deklariert werden"
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD wurde nicht innerhalb von %qD deklariert"
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "sondern nur hier als %<friend%>"
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "Attribut %qD erfordert ein einzelnes NTBS-Argument"
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "Attribut %qD ist bedeutungslos, da die Elemente des anonymen Namensraums lokale Symbole erhalten"
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "Attribut %qD an unbenanntem Namensraum wird ignoriert"
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "Attribut %qD an nicht-»inline«-Namensraum wird ignoriert"
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "Attribut-Anweisung %qD wird ignoriert"
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "obere Grenze von %d Namensräumen für %qE durchsucht"
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "empfohlene Alternative:"
 msgstr[1] "empfohlene Alternativen:"
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr "%<std::%s%> ist im Header %qs definiert; um das zu beheben, könnten Sie %<#include %s%> hinzufügen"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79869
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<std::%s%> ist erst ab %s verfügbar"
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "das Makro %qs war noch nicht definiert"
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr "es wurde später hier definiert"
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "Deklaration von %<std::initializer_list%> entspricht nicht %<#include <initializer_list>%>, ist kein Template"
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "die Direktive %<strong%>-%<using%> wird nicht mehr unterstützt"
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr "Sie können stattdessen einen inline-Namensraum verwenden"
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, gcc-internal-format
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr "%<omp::%E%> darf in diesem Kontext nicht angegeben werden"
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "es können maximal %d Namensräume geschachtelt werden"
 
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%<namespace %E%> ist mehrdeutig"
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "Namensbereich-Alias %qD ist hier nicht erlaubt, %qD angenommen"
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "ein %<inline%>-Namensraum muss bei der ersten Definition angegeben werden"
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD hier definiert"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=99298
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%s-Namensraum %qD widerspricht der Erreichbarkeits-Definition"
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "Erreichbarkeitsdefinition %s ist hier"
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX %<pop_everything%> wird betreten"
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr "XXX %<pop_everything%> wird verlassen"
@@ -59870,7 +59908,7 @@ msgstr "Bezeichner %qE wird in C++20 zum Schlüsselwort"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr "%<LEXER_DEBUGGING_ENABLED_P%> ist nicht auf true gesetzt"
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> muss direkt von einer Funktionsdeklaration oder -definition gefolgt sein"
@@ -60116,7 +60154,7 @@ msgstr "%<constinit%> aus C++20 ist erst ab %<-std=c++20%> oder %<-std=gnu++20%>
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<concept%> ist erst ab %<-std=c++20%> oder mit %<-fconcepts%> verfügbar"
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<requires%> ist erst ab %<-std=c++20%> oder mit %<-fconcepts%> verfügbar"
@@ -60296,7 +60334,7 @@ msgstr "Anweisungs-Ausdrücke sind weder außerhalb von Funktionen noch in Templ
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "fold-expressions sind nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "übergeordneter Ausdruck erwartet"
@@ -60351,7 +60389,7 @@ msgstr "%<~auto%> ist nur mit %<-std=c++14%> oder %<-std=gnu++14%> verfügbar"
 msgid "template-id not allowed for destructor in C++20"
 msgstr "template-id für Destruktor ist in C++20 nicht erlaubt"
 
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, gcc-internal-format
 msgid "remove the %qs"
 msgstr "entfernen Sie %qs"
@@ -60371,7 +60409,7 @@ msgstr "typedef-Name %qD als Destruktor-Deklarator verwendet"
 msgid "expected unqualified-id"
 msgstr "unqualifizierte ID erwartet"
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD ist kein Template"
@@ -60421,7 +60459,7 @@ msgstr "Typen dürfen nicht in einem %<typeid%>-Ausdruck definiert werden"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "falsche Anzahl von Argumenten für %<__builtin_addressof%>"
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "falsche Anzahl von Argumenten für %<__builtin_launder%>"
@@ -60456,7 +60494,7 @@ msgstr "Typen dürfen nicht innerhalb von %<__builtin_classify_type%>-Aufrufen d
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr "in einem OpenMP-Arrayabschnitt können keine mehrdimensionalen Arrayindizes verwendet werden"
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "ungültige Verwendung von %qD"
@@ -60481,7 +60519,7 @@ msgstr "ISO-C++ erlaubt kein %<alignof%> mit einem Nicht-Typ"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "Typen dürfen nicht in %<noexcept%>-Ausdrücken definiert werden"
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "Typen dürfen nicht in einem %qs-Ausdruck definiert werden"
@@ -60631,8 +60669,8 @@ msgstr "nicht-leere Initialisierung »init-capture« eines Lambdas"
 msgid "capture of non-variable %qE"
 msgstr "Erfassung von Nicht-Variable %qE"
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D hier deklariert"
@@ -60672,7 +60710,7 @@ msgstr "Standardargument für Lambda-Parameter angegeben"
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "Parameterdeklaration vor Lambdadeklarationsangaben ist erst ab %<-std=c++2b%> oder %<-std=gnu++2b%> optional"
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr "ein Lambda mit Captures darf keinen expliziten Objektparameter eines nicht verwandten Typs haben"
@@ -60798,7 +60836,7 @@ msgstr "%<if consteval%> erfordert zusammengesetzte Anweisung"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "»init-statement in Auswahlanweisungen« ist nur mit %<-std=c++17%> oder %<-std=gnu++17%> verfügbar"
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "Auswahl-Anweisung erwartet"
@@ -60860,7 +60898,7 @@ msgstr "bereichsbasierter %<for%>-Ausdruck mit Typ %qT hat unvollständigen Typ"
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "unvereinbare Anfang-/Ende-Typen in bereichsbasierter %<for%>-Anweisung: %qT und %qT"
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "Iterationsanweisung erwartet"
@@ -60886,7 +60924,7 @@ msgstr "%<goto%> innerhalb einer %<constexpr%>-Funktion ist erst mit %<-std=c++2
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO-C++ verbietet berechnete Gotos"
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "Sprunganweisung erwartet"
@@ -61167,12 +61205,12 @@ msgstr "nur Konstruktoren nehmen Elementinitialisierungen"
 msgid "cannot expand initializer for member %qD"
 msgstr "Initialisierung für Element %qD kann nicht expandiert werden"
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "Speicherinitialisierung für %qD folgt Konstruktordelegation"
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "Konstruktordelegation folgt Speicherinitialisierung für %qD"
@@ -61813,7 +61851,7 @@ msgstr "fehlende Templateargumente nach %qE"
 msgid "%qT not permitted in template argument"
 msgstr "%qT ist in einem Templateargument nicht erlaubt"
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, gcc-internal-format
 msgid "invalid use of %qT"
@@ -61992,12 +62030,12 @@ msgstr "vorherige Definition von %q#T"
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, gcc-internal-format
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr "unexpandiertes Parameterpack in lokaler Klasse in Lambda"
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "Klassenschlüssel erwartet"
@@ -62200,37 +62238,37 @@ msgstr "attribute-using-prefix ist nur mit %<-std=c++17%> oder %<-std=gnu++17%>
 msgid "expression must be enclosed in parentheses"
 msgstr "Ausdruck muss in runden Klammern eingeschlossen sein"
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr "Fehlendes zusätzliches %<requries%>, um eine requires-expression zu beginnen"
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr "Prüfung, ob eine Konzept-ID ein gültiger Ausdruck ist; fügen Sie %<requires%> hinzu, um die Erfüllung zu prüfen"
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr "Rückgabetyp ist keine einfache Typ-Einschränkung"
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "%<return-type-requirement%> ist keine Typ-Einschränkung"
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "spezialisierendes Element %<%T::%E%> erfordert Syntax %<template<>%>"
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ungültige Deklaration von %<%T::%E%>"
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "zu wenige Templateparameterlisten"
@@ -62239,438 +62277,438 @@ msgstr "zu wenige Templateparameterlisten"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "zu viele Templateparameterlisten"
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, gcc-internal-format
 msgid "template-id not allowed for constructor in C++20"
 msgstr "template-id ist für Konstruktor in C++20 nicht erlaubt"
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "benannte Rückgabewerte werden nicht mehr unterstützt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=90185
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr "ISO C++ unterstützt keine Operatortemplates in Zeichenkettenliteralen, die eine Argumentpackung von Zeichen bekommen"
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "literales Operatortemplate %qD hat ungültige Parameterliste; nicht-Typ Templateargumentpack %<<char…>%> oder einzelner Nicht-Typ-Parameter von Klassentyp erwartet"
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "literales Operatortemplate %qD hat ungültige Parameterliste; Template für Nicht-Typ Argumentpack %<<char…>%> erwartet"
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr "Template-Einführungen sind nicht Teil der C++20-Konzepte; verwenden Sie %qs, um sie zu aktivieren"
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "kein passendes Konzept für template-introduction"
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "ungültige Deklaration eines Elementtemplates in lokaler Klasse"
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "Template mit C-Bindung"
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ungültige explizite Spezialisierung"
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "Templatedeklaration von %<typedef%>"
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "eine Klassen-Templatedeklaration darf nichts anderes deklarieren"
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "explizite Template-Spezialisierung kann keine Speicherklasse haben"
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> sollte innerhalb einer geschachtelten Templateargumentliste %<> >%> sein"
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "falsches %<>>%>; %<>%> verwenden, um eine Templateargumentliste zu beenden"
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, gcc-internal-format
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr "%qs sollte %qs sein, um eine Templateargumentliste zu beenden"
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "Argument von %<sizeof...%> muss mit Klammern umschlossen werden"
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ungültige Verwendung von %qD in Spezifizierung der Bindung"
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, gcc-internal-format
 msgid "duplicate %qD specifier"
 msgstr "doppelter %qD-Spezifizierer"
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, gcc-internal-format
 msgid "%qD specifier conflicts with %qs"
 msgstr "%qD-Spezifizierer ist unverträglich mit %qs"
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> vor %qD"
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, gcc-internal-format
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr "%qD-Spezifizierer ist unverträglich mit %<typedef%>"
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO-C++ 1998 unterstützt nicht %<long long%>"
 
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "sowohl %<__thread%> als auch %<thread_local%> angegeben"
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "doppeltes %qD"
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "doppeltes %qs"
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> erwartet"
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> erwartet"
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> erwartet"
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> erwartet"
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> erwartet"
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> erwartet"
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> erwartet"
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> erwartet"
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> erwartet"
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> erwartet"
 
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> erwartet"
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> erwartet"
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> erwartet"
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> erwartet"
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> erwartet"
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "%<auto%> erwartet"
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> erwartet"
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> erwartet"
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> erwartet"
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> erwartet"
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> erwartet"
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> erwartet"
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "%<co_yield%> erwartet"
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> erwartet"
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> erwartet"
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> erwartet"
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> erwartet"
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> oder %<::%> erwartet"
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> oder %<template%> erwartet"
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr "redundanter Aufzählungsschlüssel %<enum%s%> in Bezug auf %q#T"
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Markierung %qs bei Benennung von %q#T verwendet"
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T wurde vorher hier deklariert"
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "redundanter Klassenschlüssel %qs in Verweis auf %q#T"
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT mit nicht zusammenpassendem Klassenschlüssel %qs deklariert"
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr "entfernen Sie den Klassenschlüssel oder ersetzen Sie ihn durch %qs"
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "Klassenschlüssel durch %qs ersetzen"
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "%qT wurde hier als %qs definiert"
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "%qT wurde erstmals hier als %qs deklariert"
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD mit anderem Zugriff redeklariert"
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "in C++98 ist %<template%> (zum eindeutig machen) nur innerhalb von Templates erlaubt"
 
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "Datei endet in Standardargument"
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "unpassendes Objective-C++-Konstrukt %<@%D%>"
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "Objective-C++-Nachrichtenempfänger erwartet"
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "Objective-C++ Nachrichtenargument(e) erwartet"
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> muss als Argument einen Typen angeben"
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "Ungültiger Objective-C++-Selektorname"
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "Objective-C++ Methodendeklaration erwartet"
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "Methodenattribute müssen am Ende angegeben werden"
 
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "überflüssiges %qs zwischen Objective-C++ Methoden"
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "ungültiger Typ für Instanzvariable"
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "Bezeichner nach %<@protocol%> erwartet"
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "Attribute dürfen nicht vor dem Objective-C++-Schlüsselwort %<@%D%> angegeben werden"
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "Präfix-Attribute vor %<@%D%> werden ignoriert"
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ungültiger Typ für Eigenschaft"
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr "unbekanntes Eigenschaftsattribut %qE"
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "Liste von Ganzzahlausdrücken erwartet"
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%<wait%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr "%<scalar%>, %<aggregate%> oder %<all%> erwartet"
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ungültiger reduction-identifier"
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "Typen dürfen nicht in Iteratortyp definiert werden"
@@ -62679,12 +62717,12 @@ msgstr "Typen dürfen nicht in Iteratortyp definiert werden"
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "%<#pragma omp allocate%> wird nicht mehr unterstützt"
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "geklammerte Initialisierung ist in OpenMP-%<for%>-Schleife nicht erlaubt"
@@ -62694,133 +62732,133 @@ msgstr "geklammerte Initialisierung ist in OpenMP-%<for%>-Schleife nicht erlaubt
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "%<ordered%>-Klausel mit Parameter in %<for%>-Schleife über einen Bereich"
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "Schleifenvariable %qD sollte keine Reduktion sein"
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp declare %s%> gefolgt von %<#pragma omp declare %s%>"
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr "eine andere OpenMP-Direktive als %<declare simd%> oder %<declare variant%> gehört zu einer Deklaration"
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ungültige Initialisierungsklausel"
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "»id-expression (arguments)« erwartet"
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "eins der Aufrufargumente für die Initialisierung sollte %<omp_priv%> oder %<&omp_priv%> sein"
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "neue Typen dürfen nicht in einem Rückgabetyp definiert werden"
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "vordeklarierter arithmetischer Typ %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "Funktions- oder Arraytyp %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "Referenztyp %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "%<const%>-, %<volatile%>- oder %<__restrict%>-qualifizierter Typ %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> benennt eine Menge von Überladungen"
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD bezeichnet keine Funktion innerhalb eines Namensraum"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr "%<atomic_cancel%>"
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> ohne eingeschaltete Unterstützung für transaktionsgebundenen Speicher"
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> ohne eingeschaltete Unterstützung für transaktionsgebundenen Speicher"
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "äußeres %<__transaction_cancel%> nicht innerhalb des äußeren %<__transaction_atomic%>"
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  oder einer %<transaction_may_cancel_outer%>-Funktion"
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "falsch geformtes %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp requires%> darf nur im Gültigkeitsbereich einer Datei oder eines Namensraums verwendet werden"
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, gcc-internal-format
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp assumes%> darf nur im Gültigkeitsbereich einer Datei oder eines Namensraums verwendet werden"
 
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, gcc-internal-format
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr "%<#pragma GCC %s%> muss innerhalb einer Funktion sein"
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr "Compilieren von mehreren Quellen ist für C++ nicht implementiert"
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "Platzhaltertyp ist in diesem Kontext nicht erlaubt"
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "Implizite Templates dürfen nicht %<virtual%> sein"
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr "%<extern \"C\"%>-Bindung beginnt hier"
@@ -62850,7 +62888,7 @@ msgstr "einschließende Klassentemplates werden nicht explizit spezialisiert"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "Spezialisierung von %qD muss im Gültigkeitsbereich des Namensbereiches auftreten"
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "Spezialisierung von %qD in anderem Namensbereich"
@@ -62865,170 +62903,170 @@ msgstr "  aus Definition von %q#D"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "explizite Instanziierung von %qD in Namensbereich %qD (das nicht Namensbereich %qD einschließt)"
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "Name der Klasse verdeckt Template-Templateparameter %qD"
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "Spezialisierung des Alias-Template %qD"
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "explizite Spezialisierung des Nicht-Templates %qT"
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "Spezialisierung von %qT hinter Instanziierung"
 
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, gcc-internal-format
 msgid "from definition of %q#D"
 msgstr "aus der Definition von %q#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "Spezialisierung %qT hinter Instanziierung %qT"
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "Templatespezialisierung von %qD durch ISO C++ nicht erlaubt"
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "Spezialisierung von %qD nach Instanziierung"
 
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %#qD"
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD ist kein Funktionstemplate"
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD ist kein variadisches Template"
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "Template-ID %qD für %q+D passt zu keiner Templatedeklaration"
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "%d %<template<>%> gefunden, %d werden für Spezialisierung eines Elementfunktionstemplates benötigt"
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "mehrdeutige Templatespezialisierung %qD für %q+D"
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "variable Templates sind nur mit %<-std=c++14%> oder %<-std=gnu++14%> verfügbar"
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "zu viele Templateheader für %qD (sollten %d sein)"
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr "Elemente einer explizit spezialisierten Klasse sind ohne Templateheader definiert"
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "explizite Spezialisierung von %qD außerhalb seines Namensraums muss einen nested-name-specifier verwenden"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "explizite Instanziierung von %qD außerhalb seines Namensraums muss einen nested-name-specifier verwenden"
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "der expliziten Spezialisierung %q#D fehlen möglicherweise Attribute"
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "fehlende primäre Templateattribute %s"
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "fehlendes primäres Templateattribut %s"
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr "Template-ID %qE in Deklaration des ersten Templates"
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "Templateparameterliste in expliziter Instanziierung verwendet"
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "Definition für explizite Instanziierung angegeben"
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "zu viele Templateparameterlisten in Deklaration von %qD"
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "zu wenige Templateparameterlisten in Deklaration von %qD"
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "der expliziten Spezialisierung von %D muss %<template <>%> vorausgehen"
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "explizite Spezialisierung als %<concept%> deklariert"
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "Nichttyp-Teilspezialisierung %qE ist nicht erlaubt"
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "Teilspezialisierung %qE ist nur für Klassen und Variablen erlaubt"
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "Standardargument in expliziter Spezialisierung angegeben"
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD ist keine Templatefunktion"
@@ -63041,154 +63079,154 @@ msgstr "%qD ist keine Templatefunktion"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "Spezialisierung der implizit deklarierten speziellen Elementfunktion"
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "keine Elementfunktion %qD in %qT deklariert"
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "»friend«-Deklaration %qD ist für explizite Spezialisierung nicht sichtbar"
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, gcc-internal-format
 msgid "friend declaration here"
 msgstr "%<friend%>-Deklaration hier"
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "explizite Spezialisierung des Funktionskonzepts %qD"
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "Argument von %<__integer_pack%> muss zwischen 0 und %d liegen"
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "Expansion der Basisinitialisierung %qT enthält keine Parameterpacks"
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "Expansionsmuster %qT enthält keine Parameterpacks"
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "Expansionsmuster %qE enthält keine Parameterpacks"
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "Parameterbündel nicht mit %<...%> aufgelöst:"
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr "         %s"
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "Deklaration des Templateparameters %q+D überdeckt einen Templateparameter"
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "Deklaration von %q+#D überdeckt einen Templateparameter"
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "Templateparameter %qD hier deklariert"
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "Spezialisierung des Variablenkonzepts %q#D"
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "Templateparameter nicht in partieller Spezialisierung herleitbar:"
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "Teilspezialisierung %q+D spezialisiert keine Templateargumente; um das primäre Template zu definieren, entfernen Sie die Templateargumentliste"
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "Teilspezialisierung %q+D spezialisiert keine Templateargumente und ist nicht eingeschränkter als das primäre Template; um das primäre Template zu definieren, entfernen Sie die Templateargumentliste"
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "ursprüngliches Template hier"
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "partielle Spezialisierung ist nicht näher spezialisiert als das ursprüngliche Template, da es mehrere Parameter mit einer »pack«-Erweiterung ersetzt"
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "zu viele Argumente für teilweise Spezialisierung %qT"
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "Teilspezialisierung %qD ist nicht spezialisierter als"
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "primäres Template %qD"
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "Argument %qE für Parameterpack muss am Ende der Templateargumentliste sein"
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "Argument %qT für Parameterpack muss am Ende der Templateargumentliste sein"
 
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "Typ %qT des Templatearguments %qE hängt von Templateparameter ab"
 msgstr[1] "Typ %qT des Templatearguments %qE hängt von Templateparametern ab"
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "Deklaration von %qD macht vorherige Template-Instanziierung für %qD mehrdeutig"
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "teilweise Spezialisierung von %qD nach Instanziierung von %qD"
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "kein Standard-Argument für %qD"
@@ -63197,47 +63235,47 @@ msgstr "kein Standard-Argument für %qD"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "Parameterpack %q+D muss am Ende der Templateparameterliste sein"
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "Standardtemplateargumente dürfen in friend-Redeklaration eines Funktionstemplates nicht verwendet werden"
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "Standardtemplateargumente dürfen in friend-Deklaration nicht verwendet werden"
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "Standardtemplateargumente dürfen in Funktionstemplates nur mit %<-std=c++11%> und %<-std=gnu++11%> verwendet werden"
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "Standardtemplateargumente dürfen in teilweiser Spezialisierung nicht verwendet werden"
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "Standardargument für Template-Parameter für %qD umschließende Klasse"
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "Template %qD deklariert"
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "Templateklasse ohne Namen"
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "Element-Template %qD darf keine virt-Spezifizierer haben"
@@ -63247,506 +63285,506 @@ msgstr "Element-Template %qD darf keine virt-Spezifizierer haben"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "ungültige Templatedeklaration von %qD"
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "Template-Definition eines Nicht-Templates %q#D"
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "%d Ebenen von Template-Parametern für %q#D erwartet, %d erhalten"
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "%d Template-Parameter für %q#D erhalten"
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "%d Template-Parameter für %q#T erhalten"
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  aber %d benötigt"
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "Template-Argumente für %qD passen nicht zum ursprünglichen Template %qD"
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "verwenden Sie %<template<>%> für eine explizite Spezialisierung"
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, gcc-internal-format
 msgid "redeclaration of %qD with different constraints"
 msgstr "Redeklaration von %qD mit unterschiedlichen Einschränkungen"
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT ist kein Template-Typ"
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "keine Templatespezifizierer in Deklaration von %qD angegeben"
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "mit %d Template-Parameter redeklariert"
 msgstr[1] "mit %d Template-Parametern redeklariert"
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "vorherige Deklaration %qD verwendete %d Template-Parameter"
 msgstr[1] "vorherige Deklaration %qD verwendete %d Template-Parameter"
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "Template-Parameter %q+#D"
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "hier als %q#D redeklariert"
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, gcc-internal-format
 msgid "redeclared here"
 msgstr "hier erneut deklariert"
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "Deklaration von Templateparameter %q+#D mit unterschiedlichen Einschränkungen"
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "ursprüngliche Deklaration trat hier auf"
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, gcc-internal-format
 msgid "redeclaration of %q#D with different constraints"
 msgstr "Redeklaration von %q#D mit unterschiedlichen Einschränkungen"
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT"
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "es muss die Adresse einer Funktion mit externer Bindung sein"
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "es muss der Name einer Funktion mit externer Bindung sein"
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine Bindung hat"
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine externe Bindung hat"
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "es muss ein Zeiger auf ein Element der Form %<&X::Y%> sein"
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "da es ein Element von %qT ist"
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  Template-Parameter %qD konnte nicht hergeleitet werden"
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr " Typen %qT und %qT haben unverträgliche CV-Qualifizierer"
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr " unpassende Typen %qT und %qT"
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr " Templateparameter %qD ist kein Parameterpack wie Argument %qD"
 
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr " Templateargumente %qE passt nicht zum konstanten Zeiger auf Element %qE"
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr " %qE entspricht nicht %qE"
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr " unpassende Herleitung von Parameterpack mit %qT und %qT"
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr " hergeleitete Typen für Parameter %qT stehen in Konflikt (%qT und %qT)"
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr " hergeleitete Werte für Nicht-Typ-Parameter %qE stehen in Konflikt (%qE und %qE)"
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr " Arraytyp %qT mit veränderlicher Größe ist kein gültiges Templateargument"
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr " Typ %qT von Elementfunktion ist kein gültiges Templateargument"
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr " %qE (Typ %qT) kann nicht in den Typ %qT umgewandelt werden"
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr " %qT ist mehrdeutige Basisklasse von %qT"
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr " %qT ist nicht vom Typ %qT abgeleitet"
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr " Templateparameter eines Template-Templatearguments sind mit anderen hergeleiteten Templateargumenten unverträglich"
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  für %qT kann kein Template aus Nicht-Templatetyp %qT hergeleitet werden"
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr " Template-Argument %qE passt nicht zu %qE"
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr "%qE ist kein gültiges Templateargument vom Typ %qT, weil %qE weder eine Variable noch eine Funktion ist"
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE ist in C++98 kein gültiges Templateargument des Typs %qT, weil %qD keine externe Bindung hat"
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine Bindung hat"
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "die Adresse von %qD ist kein gültiges Templateargument"
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "die Adresse des %qT-Teilobjekts von %qD ist kein gültiges Templateargument"
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "die Adresse von %qD ist kein gültiges Templateargument, weil sie keine statische Lebensdauer hat"
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD ist kein gültiges Templateargument, weil %qD eine Variable und nicht die Adresse einer Variable ist"
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE ist kein gültiges Templateargument für %qT, da es keine Adresse einer Variable ist"
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, da Zeichenkettensymbole in diesem Zusammenhang nicht verwendet werden können"
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "in Templateargument für Typ %qT"
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "Templateargument %qE für Typ %qT ist keine Übersetzungszeit-Konstante"
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, da es in CV-Qualifikation in Konflikt steht"
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es kein L-Wert ist"
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D ist kein gültiges Templateargument für Typ %qT, weil eine Referenzvariable keine konstante Adresse hat"
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es ein Zeiger ist"
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "stattdessen %qE verwenden"
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es vom Typ %qT ist"
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "Attribute an Templateargument %qT werden ignoriert"
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "Attribute an Templateargument %qE werden ignoriert"
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "eingegebener Klassenname %qD als Template-Templateargument verwendet"
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ungültige Verwendung des Destruktors %qE als Typ"
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "um auf ein Typelement eines Templateparameters zu verweisen, %<typename %E%> verwenden"
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "Typ/Wert des Arguments %d passt nicht in Template-Parameterliste für %qD"
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  Konstante des Typs %qT erwartet, %qT erhalten"
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "  mehrdeutiges Templateargument für Nichttyp-Templateparameter wird wie ein Funktionstyp behandelt"
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  Klassentemplate erwartet, %qE erhalten"
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  einen Typ erwartet, %qE erhalten"
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  einen Typ erwartet, %qT erhalten"
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  Klassentemplate erwartet, %qT erhalten"
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  ein Template des Typs %qD erwartet, %qT erhalten"
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "unpassende Beschränkungen für Argument %d in Template-Parameterliste für %qD"
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  %qD erwartet, %qD erhalten"
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "Templateargument %qE konnte nicht von %qT in %qT umgewandelt werden"
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "Templateargument %d ist ungültig"
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "falsche Anzahl der Templateargumente (%d, sollte %d sein)"
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "falsche Anzahl der Templateargumente (%d, sollte mindestens %d sein)"
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "für %qD bereitgestellt"
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "gepacktes Expansionsargument für Parameter %qD ohne »pack« von Alias-Template %qD"
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "gepacktes Expansionsargument für Parameter %qD ohne »pack« von Konzept %qD"
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "jegliche Instanziierung mit nichtleerer Parameterpackung wäre unzulässig"
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D ist kein Funktionstemplate"
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "Nicht-Template-Typ %qT als Template verwendet"
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "Für Template-Deklaration %q+D"
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "Template-Einschränkung für %qD fehlgeschlagen"
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "Verwendung des ungültigen Variablentemplates %qE"
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "Instanziierungstiefe für Templates überschreitet Höchstwert %d (%<-ftemplate-depth=%> verwenden, um dies zu erhöhen)"
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "das Score-Argument muss ein konstanter ganzzahliger Ausdruck sein"
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "das Score-Argument darf nicht negativ sein"
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "Eigenschaft muss ein konstanter ganzzahliger Ausdruck oder ein Zeichenkettenliteral sein"
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "flexibles Arrayelement %qD in Union"
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "Falten einer leeren Expansion über %O"
 
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE ist nicht das vollständige Muster einer Packexpansion"
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "Argumentpacklängen passen nicht bei Expansion von %qT"
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "Argumentpacklängen passen nicht bei Expansion von %qE"
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "  bei Instanziierung des Standardarguments für Aufruf von %qD"
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "Erzeugung eines Zeigers auf Elementfunktion des Nicht-Klassentyps %qT"
 
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, gcc-internal-format, gfc-internal-format
 msgid "mismatched argument pack lengths (%d vs %d)"
 msgstr "Argumentpacklängen %d und %d sind unverträglich"
@@ -63764,301 +63802,301 @@ msgstr "Argumentpacklängen %d und %d sind unverträglich"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "Variable %qD hat Funktionstyp"
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ungültiger Parametertyp %qT"
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "in Deklaration %q+D"
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "Funktion gibt ein Array zurück"
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "Funktion gibt eine Funktion"
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "Referenz auf »void« wird gebildet"
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "Zeiger auf Referenztyp %qT wird geformt"
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "Referenz auf Referenztyp %qT wird geformt"
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "Zeiger auf qualifizierten Funktionstypen %qT wird geformt"
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "Referenz auf qualifizierten Funktionstypen %qT wird geformt"
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "Zeiger auf Element des Nicht-Klassentypen %qT wird erzeugt"
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "Zeiger auf Elementreferenztyp %qT wird erzeugt"
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "Zeiger auf Element mit Typ »void« wird erzeugt"
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "Array von %qT wird erzeugt"
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr "%qD wird für ein leeres Pack instanziiert"
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ist kein Klassen-, Struktur- oder Union-Typ"
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT wird in %qT aufgelöst, was kein Aufzählungstyp ist"
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT wird in %qT aufgelöst, aber das ist kein Klassentyp"
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "Verwendung von %qs in Template"
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "qualifizierender Typ %qT passt nicht zum Destruktornamen ~%qT"
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "Abhängigenname %qE wird als Nicht-Typ erkannt, aber die Instanziierung liefert einen Typ"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "%<typename %E%> sagen, wenn ein Typ gemeint ist"
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "Initialisierer für %q#D expandiert zu einer leeren Ausdrucksliste"
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "falsche Verwendung eines Packauflösungs-Ausdruckes"
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> verwenden, um Argumentpack aufzulösen"
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "leere Initialisierung in »init-capture« für Lambda"
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD wurde in diesem Gültigkeitsbereich nicht deklariert, und bei argumentabhängiger Suche am Ort der Instanziierung wurden keine Deklarationen gefunden"
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "Deklarationen in abhängiger Basis %qT wurden bei unqualifizierter Suche nicht gefunden"
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "stattdessen %<this->%D%> verwenden"
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "stattdessen %<%T::%D%> verwenden"
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD hier deklariert, später in der Übersetzungseinheit"
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "falsche Anzahl von Argumenten für %<__builtin_convertvector%>"
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, gcc-internal-format
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "Falsche Anzahl an Argumenten für das Attribut %<assume%> angegeben"
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT ist keine Klasse oder Namensbereich"
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ist keine Klasse oder Namensbereich"
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "ungültiges Feld %qD wird verwendet"
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT ist/verwendet anonymen Typen"
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "Templateargument für %qD verwendet lokalen Typ %qT"
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT ist ein variabel modifizierter Typ"
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "Ganzzahlausdruck %qE ist nicht konstant"
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  Versuch, %qD zu instanziieren"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "mehrdeutige Template-Instanziierung für %q#T"
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "mehrdeutige Template-Instanziierung für %q#D"
 
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "explizite Instanziierung des Nicht-Templates %q#D"
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "Explizite Instanziierung des Variablenkonzepts %q#D"
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "Explizite Instanziierung des Funktionskonzepts %q#D"
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD ist kein statisches Datenelement eines Klassentemplates"
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "kein passendes Template für %qD gefunden"
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "Typ %qT für explizite Instanziierung %qD passt nicht zum deklarierten Typ %qT"
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "explizite Instanziierung von %q#D"
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "doppelte explizite Instanziierung von %q#D"
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO-C++ 1998 verbietet die Verwendung von %<extern%> bei expliziten Instanziierungen"
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "Speicherklasse %qD auf Templateinstanziierung angewendet"
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "explizite Instanziierung des Nicht-Klassen-Templates %qD"
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "explizite Instanziierung des Nicht-Templatetyps %qT"
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "explizite Instanziierung von %q#T vor Definition des Templates"
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO-C++ verbietet die Verwendung von %qE bei expliziten Instanziierungen"
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "doppelte explizite Instanziierung von %q#T"
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "Ausnahmen-Angabe von %qD hängt von sich selbst ab"
@@ -64070,163 +64108,163 @@ msgstr "Ausnahmen-Angabe von %qD hängt von sich selbst ab"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "explizite Instanziierung von %qD, aber keine Definition verfügbar"
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "Instanziierungstiefe für Templates überschreitet Höchstwert %d beim Instanziieren von %q+D, möglicherweise wegen Generierung der virtuellen Tabelle (%<-ftemplate-depth=%> verwenden, um den Höchstwert zu erhöhen)"
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Nichttypen-Templateparameter von hergeleitetem Klassentyp sind erst ab %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%qT ist kein gültiger Typ für einen Nichttyp-Templateparameter, da er nicht strukturell ist"
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Nichttypen-Templateparameter von Klassentyp sind nur mit %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "ungültiger Nicht-Typ-Parameter für Template"
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T ist kein gültiger Typ für einen Nicht-Typ-Parameter eines Templates"
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "Schlüsselwort %<template%> nicht innerhalb der declarator-id erlaubt"
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "ein Konzept kann nicht eingeschränkt werden"
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "das Konzept %qE ist nicht im Gültigkeitsbereich des Namensraums"
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr "das Konzept %qE hat mehrere Vorlagenparameterlisten"
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "Ermittlung aus geschweift geklammerter Initialisierungsliste erfordert %<#include <initializer_list>%>"
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "nicht herleitbares Templates %qT wird ohne Template-Argumente verwendet"
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "Alias-Template-Herleitung ist erst ab %<-std=c++20%> oder %<-std=gnu++20%> verfügbar"
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr "verwenden Sie stattdessen %qD"
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "Templateargumente für die Kopierinitialisierung von %qT können nicht abgeleitet werden, da es keine expliziten Ableitungshinweise oder benutzerdeklarierten Konstruktoren gibt"
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "Templateargumente für %qT können nicht abgeleitet werden, da es keine Ableitungshinweise gibt"
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "Argumentherleitung für Klassentemplate gescheitert:"
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Explizite Herleitungshinweise werden nicht für »copy-initialization« berücksichtigt"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "Argumentherleitung für Klassentemplate von %qT fehlgeschlagen: expliziter Herleitungshinweis in copy-list-initialization ausgewählt"
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "der explizite Herleitungshinweis ist hier deklariert"
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "%qT beabsichtigt möglicherweise nicht, Argumentherleitung für Klassentemplates zu unterstützen"
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr "fügen Sie einen Herleitungshinweis hinzu, um diese Warnung zu unterdrücken"
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direct-list-initialization von %<auto%> erfordert genau ein Element"
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "um %<std::initializer_list%> herzuleiten, verwenden Sie einen copy-list-initialization (also mit %<=%> vor dem %<{%>)"
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Lambda-Rückgabewert von %qE kann nicht hergeleitet werden"
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "%qT kann nicht aus %qE hergeleitet werden"
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "Platzhalter-Beschränkungen nicht erfüllt"
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "hergeleiteter Initialisierer erfüllt die Platzhalter-Beschränkungen nicht"
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "hergeleiteter Rückgabetyp erfüllt die Platzhalter-Beschränkungen nicht"
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "hergeleiteter Ausdruckstyp erfüllt die Platzhalterbeschränkungen nicht"
 
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "ungültige Verwendung von %qT in Templateargument"
@@ -64432,630 +64470,630 @@ msgstr "Typ des %<asm%>-Operanden %qE konnte nicht ermittelt werden"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "%<__label__%>-Deklarationen sind nur im Funktionsgültigkeitsbereich erlaubt"
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "ungültige Verwendung des Elementes %qD in statischer Elementfunktion"
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, gcc-internal-format
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr "ungültige Verwendung des Elementes %qD in %<pre%>-Vertrag eines Konstruktors"
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, gcc-internal-format
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr "ungültige Verwendung des Elementes %qD in %<post%>-Vertrag eines Destruktors"
 
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr "fehlende Templateargumente für %qE"
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr "ein Anweisungsausdruck reicht nicht als Kontext für Überladungs-Auflösung nicht aus"
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr "ein Konzept kann nicht wie eine Funktion aufgerufen werden"
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "Argumente für Destruktor sind nicht erlaubt"
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, gcc-internal-format
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr "%<this%> ist für explizite Objektmemberfunktionen nicht verfügbar"
 
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, gcc-internal-format
 msgid "use explicit object parameter %qs instead"
 msgstr "verwenden Sie stattdessen den expliziten Objektparameter %qs"
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, gcc-internal-format
 msgid "name the explicit object parameter"
 msgstr "geben Sie dem expliziten Objektparameter einen Namen"
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> ist für statische Elementfunktionen nicht verfügbar"
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, gcc-internal-format
 msgid "invalid use of %<this%> before it is valid"
 msgstr "ungültige Verwendung von %<this%>, bevor es gültig ist"
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, gcc-internal-format
 msgid "invalid use of %<this%> after it is valid"
 msgstr "ungültige Verwendung von %<this%>, nachdem es gültig war"
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "ungültige Verwendung von %<this%> in Nicht-Element-Funktion"
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "ungültige Verwendung von %<this%> auf höchster Ebene"
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ungültiger angegebener Gültigkeitsbereich in Pseudodestruktor-Name"
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "qualifizierter Typ %qT passt nicht zum Destruktornamen ~%qT"
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE ist nicht vom Typ %qT"
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "zusammengesetztes Literal vom Nicht-Objekt-Typ %qT"
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, gcc-internal-format
 msgid "%<auto{x}%> cannot be constrained"
 msgstr "%<auto{x}%> kann nicht eingeschränkt werden"
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, gcc-internal-format
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<auto{x}%> ist erst mit %<-std=c++2b%> oder %<-std=gnu++2b%> verfügbar"
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "Templatetypparameter müssen das Schlüsselwort %<class%> oder %<typename%> verwenden"
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "ungültige Verwendung des Typs %qT als Standardwert für einen Template-Templateparameter"
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "ungültiges Standardargument für einen Template-Templateparameter"
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "Definition von %q#T in Templateparameterliste"
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "ungültige Definition des qualifizierten Typen %qT"
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "ungültige Spezifizierung der Basisklasse"
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "Element %qD von unbenannter Union kann nicht eingefangen werden"
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD ist nicht eingefangen"
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "das Lambda hat keinen »capture-default«"
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr "Lambda in lokaler Klasse %q+T kann Variablen aus dem umschließenden Kontext nicht einfangen"
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "Verwendung lokaler Variable mit automatischer Speicherklasse aus enthaltender Funktion"
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "Verwendung eines Parameters aus enthaltender Funktion"
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "Verwendung eines Parameters außerhalb des Funktionskörpers"
 
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr "fehlende Templateargumente"
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "Templateparameter %qD vom Typ %qT ist in ganzzahligem Konstantenausdruck nicht erlaubt, da er nicht Ganzzahl- oder Aufzählungstyp hat"
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "Verwendung des Klassentemplates %qT als Ausdruck"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "Abfrage des Elementes %qD ist im Gitter der Mehrfachvererbung mehrdeutig"
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD kann nicht in Konstanten-Ausdruck auftreten"
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "Typ von %qE ist unbekannt"
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT ist kein Aufzählungstyp"
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr "%<__type_pack_element%>-Index ist keine Ganzzahlkonstante"
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr "%<__type_pack_element%>-Index ist negativ"
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is out of range"
 msgstr "%<__type_pack_element%>-Index liegt außerhalb des Bereichs"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "Parameterpack %<__bases%> ist nur in Templatedeklaration gültig"
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "%<offsetof%> kann nicht auf Destruktor %<~%T%> angewandt werden"
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "%<offsetof%> kann nicht auf Elementfunktion %qD angewandt werden"
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "%<offsetof%> kann nicht auf Elementfunktion angewandt werden"
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "%<offsetof%> kann nicht auf Aufzähler %qD angewandt werden"
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr "%<offsetof%> innerhalb von Typ %qT (der kein Standardlayout hat) ist bedingt unterstützt"
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, gcc-internal-format
 msgid "pointer-to-member mapping %qE not supported"
 msgstr "Pointer-to-Member-Mapping %qE wird nicht unterstützt"
 
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "benutzerdefinierte Reduktionsauflösung ist mehrdeutig"
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "%qE in %<reduction%>-Klausel ist ein Array der Länge 0"
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE hat konstanten Typ für %<reduction%>"
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "benutzerdefinierte Reduktion mit Konstruktorinitialisierung für Basisklasse %qT"
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, gcc-internal-format
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr "Modifizierer außer %<val%> ist in %<linear%>-Klausel an %<simd%>- oder %<for%>-Konstrukten angegeben, zusammen mit OpenMP-5.2-Modifizierern"
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr "»linear«-Klausel mit Modifizierer %qs wird auf Nicht-Referenz-Variable mit Typ %qT angewandt"
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "»linear«-Klausel wird auf Variable vom Typ %qT angewandt, die weder ganzzahlig noch Zeiger ist"
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "Ausdruck für »linear«-Schrittweite muss ganzzahlig sein"
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> ist in OpenMP nur innerhalb von %<declare simd%>-Klauseln erlaubt"
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD ist in Klausel %qs keine Variable"
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD ist in Klausel %<firstprivate%> keine Variable"
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD ist in Klausel %<lastprivate%> keine Variable"
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "statischer %<gang%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "statischer %<gang%>-Ausdruck muss positiv sein"
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "Ausdruck für %<gang%>-Nummer muss ganzzahlig sein"
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "Ausdruck für %<vector%>-Länge muss ganzzahlig sein"
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "Ausdruck für %<worker%>-Nummer muss ganzzahlig sein"
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "Wert von %<gang%> muss positiv sein"
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "Wert der %<vector%>-Länge muss positiv sein"
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "Wert der %<worker%>-Nummer muss positiv sein"
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "Plan-Teilgrößenausdruck muss bestimmt sein"
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "Ausdruck für %qs-Länge muss ganzzahlig sein"
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "Ausdruck für %qs-Länge muss ganzzahlig, positiv und konstant sein"
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "%<device%>-ID muss ganzzahlig sein"
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "Ausdruck für %<dist_schedule%>-Chunkgröße muss ganzzahlig sein"
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD ist in %<aligned%>-Klausel keine Variable"
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE in %<aligned%>-Klausel ist weder Zeiger noch Array noch Referenz auf Zeiger oder Array"
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD tritt in %<aligned%>-Klausel mehrfach auf"
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "Ausdruck für Ausrichtung der %<aligned%>-Klausel muss ganzzahlig sein"
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD ist in %<nontemporal%>-Klausel keine Variable"
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD tritt in %<nontemporal%>-Klauseln mehrfach auf"
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%<this%> ist in %<allocate%>-Klausel nicht erlaubt"
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD ist in %<allocate%>-Klausel keine Variable"
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD kommt in %<allocate%>-Klausel mehrfach vor"
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr "%qD ist in %qs-Klausel weder lvalue-Ausdruck noch Arrayabschnitt"
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "Template %qE in Klausel %qs"
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "überladener Funktionsname %qE in Klausel %qs"
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "Ausdruck für %<grainsize%> muss ganzzahlig sein"
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "Ausdruck für %<priority%> muss ganzzahlig sein"
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "%<hint%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%<hint%>-Ausdruck muss ganzzahlig und konstant sein"
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, gcc-internal-format
 msgid "%<filter%> expression must be integral"
 msgstr "%<filter%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "Variable %qs ist weder Zeiger noch Referenz auf Zeiger"
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "Variable %qs ist weder Zeiger noch Array noch Referenz auf Zeiger oder Array"
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "Argument für %<tile%> erfordert ganzzahligen Typ"
 
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "%<const%>-qualifiziertes %qE ohne %<mutable%>-Element darf nur in %<shared%>- oder %<firstprivate%>-Klauseln vorkommen"
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD ist weder Datei-, Namens- noch Blockbereichsvariable"
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> Direktive %qE nicht in Definition von %qT"
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "Unterschied zwischen %qE und %qD hat keinen Ganzzahltyp"
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> zusammen mit Iterationsvariable %qE verwendet"
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> verwendet zwei unterschiedliche Ausdrücke für Speicher"
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr "%<static_assert%>-Meldung muss ein Stringliteral oder ein Objekt mit den Membern %<size%> und %<data%> sein"
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr "%<size()%> der %<static_assert%>-Nachricht muss implizit in %<std::size_t%> umwandelbar sein"
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr "%<data()%> der %<static_assert%>-Nachricht muss implizit in %<const char*%> umwandelbar sein"
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr "%<size()%> der %<static_assert%>-Meldung muss ein konstanter Ausdruck sein"
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr "%<size()%> der %<static_assert%>-Meldung ist %qE und damit zu groß"
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr "%<data()[%d]%> der %<static_assert%>-Meldung muss ein konstanter Ausdruck sein"
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr "%<data()%> der %<static_assert%>-Meldung muss ein Kernkonstantenausdruck sein"
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, gcc-internal-format
 msgid "static assertion failed: %.*s"
 msgstr "statische Assertion fehlgeschlagen: %.*s"
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "Nicht-konstante Bedingung für statische Behauptung"
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "Argument für %<decltype%> muss ein Ausdruck sein"
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%<decltype%> kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr "%<__builtin_is_pointer_interconvertible_with_class%> benötigt ein einziges Argument"
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr "Argument von %<__builtin_is_pointer_interconvertible_with_class%> muss ein Zeiger auf Member sein"
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr "%<__builtin_is_corresponding_member%> nicht wohldefiniert für anonyme Vereinigungen"
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr "%<__builtin_is_corresponding_member%> benötigt zwei Argumente"
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr "Argument von %<__builtin_is_corresponding_member%> muss ein Zeiger auf Member sein"
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "%qD ist weder ein Klassen- noch ein Alias-Template"
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "Operand des Faltungsausdrucks hat keine unexpandierten Parameterpackungen"
 
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "beide Argumente in binärer Faltung haben unexpandierte Parameterpackungen"
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "keine unexpandierten Parameterpackungen in binärer Faltung"
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "Argument, das kein Zeiger ist, in %<__builtin_launder%>"
@@ -65063,1159 +65101,1159 @@ msgstr "Argument, das kein Zeiger ist, in %<__builtin_launder%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr "Zieltyp %qT von %<__builtin_bit_cast%> ist ein Arraytyp"
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr "Zieltyp %qT von %<__builtin_bit_cast%> ist nicht trivial kopierbar"
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr "Quelltyp %qT von %<__builtin_bit_cast%> ist nicht trivial kopierbar"
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr "in %<__builtin_bit_cast%> ist die Quellgröße %qE ungleich der Zieltypgröße %qE"
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV-Qualifizierer können nicht auf %qT angewendet werden"
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "Anweisungs-Ausdruck in konstantem Ausdruck"
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr "%<-fabi-version=13%> (GCC 8.2) korrigiert die Aufrufkonvention für %qT, die in 8.1 versehentlich geändert wurde"
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr "%<-fabi-version=12%> (GCC 8.1) ändert versehentlich die Aufrufkonvention für %qT"
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, gcc-internal-format
 msgid " declared here"
 msgstr " hier deklariert"
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr "die Aufrufkonvention für %qT ändert sich mit %<-fabi-version=13%> (GCC 8.2)"
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr " da alle seine Kopier- und Verschiebekonstruktoren gelöscht sind"
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "Basisklasse %qT ist nicht %<public%>"
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, gcc-internal-format
 msgid "%qD is not public"
 msgstr "%qD ist nicht %<public%>"
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, gcc-internal-format
 msgid "%qD is mutable"
 msgstr "%qD ist veränderlich"
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr "%qD ist kein nicht-struktureller Typ"
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr "Attribut %qE kann nur auf Funktionen oder Parameter angewendet werden"
 
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr "Argument des Attributs %qE muss eine Zeichenkettenkonstante sein"
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "Attribut %qE kann nur auf Funktionen oder auf Klasse- oder Aufzählungstypen angewendet werden"
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "Attribut %qE kann nur auf nicht-statische Datenelemente angewendet werden"
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, gcc-internal-format
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "Attribut %qE kann nicht auf Bitfeld angewendet werden"
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "Attribut %qE erwartet keine Argumente"
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "Attribut %qE aus ISO C++ ist nicht auf Funktionen anwendbar; wird als %<[[gnu::%E]]%> behandelt"
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, gcc-internal-format
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "angeforderte %<init_priority%> muss ganzzahlig und konstant sein"
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "nur Attribut %qE kann für Definitionen von Objekten eines Klassentyps im Datei-Gültigkeitsbereich verwendet werden"
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "angeforderte %<init_priority%> %i liegt außerhalb des Bereichs [0, %i]"
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "angeforderte %<init_priority%> %i ist für interne Verwendung reserviert"
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "Redeklaration von %qD fügt ABI-Marke %qE hinzu"
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "Attribut %qE erfordert Argumente"
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "Argumente für Attribut %qE müssen enge Zeichenkettenliterale sein"
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "Argumente für Attribut %qE müssen gültige Bezeichner enthalten"
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%c%> ist kein gültiges Anfangszeichen für einen Bezeichner"
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%c%> ist kein gültiges Zeichen in einem Bezeichner"
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "Attribut %qE auf Nicht-Klassen-, Nicht-Enum-Typ %qT angewendet"
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "Attribut %qE auf %qT nach seiner Definition angewendet"
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "%qE-Attribut wird für Templateinstanziierung %qT ignoriert"
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "%qE-Attribut wird für Templatespezialisierung %qT ignoriert"
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE-Attribut wird auf %qD angewendet, das weder Funktion noch Variable ist"
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "Attribut %qE wird auf »extern \"C\"«-Deklaration %qD angewendet"
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, gcc-internal-format
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr "Argument %qE des Attributs muss ein Ausdruck sein, der zu true oder false auswertet"
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "Null als Nullzeigerkonstante"
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "%<lang_*%> check: failed in %s, at %s:%d"
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "Vergleich zwischen den unterschiedlichen Zeigertypen %qT und %qT benötigt Umwandlung"
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "Umwandlung zwischen den unterschiedlichen Zeigertypen %qT und %qT benötigt Umwandlung"
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "Bedingungsausdruck mit den unterschiedlichen Zeigertypen %qT und %qT benötigt Umwandlung"
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO-C++ verbietet Vergleich zwischen Zeiger des Typs %<void *%> und Zeiger auf Funktion"
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO-C++ verbietet Umwandlung zwischen Zeiger des Typs %<void *%> und Zeiger auf Funktion"
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO-C++ verbietet Bedingungsausdruck mit Zeiger des Typs %<void *%> und Zeiger auf Funktion"
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "beim Vergleich zwischen unterschiedlichen Zeiger-auf-Element-Typen %qT und %qT fehlt eine Typkonvertierung"
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "bei Umwandlung zwischen unterschiedlichen Zeiger-auf-Element-Typen %qT und %qT fehlt eine Typkonvertierung"
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "im Bedingungsausdruck mit unterschiedlichen Zeiger-auf-Element-Typen %qT und %qT fehlt eine Typkonvertierung"
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "kanonische Typen unterscheiden sich für identische Typen %qT und %qT"
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "selber kanonischer Typknoten für die unterschiedlichen Typen %qT und %qT"
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "ungültige Anwendung von %qs auf Elementfunktion"
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ungültige Anwendung von %<sizeof%> auf ein Bitfeld"
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO-C++ verbietet Anwendung von %<sizeof%> auf einen Ausdruck mit Funktionstyp"
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "ungültige Anwendung von %<__alignof%> auf ein Bitfeld"
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO-C++ verbietet Anwendung von %<__alignof%> auf einen Ausdruck mit Funktionstyp"
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "Argument für %<alignas%> hat nicht-ganzzahligen Typen %qT"
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "ungültige Verwendung der nicht-statischen Elementfunktion vom Typ %qT"
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ verbietet, eine Zeichenkettenkonstante in %qT zu konvertieren"
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "veraltete Konvertierung von Zeichenkettenkonstante in %qT"
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "Anforderung des Elements %qD in %qE, das vom Zeigertyp %qT ist (vielleicht war %<->%> gemeint?)"
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "Abfrage des Elementes %qD in %qE, das vom Nicht-Klassentyp %qT ist"
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "ungültige Verwendung des nicht-statischen Datenelements %qE"
 
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ungültiger Zugriff auf nicht-statisches Datenelement %qD in virtueller Basis des NULL-Objektes"
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "Objekttyp %qT passt nicht zum Destruktornamen ~%qT"
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "der zerstörte Typ ist %qT, aber der Destruktor verweist auf %qT"
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "auf Feld %q#D kann mittels %q#D zugegriffen werden"
 
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T hat kein Element namens %qE"
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%q#T hat kein Element namens %qE; meinten Sie %q#D? (zugreifbar über %q#D)"
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%q#T hat kein Element namens %qE; meinten Sie %q#D? (aus diesem Kontext nicht zugreifbar)"
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T hat kein Element namens %qE; meinten Sie %qE?"
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> ist kein Element von %qT"
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT ist keine Basis von %qT"
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD ist keine Elementtemplatefunktion"
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT ist kein Zeiger auf Objekt"
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "ungültige Verwendung von Arrayindizierung bei Zeiger auf Element"
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "ungültige Verwendung des unären %<*%> bei Zeiger auf Element"
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "ungültige Verwendung impliziter Umwandlung bei Zeiger auf Element"
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr "linker Operand von %<->*%> muss Zeiger auf Klasse sein, ist aber ein Zeiger auf Element des Typs %qT"
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "Index fehlt in Arrayreferenz"
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "Indizierung eines als %<register%> deklarierten Arrays"
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indizierter Wert ist weder ein Array noch ein Zeiger"
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "bei Verwendung von %qE fehlt Objekt"
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO-C++ verbietet den Aufruf von %<::main%> vom Programm aus"
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "%<.*%> oder %<->*%> muss verwendet werden, um Zeiger auf Element als Funktion in %<%E (...)%> aufzurufen, z.B. %<(... ->* %E) (...)%>"
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE kann nicht als Funktion verwendet werden"
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD kann nicht als Funktion verwendet werden"
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "Ausdruck kann nicht als Funktion verwendet werden"
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "zu viele Argumente für Konstruktor %q#D"
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "zu wenige Argumente für Konstruktor %q#D"
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "zu viele Argumente für Elementfunktion %q#D"
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "Zu wenige Argumente für Elementfunktion %q#D"
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "zu viele Argumente für Funktion %q#D"
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "zu wenige Argumente für Funktion %q#D"
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "zu viele Argumente für Methode %q#D"
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "zu wenige Argumente für Methode %q#D"
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "zu viele Argumente für Funktion"
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "zu wenige Argumente für Funktion"
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "Parameter %P von %qD hat unvollständigen Typen %qT"
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "Parameter %P hat unvollständigen Typen %qT"
 
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, gcc-internal-format
 msgid "the address %qE will never be NULL"
 msgstr "die Adresse %qE ist niemals NULL"
 
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "die Adresse von %qD ist niemals NULL"
 
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr "der Compiler kann annehmen, dass die Adresse von %qE niemals NULL ist"
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr "Vergleich des Ergebnisses der Zeigeraddition %qE mit NULL"
 
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "der Compiler kann annehmen, dass die Adresse von %qD niemals NULL ist"
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr "bitweise Operation zwischen den unterschiedlichen Aufzählungstypen %qT und %qT"
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "bitweise Operation zwischen den unterschiedlichen Aufzählungstypen %qT und %qT ist veraltet"
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr "Arithmetik zwischen den unterschiedlichen Aufzählungstypen %qT und %qT"
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "Arithmetik zwischen den unterschiedlichen Aufzählungstypen %qT und %qT ist veraltet"
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr "Vergleich zwischen Aufzählungstyp %qT und Gleitkommatyp %qT"
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr "Vergleich zwischen Gleitkommatyp %qT und Aufzählungstyp %qT"
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr "Vergleich zwischen Aufzählungstyp %qT und Gleitkommatyp %qT ist veraltet"
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "Vergleich zwischen Gleitkommatyp %qT und Aufzählungstyp %qT ist veraltet"
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr "Arithmetik zwischen Aufzählungstyp %qT und Gleitkommatyp %qT"
 
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr "Arithmetik zwischen Gleitkommatyp %qT und Aufzählungstyp %qT"
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "Arithmetik zwischen Aufzählungstyp %qT und Gleitkommatyp %qT ist veraltet"
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "Arithmetik zwischen Gleitkommatyp %qT und Aufzählungstyp %qT ist veraltet"
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "Umwandlung in Typ %qT von überladener Funktion wird angenommen"
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL in Arithmetik verwendet"
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO-C++ verbietet Vergleich zwischen Zeiger und Ganzzahl"
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "Operandentypen sind %qT und %qT"
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr "Drei-Wege-Vergleich von Vektoren"
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "geordneter Vergleich von Zeiger mit der Zahl 0 (%qT und %qT)"
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr "ungeordneter Vergleich mit Nicht-Gleitkomma-Argument"
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "implizite Umwandlung von %qH in %qI zur Anpassung an anderen Operanden des Binärausdrucks"
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ungültige Operanden der Typen %qT und %qT für binäres %qO"
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO-C++ verbietet die Verwendung eines Zeigers des Typs %<void *%> in Subtraktion"
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO-C++ verbietet die Verwendung eines Zeigers auf eine Funktion in Subtraktion"
 
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO-C++ verbietet die Verwendung eines Zeigers auf Methode in Subtraktion"
 
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ungültige Verwendung eines Zeigers auf einen unvollständigen Typen in Zeigerarithmetik"
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "Adresse des Konstruktors %qD wird genommen"
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "Adresse des Destruktors %qD wird genommen"
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ungültige Verwendung von %qE um Zeiger auf Elementfunktion zu erzeugen"
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  eine qualifizierte ID ist erforderlich"
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "Klammern um %qE können nicht verwendet werden, einen Zeiger auf Elementfunktion zu erzeugen"
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO-C++ verbietet das Ermitteln der Adresse einer nicht qualifizierten oder geklammerten nicht-statischen Elementfunktion, um einen Zeiger auf Elementfunktion zu erzeugen. Stattdessen %<&%T::%D%> verwenden"
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr "ISO-C++ verbietet das Ermitteln der Adresse einer nicht qualifizierten oder geklammerten nicht-statischen Memberfunktion, um einen Zeiger auf eine explizite Memberfunktion zu erzeugen"
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO-C++ verbietet das Ermitteln der Adresse einer gebundenen Elementfunktion, um einen Zeiger auf Elementfunktion zu erzeugen. Stattdessen %<&%T::%D%> verwenden"
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr "ISO-C++ verbietet es, die Adresse einer gebundenen Memberfunktion zu nehmen, um einen Zeiger auf eine explizite Objekt-Memberfunktion zu bilden"
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, gcc-internal-format
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr "ein Zeiger auf eine explizite Objektelementfunktion kann nur mit %<&%T::%D%> erzeugt werden"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "Adresse eines Rvalues wird ermittelt"
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO-C++ verbietet das Ermitteln der Adresse der Funktion %<::main%>"
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "Zeiger auf Referenzelement %qD kann nicht erzeugt werden"
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "Versuch, die Adresse eines Bitfelds zu bestimmen"
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<~%> auf einem Ausdruck vom Typ %<bool%>"
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "meinten Sie ein logisches Nicht (%<!%>)?"
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO-C++ verbietet erhöhen einer Aufzählung"
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO-C++ verbietet verringern einer Aufzählung"
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "Zeiger auf unvollständigen Typen %qT kann nicht erhöht werden"
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "Zeiger auf unvollständigen Typen %qT kann nicht verringert werden"
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO-C++ verbietet Erhöhen eines Zeigers vom Typ %qT"
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO-C++ verbietet Verringern eines Zeigers vom Typ %qT"
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr "%qs-Ausdruck von %<volatile%>-qualifiziertem Typ ist veraltet"
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr "Verwendung eines Operanden vom Typ %qT in %<operator--%> ist verboten"
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr "Verwendung eines Operanden vom Typ %qT in %<operator++%> ist in C++17 verboten"
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr "Verwendung eines Operanden vom Typ %qT in %<operator++%> ist veraltet"
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "Adresse von %<this%> kann nicht ermittelt werden, das ein R-Wert-Ausdruck ist"
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "Adresse der Register-Variablen %qD angefordert"
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "Adresse für %qD angefordert, was als %<register%> deklariert ist"
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "Listeninitialisierung für Nicht-Klassentyp darf nicht geklammert sein"
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "Ausdrucksliste als zusammengesetzten Ausdruck in Initialisierung behandelt"
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "Ausdrucksliste als zusammengesetzten Ausdruck in Speicherinitialisierung behandelt"
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "Ausdrucksliste als zusammengesetzten Ausdruck in funktionaler Umwandlung behandelt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=80191
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "Ausdrucksliste für »%s« wird als zusammengesetzten Ausdruck behandelt"
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "kein Kontext, um Typ von %qE aufzulösen"
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "Umwandlung des Typs %qT in Typ %qT entfernt Qualifizierer"
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%<static_cast%> von Typ %qT in Typ %qT entfernt Qualifizierer"
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%<reinterpret_cast%> von Typ %qT in Typ %qT entfernt Qualifizierer"
 
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "nutzlose Umwandlung in Typ %q#T"
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "Typkennzeichner an Umwandlungs-Rückgabetyp ignoriert"
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "ungültiges %<static_cast%> von Typ %qT in Typ %qT"
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "Klassentyp %qT ist unvollständig"
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 msgid "converting from %qH to %qI"
 msgstr "Umwandlung von %qH nach %qI"
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, gcc-internal-format
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "ungültige Typumwandlung eines prvalue-Ausdrucks des Typs %qT in Typ %qT"
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 msgid "cast from %qH to %qI loses precision"
 msgstr "Typumwandlung von %qH nach %qI verliert Genauigkeit"
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr "Umwandlung zwischen inkompatiblen Funktionstypen von %qH nach %qI"
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "Umwandlung zwischen inkompatiblen Elementzeigertypen von %qH nach %qI"
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "Umwandlung von %qH in %qI erhöht erforderliche Ausrichtung des Zieltyps"
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "Umwandlung zwischen Zeiger auf Funktion und Zeiger auf Objekt ist bedingt unterstützt"
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ungültige Umwandlung von Typ %qT in Typ %qT"
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ungültige Verwendung von %<const_cast%> mit Typ %qT, der weder Zeiger, Referenz, noch Zeiger auf ein Datenelement ist"
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "ungültige Verwendung von %<const_cast%> mit Typ %qT, der ein Zeiger oder Referenz auf Funktionstyp ist"
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "ungültiges %<const_cast%> eines R-Wertes des Typs %qT in Typ %qT"
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "ungültiges %<const_cast%> von Typ %qT in Typ %qT"
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO-C++ verbietet Umwandlung in Arraytyp %qT"
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "ungültige Umwandlung in Funktionstyp %qT"
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, gcc-internal-format
 msgid "moving %qE of type %qT to itself"
 msgstr "%qE vom Typ %qT wird auf sich selbst verschoben"
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr "entfernen Sie den Aufruf von %<std::move%>"
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  in Auswertung von %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "Zuweisung an Array von Initialisierungsliste"
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "unverträgliche Typen in Zuweisung von %qT an %qT"
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "Array als Initialisierung verwendet"
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "Ungültige Arrayzuweisung"
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   in Umwandlung in Zeiger auf Elementfunktion"
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "Umwandlung in Zeiger auf Element über virtuelle Basis %qT"
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   in Umwandlung in Zeiger auf Element"
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ungültige Umwandlung in Typ %qT von Typ %qT"
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "%qH kann nicht nach %qI im Standardargument umgewandelt werden"
 
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "%qH kann nicht nach %qI bei Argumentübergabe umgewandelt werden"
 
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "%qH kann nicht nach %qI in Initialisierung umgewandelt werden"
 
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 msgid "cannot convert %qH to %qI in return"
 msgstr "%qH kann nicht nach %qI in Rückgabe umgewandelt werden"
 
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "%qH kann nicht nach %qI in Zuweisung umgewandelt werden"
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "Parameter %qP von %qD könnte Kandidat für Formatattribut sein"
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "Parameter könnte ein Kandidat für ein Formatattribut sein"
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "Ziel der Umwandlung könnte Kandidat ein für ein Formatattribut sein"
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "Ziel der Initialisierung könnte ein Kandidat für Formatattribut sein"
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "linke Seite der Zuweisung könnte ein Kandidat für ein Formatattribut sein"
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "bei Übergabe des Arguments %P von %qD"
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "Referenz auf temporären Wert wird zurückgegeben"
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, gcc-internal-format
 msgid "returning pointer to temporary"
 msgstr "Zeiger auf temporäre Variable wird zurückgegeben"
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "das Zurückgeben einer temporären %<initializer_list%> verlängert nicht die Lebenszeit des zugrundeliegenden Arrays"
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "Referenz auf lokale Variable %qD zurückgegeben"
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr "das Zurückgeben der lokalen %<initializer_list%>-Variable %qD verlängert nicht die Lebenszeit des zugrundeliegenden Arrays"
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "Adresse der lokalen Variable %qD zurückgegeben"
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "Adresse der lokalen Variable %qD zurückgegeben"
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr "das Verschieben eines temporären Objekts verhindert das Einsparen der Kopie"
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr "das Verschieben eines lokalen Objekts in einer return-Anweisung verhindert das Einsparen der Kopie"
 
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "redundantes Verschieben in Rückgabeanweisung"
 
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, gcc-internal-format
 msgid "redundant move in initialization"
 msgstr "redundantes Verschieben in Initialisierung"
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "Wert von Destruktor zurückgegeben"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "vom Behandler eines Funktions-try-Blocks eines Konstruktors kann nicht zurückgekehrt werden"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "Rückgabe eines Wertes von einem Konstruktor"
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "Return-Anweisung ohne Wert, in %qT zurückgebender Funktion"
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "Initialisierungsliste wird zurückgegeben"
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "widersprüchliche Typen %qT und %qT für Lambda-Rückgabetypen hergeleitet"
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "widersprüchliche Herleitung für automatischen Rückgabetyp: %qT und dann %qT"
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "Return-Anweisung mit Wert, in Funktion mit Rückgabetyp %qT"
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> darf nicht NULL zurückgeben, außer er ist mit %<throw%> deklariert (oder %<-fcheck-new%> ist eingeschaltet)"
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, gcc-internal-format
 msgid "not eliding copy on return from %qD"
 msgstr "bei der Rückkehr von %qD wird das Kopieren nicht eingespart"
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr "bei der Rückkehr in %qD wird das Kopieren nicht eingespart"
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "Rvalue wird als Lvalue verwendet"
@@ -66436,155 +66474,155 @@ msgstr "überladene Funktion ohne Typinformationen aus Kontext"
 msgid "insufficient contextual information to determine type"
 msgstr "unzureichende Informationen für Typbestimmung aus Kontext"
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "Konstruktorsyntax verwendet, aber kein Konstruktor für Typ %qT deklariert"
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "%<constinit%>-Variable %qD muss eine konstante Initialisierung haben"
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "verengende Umwandlung von %qE von %qH nach %qI ist in C++11 ungültig"
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "verengende Umwandlung von %qE von %qH nach %qI"
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr " der Ausdruck hat einen konstanten Wert, ist aber kein konstanter Ausdruck im Sinne von C++"
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, gcc-internal-format
 msgid "initializer-string for %qT is too long"
 msgstr "Initialisierungs-Zeichenkette für %qT ist zu lang"
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr "das Initialisieren einer Basisklasse vom Typ %qT führt zu Objektslicing"
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, gcc-internal-format
 msgid "remove %<{ }%> around initializer"
 msgstr "entfernen Sie die %<{ }%> um den Initialisierer"
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "Aggregat des Typs %qT kann nicht mit zusammengesetztem Literal initialisiert werden"
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "Initialisierung für Element %qD fehlt"
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "Element %qD ist nicht initialisierte Referenz"
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "Element %qD mit nicht initialisierten Feldern"
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "Designator-Reihenfolge für Feld %qD passt nicht zur ursprünglichen Deklaration in %qT"
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "kein Feld %qD in initialisierter Union gefunden"
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "Indexwert statt Feldname in Union-Initialisierung"
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "ringförmige Zeigerdelegation erkannt"
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "Basisoperand von %<->%> hat Nicht-Zeiger-Typ %qT"
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "Ergebnis von %<operator->()%> ergibt Nicht-Zeiger-Ergebnis"
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "Basisoperand von %<->%> ist kein Zeiger"
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE kann nicht als Elementzeiger verwendet werden, da es vom Typ %qT ist"
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "Elementzeiger %qE kann nicht auf %qE angewandt werden, da letzteres vom Nicht-Klassen-Typ %qT ist"
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "Zeiger auf Elementtyp %qT mit Objekttyp %qT inkompatibel"
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "Typ für Zeiger auf Elementfunktion %qT braucht einen rvalue"
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "Typ für Zeiger auf Elementfunktion %qT braucht einen lvalue"
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "Zeiger-auf-Element-Funktions-Typ %qT braucht vor C++20 einen lvalue"
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "funktionale Umwandlung in Arraytyp %qT"
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "%<auto(x)%> kann nicht eingeschränkt werden"
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<auto{x}%> ist erst mit %<-std=c++2b%> oder %<-std=gnu++2b%> verfügbar"
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "ungültige Wert-Initialisierung von Referenztyp"
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "Aufruf der Funktion %qD, die unvollständigen Typen %q#T wirft"
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "Aufruf einer Funktion, die unvollständigen Typen %q#T wirft"
@@ -67582,7 +67620,7 @@ msgstr "Die BOZ-Literalkonstante bei %L darf kein tatsächliches Argument für %
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "Argumente von %qs bei %L und %L können nicht beide literale BOZ-Konstanten sein"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "Ungültige Verwendung der BOZ-Literalkonstante bei %L"
@@ -68907,7 +68945,7 @@ msgstr "Falsche INTENT-Spezifikation bei %C"
 msgid "deferred type parameter at %C"
 msgstr "Parameter mit zurückgestelltem Typ bei %C"
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Skalarer INTEGER-Ausdruck bei %L erwartet"
@@ -69122,7 +69160,7 @@ msgstr "Komponente %qs mit CLASS bei %C muss allozierbar oder Zeiger sein"
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Feldkomponente der Struktur bei %C muss explizite oder aufgeschobene Form haben"
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "Komponente %qs bei %C bereits bei %L deklariert"
@@ -69925,7 +69963,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr "Formale Argumentliste in Funktionsdefinition bei %C erwartet"
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "BIND(C)-Attribut bei %L kann nur für Variablen oder gemeinsame Blöcke verwendet werden"
@@ -70735,12 +70773,12 @@ msgstr "identical_array_ref(): inconsistent dimensions"
 msgid "are_identical_variables: Bad type"
 msgstr "are_identical_variables: Bad type"
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr "Effektives Argument von INTENT(%s) bei %L könnte effektives Argument bei %L stören."
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr "Interner Fehler: gfc_check_dependency: expecting an EXPR_VARIABLE"
@@ -71003,274 +71041,274 @@ msgstr "Parameter %qs bei %L wurde nicht deklariert oder ist eine Variable, die
 msgid "check_init_expr(): Unknown expression type"
 msgstr "check_init_expr(): Unknown expression type"
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr "Spezifikationsfunktion %qs bei %L kann keine Anweisungsfunktion sein"
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr "Spezifikationsfunktion %qs bei %L kann keine interne Funktion sein"
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, gcc-internal-format
 msgid "Specification function %qs at %L must be PURE"
 msgstr "Spezifikationsfunktion %qs bei %L muss PURE sein"
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr "Spezifikationsfunktion %qs bei %L kann nicht RECURSIVE sein"
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, gcc-internal-format
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr "Scheinargument %qs ist im Ausdruck bei %L nicht erlaubt"
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr "Scheinargument %qs bei %L kann nicht OPTIONAL sein"
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr "Scheinargument %qs bei %L kann nicht INTENT(OUT) sein"
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr "Variable %qs kann nicht im Ausdruck bei %L auftreten"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, gcc-internal-format
 msgid "check_restricted(): Unknown expression type"
 msgstr "check_restricted(): Unknown expression type"
 
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr "Ausdruck bei %L muss INTEGER-Typ haben, %s gefunden"
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, gcc-internal-format
 msgid "Function %qs at %L must be PURE"
 msgstr "Funktion %qs bei %L muss PURE sein"
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr "Ausdruck bei %L muss skalar sein"
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr "Interner Fehler: optype_msgid overflow: %d"
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr "Unverträgliche Ränge in %s (%d und %d) bei %L"
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "Andere Form für %s bei %L für Dimension %d (%d und %d)"
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr "Die Zuweisung zu einer KIND- oder LEN-part_ref bei %L ist nicht erlaubt"
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr "%qs bei %L ist kein VALUE"
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal assignment to external procedure at %L"
 msgstr "Unzulässige Zuweisung an externe Prozedur bei %L"
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "Unverträgliche Ränge %d und %d in Zuweisung bei %L"
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "Unbekannter Variablentyp in Zuweisung bei %L"
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "Auf rechter Seite in Zuweisung bei %L tritt NULL auf"
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "POINTER-wertige Funktion tritt auf rechter Seite der Zuweisung bei %L auf"
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr "BOZ-Literalkonstante in der Nähe von %L kann nicht einer %qs-Variablen zugewiesen werden"
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr "Die Zuweisung zu einer KIND- oder LEN-Komponente eines parametrisierten Typs bei %L ist nicht erlaubt"
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Unverträgliche Typen in DATA-Anweisung bei %L; versuchte Umwandlung von %s an %s"
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "Zeiger-Zuweisungsziel ist kein POINTER bei %L"
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "%qs in Zeigerzuweisung bei %L kann kein L-Wert sein, da es eine Prozedur ist"
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Grenzen für %qs bei %L erwartet"
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Grenzenangabe für %qs in Zeigerzuweisung bei %L"
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "Bei %L darf kein Schritt vorhanden sein"
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr "Das Umordnen des Rangs erfordert eine Liste von %<untere-Grenze : obere-Grenze%>-Angaben bei %L"
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr "Liste von %<untere-Grenze :%> oder Liste von %<untere-Grenze : obere-Grenze%>-Angaben bei %L erwartet"
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "Zeigerobjekt bei %L darf keinen Koindex haben"
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Ungültige Zuweisung eines Prozedurzeigers bei %L"
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Funktionsergebnis %qs ist als Prozedurziel in Zuweisung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Abstrakte Schnittstelle %qs ist in Zuweisung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Anweisungsfunktion %qs ist in Zuweisung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Interne Prozedur %qs ist in Zuweisung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Eingebautes %qs bei %L ist in Zuweisung des Prozedurzeigers ungültig"
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Nichtintrinsische elementare Prozedur %qs ist in Zuweisung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "Unpassende Zuweisung des Prozedurzeigers bei %L: Unpassende Aufrufkonvention"
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "Unpassende Schnittstellen bei Zuweisung des Prozedurzeigers bei %L: %qs ist kein Unterprogramm"
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Explizite Schnittstelle für Komponente %qs bei %L erforderlich: %s"
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Explizite Schnittstelle für %qs bei %L erforderlich: %s"
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Unpassende Schnittstellen bei Zuweisung des Prozedurzeigers bei %L: %s"
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr "Prozedurzeigerziel %qs bei %L muss entweder eine intrinsische Funktion, host- oder use-assoziiert oder referenziert sein, oder aber das EXTERNAL-Attribut haben"
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr "Zeiger-Zuweisungsziel darf keine Konstante sein bei %L"
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr "Datenzeigerobjekt bei %L muss unbegrenzt polymorph oder von einem Typ mit BIND- oder SEQUENCE-Attribut sein, um zum unbegrenzt polymorphen Ziel zu passen"
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Verschiedene Typen in Zeigerzuweisung bei %L; Versuch der Zuweisung von %s an %s"
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Parameter verschiedener Typen in Zeigerzuweisung bei %L"
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Verschiedene Ränge in Zeigerzuweisung bei %L"
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "Ziel der Rang-Neuzuordnung ist kleiner als die Größe des Zeigers (%ld < %ld) bei %L"
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "Ziel der Rang-Neuzuordnung muss Rang 1 oder einfach fortlaufend bei %L sein"
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "Ziel der Rang-Neuzuordnung ist nicht Rang 1 bei %L"
@@ -71278,192 +71316,192 @@ msgstr "Ziel der Rang-Neuzuordnung ist nicht Rang 1 bei %L"
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "Datenziel bei %L darf keinen Koindex haben"
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Zielausdruck in Zeigerzuweisung bei %L muss ein Zeigerergebnis liefern"
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr "Array der Größe 0 bei %L gefunden, an dieser Stelle wird eine Entität mit TARGET-Attribut erwartet"
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "Ziel der Zeigerzuweisung in Initialisierungsausdruck bei %L muss das TARGET-Attribut haben"
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, gcc-internal-format, gfc-internal-format
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr "Jeder Feldindex der Zielspezifikation bei %L muss ein konstanter Ausdruck sein"
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr "Start- und Endposition der Teilzeichenkette der Zielspezifikation bei %L müssen konstante Ausdrücke sein"
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Zeiger-Zuweisungsziel bei %L ist weder TARGET noch POINTER"
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Falsches Ziel in Zeigerzuweisung in PURE-Prozedur bei %L"
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Zeigerzuweisung mit Vektorindex für rhs bei %L"
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Zeiger-Zuweisungsziel hat PROTECTED-Attribut bei %L"
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr "Zuweisung an zusammenhängenden Zeiger von nichtzusammenhängendem Ziel bei %L"
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "Zeiger bei %L in Zeigerzuweisung könnte Zeigerziel überdauern"
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Ziel der Zeigerinitialisierung bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Ziel der Zeigerinitialisierung bei %L muss das TARGET-Attribut haben"
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Ziel der Zeigerinitialisierung bei %L muss das SAVE-Attribut haben"
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "Ziel der Zeigerinitialisierung für Prozedur bei %L darf kein Prozedurzeiger sein"
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Interne Prozedur %qs ist in Initialisierung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Dummyprozedur %qs ist in Initialisierung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr "Interner Fehler: generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Zeigerfunktionen in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Nicht-variabler Ausdruck in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Benannte Konstante %qs in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qs in Variablen-Definitionskontext (%s) bei %L ist keine Variable"
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Nicht-POINTER in Zeiger-Verbindungskontext (%s) bei %L"
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Typ nicht zugreifbar in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_EVENT in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, gcc-internal-format
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr "Parameterabfrage %qs für %qs in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Scheinargument %qs mit INTENT(IN) in Zeiger-Verbindungskontext (%s) bei %L"
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Scheinargument %qs mit INTENT(IN) in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "Variable %qs ist PROTECTED und kann nicht in einem Zeigerzuordnungskontext (%s) bei %L vorkommen"
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "Variable %qs ist PROTECTED und kann nicht in Variablen-Definitionskontext (%s) bei %L auftreten"
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Variable %qs kann nicht in Variablen-Definitionskontext (%s) bei %L in PURE-Prozedur auftreten"
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr "%qs ist bei %L mit vektorindiziertem Ziel verbunden und kann nicht in Variablen-Definitionskontext (%s) verwendet werden"
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "%qs ist bei %L mit Ausdruck verbunden und kann nicht in Variablen-Definitionskontext (%s) verwendet werden"
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, gcc-internal-format
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr "%qs bei %L ist mit einer Zeigerfunktion verbunden, die in einem Variablendefinitionskontext verwendet wird (%s)"
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "Associate-Name %qs kann nicht in Variablen-Definitionskontext (%s) bei %L auftreten, da sein Ziel bei %L es auch nicht kann"
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "Elemente mit demselben Wert bei %L und %L in Vektorindex in einem Variablen-Definitionskontext (%s)"
@@ -71484,8 +71522,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Illegal id in copy_walk_reduction_arg"
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "Zwischenergebnis-Feld bei %L wird erzeugt"
@@ -71565,7 +71603,7 @@ msgstr "Variable %qs bei %L auf undefinierten Wert innerhalb der bei %L beginnen
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Variable %qs bei %L kann nicht innerhalb der bei %L beginnenden Schleife als INTENT(INOUT)-Argument für Funktion %qs definiert werden"
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr "Code zur Neu-Reservierung des reservierbaren Feldes bei %L wird hinzugefügt"
@@ -71701,12 +71739,12 @@ msgstr "Erstes Argument der definierten Zuweisung bei %L muss INTENT(OUT) oder I
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Zweites Argument der definierten Zuweisung bei %L muss INTENT(IN)"
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Erstes Argument der Operatorschnittstelle bei %L muss INTENT(IN) sein"
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Zweites Argument der Operatorschnittstelle bei %L muss INTENT(IN) sein"
@@ -72587,7 +72625,7 @@ msgstr "Umwandlung von %s in %s bei %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "%s kann nicht nach %s bei %L umgewandelt werden"
@@ -73138,7 +73176,7 @@ msgstr "NAMELIST %qs in READ-Anweisung bei %L enthält Symbol %qs, das im Kontex
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST-Objekt %qs in Namensliste %qs bei %L ist polymorph und erfordert eine definierte Ein-/Ausgabeprozedur"
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "NAMELIST-Objekt %qs in Namensliste %qs bei %L mit ALLOCATABLE- oder POINTER-Komponenten"
@@ -73305,6 +73343,11 @@ msgstr "identifier overflow: %d"
 msgid "check_charlen_present(): length not set"
 msgstr "Interner Fehler: check_charlen_present(): length not set"
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
 #: fortran/match.cc:118
 #, gcc-internal-format
@@ -73708,7 +73751,7 @@ msgstr "STOP-Code bei %L muss Standardzeichentyp KIND=%d sein"
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "STOP-Code bei %L muss Standardganzzahltyp KIND=%d sein"
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr "Der Spezifizierer QUIET bei %L muss ein skalarer LOGICAL sein"
@@ -74231,82 +74274,82 @@ msgstr "Syntaxfehler in »SELECT TYPE«-Anweisung bei %C"
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "Selektor in SELECT TYPE bei %C ist keine benannte Variable; associate-name=> verwendet"
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr "SELECT-RANK-Anweisung bei %C"
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr "Der SELECT-RANK-Selektor bei %C muss eine angenommene Rangvariable sein"
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "Syntaxfehler in SELECT-RANK-Anweisung bei %C"
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Unerwartete CASE-Anweisung bei %C"
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Syntaxfehler in CASE-Spezifikation bei %C"
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Unerwartete TYPE IS-Anweisung bei %C"
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr "Typspezifikation darf keinen Sequenz-abgeleiteten Typ oder Typ mit BIND-Attribut in SELECT TYPE bei %C beschreiben [F2003:C815]"
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr "Alle LEN-Typparameter in der TYPE-IS-Anweisung bei %C müssen ASSUMED sein"
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Syntaxfehler in TYPE IS-Spezifikation bei %C"
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Syntaxfehler in CLASS IS-Spezifikation bei %C"
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr "Unerwartete RANK-Anweisung bei %C"
 
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "Der SELECT-RANK-CASE-Ausdruck bei %C muss eine skalare, ganzzahlige Konstante sein"
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr "Der Wert des SELECT-RANK-CASE-Ausdrucks bei %C darf nicht kleiner als Null oder größer als %d sein"
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr "Syntaxfehler in RANK-Spezifikation bei %C"
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "ELSEWHERE-Anweisung bei %C nicht eingeschlossen in WHERE-Block"
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "Marke %qs bei %C passt nicht zur WHERE-Marke %qs"
@@ -75736,8 +75779,8 @@ msgstr "ORDERED-Parameter der Klausel bei %L ist weniger als COLLAPSE"
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr "ORDER-Klausel bei %L darf nicht zusammen mit ORDERED verwendet werden"
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF-Klausel bei %L erfordert einen skalaren LOGICAL-Ausdruck"
@@ -78112,12 +78155,12 @@ msgstr "Das bei %2$L deklarierte INTRINSIC %1$qs ist in den derzeitigen Standard
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Nicht-RECURSIVE Prozedur %qs aus Modul %qs ruft sich möglicherweise rekursiv selbst auf, in der Prozedur %qs. Deklarieren Sie die Prozedur als RECURSIVE oder verwenden Sie %<-frecursive%>"
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Nicht-RECURSIVE Prozedur %qs bei %L ruft sich möglicherweise rekursiv selbst auf. Sollte als RECURSIVE oder mit %<-frecursive%> verwendet werden"
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Marke %d wird bei %L referenziert, aber nirgendwo definiert"
@@ -78237,7 +78280,7 @@ msgstr "Fehlende explizite Deklaration mit EXTERNAL-Attribut für Symbol %qs bei
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Funktion %qs bei %L hat keinen IMPLICIT-Typ; meinen Sie %qs?"
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Funktion %qs bei %L hat keinen IMPLICIT-Typ"
@@ -78646,279 +78689,284 @@ msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Variable »%s« vermuteten Ranges bei %L darf keine Referenz auf Subobjekt haben"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, gcc-internal-format
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr "Skalare Variable %qs hat eine Array-Referenz bei %L"
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "In Spezifikationsausdruck verwendete Variable %qs wird bei %L vor Anweisung ENTRY referenziert, in der sie ein Parameter ist"
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variable %qs wird bei %L vor Anweisung ENTRY verwendet, in der sie ein Parameter ist"
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Polymorphes Subobjekt des koindizierten Objektes bei %L"
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Koindiziertes Objekt mit polymorpher reservierbarer Subkomponente bei %L"
 
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "Verwendung der Variable %qs bei %L ist veraltet"
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid array reference at %L"
+msgstr "Ungültige Feldreferenz bei %L"
+
+#: fortran/resolve.cc:6433
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr "%qs bei %L ist Host-verbunden bei %L in eine enthaltene Prozedur mit einer gleichnamigen internen Prozedur"
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "Fehler in Typbeschränktem Aufruf bei %L"
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Weitergegebenes Objekt bei %L muss Skalar sein"
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Basisobjekt für Aufruf der Prozedurzeigerkomponente bei %L hat ABSTRACT-Typ %qs"
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Basisobjekt für Aufruf der typgebundenen Prozedur bei %L hat ABSTRACT-Typ %qs"
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Basisobjekt für Aufruf der typgebundenen NOPASS-Prozedur bei %L muss skalar sein"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Keine passende spezifische Bindung für Aufruf des GENERIC %qs bei %L gefunden"
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs bei %L sollte eine SUBROUTINE sein"
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs bei %L sollte eine FUNCTION sein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Bad expression type"
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s bei %L muss skalar sein"
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s bei %L muss ganzzahlig sein"
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s bei %L muss INTEGER sein"
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Schrittausdruck in DO-Schleife bei %L kann nicht Null sein"
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO-Schleife bei %L wird null mal ausgeführt"
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "DO-Schleife bei %L ist undefiniert, da sie überläuft"
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "DO-Schleife bei %L ist undefiniert, da sie unterläuft"
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL-Indexname bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL-Anfangsausdruck bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL-Endausdruck bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL-Schrittausdruck bei %L muss skalares %s sein"
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL-Schrittausdruck bei %L kann nicht Null sein"
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL-Index %qs kann nicht in Tripel-Spezifikation bei %L auftreten"
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "ALLOCATE-Objekt bei %L muss ALLOCATABLE oder ein POINTER sein"
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Koindiziertes reservierbares Objekt bei %L"
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Quell-Ausdruck bei %L muss skalar sein oder den selben Rang wie das ALLOCATE-Objekt bei %L haben"
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Quell-Ausdruck bei %L und ALLOCATE-Objekt bei %L müssen dieselbe Form haben"
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Typ der Entität bei %L ist mit Quellausdruck bei %L typunverträglich"
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Das ALLOCATE-Objekt bei %L und der Quellausdruck bei %L müssen Typparameter der gleichen Art haben"
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Der Quellausdruck bei %L darf weder vom Typ LOCK_TYPE sein noch eine LOCK_TYPE-Komponente haben, wenn ALLOCATE-Objekt bei %L ein Koarray ist"
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "Der Quellausdruck bei %L darf weder vom Typ EVENT_TYPE sein noch eine EVENT_TYPE-Komponente haben, wenn ALLOCATE-Objekt bei %L ein Koarray ist"
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Reservierung von %s mit ABSTRACT-Basistyp bei %L erfordert Typspezifikation oder Quellausdruck"
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Reservierung von %s bei %L mit Typspezifikation erfordert den selben Zeichenkettenlängenparameter wie in der Deklaration"
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "In ALLOCATE-Anweisung bei %L ist Feld-Spezifikation erforderlich"
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Feldspezifikation oder feldwertiger SOURCE=-Ausdruck erforderlich in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Koarray-Spezifikation in ALLOCATE-Anweisung bei %L erforderlich"
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Falsche Koarray-Spezifikation in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr "Obere Kogrenze ist kleiner als untere Kogrenze bei %L"
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr "Obere Kogrenze ist kleiner als untere Kogrenze von 1 bei %L"
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Falsche Feldspezifikation in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs darf nicht bei %L in einer Feldspezifikation in der gleichen ALLOCATE-Anweisung auftreten, wo es selbst alloziert wird"
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "In Koindex-Spezifikation in ALLOCATE-Anweisung bei %L wird %<*%> erwartet"
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-Variable bei %L muss skalare INTEGER-Variable sein"
 
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-Variable bei %L darf nicht %s innerhalb der gleichen %s-Anweisung sein"
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG bei %L ist ohne STAT-Marke nutzlos"
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "»ERRMSG=«-Variable bei %L muss skalare Default-CHARACTER-Variable sein"
 
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "ERRMSG-Variable bei %L darf nicht »%s« innerhalb der selben »%s«-Anweisung sein"
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "ALLOCATE-Objekt bei %L tritt auch bei %L auf"
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "ALLOCATE-Objekt bei %L ist Subobjekt des Objekts bei %L"
@@ -78927,284 +78975,284 @@ msgstr "ALLOCATE-Objekt bei %L ist Subobjekt des Objekts bei %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-Marke bei %L überschneidet sich mit CASE-Marke bei %L"
 
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss Typ %s haben"
 
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss von der Art %d sein"
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss skalar sein"
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Auswahlausdruck in berechneter GOTO-Anweisung bei %L muss ein skalarer Ganzzahlausdruck sein"
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argument der SELECT-Anweisung bei %L kann nicht %s sein"
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argument der SELECT-Anweisung bei %L muss ein skalarer Ausdruck sein"
 
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Ausdruck in CASE-Anweisung bei %L ist nicht im Bereich von %s"
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "Der DEFAULT CASE bei %L kann nicht von zweitem DEFAULT CASE bei %L gefolgt werden"
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Logischer Bereich in CASE-Anweisung bei %L ist nicht erlaubt"
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Konstanter logischer Wert in CASE-Anweisung wird bei %L wiederholt"
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Bereichsspezifikation bei %L kann nie passen"
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logischer SELECT CASE Block bei %L hat mehr als zwei Fälle"
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Zugeordneter Name %qs bei %L ist ein Prozedurzeiger"
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Abgeleiteter Typ %qs kann bei %L nicht als Variable verwendet werden"
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Zugeordneter Name %qs bei %L ist ein Prozedurname"
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr "Der zuordnende Selektor-Ausdruck bei %L ergibt eine Prozedur"
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Selektor bei %L darf nicht NULL() sein"
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Selektor bei %L hat keinen Typ"
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Zugeordneter Name %qs bei %L wird als Feld verwendet"
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "CLASS-Selektor bei %L erfordert Zwischenspeicher, was noch nicht implementiert ist"
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Selektor muss in SELECT TYPE-Anweisung bei %L polymorph sein"
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Selektor bei %L darf nicht koindiziert sein"
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS bei %L überlappt sich mit TYPE IS bei %L"
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Abgeleiteter Typ %qs bei %L muss erweiterbar sein"
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Abgeleiteter Typ %qs bei %L muss eine Erweiterung von %qs sein"
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Unerwarteter intrinsischer Typ %qs bei %L"
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Die Typspezifikation bei %L muss angeben, dass jeder Parameter mit Längentyp vermutet ist"
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Doppelter CLASS IS-Block in SELECT TYPE-Anweisung bei %L"
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr "RANK DEFAULT bei %L wird bei %L wiederholt"
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr "RANK (*) bei %L wird bei %L wiederholt"
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr "RANK (%i) bei %L wird bei %L wiederholt"
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr "RANK (*) bei %L kann nicht mit dem Zeiger oder dem allozierbaren Selektor bei %L verwendet werden"
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ungültiger Kontext für NULL()-Zeiger bei %L"
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "DTIO-%s-Prozedur bei %L muss rekursiv sein"
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Element zum Datenaustausch bei %L kann nicht polymorph sein, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine POINTER-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Datenübertragungselement bei %L kann keine Prozedurzeiger-Komponenten haben"
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine ALLOCATABLE-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Datenübertragungselement bei %L kann keine PRIVATE-Komponenten haben"
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine PRIVATE-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Datenübertragungselement bei %L kann keine vollständige Referenz auf Feld vermuteter Größe sein"
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Lock-Variable bei %L muss Skalar mit LOCK_TYPE sein"
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "Ereignis-Variable bei %L muss Skalar mit EVENT_TYPE sein"
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Argument für Ereignisvariable bei %L muss ein Koarray oder koindiziert sein"
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Argument für Ereignisvariable bei %L muss ein Koarray, aber nicht koindiziert sein"
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "»STAT=«-Argument bei %L muss skalare INTEGER-Variable sein"
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "»ERRMSG=«-Argument bei %L muss skalare CHARACTER-Variable sein"
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "»ACQUIRED_LOCK=«-Argument bei %L muss skalare LOGICAL-Variable sein"
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Argument UNTIL_COUNT= bei %L muss ein skalarer INTEGER-Ausdruck sein"
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Argument für Imageset bei %L muss Skalar oder Rang-1-INTEGER-Ausdruck sein"
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Argument für Imageset bei %L muss zwischen 1 und num_images() liegen"
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Anweisung bei %L ist keine gültige Sprungzielanweisung für Sprungziel bei %L"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Sprung bei %L könnte Endlosschleife bewirken"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO-Anweisung bei %L hinterlässt CRITICAL-Konstrukt für Marke bei %L"
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO-Anweisung bei %L hinterlässt DO CONCURRENT-Konstrukt für Marke bei %L"
@@ -79212,215 +79260,215 @@ msgstr "GOTO-Anweisung bei %L hinterlässt DO CONCURRENT-Konstrukt für Marke be
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Marke bei %L ist nicht im gleichen Block wie GOTO-Anweisung bei %L"
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE-Maske bei %L hat ungültige Form"
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE-Zuweisungsziel bei %L hat ungültige Form"
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Benutzerdefinierte Nicht-ELEMENTAL-Zuweisung in WHERE bei %L"
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Nicht unterstützte Anweisung in WHERE bei %L"
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Zuweisung an FORALL-Indexvariable bei %L"
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "Das FORALL mit Index %qs wird nicht auf der linken Seite der Zuweisung bei %L verwendet und könnte somit mehrere Zuweisungen an dieses Objekt auslösen"
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "FORALL-Konstrukt bei %L"
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL-Indexname bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Ein äußeres FORALL-Konstrukt hat bereits einen Index mit Namen %L"
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "Klausel WHERE/ELSEWHERE bei %L erfordert ein LOGICAL-Feld"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Bad block type"
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr "Die Variable in der gewöhnlichen Zuweisung bei %L ist eine Prozedurzeigerkomponente"
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, gcc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr "CHARACTER-Ausdruck wird in Zuweisung (%wd/%wd) bei %L abgeschnitten"
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Koindizierter Ausdruck bei %L wird einer Variable abgeleiteten Typs mit einer POINTER-Komponente in einer PURE-Prozedur zugewiesen"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr "In einem reinen Unterprogramm darf ein INTENT(IN)-Dummy-Argument nicht als »expr« bei %L einer intrinsischen Zuweisungsanweisung verwendet werden, in der die Variable von einem abgeleiteten Typ ist, wenn der abgeleitete Typ eine Zeigerkomponente auf irgendeiner Ebene der Komponentenauswahl hat."
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Zuweisung an koindizierte Variable bei %L in einer PURE-Prozedur"
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Zuweisung an polymorphes Koarray bei %L ist nicht erlaubt"
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Zuweisung an allozierbare polymorphe Variable bei %L"
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Zuweisung an allozierbare polymorphe Variable bei %L erfordert %<-frealloc-lhs%>"
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr "Nicht allozierbare Variable darf in intrinsischer Zuweisung bei %L nicht polymorph sein – bitte prüfen, ob es ein passendes spezifisches Unterprogramm für den »=«-Operator gibt"
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Koindizierte Variable darf keine reservierbare endgültige Komponente in Zuweisung bei %L haben"
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "TODO: als typgebunden definierte Zuweisung(en) bei %L nicht durchgeführt, da Feldreferenzen mit mehreren Teilen in Ausdrücken als Zwischenergebnisse auftreten würden."
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Zuweisung eines Prozedurzeigers bei %L"
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Funktionsergebnis auf der linken Seite der Zuweisung bei %L muss Zeiger-Attribut haben."
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "TEAM-Argument für %qs bei %L muss ein skalarer Ausdruck vom Typ TEAM_TYPE sein"
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "»TEAM NUMBER«-Argument für FORM TEAM bei %L muss skalares INTEGER sein"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "Anweisung ASSIGNED GOTO bei %L erfordert eine skalare INTEGER-Variable"
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variable %qs bei %L wurde keine Zielmarke zugewiesen"
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternative RETURN-Anweisung bei %L erfordert einen SCALAR-INTEGER-Spezifizierer als Rückgabe"
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "Erwarteter intrinsischer Initialisierungsausdruck OMP WORKSHARE bei %L"
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN-Anweisung bei %L erfordert eine skalare Standard-INTEGER-Variable"
 
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "Ungültiges NULL bei %L"
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Arithmetische IF-Anweisung bei %L erfordert einen skalaren REAL- oder INTEGER-Ausdruck"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): No expression on DO WHILE"
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Abbruchbedingung der DO WHILE-Schleife bei %L muss ein skalarer LOGICAL-Ausdruck sein"
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL-Maskenklausel bei %L erfordert einen skalaren LOGICAL-Ausdruck"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Bad statement code"
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Verwendung von Parameter %qs, der bei %L deklariert wurde, ist veraltet"
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Variable %1$qs bei %3$L mit Binde-Marke %2$qs verwenden denselben globalen Bezeichner wie die Entität bei %4$L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "Variable %qs aus Modul %qs mit Bindungsmarke %qs bei %L verwendet denselben globalen Bezeichner wie Entität bei %L aus Modul %qs"
@@ -79428,1000 +79476,1000 @@ msgstr "Variable %qs aus Modul %qs mit Bindungsmarke %qs bei %L verwendet densel
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Prozedur %1$qs bei %3$L mit Binde-Marke %2$qs verwenden denselben globalen Bezeichner wie die Entität bei %4$L"
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Zeichenkettenlänge bei %L ist zu groß"
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Reservierbares Feld %qs bei %L muss aufgeschobene Form oder vermuteten Rang haben"
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Skalares Objekt %qs bei %L kann nicht ALLOCATABLE sein"
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Feldzeiger %qs bei %L muss aufgeschobene Form oder vermuteten Rang haben"
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Feld %qs bei %L kann keine aufgeschobene Form haben"
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Typ %qs der CLASS-Variable %qs bei %L ist nicht erweiterbar"
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS-Variable %qs bei %L muss Attrappe, reservierbar oder Zeiger sein"
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Der Typ %qs bei %L darf nicht mit Wirt verbunden sein, da er von unverträglichem bei %L definierten Objekt mit gleichem Namen blockiert wird"
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Einbezogenes SAVE für Modulvariable %qs bei %L, benötigt wegen Standardinitialisierung"
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Entität %qs bei %L hat Parameter mit aufgeschobenem Typ und benötigt entweder das POINTER- oder ALLOCATABLE-Attribut"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Das Feld %qs im Modul oder Hauptprogramm bei %L muss konstante Form haben"
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entität mit vermuteter Zeichenlänge bei %L muss ein Scheinargument oder ein PARAMETER sein"
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs bei %L muss in diesem Zusammenhang konstante Zeichenlänge haben"
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON-Variable %qs bei %L muss konstante Zeichenlänge haben"
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Zuordnungsfähiges %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Externes %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Schein-%qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Intrinsisches %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktionsergebnis %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automatisches Feld %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s bei %L"
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Zeichenwertige Anweisungsfunktion %qs bei %L muss konstante Länge haben"
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs hat PRIVATE-Typ und kann kein Scheinargument von %qs bei %L sein, das PUBLIC ist"
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Prozedur %qs in PUBLIC-Schnittstelle %qs bei %L nimmt Scheinargumente von %qs, das PRIVATE ist"
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktion %qs bei %L darf keinen Initialisierer haben"
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Externes Objekt %qs bei %L darf keinen Initialisierer haben"
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-Funktion %qs bei %L muss ein skalares Ergebnis haben"
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Anweisungsfunktion %qs bei %L darf weder POINTER- oder ALLOCATABLE-Attribut haben"
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht feld-wertig sein"
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht zeiger-wertig sein"
 
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht rein sein"
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht rekursiv sein"
 
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*)-Funktion %qs bei %L"
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Prozedurzeiger %qs bei %L darf nicht ELEMENTAL sein"
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Scheinprozedur %qs bei %L darf nicht ELEMENTAL sein"
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Funktionsergebnisvariable %qs bei %L von elementarer Funktion %qs darf nicht die Attribute ALLOCATABLE oder POINTER haben"
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut SAVE in %qs bei %L in Konflikt"
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut INTENT in %qs bei %L in Konflikt"
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut RESULT in %qs bei %L in Konflikt"
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "Attribut EXTERNAL steht mit Attribut FUNCTION in %qs bei %L in Konflikt"
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Dem Ergebnis %qs als Prozedurzeiger bei %L fehlt das POINTER-Attribut"
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Konflikt in ELEMENTAL-Attribut zwischen MODULE-PROCEDURE bei %L und seiner Schnittstelle in %s"
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Konflikt in PURE-Attribut zwischen MODULE-PROCEDURE bei %L und seiner Schnittstelle in %s"
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Konflikt in RECURSIVE-Attribut zwischen MODULE-PROCEDURE bei %L und seiner Schnittstelle in %s"
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s zwischen der MODULE-PROCEDURE-Deklaration in Modul %qs und der Deklaration bei %L in (SUB)MODULE %qs"
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr "Schnittstelle von %qs bei %L muss explizit sein"
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL-Prozedur %qs bei %L ist keine SUBROUTINE"
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL-Prozedur bei %L muss genau ein Argument haben"
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argument der FINAL-Prozedur bei %L muss Typ %qs haben"
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr "FINAL-Prozedur bei %L mit angenommenem Rangargument muss der einzige Finalisierer mit derselben Art/Typ sein (F2018: C790)"
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Argument der FINAL-Prozedur bei %L darf kein POINTER sein"
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht OPTIONAL sein"
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Nicht-skalare FINAL-Prozedur bei %L sollte Argument mit vermuteter Form haben"
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "Bei %2$L deklarierte FINAL-Prozedur %1$qs hat denselben Rang (%3$d) wie %4$qs"
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr "Für den abgeleiteten Typ %qs, der bei %L definiert ist, sind ausschließlich Array-FINAL-Prozeduren deklariert. Empfohlen ist auch eine skalare, es sei denn, ein Finalisierer mit angenommenem Rang wurde deklariert"
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs und %qs können nicht gemischte FUNCTION/SUBROUTINE für GENERIC %qs bei %L sein"
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs und %qs für GENERIC %qs bei %L sind mehrdeutig"
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Undefinierte spezifische Bindung %qs als Ziel des GENERIC %qs bei %L"
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs bei %L muss auf spezifische Bindung abzielen, %qs ist ebenfalls GENERIC"
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC %qs bei %L kann nicht spezifische Bindung mit gleichem Namen überschreiben"
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Typgebundener Operator bei %L kann nicht NOPASS sein"
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs bei %L muss eine Modulprozedur oder eine externe Prozedur mit expliziter Schnittstelle sein"
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prozedur %qs mit PASS(%s) bei %L hat kein Argument %qs"
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Prozedur %qs mit PASS bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Nicht-polymorphes Scheinargument von %qs für weitergegebenes Objekt bei %L"
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L muss abgeleiteten Typ %qs haben"
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L muss den parametrisierten abgeleiteten Typ %qs haben"
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr "Alle LEN-Typparameter des hereingereichten Dummyarguments %qs von %qs bei %L müssen ASSUMED sein."
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Scheinargument von %qs für weitergegebenes Objekt bei %L muss ein Skalar sein"
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Scheinargument von %qs für weitergegebenes Objekt bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Scheinargument von %qs für weitergegebenes Objekt bei %L darf nicht POINTER sein"
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Prozedur %qs bei %L hat den gleichen Namen wie eine Komponente von %qs"
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Prozedur %qs bei %L hat den selben Namen wie eine vererbte Komponente von %qs"
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Bei %2$L deklarierter abgeleiteter Typ %1$qs muss ABSTRACT sein, da %3$qs DEFERRED und nicht überschrieben ist"
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Koarray-Komponente %qs bei %L muss reservierbar mit aufgeschobener Form sein"
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Komponente %qs bei %L mit TYPE(C_PTR) oder TYPE(C_FUNPTR) darf kein Koarray sein"
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Komponente %qs bei %L mit Koarray-Komponente darf ein Nicht-Zeiger und nicht-reservierbares Skalar sein"
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Komponente %qs bei %L hat das CONTIGUOUS-Attribut, aber ist kein Feldzeiger"
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Komponente %qs von BIND(C)-Typ bei %L muss Länge eins haben"
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prozedurzeiger-Komponente %qs mit PASS(%s) bei %L hat kein Argument %qs"
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Prozedurzeiger-Komponente %qs mit PASS bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L muss abgeleiteten Typ %qs haben"
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Parameter %qs von %qs mit PASS(%s) bei %L muss skalar sein"
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L darf kein POINTER-Attribut haben"
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponente %qs von %qs bei %L hat den gleichen Namen wie eine geerbte typgebundene Prozedur"
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Zeichenlänge der Komponente %qs muss ein konstanter Spezifikationsausdruck bei %L sein"
 
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "Ausdruck für Zeichenlänge der Komponente %qs bei %L muss vom Typ INTEGER sein, nicht %s"
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Zeichenkomponente %qs von %qs bei %L mit aufgeschobener Länge muss POINTER oder ALLOCATABLE sein"
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Die Komponente %qs ist ein PRIVATE-Typ und kann nicht Komponente von %qs sein, die PUBLIC bei %L ist"
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphe Komponente %s bei %L in SEQUENCE oder BIND(C)-Typ %s"
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponente %s des bei %L deklarierten SEQUENCE-Typen hat kein SEQUENCE-Attribut"
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "In Konflikt stehende Initialisierungen in Union bei %L und %L"
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Da der erweiterte Typ %qs bei %L eine Koarray-Komponente hat, muss der Elterntyp %qs auch eine haben"
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Nicht-erweiterbarer abgeleiteter Typ %qs bei %L darf nicht ABSTRACT sein"
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Parametrisierter Typ %1$qs hat bei %3$L keine Komponente, die zu Parameter %2$qs gehört"
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Allgemeiner Name %qs der Funktion %qs bei %L ist der gleiche wie der des abgeleiteten Typs bei %L"
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Abgeleiteter Typ %qs bei %L wurde nicht deklariert"
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Feld %qs mit vermuteter Größe in Namensliste %qs bei %L ist nicht erlaubt"
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST-Feldobjekt %qs mit vermuteter Form in Namensliste %qs bei %L"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST-Feldobjekt %qs ohne konstante Form in Namensliste %qs bei %L"
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs ohne konstante Zeichenlänge in Namensliste %qs bei %L"
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs wurde als PRIVATE deklariert und kann kein Element der PUBLIC-Namensliste %qs bei %L sein"
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs hat Verwendungs-verbundene PRIVATE-Komponenten und kann kein Element der Namensliste %qs bei %L sein"
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs hat PRIVATE-Komponenten und kann kein Element der PUBLIC-Namensliste %qs bei %L sein"
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut NAMELIST in %qs bei %L in Konflikt"
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameterfeld %qs bei %L kann nicht automatische oder vermutete Form haben"
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Implizit angegebener PARAMETER %qs bei %L passt nicht zu früherem IMPLICIT-Typ"
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Unverträglicher abgeleiteter Typ in PARAMETER bei %L"
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "COMMON-Block %qs bei %L kann nicht das EXTERNAL-Attribut haben"
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Entität %qs bei %L hat verzögerten LEN-Parameter %qs und benötigt entweder das POINTER- oder ALLOCATABLE-Attribut"
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "Das AUTOMATIC-Objekt %qs bei %L darf kein SAVE-Attribut haben und dard auch keine Variable im main-Programm, einem Modul oder einem Teilmodus sein (F08/C513)"
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "Das Objekt %qs bei %L mit ASSUMED-Typparametern muss ein Dummy oder ein SELECT-TYPE-Selektor sein (F08/4.2)"
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Sorry, allozierbare/Zeiger-Komponenten in polymorphen (CLASS-)getypten Koarrays bei %L werden nicht unterstützt"
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr "%<omp_all_memory%>, bei %L deklariert, darf nur in der OpenMP-DEPEND-Klausel verwendet werden"
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Attribut PROTECTED steht mit Attribut EXTERNAL bei %L in Konflikt"
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut PROTECTED bei %L in Konflikt"
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs bei %L hat Attribut CONTIGUOUS, aber ist kein Feldzeiger oder Feld vermuteter Größe oder Rang"
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Falsche Spezifikation für Feld bei %L mit angenommener Größe"
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Feld mit vermuteter Größe bei %L muss ein Schein-Argument sein"
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Feld mit vermuteter Form bei %L muss ein Scheinargument sein"
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Feld mit vermutetem Rang bei %L muss ein Scheinargument sein"
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Feld mit vermutetem Rang bei %L darf kein Attribut VALUE oder CODIMENSION haben"
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Symbol bei %L ist keine Scheinvariable"
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs bei %L kann nicht das VALUE-Attribut haben, da es kein Scheinargument ist"
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Zeichenwertige Scheinvariable %qs bei %L mit VALUE-Attribut muss konstante Länge haben"
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C-kompatible zeichenwertige Scheinvariable %qs bei %L mit VALUE-Attribut muss Länge eins haben"
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Der abgeleitete Typ %qs bei %L hat Typ %qs, der nicht definiert wurde"
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss ein Scheinargument sein"
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss vom Typ TYPE(*) oder von einem numerischen intrinsischen Typ sein"
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut darf nicht die Attribute ALLOCATABLE, CODIMENSION, POINTER oder VALUE haben"
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut darf nicht das Attribut INTENT(OUT) haben"
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss entweder skalar sein oder ein Feld vermuteter Größe"
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Vermuteter Typ der Variable %s bei %L ist nur für Scheinvariablen erlaubt"
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variable %s vermuteten Typs bei %L darf nicht die Attribute ALLOCATABLE, CODIMENSION, POINTER oder VALUE haben"
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variable %s vermuteten Typs bei %L darf nicht das Attribut INTENT(OUT) haben"
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Variable %s vermuteten Typs bei %L darf kein Feld mit ausdrücklicher Form sein"
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variable %qs bei %L kann nicht BIND(C) sein, weil es weder ein COMMON-Block noch mit Sichtbarkeit auf Modulebene deklariert ist"
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "BIND(C)-Variable %qs bei %L muss Länge eins haben"
 
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs bei %L mit abgeleitetem PRIVATE-Typen %qs"
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Variable %s bei %L mit LOCK_TYPE oder mit Subkomponente mit LOCK_TYPE muss ein Koarray sein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79866
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "Variable %s bei %L des Typs EVENT_TYPE oder mit Subkomponente des Typs EVENT_TYPE muss ein Koarray sein"
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "Das INTENT(OUT)-Scheinargument %qs bei %L hat ASSUMED SIZE und kann damit keine Standardinitialisierung haben"
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Scheinargument %qs bei %L mit LOCK_TYPE darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Scheinargument %qs bei %L mit EVENT_TYPE darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktionsergebnis %qs bei %L darf weder Koarray sein noch eine Koarray-Komponente haben"
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Variable %qs bei %L mit TYPE(C_PTR) oder TYPE(C_FUNPTR) darf kein Koarray sein"
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Variable %qs bei %L mit Koarraykomponente muss ein Nichtzeiger, nichtallozierbares Skalar und damit kein Koarray sein"
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Variable %qs bei %L ist ein Koarray und ist weder ALLOCATABLE, SAVE, noch ein Scheinargument"
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Koarray-Variable %qs bei %L darf keine Kodimensionen mit aufgeschobener Form haben"
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Zuordnungsfähige Koarray-Variable %qs bei %L muss aufgeschobene Form haben"
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Variable %qs bei %L ist INTENT(OUT) und kann daher kein reservierbares Coarray sein oder Coarray-Komponenten haben"
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Coarray-Scheinvariable %qs bei %L in BIND(C)-Prozedur %qs nicht erlaubt"
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-Scheinargument %qs bei %L mit Nicht-C_Bool-Art in BIND(C)-Prozedur %qs"
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-Rückgabevariable %qs bei %L mit Nicht-C_Bool-Art in BIND(C)-Prozedur %qs"
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Namensliste %qs kann bei %L nicht als Argument für Unterprogramm oder Funktion verwendet werden"
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate bei %L ist nicht SAVEd"
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "»!$OMP DECLARE TARGET«-Variable %qs bei %L ist nicht gespeichert (SAVE)"
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "Definierbare Entität bei %L erwartet"
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA Element %qs bei %L muss in COMMON sein"
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA-Feld %qs bei %L muss in vorheriger Deklaration angegeben werden"
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA-Element %qs bei %L kann keinen Coindex haben"
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA-Element %qs bei %L ist ein Zeiger und muss daher ein vollständiges Feld sein"
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr "Das DATA-Objekt in der Nähe von %L hat das Zeiger-Attribut und der entsprechende DATA-Wert ist kein gültiges initial-data-target"
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Das DATA-Element %qs bei %L kann kein ALLOCATABLE-Attribut haben"
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Abschnitt eines nicht konstanten Feldes bei %L in DATA-Anweisung"
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-Anweisung bei %L hat mehr Variablen als Werte"
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant character length at %L in DATA statement"
 msgstr "Nichtkonstante Zeichenlänge bei %L in DATA-Anweisung"
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Anfang der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Ende der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Schritt der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "Schrittweite der implied-do-Schleife bei %L darf nicht 0 sein"
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-Anweisung bei %L hat mehr Werte als Variablen"
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Marke %d bei %L definiert, aber nicht verwendet"
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Marke %d bei %L definiert, kann aber nicht verwendet werden"
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L muss SEQUENCE-Attribut haben, um EQUIVALENCE-Objekt zu sein"
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L kann keine ALLOCATABLE-Komponenten haben, um EQUIVALENCE-Objekt zu sein"
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Variable %qs abgeleiteten Typs bei %L mit Standardinitialisierung kann nicht in EQUIVALENCE mit einer Variablen in COMMON sein"
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L mit Zeigerkomponenten kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaxfehler in EQUIVALENCE-Anweisung bei %L"
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Entweder alle oder keines der Objekte in bei %L gesetztem EQUIVALENCE muss das Attribut PROTECTED haben"
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "COMMON-Blockelement %qs bei %L darf in der PURE-Prozedur %qs kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Benannte Konstante %qs bei %L kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Feld %qs bei %L mit nicht-konstanten Grenzen kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Strukturkomponente %qs bei %L kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Teilzeichenkette bei %L hat Länge Null"
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Selbstreferenz im Zeichenlängenausdruck für %qs bei %L"
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC-Funktion %qs bei %L mit PRIVATE-Typ %qs"
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs bei %L hat keinen IMPLICIT-Typ"
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Prozedur für Benutzeroperator %qs bei %L muss eine FUNCTION sein"
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Prozedur für Benutzeroperator %qs bei %L kann nicht vermutete Zeichenlänge haben"
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Prozedur für Benutzeroperator %qs bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Erstes Argument der Operatorschnittstelle bei %L kann nicht optional sein"
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Zweites Argument der Operatorschnittstelle bei %L kann nicht optional sein"
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Operatorschnittstelle bei %L darf höchstens zwei Argumente haben"
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Enthaltene Prozedur %qs bei %L einer PURE-Prozedur muss auch PURE sein"
@@ -80985,128 +81033,128 @@ msgstr "Implizit deklarierte Variable %qs bei %L könnte nicht C-kompatibel sein
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr "Funktionsergebnis %qs bei %L hat keinen IMPLICIT-Typ"
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr "Attribut %s steht mit Attribut %s bei %L in Konflikt"
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, gcc-internal-format
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr "Attribut %s steht mit Attribut %s in %qs bei %L in Konflikt"
+
+#: fortran/symbol.cc:508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr "Attribut %s ungültig in BLOCK DATA - Programmeinheit bei %L"
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "Name der Namenslisten-Gruppe bei %L kann kein SAVE-Attribut haben"
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, gcc-internal-format
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr "Interne Prozedur %qs bei %L steht in Konflikt mit DUMMY-Argument"
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "Prozedur-Zeiger bei %C"
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "Attribut %s auf %s %s bei %L angewendet"
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) auf %s %s bei %L angewendet"
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, gcc-internal-format, gfc-internal-format
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr "Attribut %s steht mit Attribut %s bei %L in Konflikt"
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, gcc-internal-format
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr "Attribut %s steht mit Attribut %s in %qs bei %L in Konflikt"
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "Attribute des USE-verbundenen Symbols bei %L können nicht verändert werden"
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "Attribute des USE-verbundenen Symbols %s bei %L können nicht verändert werden"
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "Attribut %s doppelt angegeben bei %L"
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr "ALLOCATABLE außerhalb des INTERFACE-Körpers bei %L angegeben"
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr "Doppeltes AUTOMATIC-Attribut bei %L angegeben"
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "CODIMENSION für %qs außerhalb seines INTERFACE-Körpers bei %L angegeben"
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "DIMENSION für %qs außerhalb seines INTERFACE-Körpers bei %L angegeben"
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "Cray-Zeigerende bei %L tritt in mehreren pointer()-Anweisungen auf"
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "Doppeltes PROTECTED-Attribut bei %L angegeben"
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "SAVE-Attribut bei %L kann nicht in einer PURE-Prozedur angegeben werden"
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "SAVE-Attribut doppelt angegeben bei %L"
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "Doppeltes VALUE-Attribut bei %L angegeben"
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Doppeltes VOLATILE-Attribut bei %L angegeben"
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr "VOLATILE-Attribut bei %L darf nicht in einer PURE-Prozedur angegeben werden"
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Doppeltes ASYNCHRONOUS-Attribut bei %L angegeben"
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "Attribut %s von %qs steht mit Attribut %s bei %L in Konflikt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=80012
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -81115,204 +81163,204 @@ msgstr ""
 "%s-Prozedur bei %L ist bereits als %s-Prozedur deklariert.\n"
 "F2008: Eine Zuweisung an eine Zeigerfunktion ist mehrdeutig, wenn dies die erste Anweisung nach dem Spezifikationsblock ist. Bitte fügen Sie davor irgend eine andere ausführbare Anweisung ein. FIXME (steht so im englischen Original.)"
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "Prozedur %s bei %L ist bereits als Prozedur %s deklariert"
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT(%s) steht mit INTENT(%s) bei %L in Konflikt"
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "ACCESS-Spezifikation bei %L wurde bereits spezifiziert"
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Doppeltes BIND-Attribut bei %L angegeben"
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "BIND(C) bei %L"
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Doppeltes EXTENDS-Attribut bei %L angegeben"
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "EXTENDS bei %L"
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Symbol %qs bei %L hat bereits eine explizite Schnittstelle"
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "%qs bei %L hat außerhalb seines INTERFACE-Körpers spezifizierte Attribute"
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "Symbol %qs bei %L steht mit Symbol aus Modul %qs in Konflikt, verbunden durch Verwendung bei %L"
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Symbol %qs bei %L hat bereits grundlegenden Typen %s"
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Prozedur %qs bei %L kann nicht grundlegenden Typen %s haben"
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Symbol %qs bei %L kann keinen Typen haben"
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Komponente %qs bei %C bereits im Elterntypen bei %L deklariert"
 
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Symbol %qs bei %C ist mehrdeutig"
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Abgeleiteter Typ %qs bei %C wird verwendet, bevor er definiert wird"
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Komponente %qs bei %C ist eine PRIVATE-Komponente von %qs"
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "%qs bei %C ist kein Element der Struktur %qs; meinen Sie %qs?"
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs bei %C ist kein Element der Struktur %qs"
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Doppelte Anweisungsmarke %d bei %L und %L"
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Marke %d bei %C bereits als Sprungziel referenziert"
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Marke %d bei %C bereits als eine Formatmarke referenziert"
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr "DO-Abbruchanweisung ist nicht »END DO« oder »CONTINUE« mit Marke %d bei %C"
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Marke %d bei %C vorher als FORMAT-Marke verwendet"
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Marke %d bei %C vorher als Sprungziel verwendet"
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "Gemeinsam genutzte DO-Abbruchmarke %d bei %C"
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr "DO-Anweisung mit Label bei %L"
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Name %qs bei %C ist eine mehrdeutige Referenz auf %qs vom Modul %qs"
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "Name %qs bei %C ist eine mehrdeutige Referenz auf %qs von aktueller Programmeinheit"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Symbol %qs bei %C wurde bereits mit Host verbunden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Abgeleiteter Typ %qs, bei %L deklariert, muss BIND-Attribut haben, um C-kompatibel zu sein"
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "Abgeleiteter Typ %qs mit Attribut BIND(C) bei %L ist leer und könnte für entsprechenden C-Prozessor unzugreifbar sein"
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponente %qs bei %L kann nicht POINTER-Attribut haben, da es Element des BIND(C)-abgeleiteten Typs %qs bei %L ist"
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponente %qs des Prozedurzeigers bei %L kann kein Element des BIND(C)-abgeleiteten Typs %qs bei %L sein"
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponente %qs bei %L kann nicht ALLOCATABLE-Attribut haben, da es Element des BIND(C)-abgeleiteten Typs %qs bei %L ist"
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "Komponente %qs in abgeleitetem Typ %qs bei %L könnte nicht C-kompatibel sein, obwohl abgeleiteter Typ %qs BIND(C) ist"
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "Komponente %qs in abgeleitetem Typ %qs bei %L könnte nicht C-kompatibel sein"
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Abgeleiteter Typ %qs bei %L kann nicht das SEQUENCE-Attribut haben, da er BIND(C) ist"
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "Symbol %qs wird bei %L verwendet, bevor es typisiert wird"
@@ -81342,24 +81390,24 @@ msgstr "Überlappende ungleiche Initialisierungen in EQUIVALENCE bei %L"
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "Überlappende ungleiche Initialisierungen in EQUIVALENCE bei %C"
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr "Der Strukturkonstruktor bei %C wurde finalisiert. Dieses Feature wurde von f08/0011 entfernt. Verwenden Sie -std=f2018 oder -std=gnu, um die Finalisierung zu entfernen."
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "Die Anzahl der Elemente im Feldkonstruktor bei %L erfordert Erhöhung der erlaubten oberen Grenze %d. Siehe Option %<-fmax-array-constructor%>"
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Bei %L wird ein vorübergehendes Feld für Argument %qs erzeugt"
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "Falscher Ausdruckstyp beim Durchlaufen (%d)"
@@ -81547,37 +81595,37 @@ msgstr "Rückgabewert %1$qs der bei %3$L deklarierten Funktion %2$qs nicht geset
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr "Entschuldigung, !$ACC DECLARE bei %L ist in einem BLOCK-Konstrukt nicht erlaubt"
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr "Länge des Arrays bei %L kann nicht berechnet werden."
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr "Code zur Neu-Reservierung der reservierbaren Variable bei %L wird hinzugefügt"
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Sorry, der koindizierte Zugriff bei %L auf ein unbegrenzt polymorphes Objekt wird nicht unterstützt"
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Sorry, der koindizierte Zugriff bei %L auf eine unbegrenzt polymorphe Komponente wird nicht unterstützt"
 
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Unbekannte eingebauter Operator"
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Unbekannte Argumentlistenfunktion bei %L"
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr "Wenn die Neuzuordnung von Grenzen bei %L angegeben wird, darf das Zeigerziel nicht NULL sein"
@@ -81588,17 +81636,17 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "Intrinsische Funktion %qs (%d) nicht erkannt"
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "Argument %<dim%> des intrinsischen »%s« bei %L ist kein gültiger Dimensionsindex"
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "Sorry, die Event-Komponente des abgeleiteten Typs bei %L wird noch nicht unterstützt"
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "Event-Variable bei %L darf nicht koindiziert sein"
@@ -81740,7 +81788,7 @@ msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr "Entschuldigung; für Image-Set bei %2$L ist nur Unterstützung für Ganzzahl-Art %1$d implementiert"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr "gfc_trans_select(): Bad type for case expr."
@@ -82109,6 +82157,11 @@ msgstr "Variable %qD als Funktion redeklariert"
 msgid "function %qD redeclared as variable"
 msgstr "Funktion %qD als Variable redeklariert"
 
+#: lto/lto-symtab.cc:865
+#, gcc-internal-format
+msgid "previously declared here"
+msgstr "vorher hier deklariert"
+
 #: lto/lto.cc:174
 #, gcc-internal-format
 msgid "%<lto_obj_file_open()%> failed"
@@ -83347,7 +83400,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr "%<-fobjc-sjlj-exceptions%> wird für %<-fgnu-runtime%> ignoriert"
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, gcc-internal-format
 msgid "non-objective-c type %qT cannot be caught"
 msgstr "Nicht-Objective-C-Typ %qT kann nicht aufgefangen werden"
@@ -83357,7 +83410,7 @@ msgstr "Nicht-Objective-C-Typ %qT kann nicht aufgefangen werden"
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr "%<-fobjc-sjlj-exceptions%> ist das einzige unterstützte Ausnahmesystem für %<-fnext-runtime%> mit %<-fobjc-abi-version%>-Argument kleiner 2"
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, gcc-internal-format
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
 msgstr "%<-fobjc-sjlj-exceptions%> wird für %<-fnext-runtime%> ignoriert, wenn %<-fobjc-abi-version%> größer als 1 ist"
@@ -83427,3 +83480,11 @@ msgstr "unverwendeter Name %qE"
 #, gcc-internal-format, gfc-internal-format
 msgid "are you trying to break %s? how dare you?"
 msgstr "Wert »%s« kann in diesem Bereich nicht gefunden werden"
+
+#, gcc-internal-format
+#~ msgid "cannot declare %qD in a different module"
+#~ msgstr "%qD kann nicht in einem anderen Modul deklariert sein"
+
+#, gcc-internal-format
+#~ msgid "cannot declare %qD in different module"
+#~ msgstr "%qD kann nicht in einem anderen Modul deklariert sein"
diff --git a/gcc/po/el.po b/gcc/po/el.po
index 29bd89a2fa3..069f83a3cbd 100644
--- a/gcc/po/el.po
+++ b/gcc/po/el.po
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 4.0-b20041128\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
 "PO-Revision-Date: 2004-12-15 18:53+0000\n"
 "Last-Translator: Simos Xenitellis <simos74@gmx.net>\n"
 "Language-Team: Greek <nls@tux.hellug.gr>\n"
@@ -422,7 +422,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr "δεν είναι δυνατό να παραληφθεί ο χρήστης και η ομάδα"
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 msgid "shared and mdll are not compatible"
 msgstr ""
 
@@ -19302,16 +19302,16 @@ msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 msgid "insn does not satisfy its constraints:"
 msgstr ""
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr ""
 
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 msgid "created and used with different settings of %<-fpic%>"
 msgstr ""
 
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 msgid "created and used with different settings of %<-fpie%>"
 msgstr ""
 
@@ -19638,7 +19638,7 @@ msgstr ""
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
@@ -19657,9 +19657,9 @@ msgstr "Μη έγκυρη επιλογή `%s'"
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
@@ -19679,7 +19679,7 @@ msgstr "RPC: Μη συμβατές εκδόσεις του RPC"
 msgid "incompatible register operand for '%%%c'"
 msgstr "RPC: Μη συμβατές εκδόσεις του RPC"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, fuzzy, c-format
 msgid "missing operand"
 msgstr "έχει παραληφθεί η λίστα με τα πεδία"
@@ -19708,93 +19708,93 @@ msgstr "Ακατάλληλη χρήση του διαμορφωτή διεύθυ
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr ""
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, fuzzy, c-format
 msgid "invalid %%J value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, fuzzy, c-format
 msgid "invalid %%r value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, fuzzy, c-format
 msgid "invalid %%R value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, fuzzy, c-format
 msgid "invalid %%N value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, fuzzy, c-format
 msgid "invalid %%P value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, fuzzy, c-format
 msgid "invalid %%h value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, fuzzy, c-format
 msgid "invalid %%L value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, fuzzy, c-format
 msgid "invalid %%m value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, fuzzy, c-format
 msgid "invalid %%M value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, fuzzy, c-format
 msgid "invalid %%U value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, fuzzy, c-format
 msgid "invalid %%s value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, fuzzy, c-format
 msgid "invalid %%C value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, fuzzy, c-format
 msgid "invalid %%E value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, fuzzy, c-format
 msgid "unknown relocation unspec"
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, fuzzy, c-format
 msgid "invalid %%xn code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, fuzzy, c-format
 msgid "invalid operand address"
 msgstr "Ακατάλληλη χρήση του διαμορφωτή διεύθυνσης"
@@ -19888,35 +19888,35 @@ msgstr "μη έγκυρη μετατόπιση UTC"
 msgid "unrecognized supposed constant"
 msgstr "άγνωστο πρόθεμα: %s"
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, fuzzy, c-format
 msgid "invalid shift operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, fuzzy, c-format
 msgid "predicated Thumb instruction"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, fuzzy, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -19924,124 +19924,124 @@ msgstr "Μη έγκυρη επιλογή `%s'"
 msgid "invalid operand for code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, fuzzy, c-format
 msgid "instruction never executed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 #, fuzzy
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 #, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr ""
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr ""
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 msgid "bad address, not an I/O address:"
 msgstr ""
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 #, fuzzy
 msgid "bad address, not a constant:"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 msgid "bad address, not (reg+disp):"
 msgstr ""
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 msgid "bad address, not post_inc or pre_dec:"
 msgstr ""
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr ""
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 msgid "internal compiler error.  Unknown mode:"
 msgstr ""
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 #, fuzzy
 msgid "invalid insn:"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 #, fuzzy
 msgid "incorrect insn:"
 msgstr "λάθος συνθηματικό"
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 #, fuzzy
 msgid "unknown move insn:"
 msgstr "άγνωστο σετ `%s'"
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 msgid "bad shift insn:"
 msgstr ""
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 msgid "internal compiler error.  Incorrect shift:"
 msgstr ""
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 #, fuzzy
 msgid "unsupported fixed-point conversion"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 msgid "variable"
 msgstr ""
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 #, fuzzy
 msgid "function parameter"
 msgstr "κακό όρισμα"
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 #, fuzzy
 #| msgid "structure"
 msgid "structure field"
 msgstr "δομή"
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 #, fuzzy
 msgid "return type of function"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 msgid "pointer"
 msgstr ""
 
@@ -20077,7 +20077,7 @@ msgstr "Μη ορισμένο όνομα %s"
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -20430,51 +20430,51 @@ msgstr "Μη έγκυρη επιλογή `%s'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, fuzzy, c-format
 msgid "invalid operand code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, fuzzy, c-format
 msgid "invalid constraints for operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "μη έγκυρο δικαίωμα"
 
 # src/grep.c:1133
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 #, fuzzy
 msgid "unknown insn mode"
 msgstr "άγνωστη μέθοδος καταλόγων"
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 #, fuzzy
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 #, fuzzy
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 #, fuzzy
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
 msgstr ""
 
@@ -20508,7 +20508,7 @@ msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 msgid "invalid %%P operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, fuzzy, c-format
 msgid "invalid %%p value"
 msgstr "μη έγκυρος χρήστης"
@@ -20537,29 +20537,29 @@ msgstr ""
 msgid "invalid addressing mode"
 msgstr "Ακατάλληλη χρήση του διαμορφωτή διεύθυνσης"
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, fuzzy, c-format
 msgid "'%%%c' is not a valid operand prefix"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, fuzzy, c-format
 msgid "invalid use of '%%%c'"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
@@ -20591,7 +20591,7 @@ msgid "post-increment address is not a register"
 msgstr ""
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 #, fuzzy
 msgid "bad address"
 msgstr "Εσφαλμένη διεύθυνση"
@@ -20753,7 +20753,7 @@ msgstr "Εμφάνιση έκδοσης προγράμματος"
 msgid "unsupported memory expression:"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, fuzzy, c-format
 msgid "invalid vector operand"
 msgstr "μη έγκυρος χρήστης"
@@ -20802,251 +20802,251 @@ msgstr ""
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 #, fuzzy
 msgid "bad move"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, fuzzy, c-format
 msgid "invalid %%A value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, fuzzy, c-format
 msgid "invalid %%D value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, fuzzy, c-format
 msgid "invalid %%e value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, fuzzy, c-format
 msgid "invalid %%f value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, fuzzy, c-format
 msgid "invalid %%F value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, fuzzy, c-format
 msgid "invalid %%G value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, fuzzy, c-format
 msgid "invalid %%j code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, fuzzy, c-format
 msgid "invalid %%J code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, fuzzy, c-format
 msgid "invalid %%k value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, fuzzy, c-format
 msgid "invalid %%K value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, fuzzy, c-format
 msgid "invalid %%O value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, fuzzy, c-format
 msgid "invalid %%q value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, fuzzy, c-format
 msgid "invalid %%t value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, fuzzy, c-format
 msgid "invalid %%T value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, fuzzy, c-format
 msgid "invalid %%u value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, fuzzy, c-format
 msgid "invalid %%v value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, fuzzy, c-format
 msgid "invalid %%V value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, fuzzy, c-format
 msgid "invalid %%x value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, fuzzy, c-format
 msgid "invalid %%z value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατασκευή [c*n]"
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 #, fuzzy
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "πολύ λίγα ορίσματα"
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Αδύνατη η δημιουργία διεργασίας στον εξυπηρετητή"
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 #, fuzzy
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 #, fuzzy
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 #, fuzzy
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 #, fuzzy
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, fuzzy, c-format
 msgid "cannot decompose address"
 msgstr "Δεν είναι δυνατή η εκχώρηση της ζητηθήσας διεύθυνσης"
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "Μη έγκυρος κώδικας αίτησης"
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 #, fuzzy
 msgid "vector argument passed to unprototyped function"
 msgstr "πολύ λίγα ορίσματα"
 
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -21246,12 +21246,12 @@ msgstr "((ανώνυμο))"
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -21264,7 +21264,7 @@ msgstr "Μη ορισμένο όνομα %s"
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -21273,7 +21273,7 @@ msgstr "Μη ορισμένο όνομα %s"
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -21281,7 +21281,7 @@ msgstr "Μη ορισμένο όνομα %s"
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -21292,29 +21292,29 @@ msgstr ""
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "Μη ορισμένο όνομα %s"
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -21324,17 +21324,17 @@ msgstr "Μη ορισμένο όνομα %s"
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -21343,8 +21343,8 @@ msgstr "Μη ορισμένο όνομα %s"
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -21355,17 +21355,17 @@ msgid "expected %<.%>"
 msgstr "Μη ορισμένο όνομα %s"
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr ""
@@ -21373,32 +21373,32 @@ msgstr ""
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "Μη ορισμένο όνομα %s"
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, fuzzy, gcc-internal-format
 msgid "expected %<else%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr ""
 
@@ -21407,7 +21407,7 @@ msgstr ""
 msgid "(anonymous)"
 msgstr "((ανώνυμο))"
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -21422,22 +21422,22 @@ msgstr "Μη ορισμένο όνομα %s"
 msgid "candidate:"
 msgstr ""
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 #, fuzzy
 msgid "  after user-defined conversion:"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr ""
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr ""
 
@@ -21693,7 +21693,7 @@ msgstr ""
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 msgid "candidates are:"
 msgstr ""
 
@@ -21744,49 +21744,49 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, fuzzy, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
 
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -21865,7 +21865,7 @@ msgstr ""
 msgid "Deleted feature:"
 msgstr ""
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 #, fuzzy
 msgid "array assignment"
 msgstr "προσπέρασμα ορίσματος"
@@ -22075,12 +22075,12 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 #, fuzzy
 msgid "assignment"
 msgstr "προσπέρασμα ορίσματος"
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 #, fuzzy
 msgid "pointer assignment"
 msgstr "προσπέρασμα ορίσματος"
@@ -22265,48 +22265,48 @@ msgstr ""
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -22315,11 +22315,11 @@ msgstr ""
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr ""
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
@@ -22334,12 +22334,12 @@ msgstr ""
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 #, fuzzy
 msgid "Assignment of scalar to unallocated array"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
@@ -22349,81 +22349,81 @@ msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένα
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, c-format
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, c-format
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, c-format
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
@@ -22445,15 +22445,15 @@ msgstr ""
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 msgid "Loop variable has been modified"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 msgid "DO step value is zero"
 msgstr ""
 
@@ -22533,7 +22533,7 @@ msgid "expected boolean type"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "Μη ορισμένο όνομα %s"
@@ -22605,7 +22605,7 @@ msgstr "χωρίς ορίσματα"
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, fuzzy, gcc-internal-format
 msgid "too many arguments"
 msgstr "πάρα πολλά ορίσματα"
@@ -23276,7 +23276,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error at %qs token"
 msgid "Syntax error in %s statement at %C"
@@ -23719,8 +23719,8 @@ msgstr ""
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -23737,7 +23737,7 @@ msgstr "το `%s' είναι πρόγονος του `%s'"
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments specified for %qE attribute"
 msgstr "λάθος αριθμός ορισμάτων"
@@ -23747,7 +23747,7 @@ msgstr "λάθος αριθμός ορισμάτων"
 msgid "expected %i or more, found %i"
 msgstr ""
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "expected %i, found %i"
 msgstr "Μη ορισμένο όνομα %s"
@@ -23814,12 +23814,12 @@ msgstr ""
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -23828,7 +23828,7 @@ msgstr ""
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -23850,8 +23850,8 @@ msgstr "το `%s' είναι πρόγονος του `%s'"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
@@ -23961,7 +23961,7 @@ msgstr "δε βρέθηκε ο προεπεξεργαστής C: %s \n"
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, fuzzy, gcc-internal-format
 msgid "%qE declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -24066,7 +24066,7 @@ msgstr "Λείπει παράμετρος για `%s'"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "μη έγκυρος αριθμός από γραμμές"
@@ -24088,42 +24088,42 @@ msgstr ""
 msgid "target format does not support infinity"
 msgstr ""
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr ""
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "πάρα πολλά ορίσματα"
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr ""
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "πάρα πολλά ορίσματα"
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr ""
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, fuzzy, gcc-internal-format
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, fuzzy, gcc-internal-format
 msgid "last argument of %qD is not integer constant between 0 and 3"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
@@ -25171,12 +25171,12 @@ msgstr ""
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, fuzzy, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -25734,7 +25734,7 @@ msgstr ""
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr ""
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, gcc-internal-format
 msgid "%qs failed"
 msgstr ""
@@ -25764,17 +25764,17 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, gcc-internal-format
 msgid "call to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, gcc-internal-format
 msgid "call to %qs declared with attribute warning: %s"
 msgstr ""
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
 msgstr ""
@@ -25809,7 +25809,7 @@ msgstr ""
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -25978,7 +25978,7 @@ msgstr ""
 msgid "%s signal terminated program %s"
 msgstr "μη τερματιζόμενο όνομα βάρους"
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, fuzzy, gcc-internal-format
 msgid "unrecognized command-line option %qs"
 msgstr "Μη έγκυρη επιλογή `%s'"
@@ -26240,7 +26240,7 @@ msgstr "έχουν παραληφθεί ορίσματα"
 msgid "multilib exclusions %qs is invalid"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, fuzzy, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "έχουν παραληφθεί ορίσματα"
@@ -26543,22 +26543,22 @@ msgstr ""
 msgid "%qD specified bound %E equals source length"
 msgstr ""
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, gcc-internal-format
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr ""
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr ""
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s not supported for variable length aggregates"
 msgstr ""
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -26599,16 +26599,16 @@ msgid "function returns address of local variable"
 msgstr ""
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, fuzzy, gcc-internal-format
@@ -26620,366 +26620,366 @@ msgstr "Δεν υπάρχει προηγούμενη κανονική έκφρα
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, gcc-internal-format
 msgid "referenced argument declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, fuzzy, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgid_plural "%qE output %wu bytes into a destination of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 msgid "%qE argument %Z overlaps destination object %qE"
 msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 msgid "%qE argument %Z may overlap destination object %qE"
 msgid_plural "%qE arguments %Z may overlap destination object %qE"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, gcc-internal-format
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, gcc-internal-format
 msgid "null destination pointer"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, fuzzy, gcc-internal-format
 msgid "null format string"
 msgstr "Η αλυσίδα μορφής δεν είναι έγκυρη: `%s'"
@@ -27719,12 +27719,12 @@ msgstr "Μη έγκυρη επιλογή `%s'"
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -28489,7 +28489,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -28833,17 +28833,17 @@ msgstr ""
 msgid "mismatching definition"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, fuzzy, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr "μη έγκυρο όνομα μήνα"
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, gcc-internal-format
 msgid "IPA modref summary is missing in input file"
 msgstr ""
@@ -29911,72 +29911,72 @@ msgstr "σφάλμα εγγραφής %s"
 msgid "error closing optimization records %qs"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, fuzzy, gcc-internal-format
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr "το πρώτο όρισμα της `%s' πρέπει να είναι `int'"
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer"
 msgstr "το πρώτο όρισμα της `%s' πρέπει να είναι `int'"
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is not between %d and %d"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, fuzzy, gcc-internal-format
 msgid "invalid argument in option %qs"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr ""
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, gcc-internal-format
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr ""
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument in option %qs"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, fuzzy, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is bigger than %d"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, gcc-internal-format
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
 msgstr ""
@@ -30052,8 +30052,8 @@ msgstr "το πρώτο όρισμα της `%s' πρέπει να είναι `i
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with %qs"
 msgstr "μη έγκυρο δικαίωμα"
@@ -30766,7 +30766,7 @@ msgstr ""
 msgid "register of %qD used for multiple global register variables"
 msgstr ""
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -31216,42 +31216,42 @@ msgstr ""
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, fuzzy, gcc-internal-format
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, fuzzy, gcc-internal-format
 msgid "nested functions not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, fuzzy, gcc-internal-format
 msgid "nested function trampolines not supported on this target"
 msgstr "το --no-dereference (-h) δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, fuzzy, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, fuzzy, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, fuzzy, gcc-internal-format
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, fuzzy, gcc-internal-format
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC target%> is not supported for this machine"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -32364,82 +32364,82 @@ msgstr ""
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr ""
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr ""
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr ""
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr ""
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr ""
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr ""
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr ""
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr ""
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr ""
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr ""
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr ""
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr ""
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, gcc-internal-format
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr ""
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr ""
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, fuzzy, gcc-internal-format
 msgid "called from this function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, gcc-internal-format
 msgid "inlining failed in call to %q+F: %s"
 msgstr ""
@@ -32494,28 +32494,28 @@ msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, fuzzy, gcc-internal-format
 msgid "in a call to non-static member function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "in a call to built-in function %qD"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, fuzzy, gcc-internal-format
 msgid "in a call to function %qD declared %qs"
 msgstr "Στη συνάρτηση μέλος `%s':"
@@ -32719,7 +32719,7 @@ msgstr "έχουν παραληφθεί ορίσματα"
 msgid "%qs may be used uninitialized"
 msgstr ""
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, fuzzy, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -32949,7 +32949,7 @@ msgstr ""
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -32964,122 +32964,122 @@ msgstr ""
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr ""
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr ""
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, gcc-internal-format
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, gcc-internal-format
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr ""
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, fuzzy, gcc-internal-format
 msgid "%qD is unavailable: %s"
 msgstr "το `%s' είναι μη-προσπελάσιμο"
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, fuzzy, gcc-internal-format
 msgid "%qD is unavailable"
 msgstr "το `%s' είναι μη-προσπελάσιμο"
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, gcc-internal-format
 msgid "%qE is unavailable: %s"
 msgstr ""
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, fuzzy, gcc-internal-format
 msgid "%qE is unavailable"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, gcc-internal-format, gfc-internal-format
 msgid "type is unavailable: %s"
 msgstr ""
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, gcc-internal-format
 msgid "type is unavailable"
 msgstr ""
@@ -33104,262 +33104,262 @@ msgstr ""
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr ""
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type %s is not an opaque type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type %s is not with opaque mode"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr ""
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr ""
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, fuzzy, gcc-internal-format
 msgid "main variant is not defined"
 msgstr "μη τερματιζόμενο όνομα βάρους"
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, fuzzy, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr ""
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -33574,7 +33574,7 @@ msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζ
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr ""
@@ -33776,7 +33776,7 @@ msgstr "το `%s' είναι πρόγονος του `%s'"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr ""
@@ -33958,7 +33958,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be specified for local variables"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -34273,7 +34273,7 @@ msgstr "δεν είστε μέλος της ομάδας `%s'"
 msgid "%qE argument is not a function"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, fuzzy, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
@@ -34779,7 +34779,7 @@ msgstr ""
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr ""
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %qs to a void type"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
@@ -34910,17 +34910,17 @@ msgstr ""
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "πολύ λίγα ορίσματα"
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, fuzzy, gcc-internal-format
@@ -35044,166 +35044,166 @@ msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχ
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, fuzzy, gcc-internal-format
 msgid "size of array is too large"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, fuzzy, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, fuzzy, gcc-internal-format
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, fuzzy, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "πολύ λίγα ορίσματα"
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, fuzzy, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, gcc-internal-format
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr ""
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, fuzzy, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, fuzzy, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, fuzzy, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr ""
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, fuzzy, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array is negative"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -35827,7 +35827,7 @@ msgstr "%s: το %s είναι τόσο μεγάλο που δε μπορεί ν
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr "%s: το %s είναι τόσο μεγάλο που δε μπορεί να αναπαρασταθεί"
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, fuzzy, gcc-internal-format
 msgid "%<_BitInt(%d)%> is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -35907,7 +35907,7 @@ msgstr "μη τερματιζμένο αλφαριθμητικό σταθερά
 msgid "traditional C rejects string constant concatenation"
 msgstr ""
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -35962,7 +35962,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, fuzzy, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -35977,17 +35977,17 @@ msgstr ""
 msgid "%qE is not initialized"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Η λειτουργία δεν επιτρέπεται"
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "μη έγκυρο όνομα μήνα"
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "παράληψη ορίσματος αρχείου"
@@ -35997,7 +35997,7 @@ msgstr "παράληψη ορίσματος αρχείου"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
@@ -36082,7 +36082,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -36092,7 +36092,7 @@ msgstr ""
 msgid "%qD is not a function argument"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
@@ -36689,7 +36689,7 @@ msgid "wrong type argument to %s"
 msgstr "λάθος αριθμός ορισμάτων"
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -37620,35 +37620,35 @@ msgstr ""
 
 #: c-family/c-warn.cc:3832
 #, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3836
+#: c-family/c-warn.cc:3839
 #, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr ""
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr ""
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr ""
@@ -37859,117 +37859,117 @@ msgstr ""
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, gcc-internal-format
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, gcc-internal-format
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, gcc-internal-format
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, gcc-internal-format
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr ""
@@ -38371,12 +38371,12 @@ msgstr ""
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr ""
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr ""
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr ""
@@ -38940,7 +38940,7 @@ msgstr ""
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
@@ -39016,12 +39016,12 @@ msgid "unknown tuning option (%s)"
 msgstr "άγνωστο σετ `%s'"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
@@ -39032,7 +39032,7 @@ msgid "specify a system register with a small string length"
 msgstr "Αποτυχία δέσμευσης πόρων συστήματος"
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
@@ -39214,9 +39214,9 @@ msgstr ""
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
@@ -39268,18 +39268,18 @@ msgid "virtual function multiversioning not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
@@ -39292,8 +39292,8 @@ msgstr ""
 msgid "lane %wd out of range %wd - %wd"
 msgstr "%s: αριθμός γραμμής έξω από τα όρια"
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, fuzzy, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
@@ -39303,7 +39303,7 @@ msgstr "Εμφάνιση έκδοσης προγράμματος"
 msgid "GCC does not currently support return type %qT for simd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
@@ -39313,7 +39313,7 @@ msgstr ""
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -39403,8 +39403,8 @@ msgstr ""
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr ""
@@ -39526,18 +39526,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -39651,7 +39651,7 @@ msgid "argument of %qE attribute is missing"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
@@ -39671,23 +39671,23 @@ msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζετ
 msgid "argument of %qE attribute ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr ""
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, fuzzy, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
@@ -39929,7 +39929,7 @@ msgstr ""
 msgid "target CPU does not support unaligned accesses"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr ""
@@ -39979,7 +39979,7 @@ msgstr ""
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr ""
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -40087,7 +40087,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -40127,42 +40127,42 @@ msgstr ""
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr ""
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -40170,22 +40170,22 @@ msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, fuzzy, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, fuzzy, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -40239,160 +40239,160 @@ msgstr ""
 msgid "unknown core architecture %qs specified with %qs"
 msgstr ""
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "%<-fpic%> is not supported"
 msgstr "το -pipe δεν υποστηρίζεται"
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, fuzzy, gcc-internal-format
 msgid "%<-fPIC%> is not supported"
 msgstr "Το ai_family δεν υποστηρίζεται"
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "%<-fpie%> is not supported"
 msgstr "το -pipe δεν υποστηρίζεται"
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, fuzzy, gcc-internal-format
 msgid "%<-fPIE%> is not supported"
 msgstr "Το ai_family δεν υποστηρίζεται"
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "οι επιλογές --string και --check είναι αμοιβαίως αποκλειόμενες"
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, gcc-internal-format
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr ""
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, gcc-internal-format
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr ""
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr ""
 
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr ""
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, gcc-internal-format
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr ""
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr ""
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr ""
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, gcc-internal-format
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr ""
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, gcc-internal-format
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr ""
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr "μη πλήρης εγγραφή"
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr ""
@@ -40401,42 +40401,42 @@ msgstr ""
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, gcc-internal-format
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr ""
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, fuzzy, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, fuzzy, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr ""
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -40575,7 +40575,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr ""
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, fuzzy, gcc-internal-format
@@ -41196,8 +41196,8 @@ msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένα
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -41263,255 +41263,255 @@ msgstr "πάρα πολλά ορίσματα"
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, fuzzy, gcc-internal-format
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, fuzzy, gcc-internal-format
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, fuzzy, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "Το ai_family δεν υποστηρίζεται"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, fuzzy, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%s: η υποστήριξη εκσφαλμάτωσης δεν έχει συμπεριληφθεί στη μεταγλώττιση.\n"
 
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr ""
@@ -41519,290 +41519,290 @@ msgstr ""
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr ""
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "το --no-dereference (-h) δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "Άγνωστη επιλογή: %s %s %s"
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr ""
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, fuzzy, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
@@ -41993,46 +41993,46 @@ msgstr ""
 msgid "non-integer operand used with operand code %<z%>"
 msgstr ""
 
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, gcc-internal-format
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr ""
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, fuzzy, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr ""
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr ""
@@ -42054,8 +42054,8 @@ msgstr ""
 msgid "malformed %<#pragma builtin%>"
 msgstr "κακοσχηματισμένος μετρητής επανάληψης"
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, fuzzy, gcc-internal-format
 msgid "invalid argument of %qE attribute"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -42110,12 +42110,12 @@ msgstr ""
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr ""
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, fuzzy, gcc-internal-format
 msgid "failed to expand built-in function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
@@ -42241,17 +42241,17 @@ msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζοντ
 msgid "%qs cannot be used for compiling a shared library"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be specified for register variables"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, gcc-internal-format
 msgid "multiple %qE attribute"
 msgstr ""
@@ -42352,12 +42352,12 @@ msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζοντ
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, fuzzy, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, fuzzy, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -42399,7 +42399,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr ""
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
@@ -42439,132 +42439,132 @@ msgstr ""
 msgid "argument to %qE attribute is not intstack"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, fuzzy, gcc-internal-format
 msgid "cannot handle inconsistent calls to %qs"
 msgstr "αδυναμία εκτέλεσης ioctl στο `%s'"
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr ""
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr ""
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr ""
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE not supported for MIPS16"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, fuzzy, gcc-internal-format
 msgid "%qs does not support MIPS16 code"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr ""
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, gcc-internal-format
 msgid "MIPS16 %<-mxgot%> code"
 msgstr ""
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, gcc-internal-format
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr ""
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, gcc-internal-format
 msgid "MSA MIPS16 code"
 msgstr ""
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, gcc-internal-format
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr ""
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported combination: %s"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, gcc-internal-format
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr ""
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, gcc-internal-format
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, fuzzy, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr "Χρήση ABI 32-bit"
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, fuzzy, gcc-internal-format
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr "Χρήση ABI 64-bit"
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, fuzzy, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr "Χρήση ABI 32-bit"
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr ""
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr ""
@@ -42574,117 +42574,117 @@ msgstr ""
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, gcc-internal-format
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, gcc-internal-format
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr ""
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, fuzzy, gcc-internal-format
 msgid "unsupported combination: %qs%s %s"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, fuzzy, gcc-internal-format
 msgid "unsupported combination: %qs %s"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, gcc-internal-format
 msgid "cannot generate position-independent code for %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, gcc-internal-format
 msgid "position-independent code requires %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr ""
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, gcc-internal-format
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr ""
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, gcc-internal-format
 msgid "%qs must be used with %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, gcc-internal-format
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr ""
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr ""
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support DSP instructions"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, gcc-internal-format
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr ""
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, gcc-internal-format
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr ""
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, fuzzy, gcc-internal-format
 msgid "%qs requires branch-likely instructions"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support the synci instruction"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr ""
@@ -43557,57 +43557,57 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, gcc-internal-format
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, gcc-internal-format
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, gcc-internal-format
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> attribute"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, gcc-internal-format
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, gcc-internal-format
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> attribute"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -43667,173 +43667,193 @@ msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s
 msgid "capture by copy of RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, gcc-internal-format
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, gcc-internal-format
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function call to %qE with empty arguments"
 msgstr "δεν ταιριάζει συνάρτηση για την κλήση στο %<%T::%s(%A)%#V%>"
 
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, fuzzy, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "πάρα πολλές δηλώσεις μετατροπής στην κατάληξη"
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, gcc-internal-format
 msgid "this operation requires the RVV ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, fuzzy, gcc-internal-format
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, gcc-internal-format
 msgid "%s %qT requires the V ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, gcc-internal-format
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, gcc-internal-format
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, gcc-internal-format
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, gcc-internal-format
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr ""
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, gcc-internal-format
 msgid "function attribute %qs requires the V ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr ""
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, fuzzy, gcc-internal-format
 msgid "%qs applied to non-RVV type %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, fuzzy, gcc-internal-format
 msgid "%qs requires an integer constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr ""
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, fuzzy, gcc-internal-format
 msgid "code model %qs with %qs"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, gcc-internal-format
 msgid "rv64e requires lp64e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr ""
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr ""
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr ""
@@ -44083,32 +44103,32 @@ msgstr ""
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, gcc-internal-format
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
@@ -44148,30 +44168,23 @@ msgstr "Μη έγκυρη επιλογή `%s'"
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, gcc-internal-format
-msgid "%qs requires the ELFv2 ABI"
-msgstr ""
-
 # src/shred.c:1134
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, fuzzy, gcc-internal-format
 msgid "stack frame too large"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported number of nops before function entry (%u)"
 msgstr ""
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, fuzzy, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "Δεν είναι δυνατή η καταχώρηση της υπηρεσίας"
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
@@ -44296,107 +44309,117 @@ msgstr ""
 msgid "unknown option for %<%s=%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4837
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4855
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr ""
@@ -44442,7 +44465,7 @@ msgstr ""
 msgid "builtin %qs can only be used on vector types"
 msgstr ""
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -44513,225 +44536,225 @@ msgstr "το `%s' δεν είναι κανονικό αρχείο"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
 
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher"
 msgstr ""
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher"
 msgstr ""
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr ""
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr ""
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr ""
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr ""
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr ""
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr ""
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, gcc-internal-format
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, fuzzy, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "%s: ο αριθμός γραμμής πρέπει να είναι μεγαλύτερος από το μηδέν"
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "το πρώτο όρισμα της `%s' πρέπει να είναι `int'"
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, gcc-internal-format
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, fuzzy, gcc-internal-format
 msgid "invalid cc output constraint: %qs"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, fuzzy, gcc-internal-format
 msgid "multiple cc output constraints not supported"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, gcc-internal-format
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr ""
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, fuzzy, gcc-internal-format
 msgid "invalid type for cc output constraint"
 msgstr "Μη έγκυρος κώδικας αίτησης"
@@ -45157,8 +45180,8 @@ msgstr "%s σε %s"
 msgid "attribute %qs applies to array types only"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -45233,7 +45256,7 @@ msgstr ""
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr ""
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, fuzzy, gcc-internal-format
 msgid "originally defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -45465,7 +45488,7 @@ msgstr "αυτός είναι ο πρώτος ορισμός"
 msgid "declaration of %qD shadows a parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -45475,7 +45498,7 @@ msgstr ""
 msgid "declaration of %qD shadows a previous local"
 msgstr ""
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, fuzzy, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -45541,7 +45564,7 @@ msgstr "%qE δεν έχει διακυρηχθεί (πρώτη χρήση στη
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr ""
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
@@ -45577,7 +45600,7 @@ msgstr "Πρόωρο τέλος της κανονικής έκφρασης"
 msgid "duplicate label declaration %qE"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "διπλό κλειδί"
@@ -45612,7 +45635,7 @@ msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 msgid "%qE defined as wrong kind of tag"
 msgstr ""
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr ""
@@ -45754,12 +45777,12 @@ msgstr ""
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, gcc-internal-format
 msgid "%<omp::%s%> not allowed to be specified in this context"
 msgstr ""
@@ -45769,7 +45792,7 @@ msgstr ""
 msgid "%q+D is usually a function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
@@ -45846,7 +45869,7 @@ msgstr ""
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "μη αρχικοποιημένη σταθερά const %qD"
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -46032,7 +46055,7 @@ msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεω
 msgid "storage class specified for unnamed parameter"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
@@ -46095,7 +46118,7 @@ msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 msgid "declaration of type name as array of functions"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, fuzzy, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "μη έγκυρη ώρα της μέρας"
@@ -46201,7 +46224,7 @@ msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 msgid "function definition has qualified void return type"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -46328,7 +46351,7 @@ msgstr ""
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, fuzzy, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
@@ -46433,7 +46456,7 @@ msgstr ""
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr ""
@@ -46523,17 +46546,17 @@ msgstr "αδυναμία ανοίγματος αρχείου ορισμού loca
 msgid "nested redefinition of %<struct %E%>"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, gcc-internal-format
 msgid "%qT defined in underspecified object initializer"
 msgstr ""
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -46563,598 +46586,598 @@ msgstr ""
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, fuzzy, gcc-internal-format
 msgid "union has no named members"
 msgstr "επώνυμα μέλη"
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, fuzzy, gcc-internal-format
 msgid "union has no members"
 msgstr "επώνυμα μέλη"
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, fuzzy, gcc-internal-format
 msgid "struct has no named members"
 msgstr "επώνυμα μέλη"
 
 # src/request.c:37
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, fuzzy, gcc-internal-format
 msgid "struct has no members"
 msgstr "%s σε %s"
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, fuzzy, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, gcc-internal-format
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr ""
 
 # src/shred.c:1134
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, gcc-internal-format
 msgid "type punning toggles scalar storage order"
 msgstr ""
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr ""
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, gcc-internal-format
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr ""
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, fuzzy, gcc-internal-format
 msgid "redefinition of struct or union %qT"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr ""
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, fuzzy, gcc-internal-format
 msgid "enumeration values exceed range of %qs"
 msgstr "σχετική θέση αρχείου είναι εκτός ορίων"
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, fuzzy, gcc-internal-format
 msgid "conflicting redefinition of enum %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr ""
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, gcc-internal-format
 msgid "enumerator value outside the range of underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, fuzzy, gcc-internal-format
 msgid "enumerator value outside the range of %qs"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr ""
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr ""
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, fuzzy, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "ο επιστρεφόμενος τύπος προκαθορίζεται σε `int'"
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr ""
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, fuzzy, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "διατήρηση ωρών στο %s"
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, fuzzy, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr ""
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr ""
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr ""
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, fuzzy, gcc-internal-format
 msgid "old-style function definition"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, fuzzy, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, fuzzy, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "ο επιστρεφόμενος τύπος προκαθορίζεται σε `int'"
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, fuzzy, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, fuzzy, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, fuzzy, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, fuzzy, gcc-internal-format
 msgid "prototype declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, fuzzy, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, fuzzy, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %<auto%>"
 msgstr "σφάλμα εγγραφής %s"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, gcc-internal-format
 msgid "%<auto%> used with %<constexpr%>"
 msgstr ""
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "διπλό κλειδί"
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, fuzzy, gcc-internal-format
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, fuzzy, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr ""
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, fuzzy, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "σφάλμα εγγραφής %s"
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, gcc-internal-format
 msgid "%qE used with %<constexpr%>"
 msgstr ""
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr ""
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr ""
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, gcc-internal-format
 msgid "%<typedef%> used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, gcc-internal-format
 msgid "%qE used with %<extern%>"
 msgstr ""
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, gcc-internal-format
 msgid "%qE used with %qs"
 msgstr ""
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr ""
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, gcc-internal-format
 msgid "%<constexpr%> used with %qE"
 msgstr ""
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, gcc-internal-format
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr ""
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
@@ -47184,7 +47207,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "Μη ορισμένο όνομα %s"
@@ -47194,8 +47217,8 @@ msgstr "Μη ορισμένο όνομα %s"
 msgid "ISO C forbids an empty translation unit"
 msgstr ""
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr ""
@@ -47235,9 +47258,9 @@ msgstr "Μη έγκυρη επιλογή `%s'"
 msgid "unknown type name %qE"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -47267,7 +47290,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "το `%s' είναι πρόγονος του `%s'"
@@ -47287,7 +47310,7 @@ msgstr "Μη ορισμένο όνομα %s"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, fuzzy, gcc-internal-format
 msgid "%<assume%> attribute not followed by %<;%>"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -47378,7 +47401,7 @@ msgstr "μη τερματιζμένο αλφαριθμητικό σταθερά
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
@@ -47449,10 +47472,10 @@ msgstr "έχουν παραληφθεί ορίσματα"
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
@@ -47603,7 +47626,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr ""
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr ""
@@ -47613,8 +47636,8 @@ msgstr ""
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs attribute argument"
 msgstr ""
@@ -47788,12 +47811,12 @@ msgstr ""
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr ""
@@ -47940,7 +47963,7 @@ msgstr "αρχεία fifo δεν υποστηρίζονται"
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, fuzzy, gcc-internal-format
 msgid "expected expression"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
@@ -48261,12 +48284,12 @@ msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χ
 msgid "no type or storage class may be specified here,"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr ""
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, fuzzy, gcc-internal-format
 msgid "missing property attribute"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
@@ -48276,57 +48299,57 @@ msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 msgid "unknown property attribute %<%s%s%>"
 msgstr ""
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr ""
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, fuzzy, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr ""
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr ""
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -48336,25 +48359,25 @@ msgstr ""
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr ""
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "πάρα πολλά ορίσματα"
@@ -48369,63 +48392,63 @@ msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 msgid "expected %<)%> or %<,%>"
 msgstr ""
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, gcc-internal-format
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr ""
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, fuzzy, gcc-internal-format
 msgid "expected constant logical expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr ""
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -48448,22 +48471,22 @@ msgstr ""
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr ""
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr ""
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr ""
@@ -48473,94 +48496,94 @@ msgstr ""
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr ""
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, fuzzy, gcc-internal-format
 msgid "too many %<self%> clauses"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, gcc-internal-format
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr ""
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, fuzzy, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "διπλό κλειδί"
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr ""
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, fuzzy, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "μη έγκυρο δικαίωμα"
@@ -48570,22 +48593,22 @@ msgstr "μη έγκυρο δικαίωμα"
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr ""
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, gcc-internal-format
 msgid "expected %<allocator%> or %<align%>"
 msgstr ""
@@ -48595,22 +48618,22 @@ msgstr ""
 msgid "duplicate %qs modifier"
 msgstr "διπλό κλειδί"
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, gcc-internal-format
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr ""
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, gcc-internal-format
 msgid "multiple linear modifiers"
 msgstr ""
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, gcc-internal-format
 msgid "multiple %<step%> modifiers"
 msgstr ""
@@ -48630,63 +48653,63 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr ""
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "μη έγκυρος χρήστης"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, fuzzy, gcc-internal-format
 msgid "invalid doacross kind"
 msgstr "μη έγκυρο όνομα μήνα"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, gcc-internal-format
 msgid "too many %<always%> modifiers"
 msgstr ""
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, gcc-internal-format
 msgid "too many %<close%> modifiers"
 msgstr ""
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<present%> modifiers"
 msgstr "υπερβολικά πολλά αρχεία εισόδου"
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "μη έγκυρος χρήστης"
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr ""
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, gcc-internal-format
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr ""
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, gcc-internal-format
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr ""
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
@@ -48701,88 +48724,88 @@ msgstr "Μη έγκυρη ημερομηνία `%s'."
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr ""
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, fuzzy, gcc-internal-format
 msgid "expected an OpenACC clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, fuzzy, gcc-internal-format
 msgid "expected an OpenMP clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr ""
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr ""
@@ -48797,7 +48820,7 @@ msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 msgid "expected function name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "Το `%s' δεν είναι κατάλογος."
@@ -48807,22 +48830,22 @@ msgstr "Το `%s' δεν είναι κατάλογος."
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
@@ -48848,7 +48871,7 @@ msgstr ""
 msgid "modified here"
 msgstr ""
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, gcc-internal-format
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
 msgstr ""
@@ -48888,110 +48911,110 @@ msgstr ""
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr ""
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr ""
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr ""
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, fuzzy, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, fuzzy, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, gcc-internal-format
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, gcc-internal-format
 msgid "%qs clause requires %qs clause"
 msgstr ""
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, gcc-internal-format
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr ""
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, gcc-internal-format
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr ""
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr ""
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, fuzzy, gcc-internal-format
 msgid "unexpected %<else%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, gcc-internal-format
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr ""
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr ""
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
@@ -49001,27 +49024,27 @@ msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr ""
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr ""
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr ""
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr ""
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -49031,163 +49054,163 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr ""
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr ""
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr ""
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, fuzzy, gcc-internal-format
 msgid "not enough nested loops"
 msgstr "εμφάνιση πληροφοριών προόδου"
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "αναμενόταν ')'\n"
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr ""
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, fuzzy, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, gcc-internal-format
 msgid "unknown selector %qs for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, gcc-internal-format
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr ""
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, gcc-internal-format
 msgid "%<score%> argument must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, gcc-internal-format
 msgid "%<score%> argument must be non-negative"
 msgstr ""
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, fuzzy, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
@@ -49195,290 +49218,290 @@ msgstr ""
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> selector is not supported yet"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, gcc-internal-format
 msgid "expected context selector set name"
 msgstr ""
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr ""
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, fuzzy, gcc-internal-format
 msgid "variant %qD is not a function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, gcc-internal-format
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, gcc-internal-format
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr ""
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr ""
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr ""
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, gcc-internal-format
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr ""
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, gcc-internal-format
 msgid "expected %<declare%> or %<assumes%>"
 msgstr ""
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, gcc-internal-format
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, fuzzy, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr ""
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, fuzzy, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr ""
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr ""
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, gcc-internal-format
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, gcc-internal-format
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, fuzzy, gcc-internal-format
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, fuzzy, gcc-internal-format
 msgid "expected %qs or %qs"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, gcc-internal-format
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr ""
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr ""
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, fuzzy, gcc-internal-format
 msgid "expected at least one assumption clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, fuzzy, gcc-internal-format
 msgid "expected directive name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr ""
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, fuzzy, gcc-internal-format
 msgid "unknown assumption clause %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, fuzzy, gcc-internal-format
 msgid "expected assumption clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, gcc-internal-format
 msgid "no closing brace"
 msgstr ""
@@ -49623,7 +49646,7 @@ msgstr "Δεν μπορεί να καθοριστεί το όνομα του σ
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "το πέρασμα του ορίσματος %d του δείκτη στη συνάρτηση"
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr ""
@@ -49653,7 +49676,7 @@ msgstr ""
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -49766,17 +49789,17 @@ msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζε
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "πολύ λίγα ορίσματα"
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, fuzzy, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, fuzzy, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, fuzzy, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
@@ -49801,7 +49824,7 @@ msgstr ""
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -50094,7 +50117,7 @@ msgstr ""
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
@@ -50273,7 +50296,7 @@ msgstr ""
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -50473,12 +50496,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -50488,7 +50511,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr ""
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "μη έγκυρη ώρα της μέρας"
@@ -50519,7 +50542,7 @@ msgstr "μη τερματιζμένο αλφαριθμητικό σταθερά
 msgid "initializer element is not computable at load time"
 msgstr ""
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
@@ -50534,7 +50557,7 @@ msgstr "ακολουθούν σκουπίδια στο τέλος της γρα
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
@@ -50624,7 +50647,7 @@ msgstr ""
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
@@ -50664,7 +50687,7 @@ msgstr ""
 msgid "computed goto must be pointer type"
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
@@ -50719,7 +50742,7 @@ msgstr ""
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -50765,27 +50788,27 @@ msgstr ""
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr ""
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr ""
@@ -50857,29 +50880,29 @@ msgstr ""
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr ""
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
@@ -50890,85 +50913,85 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr ""
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, fuzzy, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr ""
@@ -50978,17 +51001,17 @@ msgstr ""
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr ""
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, fuzzy, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
@@ -50998,32 +51021,32 @@ msgstr ""
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, fuzzy, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr ""
@@ -51053,7 +51076,7 @@ msgstr ""
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "Οι ορισμοί πηγή βρίσκονται στο ΑΡΧΕΙΟ"
@@ -51063,17 +51086,17 @@ msgstr "Οι ορισμοί πηγή βρίσκονται στο ΑΡΧΕΙΟ"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
 msgstr ""
@@ -51088,23 +51111,23 @@ msgstr ""
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, gcc-internal-format
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -51116,32 +51139,32 @@ msgstr ""
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
@@ -51161,7 +51184,7 @@ msgstr ""
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr ""
@@ -51171,7 +51194,7 @@ msgstr ""
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr ""
@@ -51181,76 +51204,76 @@ msgstr ""
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr ""
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, fuzzy, gcc-internal-format
 msgid "unsupported map expression %qE"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
@@ -51265,22 +51288,22 @@ msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr ""
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
@@ -51290,38 +51313,38 @@ msgstr "το `%s' είναι πρόγονος του `%s'"
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
@@ -51590,14 +51613,14 @@ msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζε
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -51915,37 +51938,37 @@ msgstr ""
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no match for call to %<%T::operator[] (%A)%>"
@@ -51953,425 +51976,425 @@ msgstr "δεν ταιριάζει συνάρτηση για την κλήση σ
 
 # src/getopt.c:813
 # src/getopt.c:813
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, fuzzy, gcc-internal-format
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr "%s: η επιλογή `-W %s' είναι διφορούμενη\n"
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr ""
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, fuzzy, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "το `%s' είναι μη-προσπελάσιμο"
 
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, fuzzy, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, fuzzy, gcc-internal-format
 msgid "  declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, fuzzy, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr ""
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr ""
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 #, fuzzy
 msgid "invalid conversion from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 #, fuzzy
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "δεν είναι δυνατό να μετανομαστεί το `.' ή το `..'"
 
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, fuzzy, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, fuzzy, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "δεν είναι δυνατό να μετανομαστεί το `.' ή το `..'"
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr ""
 
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, fuzzy, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, fuzzy, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "Κακή αίτηση παραμέτρων"
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, gcc-internal-format
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr ""
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 #, fuzzy
 msgid "cannot convert %qH to %qI"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "δεν ταιριάζει συνάρτηση για την κλήση στο %<%T::%s(%A)%#V%>"
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "δεν ταιριάζει συνάρτηση για την κλήση στο %<%T::%s(%A)%#V%>"
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%s(%A)%>"
@@ -52379,106 +52402,106 @@ msgstr "δεν ταιριάζει συνάρτηση για την κλήση σ
 
 # src/getopt.c:813
 # src/getopt.c:813
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "η κλήση της υπερφορτωμένης %<%s(%A)%> είναι διφορούμενη"
 
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, gcc-internal-format
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr ""
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, fuzzy, gcc-internal-format
 msgid "try making the operator a %<const%> member function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 #, fuzzy
 msgid "  for conversion from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr ""
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr ""
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, fuzzy, gcc-internal-format
 msgid "possibly dangling reference to a temporary"
 msgstr "xdr_reference: η μνήμη εξαντλήθηκε\n"
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr ""
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, fuzzy, gcc-internal-format
 msgid "explicit conversion function was not considered"
 msgstr "Οι ορισμοί πηγή βρίσκονται στο ΑΡΧΕΙΟ"
@@ -52524,7 +52547,7 @@ msgid "%q#D cannot be overloaded with %q#D"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "αυτός είναι ο πρώτος ορισμός"
@@ -52947,7 +52970,7 @@ msgstr "μη έγκυρη ώρα της μέρας"
 msgid "next member %q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "κανένας ορισμός του `UNDEFINED'"
@@ -53078,7 +53101,7 @@ msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
@@ -53119,7 +53142,7 @@ msgstr ""
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr ""
@@ -53137,7 +53160,7 @@ msgstr ""
 msgid "%q+E is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -53158,7 +53181,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
@@ -53206,7 +53229,7 @@ msgstr "το `%s' είναι πρόγονος του `%s'"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
@@ -53335,18 +53358,18 @@ msgstr ""
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -53354,469 +53377,469 @@ msgstr "Δεν μπορεί να καθοριστεί το όνομα του σ
 msgid "%qE is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr ""
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr ""
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr ""
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr ""
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr ""
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr ""
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr ""
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr ""
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, fuzzy, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, fuzzy, gcc-internal-format
 msgid "allocated here"
 msgstr "διπλό κλειδί"
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
 msgstr ""
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "το `%s' είναι μη-προσπελάσιμο"
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, gcc-internal-format
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, gcc-internal-format
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, gcc-internal-format
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr ""
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr ""
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr ""
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, fuzzy, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, fuzzy, gcc-internal-format
 msgid "use of %qD"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr ""
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr ""
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr ""
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr ""
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, gcc-internal-format
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, gcc-internal-format
 msgid "pointed-to object declared here"
 msgstr ""
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr ""
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr ""
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, fuzzy, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, fuzzy, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, gcc-internal-format
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, fuzzy, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, fuzzy, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr ""
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, fuzzy, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "Μη ορισμένο όνομα %s"
@@ -54530,7 +54553,7 @@ msgstr "Λείπει παράμετρος για `%s'"
 msgid "no suspend point info for %qD"
 msgstr "Ο αντιτοποθετητής επιφάνειας έχει τεθεί περισσότερο από μια φορά για το `%s'"
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -54550,23 +54573,23 @@ msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr ""
@@ -54586,68 +54609,68 @@ msgstr ""
 msgid "%qD was promoted to an immediate function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, fuzzy, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, fuzzy, gcc-internal-format
 msgid "call to consteval function %qE is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, fuzzy, gcc-internal-format
 msgid "pack expansion of %qE attribute"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, gcc-internal-format
 msgid "use fold expression in the attribute argument instead"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
@@ -54692,7 +54715,7 @@ msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαρ
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, fuzzy, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
@@ -55079,7 +55102,7 @@ msgstr "αυτός είναι ο πρώτος ορισμός"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "αυτός είναι ο πρώτος ορισμός"
@@ -55220,8 +55243,8 @@ msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'
 msgid "%q#D previously defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, fuzzy, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -55296,52 +55319,37 @@ msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 msgid "previous specification in %q#D here"
 msgstr "%s: Μη έγκυρη ρύθμιση `%s'.\n"
 
-#: cp/decl.cc:2285
-#, fuzzy, gcc-internal-format
-msgid "declaration %qD conflicts with builtin"
-msgstr "αυτονόητη διακύρηξη της συνάρτησης `%#D'"
-
-#: cp/decl.cc:2288
-#, fuzzy, gcc-internal-format
-msgid "declaration %qD conflicts with import"
-msgstr "αυτονόητη διακύρηξη της συνάρτησης `%#D'"
-
-#: cp/decl.cc:2289
-#, fuzzy, gcc-internal-format
-msgid "import declared %q#D here"
-msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, fuzzy, gcc-internal-format
 msgid "conflicting exporting for declaration %qD"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, fuzzy, gcc-internal-format
 msgid "previously declared here without exporting"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr ""
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, fuzzy, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
@@ -55354,44 +55362,44 @@ msgstr "αυτός είναι ο πρώτος ορισμός"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, fuzzy, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "σφάλμα ταιριάσματος τύπου με προηγούμενη αυτονόητη διακύρηξη"
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, fuzzy, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -55399,2510 +55407,2510 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, fuzzy, gcc-internal-format
 msgid "jump to label %qD"
 msgstr "διπλό κλειδί"
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr ""
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr ""
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, gcc-internal-format
 msgid "  from here"
 msgstr ""
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
 # src/request.c:263
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr ""
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr ""
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, fuzzy, gcc-internal-format
 msgid "  enters statement expression"
 msgstr "Πρόωρο τέλος της κανονικής έκφρασης"
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, gcc-internal-format
 msgid "  enters %<consteval if%> statement"
 msgstr ""
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, fuzzy, gcc-internal-format
 msgid "  does not destroy %qD"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, gcc-internal-format
 msgid "  does not clean up handled exception"
 msgstr ""
 
 # src/request.c:263
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, fuzzy, gcc-internal-format
 msgid "%qD is a function, not a type"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr ""
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr ""
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "Δεν ήταν δυνατή η εύρεση ετικέττας για μεταγωγή στο `%s'"
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
 # src/request.c:263
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr ""
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "σφάλμα κατά το κλείσιμο της εισόδου `%s'"
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr ""
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "μη αρχικοποιημένη σταθερά const %qD"
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "υπερβολικά πολλά αρχεία εισόδου"
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, fuzzy, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, fuzzy, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, fuzzy, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, fuzzy, gcc-internal-format
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, fuzzy, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "Δεν είναι δυνατή η εκχώρηση της ζητηθήσας διεύθυνσης"
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "σφάλμα κατά το κλείσιμο της εισόδου `%s'"
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "συνεχίζεται στο τμήμα"
 
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "συνεχίζεται στο τμήμα"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, fuzzy, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, fuzzy, gcc-internal-format
 msgid "constrained non-template friend declaration must be a definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, fuzzy, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, gcc-internal-format
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, gcc-internal-format
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, fuzzy, gcc-internal-format
 msgid "explicit object parameter declared here"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr ""
 
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> πρέπει να επιστρέψει %<int%>"
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr ""
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr ""
 
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "μη έγκυρος δεύτερος τελεστής σε κατάσταση συμβατότητας `%s'"
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr ""
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr ""
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr ""
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr ""
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, fuzzy, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, fuzzy, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr "Δεν υπάρχουν αρχεία εισόδου"
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "μη ορισμένο"
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, gcc-internal-format
 msgid "%qs specified with typedef-name %qD"
 msgstr ""
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "μη ορισμένο"
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr ""
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, fuzzy, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr ""
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, fuzzy, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr ""
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, gcc-internal-format
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, gcc-internal-format
 msgid "a function type cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, gcc-internal-format
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, gcc-internal-format
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr ""
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, gcc-internal-format
 msgid "the type of an explicit object member function is a regular function type"
 msgstr ""
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "valid explicit object parameter declared here"
 msgstr ""
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, fuzzy, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, fuzzy, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, gcc-internal-format
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr ""
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be an explicit object member function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr ""
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "Υπάρχει αντικείμενο με το ίδιο όνομα"
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "μη έγκυρη ώρα της μέρας"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%#D'"
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
 # src/shred.c:1134
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -57914,117 +57922,102 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "έχουν παραληφθεί ορίσματα"
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, fuzzy, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, fuzzy, gcc-internal-format
-msgid "cannot declare %qD in a different module"
-msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
-
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, fuzzy, gcc-internal-format
-msgid "previously declared here"
-msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/decl.cc:16984
-#, fuzzy, gcc-internal-format
-msgid "cannot declare %qD in different module"
-msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -58033,82 +58026,82 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, fuzzy, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, fuzzy, gcc-internal-format
 msgid "using %qs"
 msgstr "σφάλμα ανάγνωσης %s"
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -58163,7 +58156,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -58173,7 +58166,7 @@ msgstr "δημιουργία αρχείου `%s'\n"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -58358,64 +58351,64 @@ msgstr ""
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr ""
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, gcc-internal-format
 msgid "%qT has a base %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, gcc-internal-format
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, gcc-internal-format
 msgid "%qT has a base %qT which has internal linkage"
 msgstr ""
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, gcc-internal-format
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr ""
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but not defined"
 msgstr ""
@@ -58424,104 +58417,104 @@ msgstr ""
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr ""
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, fuzzy, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, gcc-internal-format
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr ""
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q#D"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, gcc-internal-format
 msgid "...following parameter %P which has a default argument"
 msgstr ""
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, gcc-internal-format
 msgid "implicitly-declared %qD is deprecated"
 msgstr ""
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr ""
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -58629,7 +58622,7 @@ msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
@@ -58639,7 +58632,7 @@ msgstr "δεν είστε μέλος της ομάδας `%s'"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
@@ -58664,47 +58657,47 @@ msgstr ""
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr ""
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, gcc-internal-format
 msgid "  in thrown expression"
 msgstr ""
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, gcc-internal-format
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr ""
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, gcc-internal-format
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr ""
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, gcc-internal-format
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr ""
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, gcc-internal-format
 msgid "for type %qT"
 msgstr ""
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, gcc-internal-format
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr ""
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr ""
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
 msgstr ""
@@ -58973,12 +58966,12 @@ msgstr "Το `%s' δεν είναι κατάλογος."
 msgid "type %qT is not a direct base of %qT"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -58993,12 +58986,12 @@ msgstr ""
 msgid "invalid pointer to bit-field %qD"
 msgstr "ακατάλληλος τύπος δικτύου :`%s'\n"
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
@@ -59193,52 +59186,52 @@ msgstr ""
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, fuzzy, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, fuzzy, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
@@ -59611,223 +59604,268 @@ msgstr ""
 msgid "encapsulation is malformed"
 msgstr ""
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, fuzzy, gcc-internal-format
 msgid "conflicting global module declaration %#qD"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, fuzzy, gcc-internal-format
 msgid "existing declaration %#qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, fuzzy, gcc-internal-format
 msgid "existing definition %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, fuzzy, gcc-internal-format
 msgid "... this enumerator %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, fuzzy, gcc-internal-format
 msgid "enumerator %qD does not match ..."
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr ""
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr ""
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr ""
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, gcc-internal-format
 msgid "recursive lazy load"
 msgstr ""
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr ""
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, fuzzy, gcc-internal-format
 msgid "module %qs declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, gcc-internal-format
 msgid "indirect import %qs is not already loaded"
 msgstr ""
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr ""
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr ""
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, fuzzy, gcc-internal-format
 msgid "macro definitions of %qE corrupted"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, fuzzy, gcc-internal-format
 msgid "inconsistent imported macro definition %qE"
 msgstr "Μεταγλωττισμός προδιαγραφών τοπικών ρυθμίσεων"
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr ""
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr ""
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, fuzzy, gcc-internal-format
 msgid "compiled module file is %qs"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
 
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, gcc-internal-format, gfc-internal-format
 msgid "compiled module is %sversion %s"
 msgstr ""
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, gcc-internal-format, gfc-internal-format
 msgid "compiler is %sversion %s%s%s"
 msgstr ""
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, fuzzy, gcc-internal-format
 msgid "module %qs found"
 msgstr "το αρχείο χάρτη χαρακτήρων `%s' δεν βρέθηκε"
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr ""
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr ""
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr ""
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr ""
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, gcc-internal-format
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr ""
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, fuzzy, gcc-internal-format
 msgid "fixed tree mismatch"
 msgstr "Κακοσυνταίριασμα τύπων καταχώρησης/πίνακα"
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, fuzzy, gcc-internal-format
 msgid "interface partition is not exported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module cluster %u: %s"
 msgstr ""
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module: %s"
 msgstr ""
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr ""
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr ""
 
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr ""
 
-#: cp/module.cc:19283
+#: cp/module.cc:19117
+#, fuzzy, gcc-internal-format
+msgid "declaration %qD conflicts with builtin"
+msgstr "αυτονόητη διακύρηξη της συνάρτησης `%#D'"
+
+#: cp/module.cc:19122
+#, fuzzy, gcc-internal-format
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr "αυτονόητη διακύρηξη της συνάρτησης `%#D'"
+
+#: cp/module.cc:19125
+#, gcc-internal-format
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr ""
+
+#: cp/module.cc:19130
+#, gcc-internal-format
+msgid "import declared attached to module %qs"
+msgstr ""
+
+#: cp/module.cc:19134
+#, gcc-internal-format
+msgid "import declared in global module"
+msgstr ""
+
+#: cp/module.cc:19140
+#, fuzzy, gcc-internal-format
+msgid "conflicting declaration of %qD in module %qs"
+msgstr "Μη έγκυρη ανταλλαγή"
+
+#: cp/module.cc:19143
+#, fuzzy, gcc-internal-format
+msgid "conflicting declaration of %qD in global module"
+msgstr "Μη έγκυρη ανταλλαγή"
+
+#: cp/module.cc:19148
+#, fuzzy, gcc-internal-format
+msgid "previously declared in module %qs"
+msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
+
+#: cp/module.cc:19152
+#, fuzzy, gcc-internal-format
+msgid "previously declared in global module"
+msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
+
+#: cp/module.cc:19404
 #, fuzzy, gcc-internal-format
 msgid "reading CMI %qs"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, gcc-internal-format
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, gcc-internal-format
 msgid "during load of pendings for %<%E%s%E%>"
 msgstr ""
@@ -59839,394 +59877,394 @@ msgstr ""
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr ""
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, gcc-internal-format
 msgid "module already declared"
 msgstr ""
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, gcc-internal-format
 msgid "module already imported"
 msgstr ""
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, gcc-internal-format
 msgid "module %qs imported here"
 msgstr ""
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown Compiled Module Interface: %s"
 msgstr ""
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr ""
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr ""
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr ""
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, gcc-internal-format
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr ""
 
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, gcc-internal-format
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr ""
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr ""
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr ""
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, gcc-internal-format
 msgid "you should use the %<-%s%> option"
 msgstr ""
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, fuzzy, gcc-internal-format
 msgid "invalid header name %qs"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, fuzzy, gcc-internal-format
 msgid "invalid module name %qs"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr ""
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, fuzzy, gcc-internal-format
 msgid "writing CMI %qs"
 msgstr "σφάλμα εγγραφής %s"
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, gcc-internal-format
 msgid "not writing module %qs due to errors"
 msgstr ""
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to write compiled module: %s"
 msgstr ""
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, fuzzy, gcc-internal-format
 msgid "unknown header kind %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, gcc-internal-format
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr ""
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "σφάλμα ταιριάσματος τύπου με προηγούμενη αυτονόητη διακύρηξη"
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, fuzzy, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, fuzzy, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, fuzzy, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
 # src/request.c:37
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s: %s: "
 
 # src/request.c:37
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, fuzzy, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, gcc-internal-format
 msgid "exporting %q#D that does not have external linkage"
 msgstr ""
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here with no linkage"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here with internal linkage"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here with module linkage"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, fuzzy, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, fuzzy, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, fuzzy, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a direct base of %qT"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr ""
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr ""
 
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, fuzzy, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, fuzzy, gcc-internal-format
 msgid "it was later defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, fuzzy, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, gcc-internal-format
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "δεν είναι δυνατό να μετανομαστεί το `.' ή το `..'"
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, fuzzy, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -60251,7 +60289,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -60497,7 +60535,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
@@ -60677,7 +60715,7 @@ msgstr ""
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, fuzzy, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
@@ -60732,7 +60770,7 @@ msgstr ""
 msgid "template-id not allowed for destructor in C++20"
 msgstr ""
 
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, gcc-internal-format
 msgid "remove the %qs"
 msgstr ""
@@ -60752,7 +60790,7 @@ msgstr ""
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -60802,7 +60840,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "λάθος αριθμός ορισμάτων"
@@ -60837,7 +60875,7 @@ msgstr ""
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr ""
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "μη έγκυρος χρήστης"
@@ -60862,7 +60900,7 @@ msgstr ""
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
@@ -61012,8 +61050,8 @@ msgstr ""
 msgid "capture of non-variable %qE"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -61053,7 +61091,7 @@ msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr ""
@@ -61178,7 +61216,7 @@ msgstr ""
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
@@ -61240,7 +61278,7 @@ msgstr "μη πλήρης εγγραφή"
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
@@ -61266,7 +61304,7 @@ msgstr ""
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
@@ -61547,12 +61585,12 @@ msgstr ""
 msgid "cannot expand initializer for member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -62192,7 +62230,7 @@ msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 msgid "%qT not permitted in template argument"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
@@ -62371,12 +62409,12 @@ msgstr "κανένας ορισμός του `UNDEFINED'"
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, gcc-internal-format
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr ""
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
@@ -62578,37 +62616,37 @@ msgstr ""
 msgid "expression must be enclosed in parentheses"
 msgstr ""
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr ""
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, fuzzy, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, fuzzy, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
@@ -62617,439 +62655,439 @@ msgstr "διπλό όνομα χαρακτήρα `%s'"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, gcc-internal-format
 msgid "template-id not allowed for constructor in C++20"
 msgstr ""
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, fuzzy, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "Ο έλεγχος μονοπατιού για το `%s' βρήκε `%s'"
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, fuzzy, gcc-internal-format
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD specifier"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, gcc-internal-format
 msgid "%qD specifier conflicts with %qs"
 msgstr ""
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, gcc-internal-format
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr ""
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, fuzzy, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, fuzzy, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, fuzzy, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "μη τερματιζόμενο όνομα βάρους"
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, fuzzy, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, fuzzy, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "Προσδιοριστής αφαιρέθηκε"
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr ""
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr ""
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "Το `%s' δεν είναι κατάλογος."
@@ -63058,12 +63096,12 @@ msgstr "Το `%s' δεν είναι κατάλογος."
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr ""
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
@@ -63073,133 +63111,133 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr ""
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr ""
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, fuzzy, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr ""
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, gcc-internal-format
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr ""
 
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, gcc-internal-format
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr ""
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, fuzzy, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr ""
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -63229,7 +63267,7 @@ msgstr ""
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
@@ -63244,171 +63282,171 @@ msgstr "κανένας ορισμός του `UNDEFINED'"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, fuzzy, gcc-internal-format
 msgid "from definition of %q#D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
 # src/request.c:37
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, fuzzy, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s: %s"
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, fuzzy, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "Ο έλεγχος μονοπατιού για το `%s' βρήκε `%s'"
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, fuzzy, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, fuzzy, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, fuzzy, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "Το `%s' δεν είναι κατάλογος."
@@ -63421,154 +63459,154 @@ msgstr "Το `%s' δεν είναι κατάλογος."
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "Στη συνάρτηση μέλος `%s':"
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, fuzzy, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, fuzzy, gcc-internal-format
 msgid "        %qD"
 msgstr "        `%D'"
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr "        `%D'"
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, fuzzy, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "%s' δεν είναι ισχύων θετικός ακέραιος."
 msgstr[1] "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -63577,47 +63615,47 @@ msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, fuzzy, gcc-internal-format
 msgid "template class without a name"
 msgstr "μη τερματιζόμενο όνομα βάρους"
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -63627,506 +63665,506 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, fuzzy, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  αλλά %d απαιτούνται"
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD with different constraints"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "διπλό όνομα χαρακτήρα `%s'"
 msgstr[1] "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 msgstr[1] "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, fuzzy, gcc-internal-format
 msgid "redeclared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr ""
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D with different constraints"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, fuzzy, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr ""
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, fuzzy, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr ""
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr ""
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, gcc-internal-format, gfc-internal-format
 msgid "mismatched argument pack lengths (%d vs %d)"
 msgstr ""
@@ -64144,303 +64182,303 @@ msgstr ""
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr ""
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr ""
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "έχει παραληφθεί η λίστα με τα πεδία"
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
 # src/request.c:37
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 #, fuzzy
 msgid "%s %#qS"
 msgstr "%s: %s"
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, fuzzy, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "Ο έλεγχος μονοπατιού για το `%s' βρήκε `%s'"
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, fuzzy, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
@@ -64452,165 +64490,165 @@ msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, fuzzy, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr ""
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, fuzzy, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
@@ -64817,632 +64855,632 @@ msgstr ""
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr ""
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, fuzzy, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, fuzzy, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, fuzzy, gcc-internal-format
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, gcc-internal-format
 msgid "use explicit object parameter %qs instead"
 msgstr ""
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, gcc-internal-format
 msgid "name the explicit object parameter"
 msgstr ""
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, fuzzy, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> before it is valid"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> after it is valid"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, fuzzy, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, gcc-internal-format
 msgid "%<auto{x}%> cannot be constrained"
 msgstr ""
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, gcc-internal-format
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr ""
 
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, fuzzy, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, fuzzy, gcc-internal-format
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr ""
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, fuzzy, gcc-internal-format
 msgid "%<__type_pack_element%> index is out of range"
 msgstr "%s: αριθμός γραμμής έξω από τα όρια"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, gcc-internal-format
 msgid "pointer-to-member mapping %qE not supported"
 msgstr ""
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, gcc-internal-format
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr ""
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr ""
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr ""
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr ""
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr ""
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr ""
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr ""
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "αποτυχία κατά την εγγραφή δεδομένων για την κατηγορία `%s'"
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, gcc-internal-format
 msgid "%<filter%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr ""
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr ""
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr ""
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr ""
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr ""
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, gcc-internal-format
 msgid "static assertion failed: %.*s"
 msgstr ""
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, fuzzy, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr ""
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr ""
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr ""
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "Λείπει παράμετρος για `%s'"
@@ -65450,1165 +65488,1165 @@ msgstr "Λείπει παράμετρος για `%s'"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, fuzzy, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, fuzzy, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, fuzzy, gcc-internal-format
 msgid " declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, fuzzy, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, fuzzy, gcc-internal-format
 msgid "%qD is not public"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, fuzzy, gcc-internal-format
 msgid "%qD is mutable"
 msgstr "το `%s' είναι μη-προσπελάσιμο"
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, fuzzy, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr ""
 
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr ""
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr ""
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, fuzzy, gcc-internal-format
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr ""
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr ""
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr ""
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, gcc-internal-format
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr ""
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr ""
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr ""
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, fuzzy, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, fuzzy, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "το αρχείο δεδομένων προφίλ `%s' δεν ταιριάζει με το διαμοιραζόμενο αντικείμενο `%s'"
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 # src/main.c:697 src/main.c:751
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "Άγνωστη γλώσσα `%s'"
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr ""
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "πολύ λίγα ορίσματα"
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "πολύ λίγα ορίσματα"
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "πάρα πολλά ορίσματα"
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "πολύ λίγα ορίσματα"
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, gcc-internal-format
 msgid "the address %qE will never be NULL"
 msgstr ""
 
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr ""
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr ""
 
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, fuzzy, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr ""
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr ""
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, fuzzy, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr ""
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχείο fifo `%s'"
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr ""
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr ""
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, gcc-internal-format
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr ""
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr ""
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχείο fifo `%s'"
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr ""
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr ""
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, fuzzy, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, fuzzy, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, fuzzy, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 #, fuzzy
 msgid "converting from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, fuzzy, gcc-internal-format
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr ""
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, fuzzy, gcc-internal-format
 msgid "moving %qE of type %qT to itself"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 #, fuzzy
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 #, fuzzy
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 #, fuzzy
 msgid "cannot convert %qH to %qI in return"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 #, fuzzy
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, fuzzy, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "xdr_reference: η μνήμη εξαντλήθηκε\n"
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, fuzzy, gcc-internal-format
 msgid "returning pointer to temporary"
 msgstr "xdr_reference: η μνήμη εξαντλήθηκε\n"
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, fuzzy, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "Έχει παραληφθεί εντολή"
 
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, fuzzy, gcc-internal-format
 msgid "redundant move in initialization"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, fuzzy, gcc-internal-format
 msgid "not eliding copy on return from %qD"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr ""
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, fuzzy, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "μη έγκυρος χρήστης"
@@ -66829,157 +66867,157 @@ msgstr ""
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr ""
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, gcc-internal-format
 msgid "initializer-string for %qT is too long"
 msgstr ""
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, gcc-internal-format
 msgid "remove %<{ }%> around initializer"
 msgstr ""
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "το αρχείο δεδομένων προφίλ `%s' δεν ταιριάζει με το διαμοιραζόμενο αντικείμενο `%s'"
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr ""
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "μη πλήρης εγγραφή"
@@ -67962,7 +68000,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
@@ -69286,7 +69324,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -69501,7 +69539,7 @@ msgstr ""
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr ""
@@ -70309,7 +70347,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
@@ -71117,12 +71155,12 @@ msgstr ""
 msgid "are_identical_variables: Bad type"
 msgstr ""
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr ""
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr ""
@@ -71372,273 +71410,273 @@ msgstr ""
 msgid "check_init_expr(): Unknown expression type"
 msgstr ""
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr ""
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr ""
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, gcc-internal-format
 msgid "Specification function %qs at %L must be PURE"
 msgstr ""
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr ""
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, gcc-internal-format
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr ""
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr ""
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr ""
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, gcc-internal-format
 msgid "check_restricted(): Unknown expression type"
 msgstr ""
 
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, gcc-internal-format
 msgid "Function %qs at %L must be PURE"
 msgstr ""
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr ""
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr ""
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr ""
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr ""
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr ""
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal assignment to external procedure at %L"
 msgstr ""
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr ""
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "%s: Μη έγκυρη ρύθμιση `%s'.\n"
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr ""
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr ""
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr ""
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
@@ -71646,192 +71684,192 @@ msgstr ""
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr ""
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr ""
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, gcc-internal-format, gfc-internal-format
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr ""
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr ""
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr ""
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr ""
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, gcc-internal-format
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, gcc-internal-format
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr ""
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -71852,8 +71890,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -71933,7 +71971,7 @@ msgstr ""
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -72068,12 +72106,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -72946,7 +72984,7 @@ msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζε
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
@@ -73497,7 +73535,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -73663,6 +73701,11 @@ msgstr ""
 msgid "check_charlen_present(): length not set"
 msgstr ""
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr ""
+
 #: fortran/match.cc:118
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
@@ -74066,7 +74109,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr ""
@@ -74589,82 +74632,82 @@ msgstr ""
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr ""
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr ""
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr ""
 
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr ""
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, fuzzy, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "το αρχείο δεδομένων προφίλ `%s' δεν ταιριάζει με το διαμοιραζόμενο αντικείμενο `%s'"
@@ -76080,8 +76123,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -78447,12 +78490,12 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -78574,7 +78617,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -78973,279 +79016,284 @@ msgstr ""
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, gcc-internal-format
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
 # src/shred.c:1134
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, fuzzy, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "Invalid array reference at %L"
+msgstr "Μη έγκυρη πισω-παραπομπή"
+
+#: fortran/resolve.cc:6433
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -79254,284 +79302,284 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -79539,212 +79587,212 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, gcc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -79752,1001 +79800,1001 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "σχετική θέση αρχείου είναι εκτός ορίων"
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
 # src/request.c:37
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fstat %s"
 msgid "%s at %L"
 msgstr "fstat %s"
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr ""
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr ""
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr ""
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant character length at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr ""
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -81290,332 +81338,332 @@ msgstr ""
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, gcc-internal-format
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr ""
+
+#: fortran/symbol.cc:508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr ""
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, gcc-internal-format
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr ""
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, gcc-internal-format
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr ""
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr ""
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr ""
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr ""
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr ""
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr ""
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr ""
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr ""
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr ""
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -81645,24 +81693,24 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -81850,38 +81898,38 @@ msgstr ""
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
 # src/grep.c:1133
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, fuzzy, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "άγνωστη μέθοδος καταλόγων"
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -81892,17 +81940,17 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr ""
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr ""
@@ -82042,7 +82090,7 @@ msgstr ""
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr ""
@@ -82411,6 +82459,11 @@ msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 msgid "function %qD redeclared as variable"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
+#: lto/lto-symtab.cc:865
+#, fuzzy, gcc-internal-format
+msgid "previously declared here"
+msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
+
 #: lto/lto.cc:174
 #, gcc-internal-format
 msgid "%<lto_obj_file_open()%> failed"
@@ -83657,7 +83710,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr ""
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, gcc-internal-format
 msgid "non-objective-c type %qT cannot be caught"
 msgstr ""
@@ -83667,7 +83720,7 @@ msgstr ""
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr ""
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, gcc-internal-format
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
 msgstr ""
diff --git a/gcc/po/es.po b/gcc/po/es.po
index 9da128eb902..4a18892d9f3 100644
--- a/gcc/po/es.po
+++ b/gcc/po/es.po
@@ -42,7 +42,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 10.1-b20200209\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
 "PO-Revision-Date: 2020-03-22 16:48+0100\n"
 "Last-Translator: Antonio Ceballos Roa <aceballos@gmail.com>\n"
 "Language-Team: Spanish <es@tp.org.es>\n"
@@ -431,7 +431,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr "no especifique -march=... y -mcpu=... al mismo tiempo"
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 msgid "shared and mdll are not compatible"
 msgstr "shared y mdll no son compatibles"
 
@@ -19749,16 +19749,16 @@ msgstr "no se reconoce la insn:"
 msgid "insn does not satisfy its constraints:"
 msgstr "la insn no satisface sus restricciones:"
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "creado y usado con diferentes opciones de '%s'"
 
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "creado y usado con diferentes opciones de %<-fpic%>"
 
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 msgid "created and used with different settings of %<-fpie%>"
 msgstr "creado y usado con diferentes opciones de %<-fpie%>"
 
@@ -20079,7 +20079,7 @@ msgstr "modificador de longitud en formato strfmon"
 msgid "<command-line>"
 msgstr "<línea-de-órdenes>"
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "no se admite el operando para el código '%c'"
@@ -20098,9 +20098,9 @@ msgstr "operando no válido para '%%%c'"
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, c-format
 msgid "invalid vector constant"
 msgstr "constante de vector no válida"
@@ -20122,7 +20122,7 @@ msgstr "coma flotante incompatible / operando de registro de vector para '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "coma flotante incompatible / operando de registro de vector para '%%%c'"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, c-format
 msgid "missing operand"
 msgstr "falta un operando"
@@ -20153,93 +20153,93 @@ msgstr "modo de direccionamiento no válido"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "operandos no válidos en la operación binaria"
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "se usó '%%&' sin ninguna referencia TLS dinámica local"
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, c-format
 msgid "invalid %%J value"
 msgstr "valor %%J no válido"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, c-format
 msgid "invalid %%r value"
 msgstr "valor %%r no válido"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, c-format
 msgid "invalid %%R value"
 msgstr "valor %%R no válido"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, c-format
 msgid "invalid %%N value"
 msgstr "valor %%N no válido"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, c-format
 msgid "invalid %%P value"
 msgstr "valor %%P no válido"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, c-format
 msgid "invalid %%h value"
 msgstr "valor %%h no válido"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, c-format
 msgid "invalid %%L value"
 msgstr "valor %%L no válido"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, c-format
 msgid "invalid %%m value"
 msgstr "valor %%m no válido"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, c-format
 msgid "invalid %%M value"
 msgstr "valor %%M no válido"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, c-format
 msgid "invalid %%U value"
 msgstr "valor %%U no válido"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, c-format
 msgid "invalid %%s value"
 msgstr "valor %%s no válido"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, c-format
 msgid "invalid %%C value"
 msgstr "valor %%C no válido"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, c-format
 msgid "invalid %%E value"
 msgstr "valor %%E no válido"
 
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "reubicación unspec desconocida"
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, c-format
 msgid "invalid %%xn code"
 msgstr "código %%xn no válido"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, c-format
 msgid "invalid operand address"
 msgstr "dirección de operando no válida"
@@ -20335,35 +20335,35 @@ msgstr "UNSPEC no válido como operando: %d"
 msgid "unrecognized supposed constant"
 msgstr "no se reconoce la constante supuesta"
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, c-format
 msgid "invalid shift operand"
 msgstr "operando de desplazamiento no válido"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "instrucción de predicado Thumb"
 
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instrucción de predicado en una secuencia condicional"
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "No se admite el operando para el código '%c'"
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -20371,113 +20371,113 @@ msgstr "No se admite el operando para el código '%c'"
 msgid "invalid operand for code '%c'"
 msgstr "operando no válido para el código '%c'"
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, c-format
 msgid "instruction never executed"
 msgstr "la instrucción nunca se ejecuta"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "código de formato Maverick obsoleto '%c'"
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "conversión no válida desde el tipo %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "conversión no válida al tipo %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "operación no permitida con el tipo %<bfloat16_t%>"
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "el operando de dirección requiere una restricción para los registros X, Y, o Z"
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "los operandos para %T/%t deben ser reg + const_int:"
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 msgid "bad address, not an I/O address:"
 msgstr "dirección errónea, no es una dirección de E/S:"
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 msgid "bad address, not a constant:"
 msgstr "dirección errónea, no es una constante:"
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 msgid "bad address, not (reg+disp):"
 msgstr "dirección errónea, no (reg+disp):"
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "dirección errónea, no hay post_inc o pre_dec:"
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr "error interno del compilador.  Dirección errónea:"
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "Código '%c' no admitido para coma fija:"
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 msgid "internal compiler error.  Unknown mode:"
 msgstr "error interno del compilador.  Modo desconocido:"
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 msgid "invalid insn:"
 msgstr "insn no válida:"
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 msgid "incorrect insn:"
 msgstr "insn incorrecta:"
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 msgid "unknown move insn:"
 msgstr "insn move desconocida:"
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 msgid "bad shift insn:"
 msgstr "insn shift errónea:"
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "error interno del compilador.  Desplazamiento incorrecto:"
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 msgid "unsupported fixed-point conversion"
 msgstr "conversión de coma fija no admitida"
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 msgid "variable"
 msgstr "variable"
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 msgid "function parameter"
 msgstr "parámetro de función"
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 msgid "structure field"
 msgstr "campo de estructura"
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 msgid "return type of function"
 msgstr "tipo de retorno de función"
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 msgid "pointer"
 msgstr "puntero"
 
@@ -20517,7 +20517,7 @@ msgstr "operando inesperado"
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -20840,57 +20840,57 @@ msgstr "el operando no es un entero, código de operando 'R' no válido"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "el operando no es un entero concreto, código de operando 'R' no válido"
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "código de operando '%c' no válido"
 
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "restricciones no válidas para el operando"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, fuzzy, c-format
 #| msgid "invalid vector constant"
 msgid "invalid vector immediate"
 msgstr "constante de vector no válida"
 
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 msgid "unknown insn mode"
 msgstr "modo insn desconocido"
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 #, fuzzy
 #| msgid "invalid conversion from type %<bfloat16_t%>"
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr "conversión no válida desde el tipo %<bfloat16_t%>"
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 #, fuzzy
 #| msgid "invalid conversion from type %<bfloat16_t%>"
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr "conversión no válida desde el tipo %<bfloat16_t%>"
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 #, fuzzy
 #| msgid "invalid conversion to type %<bfloat16_t%>"
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr "conversión no válida al tipo %<bfloat16_t%>"
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 #, fuzzy
 #| msgid "invalid conversion to type %<bfloat16_t%>"
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr "conversión no válida al tipo %<bfloat16_t%>"
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 #, fuzzy
 #| msgid "operation not permitted on type %<bfloat16_t%>"
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr "operación no permitida con el tipo %<bfloat16_t%>"
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 #, fuzzy
 #| msgid "operation not permitted on type %<bfloat16_t%>"
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
@@ -20923,7 +20923,7 @@ msgstr "operación no válida en %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "operando %%P no válido"
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, c-format
 msgid "invalid %%p value"
 msgstr "valor %%p no válido"
@@ -20950,29 +20950,29 @@ msgstr "no se puede usar la dirección absoluta que no es relativa a gp"
 msgid "invalid addressing mode"
 msgstr "modo de direccionamiento no válido"
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, c-format
 msgid "'%%%c' is not a valid operand prefix"
 msgstr "'%%%c' no es un prefijo de operando válido"
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "uso no válido de '%%%c'"
@@ -21004,7 +21004,7 @@ msgid "post-increment address is not a register"
 msgstr "la dirección de post-incremento no es un registro"
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 msgid "bad address"
 msgstr "dirección errónea"
 
@@ -21170,7 +21170,7 @@ msgstr "no se admite la combinación: %s"
 msgid "unsupported memory expression:"
 msgstr "conversión de coma fija no admitida"
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, fuzzy, c-format
 #| msgid "invalid %%r operand"
 msgid "invalid vector operand"
@@ -21219,253 +21219,253 @@ msgstr "%<-mquad-memory-atomic%> requiere modo de 64 bits"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "%<-mquad-memory%> no está disponible en modo little endian"
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 msgid "bad move"
 msgstr "move erróneo"
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 msgid "Bad 128-bit move"
 msgstr "Movimiento de 128 bits erróneo"
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%A value"
 msgstr "valor %%J no válido"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%D value"
 msgstr "valor %%D no válido"
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, c-format
 msgid "invalid %%e value"
 msgstr "valor %%e no válido"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, c-format
 msgid "invalid %%f value"
 msgstr "valor %%f no válido"
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, c-format
 msgid "invalid %%F value"
 msgstr "valor %%F no válido"
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, c-format
 msgid "invalid %%G value"
 msgstr "valor %%G no válido"
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, c-format
 msgid "invalid %%j code"
 msgstr "código %%j no válido"
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, c-format
 msgid "invalid %%J code"
 msgstr "código %%J no válido"
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, c-format
 msgid "invalid %%k value"
 msgstr "valor %%k no válido"
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, c-format
 msgid "invalid %%K value"
 msgstr "valor %%K no válido"
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, c-format
 msgid "invalid %%O value"
 msgstr "valor %%O no válido"
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, c-format
 msgid "invalid %%q value"
 msgstr "valor %%q no válido"
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, c-format
 msgid "invalid %%t value"
 msgstr "valor %%t no válido"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, c-format
 msgid "invalid %%T value"
 msgstr "valor %%T no válido"
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, c-format
 msgid "invalid %%u value"
 msgstr "valor %%u no válido"
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, c-format
 msgid "invalid %%v value"
 msgstr "valor %%v no válido"
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, c-format
 msgid "invalid %%V value"
 msgstr "valor %%V no válido"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, c-format
 msgid "invalid %%x value"
 msgstr "valor %%x no válido"
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, c-format
 msgid "invalid %%z value"
 msgstr "valor %%z no válido"
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "valor %%y no válido, pruebe usando la restricción 'Z'"
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 #, fuzzy
 #| msgid "Enable using IEEE 128-bit floating point instructions."
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Activa el uso de instrucciones de coma flotante de 128 bits IEEE."
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Se pasó un argumento Altivec a una función sin prototipo"
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 msgid "Could not generate addis value for fusion"
 msgstr "No se ha podido generar valor addis para fusión"
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 msgid "Unable to generate load/store offset for fusion"
 msgstr "No se puede generar desplazamiento de carga/almacenamiento para fusión"
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 msgid "Bad GPR fusion"
 msgstr "Fusión GPR errónea"
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 #, fuzzy
 #| msgid "invalid conversion from type %<bfloat16_t%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "conversión no válida desde el tipo %<bfloat16_t%>"
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 #, fuzzy
 #| msgid "invalid conversion to type %<bfloat16_t%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "conversión no válida al tipo %<bfloat16_t%>"
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "conversión no válida de %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "conversión no válida a %<__fpreg%>"
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "las referencias a memoria simbólica sólo se admiten en z10 o posterior"
 
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, c-format
 msgid "cannot decompose address"
 msgstr "no se puede descomponer la dirección"
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "operador de comparación no válido para el modificador de salida 'E'"
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "referencia no válida para el modificador de salida 'J'"
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "dirección no válida para el modificador de salida 'O'"
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "dirección no válida para el modificador de salida 'R'"
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "se esperaba una referencia de memoria para el modificador de salida 'S'"
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "dirección no válida para el modificador de saida 'S'"
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "se esperaba un registro o expresión de memoria para el modificador de salida 'N'"
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "se esperaba un registro o expresión de memoria para el modificador de salida 'M'"
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "constante no válida para el modificador de salida '%c'"
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "constante no válida - pruebe usar un modificador de salida"
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "vector constante no válido para el modificador de salida '%c'"
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "expresión no válida - pruebe usar un modificador de salida"
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "expresión no válida para el modificador de salida '%c'"
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 msgid "vector argument passed to unprototyped function"
 msgstr "se pasó un argumento vector a una función sin prototipo"
 
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 msgid "types differ in signedness"
 msgstr "los tipos difieren en el signo"
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 msgid "binary operator does not support two vector bool operands"
 msgstr "el operador binario no admite dos operadores bool vector"
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 msgid "binary operator does not support vector bool operand"
 msgstr "el operador binario no admite operador bool vector"
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "el operador binario no admite que se mezclen operandos bool vector y vector de coma flotante"
 
@@ -21661,12 +21661,12 @@ msgstr "({anónimo})"
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "se esperaba %<;%>"
@@ -21679,7 +21679,7 @@ msgstr "se esperaba %<;%>"
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -21688,7 +21688,7 @@ msgstr "se esperaba %<;%>"
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "se esperaba %<)%>"
@@ -21696,7 +21696,7 @@ msgstr "se esperaba %<)%>"
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "se esperaba %<]%>"
@@ -21707,29 +21707,29 @@ msgstr "se esperaba %<;%>, %<,%> o %<)%>"
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "se esperaba %<(%>"
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "se esperaba %<[%>"
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "se esperaba %<{%>"
@@ -21739,17 +21739,17 @@ msgstr "se esperaba %<{%>"
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "se esperaba %<:%>"
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "se esperaba %<while%>"
@@ -21758,8 +21758,8 @@ msgstr "se esperaba %<while%>"
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "se esperaba %<,%>"
@@ -21769,17 +21769,17 @@ msgid "expected %<.%>"
 msgstr "se esperaba %<.%>"
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "se esperaba %<@end%>"
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "se esperaba %<>%>"
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "se esperaba %<,%> o %<)%>"
@@ -21787,33 +21787,33 @@ msgstr "se esperaba %<,%> o %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "se esperaba %<=%>"
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "se esperaba %<}%>"
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<delete%>"
 msgid "expected %<else%>"
 msgstr "se esperaba %<delete%>"
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "se esperaba %<#pragma omp section%> o %<}%>"
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr ""
 
@@ -21821,7 +21821,7 @@ msgstr ""
 msgid "(anonymous)"
 msgstr "(anónimo)"
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "se esperaba %<<%>"
@@ -21838,23 +21838,23 @@ msgstr "se esperaba etiqueta"
 msgid "candidate:"
 msgstr "candidato 1:"
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 #, fuzzy
 #| msgid "Enable user-defined instructions."
 msgid "  after user-defined conversion:"
 msgstr "Activa las instrucciones definidas por el usuario."
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "el candidato es:"
 msgstr[1] "los candidatos son:"
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr "candidato 1:"
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr "candidato 2:"
 
@@ -22106,7 +22106,7 @@ msgstr "%r%s:%d:%d:%R   en la expansión de la %<constexpr%> de %qs"
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%R   en la expansión de la %<constexpr%> de %qs"
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 msgid "candidates are:"
 msgstr "los candidatos son:"
 
@@ -22150,48 +22150,48 @@ msgstr "la conversión descarta la constancia"
 msgid "source type is not polymorphic"
 msgstr "el tipo fuente no es polimórfico"
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "argumento de tipo erróneo para el decremento unario"
 
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "argumento de tipo erróneo para el incremento unario"
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "argumento de tipo erróneo para complemento de bits"
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "argumento de tipo erróneo para abs"
 
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "argumento de tipo erróneo para la conjugación"
 
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 msgid "in argument to unary !"
 msgstr "en el argumento para el ! unario"
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 msgid "no pre-increment operator for type"
 msgstr "no hay operador de pre-incremento para el tipo"
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 msgid "no post-increment operator for type"
 msgstr "no hay operador de post-incremento para el tipo"
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 msgid "no pre-decrement operator for type"
 msgstr "no hay operador de pre-decremento para el tipo"
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 msgid "no post-decrement operator for type"
 msgstr "no hay operador de post-decremento para el tipo"
 
@@ -22277,7 +22277,7 @@ msgstr "Característica obsoleta:"
 msgid "Deleted feature:"
 msgstr "Característica borrada:"
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 msgid "array assignment"
 msgstr "asignación de matriz"
 
@@ -22486,11 +22486,11 @@ msgstr "bloque IF"
 msgid "implied END DO"
 msgstr "END DO implícito"
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 msgid "assignment"
 msgstr "asignación"
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 msgid "pointer assignment"
 msgstr "asignación de puntero"
 
@@ -22651,47 +22651,47 @@ msgstr "El operando del operador de usuario %%<%s%%>  en %%L es %s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Los operandos del operador de usuario %%<%s%%> en %%L son %s/%s"
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 msgid "Loop variable"
 msgstr "Variable de ciclo"
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 msgid "iterator variable"
 msgstr "variable de iterador"
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 msgid "Start expression in DO loop"
 msgstr "Expresión de inicio en el bucle DO"
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 msgid "End expression in DO loop"
 msgstr "Expresión de fin en el bucle DO"
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 msgid "Step expression in DO loop"
 msgstr "Expresión de paso en el bucle DO"
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 msgid "DEALLOCATE object"
 msgstr "objeto DEALLOCATE"
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 msgid "ALLOCATE object"
 msgstr "objeto ALLOCATE"
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 msgid "STAT variable"
 msgstr "variable STAT"
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 msgid "ERRMSG variable"
 msgstr "variable ERRMSG"
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 msgid "item in READ"
 msgstr "elemento en READ"
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 msgid "ACQUIRED_LOCK variable"
 msgstr "variable ACQUIRED_LOCK"
 
@@ -22700,11 +22700,11 @@ msgstr "variable ACQUIRED_LOCK"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "Longitudes de CHARACTER diferentes (%ld/%ld) en el constructor de matriz"
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Desborde entero al calcular la cantidad de memoria a reservar"
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "El valor del parámetro PDT LEN '%s' no concuerda con el de la declaración «dummy»"
@@ -22719,12 +22719,12 @@ msgstr "La longitud de la cadena actual no coincide con la declarada para el arg
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "La longitud de la cadena actual es más corta que la declarada para el argumento dummy '%s' (%ld/%ld)"
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "El objetivo del remapeo de rango es demasiado pequeño (%ld < %ld)"
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 msgid "Assignment of scalar to unallocated array"
 msgstr "Asignación de escalar a un array sin espacio asignado"
 
@@ -22733,86 +22733,86 @@ msgstr "Asignación de escalar a un array sin espacio asignado"
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Longitudes de caracteres desiguales (%ld/%ld) en %s"
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, fuzzy, c-format
 #| msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "argumentos 'a%d' y 'a%d' para el intrínseco '%s'"
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, fuzzy, c-format
 #| msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "argumentos 'a%d' y 'a%d' para el intrínseco '%s'"
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "El argumento NCOPIES del intrínseco REPEAT es negativo (su valor es %ld)"
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "El argumento NCOPIES del intrínseco REPEAT es demasiado grande"
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, fuzzy, c-format
 #| msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "argumentos 'a%d' y 'a%d' para el intrínseco '%s'"
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, fuzzy, c-format
 #| msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "argumentos 'a%d' y 'a%d' para el intrínseco '%s'"
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, fuzzy, c-format
 #| msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "argumentos 'a%d' y 'a%d' para el intrínseco '%s'"
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
@@ -22834,15 +22834,15 @@ msgstr "La etiqueta asignada no es una etiqueta objetivo"
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Número de imagen %d no válido en SYNC IMAGES"
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr "El bucle itera infinitamente"
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 msgid "Loop variable has been modified"
 msgstr "Se modificó la variable de ciclo"
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 msgid "DO step value is zero"
 msgstr "El valor de paso de DO es cero"
 
@@ -22921,7 +22921,7 @@ msgid "expected boolean type"
 msgstr "se esperaba un tipo booleano"
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "se esperaba un entero"
@@ -22986,7 +22986,7 @@ msgstr "faltan argumentos"
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "demasiados argumentos"
@@ -23637,7 +23637,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "-mrelax sólo se admite pare el PIC de RTP"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Error sintáctico en la declaración %s en %C"
@@ -24103,8 +24103,8 @@ msgstr "Se hace caso omiso del atributo %qE debido a un conflicto con el atribut
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "declaración previa aquí"
@@ -24121,7 +24121,7 @@ msgstr "se descarta la directiva de atributo %qE"
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr "se descarta la directiva de atributo de alcance %<%E::%E%>"
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, gcc-internal-format
 msgid "wrong number of arguments specified for %qE attribute"
 msgstr "se especificó el número equivocado de argumentos para el atributo %qE"
@@ -24132,7 +24132,7 @@ msgstr "se especificó el número equivocado de argumentos para el atributo %qE"
 msgid "expected %i or more, found %i"
 msgstr "se esperaba %<(%> o fin de línea"
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %i, found %i"
@@ -24200,12 +24200,12 @@ msgstr "se descartan los atributos de tipo después de que el tipo ya se defini
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -24214,7 +24214,7 @@ msgstr "se descartan los atributos de tipo después de que el tipo ya se defini
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -24236,8 +24236,8 @@ msgstr "se descarta el atributo %qE"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "falta el atributo %<target%> para %qD multiversionado"
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "declaración previa de %qD"
@@ -24349,7 +24349,7 @@ msgstr "no se puede leer el perfil de función de %s"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "el desplazamiento %qwi fuera de los límites de la constante de cadena"
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qE declared here"
@@ -24463,7 +24463,7 @@ msgstr "argumento %qs no válido para %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, fuzzy, gcc-internal-format
 #| msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
@@ -24487,44 +24487,44 @@ msgstr "el segundo argumento de %<__builtin_longjump%> debe ser 1"
 msgid "target format does not support infinity"
 msgstr "el formato objetivo no soporta infinito"
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, fuzzy, gcc-internal-format
 #| msgid "%<va_start%> used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "se usó %<va_start%> en una función con argumentos fijos"
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "número erróneo argumentos para la función %<va_start%>"
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "se llamó a %<__builtin_next_arg%> sin un argumento"
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "número erróneo de argumentos para la función %<__builtin_next_arg%>"
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "el segundo parámetro de %<va_start%> no es el último argumento nombrado"
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "la conducta es indefinida cuando el segundo parámetro de %<va_start%> se declara con almacenamiento %<register%>"
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr "%Kel primer argumento de %qD debe ser un puntero, el segundo una constante entera"
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, fuzzy, gcc-internal-format
 #| msgid "%Klast argument of %qD is not integer constant between 0 and 3"
 msgid "last argument of %qD is not integer constant between 0 and 3"
@@ -25603,12 +25603,12 @@ msgstr "se descarta el atributo %<weakref%> porque ya se inicializó la variable
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "se usa %q+F pero nunca se define"
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F se declaró %<static%> pero nunca se define"
@@ -26201,7 +26201,7 @@ msgstr "region_array no coincide con region_tree"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "lp_array no coincide con region_tree"
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, fuzzy, gcc-internal-format
 #| msgid "open %s failed: %s"
 msgid "%qs failed"
@@ -26232,19 +26232,19 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, fuzzy, gcc-internal-format
 #| msgid "%Kcall to %qs declared with attribute error: %s"
 msgid "call to %qs declared with attribute error: %s"
 msgstr "%Kla llamada a %qs se redeclaró con error de atributo: %s"
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, fuzzy, gcc-internal-format
 #| msgid "%Kcall to %qs declared with attribute warning: %s"
 msgid "call to %qs declared with attribute warning: %s"
 msgstr "%Kla llamada a %qs se redecló con aviso de atributo: %s"
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, fuzzy, gcc-internal-format
 #| msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
@@ -26281,7 +26281,7 @@ msgstr "se truncó la constante de coma fija grande implícitamente al tipo de c
 msgid "comparison is always %d due to width of bit-field"
 msgstr "la comparación siempre es %d debido a la anchura del campo de bit"
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "se asume que el desbordamiento con signo no sucede al simplificar la prueba de rango"
@@ -26460,7 +26460,7 @@ msgstr "no se pueden obtener los tiempos de proceso: %m"
 msgid "%s signal terminated program %s"
 msgstr "la señal %s terminó el programa %s"
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option %qs"
 msgid "unrecognized command-line option %qs"
@@ -26741,7 +26741,7 @@ msgstr "la especificación multilib %qs es no válida"
 msgid "multilib exclusions %qs is invalid"
 msgstr "las exclusiones multilib %qs son no válidas"
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "la selección multilib %qs %qs no es válida"
@@ -27065,24 +27065,24 @@ msgstr "%K%qD: el límite %E especificado excede el tamaño del destino %E"
 msgid "%qD specified bound %E equals source length"
 msgstr "el límite de %G%qD especificado %E es igual a la longitud del origen"
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr "el miembro de matriz flexible no está al final del struct"
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr ""
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mn is not supported for linux targets"
 msgid "%s not supported for variable length aggregates"
 msgstr "no se admite -mn para objetivos linux"
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ifunc is not supported on this target"
 msgid "%s not supported on this target"
@@ -27124,16 +27124,16 @@ msgid "function returns address of local variable"
 msgstr "la función devuelve la dirección de una variable local"
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, gcc-internal-format
@@ -27146,271 +27146,271 @@ msgstr "se declara aquí"
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr "argumento %qD no nulo comparado con NULL"
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr "la salida %qE podría truncarse antes del último carácter de formato"
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr "la salida %qE podría truncarse antes del último carácter de formato"
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr "%qE podría escribir un nul al final del destino"
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr "%qE se escribe un nul al final del destino"
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] "directiva %<%.*s%> escribiendo %wu byte en una región de tamaño %wu"
 msgstr[1] "directiva %<%.*s%> escribiendo %wu bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] "salida de la directiva %<%.*s%> podría truncarse escribiendo %wu byte en una región de tamaño %wu"
 msgstr[1] "salida de la directiva %<%.*s%> podría truncarse escribiendo %wu bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] "salida de la directiva %<%.*s%> truncada escribiendo %wu byte en una región de tamaño %wu"
 msgstr[1] "salida de la directiva %<%.*s%> truncada escribiendo %wu bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr "la salida de la directiva %<%.*s%> podría truncarse al escribir hasta %wu bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr "salida de la directiva %<%.*s%> truncada escribiendo hasta %wu bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr "directiva %<%.*s%> escribiendo hasta %wu bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "la salida de la directiva %<%.*s%> podría truncarse escribiendo probablemente %wu o más bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "salida de la directiva %<%.*s%> truncada escribiendo probablemente %wu o más bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr "directiva %<%.*s%> escribiendo probablemente %wu o más bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "la salida de la directiva %<%.*s%> podría truncarse escribiendo entre %wu y %wu bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "salida de la directiva %<%.*s%> truncada escribiendo entre %wu y %wu bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr "directiva %<%.*s%> escribiendo entre %wu y %wu bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr "la salida de la directiva %<%.*s%> podría truncarse escribiendo %wu o más bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr "salida de la directiva %<%.*s%> truncada escribiendo %wu o más bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr "directiva %<%.*s%> escribiendo %wu o más bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] "directiva %<%.*s%> escribiendo %wu byte en una región de un tamaño entre %wu y %wu"
 msgstr[1] "directiva %<%.*s%> escribiendo %wu bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] "la salida de la directiva %<%.*s%> podría truncarse al escribir %wu byte en una región de un tamaño entre %wu y %wu"
 msgstr[1] "la salida de la directiva %<%.*s%> podría truncarse al escribir %wu bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] "salida de la directiva %<%.*s%> truncada escribiendo %wu byte en una región de un tamaño entre %wu y %wu"
 msgstr[1] "salida de la directiva %<%.*s%> truncada escribiendo %wu bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "la salida de la directiva %<%.*s%> podría truncarse escribiendo hasta %wu bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "salida de la directiva %<%.*s%> truncada escribiendo hasta %wu bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "directiva %<%.*s%> escribiendo hasta %wu bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "la salida de la directiva %<%.*s%> podría truncarse escribiendo probablemente %wu o más bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "salida de la directiva %<%.*s%> truncada escribiendo probablemente %wu o más bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "directiva %<%.*s%> escribiendo probablemente %wu o más bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "la salida de la directiva %<%.*s%> podría truncarse escribiendo entre %wu y %wu bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "salida de la directiva %<%.*s%> truncada escribiendo entre %wu y %wu bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "directiva %<%.*s%> escribiendo entre %wu y %wu bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "la salida de la directiva %<%.*s%> podría truncarse escribiendo %wu o más bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "salida de la directiva %<%.*s%> truncada escribiendo %wu o más bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "directiva %<%.*s%> escribiendo %wu o más bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive argument is null"
 msgid "%<%.*s%> directive argument is null"
 msgstr "el argumento de la directiva %<%.*s%> es nulo"
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr "la salida de la directiva %<%.*s%> de %wu bytes supera el tamaño mínimo requerido de 4095"
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr "la salida de la directiva %<%.*s%> entre %wu y %wu bytes supera el tamaño mínimo requerido de 4095"
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr "la salida de la directiva %<%.*s%> entre %wu y %wu bytes podría superar el tamaño mínimo requerido de 4095"
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr "la salida de la directiva %<%.*s%> de %wu bytes provoca que el resultado supere %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr "la salida de la directiva %<%.*s%> entre %wu y %wu bytes provoca que el resultado supere %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "la salida de la directiva %<%.*s%> de %wu bytes provoca que el resultado supere %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "la salida de la directiva %<%.*s%> entre %wu y %wu bytes provoca que el resultado supere %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr "la salida de la directiva %<%.*s%> entre %wu y %wu bytes podría provocar que el resultado supere %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive argument is null"
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr "el argumento de la directiva %<%.*s%> es nulo"
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qD declared here"
 msgid "referenced argument declared here"
 msgstr "el argumento %qD se declara aquí"
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] "se asume salida de directiva de %wu byte"
 msgstr[1] "se asume salida de directiva de %wu bytes"
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "argumento de la directiva %qE"
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr "argumento de la directiva en el rango de [%E, %E]"
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr "se utiliza el rango [%E, %E] para el argumento de la directiva"
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, fuzzy, gcc-internal-format
 #| msgid "%qE output %wu byte into a destination of size %wu"
 msgid "%qE output %wu byte into a destination of size %wu"
@@ -27418,61 +27418,61 @@ msgid_plural "%qE output %wu bytes into a destination of size %wu"
 msgstr[0] "%qE manda %wu byte a un destino de tamaño %wu"
 msgstr[1] "%qE manda %wu byte a un destino de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr "%qE manda entre %wu y %wu bytes a un destino de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr "%qE manda %wu o más bytes (se asume %wu) a un destino de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr "%qE manda %wu o más bytes a un destino de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, fuzzy, gcc-internal-format
 #| msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgid "%qE output between %wu and %wu bytes"
 msgstr "%qE manda entre %wu y %wu bytes a un destino de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, fuzzy, gcc-internal-format
 #| msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr "%qE manda %wu o más bytes (se asume %wu) a un destino de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, fuzzy, gcc-internal-format
 #| msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgid "%qE output %wu or more bytes"
 msgstr "%qE manda %wu o más bytes a un destino de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr "anchura de la directiva %<%.*s%> fuera de rango"
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr "precisión de la directiva %<%.*s%> fuera de rango"
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 #, fuzzy
 #| msgid "%qD source argument is the same as destination"
 msgid "%qE argument %Z overlaps destination object %qE"
@@ -27480,7 +27480,7 @@ msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] "el argumento origen %qD es el mismo que el destino"
 msgstr[1] "el argumento origen %qD es el mismo que el destino"
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 #, fuzzy
 #| msgid "%qE output %wu byte into a destination of size %wu"
 msgid "%qE argument %Z may overlap destination object %qE"
@@ -27488,39 +27488,39 @@ msgid_plural "%qE arguments %Z may overlap destination object %qE"
 msgstr[0] "%qE manda %wu byte a un destino de tamaño %wu"
 msgstr[1] "%qE manda %wu byte a un destino de tamaño %wu"
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr "el límite especificado %wu supera el tamaño máximo del objeto %wu"
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr "el límite especificado %wu supera %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr "el límite especificado %wu supera %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, fuzzy, gcc-internal-format
 #| msgid "null destination pointer"
 msgid "null destination pointer"
 msgstr "puntero de destino nulo"
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr "el límite especificado %wu supera el tamaño %wu del objeto de destino"
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, fuzzy, gcc-internal-format
 #| msgid "null format string"
 msgid "null format string"
@@ -28414,12 +28414,12 @@ msgstr "modo de puntero %qs no válido"
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD se declara aquí"
@@ -29268,7 +29268,7 @@ msgstr "el elemento %u tiene ubicación-x == %u"
 msgid "token %u has %<y-location == %u%>"
 msgstr "el elemento %u tiene ubicación-y == %u"
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "uso no válido del atribute  %<fallthrough%>"
@@ -29624,18 +29624,18 @@ msgstr "está definido como puntero a un tipo diferente en otra unidad de traduc
 msgid "mismatching definition"
 msgstr "falta la definición"
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function in gimple call"
 msgid "invalid fnsummary in LTO stream"
 msgstr "función no válida en la llamada gimple"
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr "falta el resumen de inclusión en línea ipa en el fichero de entrada"
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, fuzzy, gcc-internal-format
 #| msgid "ipa inline summary is missing in input file"
 msgid "IPA modref summary is missing in input file"
@@ -30773,77 +30773,77 @@ msgstr "error al escribir a %s: %m"
 msgid "error closing optimization records %qs"
 msgstr "Realiza optimizaciones de saltos cruzados."
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, fuzzy, gcc-internal-format
 #| msgid "command line option %qs is not supported by this configuration"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "la opción de línea de órdenes %qs no se admite en esta configuración"
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "faltan argumentos para %qs"
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs should be a non-negative integer"
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr "el argumento para %qs debe ser un entero no negativo"
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer"
 msgstr "el argumento para %qs debe ser un entero no negativo"
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, gcc-internal-format
 msgid "argument to %qs is not between %d and %d"
 msgstr "el argumento para %qs no está entre %d y %d"
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument %qs to %qs"
 msgid "invalid argument in option %qs"
 msgstr "argumento %qs no válido para %qs"
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr ""
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, fuzzy, gcc-internal-format
 #| msgid "FPX fast and compact options cannot be specified together"
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr "las opciones de FPX fast y compact no pueden especificarse juntas"
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, gcc-internal-format
 msgid "unrecognized argument in option %qs"
 msgstr "no se reconoce el argumento en la opción %qs"
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para %qs son: %s; ¿quiso decir %qs?"
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "los argumentos válidos para %qs son: %s"
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "la opción %qs ya no se admite"
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute larger than %d"
 msgid "argument to %qs is bigger than %d"
 msgstr "el argumento para el atributo %qE es más grande que %d"
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, fuzzy, gcc-internal-format
 #| msgid "malformed COLLECT_GCC_OPTIONS"
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
@@ -30925,8 +30925,8 @@ msgstr "el argumento para %<-O%> debe ser un entero no negativo, %<g%>, %<s%> o
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, gcc-internal-format
 msgid "%qs is incompatible with %qs"
 msgstr "%qs es incompatible con %qs"
@@ -31717,7 +31717,7 @@ msgstr "la variable de registro global después de una definición de función"
 msgid "register of %qD used for multiple global register variables"
 msgstr "se usó el registro de %qD para múltiples variables de registro globales"
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "genera un conflicto con %qD"
@@ -32185,45 +32185,45 @@ msgstr "la sección del alias %q+D debe cuadrar con la sección de su objetivo"
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "no se admite __builtin_saveregs en este objetivo"
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, fuzzy, gcc-internal-format
 #| msgid "ifunc is not supported on this target"
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "no se admiten ifunc en este objetivo"
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, gcc-internal-format
 msgid "nested functions not supported on this target"
 msgstr "no se admiten funciones anidadas en este objetivo"
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, gcc-internal-format
 msgid "nested function trampolines not supported on this target"
 msgstr "no se admiten trampolines de funciones anidadas para este objetivo"
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "no se admiten constructores globales en este objetivo"
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "no se admiten los destructores globales en este objetivo"
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute is not supported on this machine"
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "el atributo target no se admite en esta plataforma"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute is not supported on this machine"
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "el atributo target no se admite en esta plataforma"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "%<#pragma GCC target%> is not supported for this machine"
@@ -33434,86 +33434,86 @@ msgstr "BB %i tiene un borde incorrecto"
 msgid "BB %i has incorrect fallthru edge"
 msgstr "BB %i tiene un borde de respaldo incorrecto"
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr "la función %q+F nunca se puede copiar porque recibe un goto que no es local"
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr "la función %q+F nunca se puede copiar porque guarda direcciones de etiqueta local en una variable estática"
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr "la función %q+F nunca se puede incluir en línea porque usa alloca (forzar usando el atributo always_inline)"
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr "la función %q+F nunca se puede incluir en línea porque usa setjmp"
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr "la función %q+F nunca se puede incluir en línea porque usa listas variables de argumentos"
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr "la función %q+F nunca se puede incluir en línea porque usa manejo de excepciones setjmp-longjmp"
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr "la función %q+F nunca se puede incluir en línea porque contiene un goto que no es local"
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses __builtin_return or __builtin_apply_args"
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr "la función %q+F nunca se puede incluir en línea porque usa __builtin_return o __builtin_apply_args"
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr "la función %q+F nunca se puede incluir en línea porque contiene un goto calculado"
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr "la función %q+F nunca se puede incluir en línea porque usa listas variables de argumentos"
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it is suppressed using -fno-inline"
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr "la función %q+F nunca puede ser incluida en línea porque se suprime al usar -fno-inline"
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr "la función %q+F nunca puede ser incluida en línea porque utiliza atributos que generan conflictos con la inclusión en línea"
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, fuzzy, gcc-internal-format
 #| msgid "inlining failed in call to always_inline %q+F: %s"
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr "falló la inclusión en línea en la llamada a always_inline %q+F: %s"
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr "llamado desde aquí"
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, gcc-internal-format
 msgid "called from this function"
 msgstr "llamada desde esta función"
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, gcc-internal-format
 msgid "inlining failed in call to %q+F: %s"
 msgstr "falló la inclusión en línea en la llamada a %q+F: %s"
@@ -33572,29 +33572,29 @@ msgstr "tipo de elemento no válido para el atributo %qs"
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr "uso no válido del atribute  %<fallthrough%>"
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "in a call to non-static member function %qD"
 msgstr "uso no válido de la función miembro no static %qD"
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument %u null where non-null expected"
 msgid "argument %u null where non-null expected"
 msgstr "argumento %u nulo donde se esperaba no nulo"
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "en una llamada a la función interna %qD"
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, fuzzy, gcc-internal-format
 #| msgid "in a call to function %qD declared here"
 msgid "in a call to function %qD declared %qs"
@@ -33832,7 +33832,7 @@ msgstr "%qE no está inicializado"
 msgid "%qs may be used uninitialized"
 msgstr "puede ser que se utilice %qD sin inicializar en esta función"
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD se declaró aquí"
@@ -34071,7 +34071,7 @@ msgstr "la condición vectorial se expandirá por piezas"
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "la operación de ordenamiento vectorial se expandirá por piezas"
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr "no se ha producido vectorización para un bucle simd"
@@ -34086,131 +34086,131 @@ msgstr "elemento no constante en CONSTRUCTOR constante"
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr "elemento con efectos colaterales en CONSTRUCTOR sin efectos colaterales"
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "las matrices de funciones no tienen significado"
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "el tipo de devolución de función no puede ser función"
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "revisión de árbol: %s, se tiene %s en %s, en %s:%d"
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "revisión de árbol: no se esperaba ninguno de %s, se tiene %s en %s, en %s:%d"
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "revisión de árbol: se esperaba la clase %qs, se tiene %qs (%s) en %s, en %s:%d"
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "revisión de árbol: no se esperaba la clase %qs, se tiene %qs (%s) en %s, en %s:%d"
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr "revisión de árbol: se esperaba omp_clause %s, se tiene %s en %s, en %s:%d"
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "revisión de árbol: se esperaba un árbol que contenga la estructura %qs, se tiene %qs en %s, en %s:%d"
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr "revisión de árbol: acceso de elt %d de tree_int_cst con %d elts en %s, en %s:%d"
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr "revisión de árbol: acceso de elt %d de tree_vec con %d elts en %s, en %s:%d"
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "revisión de árbol: acceso del operando %d de %s con %d operandos en %s, en %s:%d"
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "revisión de árbol: acceso del operando %d de omp_clause %s con %d operandos en %s, en %s:%d"
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD es obsoleto: %s"
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD es obsoleto"
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE es obsoleto: %s"
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE es obsoleto"
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "el tipo es obsoleto: %s"
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "el tipo es obsoleto"
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is unavailable: %s"
 msgstr "%qD no es una variable"
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is unavailable"
 msgstr "%qD no es una variable"
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qE is unavailable: %s"
 msgstr "%qD no es una variable"
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qE is unavailable"
 msgstr "%qD no es una variable"
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "open %s failed: %s"
 msgid "type is unavailable: %s"
 msgstr "falló al abrir %s: %s"
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "type is unavailable"
@@ -34236,308 +34236,308 @@ msgstr "%qD no es una variable"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr "tipo variante difiere en %s"
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_SIZE_UNIT"
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr "tipos variantes difieren en TYPE_SIZE_UNIT"
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TYPE_SIZE_UNIT"
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr "TYPE_SIZE_UNIT del tipo variante"
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, fuzzy, gcc-internal-format
 #| msgid "type's TYPE_SIZE_UNIT"
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr "TYPE_SIZE_UNIT del tipo"
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, fuzzy, gcc-internal-format
 #| msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr "tipo variante con TYPE_ALIAS_SET_KNOWN_P"
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_VFIELD"
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr "tipo variante con diferente TYPE_VFIELD"
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_BINFO"
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr "tipo variante con diferente TYPE_BINFO"
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TYPE_BINFO"
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr "TYPE_BINFO del tipo variante"
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, fuzzy, gcc-internal-format
 #| msgid "type's TYPE_BINFO"
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr "TYPE_BINFO del tipo"
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_FIELDS"
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr "tipo variante con diferente TYPE_FIELDS"
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "el primer descuadre es campo"
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, gcc-internal-format
 msgid "and field"
 msgstr "y campo"
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TREE_TYPE"
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr "tipo variante con diferente TREE_TYPE"
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TREE_TYPE"
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr "TREE_TYPE del tipo variante"
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, fuzzy, gcc-internal-format
 #| msgid "type's TREE_TYPE"
 msgid "type%'s %<TREE_TYPE%>"
 msgstr "TREE_TYPE del tipo"
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "el tipo no es compatible con su variante"
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qT is not a template type"
 msgid "type %s is not an opaque type"
 msgstr "%qT no es un tipo plantilla"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "type %s is not with opaque mode"
 msgstr "el tipo %qT no es una base directa de %qT"
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_BINFO"
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr "tipo variante con diferente TYPE_BINFO"
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_SIZE_UNIT"
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr "tipos variantes difieren en TYPE_SIZE_UNIT"
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_BINFO"
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr "tipo variante con diferente TYPE_BINFO"
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_SIZE_UNIT"
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr "tipos variantes difieren en TYPE_SIZE_UNIT"
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, fuzzy, gcc-internal-format
 #| msgid "Main variant is not defined"
 msgid "main variant is not defined"
 msgstr "La variante principal no está definida"
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr "TYPE_MAIN_VARIANT tiene diferente TYPE_MAIN_VARIANT"
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr "TYPE_CANONICAL tiene diferente TYPE_CANONICAL"
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CANONICAL is not compatible"
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr "TYPE_CANONICAL no es compatible"
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr "TYPE_MODE de TYPE_CANONICAL no es compatible"
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr "TYPE_VFIELD no es FIELD_DECL ni TREE_LIST"
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr "TYPE_NEXT_PTR_TO no es POINTER_TYPE"
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr "TYPE_NEXT_REF_TO no es REFERENCE_TYPE"
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_BINFO is not TREE_BINFO"
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr "TYPE_BINFO no es TREE_BINFO"
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr "El tipo TYPE_BINFO no es TYPE_MAIN_VARIANT"
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr "TYPE_METHOD_BASETYPE no es registro ni unión"
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr "TYPE_OFFSET_BASETYPE no es registro ni unión"
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr "TYPE_ARRAY_MAX_SIZE no es INTEGER_CST"
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr "TYPE_MAX_VALUE_RAW no NULL"
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr "El campo TYPE_LANG_SLOT_1 (binfo) es no NULL"
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, fuzzy, gcc-internal-format
 #| msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr "El valor enumerado no es CONST_DECL ni INTEGER_CST"
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, fuzzy, gcc-internal-format
 #| msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr "El tipo de valor enumerado no es INTEGER_TYPE ni puede convertirse al enumerado"
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, fuzzy, gcc-internal-format
 #| msgid "Enum value name is not IDENTIFIER_NODE"
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr "El nombre de valor enumerado no es IDENTIFIER_NODE"
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, fuzzy, gcc-internal-format
 #| msgid "Array TYPE_DOMAIN is not integer type"
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "El array TYPE_DOMAIN no es de un tipo entero"
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_FIELDS defined in incomplete type"
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "TYPE_FIELDS definidos en un tipo incompleto"
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, fuzzy, gcc-internal-format
 #| msgid "Wrong tree in TYPE_FIELDS list"
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr "Árbol incorrecto en una lista TYPE_FIELDS"
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr "TYPE_CACHED_VALUES_P es %i mientras que TYPE_CACHED_VALUES es %p"
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr "TYPE_CACHED_VALUES no es TREE_VEC"
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, fuzzy, gcc-internal-format
 #| msgid "wrong TYPE_CACHED_VALUES entry"
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr "entrada TYPE_CACHED_VALUES incorrecta"
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, fuzzy, gcc-internal-format
 #| msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr "TREE_PURPOSE es no NULL en una lista TYPE_ARG_TYPES"
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, fuzzy, gcc-internal-format
 #| msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr "Entrada incorrecta en una lista TYPE_ARG_TYPES"
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_VALUES_RAW field is non-NULL"
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr "El campo TYPE_VALUES_RAW es no NULL"
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr "TYPE_CACHED_VALUES_P está activado y no debería"
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
@@ -34765,7 +34765,7 @@ msgstr "no se admiten las definiciones de alias en esta configuración"
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "no se admiten los atributos de visibilidad en esta configuración; descartados"
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr ""
@@ -34999,7 +34999,7 @@ msgstr "se descarta el atributo %qE porque %qT ya está definido"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "se descarta el atributo %qE porque %qT ya está definido"
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "el atributo %qE sólo tiene efecto en objetos públicos"
@@ -35191,7 +35191,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr "el atributo %qE no tiene efecto en variables automáticas"
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for local variables"
 msgstr "no se puede especificar el atributo %qE para las variables locales"
@@ -35543,7 +35543,7 @@ msgstr "%qD no es compatible con %qD"
 msgid "%qE argument is not a function"
 msgstr "el argumento %qE no es una función"
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "el mensaje obsoleto no es una cadena"
@@ -36104,7 +36104,7 @@ msgstr "ISO C++ no permite %<alignof%> aplicado a un tipo de función"
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr "ISO C no permite %<_Alignof%> aplicado a un tipo de función"
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, gcc-internal-format
 msgid "invalid application of %qs to a void type"
 msgstr "aplicación no válida de %qs a un tipo void"
@@ -36239,17 +36239,17 @@ msgstr "atributo %<fallthrough%> especificado múltiples veces"
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "el atributo %<fallthrough%> se especificó con un parámetro"
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "faltan argumentos para la función %qE"
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, gcc-internal-format
@@ -36381,181 +36381,181 @@ msgstr "se intentó tomar la dirección del miembro de la estructura de campos d
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "el índice %E denota un desplazamiento mayor que el tamaño de %qT"
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "el tamaño de la matriz es demasiado grande"
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "el tipo %qT del operando es incompatible con el argumento %d de %qE"
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "el paso del argumento %d de %qE crea un puntero desde un entero sin una conversión"
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, fuzzy, gcc-internal-format
 #| msgid "left argument must be a slice"
 msgid "both arguments must be compatible"
 msgstr "el argumento izquierdo debe ser una rebanada"
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "número incorrecto de argumentos para la función %qE"
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "el argumento 1 de %qE debe ser un tipo puntero que no sea void"
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr "el argumento 1 de %qE debe ser un puntero a un tipo de tamaño constante"
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "el argumento 1 de %qE debe ser un puntero a un tipo de tamaño constante"
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "el argumento 1 de %qE debe ser un puntero a un objeto de tamaño diferente de cero"
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "el argumento %d de %qE debe ser un tipo puntero"
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "el argumento %d de %qE debe ser un puntero a un tipo de tamaño constante"
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "el argumento %d de %qE no debe ser un puntero a función"
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "no coincide el tamaño en el argumento %d de %qE"
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be a pointer to a constant size type"
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr "el argumento %d de %qE debe ser un puntero a un tipo de tamaño constante"
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr "el paso del argumento %d de %qE descarta el calificador %qv del tipo del destino del puntero"
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be a pointer to a constant size type"
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr "el argumento %d de %qE debe ser un puntero a un tipo de tamaño constante"
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr "el paso del argumento %d de %qE descarta el calificador %qv del tipo del destino del puntero"
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "argumento de modelo de memoria %d que no es entero de %qE"
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "argumento de modelo de memoria %d no válido de %qE"
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "el valor del índice está fuera del límite"
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "la conversión del escalar %qT al vector %qT implica truncado"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "la función interna %qE ha de ser llamada directamente"
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "size of array %qE is not a constant expression"
 msgstr "el tamaño de la matriz %qD no es una expresion constante integral"
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array is not a constant expression"
 msgstr "el tamaño de la matriz no es una expresion constante integral"
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "el tamaño de la matriz %qE es negativo"
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "el tamaño de la matriz es negativo"
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, fuzzy, gcc-internal-format
 #| msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr "%Kargumento %i, valor %qE, supera el tamaño máximo %E del objeto"
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, fuzzy, gcc-internal-format
 #| msgid "%K%qD specified size %E exceeds maximum object size %E"
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr "%K%qD: el tamaño especificado %E excede el tamaño máximo %E del objeto"
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, fuzzy, gcc-internal-format
 #| msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "%Kargumento %i, valor %qE, supera el tamaño máximo %E del objeto"
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "size of array exceeds maximum object size %qE"
 msgstr "el límite especificado %wu supera el tamaño máximo del objeto %wu"
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -37216,7 +37216,7 @@ msgstr "la constante entera es demasiado grande para el tipo %<unsigned long%>"
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr "la constante entera es demasiado grande para el tipo %<unsigned long%>"
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int%d%> is not supported on this target"
 msgid "%<_BitInt(%d)%> is not supported on this target"
@@ -37302,7 +37302,7 @@ msgstr "no se admite la concatenación no estándar de literales de cadena"
 msgid "traditional C rejects string constant concatenation"
 msgstr "C tradicional rechaza la concatenación de constantes de cadenas"
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -37361,7 +37361,7 @@ msgstr "cláusula %<depend(source)%> especificada junto con cláusulas %<depend(
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "la cláusula %<ordered%> con parámetro no se puede especificar en la construcción %qs"
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "tipo no válido para la variable de iteración %qE"
@@ -37376,17 +37376,17 @@ msgstr "variable de iteración %<_Atomic%> %qE"
 msgid "%qE is not initialized"
 msgstr "%qE no está inicializado"
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "falta el predicado controlador"
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "predicado controlador no válido"
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "falta la expresión de incremento"
@@ -37396,7 +37396,7 @@ msgstr "falta la expresión de incremento"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "expresión de incremento no válida"
@@ -37487,7 +37487,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -37498,7 +37498,7 @@ msgstr ""
 msgid "%qD is not a function argument"
 msgstr "%qD no es un argumento de función"
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "campo de bits %qE en cláusula %qs"
@@ -38140,7 +38140,7 @@ msgid "wrong type argument to %s"
 msgstr "argumento de tipo erróneo para %s"
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -39098,35 +39098,35 @@ msgstr "comparación entre %qT y %qT"
 
 #: c-family/c-warn.cc:3832
 #, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3836
+#: c-family/c-warn.cc:3839
 #, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr ""
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr ""
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr ""
@@ -39358,129 +39358,129 @@ msgstr "-mregparm=%d no está entre 0 y %d"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr "para la opción -mcache-block-size=X, las X válidas son: 4, 8, 16, 32, 64, 128, 256, o 512"
 
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> requires %<-mfp32%>"
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr "%<-march=%s%> requiere %<-mfp32%>"
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s: ISA string must begin with rv32 or rv64"
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr "-march=%s: la cadena ISA debe empezar por rv32 o rv64"
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s: invalid ISA string"
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr "-march=%s: cadena ISA no válida"
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> requires %<-mfp32%>"
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr "%<-march=%s%> requiere %<-mfp32%>"
 
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s: ISA string must begin with rv32 or rv64"
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr "-march=%s: la cadena ISA debe empezar por rv32 o rv64"
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the SPE ABI extensions."
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr "No usa las extensiones de ABI SPE."
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, fuzzy, gcc-internal-format
 #| msgid "-mcpu=%s conflicts with -march=%s"
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr "-mcpu=%s genera conflicto con -march=%s"
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, fuzzy, gcc-internal-format
 #| msgid "-mcpu=%s conflicts with -march=%s"
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr "-mcpu=%s genera conflicto con -march=%s"
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "%<-march=%s%> no es compatible con la ABI seleccionada"
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr "%<-march=%s%> no es compatible con la ABI seleccionada"
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s: ISA string must begin with rv32 or rv64"
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr "-march=%s: la cadena ISA debe empezar por rv32 o rv64"
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, fuzzy, gcc-internal-format
 #| msgid "%<%s%> is unknown"
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "%<%s%> es desconocido"
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr ""
@@ -39923,13 +39923,13 @@ msgstr "se esperaba %qT pero el argumento es de tipo %qT"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "se esperaba %qT pero el argumento es de tipo %qT"
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC optimize%> is not a string or number"
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC optimize%> no es una cadena o un número"
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, fuzzy, gcc-internal-format
 #| msgid "unknown #pragma GCC coprocessor %E"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
@@ -40572,7 +40572,7 @@ msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, fuzzy, gcc-internal-format
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
@@ -40656,12 +40656,12 @@ msgid "unknown tuning option (%s)"
 msgstr "opción de cadena de ajuste desconocida (%s)"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
@@ -40673,7 +40673,7 @@ msgid "specify a system register with a small string length"
 msgstr "Especifica el orden de asignación de registros"
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs no es un desplazamiento válido en %qs"
@@ -40873,9 +40873,9 @@ msgstr "el pragma o atributo %<target(\"%s\")%> no acepta forma negada"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "el pragma o atributo %<target(\"%s=%s\")%> no es válido"
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "el argumento del atributo %<target%> no es una cadena"
@@ -40933,21 +40933,21 @@ msgid "virtual function multiversioning not supported"
 msgstr "No se admiten versiones múltiples de funciones virtuales"
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, fuzzy, gcc-internal-format
 #| msgid "multiversioning needs ifunc which is not supported on this target"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "el versionado múltiple necesita ifunc, que no se admite en este objetivo"
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 #, fuzzy
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1"
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 #, fuzzy
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
@@ -40964,8 +40964,8 @@ msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1
 msgid "lane %wd out of range %wd - %wd"
 msgstr "vía %wd fuera de rango %wd - %wd"
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported simdlen %d"
 msgid "unsupported simdlen %wd"
@@ -40977,7 +40977,7 @@ msgstr "simdlen %d no admitido"
 msgid "GCC does not currently support return type %qT for simd"
 msgstr "no se admite el tipo de retorno %qT para simd"
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "no se admite el tipo de retorno %qT para simd"
@@ -40988,7 +40988,7 @@ msgstr "no se admite el tipo de retorno %qT para simd"
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr "no se admite el tipo de argumento %qT para simd"
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "no se admite el tipo de argumento %qT para simd"
@@ -41090,8 +41090,8 @@ msgstr "latencia de caché L%d desconocida para %s"
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "valor %qs erróneo para -mmemory-latency"
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr "fcode interno erróneo"
@@ -41220,18 +41220,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "el argumento del atributo %qE no es \"ilink\" o \"firq\""
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -41349,7 +41349,7 @@ msgid "argument of %qE attribute is missing"
 msgstr "falta el argumento del atributo %qE"
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "el atributo %qE sólo permite una constante entera como argumento"
@@ -41370,25 +41370,25 @@ msgstr "el atributo %qE se aplica solamente a tipos"
 msgid "argument of %qE attribute ignored"
 msgstr "falta el argumento del atributo %qE"
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "el atributo %qE solamente se aplica a variables"
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, fuzzy, gcc-internal-format
 #| msgid "alternatives not allowed in asm flag output"
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "no se permiten alternativas en la salida del indicador asm"
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, fuzzy, gcc-internal-format
 #| msgid "unknown asm flag output %qs"
 msgid "unknown %<asm%> flag output %qs"
 msgstr "salida del indicador asm %qs desconocida"
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for asm flag output"
 msgid "invalid type for %<asm%> flag output"
@@ -41654,7 +41654,7 @@ msgstr "el CPU objetivo no admite las instrucciones THUMB"
 msgid "target CPU does not support unaligned accesses"
 msgstr "el CPU objetivo no admite accesos sin alinear"
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support branch-likely instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -41710,7 +41710,7 @@ msgstr "el límite del tamaño de la estructura sólo se puede establecer a 8 o
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "El PIC de RTP es incompatible con -msingle-pic-base"
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
@@ -41827,7 +41827,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1"
@@ -41868,45 +41868,45 @@ msgstr "el atributo %qE no tiene efecto en funciones con enlazado estático"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "el atributo %qE se aplica solamente al tipo base de un puntero a función"
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd fuera de rango %wd - %wd"
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "no se puede calcular la ubicación real del parámetro apilado"
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Fin de módulo inesperado"
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "no hay registros inferiores disponibles para extraer registros superiores"
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "no se pueden codificar las Rutinas de Servicios de Interrupción en el modo Thumb"
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-check=specific for Thumb-1"
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "-fstack-check=specific para Thumb-1"
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "fpu no válida para el atributo o pragma del objetivo %qs"
@@ -41914,22 +41914,22 @@ msgstr "fpu no válida para el atributo o pragma del objetivo %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "selección automática de fpu actualmente no permitida aquí"
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "arquitectura no válida para el atributo o pragma objetivo %qs"
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "atributo o pragma objetivo %qs desconocido"
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, fuzzy, gcc-internal-format
 #| msgid "address mode %qs not supported in the %s bit mode"
 msgid "%<asm%> flags not supported in thumb1 mode"
@@ -41984,167 +41984,167 @@ msgstr "arquitecturas de núcleo no admitidas:%s"
 msgid "unknown core architecture %qs specified with %qs"
 msgstr "arquitectura de núcleo %qs desconocida especificada con %qs"
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic is not supported"
 msgid "%<-fpic%> is not supported"
 msgstr "no se admite -fpic"
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIC is not supported"
 msgid "%<-fPIC%> is not supported"
 msgstr "no se admite -fPIC"
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, fuzzy, gcc-internal-format
 #| msgid "-fpie is not supported"
 msgid "%<-fpie%> is not supported"
 msgstr "no se admite -fpie"
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIE is not supported"
 msgid "%<-fPIE%> is not supported"
 msgstr "no se admite -fPIE"
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "los atributos de función %qs y %qs son mutuamente excluyentes"
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "la función %qs no puede tener argumentos"
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "la función %qs no puede devolver un valor"
 
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, gcc-internal-format
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs parece ser un manejador %s mal escrito; falta el prefijo %<__vector%>"
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr "%qs es un identificador invertido en AVR-LibC.  Plantéese %<#include <avr/interrupt.h>%> antes de usar la macro %qs"
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr "%qs es un identificador invertido en AVR-LibC.  Plantéese %<#include <avr/interrupt.h>%> antes de usar la macro %qs"
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr "%<builtin_return_address%> sólo contiene 2 bytes de dirección"
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr "el desplazamiento del puntero desde el símbolo tal vez es incorrecto"
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr "se accede a memoria de datos con dirección de memoria de programa"
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr "se accede a memoria de programa con dirección de memoria de datos"
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr "se usó el registro fijo %s para pasar un parámetro a la función"
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "no se admite escribir al espacio de direcciones %qs"
 
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "el atributo %qE se aplica solamente a variables en almacenamiento estático"
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "solo se admite el atributo %qE núcleos Tiny reducidos"
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute address out of range"
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr "la dirección del atributo %qE está fuera de rango"
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr "tanto el atributo %s como el %qE proporcionan dirección"
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "atributo %qE en variable no volátil"
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "no se admiten espacios de direcciones para dispositivos Tiny reducidos"
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "no se admite el espacio de direcciones %qs para dispositivos con tamaño de flash de hasta %d KiB"
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr "el espacio de direcciones %qs que apuntan a punteros debe ser const en %qT"
 
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr "el espacio de direcciones %qs que apuntan a punteros debe ser const en %s %q+D"
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object %qD may not be initialized"
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr "el objeto de tamaño variable %qD no se puede inicializar"
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr "la variable %q+D debe ser const para que se ponga en la sección de sólo lectura a través de %qs"
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, fuzzy, gcc-internal-format
 #| msgid "static IO declaration for %q+D needs an address"
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr "la declaración de ES estática para %q+D necesita una dirección"
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, fuzzy, gcc-internal-format
 #| msgid "only uninitialized variables can be placed in the .noinit section"
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr "Sólo las variables sin inicializar se pueden colocar en la sección .noinit"
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, gcc-internal-format
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr "se colocó la variable %q+D con inicialización dinámica en el área de memoria del programa"
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "se colocó la variable %q+D sin inicializar en el área de memoria del programa"
@@ -42153,43 +42153,43 @@ msgstr "se colocó la variable %q+D sin inicializar en el área de memoria del p
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object %qD may not be initialized"
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr "el objeto de tamaño variable %qD no se puede inicializar"
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%q+D tiene atributos incompatibles %qs y %qs"
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr "la arquitectura %qs sólo se admite para ensamblador"
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "vonversión del espacio de direcciones %qs al espacio de direcciones %qs"
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "%s expera una constante entera en tiempo de compilación"
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%s espera una constante entera long en tiempo de compilación como primer argumento"
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr "redondear a %d bits no tiene ningún efecto en valores de coma fija con %d bits de fracción"
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr "el resultado del redondeo será siempre 0"
@@ -42346,7 +42346,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "la llamada requiere ifunc, que no se admite en este objetivo"
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, gcc-internal-format
@@ -43035,8 +43035,8 @@ msgstr "el penúltimo argumento debe ser un inmediato de 8-bit"
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr "Las versiones de funciones no pueden marcarse como gnu_inline; hay que generar cuerpos"
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "el modelo de código %s no admite el modo PIC"
@@ -43107,273 +43107,273 @@ msgstr "se especificaron demasiados rangos de tamaños en la opción %qs"
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "parámetro desconocido para la opción -mtune-ctrl: %s"
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "no se admite Intel MCU psABI en el modo %s"
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> es obsoleto; use en su lugar %<-mtune=k8%> o %<-mtune=generic%> como sea adecuado"
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> es obsoleto; use %<target(\"tune=k8\")%> o %<target(\"tune=generic\")%> en su lugar como convenga"
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "no se admite -mstringop-stategy=rep_8byte para código de 32-bit"
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32-bit systems"
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "-mcmodel= no se admite en sistemas de 32 bits"
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32-bit systems"
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr "-mcmodel= no se admite en sistemas de 32 bits"
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "no se admite -mstringop-stategy=rep_8byte para código de 32-bit"
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32-bit systems"
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "-mcmodel= no se admite en sistemas de 32 bits"
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "el modelo de direcciones %qs no se admite en el modo de bit %s"
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, fuzzy, gcc-internal-format
 #| msgid "-mabi=ms not supported with X32 ABI"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "no se admite -mabi=ms con X32 ABI"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, fuzzy, gcc-internal-format
 #| msgid "transactional memory is not supported with %<-fsanitize=address%>"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "la memoria transaccional no se admite con %<-fsanitize=address%>"
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, fuzzy, gcc-internal-format
 #| msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "la memoria transaccional no se admite con %<-fsanitize=kernel-address%>"
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fsanitize=leak%> is incompatible with %<-fsanitize=thread%>"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "%<-fsanitize=leak%> es incompatible con %<-fsanitize=thread%>"
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "el modelo de código %qs no se admite en el modo de bit %s"
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "el modelo de código %qs no se admite en modo x32"
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, fuzzy, gcc-internal-format
 #| msgid "-masm=intel not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "no se admite -masm=intel en esta configuración"
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "no está compilado el modo bit-%i"
 
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "la CPU %<generic%> solo se puede usar para el ajuste %<-tune=%>"
 
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "la CPU %<generic%> solo se puede usar para el atributo %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "la CPU %<intal%> solo se puede usar para el ajuste %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "la CPU %<intel%> solo se puede usar para el atributo %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "el CPU que seleccionó no admite el conjunto de instrucciones x86-64"
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<-march=%> switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "valor erróneo (%qs) para la opción %<-march=%>"
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "valor erróneo (%qs) para el atributo %<target(\"arch=\")%>"
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para la opción %<-march=%> son: %s; ¿quiso decir %qs?"
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para el atributo %<target(\"arch=\")%> son: %s; ¿qiuso decir %qs?"
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "los argumentos válidos para la opción %<-march=%> son: %s"
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "los argumentos válidos para el atributo %<target(\"arch=\")%> son: %s"
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<-mtune=%> switch"
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "valor erróneo (%qs) para la opción %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "valor erróneo (%qs) para el atributo %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para la opción %<-mtune=%> son: %s; ¿quiso decir %qs?"
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para el atributo %<target(\"tune=\")%> son: %s; ¿quiso decir %qs?"
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "los argumentos válidos para la opción %<-mtune=%> son: %s"
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "los argumentos válidos para el atributo %<target(\"tune=\")%> son: %s"
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored in 64-bit mode"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "se descarta -mregparm en modo de 64-bit"
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored for Intel MCU psABI"
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "se descarta -mregparm para Intel MCU psABI"
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d no está entre 0 y %d"
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "-mnop-mcount no es compatible con este objetivo"
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "se descarta %<-mrtd%> en el modo de 64bit"
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "se descarta %<target(\"rtd\")%> en el modo de 64bit"
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr ""
@@ -43381,311 +43381,311 @@ msgstr ""
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr ""
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary is not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "no se admite -mpreferred-stack-boundary en este objetivo"
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d no está entre %d y %d"
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, fuzzy, gcc-internal-format
 #| msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d no está entre %d y 12"
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-mnop-mcount no es compatible con este objetivo"
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not implemented for -fPIC"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "-mnop-mcount no está implementada para -fPIC"
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "se usó %<-msseregparm%> sin SSE activado"
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "se usó %<target(\"ssseregparm\")%> sin SSE activado"
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "el conjunto de instrucciones SSE está desactivado, usando la aritmética 387"
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "el conjunto de instrucciones 387 está desactivado, usando la aritmética SSE"
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "la prueba de pila requiere %<-maccumulate-outgoing-args%> para ser correcta"
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "la prueba de pila requiere %<target(\"accumulate-outgoing-args\"%> para ser correcta"
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "el registro ebp fijo requiere %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "el registro ebp fijo requiere %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, fuzzy, gcc-internal-format
 #| msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "-mfentry no se admite para 32-bit en combinación con -fpic"
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry no es compatible con SEH"
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, fuzzy, gcc-internal-format
 #| msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "-mcall-ms2sysv-xlogues no es compatible con %s"
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, fuzzy, gcc-internal-format
 #| msgid "unknown option for -mrecip=%s"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "opción desconocida para -mrecip=%s"
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs no es un número válido en -mstack-protector-guard-offset="
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs no es un desplazamiento válido en -mstack-protector-guard-offset="
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs no es un registro base válido en -mstack-protector-guard-reg="
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr ""
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-mnop-mcount no es compatible con este objetivo"
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "interrupción y atributos desnudos no es compatible"
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, fuzzy, gcc-internal-format
 #| msgid "ms_abi and sysv_abi attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "los atributos ms_abi y sysv_abi no son compatibles"
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, fuzzy, gcc-internal-format
 #| msgid "Only DWARF debug format is supported for interrupt service routine."
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr "Solo se admite el formato de depuración DWARF para la rutina de servicio de interrupciones."
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mfunction-return=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "las instrucciones %s no se permiten en la rutina de servicio %s"
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "las instrucciones %s no se permiten en la rutina de servicio %s"
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "Las instrucciones %s no están permitidas en funciones con el atributo no_caller_saved_registers"
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "los atributos fastcall y regparm no son compatibles"
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "los atributos regparam y thiscall no son compatibles"
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "el atributo %qE requiere un argumento constante entero"
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "el argumento para el atributo %qE es más grande que %d"
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "los atributos fastcall y cdecl no son compatibles"
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "los atributos fastcall y stdcall no son compatibles"
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "los atributos fastcall y thiscall no son compatibles"
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "los atributos stdcall y cdecl no son compatibles"
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "los atributos stdcall y fastcall no son compatibles"
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "los atributos stdcall y thiscall no son compatibles"
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "los atributos cdecl y thiscall no son compatibles"
 
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "se usó el atributo %qE para método no de clase"
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "se descarta el atributo incompatible %qE"
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "el atributo %qE solamente está disponible para 64-bit"
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "el argumento del atributo %qE no es cero ni uno"
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "el atributo %qE requiere una constante entera como argumento"
 
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "el argumento del atributo %qE no es (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "la rutina de servicio de interrupciones debería tener un puntero como primer argumento"
 
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "la rutina de atención de interrupciones debería tener como segundo argumento un unsigned %sint"
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "la rutina de servicio de interrupciones solo puede tener un argumento puntero y un argumento entero opcional"
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine can't have non-void return value"
 msgid "interrupt service routine must return %<void%>"
@@ -43895,53 +43895,53 @@ msgstr "no se admite el tamaño de operando para el registro extendido"
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "se usó un operando que no es entero con el código de operando 'z'"
 
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr "la alineación de %qD es más grande que la declaración original"
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 #, fuzzy
 #| msgid "the mangling of %<va_list%> has changed in GCC 4.4"
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr "la decodificación de %<va_list%> cambió en GCC 4.4"
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, fuzzy, gcc-internal-format
 #| msgid "no low registers available for popping high registers"
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr "no hay registros inferiores disponibles para extraer registros superiores"
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32-bit systems"
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "-mcmodel= no se admite en sistemas de 32 bits"
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr ""
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "modelo de memoria específico de la arquitectura desconocido"
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, fuzzy, gcc-internal-format
 #| msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr "HLE_ACQUIRE no se usa con ACQUIRE o modelos de memoria más fuertes"
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, fuzzy, gcc-internal-format
 #| msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr "HLE_RELEASE no se usa con RELEASE o modelos de memoria más fuertes"
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, fuzzy, gcc-internal-format
 #| msgid "-fdirectives-only is incompatible with -traditional"
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
@@ -43963,8 +43963,8 @@ msgstr "la definición de los datos miembro static %q+D de la clase dllimportada
 msgid "malformed %<#pragma builtin%>"
 msgstr "#pragma builtin malformado"
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, gcc-internal-format
 msgid "invalid argument of %qE attribute"
 msgstr "argumento no válido del atributo %qE"
@@ -44024,12 +44024,12 @@ msgstr "PRINT_OPERAND: Puntuación desconocida '%c'"
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr "PRINT_OPERAND puntero nulo"
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "el argumento %d para la función interna debe ser una constante en el rango entre %d y %d"
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, gcc-internal-format
 msgid "failed to expand built-in function"
 msgstr "fallo al expandir función interna"
@@ -44164,19 +44164,19 @@ msgstr "%qD no es compatible con %qD"
 msgid "%qs cannot be used for compiling a shared library"
 msgstr "%<constexpr%> no se puede usar en declaraciones de tipo"
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr "no se puede especificar el atributo %qE para las variables locales"
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for register variables"
 msgstr "no se puede especificar el atributo %qE para las variables locales"
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "multiple %qE attribute"
@@ -44290,12 +44290,12 @@ msgstr "no se permiten atributos interrupt múltiples"
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr "interrupt_thread sólo está disponible en fido"
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "no se admite la expresión del límite de la pila"
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fcf-protection=full%> is not supported for this target"
 msgid "%<-fexcess-precision=16%> is not supported on this target"
@@ -44342,7 +44342,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr "-mxl-multiply-high requiere -mno-xl-soft-mul"
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "el atributo %qE requiere una cadena como argumento"
@@ -44385,136 +44385,136 @@ msgstr "el vector de interrupciones para %qE no es vector=(sw0|sw1|hw0|hw1|hw2|h
 msgid "argument to %qE attribute is not intstack"
 msgstr "el argumento del atributo %qE no es intstack"
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, gcc-internal-format
 msgid "cannot handle inconsistent calls to %qs"
 msgstr "no se pueden manejar llamadas inconsistentes a %qs"
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr "el atributo %<interrupt%> requiere un procesador MIPS32r2 o superior"
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr "los manejadores de interrupciones no pueden ser funciones MIPS16"
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-check=specific not implemented for MIPS16"
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr "-fstack-check=specific no implementado para MIPS16"
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, gcc-internal-format
 msgid "built-in function %qE not supported for MIPS16"
 msgstr "no se admite la función interna %qE para MIPS16"
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, gcc-internal-format
 msgid "%qs does not support MIPS16 code"
 msgstr "%qs no admite código MIPS16"
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr "PIC MIPS16 para ABIs diferentes de o32 y o64"
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, fuzzy, gcc-internal-format
 #| msgid "MIPS16 -mxgot code"
 msgid "MIPS16 %<-mxgot%> code"
 msgstr "código MIPS16 -mxgot"
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, fuzzy, gcc-internal-format
 #| msgid "hard-float MIPS16 code for ABIs other than o32 and o64"
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr "código MIPS16 de coma flotante hard para ABIs diferentes de o32 y o64"
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, gcc-internal-format
 msgid "MSA MIPS16 code"
 msgstr "código MSA MIPS16"
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr "%<-mno-gpopt%> necesita %<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported combination: %s"
 msgstr "no se admite la combinación: %s"
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, gcc-internal-format
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr "%<-%s%> genera un conflicto con las otras opciones de la arquitectura, las cuales especifican un procesador %s"
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, gcc-internal-format
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr "%<-march=%s%> no es compatible con la ABI seleccionada"
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr "se utiliza %<-mgp64%> con un procesador de 32-bit"
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, gcc-internal-format
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr "se utiliza %<-mgp32%> con una ABI de 64-bit"
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr "se utiliza %<-mgp64%> con una ABI de 32-bit"
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "la arquitectura %qs no admite %<-mfp32%>"
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr "%<-mgp32%> y %<-mfp64%> sólo se pueden combinar si el objetivo admite las instrucciones mfhc1 y mthc1"
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr "%<-mgp32%> y %<-mfp64%> sólo se pueden combinar al usar la ABI o32"
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr "%<-mfpxx%> solo se puede usar con la ABI o32"
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr "%<-march=%s%> requiere %<-mfp32%>"
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr "%<-mfpxx%> requiere %<-mlra%>"
@@ -44524,119 +44524,119 @@ msgstr "%<-mfpxx%> requiere %<-mlra%>"
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, gcc-internal-format
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr "la combinacion de %qs y %qs es incompatible con %qs"
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, gcc-internal-format
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr "la arquitectura %qs no admite las instrucciones con probabilidad de ramificación"
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, gcc-internal-format
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr "la arquitectura %qs no admite las instrucciones madd ni msub"
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr "la arquitectura %qs no admite los registros de precisión sencilla impar"
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, gcc-internal-format
 msgid "unsupported combination: %qs%s %s"
 msgstr "no se admite la combinación: %qs%s %s"
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, gcc-internal-format
 msgid "unsupported combination: %qs %s"
 msgstr "no se admite la combinación: %qs %s"
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, gcc-internal-format
 msgid "cannot generate position-independent code for %qs"
 msgstr "no se puede generar código independiente de posición para %qs"
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, gcc-internal-format
 msgid "position-independent code requires %qs"
 msgstr "el código independiente de posición requiere %qs"
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr "%<-mno-gpopt%> necesita %<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr "no se pueden usar accesos de data small para %qs"
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr "la arquitectura %qs no admite %<-m%s=legacy%>"
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr "la arquitectura %qs no admite %<-m%s=2008%>"
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, gcc-internal-format
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr "%<-mips3d%> requiere %<-mpaired-single%>"
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, gcc-internal-format
 msgid "%qs must be used with %qs"
 msgstr "%qs se debe usar con %qs"
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, gcc-internal-format
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr "%<-mmsa%> debe usarse con %<-mfp64%> y %<-mhard-float%>"
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, gcc-internal-format
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr "la arquitectura %qs no admite las instrucciones par-sencillo"
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr "%qs requiere un objetivo que provea la instrucción %qs"
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, gcc-internal-format
 msgid "the %qs architecture does not support DSP instructions"
 msgstr "la arquitectura %qs no admite las instrucciones DSP"
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr "%<-mmsa%> debe usarse con %<-mfp64%> y %<-mhard-float%>"
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr "%<-mmsa%> debe usarse con %<-mfp64%> y %<-mhard-float%>"
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, gcc-internal-format
 msgid "%qs requires branch-likely instructions"
 msgstr "%qs requiere instrucciones con probabilidad de ramificación"
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, gcc-internal-format
 msgid "the %qs architecture does not support the synci instruction"
 msgstr "la arquitectura %qs no admite la instrucción synci"
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr "análisis de perfil de las funciones mips16"
@@ -45608,63 +45608,63 @@ msgstr "%<#pragma GCC optimize%> no es una cadena o un número"
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "basura al final de #pragma GCC coprocessor %E"
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<target()%> pragma or attribute"
 msgid "malformed %<target()%> attribute"
 msgstr "pragma o atributo %<target()%> mal formado"
 
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, fuzzy, gcc-internal-format
 #| msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "el pragma o atributo %<target(\"%s\")%> no acepta un argumento"
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, fuzzy, gcc-internal-format
 #| msgid "empty string in attribute %<target%>"
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr "cadena vacía en el atributo %<target%>"
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgid "malformed %<target(\"%s\")%> attribute"
@@ -45734,194 +45734,218 @@ msgstr "no se puede asignar un objeto de tipo abstracto %qT"
 msgid "capture by copy of RVV type %qT"
 msgstr "uso no válido del tipo incompleto %q#T"
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, fuzzy, gcc-internal-format
+#| msgid "Builtin function %s requires the -mhtm option"
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr "La función interna %s requiere la opción -mhtm"
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, fuzzy, gcc-internal-format
+#| msgid "Builtin function %s requires the -mpaired option"
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr "La función interna %s requiere la opción -mpaired"
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, fuzzy, gcc-internal-format
+#| msgid "Builtin function %s requires the -mvsx option"
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr "La función interna %s requiere la opción -mvsx"
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, fuzzy, gcc-internal-format
+#| msgid "Builtin function %s requires the -mvsx option"
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr "La función interna %s requiere la opción -mvsx"
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin function %s requires the -mvsx option"
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr "La función interna %s requiere la opción -mvsx"
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function call to %qE with empty arguments"
 msgstr "no hay una función coincidente para la llamada a %<%D(%A)%>"
 
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, fuzzy, gcc-internal-format
 #| msgid "unknown cpu %qs for -mtune"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "cpu %qs desconocida para -mtune"
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the SPE ABI extensions."
 msgid "this operation requires the RVV ISA extension"
 msgstr "No usa las extensiones de ABI SPE."
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "la ABI para pasar una estructura con un miembro de coma flotante compleja cambió en GCC 4.4"
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr "Se pasó un argumento Altivec a una función sin prototipo"
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, fuzzy, gcc-internal-format
 #| msgid "Use the SPE ABI extensions."
 msgid "%s %qT requires the V ISA extension"
 msgstr "Usa las extensiones de ABI SPE."
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, fuzzy, gcc-internal-format
 #| msgid "Use the SPE ABI extensions."
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr "Usa las extensiones de ABI SPE."
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, fuzzy, gcc-internal-format
 #| msgid "Use the SPE ABI extensions."
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr "Usa las extensiones de ABI SPE."
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, fuzzy, gcc-internal-format
 #| msgid "Use the SPE ABI extensions."
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr "Usa las extensiones de ABI SPE."
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, fuzzy, gcc-internal-format
 #| msgid "Use the SPE ABI extensions."
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr "Usa las extensiones de ABI SPE."
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr ""
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, fuzzy, gcc-internal-format
 #| msgid "builtin function %qs requires the %qs option"
 msgid "function attribute %qs requires the V ISA extension"
 msgstr "la función interna %qs requiere la opción %qs"
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute is neither zero, nor one"
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "el argumento del atributo %qE no es cero ni uno"
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr ""
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "%qs applied to non-RVV type %qT"
 msgstr "sizeof aplicado a un tipo de función"
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires an integer constant argument"
 msgid "%qs requires an integer constant"
 msgstr "el atributo %qE requiere un argumento constante entero"
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, fuzzy, gcc-internal-format
 #| msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "-mdiv requiere -march para subsumir la extensión %<M%>"
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support ARM mode"
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr "el CPU objetivo no tiene soporte para el modo ARM"
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs with -f%s"
 msgid "code model %qs with %qs"
 msgstr "modelo de código %qs con -f%s"
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, fuzzy, gcc-internal-format
 #| msgid "requested ABI requires -march to subsume the %qc extension"
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "la ABI solicitada requiere -march para subsumir la extensión %qc"
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, gcc-internal-format
 msgid "rv64e requires lp64e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr ""
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, fuzzy, gcc-internal-format
 #| msgid "ABI requires -march=rv%d"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "ABI requiere -march=rv%d"
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d debe estar entre %d y %d"
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs no es un registro base válido en %qs"
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs no es un número válido en %qs"
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "%qs function cannot have different interrupt type"
 msgstr "la función %qs no puede tener argumentos"
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr ""
@@ -46193,36 +46217,36 @@ msgstr "el interno %qs sólo acepta 2 argumentos"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "el interno %qs solo acepta 3 argumentos"
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, fuzzy, gcc-internal-format
 #| msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl está obsoleta para little endian; utilize asignación para cargas y almacenajes no alineados"
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, fuzzy, gcc-internal-format
 #| msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr está obsoleta para little endian; utilize asignación para cargas y almacenajes no alineados"
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr "el paso del argumento %d de %qE descarta el calificador %qv del tipo del destino del puntero"
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "combinación de parámetros no válida para el intrínseco AltiVec %qs"
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %qs requires builtin %qs"
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr "la función interna %qs requiere la función interna %qs"
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
@@ -46265,31 +46289,23 @@ msgstr "operadores no válidos de tipos %qT y %qT para el binario %qO"
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "vector GCC pasado por referencia: extensión ABI que no es estándar sin garantía de compatibilidad"
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, fuzzy, gcc-internal-format
-#| msgid "Use the ELFv2 ABI."
-msgid "%qs requires the ELFv2 ABI"
-msgstr "Usa el ABI ELFv2."
-
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "marco de pila demasiado grande"
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incorrect number of arguments to function %qE"
 msgid "unsupported number of nops before function entry (%u)"
 msgstr "número incorrecto de argumentos para la función %qE"
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%qs usa el registro r29"
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, fuzzy, gcc-internal-format
 #| msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
@@ -46423,109 +46439,119 @@ msgstr "%qs necesita un registro bae válido"
 msgid "unknown option for %<%s=%s%>"
 msgstr "opción desconocida para %<%s=%s%>"
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4837
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4855
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs está obsoleto y no está recomendada bajo ninguna circunstancia"
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "no hay análisis de perfil del código de 64-bit para esta ABI"
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "no se puede tomar la dirección de una función anindada si se usa la opción %qs"
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "el uso de %<long double%> en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "el uso de tipos booleanos en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "el uso de %<complex%> en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, fuzzy, gcc-internal-format
 #| msgid "use of decimal floating point types in AltiVec types is invalid"
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "el uso de tipos de coma flotante decimal en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "el uso de %<long%> en tipos AltiVec no es válido para código de 64 bits sin %qs"
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "el uso de %<long%> en tipos AltiVec es obsoleto; use %<int%>"
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "el uso de %<long long%> en tipos AltiVec no es válido sin %qs"
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "el uso de %<double%> en tipos AltiVec no es válido sin %qs"
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "cpu %qs no válida para %s%qs%s"
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s no está permitido"
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s no es válido"
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno=%s%> anula %<-m%s%>"
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "No se admiten versiones múltiples de funciones virtuales"
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, fuzzy, gcc-internal-format
 #| msgid "builtin function %qs requires the %qs option"
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "la función interna %qs requiere la opción %qs"
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, fuzzy, gcc-internal-format
 #| msgid "builtin function %qs requires the %qs option"
 msgid "type %<__vector_pair%> requires the %qs option"
@@ -46577,7 +46603,7 @@ msgstr "las instrucciones FPU de RX no admiten NaNs e infinitos"
 msgid "builtin %qs can only be used on vector types"
 msgstr "la interna vec_step solo puede usarse con tipos vectoriales."
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "se requiere un valor constante para la interna %qF, argumento %d"
@@ -46654,250 +46680,250 @@ msgstr "%qs es obsoleto"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "el argumento constante %d para la función interna %qF está fuera de rango para el tipo de objetivo"
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument %d for builtin %qF is out of range ("
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr "el argumento constante %d para la función interna %qF está fuera de rango ("
 
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument %d for builtin %qF is out of range (0.."
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr "el argumento constante %d para la función interna %qF está fuera de rango (0.."
 
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument %d for builtin %qF is out of range (0.."
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr "el argumento constante %d para la función interna %qF está fuera de rango (0.."
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr "la función interna %qF no se admite sin -mhtm (predeterminado con -march=zEC12 y superiores)."
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr "la función interna %qF requiere -mvx (predeterminado con -march=z13 y superiores)."
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin %qF requires z14 or higher."
 msgid "Builtin %qF requires z14 or higher"
 msgstr "la función interna %qF requiere z14 o superior."
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin %qF requires z14 or higher."
 msgid "Builtin %qF requires z15 or higher"
 msgstr "la función interna %qF requiere z14 o superior."
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "unresolved overloaded builtin"
 msgstr "<tipo de función sobrecargada sin resolver>"
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "icode interno erróneo"
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "argumento no válido %d para la función interna %qF"
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "el atributo %qE solicitado no es una pareja de constantes enteras no negativas separadas por coma o es demasiado grande (máx. %d)"
 
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "el argumento del atributo %qE no es (keep|thunk|thunk-extern)"
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "el tamaño total de las variables locales excede el límite de la arquitectura"
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr "el tamaño de marco de la función %qs de %wd bytes excede el límite de pila definido por el usuario de %d bytes.  Se agrega una trampa incondicional."
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr "el tamaño de marco de la función %qs de %wd bytes es mayor que la mitad del tamaño de la pila. La revisión dinámica no será confiable. No se emitirá revisión para esta función."
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "el tamaño de marco de %qs es de %wd bytes"
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs utiliza alojamiento dinámico de pila"
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, fuzzy, gcc-internal-format
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1"
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, fuzzy, gcc-internal-format
 #| msgid "%<__RTL%> function cannot be compiled with %<-flto%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "la función %<__RTL%> no se puede compilar con %<-flto%>"
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "no se admite la ABI de 64-bit en el modo ESA/390"
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, fuzzy, gcc-internal-format
 #| msgid "thunk-inline is only supported with -mindirect-branch-jump"
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr "thunk-inline solo se admite con -mindirect-branch-jump"
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "vector de hardware no está disponible en %s"
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, fuzzy, gcc-internal-format
 #| msgid "hardware vector support not available with -msoft-float"
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "vector de hardware no está disponible con -msoft-float"
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr "las instrucciones de coma flotante decimal de hardware no están disponibles en %s"
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, fuzzy, gcc-internal-format
 #| msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr "las instrucciones de coma flotante decimal de hardware no están disponibles en el modo ESA/390"
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, fuzzy, gcc-internal-format
 #| msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr "-mhard-dfp no se puede usar en conjunción con -msoft-float"
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "no se admiten -mbackchain -mpacked-stack -mhard-float en combinación"
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "el tamaño de la pila debe ser mayor que el valor de la guardia de pila"
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "el tamaño de la pila no debe ser mayor a 64k"
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard implica el uso de -mstack-size"
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is supported only for SH2A"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "el atributo %qE solo se admite para SH2A"
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "los argumentos para %qs deben ser enteros no negativos"
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "el argumento para %qs es demasiado grande (máx. %d)"
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-pic-data-is-text-relative cannot be used without -fpic/-fPIC"
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr "-mno-pic-data-is-text-relative no puede utilizarse sin -fpic/-fPIC"
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr "se desconoce attribute(target(\"%s\"))"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "no se admite el valor %qs para el atributo %<target%>"
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, fuzzy, gcc-internal-format
 #| msgid "invalid fp constant"
 msgid "invalid cc output constraint: %qs"
 msgstr "constante fp no válida"
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, fuzzy, gcc-internal-format
 #| msgid "-mhard-float not supported"
 msgid "multiple cc output constraints not supported"
 msgstr "no se admite -mhard-float"
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, fuzzy, gcc-internal-format
 #| msgid "asm-specifier for variable %qE conflicts with asm clobber list"
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr "el especificador asm para la variable %qE genera un conflicto con la lista de sobreescritura de asm"
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for pointer diff"
 msgid "invalid type for cc output constraint"
@@ -47369,8 +47395,8 @@ msgstr "el atributo %qE no tiene efecto"
 msgid "attribute %qs applies to array types only"
 msgstr "el atributo %qs solamente se aplica a tipos de matriz"
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "no se descarta el valor void como debería de ser"
@@ -47447,7 +47473,7 @@ msgstr "el tipo de la matriz %q+D se completó de forma incompatible con la inic
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr "%qD ya se declaró en este ámbito"
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "se definió originalmente aquí"
@@ -47692,7 +47718,7 @@ msgstr "la declaración de %q+D oscurece a una declaración previa que no es var
 msgid "declaration of %qD shadows a parameter"
 msgstr "la declaración de %qD oscurece un parámetro"
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "la declaración de %qD oscurece a una declaración global"
@@ -47702,7 +47728,7 @@ msgstr "la declaración de %qD oscurece a una declaración global"
 msgid "declaration of %qD shadows a previous local"
 msgstr "la declaración de %qD oscurece a una declaración local previa"
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "aquí está la declaración oscurecida"
@@ -47768,7 +47794,7 @@ msgstr "%qE no se declaró aquí (primer uso en esta función)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "cada identificador sin declarar se reporta sólo una vez para cada función en el que aparece"
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "la etiqueta %qE es referenciada fuera de cualquier función"
@@ -47803,7 +47829,7 @@ msgstr "salto a una expresión de declaración"
 msgid "duplicate label declaration %qE"
 msgstr "declaración duplicada de la etiqueta %qE"
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "etiqueta %qD duplicada"
@@ -47839,7 +47865,7 @@ msgstr "switch salta dentro de una expresión de declaración"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE definido como un tipo erróneo de etiqueta"
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute applied to %qD with void return type"
@@ -47992,12 +48018,12 @@ msgstr "ISO C90 no admite declaradores de matriz %<[*]%>"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "no se permite %<[*]%> en otro lugar que no sea el ámbido de prototipo de función"
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<omp::%s%> not allowed to be specified in this context"
@@ -48008,7 +48034,7 @@ msgstr "no se puede usar %<this%> en este contexto"
 msgid "%q+D is usually a function"
 msgstr "%q+D generalmente es una función"
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "no hay declaración previa para %qD"
@@ -48088,7 +48114,7 @@ msgstr "no se puede poner un objeto con un campo volatile en register"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "const %qD sin inicializar es no válida en C++"
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D en directiva de objetivo de declaración no tiene tipo asociable"
@@ -48279,7 +48305,7 @@ msgstr "se especificó una clase de almacenamiento para el parámetro %qE"
 msgid "storage class specified for unnamed parameter"
 msgstr "se especificó una clase de almacenamiento para un parámetro sin nombre"
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "se especificó una clase de almacenamiento para el nombre de tipo"
@@ -48342,7 +48368,7 @@ msgstr "declaración de %qE como una matriz de funciones"
 msgid "declaration of type name as array of functions"
 msgstr "declaración de nombre de tipo como una matriz de funciones"
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "uso no válido de una estructura con un miembro de matriz flexible"
@@ -48448,7 +48474,7 @@ msgstr "el nombre de tipo que se declaró como función devuelve una matriz"
 msgid "function definition has qualified void return type"
 msgstr "la definición de la función tiene un tipo de devolución void calificado"
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
@@ -48575,7 +48601,7 @@ msgstr "ISO C prohíbe los tipos de función const o volatile"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "un miembro de una estructura o union no puede tener un tipo modificado variablemente"
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "se declaró la variable o campo %qE como void"
@@ -48684,7 +48710,7 @@ msgstr "función no anidada con tipo modificado variablemente"
 msgid "object with variably modified type must have no linkage"
 msgstr "un objeto con tipo modificado variablemente no debe tener enlace"
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "la declaración de la función no es un prototipo"
@@ -48774,18 +48800,18 @@ msgstr "redefinición anidada de %<union %E%>"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "redefinición anidada de %<struct %E%>"
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "la definición de tipo en %qs es no válida en C++"
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, fuzzy, gcc-internal-format
 #| msgid "unknown field %qE specified in initializer"
 msgid "%qT defined in underspecified object initializer"
 msgstr "se especificó el campo desconocido %qE en el inicializador"
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "la declaración no declara nada"
@@ -48815,362 +48841,362 @@ msgstr "una struct vacía tiene tamaño 0 en C y tamaño 1 en C++"
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr "una union vacía tiene tamaño 0 en C y tamaño 1 en C++"
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union no tiene miembros nombrados"
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union no tiene miembros"
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "struct no tiene miembros nombrados"
 
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct no tiene miembros"
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "miembro de matriz flexible en union"
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "el miembro de matriz flexible no está al final del struct"
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "miembro de matriz flexible en estructura sin miembros con nombre"
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr "el miembro de matriz flexible no está al final del struct"
 
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "el tipo %qT es demasiado grande"
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized scalar storage order value %qs"
 msgid "type punning toggles scalar storage order"
 msgstr "no se reconoce el valor del orden de almacenamiento de escalares %qs"
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union no se puede hacer transparente"
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of typedef %q+D with variably modified type"
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr "redefinición de la definición de tipo %q+D con un tipo modificado variablemente"
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %<struct %E%>"
 msgid "redefinition of struct or union %qT"
 msgstr "redefinición de %<struct %E%>"
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "redefinición anidada de %<enum %E%>"
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "redeclaración de %<enum %E%>"
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
 msgstr "el modo especificado es demasiado pequeño para valores enumerados"
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "los valores de enumeración exceden el rango del entero más grande"
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration values exceed range of largest integer"
 msgid "enumeration values exceed range of %qs"
 msgstr "los valores de enumeración exceden el rango del entero más grande"
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of %<enum %E%>"
 msgid "conflicting redefinition of enum %qT"
 msgstr "redefinición anidada de %<enum %E%>"
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "el valor de enumerador para %qE no es una constante entera"
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "el valor de enumerador para %qE no es una expresión constante entera"
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "desbordamiento en valores de enumeración"
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value outside the range of underlying type"
 msgstr "el valor de enumerador %E es demasiado grande para el tipo subyacente %<%T%>"
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value outside the range of %qs"
 msgstr "el valor de enumerador %E es demasiado grande para el tipo subyacente %<%T%>"
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr "ISO C restringe los valores de enumeración al rango de %<int%>"
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %qD given attribute noinline"
 msgid "inline function %qD given attribute %qs"
 msgstr "se le dió a la función incluida en línea %qD un atributo noinline"
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "el tipo de devolución es un tipo de dato incompleto"
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "el tipo de devolución por defecto es %<int%>"
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about global functions without prototypes"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "Avisa sobre funciones globales sin prototipos"
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "no hay un prototipo previo para %qD"
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "se usó %qD sin prototipo antes de su definición"
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "se usó %qD sin declaración antes de su definición"
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "el tipo de devolución de %qD no es %<int%>"
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "calificado %<_Atomic%> el tipo de retorno de %qD"
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD generalmente es una función que no es static"
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "declaraciones de parámetros de estilo antiguo en la definición de una función prototipo"
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "C tradicional rechaza la definición de funciones de estilo ISO C"
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr "ISO C no admite coma flotante decimal"
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "definición de función de estilo antiguo"
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "falta el nombre del parámetro de la lista de parámetros"
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD se declaró como un no-parámetro"
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "múltiples parámetros nombrados %qD"
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "el parámetro %qD se declaró con tipo void"
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "el tipo de %qD es %<int%> por defecto"
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "el parámetro %qD tiene tipo incompleto"
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "existe la declaración para el parámetro %qD pero no hay tal parámetro"
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "el número de argumentos no coinciden con el prototipo interno"
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "el número de argumentos no coinciden con el prototipo"
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "declaración de prototipo"
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "el argumento promovido %qD no coincide con el prototipo interno"
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "el argumento promovido %qD no coincide con el prototipo"
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "el argumento %qD no coincide con el prototipo interno"
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "el argumento %qD no coincide con el prototipo"
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "no hay una declaración de devolución en la función que no devuelve void"
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "se definió el parámetro %qD pero no se usa"
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "sólo se permiten las declaraciones iniciales del bucle %<for%> en modo C99 o C11"
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, fuzzy, gcc-internal-format
 #| msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "use la opción -std=c99, -std=gnu99, -std=c11 o -std=gnu11 para compilar su código"
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 no admite declaradores de matriz %<[*]%>"
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "declaración de la variable static %qD en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "declaración de la variable %<extern%> %qD en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> se declaró en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> se declaró en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> se declaró en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "declaración de %qD que no es variable en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "calificadores de espacio de direcciones incompatibles %qs y %qs"
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "especificador %qE de declaración duplicado"
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "múltiples clases de almacenamiento en los especificadores de declaración"
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<auto%>"
 msgid "%qs used with %<auto%>"
@@ -49178,262 +49204,262 @@ msgstr "se usó %qE con %<auto%>"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<register%>"
 msgid "%<auto%> used with %<constexpr%>"
 msgstr "se usó %qE con %<register%>"
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "dos o más tipos de datos en los especificadores de la declaración"
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> es demasiado largo para GCC"
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 no admite %<long long%>"
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 no admite tipos complejos"
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C no admite tipos saturantes"
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE duplicado"
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C no admite los tipos %<__int%d%>"
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "no se admite %<__int%d%> para este objetivo"
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 no admite tipos booleanos"
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support the %<_Float%d%s%> type"
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr "ISO C no admite el tipo %<_float%d%s%>"
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "no se admite %<_float%d%s%> para este objetivo"
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr "ISO C no admite coma flotante decimal"
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "no se admiten tipos de coma fija para este objetivo"
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C no admite tipos de coma fija"
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, fuzzy, gcc-internal-format
 #| msgid "case label is not an integer constant expression"
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr "la etiqueta de case no es una expresion constante entera"
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant expression"
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr "el valor de enumerador para %qE no es una expresión constante entera"
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr ""
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "la búsqueda en C++ de %qD devolvería un campo, no un tipo"
 
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE falla al ser un typedef o un tipo interno del compilador"
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE no está al inicio de la declaración"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "se usó %qE con %<auto%>"
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "se usó %qE con %<register%>"
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "se usó %qE con %<typedef%>"
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<register%>"
 msgid "%qE used with %<constexpr%>"
 msgstr "se usó %qE con %<register%>"
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 no admite %qE"
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 no admite %qE"
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> antes de %<extern%>"
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> antes de %<static%>"
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<auto%>"
 msgid "%<typedef%> used with %<auto%>"
 msgstr "se usó %qE con %<auto%>"
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<register%>"
 msgid "%qE used with %<extern%>"
 msgstr "se usó %qE con %<register%>"
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, fuzzy, gcc-internal-format
 #| msgid "%qs used with %qE"
 msgid "%qE used with %qs"
 msgstr "se usó %qs con %qE"
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "%<_Thread_local%> o %<__thread%> duplicado"
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "se usó %qs con %qE"
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%<constexpr%> used with %qE"
 msgstr "se usó %<__thread%> con %qE"
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "se usó %<_Sat%> sin %<_Fract%> o %<_Accum%>"
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C no admite %<complex%> simples que significan %<double complex%>"
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr "ISO C90 no admite declaradores de matriz %<[*]%>"
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C no admite tipos enteros complejos"
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, fuzzy, gcc-internal-format
 #| msgid "Fixed line length must be at least seven."
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr "La longitud de línea fija debe ser al menos de siete."
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<__int128%> for %qs"
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr "ISO C++ no admite %<__int128%> para %qs"
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "el combinador %<#pragma omp declare reduction%> hace referencia a la variable %qD, la cual no es %<omp_out%> ni %<omp_in%>"
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "el nicializador %<#pragma omp declare reduction%> hace referencia a la variable %qD, la cual no es %<omp_priv%> ni %<omp_orig%>"
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "desplazamiento a la izquierda o valor negativo"
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "la cuenta de desplazamiento a la izquierda es negativa"
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "la cuenta de desplazamiento a la derecha es negativa"
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "cuenta de desplazamiento a la izquierda >= anchura del tipo"
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "cuenta de desplazamiento a la derecha >= anchura del tipo"
@@ -49464,7 +49490,7 @@ msgstr "marcador de conflicto en control de versiones en el fichero"
 msgid "to match this %qs"
 msgstr "%J  otro tipo aquí"
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "se esperaba fin de línea"
@@ -49474,8 +49500,8 @@ msgstr "se esperaba fin de línea"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C prohíbe una unidad de traducción vacía"
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr ""
@@ -49516,9 +49542,9 @@ msgstr "nombre de tipo %qE desconocido; ¿quiso decir %qs?"
 msgid "unknown type name %qE"
 msgstr "nombre de tipo %qE desconocido"
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "se esperaban especificadores de declaración"
@@ -49552,7 +49578,7 @@ msgstr "el atributo %<fallthrough%> no está seguido de %<;%>"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "se esperaba %<;>, identificador o %<(%>"
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "se descartan los atributos de prefijo para los métodos"
@@ -49572,7 +49598,7 @@ msgstr "atributo inesperado"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "el atributo %<fallthrough%> no está seguido de %<;%>"
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, fuzzy, gcc-internal-format
 #| msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgid "%<assume%> attribute not followed by %<;%>"
@@ -49668,7 +49694,7 @@ msgstr "la expresión en la aserción static no es una constante"
 msgid "static assertion failed: %E"
 msgstr "falló la aserción estática: %E"
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
@@ -49745,10 +49771,10 @@ msgstr "un enum vacío no es válido"
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "se esperaba un identificador"
@@ -49911,7 +49937,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr ""
@@ -49921,8 +49947,8 @@ msgstr ""
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs attribute argument"
 msgstr ""
@@ -50101,12 +50127,12 @@ msgstr "ISO C prohíbe la omisión del término medio de una expresión ?:"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr "la división %<sizeof (%T) / sizeof (%T)%> no computa el número de elementos del array"
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "el primer operando %<sizeof%> se declaró aquí"
@@ -50258,7 +50284,7 @@ msgstr "ISO C90 no admite el identificador predefinido %<__func__%>"
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, gcc-internal-format
 msgid "expected expression"
 msgstr "se esperaba una expresión"
@@ -50590,13 +50616,13 @@ msgstr "se esperaba una declaración método objective-c"
 msgid "no type or storage class may be specified here,"
 msgstr "ninguna clase de almacenamiento o tipo se puede especificar aquí,"
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, fuzzy, gcc-internal-format
 #| msgid "unknown property attribute"
 msgid "empty property attribute list"
 msgstr "atributo de propiedad desconocido"
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, fuzzy, gcc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing property attribute"
@@ -50608,61 +50634,61 @@ msgstr "falta el atributo Code"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "atributo de propiedad desconocido"
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "atributo de propiedad desconocido"
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, fuzzy, gcc-internal-format
 #| msgid "repeated %<@%> before Objective-C string"
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "%<@%> repetida antes de la cadena Objective-C"
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected %qE selector name"
 msgstr "se esperaba una declaración de selección"
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, fuzzy, gcc-internal-format
 #| msgid "setter name must terminate with %<:%>"
 msgid "setter method names must terminate with %<:%>"
 msgstr "el nombre del setter debe terminar con %<:%>"
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> requiere una expresión de asignación que evaluada dé una constante entera no negativa menor que %u"
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr ""
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> debe estar en el alcance del fichero"
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp section%> sólo se puede usar en construcciones %<#pragma omp sections%>"
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> sólo se puede usar en construcciones %<#pragma omp sections%>"
@@ -50673,25 +50699,25 @@ msgstr "%<#pragma omp section%> sólo se puede usar en construcciones %<#pragma
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr "%<#pragma %s%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "se esperaba una declaración for, while o do"
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> debe ser primero"
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "demasiadas cláusulas %qs"
@@ -50707,65 +50733,65 @@ msgstr "la expresión debe ser integral"
 msgid "expected %<)%> or %<,%>"
 msgstr "se esperaba %<,%> o %<)%>"
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD no es una variable"
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD no es una variable puntero"
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "el argumento de collapse necesita una expresión entera constante positiva"
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "se esperaba %<none%> o %<present%>"
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr "se esperaba %<simd%>, %<reduction%> o %<target%>"
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected constant logical expression"
 msgstr "se esperaba una expresión entera"
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "se esperaba %<data%>, %<update%>, %<enter%> o %<exit%>"
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "se esperaba %<data%>"
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "demasiadas cláusulas %<if%> con el modificador %qs"
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "demasiadas cláusulas %<if%>"
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "demasiadas cláusulas %<if%> sin modificador"
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "si alguna cláusula %<if%> tiene modificador, entonces todas las cláusulas %<if%> tienen que usar modificador"
@@ -50788,23 +50814,23 @@ msgstr "el valor de %<num_threads%> debe ser positivo"
 msgid "%<num_tasks%> value must be positive"
 msgstr "el valor de %<num_tasks%> debe ser positivo"
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "el valor de %<grainsize%> debe ser positivo"
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "el valor de %<priority%> debe ser no negativo"
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "se esperaba una expresión entera"
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
@@ -50816,102 +50842,102 @@ msgstr "se esperaba %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses with %qs modifier"
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "demasiadas cláusulas %<if%> con el modificador %qs"
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses with %qs modifier"
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "demasiadas cláusulas %<if%> con el modificador %qs"
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "la expresión %qs debe ser integral"
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "el valor de %qs debe ser positivo"
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "demasiados argumentos %<static%>"
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "argumento inesperado"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "el argumento de %<tile%> necesita una constante entera positiva"
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses"
 msgid "too many %<self%> clauses"
 msgstr "demasiadas cláusulas %<if%>"
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr "se esperaba %<none%> o %<shared%>"
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<new%>"
 msgid "expected %<concurrent%>"
 msgstr "se esperaba %<new%>"
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "el argumento de collapse necesita una expresión entera constante positiva"
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "se esperaba %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> o identificador"
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "se usaron al mismo tiempo los modificadores %<monotonic%> y %<nonmonotonic%>"
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "el planificador %<runtime%> no toma un parámetro %<chunk_size%>"
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "el planificador %<auto%> no toma un parámetro %<chunk_size%>"
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "género de planificador no válido"
@@ -50921,23 +50947,23 @@ msgstr "género de planificador no válido"
 msgid "%<num_teams%> value must be positive"
 msgstr "el valor de %<num_teams%> debe ser positivo"
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr ""
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "el valor de %<thread_limit%> debe ser positivo"
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<allocator%> or %<align%>"
@@ -50949,24 +50975,24 @@ msgstr "se esperaba %<,%> o %<)%>"
 msgid "duplicate %qs modifier"
 msgstr "%qs duplicado"
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple linear modifiers"
 msgstr "especificadores `virtual' múltiples"
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple %<step%> modifiers"
@@ -50990,69 +51016,69 @@ msgstr "%Hel argumento de collapse necesita ser una expresión entera constante
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, fuzzy, gcc-internal-format
 #| msgid "%qs feature modifier is incompatible with %s %s"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "el modificador de característica %qs es incompatible con %s %s"
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "tipo de dependencia no válida"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, fuzzy, gcc-internal-format
 #| msgid "invalid map kind"
 msgid "invalid doacross kind"
 msgstr "tipo de mapa no válida"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses with %qs modifier"
 msgid "too many %<always%> modifiers"
 msgstr "demasiadas cláusulas %<if%> con el modificador %qs"
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses with %qs modifier"
 msgid "too many %<close%> modifiers"
 msgstr "demasiadas cláusulas %<if%> con el modificador %qs"
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses with %qs modifier"
 msgid "too many %<present%> modifiers"
 msgstr "demasiadas cláusulas %<if%> con el modificador %qs"
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "tipo de mapa no válida"
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr ""
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<present%>"
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr "se esperaba %<none%> o %<present%>"
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -51070,91 +51096,91 @@ msgstr "género de planificador no válido"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "se esperaba %<;%>, %<,%> o %<)%>"
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected an OpenACC clause"
 msgstr "se esperaba un puntero"
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs no es válido para %qs"
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs debe ser la primera cláusula de %qs"
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected an OpenMP clause"
 msgstr "se esperaba un puntero"
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "no hay cláusulas válidas especificadas en %<#pragma acc declare%>"
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "sección de matriz en %<#pragma acc declare%>"
 
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD debe ser una variable global en %<#pragma acc declare link%>"
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "cláusula OpenACC no válida en el alcance del fichero"
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "uso no válido de la variable %<extern%> %qD en %<#pragma acc declare%>"
 
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "uso no válido de la variable %<global%> %qD en %<#pragma acc declare%>"
 
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "%qD debe ser una variable global en %<#pragma acc declare link%>"
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "La variable %qD se usa más de una vez con %<#pragma acc declare%>"
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "se esperaba %<data%> después de %<#pragma acc %s%>"
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> no tiene cláusula de movimiento de datos"
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr ""
@@ -51169,7 +51195,7 @@ msgstr "%qE no se ha declarado"
 msgid "expected function name"
 msgstr "se esperaba nombre de función"
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD no hace referencia a una función"
@@ -51179,22 +51205,22 @@ msgstr "%qD no hace referencia a una función"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> no está inmediatamente seguido de una declaración o definición de función"
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> no está inmediatamente seguido de una única declaración o definición de función"
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> debe aplicarse antes de uso"
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> debe aplicarse antes de definición"
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> debe contener al menos una cláusula %<device%>, %<host%> o %<self%>"
@@ -51221,7 +51247,7 @@ msgstr ""
 msgid "modified here"
 msgstr "se definió union aquí"
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
@@ -51263,125 +51289,125 @@ msgstr ""
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr "Aún no se admite la matriz polimórfica en %C"
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "se esperaba %<;%>, %<,%> o %<)%>"
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "se esperaba %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> o identificador"
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "demasiadas cláusulas %qs"
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "demasiadas cláusulas %qs"
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr "%<#pragma omp target update%> debe contener al menos una cláusula %<from%> o %<to%>"
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, fuzzy, gcc-internal-format
 #| msgid "%qs requires %qs"
 msgid "%qs clause requires %qs clause"
 msgstr "%qs requiere %qs"
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr "%<#pragma omp target update%> debe contener al menos una cláusula %<from%> o %<to%>"
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr "%<#pragma omp target update%> debe contener al menos una cláusula %<from%> o %<to%>"
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr "%<#pragma omp target update%> debe contener al menos una cláusula %<from%> o %<to%>"
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr "%<#pragma omp target update%> debe contener al menos una cláusula %<from%> o %<to%>"
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after union definition"
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr "se esperaba %<;%> después de la definición de union"
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, gcc-internal-format
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr ""
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, fuzzy, gcc-internal-format
 #| msgid "invalid form of %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr "forma no válida de %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<delete%>"
 msgid "unexpected %<else%>"
 msgstr "se esperaba %<delete%>"
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, fuzzy, gcc-internal-format
 #| msgid "invalid form of %<#pragma omp atomic%>"
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr "forma no válida de %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "forma no válida de %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "operador no válido para %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr ""
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> usa dos expresiones diferentes para la memoria"
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "%<depobj%> expression is not lvalue expression"
@@ -51393,30 +51419,30 @@ msgstr "la expresión %qE no es una expresión constante"
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr ""
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr "se esperaba %<data%>, %<update%>, %<enter%> o %<exit%>"
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "se esperaba %<;%>, %<,%> o %<)%>"
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, fuzzy, gcc-internal-format
 #| msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgid "%<flush%> list specified together with memory order clause"
@@ -51427,182 +51453,182 @@ msgstr "la cláusula %<linear%> no puede especificarse junto con la cláusula %<
 msgid "expected %<(%> or end of line"
 msgstr "se esperaba %<(%> o fin de línea"
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr "%<#pragma omp taskyield%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<present%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "se esperaba %<none%> o %<present%>"
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "se esperaba una cláusula %<#pragma omp%>"
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr "%<#pragma omp taskyield%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "se esperaba una declaración de iteración o una inicialización"
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, fuzzy, gcc-internal-format
 #| msgid "not enough perfectly nested loops"
 msgid "not enough nested loops"
 msgstr "no hay suficientes bucles perfectamente anidados"
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "el parámetro de la cláusula %<ordered%> es menor que %<collapse%>"
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "se esperaba una declaración for"
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "la variable de iteración %qD no debe ser firstprivate"
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "se esperaba %<fork%> después de %qs"
 
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "se esperaba %<point%>"
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> con map-type distinto de %<to%>, %<from%>, %<tofrom%> y %<alloc%> en la cláusula %<map%>"
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp target data%> debe contener al menos una cláusula %<map%>"
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> debe contener al menos una cláusula %<from%> o %<to%>"
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> con map-type distinto de %<to%> y %<alloc%> en la cláusula %<map%>"
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> debe contener al menos una cláusula %<map%>"
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> con map-type distinto de %<from%>, %<release%> y %<delete%> en la cláusula %<map%>"
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> debe contener al menos una cláusula %<map%>"
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> con map-type distinto de %<to%>, %<from%>, %<tofrom%> y %<alloc%> en la cláusula %<map%>"
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp declare simd%> debe ir seguida de una declaración o definición de función o de otra %<#pragma omp declare simd%>"
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma omp declare simd%> debe ir seguida de una declaración o definición de función"
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected trait selector name"
 msgstr "se esperaba una declaración de selección"
 
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, fuzzy, gcc-internal-format
 #| msgid "constructor not allowed for non-vector types"
 msgid "unknown selector %qs for context selector set %qs"
 msgstr "no se permite un constructor para tipos que no sean vectores"
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, fuzzy, gcc-internal-format
 #| msgid "%<no-custom-%s%> does not accept arguments"
 msgid "selector %qs does not accept any properties"
 msgstr "%<no-custom-%s%> no acepta argumentos"
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr "%<friend%> sólo se puede especificar dentro de una clase"
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "%<score%> argument must be constant integer expression"
 msgstr "el argumento de collapse necesita una expresión entera constante positiva"
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must be nonnegative"
 msgid "%<score%> argument must be non-negative"
 msgstr "'%s' en %L debe ser no negativo"
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "se esperaba una cadena literal"
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "property must be constant integer expression"
 msgstr "se esperaba una expresión entera"
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, fuzzy, gcc-internal-format
 #| msgid "property %qs already specified in %<@synthesize%>"
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
@@ -51611,317 +51637,317 @@ msgstr "la propiedad %qs ya se especificó en %<@synthesize%>"
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%<requires%> selector is not supported yet"
 msgstr "aún no se admite el modelo de código %<large%>"
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected context selector set name"
 msgstr "se esperaba una declaración de selección"
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<match%>"
 msgstr "se esperaba %<catch%>"
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a function"
 msgid "variant %qD is not a function"
 msgstr "'%s' en %L no es una función"
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, fuzzy, gcc-internal-format
 #| msgid "%qs and %qs are incompatible"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "%qs y %qs son incompatibles"
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare simd%> no inmediatamente seguida de una declaración o definición de función"
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare simd%> no inmediatamente seguida de una declaración o definición de función sencilla"
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "se esperaba %<target%>"
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr "%<#pragma omp end declare target%> sin su correspondiente %<#pragma omp declare target%>"
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr ""
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr "El atributo %s genera un conflicto con el atributo %s en %L"
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<declare%> or %<assumes%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr "%<#pragma omp declare reduction%> no está en ámbito de fichero o de bloque"
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr "tipo aritmético predeclarado en %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr "tipo función o matriz en %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, gcc-internal-format
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr "tipo calificado %<_Atomic%> en %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr "tipo calificado const, volatile o restrict en %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr "redeclaración de %qs %<#pragma omp declare reduction%> para el tipo %qT"
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "%<#pragma omp declare reduction%> previo"
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr "se esperaba %<omp_priv%> o nombre-de-función"
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "se esperaba nombre-de-función %<(%>"
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "se esperaba %<simd%>, %<reduction%> o %<target%>"
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr "%<#pragma omp target data%> debe contener al menos una cláusula %<map%>"
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr "ISO C prohíbe los tipos de función calificados"
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "se usó la matriz de longitud variable"
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr "se esperaba %<;%>, %<,%> o %<)%>"
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %qs or %qs"
 msgstr "se esperaba %<,%> o %<)%>"
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr ""
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr ""
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer '%s' in %s clause at %L"
 msgid "expected at least one assumption clause"
 msgstr "El puntero Cray '%s' en la cláusula %s en %L"
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, fuzzy, gcc-internal-format
 #| msgid "expected function name"
 msgid "expected directive name"
 msgstr "se esperaba nombre de función"
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr ""
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, fuzzy, gcc-internal-format
 #| msgid "unknown spec function %qs"
 msgid "unknown assumption clause %qs"
 msgstr "función de especificación %qs desconocida"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected assumption clause"
 msgstr "se esperaba un puntero"
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE se declaró %<threadprivate%> después del primer uso"
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "la variable automática %qE no puede ser %<threadprivate%>"
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE tiene tipo incompleto"
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> sin activar el soporte para memoria transaccional"
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> dentro de un %<__transaction_relaxed%>"
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, fuzzy, gcc-internal-format
 #| msgid "%<transaction_may_cancel_outer%> function call not within outer transaction or %<transaction_may_cancel_outer%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "la llamada a la función %<transaction_may_cancel_outer%> no está en una transacción más externa o %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> no está dentro de %<__transaction_atomic%>"
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, gcc-internal-format
 msgid "no closing brace"
 msgstr "llave sin cerrar"
@@ -52069,7 +52095,7 @@ msgstr "deferenciando el puntero %<void *%>"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "el valor del subíndice no es ni matriz ni puntero ni vector"
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "el subíndice de la matriz no es un entero"
@@ -52100,7 +52126,7 @@ msgstr "%qD declarado como referencia pero no se inicializa"
 msgid "enum constant defined here"
 msgstr "se definió la constante enum aquí"
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> sobre el parámetro matriz %qE de función devolverá el tamaño de %qT"
@@ -52215,18 +52241,18 @@ msgstr "conversión implícita de %qT a %qT al pasar el argumento a la función"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "faltan argumentos para la función %qE"
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "la comparación con una literal de cadena resulta en una conducta no especificada"
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "comparación entre puntero y entero"
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "¿pretendía desreferenciar el puntero?"
@@ -52251,7 +52277,7 @@ msgstr "se utilizó un puntero a una función en la sustracción"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "aritmética en puntero a un tipo de dato incompleto"
 
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "aritmética en puntero a un agregado vacío"
@@ -52561,7 +52587,7 @@ msgstr "conversión de puntero a entero de tamaño diferente"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "conversión desde una llamada a función de tipo %qT al tipo %qT que no coincide"
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "conversión a puntero desde un entero de tamaño diferente"
@@ -52736,7 +52762,7 @@ msgstr "el lado izquierdo de la asignación puede ser un candidato para un atrib
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "el lado izquierdo de la inicialización puede ser un candidato para un atributo de formato"
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "el tipo de devolución puede ser un candidato para un atributo de formato"
@@ -52946,12 +52972,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "inicialización de un miembro de matriz flexible"
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of %qT from incompatible pointer type %qT"
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
@@ -52962,7 +52988,7 @@ msgstr "inicialización de %qT desde un tipo de puntero %qT incompatible"
 msgid "array of inappropriate type initialized from string constant"
 msgstr "matriz de tipo inapropiado inicializada con una constante de cadena"
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "uso no válido de matriz no-lvaluada"
@@ -52993,7 +53019,7 @@ msgstr "el elemento inicializador no es una expresión constante"
 msgid "initializer element is not computable at load time"
 msgstr "el elemento inicializador no es calculable al momento de la carga"
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "no se pueden inicializar los tipos de vector opacos"
@@ -53008,7 +53034,7 @@ msgstr "grupo extra de llaves al final del inicializador"
 msgid "braces around scalar initializer"
 msgstr "llaves alrededor del inicializador escalar"
 
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "inicialización de un miembro de matriz flexible en un contexto anidado"
@@ -53099,7 +53125,7 @@ msgstr "exceso de elementos en el inicializador de struct"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "inicialización posicional de un campo de %<struct%> declarado con el atributo %<designated_init%>"
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "inicialización no estática de un miembro de matriz flexible"
@@ -53140,7 +53166,7 @@ msgstr "ISO C prohíbe %<goto *expr;%>"
 msgid "computed goto must be pointer type"
 msgstr "el argumento %d de %qE debe ser un tipo puntero"
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "la función declarada %<noreturn%> tiene una declaración %<return%>"
@@ -53195,7 +53221,7 @@ msgstr "la etiqueta %<default%> no está dentro de una declaración switch"
 msgid "break statement not within loop or switch"
 msgstr "la declaración break no está dentro de un bucle o switch"
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -53245,27 +53271,27 @@ msgstr "la comparación siempre se evalúa como %<false%> para la dirección de
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr "la comparación siempre se evalúa como %<true%> para la dirección de %qD que nunca será NULL"
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "se comparan vectores con tipos de elemento diferentes"
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "se comparan vectores con números de elementos diferentes"
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "comparación entre los tipos %qT y %qT"
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "no se puede encontrar un tipo entero del mismo tamaño que %qT"
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
@@ -53338,30 +53364,30 @@ msgstr "se usa un valor de tipo union cuando se requiere un escalar"
 msgid "used vector type where scalar is required"
 msgstr "se usa un tipo vector cuando se requiere un escalar"
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> debe especificar una de las cláusulas %<parallel%>, %<for%>, %<sections%> o %<taskgroup%>"
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<parallel%> or %<target%> %<if%> clause modifier"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "se esperaba el modificador de cláusula %<parallel%> o %<target%> %<if%>"
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> debe especificar una de las cláusulas %<parallel%>, %<for%>, %<sections%> o %<taskgroup%>"
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE no es una variable en la cláusula %qs"
@@ -53373,90 +53399,90 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%Hdemasiadas cláusulas %qs"
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "el tamaño de la matriz nueva debe tener un tipo integral"
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "la longitud %qE de la sección de matriz no es de tipo integral"
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer '%s' in %s clause at %L"
 msgid "expected single pointer in %qs clause"
 msgstr "El puntero Cray '%s' en la cláusula %s en %L"
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "sección de matriz de longitud cero en la cláusula %qs"
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "límite inferior negativo en sección de matriz en cláusula %qs"
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "longitud negativa en sección de matriz en cláusula %qs"
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "límite inferior %qE por encima del tamaño de la sección de matriz en cláusula %qs"
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "longitud %qE por encima del tamaño de la sección de matriz en cláusula %qs"
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "límite superior %qE por encima del tamaño de la sección de matriz en cláusula %qs"
 
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, fuzzy, gcc-internal-format
 #| msgid "for increment expression has no effect"
 msgid "for array function parameter length expression must be specified"
 msgstr "la expresión de incremento for no tiene efecto"
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, fuzzy, gcc-internal-format
 #| msgid "for increment expression has no effect"
 msgid "for pointer type length expression must be specified"
 msgstr "la expresión de incremento for no tiene efecto"
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "la sección de matriz no es contigua en la cláusula %qs"
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE no es de tipo puntero o matriz"
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, fuzzy, gcc-internal-format
 #| msgid "throwing NULL, which has integral, not pointer type"
 msgid "iterator %qD has neither integral nor pointer type"
@@ -53468,19 +53494,19 @@ msgstr "arrojando NULL, que tiene un tipo integral, que no es puntero"
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "tipo matriz cualificado %<_Atomic%>"
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD has incomplete type"
 msgid "iterator %qD has const qualified type"
 msgstr "el parámetro %qD tiene tipo incompleto"
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "iterator step with non-integral type"
 msgstr "campo de bits %qD con tipo no integral"
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
@@ -53490,37 +53516,37 @@ msgstr ""
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, fuzzy, gcc-internal-format
 #| msgid "condition expression refers to iteration variable %qD"
 msgid "begin expression refers to outer iterator %qD"
 msgstr "la expresión de la condición hace referencia a la variable de iteración %qD"
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, fuzzy, gcc-internal-format
 #| msgid "condition expression refers to iteration variable %qD"
 msgid "end expression refers to outer iterator %qD"
 msgstr "la expresión de la condición hace referencia a la variable de iteración %qD"
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, fuzzy, gcc-internal-format
 #| msgid "initializer expression refers to iteration variable %qD"
 msgid "step expression refers to outer iterator %qD"
 msgstr "la expresión inicializadora hace referencia a la variable de iteración %qD"
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected pointer in %qs clause"
 msgstr "se esperaba un puntero"
 
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "aún no se admite el modelo de código %<large%>"
 
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%<inscan%> %<reduction%> clause with array section"
@@ -53554,7 +53580,7 @@ msgstr "campo de bits %qE en cláusula %qs"
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE tiene tipo no válido para %<reduction(%s)%>"
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, fuzzy, gcc-internal-format
 #| msgid "No label definition found for %qs"
 msgid "user defined reduction not found for %qE"
@@ -53566,17 +53592,17 @@ msgstr "No se encontró una definición de etiqueta para %qs"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "se usó la matriz de longitud variable"
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE debe ser %<threadprivate%> para %<copin%>"
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
 msgstr ""
@@ -53591,24 +53617,24 @@ msgstr "cláusula lineal aplicada a variable no puntero no integral con tipo %qT
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "cláusula %<linear%> paso %qE no es ni constante ni parámetro"
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de reducción"
@@ -53620,33 +53646,33 @@ msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE no es una variable en la cláusula %<firstprivate%>"
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE no es una variable en la cláusula %<lastprivate%>"
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE no es una variable en la cláusula %<saligned%>"
@@ -53668,7 +53694,7 @@ msgstr "%qD no es una variable en la cláusula %qs"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<nontemporal%> clause"
@@ -53680,7 +53706,7 @@ msgstr "%qE no es una variable en la cláusula %qs"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<aligned%> clause"
 msgid "%qE is not a variable in %<allocate%> clause"
@@ -53692,85 +53718,85 @@ msgstr "%qE no es una variable en la cláusula %<saligned%>"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr ""
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, fuzzy, gcc-internal-format
 #| msgid "Array section not permitted in '%s' call at %L"
 msgid "array section does not have mappable type in %qs clause"
 msgstr "No se permite una sección de matriz en la llamada '%s' en %L"
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported fixed-point conversion"
 msgid "unsupported map expression %qE"
 msgstr "conversión de coma fija no admitida"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
@@ -53787,24 +53813,24 @@ msgstr "la fuente no es un puntero"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "la variable %qs no es un puntero ni una matriz"
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %qs clauses on a task construct"
 msgstr "demasiadas cláusulas %qs"
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "la cláusula %<inbranch%> es incompatible con %<notinbranch%>"
 
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE está predeterminado como %qs para %qs"
@@ -53814,41 +53840,41 @@ msgstr "%qE está predeterminado como %qs para %qs"
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "el valor de la cláusula %<simdlen%> es mayor que el valor de la cláusula %<safelen%>"
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
@@ -54150,7 +54176,7 @@ msgstr "  no hay una conversión de %qH a %qI"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  no hay una conversión conocida para el argumento %d de %qH a %qI"
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  candidate expects %d argument, %d provided"
 #| msgid_plural "  candidate expects %d arguments, %d provided"
@@ -54159,7 +54185,7 @@ msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  el candidato espera %d argumento, se proporcionaron %d"
 msgstr[1] "  el candidato espera %d argumentos, se proporcionaron %d"
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -54493,624 +54519,624 @@ msgstr "la expresión condicional entre diferentes tipos de punteros %qT y %qT c
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "tipos enumeral y no enumeral en la expresión condicional"
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "no se declaró %<%D(int)%> para el %qs postfijo, intentando en su lugar el operador prefijo"
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "no se declaró %<%D(int)%> para el %qs postfijo"
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %qD is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "el tipo de devolución de %qD no es %<int%>"
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "comparación entre %q#T y %q#T"
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to %<(%T) (%A)%>"
 msgid "no match for call to %<%T::operator[] (%A)%>"
 msgstr "no hay coincidencia para la llamada a %<(%T) (%A)%>"
 
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, fuzzy, gcc-internal-format
 #| msgid "call of %<(%T) (%A)%> is ambiguous"
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr "la llamada de %<(%T) (%A)%> es ambigua"
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, fuzzy, gcc-internal-format
 #| msgid "non-placement deallocation function %q+D"
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "función de desalojo %q+D sin ubicación"
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, fuzzy, gcc-internal-format
 #| msgid "non-placement deallocation function %q+D"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "función de desalojo %q+D sin ubicación"
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "no existe una función de desalojo correspondiente para %qD"
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr ""
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "no hay un %<operator %s%> adecuado para %qT"
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "desde este contexto"
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared private here"
 msgstr "se declara aquí"
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "desde este contexto"
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared protected here"
 msgstr "se declara aquí"
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D es inaccesible"
 
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "se pasó NULL al argumento %P de %qD que no es puntero"
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "  declared here"
 msgstr "se declara aquí"
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "se convierte al tipo %qT que no es puntero desde NULL"
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "se convierte %<false%> a tipo puntero para el argumento %P de %qD"
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "se convierte %<false%> al tipo puntero %qT"
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  argumento de inicialización %P de %qD"
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "demasiadas llaves alrededor del inicializador para %qT"
 
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in initialization"
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "no se puede convertir %qT a %qT en la inicialización"
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 #, fuzzy
 #| msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr "ISO C++ no permite %<alignof%> con algo que no es tipo"
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr ""
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 #, fuzzy
 #| msgid "invalid user-defined conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "conversión definida por el usuario no válida de %qT a %qT"
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "conversión no válida de %qT a %qT"
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "la conversión a %qT desde la lista del inicializador usaría el constructor explícito %qD"
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "solamente las declaraciones de constructores pueden ser %<explicit%>"
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 #, fuzzy
 #| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "inicialización a un tipo de referencia volatile %q#T desde un r-valor de tipo %qT"
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr "inicialización no válida de una referencia que no es constante de tipo %qT desde un r-valor de tipo %qT"
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "inicialización no válida de una referencia que no es constante de tipo %qT desde un r-valor de tipo %qT"
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 #, fuzzy
 #| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "inicialización a un tipo de referencia volatile %q#T desde un r-valor de tipo %qT"
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 #, fuzzy
 #| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "inicialización a un tipo de referencia volatile %q#T desde un r-valor de tipo %qT"
 
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 #, fuzzy
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "pasar %qT como el argumento %<this%> de %q#D descarta a los calificadores"
 
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "no se puede unir el campo de bits %qE a %qT"
 
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "no se unir el campo packed %qE a %qT"
 
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "no se puede unir el r-valor %qE a %qT"
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "conversión implícita de %qT a %qT al pasar el argumento a la función"
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "el paso de objetos de tipo no-copiable-trivialmente %q#T a través de %<...%> se admite condicionalmente"
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "no se puede recibir el tipo de referencia %qT a través de %<...%>"
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "la recepción de objetos de tipo no-copiable-trivialmente %q#T a través de %<...%> se admite condicionalmente"
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "evaluación recursiva del argumento por defecto para %q#D"
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "la llamada a %qD usa el argumento por defecto para el parámetro %P, el cual no se ha definido aún"
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "el argumento de la llamada a función puede ser un candidato para un atributo de formato"
 
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted function %q+D with default argument"
 msgid "use of multiversioned function without a default"
 msgstr "función definida por defecto %q+D con argumento por defecto"
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr ""
 
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "pasar %qT como el argumento %<this%> de %q#D descarta a los calificadores"
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  en la llamada a %qD"
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT no es una base inaccesible de %qT"
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to constructor %q#D"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "demasiados argumentos para el constructor %q#D"
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-trivial type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%qD no puede ser thread-local porque es de tipo %qT que no es trivial"
 
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "asignación (no inicialización) en la declaración"
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "use #include en su lugar"
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of function type %qT"
 msgid "; use value-initialization instead"
 msgstr "inicialización por valor del tipo de función %qT"
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-trivial type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD no puede ser thread-local porque es de tipo %qT que no es trivial"
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "asignación (no inicialización) en la declaración"
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "use #include en su lugar"
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: re-initialization of '%s' at %L"
 msgid "; use copy-initialization instead"
 msgstr "Extensión: reinicialización de '%s' en %L"
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "la conversión a void no accederá al objeto de tipo no-copiable-trivialmente %qT"
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "no se puede recibir objetos de tipo no-copiable-trivialmente q%#T a través de %<...%>"
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%#qT declared here"
 msgstr "%qD se declara aquí"
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr "el argumento 3 en la llamada a la función %qE tiene un puntero a un tipo boolean"
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, fuzzy, gcc-internal-format
 #| msgid "constant refers to itself"
 msgid "constructor delegates to itself"
 msgstr "la constante se refiere a sí misma"
 
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI"
 msgstr "no se puede convertir %qT a %qT"
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "no se encontró una función coincidente para la llamada a %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "no se encontró una función coincidente para la llamada a %<%T::%s(%A)%#V%>"
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "llamada a %qD que no es función"
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "no se puede llamar directamente al constructor %<%T::%D%>"
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, fuzzy, gcc-internal-format
 #| msgid "  for a function-style cast, remove the redundant %<::%D%>"
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "  para una conversión de estilo de función, borre el %<::%D%> redundante"
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "no hay una función coincidente para la llamada a %<%D(%A)%>"
 
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "la llamada del %<%s(%A)%> sobrecargado es ambigua"
 
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "los inicializadores de los datos miembro no son estáticos"
 
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, fuzzy, gcc-internal-format
 #| msgid "abstract virtual `%#D' called from constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "virtual abstracto `%#D' llamado desde un constructor"
 
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, fuzzy, gcc-internal-format
 #| msgid "abstract virtual `%#D' called from destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "virtual abstracto `%#D' llamado desde un destructor"
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "no se puede llamar a la función miembro %qD sin un objeto"
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "al pasar %qT se escoge %qT sobre %qT"
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr "ISO C++ dice que estos son ambiguos, aún cuando la peor conversión para el primero es mejor que la peor conversión para el segundo:"
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, fuzzy, gcc-internal-format
 #| msgid "destructors must be member functions"
 msgid "try making the operator a %<const%> member function"
 msgstr "los destructores deben ser funciones miembro"
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "se escoge %qD sobre %qD"
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  para la conversión de %qT a %qT"
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  porque la secuencia de conversión para el argumento es mejor"
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "no coincide el argumento por defecto en la resolución de sobrecarga"
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr " candidato 1: %q+#F"
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr " candidato 2: %q+#F"
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ dice que estos son ambiguos, aún cuando la peor conversión para el primero es mejor que la peor conversión para el segundo:"
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "un enlace temporal a %qD sólo persiste hasta que el constructor termina"
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "inicialización no válida de una referencia que no es constante de tipo %qT desde un r-valor de tipo %qT"
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "inicialización no válida de la referencia de tipo %qT desde una expresión de tipo %qT"
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "possibly dangling reference to a temporary"
 msgstr "se devuelve la referencia al temporal"
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr ""
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, fuzzy, gcc-internal-format
 #| msgid "%s: definition of function '%s' not converted\n"
 msgid "explicit conversion function was not considered"
@@ -55165,7 +55191,7 @@ msgid "%q#D cannot be overloaded with %q#D"
 msgstr "no se puede sobrecargar %q+#D"
 
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previous declaration %q#D"
@@ -55633,7 +55659,7 @@ msgstr "el miembro de matriz flexible sería de otra manera un struct vacío"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D se declaró aquí"
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redefinición de %q#T"
@@ -55771,7 +55797,7 @@ msgstr "tipo no válido del parámetro %d en la función %<constexpr%> %q+#D"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
@@ -55818,7 +55844,7 @@ msgstr "el cuerpo de la función constexpr %qD no es una declaración de devoluc
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%q+D no se puede usar como una función constexpr porque:"
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr ""
@@ -55837,7 +55863,7 @@ msgstr "Avisa en las llamadas a estas funciones"
 msgid "%q+E is not a constant expression"
 msgstr "%q+E no es una expresión constante"
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
@@ -55861,7 +55887,7 @@ msgstr "autocomparación siempre falsa"
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, fuzzy, gcc-internal-format
 #| msgid "internal function"
@@ -55914,7 +55940,7 @@ msgstr "  %qT es una clase base ambigua de %qT"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-constexpr function %qD"
@@ -56062,20 +56088,20 @@ msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "deferenciando el puntero %<void *%>"
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -56083,534 +56109,534 @@ msgstr "deferenciando el puntero %<void *%>"
 msgid "%qE is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD mutable no se puede usar en una expresión constante"
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "se accede al miembro %qD  en lugar del miembro inicializado %qD en la expresión constante"
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, fuzzy, gcc-internal-format
 #| msgid "ifunc is not supported on this target"
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "no se admiten ifunc en este objetivo"
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "se accede al valor de %qE a través de glvalue %qT en una expresión constante"
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, fuzzy, gcc-internal-format
 #| msgid "use of the value of the object being constructed in a constant expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "uso del valor del objeto en construcción en una expresión constante"
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "allocated here"
 msgstr "se declara aquí"
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
 msgstr ""
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, fuzzy, gcc-internal-format
 #| msgid "the value of %qD is not usable in a constant expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "el valor de %qD no se puede usar en una expresión constante"
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "el valor de %qD no se puede usar en una expresión constante"
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "se usó %qD en su propio inicializador"
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D no es const"
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q+#D es volatile"
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD no se inicializó con una expresion constante"
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD no se declaró %<constexpr%>"
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD no tiene tipo integral o de enumeración"
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, fuzzy, gcc-internal-format
 #| msgid "use of the value of the object being constructed in a constant expression"
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr "uso del valor del objeto en construcción en una expresión constante"
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, fuzzy, gcc-internal-format
 #| msgid "difference of two pointer expressions is not a constant expression"
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr "la diferencia de dos expresiones puntero no es una expresión constante"
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, fuzzy, gcc-internal-format
 #| msgid "Change of value in conversion from  %s to %s at %L"
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr "Cambio de valor en la conversión de %s a %s en %L"
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr ""
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr ""
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, fuzzy, gcc-internal-format
 #| msgid "Change of value in conversion from  %s to %s at %L"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "Cambio de valor en la conversión de %s a %s en %L"
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "statement is not a constant expression"
 msgstr "el elemento inicializador no es una expresión constante"
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "la profundidad de evaluación de constexpr excede el máximo de %d (use -fconstexpr-depth= para incrementar el máximo)"
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "inline assembly is not a constant expression"
 msgstr "el elemento inicializador no es una expresión constante"
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "use of %qD"
 msgstr "uso no válido de %qD"
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr ""
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr ""
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr ""
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr ""
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "la profundidad de evaluación de constexpr excede el máximo de %d (use -fconstexpr-depth= para incrementar el máximo)"
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, fuzzy, gcc-internal-format
 #| msgid "capture of variable %qD with non-automatic storage duration"
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "captura de la variable %qD con duración de almacenamiento que no es automática"
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporal del tipo %qT que no es literal en una expresión constante"
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "conversión del tipo puntero %qT al tipo aritmético %qT en una expresión constante"
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "pointed-to object declared here"
 msgstr "  %q+#D se declaró aquí"
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr "no se permite el parámetro de plantilla %qD de tipo %qT en una expresión integral constante porque no es de tipo integral o de enumeración"
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "expression %qE is not a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "contract predicate is false in constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-id"
 msgid "unexpected template-id %qE"
 msgstr "se esperaba un id de plantilla"
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qE must be directly called"
 msgid "function concept must be called"
 msgstr "la función interna %qE ha de ser llamada directamente"
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "el tamaño de la matriz %qD no es una expresion constante integral"
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "expresión %qE inesperada de género %s"
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr "se toma la dirección del destructor %qE"
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "conversión no válida de una expresión r-valuada de tipo %qT al tipo %qT"
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast from type `%T' to type `%T'"
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "reinterpret_cast no válido del tipo `%T' al tipo `%T'"
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "la dirección de un objeto %qE con hilo local o almacenamiento automático no es una expresión constante"
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "new-expression is not a constant expression before C++20"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, fuzzy, gcc-internal-format
 #| msgid "temporary of non-literal type %qT in a constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "temporal del tipo %qT que no es literal en una expresión constante"
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "%qE no se declaró aquí (no en una función)"
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "%q+F se declaró %<static%> pero nunca se define"
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "inicialización de una matriz que no es constante"
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "AST inesperado de género %s"
@@ -57424,7 +57450,7 @@ msgstr "el tercer argumento de %<__builtin_prefetch%> debe ser una constante"
 msgid "no suspend point info for %qD"
 msgstr "no hay un prototipo previo para %qD"
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -57447,23 +57473,23 @@ msgstr "no se permite usar punteros como valores case"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "el límite del array de longitud variable es desconocido"
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
@@ -57485,78 +57511,78 @@ msgstr ""
 msgid "%qD was promoted to an immediate function"
 msgstr "%qD no es una función plantilla"
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of an immediate function %qD"
 msgstr "se toma la dirección del destructor %qE"
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "call to consteval function %qE is not a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "la dirección de %qD siempre se evaluará como %<true%>"
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "un destructor no puede ser %<constexpr%>"
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qE attribute"
 msgid "pack expansion of %qE attribute"
 msgstr "argumento no válido del atributo %qE"
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in unevaluated context"
 msgid "use fold expression in the attribute argument instead"
 msgstr "expresión lambda en un contexto sin evaluar"
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD no es un tipo"
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qD is not a class type"
 msgstr "%qT no es un tipo de clase"
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have pointer or array type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE no es de tipo puntero o matriz"
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qD does not have integral type"
 msgstr "%qD no tiene tipo integral o de enumeración"
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
@@ -57605,7 +57631,7 @@ msgstr "inicialización a un tipo de referencia que no es constante %q#T desde u
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "la conversión de %qT a %qT descarta los calificadores"
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "la conversión de %qT a %qT no dereferencía a los punteros"
@@ -58007,7 +58033,7 @@ msgstr "de la declaración previa de %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "la redeclaración de %qD difiere en %<constexpr%>"
 
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previous declaration %qD"
@@ -58171,8 +58197,8 @@ msgstr "la declaración previa %q+#D que no es función"
 msgid "%q#D previously defined here"
 msgstr "se define %q+#D previamente aquí"
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#D previously declared here"
@@ -58259,60 +58285,42 @@ msgstr "argumento por defecto dado para el parámetro %d de %q#D"
 msgid "previous specification in %q#D here"
 msgstr "después de la especificación previa en %q+#D"
 
-#: cp/decl.cc:2285
-#, fuzzy, gcc-internal-format
-#| msgid "conflicts with built-in declaration %q#D"
-msgid "declaration %qD conflicts with builtin"
-msgstr "genera un conflicto con la declaración interna %q#D"
-
-#: cp/decl.cc:2288
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of namespace %qD conflicts with"
-msgid "declaration %qD conflicts with import"
-msgstr "la declaración del espacio de nombres %qD genera un conflicto con"
-
-#: cp/decl.cc:2289
-#, fuzzy, gcc-internal-format
-#| msgid "  also declared as %q#D here"
-msgid "import declared %q#D here"
-msgstr "  también declarado como %q#D aquí"
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting exporting for declaration %qD"
 msgstr "declaraciones de %q#D en conflicto"
 
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared here without exporting"
 msgstr "se declaró previamente aquí"
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD here"
 msgstr "la definición previa de %q+D estaba aquí"
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD here"
 msgstr "la declaración previa de %q+D estaba aquí"
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "la función %qD se declaró virtual dentro de un union"
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "declaración redundante de %qD en el mismo ámbito"
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, fuzzy, gcc-internal-format
 #| msgid "deleted definition of %qD"
 msgid "deleted definition of %qD is not first declaration"
@@ -58326,45 +58334,45 @@ msgstr "se borró la definición de %qD"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "especialización explícita de %qD después del primer uso"
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, fuzzy, gcc-internal-format
 #| msgid "'setter' attribute of property %qD conflicts with previous declaration"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "el atributo 'setter' de la propiedad %qD genera un conflicto con la declaración previa"
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "redefinición de %q#D"
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD genera un conflicto con la función utilizada"
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D no se declaró en la clase"
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D se redeclaró incluida en línea con el atributo %<gnu_inline%>"
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D se redeclaró incluida en línea sin el atributo %<gnu_inline%>"
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -58372,800 +58380,800 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "la redeclaración de friend %q#D no puede tener argumentos de plantilla por defecto"
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "declaración thread-local de %q#D después de una declaración que no es thread-local"
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "declaración que no es thread-local de %q#D después de una declaración thread-local"
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "redeclaración de %q#D"
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of `%s' in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "declaración redundante de `%s' en el mismo ámbito"
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, fuzzy, gcc-internal-format
 #| msgid "a previous local"
 msgid "previous label"
 msgstr "un local previo"
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, gcc-internal-format
 msgid "jump to label %qD"
 msgstr "salto a la etiqueta %qD"
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr "salto a la etiqueta case"
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr ""
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  desde aquí"
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  sale del bloque estructurado OpenMP"
 
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  cruza la inicialización de %q+#D"
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  entra al bloque try"
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  entra al bloque catch"
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  entra al bloque estructurado OpenMP"
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, fuzzy, gcc-internal-format
 #| msgid "jump into statement expression"
 msgid "  enters statement expression"
 msgstr "salto a una expresión de declaración"
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "  enters %<constexpr if%> statement"
 msgstr "se esperaba una declaración"
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "  enters %<consteval if%> statement"
 msgstr "se esperaba una declaración"
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C99 does not support %qE"
 msgid "  does not destroy %qD"
 msgstr "ISO C99 no admite %qE"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not take any feature options"
 msgid "  does not clean up handled exception"
 msgstr "%s no toma ninguna opción de característica"
 
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  salta la inicialización de %q+#D"
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "se usa %qD sin parámetros de plantilla"
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is a function, not a type"
 msgstr "%qD no es una plantilla de función"
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T no es una clase"
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "no hay una plantilla de clase llamada %q#T en %q#T"
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "no hay un tipo llamado %q#T en %q#T"
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "la búsqueda de %qT en %qT es ambigua"
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nombra a %q#T, el cual no es una plantilla de clase"
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, fuzzy, gcc-internal-format
 #| msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> nombra a %q#T, el cual no es un tipo"
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "los parámetros de la plantilla no coinciden con la plantilla"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, fuzzy, gcc-internal-format
 #| msgid "-falign-labels=%d is not supported"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "no se admite -falign-labels=%d"
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D no válido; una union anónima solo puede tener miembros con datos no estáticos públicos"
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "esta flexibilidad es obsoleta y será eliminada"
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous struct not inside named type"
 msgid "anonymous struct with base classes"
 msgstr "struct anónimo no está dentro de un tipo nombrado"
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "no se permite el miembro %q+#D con constructor en un agregado anónimo"
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "no se permite el miembro %q+#D con destructor en un agregado anónimo"
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "no se permite el miembro %q+#D con operador de asignación de copia en un agregado anónimo"
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "se descarta el atributo en la declaración de %q#T"
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "el atributo para %q#T debe estar a continuación de la palabra clave %qs"
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "tipos múltiples en una declaración"
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "redeclaración del tipo interno de C++ %qT"
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> sólo se puede especificar para variables o declaraciones de función"
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "falta el nombre del tipo en la declaración typedef"
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ prohíbe structs anónimos"
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs sólo se puede especificar para funciones"
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs sólo se puede especificar para funciones"
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> sólo se puede especificar dentro de una clase"
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> sólo se puede especificar para constructores"
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "una clase de almacenamiento sólo se puede especificar para objetos y funciones"
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "los calificadores sólo se pueden especificar para objetos y funciones"
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "los calificadores sólo se pueden especificar para objetos y funciones"
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "los calificadores sólo se pueden especificar para objetos y funciones"
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "una clase de almacenamiento sólo se puede especificar para objetos y funciones"
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "se descartó %<typedef%> en esta declaración"
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%> no se puede usar en declaraciones de tipo"
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "se descartan los atributos en la instanciación de una plantilla"
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "el atributo %qE sólo se puede aplicar a definiciones de clase"
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "se descartan los atributos aplicados al tipo de clase %qT fuera de la definición"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "se descartan los atributos aplicados al tipo dependiente %qT sin una declaración asociada"
 
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use decltype instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD está inicializado (utilice decltype en su lugar)"
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "la declaración de %q#D tiene %<extern%> y está inicializada"
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "la definición de %q#D se marca como %<dllimport%>"
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D no es un dato miembro no static de %qT"
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "declaración plantilla de %q#D"
 
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "declaración de la plantilla miembro %qD no válida"
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ no permite que %<%T::%D%> se defina como %<%T::%D%>"
 
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "inicialización duplicada de %qD"
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "la declaración de %q#D fuera de la clase no es una definición"
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr ""
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "la variable %q#D tiene inicializador pero de tipo de dato incompleto"
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementos de la matriz %q#D con tipo de dato incompleto"
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "el agregado %q#D tiene un tipo incompleto y no se puede definir"
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD declarado como referencia pero no se inicializa"
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "se usó un nombre en un inicializador designado de estilo GNU para una matriz"
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "el nombre %qD se utiliza en un inicializador designado en estilo GNU para una matriz"
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "no se admiten los inicializadores designados como no triviales"
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "el tamaño de la matriz %qD no es una expresion constante integral"
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "el inicializador no puede determinar el tamaño de %qD"
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "falta el tamaño de la matriz en %qD"
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "matriz %qD de tamaño cero"
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "no se conoce el tamaño de almacenamiento de %qD"
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "el tamaño de almacenamiento de %qD no es constante"
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you%'ll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "perdón: la semántica de los datos static de la función inline %q+#D es errónea (terminará con múltiples copias)"
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you%'ll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "perdón: la semántica de los datos static de la función inline %q+#D es errónea (terminará con múltiples copias)"
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, fuzzy, gcc-internal-format
 #| msgid "  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "  puede evitar esto eliminando el inicializador"
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "const %qD sin inicializar"
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "miembro %qD sin inicializar en el constructor %<constexpr%>"
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "miembro %qD sin inicializar en el constructor %<constexpr%>"
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T no tiene constructor por defecto proporcionado por el usuario"
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "el constructor no es proporcionado por el usuario porque está marcado explícitamente por defecto en el cuerpo de la clase"
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, fuzzy, gcc-internal-format
 #| msgid "and the implicitly-defined constructor does not initialize %q+#D"
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "y el constructor implícitamente definido no inicializa %q+#D"
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "tipo %qT no válido como inicializador para un vector de tipo %qT"
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "el inicializador para %qT debe estar encerrado entre llaves"
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "se usa %<[%E] =%> en un inicializador designado en estilo GNU para la clase %qT"
 
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "la petición para el miembro %qD es ambigua"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT no tiene un dato miembro que no es static llamado %qD"
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD no es un miembro de %qT"
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for array member %q#D"
 msgid "invalid initializer for %q#D"
 msgstr "inicializador no válido para la matriz miembro %q#D"
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "asignador C99 %qE fuera del inicializador agregado"
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "demasiados inicializadores para %qT"
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "llaves alrededor del inicializador escalar para el tipo %qT"
 
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "llaves alrededor del inicializador escalar para el tipo %qT"
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "faltan llaves alrededor del inicializador para %qT"
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding has incomplete type %qT"
 msgstr "puntero deferenciado a tipo de dato incompleto"
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "elementos de la matriz %q#T tienen tipo de dato incompleto"
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "literal compuesta de tamaño variable"
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D tiene un tipo incompleto"
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "el objeto escalar %qD requiere un elemento en el inicializador"
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "en C++98 %qD debe ser inicializado por un constructor, no por %<{...}%>"
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "matriz %qD inicializada con una constante de cadena entre paréntesis %qE"
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "inicializador no válido para el miembro static con constructor"
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "inicialización en clase que no es constante no válida para el miembro static %qD"
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, fuzzy, gcc-internal-format
 #| msgid "non-constant in-class initialization invalid for static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "inicialización en clase que no es constante no válida para el miembro static %qD"
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(se requiere una inicialización fuera de la clase)"
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is initialized with itself"
 msgid "reference %qD is initialized with itself"
 msgstr "%qD se inicializa con sí mismo"
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%> fuera de una declaración"
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, fuzzy, gcc-internal-format
 #| msgid "%s: recursive invocation of constructor %qs"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%s: invocación recursiva del constructor %qs"
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration cannot name destructor"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "uan declaración de uso no puede nombrar al destructor"
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "asignación (no inicialización) en la declaración"
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ no permite inicializadores designados"
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "se especificó una clase de almacenamiento para %qs"
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "la declaración de %q#D no tiene inicializadores"
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member function (did you forget the %<()%> ?)"
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "uso no válido de la función miembro (¿Olvidó el %<&%>?)"
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "el tipo de devolución %q#T es un tipo de dato incompleto"
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "un objeto de tamaño variable puede no ser inicializado"
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "se oscurece la declaración de tipo previa de %q#D"
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables in static storage"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "el atributo %qE se aplica solamente a variables en almacenamiento estático"
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "la función %q#D se inicializa como una variable"
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  no se puede usar la asignación obsoleta en %q+D porque tiene un destructor"
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, fuzzy, gcc-internal-format
 #| msgid "cannot form pointer to member of non-class %q#T"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "no se puede formar un puntero al miembro de %q#T que no es clase"
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "puntero deferenciado a tipo de dato incompleto"
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
@@ -59173,7 +59181,7 @@ msgid_plural "%u names provided for structured binding"
 msgstr[0] "se especificó %qs para el campo de estructura"
 msgstr[1] "se especificó %qs para el campo de estructura"
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "only %u name provided for structured binding"
@@ -59181,1908 +59189,1908 @@ msgid_plural "only %u names provided for structured binding"
 msgstr[0] "inicializador no válido para la cadena de bits"
 msgstr[1] "inicializador no válido para la cadena de bits"
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length vector %qT"
 msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "el tamaño de la matriz no es una expresion constante integral"
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "in initialization of structured binding variable %qD"
 msgstr "tipo no válido para la variable de iteración %qE"
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "se crea un puntero al miembro del tipo %qT que no es clase"
 
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "puntero deferenciado a tipo de dato incompleto"
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "no se puede aplicar %<offsetof%> al dato miembro static %qD"
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+T has a non-trivial destructor"
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T tiene un destructor que no es trivial"
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "el inicializador no puede determinar el tamaño de %qT"
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "falta el tamaño de la matriz en %qT"
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "matriz %qT de tamaño cero"
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "el destructor para la clase extranjera %qT no puede ser un miembro"
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "el constructor para la clase extranjera %qT no puede ser un miembro"
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD se declaró como una variable %<virtual%>"
 
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de variable"
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD se declaró como un parámetro %<virtual%>"
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD se declaró como un parámetro %<inline%>"
 
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de parámetro"
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD se declaró como un tipo %<virtual%>"
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD se declaró como un tipo %<inline%>"
 
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de tipo"
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD se declaró como un campo %<virtual%>"
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD se declaró como un campo %<inline%>"
 
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de campo"
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D se declaró como friend"
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D se declaró con una especificación de excepción"
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "la definición de %qD no está en un espacio de nombres que contenga a %qT"
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "la función miembro static %q#D se declara con calificadores de tipo"
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD se declaró como un no-parámetro"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "el parámetro %qD se declaró con tipo void"
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "el método Java %qD tiene un tipo de devolución %qT que no es de Java"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after union definition"
 msgid "concept %qD has no definition"
 msgstr "se esperaba %<;%> después de la definición de union"
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be instrumented"
 msgid "a function concept cannot be constrained"
 msgstr "no se puede instrumentar la función"
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD no es una función plantilla"
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "constrained non-template friend declaration must be a definition"
 msgstr "la declaración friend no está en una definición de clase"
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "definiendo la especialización explícita %qD en la declaración friend"
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "uso no válido del id de plantilla %qD en la declaración de la plantilla primaria"
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "no se permiten los argumentos por defecto en la declaración de la especialización friend de la plantilla %qD"
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "no se permite %<inline%> en la declaración de la especialización friend de la plantilla %qD"
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "la declaración de %q#D fuera de la clase no es una definición"
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "no se puede declarar %<::main%> como plantilla"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "no se puede declarar %<::main%> como inline"
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "no se puede declarar %<::main%> como static"
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "no se puede declarar %<::main%> como static"
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "la función que no es miembro %qD no puede tener calificador-cv"
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "la función miembro static %qD no puede tener calificador-cv"
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr "la función miembro static %qD no puede tener calificador-cv"
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "la función que no es miembro %qD no puede tener calificador-cv"
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "la función miembro static %qD no puede tener calificador-cv"
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr "la función miembro static %qD no puede tener calificador-cv"
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "explicit object parameter declared here"
 msgstr "el tipo de parámetro de plantilla %qT se declaró %<friend%>"
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "la especialización de %qD debe aparecer en un ámbito de espacio de nombres"
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "la especialización de %qD debe aparecer en un ámbito de espacio de nombres"
 
 #  FIXME traducción
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "la declaración de %qD como algo que no es función"
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "operador literal con enlace C"
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD tien una lista de argumentos no válida"
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, fuzzy, gcc-internal-format
 #| msgid "integer suffix %<%s%> shadowed by implementation"
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "se oscurece el sufijo entero %<%s%> por la implementación"
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, fuzzy, gcc-internal-format
 #| msgid "floating point suffix %<%s%> shadowed by implementation"
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "se oscurece el sufijo de coma flotante %<%s%> por la implementación"
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "los sufijos de operador literal que no están precedidos por %<_%> están reservados para estandarización futura"
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD debe ser una función que no sea miembro"
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> debe devolver %<int%>"
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "la definición de %qD declarado implícitamente"
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "la definición de %qD explícitamente por defecto"
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D explicitly defaulted here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D explícitamente por defecto aquí"
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "no hay una función miembro %q#D declarada en la clase %qT"
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "no se puede declarar %<::main%> como plantilla"
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "la variable automática %qE no puede ser %<threadprivate%>"
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "concept must be defined at namespace scope"
 msgstr "la especialización de %qD debe aparecer en un ámbito de espacio de nombres"
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "un objeto de tamaño variable puede no ser inicializado"
 
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "inicialización en la clase del miembro de datos static %q#D de tipo incompleto"
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "se necesita %<constexpr%> para la inicialización en la clase no válida del miembro de datos static %q#D de tipo que no es integral"
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "inicialización en la clase del miembro de datos static %q#D de tipo que no es literal"
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "inicialización en la clase no válida para el miembro de datos static de tipo %qT que no es integral"
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ prohíbe la inicialización en la clase del miembro static %qD que no es constante"
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ prohíbe la inicialización de la constante miembro %qD del tipo %qT que no es entero"
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "el tamaño de la matriz %qD tiene un tipo %qT que no es integral"
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "el tamaño de la matriz tiene un tipo %qT que no es integral"
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "el tamaño de la matriz %qD no es una expresion constante integral"
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "el tamaño de la matriz no es una expresion constante integral"
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ prohíbe la matriz %qD de tamaño cero"
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ prohíbe matrices de tamaño cero"
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ prohíbe la matriz %qD de longitud variable"
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ prohíbe las matrices de longitud variable"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "se usa la matriz de longitud variable %qD"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "se usó la matriz de longitud variable"
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "desbordamiento en la dimensión de la matriz"
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%q+D se declaró como friend"
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "creating array of template placeholder type %qT"
 msgstr "se crea un puntero al miembro de referencia de tipo %qT"
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "la declaración de %qD como una matriz de voids"
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "se crea la matriz de voids"
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "la declaración de %qD como una matriz de funciones"
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "se crea la matriz de funciones"
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "la declaración de %qD como una matriz de referencias"
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "se crea la matriz de referencias"
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "la declaración de %qD como una matriz de miembros de función"
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "se crea la matriz de miembros de función"
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "la declaración de %qD como una matriz multidimensional debe tener límites para todas las dimensiones excepto la primera"
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "una matriz multidimensional debe tener límites para todas las dimensiones excepto para la primera"
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable-length array of %<auto%>"
 msgstr "se usó la matriz de longitud variable"
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "la especificación del tipo de devolución para el constructor es no válida"
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "la especificación del tipo de devolución para el destructor es no válida"
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "se especificó un tipo de devolución para %<operator %T%>"
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "la especificación del tipo de devolución para el destructor es no válida"
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "especificadores en conflicto en la declaración de %qs"
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "especificadores en conflicto en la declaración de %qs"
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "se declaró la variable o campo sin nombre como void"
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "se declaró la variable o campo como void"
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "el especificador %<inline%> es no válido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "uso no válido del nombre calificado %<::%D%>"
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "uso no válido del nombre calificado %<%T::%D%>"
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "uso no válido del nombre calificado %<%D::%D%>"
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT no es una clase o un espacio de nombres"
 
 #  FIXME traducción
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "la declaración de %qD como algo que no es función"
 
 #  FIXME traducción
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "declaración de %qD como algo que no es miembro"
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "falta el id del declarador; se utiliza la palabra reservada %qD"
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "la definición de la función no declara parámetros"
 
 #  FIXME traducción
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "la declaración de %qD como algo que no es función"
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "declaración de %qD como %<typedef%>"
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "la declaración de %qD como parámetro"
 
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, fuzzy, gcc-internal-format
 #| msgid "no classes specified"
 msgid "both %qs and %qs specified"
 msgstr "no se especificó ninguna clase"
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%<constexpr%> no puede aparecer en una declaración typedef"
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "dos o más tipos de datos en la declaración de %qs"
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C no admite %<complex%> simples que significan %<double complex%>"
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ prohíbe la declaración de %qs sin tipo"
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "no se admite %<__int128%> en este objetivo"
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<__int128%> for %qs"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ no admite %<__int128%> para %qs"
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, fuzzy, gcc-internal-format
 #| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> y %<unsigned%> se especificaron juntos para %qs"
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> y %<short%>  se especificaron juntos para %qs"
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, fuzzy, gcc-internal-format
 #| msgid "%qs used with %qE"
 msgid "%qs specified with %qT"
 msgstr "se usó %qs con %qE"
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<typedef%>"
 msgid "%qs specified with typedef-name %qD"
 msgstr "se usó %qE con %<typedef%>"
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<typedef%>"
 msgid "%qs specified with %<decltype%>"
 msgstr "se usó %qE con %<typedef%>"
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "se usó %qE con %<typedef%>"
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex no válido para %qs"
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "el miembro %qD no se puede declarar como virtual y static al mismo tiempo"
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "el miembro %qD no se puede declarar como virtual y static al mismo tiempo"
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "declaración typedef no válida en la declaración de parámetros"
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "se especificó una clase de almacenamiento para el parámetro de plantilla %qs"
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "se especificó una clase de almacenamiento para el parámetro %qs"
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %qs"
 msgstr "un parámetro no se puede declarar %<constexpr%>"
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "declaración de clase fuera de %<virtual%>"
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "se descarta el atributo en la declaración de %q#T"
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "inicializador no válido para la cadena de bits"
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "la función %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, fuzzy, gcc-internal-format
 #| msgid "indirect function %q+D cannot be declared weak"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "la función indirecta %q+D no se puede declarar weak"
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, fuzzy, gcc-internal-format
 #| msgid "indirect function %q+D cannot be declared weak"
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "la función indirecta %q+D no se puede declarar weak"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "múltiples clases de almacenamiento en la declaración de %qs"
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "se especificó una clase de almacenamiento para %qs"
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "la función anidada %qs se declaró %<extern%>"
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "la declaración del nivel superior de %qs especifica %<auto%>"
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "el ámbito de la función %qs es implícitamente auto y declarado %<__thread%>"
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "especificadores de clase de almacenamiento no válidos en las declaraciones de funciones friend"
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "se descarta el atributo"
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "un atributo que atañe a un especificador de tipo se descarta"
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "múltiples clases de almacenamiento en la declaración de %qs"
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "Se esperaba un paréntesis izquierdo"
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "a function type cannot have an explicit object parameter"
 msgstr "La función '%s' en %L no puede tener un inicializador"
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr "la función %qs no puede tener argumentos"
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, fuzzy, gcc-internal-format
 #| msgid "  member function type %qT is not a valid template argument"
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr "  el tipo de función miembro %qT no es un argumento de plantilla válido"
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr ""
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "the type of an explicit object member function is a regular function type"
 msgstr "no se pueden definir tipos en condiciones"
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "valid explicit object parameter declared here"
 msgstr "el tipo de parámetro de plantilla %qT se declaró %<friend%>"
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "la función %qs usa el especificador de tipo %<auto%> sin un tipo de devolución trailing"
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "el tipo de devolución trailing sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "la función %qs con tipo de devolución trailing tiene %qT como su tipo en lugar de un simple %<auto%>"
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "la función %qs con tipo de devolución trailing tiene %qT como su tipo en lugar de un simple %<auto%>"
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "uso no válido de %<auto%>"
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "la función %qs no puede tener argumentos"
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "el tipo de devolución trailing sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "no se declaró la función %qs con tipo de devolución trailing con el especificador de tipo %<auto%>"
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "la función %qs no puede tener argumentos"
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%>-qualified return type of %qD"
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "calificado %<_Atomic%> el tipo de retorno de %qD"
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs que se declaró como función devuelve una función"
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs que se declaró como función devuelve una matriz"
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "la función %<noreturn%> devuelve un valor que no es void"
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "el destructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "los constructores tal vez no sean cv-calificados"
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "los constructores no se pueden declarar virtual"
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "la declaración friend no está en una definición de clase"
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "no se puede definir la función friend %qs en una definición de clase local"
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr "la función que no es miembro %qD no puede tener calificador-cv"
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr "las plantillas no pueden ser %<virtual%>"
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "an explicit object member function cannot be %<static%>"
 msgstr "los constructores no se pueden declarar virtual"
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD cannot be an explicit object member function"
 msgstr "%qD debe ser una función miembro que no sea static"
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "los destructores no pueden tener parámetros"
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "no se puede declarar el puntero a %q#T"
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "no se puede declarar la referencia a %q#T"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "no se puede declarar el puntero al miembro %q#T"
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "no se puede declarar la referencia para el tipo de función calificado %qT"
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "no se puede declarar la referencia a %q#T, el cual no es una definición de tipo o un argumento de tipo de plantilla"
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "el id de plantilla %qD se usa como un declarador"
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "las funciones miembros son implícitamente friends de su clase"
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "calificación extra %<%T::%> en el miembro %qs"
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "no se puede definir la función miembro %<%T::%s%> dentro de %<%T%>"
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "no se puede declarar la función miembro %<%T::%s%> dentro de %<%T%>"
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "no se puede declarar el miembro %<%T::%s%> dentro de %qT"
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "%qs que no es parámetro no puede ser un paquete de parámetro"
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "los datos miembro pueden no tener el tipo modificado variablemente %qT"
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "el parámetro puede no tener el tipo modificado variablemente %qT"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "declaración de clase fuera de %<virtual%>"
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> en una declaración vacía"
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "solamente las declaraciones de constructores pueden ser %<explicit%>"
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "el no-miembro %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "el miembro que no es objeto %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "la función %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "static %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "const %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "la referencia %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a function definition"
 msgstr "no se pueden definir tipos en condiciones"
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a member function definition"
 msgstr "no se pueden definir tipos en condiciones"
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> fuera de una declaración"
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "la definición de tipo se declaró %<auto%>"
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "el nombre del typedef puede no ser un especificador-de-nombre-anidado"
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ prohíbe el tipo anidado %qD con el mismo nombre que la clase que lo contiene"
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "se especificó %<inline%> para la declaración de clase friend"
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "los parámetros de la plantilla no pueden ser friends"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "la declaración friend requere una llave de clase, p.e. %<friend class %T::%D%>"
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "la declaración friend requiere una llave de clase, p.e. %<friend %#T%>"
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "se intenta hacer que la clase %qT sea un friend de ámbito global"
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "calificadores no válidos en el tipo de función que no es miembro"
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "el declarador abstracto %qT se usó como declaración"
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of function type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "inicialización por valor del tipo de función %qT"
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "no se puede usar %<::%>  en la declaración de parámetros"
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "no se puede declarar que el parámetro %q+D sea del tipo abstracto %qT"
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "no se puede usar %<this%> en este contexto"
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "el parámetro se declaró %<auto%>"
 
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "uso no válido del nombre-de-plantilla %qE sin una lista de argumentos"
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member declared %<auto%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "se declaró el miembro dato que no es static como %<auto%>"
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C90 no admite miembros de matriz flexibles"
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 no admite miembros de matriz flexibles"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "uso no válido de %<::%>"
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "declaración de la función %qD en un contexto no válido"
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "la función %qD se declaró virtual dentro de un union"
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD no se puede declarar virtual, ya que siempre es static"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "se esperaba un nombre calificado en la declaración friend para el destructor %qD"
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "declaración de %qD como miembro de %qT"
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %qs"
 msgstr "un destructor no puede ser %<constexpr%>"
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "se esperaba un nombre calificado en la declaración friend para el constructor %qD"
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a constructor cannot be %<concept%>"
 msgstr "un destructor no puede ser %<constexpr%>"
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "no se puede abrir %s"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD redeclared as function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "la variable %qD se redeclaró como función"
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, fuzzy, gcc-internal-format
 #| msgid "original type declared here"
 msgid "variable template declared here"
 msgstr "el tipo original se definió aquí"
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "el campo %qD tiene tipo de dato incompleto"
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "el nombre %qT tiene tipo de dato incompleto"
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE no es ni función ni función miembro; no se puede declarar friend"
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE no es ni función ni función miembro; no se puede declarar friend"
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, fuzzy, gcc-internal-format
 #| msgid "an attribute that appertains to a type-specifier is ignored"
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr "un atributo que atañe a un especificador de tipo se descarta"
 
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "static data member %qE declared %qs"
 msgstr "se declaró el miembro dato que no es static %qE como %<constexpr%>"
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr static data member %qD must have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "el miembro dato static constexpr %qD debe tener un inicializador"
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "se declaró el miembro dato que no es static %qE como %<constexpr%>"
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<auto%> es no válida para la función %qs"
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<register%> es no válida para la función %qs"
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<__thread%> es no válida para la función %qs"
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<__thread%> es no válida para la función %qs"
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, fuzzy, gcc-internal-format
 #| msgid "alignment specified for function %qE"
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr "se especificó la alineación para la función %qE"
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "no se permiten los especificadores-virt en %qs fuera de una definición de clase"
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "el especificador %<static%> es no válido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "el especificador %<inline%> es no válido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "función virtual %qs que no es clase"
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "se definió %qs en un ámbito que no es una clase"
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "se declaró %qs en un ámbito que no es una clase"
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "no se puede declarar que la función miembro %qD tenga enlace estático"
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "no se puede declarar una función static dentro de otra función"
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> puede no ser utilizado cuando se define (opuesto a la declaración) un dato miembro static"
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "se declaró el miembro static %qD como %<register%>"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "no se puede declarar explícitamente que el miembro %q#D tenga un enlace externo"
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of constexpr variable %qD is not a definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "la declaración de la variable constexpr %qD no es una definición"
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "un parámetro no se puede declarar %<constexpr%>"
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs inicializado y declarado como %<extern%>"
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs tiene %<extern%> e inicializador al mismo tiempo"
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "el argumento por defecto %qE usa %qD"
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "el argumento por defecto %qE usa la variable local %qD"
 
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "uso no válido de %<virtual%> en la declaración de plantilla de %q#D"
 
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "uso no válido de %<virtual%> en la declaración de plantilla de %q#D"
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "tipo de parámetro cualificado %<_Atomic%> %qT de %q+D"
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "el parámetro %qD se declaró no válidamente como tipo de método"
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "el parámetro %qD incluye un puntero a matriz %qT de límite desconocido"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "el parámetro %qD incluye una referencia a matriz %qT de límite desconocido"
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "constructor no válido; tal vez quiso decir %<%T (const %T&)%>"
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD no se puede declarar dentro de un espacio de nombres"
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD no se puede declarar como static"
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD debe ser una función miembro que no sea static"
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a non-member function"
 msgid "%qD must be a member function"
 msgstr "%qD debe ser una función que no sea miembro"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD debe ser una función miembro que no sea static o una función que no sea miembro"
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD debe tener un argumento de tipo clase o enumerado"
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ prohíbe la sobrecarga del operador ?:"
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD no debe tener un número variable de argumentos"
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD debe tomar cero o un argumentos"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD debe tomar uno o dos argumentos"
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "el postfijo %qD debe tomar %<int%> como su argumento"
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "el postfijo %qD debe tomar %<int%> como su segundo argumento"
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD debe tomar dos argumentos exactamente"
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD debe tomar un argumento exactamente"
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD debe tomar dos argumentos exactamente"
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD no puede tener argumentos por defecto"
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "la conversión a void nunca usará un operador de conversión de tipo"
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "la conversión a una referencia al mismo tipo nunca usará un operador de conversión de tipo"
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to the same type will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "la conversión al mismo tipo nunca usará un operador de conversión de tipo"
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "la conversión a una referencia a una clase base nunca usará un operador de conversión de tipo"
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a base class will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "la conversión a una clase base nunca usará un operador de conversión de tipo"
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "el %qD definido por el usuario siempre evalúa ambos argumentos"
 
 #  En esta traducción se emplea 'devolver' por 'return'. Si embargo, aquí
 #  se cambió por cacofonía: no es agradable escuchar 'debe devolver'. cfuga
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "el prefijo %qD debe regresar %qT"
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "el postfijo %qD debe regresar %qT"
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD debe devolver por valor"
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "usando el parámetro de tipo plantilla %qT después de %qs"
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "se usa especialización de plantilla %qT alias después de %qs"
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "se usó el nombre de definición de tipo %qD después de %qs"
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD tiene una declaración previa aquí"
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "se refirió a %qT como %qs"
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T tiene una declaración previa aquí"
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "se refirió a %qT como un enum"
@@ -61094,71 +61102,60 @@ msgstr "se refirió a %qT como un enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "se requiere un argumento de plantilla para %<%s %T%>"
 
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "la referencia a %qD es ambigua"
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, fuzzy, gcc-internal-format
 #| msgid "function template %qD redeclared as a class template"
 msgid "class template %qD redeclared as non-template"
 msgstr "la plantilla de función %qD se redeclaró commo una plantilla de clase"
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD tiene el mismo nombre que la clase en la cual se declaró"
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT no es una plantilla"
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "uso del enum %q#D sin declaración previa"
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redeclaración de %qT como algo que no es plantilla"
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare %qD to be a bit-field type"
-msgid "cannot declare %qD in a different module"
-msgstr "no se puede declarar %qD que sea un tipo de campo de bits"
-
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, gcc-internal-format
-msgid "previously declared here"
-msgstr "se declaró previamente aquí"
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "union derivada %qT no válida"
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
@@ -61166,49 +61163,43 @@ msgstr "el tipo %qT no es una base directa o virtual de %qT"
 
 #  No me gusta mucho esta traducción. Creo que es mejor
 #  "el tipo base %qT no es de tipo struct o clase". cfuga
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "el tipo base %qT falla en ser un tipo struct o clase"
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "tipo recursivo %qT sin definir"
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "tipo base duplicado %qT no válido"
 
-#: cp/decl.cc:16984
-#, fuzzy, gcc-internal-format
-#| msgid "cannot capture %qE by reference"
-msgid "cannot declare %qD in different module"
-msgstr "no se puede capturar %qE por referencia"
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "no coinciden scoped/unscoped en el enum %q#T"
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "la definición previa está aquí"
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "no coincide el tipo subyacente en el enum %q#T"
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "tipos subyacentes diferentes en el enum %q#T"
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -61218,89 +61209,89 @@ msgstr "el tipo subyacente %<%T%> de %<%T%> debe ser un tipo integral"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ningún tipo integral puede representar todos los valores de enumerador de %qT"
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "el valor de enumerador para %qD no es una constante entera"
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "el valor de enumerador para %qD no es una constante entera"
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "el valor del enumerador incrementado es demasiado grande para %<unsigned long%>"
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, fuzzy, gcc-internal-format
 #| msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "el valor del enumerador incrementado es demasiado grande para %<unsigned long%>"
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "desbordamiento en valores de enumeración en %qD"
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "el valor de enumerador %E es demasiado grande para el tipo subyacente %<%T%>"
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "definición múltiple de %q#T"
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "el tipo de devolución %q#T es un tipo de dato incompleto"
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> debe devolver una referencia a %<*this%>"
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "no hay una declaración de devolución en la función que no devuelve void"
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "los tipos de devolución de función no son compatibles debido a %<volatile%>"
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "no hay una declaración de devolución en la función que no devuelve void"
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD ya se definió en la clase %qT"
 
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing %qs"
 msgid "using %qs"
 msgstr "%qs contenedora"
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD defaults to %<int%>"
 msgid "use of %qD before deduction of %<auto%>"
@@ -61358,7 +61349,7 @@ msgstr "no se puede borrar una función.  Solamente los punteros a objetos son a
 msgid "deleting %qT is undefined"
 msgstr "el borrado de %qT está indefinido"
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "declaración plantilla de %q#D"
@@ -61368,7 +61359,7 @@ msgstr "declaración plantilla de %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "las listas de parámetro de plantilla proporcionadas no coinciden con los parámetros de plantilla de %qD"
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "se declaró el destructor %qD como una plantilla miembro"
@@ -61567,73 +61558,73 @@ msgstr "los destructores deben ser funciones miembro"
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> toma el tipo %qT como primer argumento"
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr "%qT tiene un campo %qD cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT tiene un campo %qD cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr "%qT tiene un campo %qD cuyo tipo usa el espacio de nombres anónimo"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr "%qT tiene un campo %qD cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT se declaró con mayor visibilidad que el tipo de su campo %qD"
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT which has no linkage"
 msgstr "%qT tiene una base %qT cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr "%qT tiene una base %qT cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT which has internal linkage"
 msgstr "%qT tiene una base %qT cuyo tipo usa el espacio de nombres anónimo"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr "%qT tiene una base %qT cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT se declaró con mayor visibilidad que su base %qT"
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using anonymous type, is used but never defined"
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr "%q+#D, declarada usando el tipo anónimo, se usa pero nunca se define"
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using anonymous type, is used but never defined"
 msgid "%q#D, declared using an unnamed type, is used but not defined"
@@ -61643,118 +61634,118 @@ msgstr "%q+#D, declarada usando el tipo anónimo, se usa pero nunca se define"
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "se usó un tipo anónimo sin enlace para declarar la variable %q#D sin enlace"
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "se usó un tipo anónimo sin enlace para declarar la función %q#D con enlace"
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D no se refiere al tipo sin calificar, así que no se usa para el enlace"
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using local type %qT, is used but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+#D, declarada usando el tipo local %qT, se usa pero nunca se define"
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using local type %qT, is used but never defined"
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr "%q+#D, declarada usando el tipo local %qT, se usa pero nunca se define"
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "se usó el tipo %qT sin enlace para declarar la variable %q#D con enlace"
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "se usó el tipo %qT sin enlace para declarar la función %q#D con enlace"
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with a previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q#D genera un conflicto con una declaración previa"
 
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previous mangling %q#D"
 msgstr "declaración previa de %q+#D"
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, fuzzy, gcc-internal-format
 #| msgid "-fabi-version=6 (or =0) avoids this error with a change in mangling"
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr "-fabi-version=6 (o =0) evita este error con un cambio en la decodificación"
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "se usa la función inline %q+D pero nunca se define"
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, fuzzy, gcc-internal-format
 #| msgid "default argument missing for parameter %P of %q+#D"
 msgid "default argument missing for parameter %P of %q#D"
 msgstr "falta el argumento por defecto para el parámetro %P de %q+#D"
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, fuzzy, gcc-internal-format
 #| msgid "parameter pack cannot have a default argument"
 msgid "...following parameter %P which has a default argument"
 msgstr "el paquete de parámetros no puede tener un argumento por defecto"
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, fuzzy, gcc-internal-format
 #| msgid "class %qE is deprecated"
 msgid "implicitly-declared %qD is deprecated"
 msgstr "la clase %qE es obsoleta"
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, fuzzy, gcc-internal-format
 #| msgid "converting lambda which uses %<...%> to function pointer"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "se convierte lambda la cual usa %<...%> a un puntero de función"
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "se usó la función borrada %q+D"
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "la redeclaración de %qD difiere en %<constexpr%>"
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -61877,7 +61868,7 @@ msgstr "la referencia a %<%T::%D%> es ambigua"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qT no tiene un miembro llamado %qE; ¿quiso decir %qE?"
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD no es un miembro de %qT"
@@ -61888,7 +61879,7 @@ msgstr "%qD no es un miembro de %qT"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qT no tiene un miembro llamado %qE; ¿quiso decir %qE?"
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD no es un miembro de %qD"
@@ -61915,52 +61906,52 @@ msgstr "manejo de excepciones desactivado, use -fexceptions para activar"
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr "arrojando NULL, que tiene un tipo integral, que no es puntero"
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, gcc-internal-format
 msgid "  in thrown expression"
 msgstr "  en la expresión thrown"
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr "no se puede declarar que el parámetro %q+D sea del tipo abstracto %qT"
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create type information for type %qT because it involves types of variable size"
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr "no se puede crear la información de tipo para el tipo %qT porque involucra tipos de tamaño variable"
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create type information for type %qT because it involves types of variable size"
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr "no se puede crear la información de tipo para el tipo %qT porque involucra tipos de tamaño variable"
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, fuzzy, gcc-internal-format
 #| msgid "exception of type %qT will be caught"
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr "la excepción del tipo %qT se atrapará"
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to %s"
 msgid "for type %qT"
 msgstr "argumento de tipo erróneo para %s"
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, gcc-internal-format
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr "el manejador %<...%> debe ser el último manejador para su bloque try"
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr "la expresión noexcept evalúa a %<falso%> por una llamada a %qD"
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, fuzzy, gcc-internal-format
 #| msgid "but %q+D does not throw; perhaps it should be declared %<noexcept%>"
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
@@ -62238,12 +62229,12 @@ msgstr "el tipo %qT no es una base directa o virtual de %qT"
 msgid "type %qT is not a direct base of %qT"
 msgstr "el tipo %qT no es una base directa de %qT"
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "la matriz se debe inicializar con un inicializador dentro de llaves"
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT no es un tipo de clase"
@@ -62258,12 +62249,12 @@ msgstr "el tipo incompleto %qT no tiene al miembro %qD"
 msgid "invalid pointer to bit-field %qD"
 msgstr "puntero no válido al campo de bits %qD"
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "uso no válido de la función miembro no static %qD"
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "uso no válido del dato miembro no static %qD"
@@ -62477,54 +62468,54 @@ msgstr "si borra un objeto de tipo de clase abstracta %qT que tiene un destructo
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "si borra un objeto de tipo de clase polimórfica %qT que tiene un destructor que no es virtual, puede causar conducta indefinida"
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "el tipo de vector delete no es del tipo puntero ni matriz"
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, fuzzy, gcc-internal-format
 #| msgid "compound literal has variable size"
 msgid "because the array element type %qT has variable size"
 msgstr "la literal compuesta tiene tamaño variable"
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "no se puede capturar %qE por referencia"
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of incomplete type %q#T"
 msgid "capture by copy of incomplete type %qT"
 msgstr "uso no válido del tipo incompleto %q#T"
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "no se capturó %<this%> para esta función lambda"
@@ -62934,242 +62925,293 @@ msgstr "se esperaba un id de plantilla para el tipo"
 msgid "encapsulation is malformed"
 msgstr ""
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting global module declaration %#qD"
 msgstr "declaraciones de %q#D en conflicto"
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration %q+D"
 msgid "existing declaration %#qD"
 msgstr "en la declaración %q+D"
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, fuzzy, gcc-internal-format
 #| msgid "extern declaration of %q#D doesn%'t match"
 msgid "definition of %qD does not match"
 msgstr "la declaración extern de %q#D no coincide"
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, fuzzy, gcc-internal-format
 #| msgid "missing definition"
 msgid "existing definition %qD"
 msgstr "falta la definición"
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "... this enumerator %qD"
 msgstr "redeclaración del enumerador %q+D"
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "enumerator %qD does not match ..."
 msgstr "el argumento de tipo %qT no coincide con %qT"
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr ""
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr ""
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr ""
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, gcc-internal-format
 msgid "recursive lazy load"
 msgstr ""
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr ""
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, fuzzy, gcc-internal-format
 #| msgid "routine %qD declared here"
 msgid "module %qs declared here"
 msgstr "la rutina %qD se declara aquí"
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, gcc-internal-format
 msgid "indirect import %qs is not already loaded"
 msgstr ""
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr ""
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr ""
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "macro definitions of %qE corrupted"
 msgstr "la definición previa de %q+D estaba aquí"
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, fuzzy, gcc-internal-format
 #| msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgid "inconsistent imported macro definition %qE"
 msgstr "  deducción de paquete de parámetros inconsistente con %qT y %qT"
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr ""
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr ""
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete module file %qs: %s"
 msgid "compiled module file is %qs"
 msgstr "No se puede borrar el fichero de módulo %qs: %s"
 
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Display the compiler's version."
 msgid "compiled module is %sversion %s"
 msgstr "Muestra la versión del compilador."
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collect2 version %s\n"
 msgid "compiler is %sversion %s%s%s"
 msgstr "collect2 versión %s\n"
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, fuzzy, gcc-internal-format
 #| msgid "no %qs getter found"
 msgid "module %qs found"
 msgstr "no se encuentra el getter %qs"
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr ""
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr ""
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr ""
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr ""
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, fuzzy, gcc-internal-format
 #| msgid "exception handling disabled, use -fexceptions to enable"
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr "manejo de excepciones desactivado, use -fexceptions para activar"
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, fuzzy, gcc-internal-format
 #| msgid "function attribute mismatch"
 msgid "fixed tree mismatch"
 msgstr "no coincide el atributo de función"
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, fuzzy, gcc-internal-format
 #| msgid "target optimization options not supported yet"
 msgid "interface partition is not exported"
 msgstr "no se admiten aún las opciones de optimización del objetivo"
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to rename %s to state file %s [%s]"
 msgid "failed to read compiled module cluster %u: %s"
 msgstr "no se puede renombrar %s al fichero de estado %s [%s]"
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to open %s"
 msgid "failed to read compiled module: %s"
 msgstr "no se puede abrir %s"
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr ""
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr ""
 
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr ""
 
-#: cp/module.cc:19283
+#: cp/module.cc:19117
+#, fuzzy, gcc-internal-format
+#| msgid "conflicts with built-in declaration %q#D"
+msgid "declaration %qD conflicts with builtin"
+msgstr "genera un conflicto con la declaración interna %q#D"
+
+#: cp/module.cc:19122
+#, fuzzy, gcc-internal-format
+#| msgid "declaration of namespace %qD conflicts with"
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr "la declaración del espacio de nombres %qD genera un conflicto con"
+
+#: cp/module.cc:19125
+#, gcc-internal-format
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr ""
+
+#: cp/module.cc:19130
+#, gcc-internal-format
+msgid "import declared attached to module %qs"
+msgstr ""
+
+#: cp/module.cc:19134
+#, gcc-internal-format
+msgid "import declared in global module"
+msgstr ""
+
+#: cp/module.cc:19140
+#, fuzzy, gcc-internal-format
+#| msgid "declaration of template %q#D"
+msgid "conflicting declaration of %qD in module %qs"
+msgstr "redeclaración de la plantilla %q#D"
+
+#: cp/module.cc:19143
+#, fuzzy, gcc-internal-format
+#| msgid "previous declaration of %q+#D with %qL linkage"
+msgid "conflicting declaration of %qD in global module"
+msgstr "declaración previa de %q+#D con el enlace %qL"
+
+#: cp/module.cc:19148
+#, fuzzy, gcc-internal-format
+#| msgid "previously declared here"
+msgid "previously declared in module %qs"
+msgstr "se declaró previamente aquí"
+
+#: cp/module.cc:19152
+#, fuzzy, gcc-internal-format
+#| msgid "previously declared here"
+msgid "previously declared in global module"
+msgstr "se declaró previamente aquí"
+
+#: cp/module.cc:19404
 #, fuzzy, gcc-internal-format
 #| msgid "reading"
 msgid "reading CMI %qs"
 msgstr "leyendo"
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, gcc-internal-format
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, fuzzy, gcc-internal-format
 #| msgid "unknown option for %<%s=%s%>"
 msgid "during load of pendings for %<%E%s%E%>"
@@ -63182,442 +63224,442 @@ msgstr "opción desconocida para %<%s=%s%>"
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr ""
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol %qs already declared"
 msgid "module already declared"
 msgstr "El símbolo %qs ya se había declarado"
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, fuzzy, gcc-internal-format
 #| msgid "module procedure"
 msgid "module already imported"
 msgstr "procedimiento módulo"
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, fuzzy, gcc-internal-format
 #| msgid "module procedure"
 msgid "module %qs imported here"
 msgstr "procedimiento módulo"
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown operand letter: '%c'"
 msgid "unknown Compiled Module Interface: %s"
 msgstr "letra de operando desconocida: '%c'"
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr ""
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr ""
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr ""
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, fuzzy, gcc-internal-format
 #| msgid "while writing precompiled header"
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr "al escribir el encabezado precompilado"
 
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, fuzzy, gcc-internal-format
 #| msgid "Enable traditional preprocessing."
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr "Habilita el preprocesamiento tradicional."
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr ""
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr ""
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use the Xtensa SEXT option"
 msgid "you should use the %<-%s%> option"
 msgstr "No usar la opción SEXT de Xtensa"
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param name %qs"
 msgid "invalid header name %qs"
 msgstr "nombre de --param %qs no válido"
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, fuzzy, gcc-internal-format
 #| msgid "invalid macro name `%s'"
 msgid "invalid module name %qs"
 msgstr "nombre de macro `%s' no válido"
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr ""
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, fuzzy, gcc-internal-format
 #| msgid "error writing %qs"
 msgid "writing CMI %qs"
 msgstr "error al escribir %qs"
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing modules file: %s"
 msgid "not writing module %qs due to errors"
 msgstr "Error al escribir el fichero de módulos: %s"
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to write state trailer [%s]"
 msgid "failed to write compiled module: %s"
 msgstr "no se puede escribir el estado remanente [%s]"
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, fuzzy, gcc-internal-format
 #| msgid "unknown spec function %qs"
 msgid "unknown header kind %qs"
 msgstr "función de especificación %qs desconocida"
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "la declaración de %q+D oscurece un parámetro"
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D genera un conflicto con una declaración previa"
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D esconde el destructor para %q#T"
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "declaraciones de %q#D en conflicto"
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "debido a diferentes especificaciones de excepciones"
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "el parámetro %qD se declaró no válidamente como tipo de método"
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "la declaración de %q#D oscurece un parámetro"
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "declaración de %qD como miembro de %qT"
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "una declaración friend %qD en una clase local sin declaración previa"
 
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "exporting %q#D that does not have external linkage"
 msgstr "%qD no tiene tipo integral o de enumeración"
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D declared here"
 msgid "%q#D declared here with no linkage"
 msgstr "%q+#D se declaró aquí"
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here, later in the translation unit"
 msgid "%q#D declared here with internal linkage"
 msgstr "%q+D se declaró aquí, después en la unidad de translación"
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D declared here"
 msgid "%q#D declared here with module linkage"
 msgstr "%q+#D se declaró aquí"
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names destructor"
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T::%D%> nombra al destructor"
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "declaración de uso para un no miembro en el ámbito de la clase"
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a class, namespace, or enumeration"
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qE no es una clase, un espacio de nombres o una enumeración"
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "declaración plantilla de %q#D"
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "declaración de uso para un no miembro en el ámbito de la clase"
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "%qT is not a direct base of %qT"
 msgstr "el tipo %qT no es una base directa de %qT"
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared in %qD"
 msgstr "%qE no se ha declarado"
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration cannot name destructor"
 msgid "using-declaration may not name namespace %qD"
 msgstr "uan declaración de uso no puede nombrar al destructor"
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> nombra al constructor en %qT"
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "la declaración de %qD no está en un espacio de nombres alrededor de %qD"
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "calificación explícita en la declaración de %qD"
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD se debería declarar dentro de %qD"
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared within %qD"
 msgstr "%qE no se ha declarado"
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D se declaró como friend"
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "el atributo %qD requiere un solo argumento NTBS"
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "el atributo %qD no tiene signifcado porque los miembros del espacio de nombres anónimo tiene símbolos locales"
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "se descarta la directiva de atributo %qD"
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "límite máximo de %d espacios de nombres buscados para %qE"
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "alternativa sugerida:"
 msgstr[1] "alternativas sugeridas:"
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr ""
 
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not available for %s architecture"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%s no está disponible para la arquitectura %s"
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, fuzzy, gcc-internal-format
 #| msgid "weak %q+D cannot be defined %qE"
 msgid "the macro %qs had not yet been defined"
 msgstr "weak %q+D no se puede definir como %qE"
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "it was later defined here"
 msgstr "se definió struct aquí"
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "la deducción de una lista inicializadora encerrada entre llaves requiere #include <initializer_list>"
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "la opción %qs ya no se admite"
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, fuzzy, gcc-internal-format
 #| msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgid "you can use an inline namespace instead"
 msgstr "Esta opción es obsoleta; utilice en su lugar -fsanitize-recover=."
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr "no se puede usar %<this%> en este contexto"
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD no se puede declarar dentro de un espacio de nombres"
 
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "'%s' en %L es ambiguo"
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "no se permite aquí el alias del espacio de nombres %qD, se asume que es %qD"
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, fuzzy, gcc-internal-format
 #| msgid "method attributes must be specified at the end only"
 msgid "inline namespace must be specified at initial definition"
 msgstr "los atributos de método sólo se deben especificar al final"
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "la etiqueta %qD se define aquí"
 
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, fuzzy, gcc-internal-format
 #| msgid "%qD conflicts with used function"
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%qD genera un conflicto con la función utilizada"
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous definition here"
 msgid "reachable %s definition here"
 msgstr "la definición previa está aquí"
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX entrando a pop_everything ()\n"
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -63644,7 +63686,7 @@ msgstr "el identificador %qE es una palabra clave en C++11"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
@@ -63904,7 +63946,7 @@ msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu+
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, fuzzy, gcc-internal-format
 #| msgid "%<@required%> is not available in Objective-C 1.0"
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
@@ -64101,7 +64143,7 @@ msgstr "las expresiones-de-declaraciones no se permiten fuera de funciones ni en
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "se esperaba una expresión primaria"
@@ -64160,7 +64202,7 @@ msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 msgid "template-id not allowed for destructor in C++20"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, gcc-internal-format
 msgid "remove the %qs"
 msgstr ""
@@ -64180,7 +64222,7 @@ msgstr "se usa el nombre-de-definición-de-tipo %qD como un declarador de destru
 msgid "expected unqualified-id"
 msgstr "se esperaba un id sin calificar"
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD no es una plantilla"
@@ -64235,7 +64277,7 @@ msgstr "no se pueden definir tipos en una expresión %<typeid%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "número erróneo de argumentos para %<__builtin_shuffle%>"
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_complex%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -64274,7 +64316,7 @@ msgstr "no se pueden definir tipos en condiciones"
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr ""
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "uso no válido de %qD"
@@ -64299,7 +64341,7 @@ msgstr "ISO C++ no permite %<alignof%> con algo que no es tipo"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "no se pueden definir tipos en expresiones %<noexcept%>"
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in a new-expression"
 msgid "types may not be defined in %qs expressions"
@@ -64466,8 +64508,8 @@ msgstr "inicializador no-vacío para una matriz de elementos vacíos"
 msgid "capture of non-variable %qE"
 msgstr "captura de %qD que no es variable "
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D declared here"
 msgid "%q#D declared here"
@@ -64511,7 +64553,7 @@ msgstr "se especificó un argumento por defecto para el parámetro lambda"
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr ""
@@ -64652,7 +64694,7 @@ msgstr "%<#pragma omp taskyield%> sólo se puede usar en declaraciones compuesta
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "se esperaba una declaración de selección"
@@ -64718,7 +64760,7 @@ msgstr "la expresión %<for%> basada en rango de tipo %qT es de tipo incompleto"
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "tipos begin/end inconsistentes para la declaración %<for%> basada en rango: %qT y %qT"
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "se esperaba una declaración de iteración"
@@ -64747,7 +64789,7 @@ msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu+
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ prohíbe los gotos calculados"
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "se esperaba una declaración de salto"
@@ -65058,12 +65100,12 @@ msgstr "solamente los constructores toman inicializadores miembro"
 msgid "cannot expand initializer for member %qD"
 msgstr "no se puede expandir el inicializador para el miembro %<%D%>"
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "inicializador mem para %qD después de una delegación de constructor"
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "delegación de constructor después de un inicializador mem para %qD"
@@ -65759,7 +65801,7 @@ msgstr "en el argumento de plantilla para el tipo %qT "
 msgid "%qT not permitted in template argument"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, gcc-internal-format
 msgid "invalid use of %qT"
@@ -65949,12 +65991,12 @@ msgstr "definición previa de %q+#T"
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, gcc-internal-format
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr ""
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "se esperaba una llave de clase"
@@ -66181,39 +66223,39 @@ msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 msgid "expression must be enclosed in parentheses"
 msgstr "la expresión debe ser integral"
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr ""
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, fuzzy, gcc-internal-format
 #| msgid "asm template is not a string constant"
 msgid "result type is not a plain type-constraint"
 msgstr "la plantilla asm no es una cadena constante"
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not an integer constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "la alineación solicitada no es una constante entera"
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "el miembro especializado %<%T::%E%> requiere sintaxis %<template<>%>"
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "declaración no válida de %<%T::%E%>"
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "faltan listas-de-parámetros-de-plantilla"
@@ -66222,462 +66264,462 @@ msgstr "faltan listas-de-parámetros-de-plantilla"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "demasiadas listas-de-parámetros-de-plantilla"
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "template-id not allowed for constructor in C++20"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "ya no se admiten los valores de devolución nombrados"
 
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, fuzzy, gcc-internal-format
 #| msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "la plantilla de operador literal %qD tiene una lista de parámetros no válida.  Se esperaba un paquete de argumentos de plantilla que no sean de tipo <char...>"
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, fuzzy, gcc-internal-format
 #| msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "la plantilla de operador literal %qD tiene una lista de parámetros no válida.  Se esperaba un paquete de argumentos de plantilla que no sean de tipo <char...>"
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "no se encontró una plantilla coincidente para %qD"
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "declaración no válida de plantilla miembro en la clase local"
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "plantilla con enlace C"
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "especialización explícita no válida"
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "declaración plantilla de %<typedef%>"
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "la declaración no declara nada"
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "la especialización de plantilla explícita no puede tener una clase de almacenamiento"
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> debe ser %<> >%> dentro de una lista de argumentos de plantilla anidada"
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "%<>>%> sobrante, use %<>%> para terminar una lista de argumentos de plantilla"
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, fuzzy, gcc-internal-format
 #| msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr "%<>>%> sobrante, use %<>%> para terminar una lista de argumentos de plantilla"
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "uso no válido de %qD en la especificación de enlace"
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate virt-specifier"
 msgid "duplicate %qD specifier"
 msgstr "especificador-virt duplicado"
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, fuzzy, gcc-internal-format
 #| msgid "section type conflict with %qD"
 msgid "%qD specifier conflicts with %qs"
 msgstr "conflicto de tipo de sección con %qD"
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> antes de %qD"
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<typedef%>"
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr "se usó %qE con %<typedef%>"
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 no admite %<long long%>"
 
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, fuzzy, gcc-internal-format
 #| msgid "both %<_Sat%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "se usaron al mismo tiempo %<_Sat%> y %<char%> en los especificadores de declaración"
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE duplicado"
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs duplicado"
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "se esperaba %<new%>"
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "se esperaba %<delete%>"
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "se esperaba %<return%>"
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "se esperaba %<extern%>"
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "se esperaba %<static_assert%>"
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "se esperaba %<decltype%>"
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "se esperaba %<operator%>"
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "se esperaba %<class%>"
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "se esperaba %<template%>"
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "se esperaba %<namespace%>"
 
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "se esperaba %<using%>"
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "se esperaba %<asm%>"
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "se esperaba %<try%>"
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "se esperaba %<catch%>"
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "se esperaba %<throw%>"
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>"
 msgid "expected %<auto%>"
 msgstr "se esperaba %<data%>"
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "se esperaba %<__label__%>"
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "se esperaba %<@try%>"
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "se esperaba %<@synchronized%>"
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "se esperaba %<@throw%>"
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "se esperaba %<__transaction_atomic%>"
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "se esperaba %<__transaction_relaxed%>"
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "se esperaba %<@end%>"
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "se esperaba %<::%>"
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "se esperaba %<...%>"
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "se esperaba %<*%>"
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "se esperaba %<~%>"
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "se esperaba %<:%> o %<::%>"
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "se usó la etiqueta %qs al nombrar a %q#T"
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T se declaró previamente aquí"
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "no se puede declarar la referencia a %q#T"
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared with greater visibility than its base %qT"
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT se declaró con mayor visibilidad que su base %qT"
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, fuzzy, gcc-internal-format
 #| msgid "expected class-key"
 msgid "replace the class-key with %qs"
 msgstr "se esperaba una llave de clase"
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qT defined as %qs here"
 msgstr "la etiqueta %qD se define aquí"
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, fuzzy, gcc-internal-format
 #| msgid "  first declared as %q#D here"
 msgid "%qT first declared as %qs here"
 msgstr "  declarado inicialmente como %q#D aquí"
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD se redeclaró con acceso diferente"
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (como desambiguador) sólo se permite dentro de plantillas"
 
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "el fichero termina en el argumento por defecto"
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "construct Objective-C++ %<@%D%> mal ubicado"
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, fuzzy, gcc-internal-format
 #| msgid "objective-c++ message argument(s) are expected"
 msgid "objective-c++ message receiver expected"
 msgstr "se esperaba(n) argumento(s) de mensaje de objective-c++"
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "se esperaba(n) argumento(s) de mensaje de objective-c++"
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> debe especificar un tipo como un argumento"
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "nombre de selector Objective-C++ no válido"
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "se esperaba una declaración de método de objective-c++"
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "los atributos de método se deben especificar al final"
 
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "%qs sobrante después de los métodos Objective-C++"
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "tipo no válido para la variable de de instancia"
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "se esperaba un identificador después de %<@protocol%>"
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "los atributos no se pueden especificar antes de la palabra clave de Objective-C++ %<@%D%>"
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "se descartan los atributos de prefijo antes de %<@%D%>"
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "tipo no válido para la propiedad"
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, fuzzy, gcc-internal-format
 #| msgid "unknown property attribute"
 msgid "unknown property attribute %qE"
 msgstr "atributo de propiedad desconocido"
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "se esperaba una expresión entera"
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "inicializador no válido"
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in parameter types"
 msgid "types may not be defined in iterator type"
@@ -66687,13 +66729,13 @@ msgstr "no se pueden definir tipos en tipos de parámetro"
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma vtable no longer supported"
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "#pragma vtable ya no se admite"
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "no se permite la inicialización entre paréntesis para el bucle %<for%> en OpenMP"
@@ -66704,146 +66746,146 @@ msgstr "no se permite la inicialización entre paréntesis para el bucle %<for%>
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "la cláusula %<ordered%> con parámetro no se puede especificar en la construcción %qs"
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "la variable de iteración %qD no debe ser reduction"
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp end declare target%> sin su correspondiente %<#pragma omp declare target%>"
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr ""
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "inicializador no válido"
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, fuzzy, gcc-internal-format
 #| msgid "expected id-expression"
 msgid "expected id-expression (arguments)"
 msgstr "se esperaba una expresión id"
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "no se pueden definir tipos nuevos en un tipo de devolución"
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, fuzzy, gcc-internal-format
 #| msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "tipo calificado const, volatile o restrict en %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD no es una función plantilla miembro"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> sin activar el soporte de memoria transaccional"
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> sin activar el soporte de memoria transaccional"
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> más externo no está dentro del %<__transaction_atomic%> más externo"
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  o una función %<transaction_may_cancel_outer%>"
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma GCC coprocessor"
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "#pragma GCC coprocessor malformado"
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%> sólo se puede usar en declaraciones compuestas"
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp taskyield%> sólo se puede usar en declaraciones compuestas"
 
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "multi-source compilation not implemented for C++"
 msgstr "no se han implementado las optimizaciones intermódulos para C++"
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "no se permiten las conversiones estándar en este contexto"
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "las plantillas no pueden ser %<virtual%>"
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -66873,7 +66915,7 @@ msgstr "las plantillas de clase contenedoras no son explícitamente especializad
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "la especialización de %qD debe aparecer en un ámbito de espacio de nombres"
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "especialización de %qD en un espacio de nombres diferente"
@@ -66889,28 +66931,28 @@ msgstr " de la definición de %q+#D"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "instanciación explícita de %qD en el espacio de nombres %qD (el cual no incluye el espacio de nombres %qD)"
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "el nombre de la clase oscurece la plantilla de parámetro de plantilla %qD"
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of alias template %qD"
 msgid "specialization of alias template %qD"
 msgstr "especialización parcial de la plantilla alias %qD"
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "instanciación explícita de %qT que no es plantilla"
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "especialización de %qT después de la instanciación"
 
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "from definition of %q#D"
@@ -66918,156 +66960,156 @@ msgstr " de la definición de %q+#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "especialización de %qT después de la instanciación %qT"
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "no se permite la especialización de plantilla de %qD por ISO C++"
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "especialización de %qD después de la instanciación"
 
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD no es una plantilla de función"
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a variable template"
 msgstr "%qD no es una variable"
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "el id-de-plantilla %qD para %q+D no coincide con ninguna declaración de plantilla"
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "se encontró %d %<template<>%>, se necesita %d para especializar una plantilla de función miembro"
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "especialización de plantilla %qD ambigua para %q+D"
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "especialización explícita de %qD después del primer uso"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "instanciación explícita de %qD en el espacio de nombres %qD (el cual no incluye el espacio de nombres %qD)"
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "especialización explícita de %qD después del primer uso"
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "missing primary template attributes %s"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "missing primary template attribute %s"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD in declaration of primary template"
 msgid "template-id %qE in declaration of primary template"
 msgstr "id de plantilla %qD en la declaración de la plantilla primaria"
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "no se usan la plantilla de lista de parámetros en la instanciación explícita"
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "se proporcionó una definición para la instanciación explícita"
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "demasiadas listas de parámetros de plantilla en la declaración de %qD"
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "faltan listas de parámetros de plantilla en la declaración de %qD"
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "la especialización explícita de %qD se debe preceder con %<template <>%>"
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "instanciación explícita de %qT que no es plantilla"
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "no se permite la especialización parcial de la función de plantilla %qD"
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "no se permite la especialización parcial de la función de plantilla %qD"
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "se especificó un argumento por defecto en la especialización explícita"
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD no es una función plantilla"
@@ -67080,175 +67122,175 @@ msgstr "%qD no es una función plantilla"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "especialización de la función miembro especial declarada implícitamente"
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "la función no miembro %qD se declaró en %qT"
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "una declaración friend %qD en una clase local sin declaración previa"
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, fuzzy, gcc-internal-format
 #| msgid "shadowed declaration is here"
 msgid "friend declaration here"
 msgstr "aquí está la declaración oscurecida"
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "instanciación explícita de %qT que no es plantilla"
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "El argumento de ACOS en %L debe estar entre -1 y 1"
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, fuzzy, gcc-internal-format
 #| msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "la expansión del inicializador base %<%T%> no contiene paquetes de parámetro"
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%T%> contains no argument packs"
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "el patrón de expansión %<%T%> no contiene paquetes de argumento"
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%E%> contains no argument packs"
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "el patrón de expansión %<%E%> no contiene paquetes de argumento"
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "no se expanden los paquetes de parámetro con %<...%>"
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "          %s"
 msgid "        %s"
 msgstr "          %s"
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "la declaración de %q+D oscurece un parámetro"
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "la declaración de %q+D oscurece un parámetro"
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "el tipo de parámetro de plantilla %qT se declaró %<friend%>"
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of alias template %qD"
 msgid "specialization of variable concept %q#D"
 msgstr "especialización parcial de la plantilla alias %qD"
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "no se usan los parámetros de plantilla en la especialización parcial:"
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "la especialización parcial %qT no especializa ningún argumento de plantilla"
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "la especialización parcial %qT no especializa ningún argumento de plantilla"
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "primary template here"
 msgstr "se declaró previamente aquí"
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "demasiados argumentos para la función %qE"
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "la especialización parcial %qT no especializa ningún argumento de plantilla"
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "primary template %qD"
 msgstr "se declaró previamente aquí"
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "el argumento de paquete de parámetro %qE debe estar al final de la lista de argumentos de plantilla"
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "el argumento de paquete de parámetro %qT debe estar al final de la lista de argumentos de plantilla"
 
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "el tipo %qT del argumento de plantilla %qE depende de un parámetro de plantilla"
 msgstr[1] "el tipo %qT del argumento de plantilla %qE depende de parámetros de plantilla"
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of %qT after instantiation of %qT"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "especialización parcial de %qT después de la instanciación %qT"
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "no hay un argumento por defecto para %qD"
@@ -67257,51 +67299,51 @@ msgstr "no hay un argumento por defecto para %qD"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, fuzzy, gcc-internal-format
 #| msgid "parameter pack %qE must be at the end of the template parameter list"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "el parámetro de paquete %qE debe estar al final de la lista de parámetros de plantilla"
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "no se pueden usar los argumentos de plantilla por defecto en la re-declaración friend de la plantilla de función"
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, fuzzy, gcc-internal-format
 #| msgid "default template arguments may not be used in function template friend declarations"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "no se pueden usar los argumentos de plantilla por defecto en las declaraciones friend de la plantilla de función"
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, fuzzy, gcc-internal-format
 #| msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "los argumentos de plantilla por defecto no se pueden usar en las plantillas de función sin -std=c++11 o -std=gnu++11"
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "no se pueden usar los argumentos de plantilla por defecto en las especializaciones parciales"
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "argumento por defecto para el parámetro de plantilla para la clase incluyente %qD"
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, fuzzy, gcc-internal-format
 #| msgid "namespace %qT undeclared"
 msgid "template %qD declared"
 msgstr "espacio de nombres %qT sin declarar"
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "clase de plantilla sin nombre"
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -67312,71 +67354,71 @@ msgstr "la función que no es miembro %qD no puede tener calificador-cv"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "declaración de la plantilla de %qD no válida"
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "definición de plantilla de %q#D que no es plantilla"
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "se esperaban %d niveles de parámetros de plantilla para %q#D, se obtuvieron %d"
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "se obtuvieron %d parámetros de plantilla para %q#D"
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "se obtuvieron %d parámetros de plantilla para %q#T"
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  pero se requieren %d"
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "los argumentos de plantilla para %qD no coinciden con la plantilla original %qD"
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, fuzzy, gcc-internal-format
 #| msgid "use template<> for an explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "utilice template<> para una especialización explícita"
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "redeclaration of %qD with different constraints"
 msgstr "la redeclaración de %qD difiere en %<constexpr%>"
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT no es un tipo plantilla"
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "no se especificaron los especificadores de plantilla en la declaración de %qD"
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "se redeclaró con %d parámetro de plantilla"
 msgstr[1] "se redeclaró con %d parámetros de plantilla"
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D used %d template parameter"
 #| msgid_plural "previous declaration %q+D used %d template parameters"
@@ -67385,474 +67427,474 @@ msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "la declaración previa de %q+#D usó %d parámetro de plantilla"
 msgstr[1] "la declaración previa de %q+#D usó %d parámetros de plantilla"
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "parámetro de plantilla %q+#D"
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "redeclarado aquí como %q#D"
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "redeclared here"
 msgstr "se declara aquí"
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "la redeclaración de %qD difiere en %<constexpr%>"
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, fuzzy, gcc-internal-format
 #| msgid "original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "la definición original apareció aquí"
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "redeclaration of %q#D with different constraints"
 msgstr "la redeclaración de %qD difiere en %<constexpr%>"
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT"
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "debe ser la dirección de una función con enlace externo"
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "debe ser la dirección de una función con enlace externo"
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque %qD no tiene enlace"
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque %qD no tiene enlace externo"
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "debe ser un puntero-a-miembro de la forma %<&X::Y%>"
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD no es un miembro de %qT"
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, fuzzy, gcc-internal-format
 #| msgid "  couldn't deduce template parameter %qD"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  no se puede deducir el parámetro de plantilla %qD"
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  los tipos %qT y %qT tiene calificadores-cv incompatibles"
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  no coinciden los tipos %qT y %qT"
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  el parámetro de plantilla %qD no es un paquete de parámetro, pero el argumento %qD sí"
 
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  el argumento de plantilla %qE no coincide con la constante puntero-a-miembro %qE"
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE no es equivalente a %qE"
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  deducción de paquete de parámetros inconsistente con %qT y %qT"
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  se deducen tipos en conflicto para el parámetro %qT (%qT y %qT)"
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  se deducen valores en conflicto para el parámetro %qE que no es tipo (%qE y %qE)"
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  el tipo matriz de tamaño variable %qT no es un argumento de plantilla válido"
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  el tipo de función miembro %qT no es un argumento de plantilla válido"
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  no se puede convertir %qE (tipo %qT) al tipo %qT"
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT es una clase base ambigua de %qT"
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT no es derivado de %qT"
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  los parámetros de plantilla de un argumento de plantilla plantilla son inconsistentes con otros argumentos de plantilla deducidos"
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, fuzzy, gcc-internal-format
 #| msgid "  can't deduce a template for %qT from non-template type %qT"
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  no se puede deducir una plantilla para %qT del tipo %qT que no es plantilla"
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument %qE does not match %qD"
 msgid "  template argument %qE does not match %qE"
 msgstr "  el argumento de plantilla %qE no coincide con %qD"
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qE no es una variable"
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace externo"
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace"
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, fuzzy, gcc-internal-format
 #| msgid "  variable-sized array type %qT is not a valid template argument"
 msgid "the address of %qD is not a valid template argument"
 msgstr "  el tipo matriz de tamaño variable %qT no es un argumento de plantilla válido"
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, fuzzy, gcc-internal-format
 #| msgid "  variable-sized array type %qT is not a valid template argument"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "  el tipo matriz de tamaño variable %qT no es un argumento de plantilla válido"
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace externo"
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD no es un argumento válido de plantilla porque %qD es una variable, no la dirección de una variable"
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD no es un argumento válido de plantilla porque %qD es una variable, no la dirección de una variable"
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque las literales de cadena nunca se pueden usar en este contexto"
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "in template argument for type %qT"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT debido a conflictos en la calificación cv"
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque no es un l-valor"
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D no es un argumento válido de plantilla para el tipo %qT porque una referencia variable no tiene una dirección constante"
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT porque es un puntero"
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "intente utilizar %qE en su lugar"
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT porque es de tipo %qT"
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring attributes in template argument %qE"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "se usó el nombre-de-clase-inyectada %qD como un argumento de plantilla plantilla"
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "uso no válido del destructor %qE como un tipo"
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "para hacer referencia a un tipo miembro de un parámetro de plantilla, use %<typename %E%>"
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "no coincide el tipo/valor en el argumento %d en la lista de parámetros de plantilla para %qD"
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  se esperaba una constante de tipo %qT, se obtuvo %qT"
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "argumento por defecto para el parámetro de plantilla para la clase incluyente %qD"
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  se esperaba una plantilla de clase, se obtuvo %qE"
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  se esperaba un tipo, se obtuvo %qE"
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  se esperaba un tipo, se obtuvo %qT"
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  se esperaba una plantilla de clase, se obtuvo %qT"
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  se esperaba una plantilla de tipo %qD, se obtuvo %qT"
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "no coincide el tipo/valor en el argumento %d en la lista de parámetros de plantilla para %qD"
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  se esperaba un tipo, se obtuvo %qE"
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "no se puede convertir el argumento de plantilla %qE a %qT"
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "el argumento de plantilla %d es no válido"
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "provisto por %q+D"
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "argumento por defecto para el parámetro de plantilla para la clase incluyente %qD"
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argumento por defecto dado para el parámetro %d de %q#D"
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D no es una plantilla de función"
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "se usa el tipo %qT que no es plantilla como una plantilla"
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "para la declaración de plantilla %q+D"
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure for %qD"
 msgstr "falla interna de consistencia"
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "uso de %qs en la plantilla"
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum) substituting %qS"
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "la profundidad de instanciación de la plantilla excede el máximo de %d (use -ftemplate-depth= para incrementar el máximo) al sustituir %qS"
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "score argument must be constant integer expression"
 msgstr "el argumento de collapse necesita una expresión entera constante positiva"
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must be nonnegative"
 msgid "score argument must be non-negative"
 msgstr "'%s' en %L debe ser no negativo"
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "property must be constant integer expression or string literal"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "miembro de matriz flexible en union"
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a potential constant expression"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE no es una expresión constante potencial"
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "no coinciden las longitudes de los paquetes de argumentos al expandir %<%T%>"
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "no coinciden las longitudes de los paquetes de argumentos al expandir %<%E%>"
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "redefinición del argumento por defecto para %q#D"
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "se crea un puntero a función miembro del tipo %qT que no es clase"
 
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths (%d vs %d)"
@@ -67871,316 +67913,316 @@ msgstr "no coinciden las longitudes de los paquetes de argumentos al expandir %<
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "la variable %qD tiene tipo de función"
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "tipo de parámetro %qT no válido"
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "en la declaración %q+D"
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "la función devuelve una matriz"
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "la función devuelve una función"
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "se forma la referencia a void"
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "se forma un puntero para referenciar al tipo %qT"
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "se forma una referencia para referenciar al tipo %qT"
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "no se puede declarar la referencia para el tipo de función calificado %qT"
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "se crea un puntero al miembro del tipo %qT que no es clase"
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "se crea un puntero al miembro de referencia de tipo %qT"
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "se crea un puntero al miembro de tipo void"
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "se crea la matriz de %qT"
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT no es de tipo clase, struct o union"
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT resuelve a %qT, el cual no es un tipo enumerado"
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT resuelve a %qT, el cual no es un tipo de clase"
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "uso de %qs en la plantilla"
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "el tipo calificador %qT no coincide con el nombre del destructor ~%qT"
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "el nombre dependiente %qE se decodifica como un no tipo, pero la instanciación genera un tipo"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "escriba %<typename %E%> si quiere un tipo"
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "el elemento inicializador no es una expresión constante"
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "uso no válido de la expresión de expansión de paquete"
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "use %<...%> para expandir el paquete de argumentos"
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer in lambda init-capture"
 msgstr "inicializador no-vacío para una matriz de elementos vacíos"
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD no se declaró en este ámbito, y no se encontraron declaraciones en la búsqueda dependiente de argumentos en el punto de la instanciación"
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "no se encontraron declaraciones en la base dependiente %qT pur la búsqueda no calificada"
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "use %<this->%D%> en su lugar"
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "use %<%T::%D%> en su lugar"
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here, later in the translation unit"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D se declaró aquí, después en la unidad de translación"
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_choose_expr%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "número erróneo de argumentos para %<__builtin_choose_expr%>"
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qE attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "se especificó el número equivocado de argumentos para el atributo %qE"
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT no es una clase o un espacio de nombres"
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD no es una clase o un espacio de nombres"
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "se usa el campo no válido %qD"
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT es/usa un tipo anónimo"
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "el argumento de plantilla para %qD usa el tipo local %qT"
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT es un tipo modificado variablemente"
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "la expresión integral %qE no es una constante"
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  se trata de instanciar %qD"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instanciación explícita de %q#D que no es plantilla"
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of alias template %qD"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "especialización parcial de la plantilla alias %qD"
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "instanciación explícita de %qT que no es plantilla"
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD no es un dato miembro static de una plantilla de clase"
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "no se encontró una plantilla coincidente para %qD"
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "el tipo %qT para la instanciación explícita %qD no coincide con el tipo declarado %qT"
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "instanciación explícita de %q#D"
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "instanciación explícita duplicada de %q#D"
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 prohíbe el uso de %<extern%> en instanciaciones explícitas"
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "clase de almacenamiento %qD aplicada a la instanciación de una plantilla"
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instanciación explícita de la plantilla %qD que no es clase"
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "instanciación explícita del tipo %qT que no es plantilla"
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "instanciación explícita de %q#T antes de la definición de la plantilla"
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ prohíbe el uso de %qE en las instanciaciones explícitas"
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "instanciación explícita duplicada de %q#T"
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -68193,185 +68235,185 @@ msgstr "especialización explícita de %qD después del primer uso"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "instanciación explícita de %qD pero no hay una definición disponible"
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "la profundidad de instanciación de la plantilla excede el máximo de %d al instanciar %q+D, posiblemente de la generación de tabla virtual (use -ftemplate-depth= para incrementar el máximo)"
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template non-type parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T no es un tipo válido para un parámetro que no es tipo plantilla"
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "parámetro que no es tipo plantilla no válido"
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T no es un tipo válido para un parámetro que no es tipo plantilla"
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "no se permite la palabra clave %<typename%> fuera de las plantillas"
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be constrained"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT no es un espacio de nombres"
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#T inside template parameter list"
 msgid "concept %qE has multiple template parameter lists"
 msgstr "la definición de %q#T dentro de la lista de parámetros de plantilla"
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "la deducción de una lista inicializadora encerrada entre llaves requiere #include <initializer_list>"
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "se usó %qD que no es plantilla como plantilla"
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, fuzzy, gcc-internal-format
 #| msgid "try using %qE instead"
 msgid "use %qD directly instead"
 msgstr "intente utilizar %qE en su lugar"
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument deduction/substitution failed:"
 msgid "class template argument deduction failed:"
 msgstr "  falló la deducción/sustitución del argumento de plantilla:"
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "la función no se consideró para la inclusión en línea"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument deduction/substitution failed:"
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "  falló la deducción/sustitución del argumento de plantilla:"
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, fuzzy, gcc-internal-format
 #| msgid "in a call to function %qD declared here"
 msgid "explicit deduction guide declared here"
 msgstr "en una llamada a la función %qD declarada aquí"
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument deduction/substitution failed:"
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "  falló la deducción/sustitución del argumento de plantilla:"
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, fuzzy, gcc-internal-format
 #| msgid "unable to deduce %qT from %qE"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "no se puede deducir %qT de %qE"
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "no se puede deducir %qT de %qE"
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' as a non-type template-argument"
 msgid "invalid use of %qT in template argument"
@@ -68604,700 +68646,700 @@ msgstr "no se puede determinar el tipo del operando asm %qE"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "las declaraciones __label__ sólo se permiten en ámbitos de función"
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "uso no válido del miembro %q+D en la función miembro static"
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr "uso no válido del miembro %q+D en la función miembro static"
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr "uso no válido del miembro %q+D en la función miembro static"
 
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "%qE missing template arguments"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "cannot call a concept as a function"
 msgstr "no se puede usar %qE como una función"
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "no se permiten argumentos para el destructor"
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr "%<this%> no está disponible para funciones miembro static"
 
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, fuzzy, gcc-internal-format
 #| msgid "used %d template parameter(s) instead of %d"
 msgid "use explicit object parameter %qs instead"
 msgstr "se usaron %d parámetro(s) de plantilla en lugar de %d"
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template non-type parameter"
 msgid "name the explicit object parameter"
 msgstr "parámetro que no es tipo plantilla no válido"
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> no está disponible para funciones miembro static"
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<this%> before it is valid"
 msgstr "uso no válido de %<this%> en el nivel principal"
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<this%> after it is valid"
 msgstr "uso no válido de %<this%> en el nivel principal"
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "uso no válido de %<this%> en la función que no es miembro"
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "uso no válido de %<this%> en el nivel principal"
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ámbito calificador no válido en el nombre del seudo-destructor"
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "el tipo calificado %qT no coincide con el nombre del destructor ~%qT"
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE no es de tipo %qT"
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "la literal compuesta del tipo %qT que no es objeto"
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "%<auto{x}%> cannot be constrained"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "los parámetros de tipo plantilla debe usar la palabra clave %<class%> o %<typename%>"
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "uso no válido del tipo %qT como un valor por defecto para una plantilla de parámetro de plantilla"
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "argumento por defecto no válido para una plantilla de parámetro de plantilla"
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "la definición de %q#T dentro de la lista de parámetros de plantilla"
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "definición no válida del tipo calificado %qT"
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "especificación de clase base no válida"
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "miembro protegido %q+#D en union anónima"
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD no se capturó"
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "uso de la variable %<auto%> desde la función contenedora"
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "uso de parámetro desde la función contenedora"
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, fuzzy, gcc-internal-format
 #| msgid "use of parameter %qD outside function body"
 msgid "use of parameter outside function body"
 msgstr "se usó el parámetro %qD fuera del cuerpo de la función"
 
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "missing template arguments"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "no se permite el parámetro de plantilla %qD de tipo %qT en una expresión integral constante porque no es de tipo integral o de enumeración"
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "uso de la plantilla de clase %qT como expresión"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "la petición por el miembro %qD es ambigua en la red de herencia múltiple"
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD no puede aparecer en una expresion constante"
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "el tipo de %qE es desconocido"
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT no es un tipo de enumeración"
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not an integer constant"
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr "la alineación solicitada no es una constante entera"
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr ""
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, fuzzy, gcc-internal-format
 #| msgid "Reference statement index out of range"
 msgid "%<__type_pack_element%> index is out of range"
 msgstr "Índice de sentencia de referencia fuera de rango"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter pack __bases only valid in template declaration"
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "Los paquetes de parámetros __bases sólo son válidos en la declaración de plantilla"
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "no se puede aplicar %<offsetof%> al destructor %<~%T%>"
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "no se puede aplicar %<offsetof%> a la función miembro %qD"
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "no se puede aplicar %<offsetof%> a la función miembro %qD"
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "no se puede aplicar %<offsetof%> a la función miembro %qD"
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr "no se puede recibir objetos de tipo no-copiable-trivialmente q%#T a través de %<...%>"
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, fuzzy, gcc-internal-format
 #| msgid "constructor priorities are not supported"
 msgid "pointer-to-member mapping %qE not supported"
 msgstr "no se admiten las prioridades de constructor"
 
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "la referencia a %qD es ambigua"
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE tiene tipo no válido para %<reduction%>"
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, gcc-internal-format
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr ""
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD no es una variable en la cláusula %<firstprivate%>"
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD no es una variable en la cláusula %<lastprivate%>"
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> static expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> num expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<vector%> length expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<worker%> num expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, fuzzy, gcc-internal-format
 #| msgid "slice end must be integer"
 msgid "%<device%> id must be integral"
 msgstr "el final de la rebanada debe ser entero"
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<aligned%> clause"
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%qE no es una variable en la cláusula %<saligned%>"
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "demasiadas cláusulas %qs"
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<hint%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<filter%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "el tipo de vector delete no es del tipo puntero ni matriz"
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "el tipo de vector delete no es del tipo puntero ni matriz"
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<tile%> argument needs integral type"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD no es un fichero, espacio de nombres o variable de ámbito de bloque"
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "la directiva %<threadprivate%> %qE no está en la definición %qT"
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "la diferencia entre %qE y %qD no tiene tipo entero"
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp atomic update%> usa dos variables diferentes para la memoria"
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> usa dos variables diferentes para la memoria"
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr ""
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr ""
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr ""
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr ""
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %s"
 msgid "static assertion failed: %.*s"
 msgstr "falló la aserción estática: %s"
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "condición que no es constante para una aserción estática"
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "el argumento para decltype debe ser una expresión"
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, fuzzy, gcc-internal-format
 #| msgid "decltype cannot resolve address of overloaded function"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "el tipo de declaración no puede resolver la dirección de la función sobrecargada"
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr ""
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr ""
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr "se llamó a %<__builtin_next_arg%> sin un argumento"
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a template"
 msgid "%qD is not a class or alias template"
 msgstr "%qE no es una plantilla"
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, fuzzy, gcc-internal-format
 #| msgid "third operand of conditional expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "el tercer operando de la expresión condicional no tiene efecto"
 
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "el argumento de plantilla %qE involucra a el(los) parámetro(s) de plantilla"
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -69306,1270 +69348,1270 @@ msgstr "argumento no admitido para %<__builtin_return_address%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "los calificadores %qV no se pueden aplicar a %qT"
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "statement-expression in a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid " declared here"
 msgstr "se declara aquí"
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr "la alineación de %qD es más grande que la declaración original"
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, fuzzy, gcc-internal-format
 #| msgid "base class %qT has cv qualifiers"
 msgid "base class %qT is not public"
 msgstr "la clase base %qT tiene calificadores cv"
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not captured"
 msgid "%qD is not public"
 msgstr "%qD no se capturó"
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is mutable"
 msgstr "%qD no es una variable"
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD has a non-structural type"
 msgstr "%qD no es un tipo"
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr "el atributo %qE sólo se puede aplicar a definiciones de clase"
 
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "el argumento del atributo %qE no es una constante de cadena"
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "el atributo %qE sólo se puede aplicar a definiciones de clase"
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "el atributo %qE sólo se puede aplicar a definiciones de clase"
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute cannot be applied to variables with specific sections"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "el atributo %qE no se puede aplicar a variables con secciones específicas"
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "%qE attribute takes no arguments"
 msgstr "el atributo %qD requiere un solo argumento NTBS"
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute does not apply to functions"
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "el atributo %qE no se aplica a funciones"
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "la init_priority solicitada no es una constante entera"
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "solo se puede usar el atributo %qE en definiciones de rango de fichero de objetos de tipo class"
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is out of range"
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "la init_priority solicitada está fuera de rango"
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is reserved for internal use"
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "la init_priority solicitada está reservada para uso interno"
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "declaración de %qD como miembro de %qT"
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "the %qE attribute requires arguments"
 msgstr "el atributo %qD requiere un solo argumento NTBS"
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "el argumento del atributo %qE no es una cadena constante"
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "el argumento del atributo %qE no es una cadena constante"
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, fuzzy, gcc-internal-format
 #| msgid "%.*s is not a valid universal character"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%.*s no es un carácter universal válido"
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> no es un declarador válido"
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "se descarta el atributo %qE en tipos que no son clases"
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "se descartan los atributos aplicados al %qT después de la definición"
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "se descartan los atributos aplicados al %qT después de la definición"
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "se descartan los atributos aplicados al %qT después de la definición"
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "el atributo %qE se aplica solamente a funciones, no a %s"
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute applied to %s %s at %L"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "El atributo %s se aplica a %s %s en %L"
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not a string constant"
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr "el argumento del atributo %qE no es una constante de cadena"
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "cero como constante de puntero nulo"
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, fuzzy, gcc-internal-format
 #| msgid "lang_* check: failed in %s, at %s:%d"
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "revisión lang_*: falló en %s, en %s:%d"
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "la comparación entre diferentes tipos de punteros %qT y %qT carece de una conversión"
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "la conversión entre diferentes tipos de punteros %qT y %qT carece de una conversión"
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "la expresión condicional entre diferentes tipos de punteros %qT y %qT carece de una conversión"
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ prohíbe la comparación entre punteros de tipo %<void *%> y punteros a función"
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ prohíbe la conversión entre punteros de tipo %<void *%> y punteros a función"
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ prohíbe la expresión condicional entre punteros de tipo %<void *%> y punteros a función"
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "la comparación entre diferentes tipos de punteros-a-miembro %qT y %qT carece de una conversión"
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "la conversión entre diferentes tipos de punteros-a-miembro %qT y %qT carece de una conversión"
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "la expresión condicional entre diferentes tipos de punteros-a-miembro %qT y %qT carece de una conversión"
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, fuzzy, gcc-internal-format
 #| msgid "canonical types differ for identical types %T and %T"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "los tipos canónicos difieren para los tipos idénticos %T y %T"
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, fuzzy, gcc-internal-format
 #| msgid "same canonical type node for different types %T and %T"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "el mismo nodo de tipo canónico para los tipos diferentes %T y %T"
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "aplicación no válida de %qs a una función miembro"
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "aplicación no válida de %<sizeof%> a un campo de bits"
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ prohíbe la aplicación de %<sizeof%> a una expresión de tipo de función"
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "aplicación no válida de %<__alignof%> a un campo de bits"
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ prohíbe la aplicación de %<__alignof%> a una expresión de tipo de función"
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "el tamaño de la matriz tiene un tipo %qT que no es integral"
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "uso no válido de la función miembro no static %qD"
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to %qT"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "conversión obsoleta de una constante de cadena a %qT"
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "conversión obsoleta de una constante de cadena a %qT"
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "solicitud por el miembro %qD en %qE, el cual es de tipo puntero %qT (¿ Tal vez quiso utilizar %<->%> ?)"
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "solicitud por el miembro %qD en %qE, el cual es del tipo %qT que no es clase"
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of nonstatic data member %qE"
 msgid "invalid use of non-static data member %qE"
 msgstr "uso no válido del dato miembro no static %qE"
 
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD  of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "acceso no válido a datos del miembro que no es static %qD  del objeto NULL"
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "el tipo de objeto %qT no coincide con el nombre del destructor ~%qT"
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "el tipo que se destruye es %qT, pero el destructor se refiere a %qT"
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT no tiene un miembro llamado %qE"
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%qT no tiene un miembro llamado %qE"
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%qT no tiene un miembro llamado %qE"
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT no tiene un miembro llamado %qE"
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> no es un miembro de %qT"
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT no es una base de %qT"
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD no es una función plantilla miembro"
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT no es de tipo puntero-a-objeto"
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "uso no válido del índice de matriz en puntero a miembro"
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "uso no válido del unario %<*%> en puntero a miembro"
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "uso no válido de la conversión implícita en puntero a miembro"
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "falta el subíndice en la referencia de la matriz"
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "se declaró el subíndice de la matriz como %<register%>"
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "el valor indicado por el subíndice no es ni matriz ni puntero"
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "falta un objeto en el uso de %qE"
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ prohíbe la llamada %<::main%> dentro del mismo programa"
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "se debe usar %<.*%> o %<->*%> en la llamada a la función puntero-a-miembro en %<%E (...)%>, p.e. %<(... ->* %E) (...)%>"
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "no se puede usar %qE como una función"
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "no se puede usar %qE como una función"
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "no se puede usar %qE como una función"
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "demasiados argumentos para el constructor %q#D"
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "faltan argumentos para el constructor %q#D"
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "demasiados argumentos para la función miembro %q#D"
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "faltan argumentos para la función miembro %q#D"
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "demasiados argumentos para la función %q#D"
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "faltan argumentos para la función %q#D"
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "demasiados argumentos para el método %q#D"
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "faltan argumentos para el método %q#D"
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "demasiados argumentos para la función"
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "faltan argumentos para la función"
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "el parámetro %P de %qD tiene el tipo incompleto %qT"
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "el parámetro %P tiene el tipo incompleto %qT"
 
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will never be NULL"
 msgid "the address %qE will never be NULL"
 msgstr "la dirección de %qD nunca debe ser NULL"
 
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "la dirección de %qD nunca debe ser NULL"
 
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, fuzzy, gcc-internal-format
 #| msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr "la comparación siempre se evalúa como %<true%> para la dirección de %qD que nunca será NULL"
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr ""
 
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, fuzzy, gcc-internal-format
 #| msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "la comparación siempre se evalúa como %<true%> para la dirección de %qD que nunca será NULL"
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr "los operandos de ?: tienen tipos diferentes %qT y %qT"
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, fuzzy, gcc-internal-format
 #| msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "la conversión entre diferentes tipos de punteros %qT y %qT carece de una conversión"
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, fuzzy, gcc-internal-format
 #| msgid "same canonical type node for different types %T and %T"
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr "el mismo nodo de tipo canónico para los tipos diferentes %T y %T"
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "la comparación entre diferentes tipos de punteros %qT y %qT carece de una conversión"
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, fuzzy, gcc-internal-format
 #| msgid "complex arguments must have floating-point type"
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr "los argumentos complejos deben tener tipo de coma flotante"
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, fuzzy, gcc-internal-format
 #| msgid "cast from function call of type %qT to non-matching type %qT"
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr "conversión desde una llamada a función de tipo %qT al tipo %qT que no coincide"
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "conversión del tipo puntero %qT al tipo aritmético %qT en una expresión constante"
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types when assigning to type %qT from type %qT"
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr "tipos incompatible en la asignación al tipo %qT del tipo %qT"
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "se asume la conversión al tipo %qT desde la función sobrecargada"
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "se usó NULL en la aritmética"
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ prohíbe la comparación entre puntero y entero"
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid "operand types are %qT and %qT"
 msgstr "no hay un tipo llamado %q#T en %q#T"
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "comparación ordenada de puntero con el entero cero"
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "comparación sin orden en el argumento de coma no flotante"
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 #, fuzzy
 #| msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "conversión implícita de %qT a %qT para coincidir con otro operando de la expresión binaria"
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "operadores no válidos de tipos %qT y %qT para el binario %qO"
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ prohíbe el uso de un puntero de tipo %<void *%> en la sustracción"
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ prohíbe el uso de un puntero a una función en la sustracción"
 
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ prohíbe el uso de un puntero a un método en la sustracción"
 
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "uso no válido de un puntero a un tipo incompleto en aritmética de punteros"
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of constructor %qE"
 msgid "taking address of constructor %qD"
 msgstr "se toma la dirección del constructor %qE"
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of destructor %qD"
 msgstr "se toma la dirección del destructor %qE"
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "uso no válido de %qE para formar una función puntero a miembro"
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  se requiere un id calificado"
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "no se pueden usar paréntesis alrededor de %qE para formar una función-puntero-a-miembro"
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ prohíbe tomar la dirección de una función miembro no estática sin calificar o entre paréntesis para formar un puntero a la función miembro.  Como %<&%T::%D%>"
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr "ISO C++ prohíbe tomar la dirección de una función miembro no estática sin calificar o entre paréntesis para formar un puntero a la función miembro.  Como %<&%T::%D%>"
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ prohíbe tomar la dirección de una función miembro limitada para formar un puntero a la función miembro.  Como %<&%T::%D%>"
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr "ISO C++ prohíbe tomar la dirección de una función miembro limitada para formar un puntero a la función miembro.  Como %<&%T::%D%>"
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr "(un puntero a miembro solamente se puede formar con %<&%E%>)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "se toma la dirección del temporal"
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ prohíbe tomar la dirección de la función %<::main%>"
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "no se puede crear un puntero al miembro referencia %qD"
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "no se puede tomar la dirección del campo de bits %qD"
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of expression of type %<void%>"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "se toma la dirección de la expresión de tipo %<id%>"
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ prohíbe incrementar un enum"
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ prohíbe decrementar un enum"
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "no se puede incrementar un puntero a un tipo incompleto %qT"
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "no se puede decrementar un puntero a un tipo incompleto %qT"
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ prohíbe incrementar un puntero de tipo %qT"
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ prohíbe decrementar un puntero de tipo %qT"
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, fuzzy, gcc-internal-format
 #| msgid "use of cast expressions as lvalues is deprecated"
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr "el uso de expresiones de conversión como l-valores es obsoleto"
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "no se puede tomar la dirección de %<this%> que es una expresión r-valuada"
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "se solicitó la dirección de la variable register explícita %qD"
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "se solicitó la dirección de %qD, la cual se declaró como %<register%>"
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "el inicializador de lista para el tipo que no es clase no debe estar entre paréntesis"
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "se trata la lista de expresiones como una expresión compuesta en en inicializador"
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "se trata la lista de expresiones como una expresión compuesta en el inicializador de memoria"
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "se trata la lista de expresiones como una expresión compuesta en la conversión funcional"
 
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "se trata la lista de expresiones como una expresión compuesta %s"
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "no hay contexto para resolver el tipo de %qE"
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "la conversión del tipo %qT al tipo %qT proscribe los calificadores"
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, fuzzy, gcc-internal-format
 #| msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast del tipo %qT al tipo %qT proscribe los calificadores"
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast del tipo %qT al tipo %qT proscribe los calificadores"
 
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, fuzzy, gcc-internal-format
 #| msgid "%qT uses local type %qT"
 msgid "useless cast to type %q#T"
 msgstr "%qT usa el tipo local %qT"
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "static_cast no válido del tipo %qT al tipo %qT"
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "el tipo de devolución %q#T es un tipo de dato incompleto"
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "se convierte de %qT a %qT"
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "conversión no válida de una expresión r-valuada de tipo %qT al tipo %qT"
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "la conversión de %qT a %qT pierde precisión"
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 #, fuzzy
 #| msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "la comparación entre diferentes tipos de punteros-a-miembro %qT y %qT carece de una conversión"
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "la conversión de %qT a %qT incrementa la alineación requerida del tipo del destino"
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ prohíbe la conversión entre puntero a función y puntero a objeto"
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "conversión no válida del tipo %qT al tipo %qT"
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "uso no válido de const_cast con tipo %qT, que no es puntero, referencia, ni un tipo puntero-a-datos-miembro"
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "uso no válido de const_cast con tipo %qT, el cual es un puntero o referencia a un tipo de función"
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "const_cast no válido de un valor-r de tipo %qT al tipo %qT"
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "const_cast no válido del tipo %qT al tipo %qT"
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ prohíbe la conversión a un tipo de matriz %qT"
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "conversión no válida al tipo de función %qT"
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qE from type %qT to type %qT"
 msgid "moving %qE of type %qT to itself"
 msgstr "no se puede convertir %qE desde el tipo %qT al tipo %qT"
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  en la evaluación de %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "se asigna a una matriz desde una lista de inicializador"
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "tipos incompatible en la asignación de %qT a %qT"
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "se usó una matriz como inicializador"
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "asignación de matriz no válida"
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   en la conversión del puntero a función miembro"
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "puntero a la conversión miembro a través de la base virtual %qT"
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   en la conversión del puntero a miembro"
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "conversión no válida del tipo %qT a partir del tipo %qT"
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in default argument"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "no se puede convertir %qT a %qT en el argumento por defecto"
 
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in argument passing"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "no se puede convertir %qT a %qT en el paso de argumentos"
 
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in initialization"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "no se puede convertir %qT a %qT en la inicialización"
 
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in return"
 msgid "cannot convert %qH to %qI in return"
 msgstr "no se puede convertir %qT a %qT en la devolución"
 
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in assignment"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "no se puede convertir %qT a %qT en la asignación"
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "el parámetro %qP de %qD puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "el parámetro puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "el objetivo de conversión puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "el objetivo de inicialización puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "el lado izquierdo de la asignación puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "al pasar el argumento %P de %q+D"
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "se devuelve la referencia al temporal"
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "returning pointer to temporary"
 msgstr "se devuelve la referencia al temporal"
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "se devolvió una referencia a la variable local %q+D"
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "se devolvió la dirección de la variable local %q+D"
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "se devolvió la dirección de la variable local %q+D"
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, fuzzy, gcc-internal-format
 #| msgid "not enough values in return statement"
 msgid "redundant move in return statement"
 msgstr "faltan valores en la declaración de devolución"
 
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, fuzzy, gcc-internal-format
 #| msgid "not enough values in return statement"
 msgid "redundant move in initialization"
 msgstr "faltan valores en la declaración de devolución"
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "se devuelve un valor de un destructor"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "no se puede regresar de un manejador de una función-intenta-bloque de un constructor"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "se devuelve un valor de un constructor"
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "declaración return sin valores, en una función que devuelve %qT"
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, fuzzy, gcc-internal-format
 #| msgid "<brace-enclosed initializer list>"
 msgid "returning initializer list"
 msgstr "<lista inicializador dentro de llaves>"
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "se deducen los tipos inconsistentes %qT y %qT para el tipo de devolución lambda"
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, fuzzy, gcc-internal-format
 #| msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "deducción inconsistente para %qT: %qT y después %qT"
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "declaración return sin valores, en una función que devuelve %qT"
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> no debe regresar NULL a menos que se declare %<throw()%> (o -fcheck-new esté en efecto)"
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q+#D"
 msgid "not eliding copy on return from %qD"
 msgstr "tipo de devolución covariante no válido para %q+#D"
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr ""
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, fuzzy, gcc-internal-format
 #| msgid "using temporary as lvalue"
 msgid "using rvalue as lvalue"
@@ -70807,170 +70849,170 @@ msgstr "función sobrecargada sin información contextual de tipo"
 msgid "insufficient contextual information to determine type"
 msgstr "información contextual insuficiente para determinar el tipo"
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "se usó la sintaxis de constructor, pero no se declaró un constructor para el tipo %qT"
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr static data member %qD must have an initializer"
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "el miembro dato static constexpr %qD debe tener un inicializador"
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 #, fuzzy
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "la conversión estrechadora de %qE desde %qT a %qT dentro de { } está mal formada en C++11"
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 #, fuzzy
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "conversión estrechadora de %qE desde %qT a %qT dentro de { }"
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, fuzzy, gcc-internal-format
 #| msgid "expression in static assertion is not an integer constant expression"
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "la expresión en la aserción static no es una expresión constante entera"
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, fuzzy, gcc-internal-format
 #| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "la cadena del inicializador para la matriz de caracteres es demasiado larga"
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "llaves alrededor del inicializador escalar"
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "no se puede inicializar el agregado del tipo %qT con una literal compuesta"
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "el miembro %qD es una referencia sin inicializar"
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "el miembro %qD es una referencia sin inicializar"
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "el tipo de %qD no coincide con la declaración original"
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "no existe el campo %qD en la union que se está inicializando"
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "valor de índice en lugar del nombre del campo en el inicializador de union"
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "se detectó una delegación de puntero circular"
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "el operando base de %<->%> tiene el tipo %qT que no es puntero"
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "el resultado de %<operator->()%> produce un resultado que no es puntero"
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "el operando base de %<->%> no es un puntero"
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "no se puede usar %qE como un puntero miembro, porque es de tipo %qT"
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "no se puede aplicar el puntero a miembro %qE a %qE, el cual es del tipo %qT que no es clase"
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "el tipo de puntero a miembro %qT es incompatible con el tipo objeto %qT"
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "conversión funcional al tipo de matriz %qT"
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "inicialización por valor no válida del tipo de referencia"
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "llamada a la función %qD la cual arroja el tipo incompleto %q#T"
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "llamada a una función la cual arroja el tipo incompleto %q#T"
@@ -72056,7 +72098,7 @@ msgstr "La lista de nombres %s no se puede renombrar por asociación de USE a %s
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "'I' en %L y 'J' en %L no pueden ser constantes literal BOZ al mismo tiempo"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid suffix on integer constant"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -73570,7 +73612,7 @@ msgstr "Especificación INTENT errónea en %C"
 msgid "deferred type parameter at %C"
 msgstr "Fortran 2003: parámetro de tipo diferido en %C"
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -73820,7 +73862,7 @@ msgstr "El componente '%s' con CLASS en %L debe ser allocatable o pointer"
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "El componente de matriz de la estructura en %C debe tener una forma explícita o diferida"
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already declared at %L"
@@ -74716,7 +74758,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr "Se esperaba una lista de argumentos formales en la definición de la función en %C"
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "El atributo BIND(C) en %L sólo se puede usar para variables o bloques comunes"
@@ -75594,12 +75636,12 @@ msgstr ""
 msgid "are_identical_variables: Bad type"
 msgstr ""
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr "El argumento actual INTENT(%s) en %L puede interferir con el argumento actual en %L."
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr ""
@@ -75873,301 +75915,301 @@ msgstr "El parámetro '%s' en %L no se ha declarado o es una variable, lo cual n
 msgid "check_init_expr(): Unknown expression type"
 msgstr "Se esperaba un tipo de expresión"
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be a statement function"
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr "La función de especificación '%s' en %L no puede ser una función de declaración"
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be an internal function"
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr "La función de especificación '%s' en %L no puede ser una función interna"
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L must be PURE"
 msgid "Specification function %qs at %L must be PURE"
 msgstr "La función de especificación '%s' en %L debe ser PURE"
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be RECURSIVE"
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr "La función de especificación '%s' en %L no puede ser RECURSIVE"
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' not allowed in expression at %L"
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr "No se permite el argumento dummy '%s' en la expresión en %L"
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be OPTIONAL"
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr "El argumento dummy '%s' en %L no puede ser OPTIONAL"
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr "El argumento dummy '%s' en %L no puede ser INTENT(OUT)"
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr "La variable '%s' no puede aparecer en la expresión en %L"
 
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "check_restricted(): Unknown expression type"
 msgstr "Se esperaba un tipo de expresión"
 
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr "La expresión en %L debe ser de tipo INTEGER, se encontró %s"
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L must be PURE"
 msgid "Function %qs at %L must be PURE"
 msgstr "La función '%s' en %L debe ser PURE"
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr "La expresión en %L debe ser escalar"
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr ""
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr "Rangos incompatibles en %s (%d y %d) en %L"
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "Forma diferente para %s en %L en la dimensión %d (%d y %d)"
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deferred-length character component '%s' at %L is not yet supported"
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr "El componente de caractér de longitud diferida '%s' en %L aún no se admite"
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a VALUE"
 msgid "%qs at %L is not a VALUE"
 msgstr "'%s' en %L no es un VALUE"
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal stride of zero at %L"
 msgid "Illegal assignment to external procedure at %L"
 msgstr "Tranco ilegal de cero en %L"
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "Rangos %d y %d incompatibles en la asignación en %L"
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "El tipo de la variable es UNKNOWN en la asignación en %L"
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "NULL aparece en el lado derecho de una asignación en %L"
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "POINTER valued function appears on right-hand side of assignment at %L"
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "Una función valuada como POINTER aparece en el lado derecho de la asignación en %L"
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr ""
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deferred-length character component '%s' at %L is not yet supported"
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr "El componente de caractér de longitud diferida '%s' en %L aún no se admite"
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Tipos incompatible en la declaración DATA en %L; se intentó la conversión de %s a %s"
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "El objetivo de asignación de puntero no es un POINTER en %L"
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "'%s' en la asignación de puntero en %L no puede ser un l-valor ya que es un procedimiento"
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, fuzzy, gcc-internal-format
 #| msgid "Expected bounds specification for '%s' at %L"
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Se esperaba una especificación de límites para '%s' en %L"
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Bounds specification for '%s' in pointer assignment at %L"
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Fortran 2003: Especificación de límites para '%s' en una asignación de puntero en %L"
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "El tranco no debe ser estar presente en %L"
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "El objeto puntero en %L no debe tener un coíndice"
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Asignación de puntero de procedimiento no válida en %L"
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' is invalid in procedure pointer assignment at %L"
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "La función de declaración '%s' es no válida en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "La interfaz abstracta '%s' es no válida en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' is invalid in procedure pointer assignment at %L"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "La función de declaración '%s' es no válida en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "El procedimiento interno '%s' es no válido en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "El procedimiento interno '%s' es no válido en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, fuzzy, gcc-internal-format
 #| msgid "Nonintrinsic elemental procedure '%s' is invalid in procedure pointer assigment at %L"
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "El procedimiento elemental que no es intrínseco '%s' es no válido en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "No hay coincidencia en la asignación de puntero a procedimiento en %L: no hay coincidencia en la convención a llamada"
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "No coincide la interfaz en la asignación de puntero a procedimiento en %L: %s"
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, fuzzy, gcc-internal-format
 #| msgid "NOPASS or explicit interface required at %C"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Se requiere NOPASS o una interfaz explícita en %C"
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, fuzzy, gcc-internal-format
 #| msgid "NOPASS or explicit interface required at %C"
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Se requiere NOPASS o una interfaz explícita en %C"
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "No coincide la interfaz en la asignación de puntero a procedimiento en %L: %s"
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr "El objetivo de asignación de puntero no es un POINTER en %L"
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Tipos diferentes en la asignación de puntero en %L; se intentó la asignación de %s a %s"
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Parámetros de tipo de género diferentes en la asignación de puntero en %L"
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Rangos diferentes en la asignación de puntero en %L"
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "El objetivo de remapeo de rango es menor que el tamaño del puntero (%ld < %ld) en %L"
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "El objetivo de remapeo de rango de debe ser de rango 1 o simplemente contiguo en %L"
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: Rank remapping target is not rank 1 at %L"
 msgid "Rank remapping target is not rank 1 at %L"
@@ -76176,213 +76218,213 @@ msgstr "Fortran 2008: El objetivo de remapeo de rango no es rango 1 en %L"
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "El objetivo de datos en %L no puede tener un coíndice"
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "La expresión objetivo en la asignación de puntero en %L debe entregar un resultado puntero"
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr ""
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization target at %C must have the TARGET attribute"
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "El objetivo de inicialización de puntero en %C debe tener el atributo TARGET"
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr "El especificador ASYNCHRONOUS= en %L debe ser una expresión de inicialización"
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr ""
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "El objetivo de asignación de puntero no es TARGET ni POINTER en %L"
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Objetivo erróneo en la asignación de puntero en el procedimiento PURE en %L"
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Asignación de puntero con subíndice vectorial del lado derecho en %L"
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "El objetivo de asignación de puntero tiene atributo PROTECTED en %L"
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "La expresión objetivo en la asignación de puntero en %L debe entregar un resultado puntero"
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization target at %L must not be ALLOCATABLE "
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "El objetivo de inicialización de puntero en %L no debe ser ALLOCATABLE"
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization target at %C must have the TARGET attribute"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "El objetivo de inicialización de puntero en %C debe tener el atributo TARGET"
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "El objetivo de inicialización de puntero en %L debe tener el atributo SAVE"
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "El objetivo de inicialización de puntero a procedimiento en %L tal vez no es un puntero a procedimiento"
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "El procedimiento interno '%s' es no válido en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "El procedimiento interno '%s' es no válido en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Funciones puntero en un contexto de definición variable (%s) en %L"
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Expresión que no es variable en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' in variable definition context (%s) at %L"
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Constante nombrada '%s' en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in variable definition context (%s) at %L is not a variable"
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "'%s' en el contexto de definición variable (%s) en %L no es una variable"
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Uno que no es POINTER en el contexto de asociación de puntero (%s) en %L"
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Named constant '%s' in variable definition context (%s) at %L"
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Constante nombrada '%s' en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' in variable definition context (%s) at %L"
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr "Constante nombrada '%s' en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' with INTENT(IN) in pointer association context (%s) at %L"
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Argumento dummy '%s' con INTENT(IN) en el contexto de asociación de puntero (%s) en %L"
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' with INTENT(IN) in variable definition context (%s) at %L"
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Argumento dummy '%s' con INTENT(IN) en el contexto de definición de variable (%s) en %L"
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "La variable '%s' es PROTECTED y no puede aparecer en un contexto de asociación de puntero (%s) en %L"
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "La variable '%s' es PROTECTED y no puede aparecer en un contexto de definición variable (%s) en %L"
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "La variable '%s' no puede aparecer en un contexto de definición variable (%s) en %L en el procedimiento PURE"
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr "No se puede usar '%s' en %L asociado al objetivo con índice vectorial en un contexto de definición variable (%s)"
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L associated to expression can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "No se puede usar '%s' en %L asociado a una expresión en un contexto de definición variable (%s)"
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L associated to expression can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr "No se puede usar '%s' en %L asociado a una expresión en un contexto de definición variable (%s)"
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "El nombre asociado '%s' no puede aparecer en un contexto de definición variable (%s) en %L porque su obtetivo en %L tampoco puede aparecer"
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L associated to expression can not be used in a variable definition context (%s)"
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
@@ -76406,8 +76448,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "Se crea una matriz temporal en %L"
@@ -76500,7 +76542,7 @@ msgstr "La variable '%s' en %C no se puede redefinir dentro del inicio de un buc
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "La variable '%s' en %C no se puede redefinir dentro del inicio de un bucle en %L"
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -76645,12 +76687,12 @@ msgstr "El primer argumento de la asignación definida en %L debe ser INTENT(OUT
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "El segundo argumento de la asignación definida en %L debe ser INTENT(IN)"
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "El primer argumento de la interfaz de operador en %L debe ser INTENT(IN)"
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "El segundo argumento de la interfaz de operador en %L debe ser INTENT(IN)"
@@ -77660,7 +77702,7 @@ msgstr "Conversión de %s a %s en %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
@@ -78277,7 +78319,7 @@ msgstr "NAMELIST '%s' en la declaración READ en %L contiene el símbolo '%s' el
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "El objeto NAMELIST '%s' en la lista de nombres '%s' en %L es polimórfico y requiere un procedimiento de entrada/salida definido"
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST object '%s' in namelist '%s' at %L with ALLOCATABLE or POINTER components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -78459,6 +78501,11 @@ msgstr "Desbordamiento entero"
 msgid "check_charlen_present(): length not set"
 msgstr ""
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr ""
+
 #: fortran/match.cc:118
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
@@ -78903,7 +78950,7 @@ msgstr "El código STOP en %L debe ser un carácter por defecto KIND=%d"
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "El código STOP en %L debe ser un entero por defecto KIND=%d"
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
@@ -79487,87 +79534,87 @@ msgstr "Error sintáctico en la declaración PROTECTED en %C"
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "El selector en SELECT TYPE en %C no es una variable nombrada; use nombre-asociado =>"
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: LOCK statement at %C"
 msgid "SELECT RANK statement at %C"
 msgstr "Fortran 2008: Declaración LOCK en %C"
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in PROTECTED statement at %C"
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "Error sintáctico en la declaración PROTECTED en %C"
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Declaración CASE inesperada en %C"
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Error sintáctico en la especificación CASE en %C"
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Declaración TYPE IS inesperada en %C"
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Error sintáctico en la especificación TYPE IS en %C"
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Error sintáctico en la especificación CLASS IS en %C"
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected RANK statement at %C"
 msgstr "Declaración END inesperada en %C"
 
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL stride expression at %L must be a scalar %s"
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "La expresión de tranco FORALL en %L debe ser un %s escalar"
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE specification at %C"
 msgid "Syntax error in RANK specification at %C"
 msgstr "Error sintáctico en la especificación CASE en %C"
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "La declaración ELSEWHERE en %C no está dentro de un bloque WHERE"
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -81122,8 +81169,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "La cláusula IF en %L requiere una expresión LOGICAL escalar"
@@ -83764,13 +83811,13 @@ msgstr "El intrínseco '%s' declarado como INTRINSIC en %L no está disponible e
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "El procedimiento que no es RECURSIVE '%s' en %L posiblemente se está llamando a sí mismo recursivamente. Declárelo RECURSIVE o utilice -frecursive"
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, fuzzy, gcc-internal-format
 #| msgid "Non-RECURSIVE procedure '%s' at %L is possibly calling itself recursively.  Declare it RECURSIVE or use -frecursive"
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "El procedimiento que no es RECURSIVE '%s' en %L posiblemente se está llamando a sí mismo recursivamente. Declárelo RECURSIVE o utilice -frecursive"
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "La etiqueta %d referenciada en %L nunca se define"
@@ -83907,7 +83954,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "La función '%s' en %L no es de tipo IMPLICIT"
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -84350,296 +84397,302 @@ msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of references"
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr "se crea la matriz de referencias"
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s', used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable '%s', usada en una expresión de especificación, se referencía en %L antes de la declaración ENTRY en la cual es un parámetro"
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable '%s' se usa en %L antes de la declaración ENTRY en la cual es un parámetro"
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Subobjecto polimórfico de un objeto coindizado en %L"
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Objeto coindizado con subcomponente alojable polimórfico en %L"
 
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%qs es obsoleto"
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Bad array reference at %L"
+msgid "Invalid array reference at %L"
+msgstr "Referencia de matriz errónea en %L"
+
+#: fortran/resolve.cc:6433
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Error in type-spec at %L"
 msgid "Error in typebound call at %L"
 msgstr "Error en la especificación de tipo en %L"
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "El objeto pasado en %L debe ser escalar"
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type '%s'"
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "El objeto base para la llamada a componente procedimiento-puntero en %L es de tipo ABSTRACT '%s'"
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for type-bound procedure call at %L is of ABSTRACT type '%s'"
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "El objeto base para la llamada a procedimiento enlazada a tipo en %L es de tipo ABSTRACT '%s'"
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "El objeto base para la llamada a procedimiento enlazada a tipo NOPASS en %L debe ser escalar"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, fuzzy, gcc-internal-format
 #| msgid "Found no matching specific binding for the call to the GENERIC '%s' at %L"
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "No se encontró un enlace específico coincidente para la llamada al GENERIC '%s' en %L"
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a SUBROUTINE"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "'%s' en %L debe ser una SUBROUTINE"
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a FUNCTION"
 msgid "%qs at %L should be a FUNCTION"
 msgstr "'%s' en %L debe ser una FUNCTION"
 
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Se esperaba un tipo de expresión"
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s en %L debe ser un escalar"
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L must be nonnegative"
 msgid "%s at %L must be integer"
 msgstr "'%s' en %L debe ser no negativo"
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s en %L debe ser INTEGER"
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "La expresión de paso en el bucle DO en %L no puede ser cero"
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "El bucle DO en %L se ejecutará cero veces"
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "El nombre de índice FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "La expresión de inicio FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "La expresión de fin FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "La expresión de tranco FORALL en %L debe ser un %s escalar"
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "La expresión de tranco FORALL en %L no puede ser cero"
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, fuzzy, gcc-internal-format
 #| msgid "FORALL index '%s' may not appear in triplet specification at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "El índice FORALL '%s' no puede aparecer en la especificación triplet en %L"
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "El objeto de alojamiento en %L debe ser ALLOCATABLE o un POINTER"
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Objeto alojable coindizado en %L"
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "La expresión fuente en %L debe ser escalar o tener el mismo rango que el objeto de alojamiento en %L"
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "La expresión fuente en %L y el objeto de alojamiento en %L deben tener la misma forma"
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "El tipo de entidad en %L es de tipo incompatible con la expresión fuente en %L"
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "El objeto de alojamiento en %L y la expresión fuente en %L deben tener el mismo parámetro de tipo de género"
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "La expresión fuente en %L no puede ser de tipo LOCK_TYPE ni tener un componente LOCK_TYPE si el objeto-alojado en %L es una comatriz"
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "La expresión fuente en %L no puede ser de tipo LOCK_TYPE ni tener un componente LOCK_TYPE si el objeto-alojado en %L es una comatriz"
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "El alojamiento %s del tipo de base ABSTRACT en %L requiere una especificación de tipo o una expresión source"
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Alojar %s en %L con especificación de tipo requiere el mismo parámetro de longitud de carácter que el de la declaración"
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de matriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de matriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de comatriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Especificación de comatriz errónea en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Especificación de matriz errónea en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "'%s' no debe aparecer en la especificación de matriz en %L en la misma declaración ALLOCATE donde se aloja a sí misma"
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "Se esperaba '*' en la especificación de comatriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "La variable stat en %L debe ser una variable INTEGER escalar"
 
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable stat en %L no no debe ser %sd dentro de la misma declaración %s"
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG en %L es inútil sin una etiqueta STAT"
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "El argumento ERRMSG= en %L debe ser una variable CHARACTER escalar"
 
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable errmsg en %L no debe ser %sd dentro de la misma declaración %s"
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "El objeto de alojamiento en %L también aparece en %L"
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "El objeto de alojamiento en %L es un subobjeto del objeto en %L"
@@ -84648,303 +84701,303 @@ msgstr "El objeto de alojamiento en %L es un subobjeto del objeto en %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "La etiqueta CASE en %L se encima con la etiqueta CASE en %L"
 
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "La expresión en la declaración CASE en %L debe ser de tipo %s"
 
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "La expresión en la declaración CASE en %L debe ser de género %d"
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "La expresión en la declaración CASE en %L debe ser escalar"
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "La expresión de selección en una declaración GOTO computada en %L debe ser una expresión entera escalar"
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "El argumento de la declaración SELECT en %L no puede ser %s"
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "El argumento de la declaración SELECT en %L debe ser una expresión escalar"
 
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "La expresión en la declaración CASE en %L no está en el rango de %s"
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "El DEFAULT CASE en %L no puede tener después un segundo DEFAULT CASE en %L"
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "No se permite un rango lógico en una declaración CASE en %L"
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Se repite un valor lógico constante en una declaración CASE en %L"
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "La especificación de rango en %L nunca puede coincidir"
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "El bloque SELECT CASE lógico en %L tiene más de dos cases"
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "El procedimiento interno '%s' es no válido en la asignación de puntero de procedimiento en %L"
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "El nombre '%s' no se puede usar como un operador definido en %C"
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name '%s' at %L is used as array"
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Se usa el nombre asociado '%s' en %L como una matriz"
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L cannot be NULL()"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L has no type"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name '%s' at %L is used as array"
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Se usa el nombre asociado '%s' en %L como una matriz"
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "El selector debe ser polimórfico en la declaración SELECT TYPE en %L"
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L must not be coindexed"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "La etiqueta CASE en %L se encima con la etiqueta CASE en %L"
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be extensible"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "El tipo derivado '%s' en %L debe ser extensible"
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be an extension of '%s'"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "El tipo derivado '%s' en %L debe ser una extensión de '%s'"
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected NULL() intrinsic at %L to dummy '%s'"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Intrínseco NULL inesperado en %L para el dummy '%s'"
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "La especificación de tipo en %L no puede tener un parámetro de tipo diferido"
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Bloque CLASS IS doble en la declaración SELECT TYPE  en %L"
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid context for NULL() pointer at %%L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Contexto no válido para el puntero NULL() en %%L"
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STOP code at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "El código STOP en %L debe ser escalar"
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede ser polimórfico a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes POINTER a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes de puntero a procedimiento"
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes ALLOCATABLE a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes PRIVATE"
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes POINTER a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "El elemento de transferencia de datos en %L no puede ser una referencia completa a una matriz de tamaño asumido"
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "La variable lock en %L debe ser un escalar de tipo LOCK_TYPE"
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "La variable lock en %L debe ser un escalar de tipo LOCK_TYPE"
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "El argumento actual para '%s' en %L debe ser una comatriz"
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "El argumento actual para '%s' en %L debe ser una comatriz"
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "El argumento STAT= en %L debe ser una variable INTEGER escalar"
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "El argumento ERRMSG= en %L debe ser una variable CHARACTER escalar"
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "El argumento ACQUIRED_LOCK= en %L debe ser una variable LOGICAL escalar"
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "El argumento de conjunto de imagen %L debe ser un escalar o una expresión INTEGER de rango 1"
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "El argumento de conjunto de imagen %L debe ser un escalar o una expresión INTEGER de rango 1"
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "El argumento de conjunto de imagen en %L debe estar entre 1 y num_images()"
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "La declaración en %L no es una declaración de objetivo de ramificación válida para la declaración de ramificación en %L"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "La ramificación en %L puede resultar en un bucle infinito"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "La declaración GOTO en %L deja la construcción CRITICAL por la etiqueta en %L"
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "La declaración GOTO en %L deja la construcción DO CONCURRENT por la etiqueta en %L"
@@ -84952,227 +85005,227 @@ msgstr "La declaración GOTO en %L deja la construcción DO CONCURRENT por la et
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "La etiqueta en %L no está en el mismo bloque que la declaración GOTO en %L"
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "La máscara WHERE en %L tiene forma inconsistente"
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "El objetivo de asignación WHERE en %L tiene forma inconsistente"
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Asignación definida por el usuario de un no-ELEMENTAL en WHERE en %L"
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Declaración sin soporte dentro de WHERE en %L"
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Asignación a una variable de índice FORALL en %L"
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "No se usa el FORALL con índice '%s' en el lado izquierdo de la asignación en %L y podría causar múltiples asignaciones a este objeto"
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: BLOCK construct at %C"
 msgid "FORALL construct at %L"
 msgstr "Fortran 2008: Constructor BLOCK en %C"
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "El nombre de índice FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Una construcción FORALL externa ya tiene un índice con este nombre %L"
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "la cláusula WHERE/ELSEWHERE en %L requiere una matriz LOGICAL"
 
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have procedure pointer components"
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes de puntero a procedimiento"
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr "Se truncará la expresión CHARACTER en la asignación (%d/%d) en %L"
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "La expresión con coíndice en %L se asigna a una variable de tipo derivado con un componente POINTER en un procedimiento PURE"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Asignación a una variable coindizada en %L en un procedimiento PURE"
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Polymorphic array at %C not yet supported"
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Aún no se admite la matriz polimórfica en %C"
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Asignación a una variable de índice FORALL en %L"
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, fuzzy, gcc-internal-format
 #| msgid "Variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr "La variable no debe ser polimórfica en la asignación intrínseca en %L - revise que hay una subrutina específica coincidente para el operador '='"
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coindexed variable must not be have an allocatable ultimate component in assignment at %L"
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "La variable coindizada no debe tener un componente último alojable en la asignación en %L"
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Asignación de puntero de procedimiento no válida en %L"
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "La expresión objetivo en la asignación de puntero en %L debe entregar un resultado puntero."
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "El argumento de la declaración SELECT en %L debe ser una expresión escalar"
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "El argumento STAT= en %L debe ser una variable INTEGER escalar"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "La declaración ASSIGNED GOTO en %L requiere una variable INTEGER"
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "La variable '%s' no se ha asignado a una etiqueta objetivo en %L"
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "La declaración RETURN alternativa en %L requiere de un especificador de devolución SCALAR-INTEGER"
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected initialization expression in CASE at %C"
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "Se esperaba la inicialización de la expresión en CASE en %C"
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "La declaración de ASSIGN en %L requiere una variable INTEGER escalar por defecto"
 
 # 'kind' es el tipo del tipo de dato en Fortran. Lo traduzco como 
 # 'género', para evitar confusión con 'type' = 'tipo'. cfuga
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Género no válido para %s en %L"
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "La declaración IF aritmética en %L requiere una expresión numérica"
 
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "La condición de salida del bucle DO WHILE en %L debe ser una expresión LOGICAL escalar"
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "La cláusula de máscara FORALL en %L requiere una expresión LOGICAL escalar"
 
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Código de declaración erróneo"
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter '%s' declared at %L"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Se declaró el parámetro '%s' sin uso en %L"
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -85180,7 +85233,7 @@ msgstr "La etiqueta enlazante '%s' en %L colisiona con la entidad global '%s' en
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
@@ -85189,66 +85242,66 @@ msgstr "La etiqueta enlazante '%s' en %L colisiona con la entidad global '%s' en
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "La etiqueta enlazante '%s' en %L colisiona con la entidad global '%s' en %L"
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "La longitud de la cadena en %L es demasiado grande"
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "La matriz allocatable '%s' en %L debe tener una forma diferida"
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "El objeto escalar '%s' en %L no puede ser ALLOCATABLE"
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "La matriz de puntero '%s' en %L debe tener una forma diferida"
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "La matriz '%s' en %L no puede tener una forma diferida"
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' of CLASS variable '%s' at %L is not extensible"
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "El tipo '%s' de la variable CLASS '%s' en %L no es extensible"
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, fuzzy, gcc-internal-format
 #| msgid "CLASS variable '%s' at %L must be dummy, allocatable or pointer"
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "La variable CLASS '%s' en %L debe ser dummy, allocatable o pointer"
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "El tipo '%s' no se puede asociar al anfitrión en %L porque está bloqueado por un objeto incompatible del mismo nombre declarado en %L"
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Implied SAVE for module variable '%s' at %L, needed due to the default initialization"
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008: SAVE implícito para la variable de módulo '%s' en %L, se necesita por la inicialización por defecto"
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
@@ -85256,1082 +85309,1082 @@ msgstr "La entidad '%s' en %L tiene un parámetro de tipo diferido y requiere el
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "El módulo o la matriz del programa principal '%s' en %L deben tener una forma constante"
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "La entidad con longitud de carácter asumida en %L debe ser un argumento de prueba o un PARAMETER"
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON variable '%s' at %L must have constant character length"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "La variable COMMON '%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "El allocatable '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "El external '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "El dummy '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "El intrinsic '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "El resultado de la función '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "La matriz automática '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fstat %s"
 msgid "%s at %L"
 msgstr "fstat %s"
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "La función de declaración valuada con carácter '%s' en %L debe tener longitud constante"
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: '%s' es de un tipo PRIVATE y no puede ser un argumento dummy de '%s', el cual es PUBLIC en %L"
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Procedure '%s' in PUBLIC interface '%s' at %L takes dummy arguments of '%s' which is PRIVATE"
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: El procedimiento '%s' en la interfaz PUBLIC '%s' en %L toma argumentos dummy de '%s' el cual es PRIVATE"
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "La función '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "El objeto external '%s' en %L puede no tener un inicializador"
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "La función ELEMENTAL '%s' en %L debe tener un resultado escalar"
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L may not have pointer or allocatable attribute"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "La función de declaración '%s' en %L no debe tener atributo puntero o alojable"
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser matriz-valuada"
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser puntero-valuada"
 
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser pura"
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser recursiva"
 
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser pura"
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "El procedimiento '%s' en %s en %L no tiene una interfaz explícita"
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "El procedimiento dummy '%s' en %C no puede tener una interfaz genérica"
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo SAVE en '%s' en %L"
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo INTENT en '%s' en %L"
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with RESULT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo RESULT en '%s' en %L"
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, fuzzy, gcc-internal-format
 #| msgid "EXTERNAL attribute conflicts with FUNCTION attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "El atributo EXTERNAL genera un conflicto con el atributo FUNCTION en '%s' en %L"
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer result '%s' at %L is missing the pointer attribute"
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Al resultado del puntero de procedimiento '%s' en %L le falta el atributo puntero"
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, fuzzy, gcc-internal-format
 #| msgid "Interface '%s' of procedure '%s' at %L must be explicit"
 msgid "Interface of %qs at %L must be explicit"
 msgstr "La interfaz '%s' del procedimiento '%s' en %L debe ser explícita"
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' at %L is not a SUBROUTINE"
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "El procedimiento FINAL '%s' en %L no debe ser una SUBROUTINE"
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "El procedimiento FINAL en %L debe tener exactamente un argumento"
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "El argumento del procedimiento FINAL en %L debe ser de tipo '%s'"
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser un POINTER"
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "El argumento del procedimiento final en %L no debe ser ALLOCATABLE"
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser OPTIONAL"
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser INTENT(OUT)"
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "El procedimiento FINAL que no es escalar en %L debe tener un argumento sharp asumido"
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' declared at %L has the same rank (%d) as '%s'"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "El procedimiento FINAL '%s' declarado en %L tiene el mismo rango (%d) que '%s'"
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type '%s' defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr "Sólo se declaran procedimientos FINAL de matriz para el tipo derivado '%s' definido en %L, se sugiere también uno escalar"
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' can't be mixed FUNCTION/SUBROUTINE for GENERIC '%s' at %L"
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "'%s' y '%s' no pueden ser FUNCTION/SUBROUTINE mezcladas para el GENERIC '%s' en %L"
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' for GENERIC '%s' at %L are ambiguous"
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "'%s' y '%s' para el GENERIC '%s' en %L son ambiguos"
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, fuzzy, gcc-internal-format
 #| msgid "Undefined specific binding '%s' as target of GENERIC '%s' at %L"
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "El enlace específico '%s' no está definido como objetivo del GENERIC '%s' en %L"
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L must target a specific binding, '%s' is GENERIC, too"
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "El GENERIC '%s' en %L debe apuntar a un enlace específico, '%s' es GENERIC también"
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "El GENERIC '%s' en %L no puede sobreescribir el enlace específico con el mismo nombre"
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-bound operator at %L can't be NOPASS"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "El operador enlazado a tipo en %L no puede ser NOPASS"
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must be a module procedure or an external procedure with an explicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "'%s' debe ser un procedimiento de módulo o un procedimiento externo con una interfaz explícita en %L"
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "El procedimiento '%s' con PASS(%s) en %L no tiene un argumento '%s'"
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "El procedimiento '%s' con PASS en %L debe tener al menos un argumento"
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, fuzzy, gcc-internal-format
 #| msgid "Non-polymorphic passed-object dummy argument of '%s' at %L"
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Argumento dummy pasado como objeto no polimórfico de '%s' en %L"
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser del tipo derivado '%s'"
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser del tipo derivado '%s'"
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr ""
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L debe ser escalar"
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L no debe ser ALLOCATABLE"
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L no debe ser POINTER"
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "El procedimiento '%s' en %L tiene el mismo nombre que un componente de '%s'"
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as an inherited component of '%s'"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "El procedimiento '%s' en %L tiene el mismo nombre que un componente heredado de '%s'"
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' declared at %L must be ABSTRACT because '%s' is DEFERRED and not overridden"
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "El tipo derivado '%s' declarado en %L debe ser ABSTRACT porque '%s' es DEFERRED y no se sobreescribió"
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray component '%s' at %L must be allocatable with deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "El componente de comatriz '%s' en %L debe sel alojable con forma diferida"
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "El componente '%s' en %L de TYPE(C_PTR) o TYPE(C_FUNPTR) no debe ser una comatriz"
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "El componenten '%s' en %L con componente comatriz debe ser un escalar que no sea puntero alojable"
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "El componente '%s' en %L tiene el atributo CONTIGUOUS porque no es un puntero de matriz"
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "El argumento de ICHAR en %L debe ser de longitud uno"
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "El procedimiento de componente puntero '%s' con PASS(%s) en %L no tiene un argumento '%s'"
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "El procedimiento de componente puntero '%s' con PASS en %L debe tener al menos un argumento"
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser del tipo derivado '%s'"
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser escalar"
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L no puede tener el atributo POINTER"
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L no puede ser ALLOCATABLE"
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "El componente '%s' de '%s' en %L tiene el mismo nombre que un procedimiento enlazado a tipo heredado"
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L"
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "La longitud de carácter del componente '%s' necesita ser una expresión de especificación constante en %L"
 
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be of INTEGER type, found %s"
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "La expresión en %L debe ser de tipo INTEGER, se encontró %s"
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, fuzzy, gcc-internal-format
 #| msgid "Character component '%s' of '%s' at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "El componente de carácter '%s' de '%s' en %L con longitud diferida debe ser POINTER o ALLOCATABLE"
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: the component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: el componente '%s' es un tipo PRIVATE y no puede ser un componente de '%s' el cual es PUBLIC en %L"
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "El componente polimórfico %s en %L en SEQUENCE o de tipo BIND(C) %s"
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "El componente %s del tipo SEQUENCE declarado en %L no tiene el atributo SEQUENCE"
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflicting I/O control specifications at %0 and %1"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Especificaciones de control de E/S en conflicto en %0 y %1"
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, fuzzy, gcc-internal-format
 #| msgid "As extending type '%s' at %L has a coarray component, parent type '%s' shall also have one"
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Como al extender el tipo '%s' en %L tiene un componente de comatriz, el tipo padre '%s' también debe tener uno"
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, fuzzy, gcc-internal-format
 #| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "El tipo derivado '%s' que no es extensible en %L no debe ser ABSTRACT"
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Fortran 2003: El nombre genérico '%s' de la función '%s' en %L tiene el mismo nombre que el tipo derivado en %L"
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be extensible"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "El tipo derivado '%s' en %L debe ser extensible"
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %L is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "No se permite la matriz de tamaño asumido '%s' en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Fortran 2003: Objeto de matriz NAMELIST '%s' con forma asumida en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with nonconstant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Fortran 2003: El objeto de matriz NAMELIST '%s' con forma que no es constante en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST object '%s' with nonconstant character length in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Fortran 2003: El objeto de matriz NAMELIST '%s' con longitud de carácter que no es constante en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' se declaró PRIVATE y no puede ser miembro de una lista de nombres PUBLIC '%s' en %L"
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' tiene componentes PRIVATE asociados a uso y no puede ser miembro de la lista de nombres '%s' en %L"
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' tiene componentes PRIVATE y no puede ser un miembro de la lista de nombres PUBLIC '%s' en %L"
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo NAMELIST en '%s' en %L"
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "La matriz de parámetro '%s' en %L no puede ser automática ni de forma diferida"
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "El PARAMETER de tipo implícito '%s' en %L no coincide con un tipo IMPLICIT posterior"
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Tipo derivado incompatible en PARAMETER en %L"
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block '%s' at %L can not have the EXTERNAL attribute"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "El bloque COMMON '%s' en %L no puede tener el atributo EXTERNAL"
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "La entidad '%s' en %L tiene un parámetro de tipo diferido y requiere el atributo pointer o allocatable"
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "El atributo PROTECTED genera un conflicto con el atributo EXTERNAL en %L"
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo PROTECTED en %L"
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "'%s' en %L tiene el atributo CONTIGUOUS pero no es un puntero de matriz o una matriz de forma asumida"
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Especificación errónea para la matriz de tamaño asumido en %C"
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "La matriz de tamaño asumido en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "El símbolo en %L no es una variable DUMMY"
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "'%s' en %L no puede tener el atributo VALUE porque no es un argumento dummy"
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "La variable dummy de carácter '%s' en %L con atributo VALUE debe tener longitud constante"
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "La variable dummy de carácter interoperable con C '%s' en %L con atributo VALUE debe ser de longitud uno"
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "El tipo derivado '%s' en %L es de tipo '%s', el cual no se ha definido"
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "'%s' en %L tiene el atributo CONTIGUOUS pero no es un puntero de matriz o una matriz de forma asumida"
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "No se permite la matriz de forma asumida '%s' en %L en una expresión de inicialización"
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot be a coarray"
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "La variable de bucle en %C no puede ser una comatriz"
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "La variable '%s' en %L no puede ser BIND(C) porque no es un bloque COMMON ni se declaró en el ámbito de nivel de módulo"
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON variable '%s' at %L must have constant character length"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "La variable COMMON '%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003: La función PUBLIC %s '%s' en %L es de tipo derivado PRIVATE '%s'"
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "La variable %s en %L de tipo LOCK_TYPE o con un subcomponente de tipo LOCK_TYPE debe ser una comatriz"
 
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "La variable %s en %L de tipo LOCK_TYPE o con un subcomponente de tipo LOCK_TYPE debe ser una comatriz"
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "El argumento dummy INTENT(OUT) '%s' en %L es ASSUMED SIZE y por lo tanto no puede tener un inicializador por defecto"
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "El argumento dummy '%s' en %L de LOCK_TYPE no puede ser INTENT(OUT)"
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "El argumento dummy '%s' en %L de LOCK_TYPE no puede ser INTENT(OUT)"
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L shall not be a coarray or have a coarray component"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "El resultado de la función '%s' en %L no puede ser una comatriz o tener un componente comatriz"
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "La variable '%s' en %L de TYPE(C_PTR) o TYPE(C_FUNPTR) no debe ser una comatriz"
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "La variable '%s' en %L con componente de comatriz debe ser un escalar que no sea puntero alojable"
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "La variable '%s' en %L es una comatriz y no es ALLOCATABLE, SAVE ni un argumento dummy"
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable coarray variable '%s' at %L must have deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "La variable comatriz allocatable '%s' en %L debe tener forma diferida"
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "La variable '%s' en %L es INTENT(OUT) y por lo tanto no puede ser una comatriz allocatable o tener componentes comatriz"
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "La lista de nombres %s no se puede renombrar por asociación de USE a %s"
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "No se guarda (SAVE) el threadprivate en %L"
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting list of named entities at %C"
 msgid "Expecting definable entity near %L"
 msgstr "Se espera la lista de entidades nombradas %C"
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "El elemento BLOCK DATA '%s' en %L debe estar en COMMON"
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "La matriz DATA '%s' en %L se debe especificar en una declaración previa"
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L cannot have a coindex"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "El elemento DATA '%s' en %L no puede tener un coíndice"
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L is a pointer and so must be a full array"
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "El elemento DATA '%s' en %L es un puntero y entonces debe ser una matriz completa"
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the ALLOCATABLE attribute"
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "El argumento '%s' del procedimiento elemental en %L no puede tener el atributo ALLOCATABLE"
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Sección de matriz no constante en %L en la declaración DATA"
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "La declaración DATA en %L tiene más variables que valores"
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Nonconstant array section at %L in DATA statement"
 msgid "Non-constant character length at %L in DATA statement"
 msgstr "Sección de matriz no constante en %L en la declaración DATA"
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el inicio del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el final del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el paso del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "el paso del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "La declaración DATA en %L tiene más valores que variables"
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Se define la etiqueta %d en %L pero no se usa"
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Se define la etiqueta %d en %L pero no se puede usar"
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L debe tener el atributo SEQUENCE para ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L no puede tener componentes ALLOCATABLE que sean un objeto EQUIVALENCE"
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "La variable de tipo derivado '%s' en %L con inicializadores por defecto no puede ser un objeto EQUIVALENCE con una variable en COMMON"
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L con componente(s) de puntero no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Error sintáctico en la declaración EQUIVALENCE en %L"
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Todos o ninguno de los objetos en el conjunto EQUIVALENCE en %L deben tener el atributo PROTECTED"
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "El miembro de bloque común '%s' en %L no puede ser un objeto EQUIVALENCE en el procedimiento puro '%s'"
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "La constante nombrada '%s' en %L no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "La matriz '%s' en %L con límites que no son constantes no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "El componente de estructura '%s' en %L no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "La subcadena en %L tiene longitud cero"
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, fuzzy, gcc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Longitudes de carácter diferentes en la asignación de puntero en %L"
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "La función PUBLIC '%s' en %L no puede ser del tipo PRIVATE '%s'"
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY '%s' en %L no tiene tipo IMPLICIT"
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "El procedimiento de operador de usuario '%s' en %L debe ser FUNCTION"
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "El procedimiento de operador de usuario '%s' en %L no puede ser de longitud de carácter asumido"
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "El procedimiento de operador de usuario '%s' en %L debe tener al menos un argumento"
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "El primer argumento de la interfaz de operador en %L no puede ser opcional"
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "El segundo argumento de la interfaz de operador en %L no puede ser opcional"
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "La interfaz de operador en %L debe tener, cuando mucho, dos argumentos"
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -86915,364 +86968,364 @@ msgstr "La variable declarada implícitamente '%s' en %L tal vez no es interoper
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr "El resultado de la función '%s' en %L no es de tipo IMPLICIT"
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr "El atributo %s genera un conflicto con el atributo %s en %L"
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, fuzzy, gcc-internal-format
+#| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr "El atributo %s genera un conflicto con el atributo %s en '%s' en %L"
+
+#: fortran/symbol.cc:508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr "No se permite el atributo %s en la unidad de programa BLOCK DATA en %L"
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "El nombre de grupo de lista de nombres en %L no puede tener el atributo SAVE"
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, gcc-internal-format
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr ""
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Procedure pointer at %C"
 msgid "Procedure pointer at %C"
 msgstr "Fortran 2003: Procedimiento puntero en %C"
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "El atributo %s se aplica a %s %s en %L"
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "Se aplicó BIND(C) a %s %s en %L"
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, gcc-internal-format, gfc-internal-format
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr "El atributo %s genera un conflicto con el atributo %s en %L"
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, fuzzy, gcc-internal-format
-#| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr "El atributo %s genera un conflicto con el atributo %s en '%s' en %L"
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "No se pueden cambiar los atributos de un símbolo asociado con USE en %L"
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "No se pueden cambiar los atributos del símbolo asociado con USE %s en %L"
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "Se especificó un atributo %s duplicado en %L"
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr "Se especificó ALLOCATABLE fuera de un cuerpo INTERFACE en %L"
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate VOLATILE attribute specified at %L"
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr "Se especificó un atributo VOLATILE duplicado en %L"
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, fuzzy, gcc-internal-format
 #| msgid "CODIMENSION specified for '%s' outside its INTERFACE body at %L"
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "Se especificó CODIMENSION para '%s' fuera de su cuerpo INTERFACE en %L"
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, fuzzy, gcc-internal-format
 #| msgid "DIMENSION specified for '%s' outside its INTERFACE body at %L"
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "Se especificó DIMENSION para '%s' fuera de su cuerpo INTERFACE en %L"
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "El Apuntado Cray en %L aparece en varias declaraciones pointer()"
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "Se especificó un atributo PROTECTED duplicado en %L"
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "El atributo SAVE en %L no se puede especificar en un procedimiento PURE"
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "Se especificó un atributo SAVE duplicado en %L"
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "Se especificó un atributo VALUE duplicado en %L"
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Se especificó un atributo VOLATILE duplicado en %L"
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr "El atributo SAVE en %L no se puede especificar en un procedimiento PURE"
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Se especificó un atributo ASYNCHRONOUS duplicado en %L"
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute of '%s' conflicts with %s attribute at %L"
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "El atributo %s de '%s' genera un conflicto con el atributo %s en %L"
 
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "El procedimiento %s en %L ya se había declarado como un procedimiento %s"
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) genera un conflicto con INTENT(%s) en %L"
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "La especificación ACCESS en %L ya se había especificado"
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Se especificó un atributo BIND duplicado en %L"
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid " BIND(C)"
 msgid "BIND(C) at %L"
 msgstr " BIND(C)"
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Se especificó un atributo EXTENDS duplicado en %L"
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: EXTENDS at %L"
 msgid "EXTENDS at %L"
 msgstr "Fortran 2003: EXTENDS en %L"
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "El símbolo '%s' en %L ya tenía una interfaz explícita"
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has attributes specified outside its INTERFACE body"
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "'%s' en %L tiene atributos especificados fuera de su cuerpo INTERFACE"
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "El símbolo '%s' en %L genera conflictos con el símbolo del módulo '%s' asociado a uso en %L"
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "El símbolo '%s' en %L ya tenía el tipo básico de %s"
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "El procedimiento '%s' en %L no puede tener el tipo básico de %s"
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "El símbolo '%s' en %L no puede tener un tipo"
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already in the parent type at %L"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "El componente '%s' en %C ya estaba en el tipo padre en %L"
 
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "El símbolo '%s' en %C es ambiguo"
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "El tipo derivado '%s' en %C se está usando antes de ser definido"
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "El componente '%s' en %C es un componente PRIVATE de '%s'"
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "'%s' en %C no es un miembro de la estructura '%s'"
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "'%s' en %C no es un miembro de la estructura '%s'"
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Declaración de etiqueta %d duplicada en %L y %L"
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "La etiqueta %d en %C ya se referenció como objetivo de ramificación"
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "La etiqueta %d en %C ya se referenció como etiqueta de formato"
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "La etiqueta %d en %C se utilizó previamente como una etiqueta FORMAT"
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "La etiqueta %d en %C se utilizó previamente como objetivo de ramificación"
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Shared DO termination label %d at %C"
 msgstr "Se esperaba un nombre terminal en %C"
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: LOCK statement at %C"
 msgid "Labeled DO statement at %L"
 msgstr "Fortran 2008: Declaración LOCK en %C"
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "El nombre '%s' en %C es una referencia ambigua a '%s' del módulo '%s'"
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from current program unit"
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "El nombre '%s' en %C es una referencia ambigua a '%s' de la unidad de programa actual"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "El símbolo '%s' en %C ya se había asociado con el anfitrión"
 
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' declared at %L must have the BIND attribute to be C interoperable"
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "El tipo derivado '%s' declarado en %L debe tener el atributo BIND para ser interoperable con C"
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "El tipo derivado '%s' con atributo BIND(C) en %L está vacío, y puede ser inaccesible para el procesador acompañante de C"
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "El componente '%s' en %L no puede tener el atributo POINTER porque es un miembro del tipo derivado BIND(C) '%s' en %L"
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "El procedimiento de componente puntero '%s' en %L no puede ser un miembro del tipo derivado BIND(C) '%s' en %L"
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "El componente '%s' en %L no puede tener el atributo ALLOCATABLE porque es un miembro del tipo derivado BIND(C) '%s' en %L"
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable, even though derived type '%s' is BIND(C)"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "El componente '%s' en el tipo derivado '%s' en %L tal vez no es interoperable con C, aún cuando el tipo derivado '%s' es BIND(C)"
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "El componente '%s' en el tipo derivado '%s' en %L tal vez no es interoperable con C"
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "El tipo derivado '%s' en %L no puede tener el atributo SEQUENCE porque es BIND(C)"
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' is used before it is typed at %L"
 msgid "Symbol %qs is used before it is typed at %L"
@@ -87305,26 +87358,26 @@ msgstr "Se sobreescriben los inicializadores desiguales en EQUIVALENCE en %L"
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "Se sobreescriben los inicializadores desiguales en EQUIVALENCE en %L"
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, fuzzy, gcc-internal-format
 #| msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See -fmax-array-constructor option"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "El número de elementos en el constructor de matriz en %L requiere un incremento del límite superior %d permitido.  Vea la opción -fmax-array-constructor"
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, fuzzy, gcc-internal-format
 #| msgid "Creating array temporary at %L for argument '%s'"
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Se crea una matriz temporal en %L para el argumento '%s'"
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "tipo de expresión errónea durante la caminata (%d)"
@@ -87537,40 +87590,40 @@ msgstr "No se define el valor de devolución '%s' de la función '%s' declarada
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "Cannot compute the length of the char array at %L."
 msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Sorry, allocatable scalar coarrays are not yet supported at %L"
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Lo siento, aún no se admiten las comatrices escalares alojables en %L"
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Sorry, allocatable scalar coarrays are not yet supported at %L"
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Lo siento, aún no se admiten las comatrices escalares alojables en %L"
 
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Operador intrínseco desconocido"
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Lista de argumentos de función desconocida en %L"
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -87582,19 +87635,19 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "No se reconoce la función intrínseca %s(%d)"
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "el argumento 'dim' del intrínseco '%s' en %L no es un índice de dimensión válido"
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deferred-length character component '%s' at %L is not yet supported"
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "El componente de caractér de longitud diferida '%s' en %L aún no se admite"
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer object at %C shall not be coindexed"
 msgid "The event variable at %L shall not be coindexed"
@@ -87750,7 +87803,7 @@ msgstr "El componente de caractér de longitud diferida '%s' en %L aún no se ad
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr "Lo siento, sólo se admite integer kind %d implementado para el conjunto imagen en %L"
 
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_trans_select(): Bad type for case expr."
@@ -88153,6 +88206,11 @@ msgstr "la variable %qD se redeclaró como función"
 msgid "function %qD redeclared as variable"
 msgstr "la función %qD se redeclaró como variable"
 
+#: lto/lto-symtab.cc:865
+#, gcc-internal-format
+msgid "previously declared here"
+msgstr "se declaró previamente aquí"
+
 #: lto/lto.cc:174
 #, fuzzy, gcc-internal-format
 #| msgid "lto_obj_file_open() failed"
@@ -89455,7 +89513,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr "se descarta %<-fobjc-sjlj-exceptions%> por %<-fgnu-runtime%>"
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, fuzzy, gcc-internal-format
 #| msgid "non-objective-c type '%T' cannot be caught"
 msgid "non-objective-c type %qT cannot be caught"
@@ -89467,7 +89525,7 @@ msgstr "no se puede atrapar el tipo '%T' que no es de objective-c"
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr "%<-fobjc-sjlj-exceptions%> es la única excepción a sistema admitida para %<-fnext-runtime%> con %<-fobjc-abi-version%> < 2"
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> >= 2"
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
@@ -92364,15 +92422,9 @@ msgstr ""
 #~ msgid "Builtin function %s is only valid for the cell processor"
 #~ msgstr "La función interna %s sólo es válida para el procesador cell"
 
-#~ msgid "Builtin function %s requires the -mhtm option"
-#~ msgstr "La función interna %s requiere la opción -mhtm"
-
 #~ msgid "Builtin function %s requires the -maltivec option"
 #~ msgstr "La función interna %s requiere la opción -maltivec"
 
-#~ msgid "Builtin function %s requires the -mpaired option"
-#~ msgstr "La función interna %s requiere la opción -mpaired"
-
 #~ msgid "Builtin function %s requires the -mspe option"
 #~ msgstr "La función interna %s requiere la opción -mspe"
 
@@ -100698,6 +100750,9 @@ msgstr ""
 #~ msgid "unexpected letter %qc in locate_error\n"
 #~ msgstr "letra %qc inesperada en locate_error\n"
 
+#~ msgid "  also declared as %q#D here"
+#~ msgstr "  también declarado como %q#D aquí"
+
 #~ msgid "creating array with size zero"
 #~ msgstr "creando la matriz con tamaño cero"
 
diff --git a/gcc/po/fi.po b/gcc/po/fi.po
index a755ae678cf..b6b64704b3e 100644
--- a/gcc/po/fi.po
+++ b/gcc/po/fi.po
@@ -32,7 +32,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 11.1-b20210321\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
 "PO-Revision-Date: 2021-03-23 21:16+0200\n"
 "Last-Translator: Lauri Nurmi <lanurmi@iki.fi>\n"
 "Language-Team: Finnish <translation-team-fi@lists.sourceforge.net>\n"
@@ -457,7 +457,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr "ei voi määritellä sekä valitsinta -C että valitsinta -o"
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 #, fuzzy
 msgid "shared and mdll are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
@@ -19340,17 +19340,17 @@ msgstr "tunnistamaton käsky:"
 msgid "insn does not satisfy its constraints:"
 msgstr "alustusalkio ei ole vakio"
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, fuzzy, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "%qD esitelty uudelleen eri näkyvyydellä"
 
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 #, fuzzy
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "%qD esitelty uudelleen eri näkyvyydellä"
 
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 #, fuzzy
 msgid "created and used with different settings of %<-fpie%>"
 msgstr "%qD esitelty uudelleen eri näkyvyydellä"
@@ -19677,7 +19677,7 @@ msgstr "pituusmääre strfmon-muotoilussa"
 msgid "<command-line>"
 msgstr "<komentorivi>"
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "fr30_print_operand: tuntematon koodi"
@@ -19696,9 +19696,9 @@ msgstr "virheellinen const_double-operandi"
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "virheellinen rotate-käsky"
@@ -19718,7 +19718,7 @@ msgstr "virheellinen const_double-operandi"
 msgid "incompatible register operand for '%%%c'"
 msgstr "virheellinen const_double-operandi"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, c-format
 msgid "missing operand"
 msgstr "puuttuva operandi"
@@ -19748,93 +19748,93 @@ msgstr "virheellinen %%G-tila"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "Virheellinen liukulukuoperaatio"
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, c-format
 msgid "invalid %%J value"
 msgstr "virheellinen %%J-arvo"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, c-format
 msgid "invalid %%r value"
 msgstr "virheellinen %%r-arvo"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, c-format
 msgid "invalid %%R value"
 msgstr "virheellinen %%R-arvo"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, c-format
 msgid "invalid %%N value"
 msgstr "virheellinen %%N-arvo"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, c-format
 msgid "invalid %%P value"
 msgstr "virheellinen %%P-arvo"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, c-format
 msgid "invalid %%h value"
 msgstr "virheellinen %%h-arvo"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, c-format
 msgid "invalid %%L value"
 msgstr "virheellinen %%L-arvo"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, c-format
 msgid "invalid %%m value"
 msgstr "virheellinen %%m-arvo"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, c-format
 msgid "invalid %%M value"
 msgstr "virheellinen %%M-arvo"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, c-format
 msgid "invalid %%U value"
 msgstr "virheellinen %%U-arvo"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, c-format
 msgid "invalid %%s value"
 msgstr "virheellinen %%s-arvo"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, c-format
 msgid "invalid %%C value"
 msgstr "virheellinen %%C-arvo"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, c-format
 msgid "invalid %%E value"
 msgstr "virheellinen %%E-arvo"
 
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, fuzzy, c-format
 msgid "unknown relocation unspec"
 msgstr "uudelleensijoitusvirhe"
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, c-format
 msgid "invalid %%xn code"
 msgstr "virheellinen %%xn-koodi"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, fuzzy, c-format
 msgid "invalid operand address"
 msgstr "PRINT_OPERAND_ADDRESS, null-osoitin"
@@ -19928,35 +19928,35 @@ msgstr "virheellinen lauseke kohdemuuttujana"
 msgid "unrecognized supposed constant"
 msgstr "tunnistamaton rekisterinimi %qs"
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, fuzzy, c-format
 msgid "invalid shift operand"
 msgstr "virheellinen lauseke kohdemuuttujana"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, fuzzy, c-format
 msgid "predicated Thumb instruction"
 msgstr "Virheellinen käsky"
 
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, fuzzy, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "fr30_print_operand: tuntematon koodi"
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -19964,126 +19964,126 @@ msgstr "fr30_print_operand: tuntematon koodi"
 msgid "invalid operand for code '%c'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, fuzzy, c-format
 msgid "instruction never executed"
 msgstr "kutsu  %2d ei suoritettu koskaan\n"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, fuzzy, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "fr30_print_operand: tuntematon koodi"
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 #, fuzzy
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 #, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr ""
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 #, fuzzy
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 #, fuzzy
 msgid "bad address, not an I/O address:"
 msgstr "kääntäjän sisäinen virhe.  Virheellinen osoite:"
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 #, fuzzy
 msgid "bad address, not a constant:"
 msgstr "virheellinen merkkijonovakio"
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 #, fuzzy
 msgid "bad address, not (reg+disp):"
 msgstr "kääntäjän sisäinen virhe.  Virheellinen osoite:"
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 #, fuzzy
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "virheellinen merkkijonovakio"
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr "kääntäjän sisäinen virhe.  Virheellinen osoite:"
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, fuzzy, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "void-lausekkeen epäkelpo käyttö"
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 #, fuzzy
 msgid "internal compiler error.  Unknown mode:"
 msgstr "kääntäjän sisäinen virhe.  Virheellinen osoite:"
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 msgid "invalid insn:"
 msgstr "virheellinen käsky:"
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 msgid "incorrect insn:"
 msgstr "virheellinen käsky:"
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 msgid "unknown move insn:"
 msgstr "tuntematon move-käsky:"
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 msgid "bad shift insn:"
 msgstr "virheellinen shift-käsky:"
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 #, fuzzy
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "kääntäjän sisäinen virhe.  Virheellinen osoite:"
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 #, fuzzy
 msgid "unsupported fixed-point conversion"
 msgstr "kiintopistevakiot ovat GCC-laajennos"
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 #, fuzzy
 msgid "variable"
 msgstr "Silmukkamuuttuja"
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 #, fuzzy
 msgid "function parameter"
 msgstr "parametri %q+D määritelty uudelleen"
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 #, fuzzy
 msgid "structure field"
 msgstr "struct määritelty täällä"
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 msgid "return type of function"
 msgstr "funktion paluutyyppi"
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 #, fuzzy
 msgid "pointer"
 msgstr "nollaosoitin"
@@ -20120,7 +20120,7 @@ msgstr "odottamaton siirros"
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -20475,51 +20475,51 @@ msgstr "fr30_print_operand: virheellinen %%F-koodi"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, fuzzy, c-format
 msgid "invalid operand code '%c'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, fuzzy, c-format
 msgid "invalid constraints for operand"
 msgstr "virheellinen lauseke kohdemuuttujana"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "Muotoillun tulosteen hallinta:"
 
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 #, fuzzy
 msgid "unknown insn mode"
 msgstr "tuntematon move-käsky:"
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 #, fuzzy
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 #, fuzzy
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 #, fuzzy
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 #, fuzzy
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
 msgstr ""
 
@@ -20553,7 +20553,7 @@ msgstr "Virheellinen operaatiokoodi"
 msgid "invalid %%P operand"
 msgstr "virheellinen %%P-operandi"
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, c-format
 msgid "invalid %%p value"
 msgstr "virheellinen %%p-arvo"
@@ -20581,29 +20581,29 @@ msgstr ""
 msgid "invalid addressing mode"
 msgstr "virheellinen %%G-tila"
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, fuzzy, c-format
 msgid "'%%%c' is not a valid operand prefix"
 msgstr "Nolla ei ole kelvollinen lausekenimiö kohdassa %C"
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "virheellinen ”%%%c”:n käyttö"
@@ -20639,7 +20639,7 @@ msgid "post-increment address is not a register"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 msgid "bad address"
 msgstr "virheellinen osoite"
 
@@ -20810,7 +20810,7 @@ msgstr "yritettiin käyttää ominaisuutta, jolle ei ole tukea: ”%s”"
 msgid "unsupported memory expression:"
 msgstr "kiintopistevakiot ovat GCC-laajennos"
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, fuzzy, c-format
 #| msgid "invalid %%r operand"
 msgid "invalid vector operand"
@@ -20866,255 +20866,255 @@ msgstr "valitsin --resource vaatii valitsimen -o"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "Tuota little-endian-koodia"
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 #, fuzzy
 msgid "bad move"
 msgstr "Siirrä alas"
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 #, fuzzy
 msgid "Bad 128-bit move"
 msgstr "Käytä 128-bittistä long double -tyyppiä"
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, fuzzy, c-format
 msgid "invalid %%A value"
 msgstr "virheellinen %%J-arvo"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%D value"
 msgstr "virheellinen %%D-arvo"
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, fuzzy, c-format
 msgid "invalid %%e value"
 msgstr "virheellinen %%E-arvo"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, c-format
 msgid "invalid %%f value"
 msgstr "virheellinen %%f-arvo"
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, c-format
 msgid "invalid %%F value"
 msgstr "virheellinen %%F-arvo"
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, c-format
 msgid "invalid %%G value"
 msgstr "virheellinen %%G-arvo"
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, c-format
 msgid "invalid %%j code"
 msgstr "virheellinen %%j-koodi"
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, c-format
 msgid "invalid %%J code"
 msgstr "virheellinen %%J-koodi"
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, c-format
 msgid "invalid %%k value"
 msgstr "virheellinen %%k-arvo"
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, c-format
 msgid "invalid %%K value"
 msgstr "virheellinen %%K-arvo"
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, c-format
 msgid "invalid %%O value"
 msgstr "virheellinen %%O-arvo"
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, c-format
 msgid "invalid %%q value"
 msgstr "virheellinen %%q-arvo"
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, fuzzy, c-format
 msgid "invalid %%t value"
 msgstr "virheellinen %%J-arvo"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, c-format
 msgid "invalid %%T value"
 msgstr "virheellinen %%T-arvo"
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, c-format
 msgid "invalid %%u value"
 msgstr "virheellinen %%u-arvo"
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, c-format
 msgid "invalid %%v value"
 msgstr "virheellinen %%v-arvo"
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, fuzzy, c-format
 msgid "invalid %%V value"
 msgstr "virheellinen %%J-arvo"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, c-format
 msgid "invalid %%x value"
 msgstr "virheellinen %%x-arvo"
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, fuzzy, c-format
 msgid "invalid %%z value"
 msgstr "virheellinen %%J-arvo"
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "virheellinen vektoripermutaatiovakio"
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 #, fuzzy
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-argumentti välitetty funktiolle, jolla ei ole prototyyppiä"
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Älä luo #line-direktiivejä"
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "%s: Tätä tiedostoa ei voitu varmuuskopioida"
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 #, fuzzy
 msgid "Bad GPR fusion"
 msgstr "Virheelliset merkit"
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 #, fuzzy
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 #, fuzzy
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 #, fuzzy
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 #, fuzzy
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "virheellinen muunnos gimple-kutsussa"
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, fuzzy, c-format
 msgid "cannot decompose address"
 msgstr "Pyydettyä osoitetta ei voi asettaa"
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, fuzzy, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 #, fuzzy
 msgid "vector argument passed to unprototyped function"
 msgstr "AltiVec-argumentti välitetty funktiolle, jolla ei ole prototyyppiä"
 
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 msgid "types differ in signedness"
 msgstr "tyypit eroavat etumerkillisyyden osalta"
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 #, fuzzy
 msgid "binary operator does not support two vector bool operands"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 #, fuzzy
 msgid "binary operator does not support vector bool operand"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 #, fuzzy
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "kohdemuoto ei tue äärettömyyttä"
@@ -21322,12 +21322,12 @@ msgstr "({nimetön})"
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "”)” oli odotus"
@@ -21340,7 +21340,7 @@ msgstr "”)” oli odotus"
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -21349,7 +21349,7 @@ msgstr "”)” oli odotus"
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "”)” oli odotus"
@@ -21357,7 +21357,7 @@ msgstr "”)” oli odotus"
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "”)” oli odotus"
@@ -21369,29 +21369,29 @@ msgstr "odotettiin %<,%>, %<;%> tai %<}%>"
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "”)” oli odotus"
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "”)” oli odotus"
@@ -21401,17 +21401,17 @@ msgstr "”)” oli odotus"
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -21420,8 +21420,8 @@ msgstr "odotettiin %<,%> tai %<;%>"
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "”)” oli odotus"
@@ -21432,17 +21432,17 @@ msgid "expected %<.%>"
 msgstr "”)” oli odotus"
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "odotettiin %<(%> tai rivin loppu"
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -21450,33 +21450,33 @@ msgstr "odotettiin %<,%> tai %<;%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "”)” oli odotus"
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<delete%>"
 msgid "expected %<else%>"
 msgstr "odotettiin %<delete%>"
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr ""
 
@@ -21484,7 +21484,7 @@ msgstr ""
 msgid "(anonymous)"
 msgstr "(nimetön)"
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "”)” oli odotus"
@@ -21500,22 +21500,22 @@ msgstr "odotettiin %<,%> tai %<;%>"
 msgid "candidate:"
 msgstr "ehdokas 1:"
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 #, fuzzy
 msgid "  after user-defined conversion:"
 msgstr "Ota käyttöön käyttäjän määrittelemät käskyt"
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "ehdokas on:"
 msgstr[1] "ehdokkaat ovat:"
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr "ehdokas 1:"
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr "ehdokas 2:"
 
@@ -21781,7 +21781,7 @@ msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 msgid "candidates are:"
 msgstr "ehdokkaat ovat:"
 
@@ -21834,52 +21834,52 @@ msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
 msgid "source type is not polymorphic"
 msgstr "lähde ei ole osoitin"
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "unaariselle miinus-operaatiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "unaariselle plus-operaatiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "bittikomplementille annettu väärä tyyppiargumentti"
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "abs-funktiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "konjugaatiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "unaariselle huutomerkille annettu väärä tyyppiargumentti"
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 #, fuzzy
 msgid "no pre-increment operator for type"
 msgstr "lisäykselle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 #, fuzzy
 msgid "no post-increment operator for type"
 msgstr "lisäykselle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 #, fuzzy
 msgid "no pre-decrement operator for type"
 msgstr "vähennykselle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 #, fuzzy
 msgid "no post-decrement operator for type"
 msgstr "vähennykselle annettu väärä tyyppiargumentti"
@@ -21967,7 +21967,7 @@ msgstr "Noudata ISO Fortran 2009 -standardia"
 msgid "Deleted feature:"
 msgstr "Poistettu ominaisuus:"
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 #, fuzzy
 msgid "array assignment"
 msgstr "virheellinen taulukkosijoitus"
@@ -22189,11 +22189,11 @@ msgstr "lohkolaite"
 msgid "implied END DO"
 msgstr "syötteen loppu"
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 msgid "assignment"
 msgstr "sijoitus"
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 #, fuzzy
 msgid "pointer assignment"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
@@ -22380,56 +22380,56 @@ msgstr "pilkkuoperaattori #if:in operandissa"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 msgid "Loop variable"
 msgstr "Silmukkamuuttuja"
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 #, fuzzy
 msgid "iterator variable"
 msgstr "Syntaksivirhe iteraattorissa kohdassa %C"
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 #, fuzzy
 msgid "Start expression in DO loop"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "Ennenaikainen säännöllisen lausekkeen loppu"
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 #, fuzzy
 msgid "Step expression in DO loop"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "EI OBJEKTIA\n"
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "EI OBJEKTIA\n"
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 #, fuzzy
 msgid "STAT variable"
 msgstr "tiedoston tilan lukeminen epäonnistui"
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "%qD ei ole muuttuja"
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 #, fuzzy
 msgid "item in READ"
 msgstr "Soita numero"
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "uutta arkistoa ei voi lukita"
@@ -22439,11 +22439,11 @@ msgstr "uutta arkistoa ei voi lukita"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "Odotettiin PARAMETER-symbolia kompleksivakiossa kohdassa %C"
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, fuzzy, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
@@ -22458,12 +22458,12 @@ msgstr "liikaa argumentteja funktiolle %s %q+#D"
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 #, fuzzy
 msgid "Assignment of scalar to unallocated array"
 msgstr "virheellinen taulukkosijoitus"
@@ -22473,82 +22473,82 @@ msgstr "virheellinen taulukkosijoitus"
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Erisuuret merkkipituudet (%ld/%ld) merkkijonossa %s kohdassa %L"
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, fuzzy, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "liian vähän (%d) argumentteja funktiolle ”%s”"
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, fuzzy, c-format
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "liian vähän (%d) argumentteja funktiolle ”%s”"
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, fuzzy, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 #, fuzzy
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, fuzzy, c-format
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "liian vähän (%d) argumentteja funktiolle ”%s”"
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, fuzzy, c-format
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "liian vähän (%d) argumentteja funktiolle ”%s”"
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, fuzzy, c-format
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "liian vähän (%d) argumentteja funktiolle ”%s”"
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
@@ -22573,16 +22573,16 @@ msgstr "ei-paikallinen nimiö "
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 #, fuzzy
 msgid "Loop variable has been modified"
 msgstr "Tiedostoa ”%s” on muokattu sen avaamisen jälkeen."
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 #, fuzzy
 msgid "DO step value is zero"
 msgstr "Odotettiin askelarvoa iteraattorissa kohdassa %C"
@@ -22664,7 +22664,7 @@ msgid "expected boolean type"
 msgstr "odotettiin totuusarvotyyppiä"
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "odotettiin kokonaislukua"
@@ -22735,7 +22735,7 @@ msgstr "liian vähän argumentteja"
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "liian monta argumenttia"
@@ -23412,7 +23412,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "Vain 1k-lohkot/vyöhykkeet ovat tuettuja"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Syntaksivirhe %s-lauseessa kohdassa %C"
@@ -23851,8 +23851,8 @@ msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
@@ -23869,7 +23869,7 @@ msgstr "%qE-attribuuttia ei huomioida %qE:lle"
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr "%qs-attribuuttidirektiivi jätetty huomiotta"
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, gcc-internal-format
 msgid "wrong number of arguments specified for %qE attribute"
 msgstr "attribuutille %qE annettu väärä määrä argumentteja"
@@ -23879,7 +23879,7 @@ msgstr "attribuutille %qE annettu väärä määrä argumentteja"
 msgid "expected %i or more, found %i"
 msgstr "odotettu vähintään %i, löytyi %i"
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %i or more, found %i"
 msgid "expected %i, found %i"
@@ -23947,12 +23947,12 @@ msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -23961,7 +23961,7 @@ msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -23983,8 +23983,8 @@ msgstr "%qE-attribuuttia ei huomioida"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "%qD:lle ei ole edellistä esittelyä"
@@ -24093,7 +24093,7 @@ msgstr "tiedoston ”%s” otsaketta ei voi lukea"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "siirros vakiomerkkijonon rajojen ulkopuolelle"
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE esitelty täällä"
@@ -24198,7 +24198,7 @@ msgstr "virheellinen argumentti 0 %qs:lle"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "epäkelpo argumentti funktiolle %<__builtin_frame_address%>"
@@ -24220,42 +24220,42 @@ msgstr "%<__builtin_longjmp%>-fuktion toisen argumentin pitää olla 1"
 msgid "target format does not support infinity"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, fuzzy, gcc-internal-format
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "funktiota %<va_start%> käytetty funktiossa, jolla on kiinteä määrä argumentteja"
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "väärä määrä argumentteja funktiolle %<va_start%>"
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%>-funktion toinen parametri ei ole viimeinen nimetty argumentti"
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, fuzzy, gcc-internal-format
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, fuzzy, gcc-internal-format
 msgid "last argument of %qD is not integer constant between 0 and 3"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
@@ -25300,12 +25300,12 @@ msgstr "%qs-attribuuttia ei huomioida %qs:lle"
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, fuzzy, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "nimike %q+D määritelty mutta käyttämättä"
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, fuzzy, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "sisäkkäinen funktio %q+D esitelty mutta ei koskaan määritelty"
@@ -25854,7 +25854,7 @@ msgstr "oikealle siirron lukumäärä on negatiivinen"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, fuzzy, gcc-internal-format
 msgid "%qs failed"
 msgstr "tiedoston %s avaaminen epäonnistui"
@@ -25884,19 +25884,19 @@ msgstr "Käänteinen jä_rjestys"
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, fuzzy, gcc-internal-format
 #| msgid "%Kcall to %qs declared with attribute error: %s"
 msgid "call to %qs declared with attribute error: %s"
 msgstr "%Kkutsu kohteeseen %qs esitelty attribuuttivirheellä: %s"
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, fuzzy, gcc-internal-format
 #| msgid "%Kcall to %qs declared with attribute warning: %s"
 msgid "call to %qs declared with attribute warning: %s"
 msgstr "%Kkutsu kohteeseen %qs esitelty attribuuttivaroituksella: %s"
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
 msgstr ""
@@ -25931,7 +25931,7 @@ msgstr "suuri kokonaisluku implisiittisesti katkaistu etumerkittömäksi tyypiks
 msgid "comparison is always %d due to width of bit-field"
 msgstr "vertailu on aina %d johtuen bittikentän leveydestä"
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -26094,7 +26094,7 @@ msgstr "nykyisen prosessin ryhmien noutaminen epäonnistui"
 msgid "%s signal terminated program %s"
 msgstr "%s-signaali päätti %s-ohjelman"
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, fuzzy, gcc-internal-format
 msgid "unrecognized command-line option %qs"
 msgstr "tuntematon komentorivivalitsin %qs"
@@ -26360,7 +26360,7 @@ msgstr "virheellinen tiedostonumero sarakemäärityksessä: %s"
 msgid "multilib exclusions %qs is invalid"
 msgstr "%qs-attribuutin virheellinen argumentti"
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, fuzzy, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "%qs-attribuutin virheellinen argumentti"
@@ -26662,22 +26662,22 @@ msgstr "%qE esitelty funktion palauttavana funktiona"
 msgid "%qD specified bound %E equals source length"
 msgstr "raja %3$E, jonka %1$G%2$qD määrittelee, on sama kuin lähteen pituus"
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr "joustava taulukkojäsen ei ole structin lopussa"
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr ""
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s not supported for variable length aggregates"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s not supported on this target"
 msgstr "%qs ei ole tuettu tällä kohteella"
@@ -26718,16 +26718,16 @@ msgid "function returns address of local variable"
 msgstr "funktio palauttaa osoitteen paikalliseen muuttujaan"
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, gcc-internal-format
@@ -26739,369 +26739,369 @@ msgstr "esitelty täällä"
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr "%<nonnull%>-argumenttia %qD verrataan NULLiin"
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr "%qE saattaa kirjoittaa päättävän nul-tavun kohteen lopun yli"
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr "%qE kirjoittaa päättävän nul-tavun kohteen lopun yli"
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] "%<%.*s%>-direktiivi kirjoittaa %wu tavun %wu tavun kokoiseen alueeseen"
 msgstr[1] "%<%.*s%>-direktiivi kirjoittaa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] "%<%.*s%>-direktiivin tuloste saattaa katketa kirjoittaessa %wu tavu %wu tavun kokoiseen alueeseen"
 msgstr[1] "%<%.*s%>-direktiivin tuloste saattaa katketa kirjoittaessa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] "%<%.*s%>-direktiivin tuloste katkeaa kirjoittaessa %wu tavu %wu tavun kokoiseen alueeseen"
 msgstr[1] "%<%.*s%>-direktiivin tuloste katkeaa kirjoittaessa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr "%<%.*s%>-direktiivin tuloste saattaa katketa kirjoittaessa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr "%<%.*s%>-direktiivin tuloste katkeaa kirjoitettaessa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "%<%.*s%>-direktiivin tuloste saattaa katketa kirjoittaessa kaiketi ainakin %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "%<%.*s%>-direktiivin tuloste katkeaa kirjoittaessa kaiketi ainakin %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr "%<%.*s%>-direktiivi kirjoittanee ainakin %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "%<%.*s%>-direktiivin tuloste saattaa katketa kirjoittaessa %wu–%wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "%<%.*s%>-direktiivin katkeaa kirjoittaessa %wu–%wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr "%<%.*s%>-direktiivi kirjoittaa %wu–%wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr "%<%.*s%>-direktiivin tuloste saattaa katketa kirjoittaessa ainakin %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr "%<%.*s%>-direktiivin katkeaa kirjoittaessa ainakin %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr "%<%.*s%>-direktiivi kirjoittaa vähintään %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] "%<%.*s%>-direktiivi kirjoittaa %wu tavun %wu–%wu tavun kokoiseen alueeseen"
 msgstr[1] "%<%.*s%>-direktiivi kirjoittaa %wu tavua %wu–%wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] "%<%.*s%>-direktiivin tuloste saattaa katketa kirjoittaessa %wu tavu %wu–%wu tavun kokoiseen alueeseen"
 msgstr[1] "%<%.*s%>-direktiivin tuloste saattaa katketa kirjoittaessa %wu tavua %wu–%wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] "%<%.*s%>-direktiivin katkeaa kirjoittaessa %wu tavu %wu–%wu tavun kokoiseen alueeseen"
 msgstr[1] "%<%.*s%>-direktiivin katkeaa kirjoittaessa %wu tavua %wu–%wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-direktiivin tuloste saattaa katketa kirjoittaessa jopa %wu tavua %wu–%wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-direktiivin tuloste katkeaa kirjoittaessa jopa %wu tavua %wu–%wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu–%wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-direktiivin tuloste saattaa katketa kirjoittaessa kaiketi ainakin %wu tavua %wu–%wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-direktiivin tuloste katkeaa kirjoittaessa kaiketi ainakin %wu tavua %wu–%wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-direktiivi kirjoittanee ainakin %wu tavua %wu–%wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-direktiivin tuloste saattaa katketa kirjoittaessa %wu–%wu tavua %wu–%wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-direktiivin tuloste katkeaa kirjoittaessa %wu–%wu tavua %wu–%wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-direktiivi kirjoittaa %wu–%wu tavua %wu–%wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-direktiivin tuloste saattaa katketa kirjoittaessa ainakin %wu tavua %wu–%wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-direktiivin tuloste katkeaa kirjoittaessa ainakin %wu tavua %wu–%wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-direktiivi kirjoittaa ainakin %wu tavua %wu–%wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, fuzzy, gcc-internal-format
 #| msgid "%G%<%.*s%> directive argument is null"
 msgid "%<%.*s%> directive argument is null"
 msgstr "%G%<%.*s%>-direktiivin argumentti on null"
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr "%<%.*s%>-direktiivin %wu tavun tuloste ylittää vaaditun vähimmäiskoon 4095"
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr "%<%.*s%>-direktiivin %wu–%wu tavun tuloste ylittää vaaditun vähimmäiskoon 4095"
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr "%<%.*s%>-direktiivin %wu–%wu tavun tuloste saattaa ylittää vaaditun vähimmäiskoon 4095"
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, fuzzy, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, fuzzy, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, fuzzy, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, fuzzy, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, fuzzy, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr "%<%.*s%>-direktiivi kirjoittaa jopa %wu tavua %wu tavun kokoiseen alueeseen"
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr "%<%.*s%>-direktiivin argumentti ei ole nul-päätteinen merkkijono"
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, fuzzy, gcc-internal-format
 msgid "referenced argument declared here"
 msgstr "%qD esitelty ei-parametrina"
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] "oletetaan direktiivin tuotos %wu-tavuiseksi"
 msgstr[1] "oletetaan direktiivin tuotos %wu-tavuiseksi"
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, fuzzy, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr "direktiivin argumentti välillä [%E, %E]"
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr "käytetään väliä [%E, %E] direktiivin argumentille"
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgid_plural "%qE output %wu bytes into a destination of size %wu"
 msgstr[0] "%qE tulosti %wu tavun %wu tavun kokoiseen kohteeseen"
 msgstr[1] "%qE tulosti %wu tavua %wu tavun kokoiseen kohteeseen"
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr "%qE tulosti %wu–%wu tavua %wu tavun kokoiseen kohteeseen"
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr "%qE tulosti vähintään %wu tavua (oletetaan %wu) %wu tavun kokoiseen kohteeseen"
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr "%qE tulosti ainakin %wu tavua %wu tavun kokoiseen kohteeseen"
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
 msgstr[0] "%qE tulosti %wu tavun"
 msgstr[1] "%qE tulosti %wu tavua"
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes"
 msgstr "%qE tulosti %wu–%wu tavua"
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr "%qE tulosti ainakin %wu tavua (oletetaan %wu)"
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes"
 msgstr "%qE tulosti ainakin %wu tavua"
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr "%<%.*s%>-direktiivin leveys sallitun välin ulkopuolella"
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr "%<%.*s%>-direktiivin tarkkuus sallitun välin ulkopuolella"
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 #, fuzzy
 msgid "%qE argument %Z overlaps destination object %qE"
 msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] "%qE esitelty funktion palauttavana funktiona"
 msgstr[1] "%qE esitelty funktion palauttavana funktiona"
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 #, fuzzy
 msgid "%qE argument %Z may overlap destination object %qE"
 msgid_plural "%qE arguments %Z may overlap destination object %qE"
 msgstr[0] "%qE tulosti %wu tavun %wu tavun kokoiseen kohteeseen"
 msgstr[1] "%qE tulosti %wu tavua %wu tavun kokoiseen kohteeseen"
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr "määritelty raja %wu ylittää olion enimmäiskoon %wu"
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr "määritelty raja %wu ylittää %<INT_MAX%>:in"
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, fuzzy, gcc-internal-format
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, fuzzy, gcc-internal-format
 msgid "null destination pointer"
 msgstr "nollaosoitin"
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, fuzzy, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, fuzzy, gcc-internal-format
 msgid "null format string"
 msgstr "%s muotoilumerkkijonossa kohdassa %L"
@@ -27845,12 +27845,12 @@ msgstr "epäkelpo osoitintila %qs"
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD esitelty täällä"
@@ -28615,7 +28615,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
@@ -28959,17 +28959,17 @@ msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 msgid "mismatching definition"
 msgstr "puuttuva määrittely"
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, fuzzy, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr "virheellinen muunnos gimple-kutsussa"
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, gcc-internal-format
 msgid "IPA modref summary is missing in input file"
 msgstr ""
@@ -30036,72 +30036,72 @@ msgstr "%s: Virhe kirjoitettaessa %s\n"
 msgid "error closing optimization records %qs"
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, fuzzy, gcc-internal-format
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "komentorivivalitsin %qs on kelvollinen kohteelle %s, mutta ei kohteelle %s"
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "polku puuttuu %qs:n jälkeen"
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr "%q+D:n ensimmäisen argumentin pitäisi olla %<int%>"
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer"
 msgstr "%q+D:n ensimmäisen argumentin pitäisi olla %<int%>"
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is not between %d and %d"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, fuzzy, gcc-internal-format
 msgid "invalid argument in option %qs"
 msgstr "argumentti %qd ei ole vakio"
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, fuzzy, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, fuzzy, gcc-internal-format
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr "valitsimia -mcorea ja -mcoreb ei voi käyttää yhdessä"
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument in option %qs"
 msgstr "tuntematon komentorivivalitsin %qs"
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is bigger than %d"
 msgstr "%Jei voi asettaa %qE-attribuuttia määrittelyn jälkeen"
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, fuzzy, gcc-internal-format
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
 msgstr "vääränmuotoinen COLLECT_GCC_OPTIONS"
@@ -30175,8 +30175,8 @@ msgstr "%q+D:n ensimmäisen argumentin pitäisi olla %<int%>"
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with %qs"
 msgstr "Muodostin %qs"
@@ -30884,7 +30884,7 @@ msgstr "sisäkkäisessä funktiossa käytetty globaalia rekisterimuuttujaa %qD"
 msgid "register of %qD used for multiple global register variables"
 msgstr "sisäkkäisessä funktiossa käytetty globaalia rekisterimuuttujaa %qD"
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "nimellä %qD"
@@ -31335,42 +31335,42 @@ msgstr ""
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, fuzzy, gcc-internal-format
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "%qs ei ole tuettu tällä kohteella"
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, fuzzy, gcc-internal-format
 msgid "nested functions not supported on this target"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, fuzzy, gcc-internal-format
 msgid "nested function trampolines not supported on this target"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, fuzzy, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, fuzzy, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, fuzzy, gcc-internal-format
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, fuzzy, gcc-internal-format
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC target%> is not supported for this machine"
 msgstr "#pragma extern_prefix ei ole tuettu tällä kohteella"
@@ -32498,82 +32498,82 @@ msgstr "nimettömällä kentällä on vaillinainen tyyppi"
 msgid "BB %i has incorrect fallthru edge"
 msgstr "nimettömällä kentällä on vaillinainen tyyppi"
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr "funktiota %q+F ei voi koskaan kopioida, koska se vastaanottaa ei-paikallisen goto-käskyn"
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr "funktiota %q+F ei voi koskaan kopioida, koska se tallentaa paikallisen nimiön osoitteen staattiseen muuttujaan"
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, fuzzy, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr "%Jfunktio %qF ei voi koskaan olla avoin, koska se käyttää avoimille funktioille sopimattomia attribuutteja"
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, fuzzy, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr "%Jfunktio %qF ei voi koskaan olla avoin, koska ne on poistettu käytöstä -fno-inline:lla"
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, fuzzy, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr "%Jfunktio %qF ei voi koskaan olla avoin, koska se käyttää avoimille funktioille sopimattomia attribuutteja"
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, fuzzy, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr "%Jfunktio %qF ei voi koskaan olla avoin, koska se käyttää avoimille funktioille sopimattomia attribuutteja"
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, fuzzy, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr "funktiota %q+F ei voi koskaan kopioida, koska se vastaanottaa ei-paikallisen goto-käskyn"
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, fuzzy, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr "%Jfunktio %qF ei voi koskaan olla avoin, koska se käyttää avoimille funktioille sopimattomia attribuutteja"
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, fuzzy, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr "%Jfunktio %qF ei voi koskaan olla avoin, koska ne on poistettu käytöstä -fno-inline:lla"
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, fuzzy, gcc-internal-format
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr "%Jfunktio %qF ei voi koskaan olla avoin, koska se käyttää avoimille funktioille sopimattomia attribuutteja"
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, fuzzy, gcc-internal-format
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr "%Jfunktio %qF ei voi koskaan olla avoin, koska ne on poistettu käytöstä -fno-inline:lla"
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, fuzzy, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr "%Jfunktio %qF ei voi koskaan olla avoin, koska se käyttää avoimille funktioille sopimattomia attribuutteja"
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, fuzzy, gcc-internal-format
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr "%J%qD esitelty turhaan uudestaan"
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr "kutsuttu täältä"
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, fuzzy, gcc-internal-format
 msgid "called from this function"
 msgstr "kutsuttu täältä"
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, fuzzy, gcc-internal-format
 msgid "inlining failed in call to %q+F: %s"
 msgstr "%J%qD esitelty turhaan uudestaan"
@@ -32628,27 +32628,27 @@ msgstr "epäkelpo alkiotyyppi attribuutille %qs"
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, fuzzy, gcc-internal-format
 msgid "in a call to non-static member function %qD"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, fuzzy, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "Virheellinen vähimmäisargumenttimäärä (%d) funktiolle %s"
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, fuzzy, gcc-internal-format
 msgid "in a call to function %qD declared %qs"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
@@ -32853,7 +32853,7 @@ msgstr "%qE:a ei ole alustettu"
 msgid "%qs may be used uninitialized"
 msgstr "%qD saattaa tulla käytetyksi alustamattomana tässä funktiossa"
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD esiteltiin täällä"
@@ -33084,7 +33084,7 @@ msgstr ""
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -33099,126 +33099,126 @@ msgstr "alustusalkio ei ole vakio"
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr "alustusalkio ei ole vakio"
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, fuzzy, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "------ Semaforitaulukot --------\n"
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, fuzzy, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, fuzzy, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, fuzzy, gcc-internal-format
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, fuzzy, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, fuzzy, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, fuzzy, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, fuzzy, gcc-internal-format
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD on vanhentunut: %s"
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD on vanhentunut"
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE on vanhentunut: %s"
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE on vanhentunut"
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "tyyppi on vanhentunut: %s"
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "tyyppi on vanhentunut"
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is unavailable: %s"
 msgstr "%qD ei ole muuttuja"
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is unavailable"
 msgstr "%qD ei ole muuttuja"
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qE is unavailable: %s"
 msgstr "%qD ei ole muuttuja"
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qE is unavailable"
 msgstr "%qD ei ole muuttuja"
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type is unavailable: %s"
 msgstr "tiedoston %s avaaminen epäonnistui"
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "type is unavailable"
@@ -33244,262 +33244,262 @@ msgstr "%qD ei ole muuttuja"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr "Tiedoston tyyppi eroaa"
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, fuzzy, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr "tyypillä %qT ei ole tunnettua kokoa"
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, fuzzy, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr "tyypillä %qT ei ole tunnettua kokoa"
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, fuzzy, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr "tyypillä %qT ei ole tunnettua kokoa"
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, fuzzy, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr "taulukon tyypillä on vaillinainen alkiotyyppi"
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, fuzzy, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr "taulukon tyypillä on vaillinainen alkiotyyppi"
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, fuzzy, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, fuzzy, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, fuzzy, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, fuzzy, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr "taulukon tyypillä on vaillinainen alkiotyyppi"
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, fuzzy, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, fuzzy, gcc-internal-format
 msgid "and field"
 msgstr "kentän leveys"
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, fuzzy, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, fuzzy, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, fuzzy, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, fuzzy, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type %s is not an opaque type"
 msgstr "%qT ei ole malli"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type %s is not with opaque mode"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, fuzzy, gcc-internal-format
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, fuzzy, gcc-internal-format
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr "tyypillä %qT ei ole tunnettua kokoa"
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, fuzzy, gcc-internal-format
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, fuzzy, gcc-internal-format
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr "tyypillä %qT ei ole tunnettua kokoa"
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, fuzzy, gcc-internal-format
 msgid "main variant is not defined"
 msgstr "”%s” on määrittelemättä"
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr "tyyppitäsmäämättömyys komponenttiviitteessä"
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr "tyyppitäsmäämättömyys komponenttiviitteessä"
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr "ei voi muuntaa osoitintyypiksi"
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr "tyyppitäsmäämättömyys komponenttiviitteessä"
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr "tyyppitäsmäämättömyys komponenttiviitteessä"
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr "tyyppitäsmäämättömyys komponenttiviitteessä"
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr "taulukon %qE koko ei ole kokonaislukutyyppiä"
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr "NULLin muunnos epäosoitintyypiksi"
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr "NULLin muunnos epäosoitintyypiksi"
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, fuzzy, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "taulukkoindeksi alustimessa ei ole kokonaislukutyyppinen"
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr "NULLin muunnos epäosoitintyypiksi"
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
@@ -33715,7 +33715,7 @@ msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr ""
@@ -33920,7 +33920,7 @@ msgstr "%qE-attribuuttia ei huomioida koska %qT on jo määritelty"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "%qE-attribuuttia ei huomioida koska %qT on jo määritelty"
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE-attribuutti vaikuttaa vain julkisiin objekteihin"
@@ -34103,7 +34103,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be specified for local variables"
 msgstr "osoitealueattribuuttia ei voi määritellä paikallisille muuttujille"
@@ -34418,7 +34418,7 @@ msgstr "%qD ei ole %qD:n jäsen"
 msgid "%qE argument is not a function"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, fuzzy, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
@@ -34926,7 +34926,7 @@ msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktioiden ulkopuolella
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktioiden ulkopuolella"
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, gcc-internal-format
 msgid "invalid application of %qs to a void type"
 msgstr "epäkelpo %qs:n soveltaminen tyhjään tyyppiin"
@@ -35057,17 +35057,17 @@ msgstr "oletusargumentti määritelty lambda-parametrille"
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "liian vähän argumentteja funktiolle %qE"
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, gcc-internal-format
@@ -35191,166 +35191,166 @@ msgstr "bittikenttätietueen jäsenestä %qs yritettiin ottaa osoite"
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "taulukon koko on liian suuri"
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, fuzzy, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, fuzzy, gcc-internal-format
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "argumentin %d antaminen funktiolle %qE tekee kokonaisluvusta osoittimen ilman tyyppimuunnosta"
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, fuzzy, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr "argumentin <%s>:lle on oltava yksittäinen merkki"
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "liian monta argumenttia funktiolle %qE"
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "annettu yhteensopimatonta osoitintyyppiä oleva %d. argumentti funktiolle %qE"
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "annettu yhteensopimatonta osoitintyyppiä oleva %d. argumentti funktiolle %qE"
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, fuzzy, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr "%d. argumentti funktiolle %qE hylkää kohdeosoitintyypin %qv-määritteen"
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr "%d. argumentti funktiolle %qE hylkää kohdeosoitintyypin %qv-määritteen"
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, fuzzy, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, fuzzy, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "Arvo sallitun välin ulkopuolella."
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, fuzzy, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, fuzzy, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr "taulukon %qE koko on negatiivinen"
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array is negative"
 msgstr "taulukon koko on negatiivinen"
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr "paikallisten objektien kokonaiskoko on liian suuri"
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr "paikallisten objektien kokonaiskoko on liian suuri"
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "paikallisten objektien kokonaiskoko on liian suuri"
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, fuzzy, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr "paikallisten objektien kokonaiskoko on liian suuri"
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -35989,7 +35989,7 @@ msgstr "kokonaislukuvakio on liian suuri tyypilleen"
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr "kokonaislukuvakio on liian suuri tyypilleen"
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, fuzzy, gcc-internal-format
 msgid "%<_BitInt(%d)%> is not supported on this target"
 msgstr "kohteen int-tyyppi on kapeampi kuin kohteen char-tyyppi"
@@ -36069,7 +36069,7 @@ msgstr "virheellinen loppuliite ”%.*s” liukulukuvakiolla"
 msgid "traditional C rejects string constant concatenation"
 msgstr "perinteinen C ei salli merkkijonovakioiden katenointia"
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -36124,7 +36124,7 @@ msgstr "%<void%> vain parametrina ei ole oikeutettu"
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
@@ -36139,17 +36139,17 @@ msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 msgid "%qE is not initialized"
 msgstr "%qE:a ei ole alustettu"
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "’(’ puuttuu predikaatin jäljestä"
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Muotoillun tulosteen hallinta:"
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "puuttuva kasvatuslauseke"
@@ -36159,7 +36159,7 @@ msgstr "puuttuva kasvatuslauseke"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "virheellinen kasvatuslauseke"
@@ -36246,7 +36246,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -36256,7 +36256,7 @@ msgstr ""
 msgid "%qD is not a function argument"
 msgstr "%qD ei ole funktioargumentti"
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
@@ -36850,7 +36850,7 @@ msgid "wrong type argument to %s"
 msgstr "abs-funktiolle annettu väärä tyyppiargumentti"
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -37782,35 +37782,35 @@ msgstr "tyyppien %qT ja %qT välinen vertailu"
 
 #: c-family/c-warn.cc:3832
 #, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3836
+#: c-family/c-warn.cc:3839
 #, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr ""
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr ""
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr ""
@@ -38020,117 +38020,117 @@ msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr "%s %qs"
 
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr "%s %qs"
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr "luokkanimeä ei ole annettu %qs:n kanssa"
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr "%s %qs"
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr "Älä varoita Microsoft-laajennosten käytöstä"
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "%s %qs"
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr "%s %qs"
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr "%s %qs"
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, fuzzy, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "%<%s%> on tuntematon"
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr ""
@@ -38529,12 +38529,12 @@ msgstr "odotettiin 64-bittistä osoitetta, mutta argumentti 1 on %d-bittinen"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "odotettiin 64-bittistä osoitetta, mutta argumentti 2 on %d-bittinen"
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC optimize%> ei ole merkkijono eikä luku"
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, fuzzy, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "tuntematon #pragma GCC coprocessor %E"
@@ -39139,7 +39139,7 @@ msgstr ""
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
@@ -39219,12 +39219,12 @@ msgid "unknown tuning option (%s)"
 msgstr "tuntematon valitsin -%s"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
@@ -39235,7 +39235,7 @@ msgid "specify a system register with a small string length"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "Funktio %qs"
@@ -39415,9 +39415,9 @@ msgstr "%s ei tue muotoilua %<%%%s%c%> %s"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "kohde ”%s” ei täsmää kohdehahmon kanssa"
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
@@ -39469,18 +39469,18 @@ msgid "virtual function multiversioning not supported"
 msgstr "Varoita ylikuormitetuista virtuaalifunktioiden nimistä"
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
@@ -39493,8 +39493,8 @@ msgstr ""
 msgid "lane %wd out of range %wd - %wd"
 msgstr "operandinumero on arvoalueen ulkopuolella muotoilussa"
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, fuzzy, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "tuntematon värimoodi"
@@ -39504,7 +39504,7 @@ msgstr "tuntematon värimoodi"
 msgid "GCC does not currently support return type %qT for simd"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
@@ -39514,7 +39514,7 @@ msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
@@ -39604,8 +39604,8 @@ msgstr ""
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, fuzzy, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr "<sisäänrakennettu>"
@@ -39725,18 +39725,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -39850,7 +39850,7 @@ msgid "argument of %qE attribute is missing"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
@@ -39870,23 +39870,23 @@ msgstr "%qE-attribuutti pätee vain funktiotyyppeihin"
 msgid "argument of %qE attribute ignored"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, fuzzy, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, fuzzy, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr "Funktio %qs"
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, fuzzy, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
@@ -40133,7 +40133,7 @@ msgstr "AAPCS ei tue valitsinta -mcaller-super-interworking"
 msgid "target CPU does not support unaligned accesses"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, fuzzy, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr "kohdemuoto ei tue äärettömyyttä"
@@ -40183,7 +40183,7 @@ msgstr ""
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "Muodostin %qs"
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
@@ -40289,7 +40289,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -40329,42 +40329,42 @@ msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qE-attribuutti pätee vain funktiotyyppeihin"
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, fuzzy, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "operandinumero on arvoalueen ulkopuolella muotoilussa"
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "%qs attribuuttia ei huomioida"
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, fuzzy, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "epäkelpo vektorityyppi attribuutille %qs"
@@ -40372,22 +40372,22 @@ msgstr "epäkelpo vektorityyppi attribuutille %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, fuzzy, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "epäkelpo vektorityyppi attribuutille %qE"
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, fuzzy, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "<tuntematon>"
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
@@ -40441,158 +40441,158 @@ msgstr "muunnos ”%s” <-> ”%s” ei ole tuettu"
 msgid "unknown core architecture %qs specified with %qs"
 msgstr "Funktio %qs:"
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, gcc-internal-format
 msgid "%<-fpic%> is not supported"
 msgstr "%<-fPIC%> ei ole tuettu"
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, gcc-internal-format
 msgid "%<-fPIC%> is not supported"
 msgstr "%<-fPIC%> ei ole tuettu"
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, gcc-internal-format
 msgid "%<-fpie%> is not supported"
 msgstr "%<-fpie%> ei ole tuettu"
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, gcc-internal-format
 msgid "%<-fPIE%> is not supported"
 msgstr "%<-fPIE%> ei ole tuettu"
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "valitsimet %s ja %s ovat toisensa poissulkevat"
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, gcc-internal-format
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr ""
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, gcc-internal-format
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr ""
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, fuzzy, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "%J%qD:n esittely varjostaa parametria"
 
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "%qE-attribuutti soveltuu vain muuttujiin ja funktioihin"
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, fuzzy, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr "%qE-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "%qE-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, fuzzy, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, fuzzy, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, fuzzy, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, fuzzy, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr "muuttuvakokoista objektia %qD ei voi alustaa"
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, fuzzy, gcc-internal-format
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr "%J%qD:n esittely varjostaa parametria"
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, fuzzy, gcc-internal-format
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr "muuttujalla %qD on alustin, mutta vaillinainen tyyppi"
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "muuttujalla %qD on alustin, mutta vaillinainen tyyppi"
@@ -40601,42 +40601,42 @@ msgstr "muuttujalla %qD on alustin, mutta vaillinainen tyyppi"
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr "muuttuvakokoista objektia %qD ei voi alustaa"
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%q+D:n määritteet %qs ja %qs ovat yhteensopimattomat"
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, fuzzy, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr "muunnos merkistöstä ”%s” ei ole tuettu"
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, fuzzy, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "%s odottaa käännösaikaista kokonaislukuvakiota"
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%qs odottaa vakioargumenttia"
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr "pyöristystulos on aina 0"
@@ -40773,7 +40773,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, fuzzy, gcc-internal-format
@@ -41400,8 +41400,8 @@ msgstr "puhdistusargumentti ei ole tunniste"
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
@@ -41469,255 +41469,255 @@ msgstr "epäkelpo osoitintila %qs"
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "Tuntematon argumenttiluettelofunktio kohdassa %L"
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, fuzzy, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, fuzzy, gcc-internal-format
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, fuzzy, gcc-internal-format
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, fuzzy, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, fuzzy, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "__COUNTER__ lavennettu direktiivin sisällä valitsimella -fdirectives-only"
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, fuzzy, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, fuzzy, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, fuzzy, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, fuzzy, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr ""
@@ -41725,290 +41725,290 @@ msgstr ""
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr ""
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, fuzzy, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE-käskykanta poistettu käytöstä, käytetään 387-aritmetiikkaa"
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387-käskykanta poistettu käytöstä, käytetään SSE-aritmetiikkaa"
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, fuzzy, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "”%s”-liitännäinen on yhteensopiva."
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "tuntematon valitsin -%s"
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "”%s” ei ole kelvollinen esikääntäjän valitsin"
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "”%s” ei ole kelvollinen esikääntäjän valitsin"
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "”%s” ei ole kelvollinen esikääntäjän valitsin"
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr ""
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, fuzzy, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, fuzzy, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "attribuutit stdcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, fuzzy, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, fuzzy, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, fuzzy, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, fuzzy, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, fuzzy, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE-attribuutti tarvitsee kokonaislukuvakioargumentin"
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%Jei voi asettaa %qE-attribuuttia määrittelyn jälkeen"
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "attribuutit stdcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "attribuutit stdcall ja fastcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
@@ -42199,46 +42199,46 @@ msgstr "fr30_print_operand: tuntematon koodi"
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, fuzzy, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, gcc-internal-format
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr ""
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, fuzzy, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "valitsin -mmultiple ei ole tuettu little-endian-järjestelmissä"
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr ""
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "Tuntematon arkkitehtuuri ”%s”"
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, fuzzy, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
@@ -42260,8 +42260,8 @@ msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 msgid "malformed %<#pragma builtin%>"
 msgstr "vääränmuotoinen #pragma builtin"
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, fuzzy, gcc-internal-format
 msgid "invalid argument of %qE attribute"
 msgstr "%qs-attribuutin virheellinen argumentti"
@@ -42319,12 +42319,12 @@ msgstr "Tuntematon tiheys: ”%c”"
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr "PRINT_OPERAND nollaosoitin"
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, fuzzy, gcc-internal-format
 msgid "failed to expand built-in function"
 msgstr "virheellinen sisäinen makro ”%s”"
@@ -42450,17 +42450,17 @@ msgstr "%qD ei ole %qD:n jäsen"
 msgid "%qs cannot be used for compiling a shared library"
 msgstr "%Hprototyypin esittely"
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr "osoitealueattribuuttia ei voi määritellä paikallisille muuttujille"
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be specified for register variables"
 msgstr "osoitealueattribuuttia ei voi määritellä paikallisille muuttujille"
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, fuzzy, gcc-internal-format
 msgid "multiple %qE attribute"
 msgstr "Kaksoiskappele %s attribuutti kohdassa %L"
@@ -42563,12 +42563,12 @@ msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, fuzzy, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "dwarfin versio %d ei ole tuettu"
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, fuzzy, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not supported on this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
@@ -42609,7 +42609,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr ""
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
@@ -42649,132 +42649,132 @@ msgstr ""
 msgid "argument to %qE attribute is not intstack"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, fuzzy, gcc-internal-format
 msgid "cannot handle inconsistent calls to %qs"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr ""
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr ""
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE not supported for MIPS16"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, fuzzy, gcc-internal-format
 msgid "%qs does not support MIPS16 code"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr ""
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, fuzzy, gcc-internal-format
 msgid "MIPS16 %<-mxgot%> code"
 msgstr "Tuota MIPS16-koodia"
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, gcc-internal-format
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr ""
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, fuzzy, gcc-internal-format
 msgid "MSA MIPS16 code"
 msgstr "Tuota MIPS16-koodia"
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, gcc-internal-format
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr ""
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported combination: %s"
 msgstr "yritettiin käyttää ominaisuutta, jolle ei ole tukea: ”%s”"
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, gcc-internal-format
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr ""
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr "%s %qs"
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, fuzzy, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr "Käytä 32-bittistä ABIa"
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, fuzzy, gcc-internal-format
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, fuzzy, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr "Käytä 32-bittistä ABIa"
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "%s ei tue pituusmäärettä %qs %s"
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, fuzzy, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr "Valitsinta --acls voi käyttää vain POSIX-arkistoille"
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, fuzzy, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr "Valitsinta --acls voi käyttää vain POSIX-arkistoille"
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, fuzzy, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr "Valitsinta --acls voi käyttää vain POSIX-arkistoille"
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, fuzzy, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr "-m64 vaatii PowerPC64-suorittimen"
@@ -42784,117 +42784,117 @@ msgstr "-m64 vaatii PowerPC64-suorittimen"
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, fuzzy, gcc-internal-format
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr "Jäsenfunktio %qs"
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, fuzzy, gcc-internal-format
 msgid "unsupported combination: %qs%s %s"
 msgstr "yritettiin käyttää ominaisuutta, jolle ei ole tukea: ”%s”"
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, fuzzy, gcc-internal-format
 msgid "unsupported combination: %qs %s"
 msgstr "yritettiin käyttää ominaisuutta, jolle ei ole tukea: ”%s”"
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, fuzzy, gcc-internal-format
 msgid "cannot generate position-independent code for %qs"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, fuzzy, gcc-internal-format
 msgid "position-independent code requires %qs"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr ""
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, fuzzy, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, fuzzy, gcc-internal-format
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr "-m64 vaatii PowerPC64-suorittimen"
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, fuzzy, gcc-internal-format
 msgid "%qs must be used with %qs"
 msgstr "Muodostin %qs"
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, fuzzy, gcc-internal-format
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr "-Wformat-y2k jätetty huomiotta ilman valitsinta -Wformat"
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, fuzzy, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr "Käytä AltiVec-käskyjä"
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support DSP instructions"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, fuzzy, gcc-internal-format
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr "-Wformat-y2k jätetty huomiotta ilman valitsinta -Wformat"
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, fuzzy, gcc-internal-format
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr "-Wformat-y2k jätetty huomiotta ilman valitsinta -Wformat"
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, fuzzy, gcc-internal-format
 msgid "%qs requires branch-likely instructions"
 msgstr "Käytä AltiVec-käskyjä"
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support the synci instruction"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, fuzzy, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr "Ota käyttöön funktioprofilointi"
@@ -43767,57 +43767,57 @@ msgstr "%<#pragma GCC optimize%> ei ole merkkijono eikä luku"
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "tuntematon #pragma GCC coprocessor %E"
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, gcc-internal-format
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, gcc-internal-format
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, fuzzy, gcc-internal-format
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> attribute"
 msgstr "Väärin muotoiltu kohdekohtainen muuttujamäärittely"
 
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, fuzzy, gcc-internal-format
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> attribute"
 msgstr "Väärin muotoiltu kohdekohtainen muuttujamäärittely"
@@ -43880,173 +43880,193 @@ msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 msgid "capture by copy of RVV type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, fuzzy, gcc-internal-format
 msgid "no matching function call to %qE with empty arguments"
 msgstr "päättämätön kutsu funktioon ”%s”: puuttuva ”%c”"
 
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, fuzzy, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "tuntematon cc_attr-arvo"
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, fuzzy, gcc-internal-format
 msgid "this operation requires the RVV ISA extension"
 msgstr "Älä varoita Microsoft-laajennosten käytöstä"
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, fuzzy, gcc-internal-format
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr "AltiVec-argumentti välitetty funktiolle, jolla ei ole prototyyppiä"
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the V ISA extension"
 msgstr "Käytä 64-bittistä ABIa"
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr "Käytä 64-bittistä ABIa"
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr "Käytä 64-bittistä ABIa"
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr "Käytä 64-bittistä ABIa"
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr "Käytä 64-bittistä ABIa"
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr ""
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, fuzzy, gcc-internal-format
 msgid "function attribute %qs requires the V ISA extension"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr ""
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, fuzzy, gcc-internal-format
 msgid "%qs applied to non-RVV type %qT"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires an integer constant argument"
 msgid "%qs requires an integer constant"
 msgstr "%qE-attribuutti tarvitsee kokonaislukuvakioargumentin"
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, fuzzy, gcc-internal-format
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, fuzzy, gcc-internal-format
 msgid "code model %qs with %qs"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, gcc-internal-format
 msgid "rv64e requires lp64e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr ""
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, fuzzy, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "-mvsx ja -mpaired ovat yhteensopimattomat"
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "luokkanimeä ei ole annettu %qs:n kanssa"
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "Funktio %qs"
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr ""
@@ -44297,33 +44317,33 @@ msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr "%d. argumentti funktiolle %qE hylkää kohdeosoitintyypin %qv-määritteen"
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "virheellinen parametri %qs"
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, fuzzy, gcc-internal-format
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
@@ -44363,30 +44383,22 @@ msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, fuzzy, gcc-internal-format
-#| msgid "Use the ELFv2 ABI."
-msgid "%qs requires the ELFv2 ABI"
-msgstr "Käytä ELFv2-ABIa."
-
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "pinokehys on liian suuri"
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported number of nops before function entry (%u)"
 msgstr "liian monta argumenttia funktiolle %qE"
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%qs käyttää rekisteriä r29"
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, fuzzy, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "#pragma extern_prefix ei ole tuettu tällä kohteella"
@@ -44511,107 +44523,117 @@ msgstr "luokkanimeä ei ole annettu %qs:n kanssa"
 msgid "unknown option for %<%s=%s%>"
 msgstr "tuntematon valitsin -%s"
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4837
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4855
 #, fuzzy, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "Vanhentunut. Tämä valitsin ei vaikuta mihinkään"
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, fuzzy, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, fuzzy, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, fuzzy, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, fuzzy, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, fuzzy, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, fuzzy, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "virheellinen argumentti %s %s:lle"
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s ei ole sallittu"
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s on virheellinen"
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Varoita ylikuormitetuista virtuaalifunktioiden nimistä"
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
@@ -44656,7 +44678,7 @@ msgstr ""
 msgid "builtin %qs can only be used on vector types"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, fuzzy, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "virheellinen %%H-arvo"
@@ -44726,225 +44748,225 @@ msgstr "%qE on vanhentunut"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
 
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
 
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, fuzzy, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr "%qs määritelty parametrille %qE"
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, fuzzy, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher"
 msgstr "%qs määritelty parametrille %qE"
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, fuzzy, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher"
 msgstr "%qs määritelty parametrille %qE"
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, fuzzy, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "<sisäänrakennettu>"
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, fuzzy, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "<sisäänrakennettu>"
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "%<__builtin_prefetch%>-funktion toinen argumentti on epäkelpo; käytetään nollaa"
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, fuzzy, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "paikallisten objektien kokonaiskoko on liian suuri"
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr ""
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr ""
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "pinokehys ei ole 8:n tavun monikerta: %wd"
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr ""
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, fuzzy, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, fuzzy, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, fuzzy, gcc-internal-format
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, fuzzy, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-fPIC ei ole tuettu"
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, fuzzy, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "kohdistuksen pitää olla kahden potenssi, ei %d"
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, fuzzy, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "kohdistuksen pitää olla kahden potenssi, ei %d"
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "%q+D:n ensimmäisen argumentin pitäisi olla %<int%>"
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%qs:n argumentti on liian suuri (maksimi %d)"
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr "PROCEDURE-lauseen kohdassa %C on oltava geneerisessä rajapinnassa"
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr "kohde ”%s” ei täsmää kohdehahmon kanssa"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, fuzzy, gcc-internal-format
 msgid "invalid cc output constraint: %qs"
 msgstr "virheellinen rotate-käsky"
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, fuzzy, gcc-internal-format
 msgid "multiple cc output constraints not supported"
 msgstr "Ei ole tuettu"
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, gcc-internal-format
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr ""
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, fuzzy, gcc-internal-format
 msgid "invalid type for cc output constraint"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
@@ -45368,8 +45390,8 @@ msgstr "%qE-attribuuttia ei huomioida %qE:lle"
 msgid "attribute %qs applies to array types only"
 msgstr "attribuutti %qs soveltuu vain taulukkotyyppeihin"
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
@@ -45444,7 +45466,7 @@ msgstr "%Jtaulukon %qD tyyppi viimeistelty epäkelvosti implisiittisellä alustu
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr "%qD on esittelemättä tällä näkyvyysalueella"
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "alunperin määritelty täällä"
@@ -45677,7 +45699,7 @@ msgstr "%J%qD:n esittely varjostaa edellistä paikallista"
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D:n esittely varjostaa sisäänrakennetun funktion"
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%q+D:n esittely varjostaa sisäänrakennetun funktion"
@@ -45687,7 +45709,7 @@ msgstr "%q+D:n esittely varjostaa sisäänrakennetun funktion"
 msgid "declaration of %qD shadows a previous local"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "varjostunut esittely on täällä"
@@ -45752,7 +45774,7 @@ msgstr "%qE esittelemättä (ensimmäinen käyttökerta tässä funktiossa)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(Jokaisesta esittelemättömästä tunnisteesta ilmoitetaan vain"
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, fuzzy, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "%qD ei ole määritelty funktion näkyvyysalueen ulkopuolella"
@@ -45787,7 +45809,7 @@ msgstr "Odotettiin lauseketta %s-lauseessa kohdassa %C"
 msgid "duplicate label declaration %qE"
 msgstr "%qE-nimiön kaksoisesittely"
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "Kaksoiskappale %s-nimiöspesifikaatio kohdassa %C"
@@ -45823,7 +45845,7 @@ msgstr "switch hyppää muuttuja-alustuksen yli"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
@@ -45974,12 +45996,12 @@ msgstr "ISO C90 ei tue syntaksia %<[*]%> taulukkoesittelijöissä"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<omp::%s%> not allowed to be specified in this context"
@@ -45990,7 +46012,7 @@ msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 msgid "%q+D is usually a function"
 msgstr "%q+D on yleensä funktio"
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%qD:lle ei ole edellistä esittelyä"
@@ -46066,7 +46088,7 @@ msgstr "ei voi laittaa volatile-kenttäistä objektia rekisteriin"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "alustamaton vakio %qD on virheellinen C++-kielessä"
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, fuzzy, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%qE nimiavaruudessa %qE ei nimeä tyyppiä"
@@ -46253,7 +46275,7 @@ msgstr "tallennusluokka annettu parametrille %qE"
 msgid "storage class specified for unnamed parameter"
 msgstr "tallennusluokka annettu nimettömälle parametrille"
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "tallennusluokka annettu typenamelle"
@@ -46316,7 +46338,7 @@ msgstr "%qE:n esittely taulukollisena funktioita"
 msgid "declaration of type name as array of functions"
 msgstr "tyyppinimen esittely taulukollisena funktioita"
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "joustavan taulukkojäsenen sisältävän tietueen epäkelpo käyttö"
@@ -46422,7 +46444,7 @@ msgstr "tyyppinimi esitelty taulukon palauttavan funktiona"
 msgid "function definition has qualified void return type"
 msgstr "funktion määrittely oikeuttaa tyhjän paluutyypin"
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tyyppimääritteet jätetään huomiotta funktion paluutyypissä"
@@ -46549,7 +46571,7 @@ msgstr "ISO C kieltää const- ja volatile-funktiotyypit"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "muuttuja tai kenttä %qE esitelty voidiksi"
@@ -46656,7 +46678,7 @@ msgstr "typedef %q+D määritelty uudelleen"
 msgid "object with variably modified type must have no linkage"
 msgstr "typedef %q+D määritelty uudelleen"
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "funktion esittely ei ole prototyyppi"
@@ -46746,17 +46768,17 @@ msgstr "sisäkkäinen %<union %E%>:n uudelleenmäärittely"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "sisäkkäinen %<struct %E%>:n uudelleenmäärittely"
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, fuzzy, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "tyypin määritteleminen tyyppimuunnoksessa on virheellistä C++-kielessä"
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, fuzzy, gcc-internal-format
 msgid "%qT defined in underspecified object initializer"
 msgstr "%qs määritelty tietueen kentälle %qE"
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "esittely ei esittele mitään"
@@ -46786,604 +46808,604 @@ msgstr "tyhjän structin koko on C:ssä 0, C++:ssa 1"
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr "tyhjän unionin koko on C:ssä 0, C++:ssa 1"
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "unionilla ei ole nimettyjä jäseniä"
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "unionilla ei ole jäseniä"
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "structilla ei ole nimettyjä jäseniä"
 
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "structilla ei ole jäseniä"
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "joustava taulukkojäsen unionissa"
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "joustava taulukkojäsen ei ole structin lopussa"
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "joustava taulukkojäsen unionissa"
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr "joustava taulukkojäsen ei ole structin lopussa"
 
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "Arvo on liian suuri annetulle tietotyypille"
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, fuzzy, gcc-internal-format
 msgid "type punning toggles scalar storage order"
 msgstr "Käänteinen jä_rjestys"
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "unionista ei voi tehdä läpinäkyvää"
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, fuzzy, gcc-internal-format
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr "typedef %q+D määritelty uudelleen"
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %<struct %E%>"
 msgid "redefinition of struct or union %qT"
 msgstr "%<struct %E%> uudelleenmääritelty"
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "sisäkkäinen %<enum %E%>:n uudelleenmäärittely"
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%>:n uudelleenmäärittely"
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, fuzzy, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "annettu tila on liian pieni luetelluille arvoille"
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "luetellun tyypin arvot ylittävät suurimman kokonaisluvun arvoalueen"
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration values exceed range of largest integer"
 msgid "enumeration values exceed range of %qs"
 msgstr "luetellun tyypin arvot ylittävät suurimman kokonaisluvun arvoalueen"
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of %<enum %E%>"
 msgid "conflicting redefinition of enum %qT"
 msgstr "sisäkkäinen %<enum %E%>:n uudelleenmäärittely"
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "ylivuoto luetellun tyypin arvoissa"
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, fuzzy, gcc-internal-format
 msgid "enumerator value outside the range of underlying type"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, fuzzy, gcc-internal-format
 msgid "enumerator value outside the range of %qs"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr "ISO C rajoittaa luetellun tyypin arvot %<int%>-tyypin arvoalueelle"
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "paluutyyppi on oletuksena %<int%>"
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, fuzzy, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "kenttä %qE esitelty funktiona"
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "%qD:lle ei ole edellistä prototyyppiä"
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD käytössä ilman prototyyppiä ennen sen määrittelyä"
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD käytössä ilman esittelyä ennen sen määrittelyä"
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "%qD:n paluuarvon tyyppi ei ole %<int%>"
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "%qD:n paluuarvon tyyppi ei ole %<int%>"
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD on tavallisesti ei-staattinen funktio"
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "vanhanmallisia parametriesittelyitä prototyypitetyssä funktiomäärittelyssä"
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "perinteinen C ei hyväksy ISO C -tyylisiä funktiomäärittelyitä"
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr "ISO C90 ei tue tyyppiä %<long long%>"
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "vanhanmallinen funktiomäärittely"
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "parametrin nimi puuttuu parametriluettelosta"
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD esitelty ei-parametrina"
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "useita parametreja nimellä %qD"
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "%qD:n oletustyyppi on %<int%>"
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "parametrin %qD tyyppi on vaillinainen"
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "argumenttien määrä ei vastaa sisäistä prototyyppiä"
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "argumenttien määrä ei vastaa prototyyppiä"
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "prototyypin esittely"
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "ylennetty argumentti %qD ei vastaa sisäistä prototyyppiä"
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "ylennetty argumentti %qD ei vastaa prototyyppiä"
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "argumentti %qD ei vastaa sisäistä prototyyppiä"
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argumentti %qD ei sovi prototyyppiin"
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ei palautuslausetta funktiossa, joka palauttaa ei-voidin"
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parametri %qD on alustettu"
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%>-silmukan alkuesittelyt ovat sallittuja vain C99-tilassa"
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, fuzzy, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "käytä valitsinta -std=c99 tai -std=gnu99 koodisi kääntämiseen"
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 ei tue syntaksia %<[*]%> taulukkoesittelijöissä"
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "staattisen muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "%<extern%>-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
 # XXX: alkuesittely
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> esitelty %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> esitelty %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> esitelty %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, fuzzy, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %<auto%>"
 msgstr "%qE:a saatetaan käyttää alustamattomana tässä funktiossa"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> used with %<constexpr%>"
 msgstr "%qE:a käytetään alustamattomana tässä funktiossa"
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "yli yksi tietotyyppi esittelymääritteissä"
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> on liian pitkä GCC:lle"
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 ei tue kompleksityyppejä"
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE:n kaksoiskappale"
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "kohteen int-tyyppi on kapeampi kuin kohteen char-tyyppi"
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 ei tue kompleksityyppejä"
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "kohteen int-tyyppi on kapeampi kuin kohteen char-tyyppi"
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr "ISO C90 ei tue tyyppiä %<long long%>"
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, fuzzy, gcc-internal-format
 #| msgid "case label is not an integer constant expression"
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr "case-nimiö ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant expression"
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr ""
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE ei ole typedef eikä sisäinen tyyppi"
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE ei ole esittelyn alussa"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE:a saatetaan käyttää alustamattomana tässä funktiossa"
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE:a käytetään alustamattomana tässä funktiossa"
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE ei ole typedef eikä sisäinen tyyppi"
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<constexpr%>"
 msgstr "%qE:a käytetään alustamattomana tässä funktiossa"
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "käytetty %<__thread%> ennen %<static%>:a"
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> used with %<auto%>"
 msgstr "%qE:a saatetaan käyttää alustamattomana tässä funktiossa"
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<extern%>"
 msgstr "%qE:a käytetään alustamattomana tässä funktiossa"
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %qs"
 msgstr "%qE:a käytetään alustamattomana tässä funktiossa"
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "kaksinkertainen %<_Thread_local%> tai %<__thread%>"
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qE:a käytetään alustamattomana tässä funktiossa"
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> used with %qE"
 msgstr "käytetty sekä %<__thread%> että %qs"
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, fuzzy, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "käytetty sekä %<__thread%> että %<auto&>"
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ei tue pelkkää %<complex%>-tyyppiä merkityksellä %<double complex%>"
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr "ISO C90 ei tue syntaksia %<[*]%> taulukkoesittelijöissä"
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C ei tue kompleksikokonaislukutyyppejä"
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, fuzzy, gcc-internal-format
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr "kohdistuksen %q+D:lle pitää olla vähintään %d"
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr "ISO C++ 1998 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "negatiivisen arvon siirto vasemmalle"
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "vasemmalle siirron lukumäärä on negatiivinen"
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "vasemmalle siirron lukumäärä >= tyypin leveys"
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "oikealle siirron lukumäärä >= tyypin leveys"
@@ -47413,7 +47435,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "toinen täsmäävyys on täällä"
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "odotettiin %<(%> tai rivin loppu"
@@ -47423,8 +47445,8 @@ msgstr "odotettiin %<(%> tai rivin loppu"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C kieltää tyhjät käännösyksiköt"
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr ""
@@ -47464,9 +47486,9 @@ msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 msgid "unknown type name %qE"
 msgstr "%qE ei nimeä tyyppiä"
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "useita tallennusluokkia esittelymääritteissä"
@@ -47496,7 +47518,7 @@ msgstr "pakattu attribuutti on tarpeeton %q+D:lle"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
@@ -47516,7 +47538,7 @@ msgstr "Odottamattomat argumentit"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "pakattu attribuutti on tarpeeton %q+D:lle"
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, fuzzy, gcc-internal-format
 msgid "%<assume%> attribute not followed by %<;%>"
 msgstr "pakattu attribuutti on tarpeeton %q+D:lle"
@@ -47607,7 +47629,7 @@ msgstr "ei-vakio ehto staattiselle väitteelle"
 msgid "static assertion failed: %E"
 msgstr "staattinen väite epäonnistui: %E"
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "staattinen väite epäonnistui"
@@ -47679,10 +47701,10 @@ msgstr "enum-muunnos palautuksessa on virheellistä C++-kielessä"
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "odotettu tunniste"
@@ -47836,7 +47858,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr ""
@@ -47846,8 +47868,8 @@ msgstr ""
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, fuzzy, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs attribute argument"
 msgstr "tunnistamaton osoite"
@@ -48021,12 +48043,12 @@ msgstr "ISO C kieltää ?:-lausekkeen ilman keskimmäistä termiä"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, fuzzy, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "%Jviimeksi käytetty täällä"
@@ -48176,7 +48198,7 @@ msgstr "ISO C ei tue kompleksikokonaiskulutyyppejä"
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, gcc-internal-format
 msgid "expected expression"
 msgstr "odotettiin lauseketta"
@@ -48500,12 +48522,12 @@ msgstr "Odotettiin toista ulottuvuutta taulukkoesittelyssä kohdassa %C"
 msgid "no type or storage class may be specified here,"
 msgstr "tallennusluokka annettu %qs:lle"
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, fuzzy, gcc-internal-format
 msgid "empty property attribute list"
 msgstr "<tuntematon>"
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, fuzzy, gcc-internal-format
 msgid "missing property attribute"
 msgstr "puuttuva Code-attribuutti"
@@ -48515,57 +48537,57 @@ msgstr "puuttuva Code-attribuutti"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "<tuntematon>"
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "<tuntematon>"
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "toistuva %<@%> Objective-C-merkkijonon edellä"
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, fuzzy, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, fuzzy, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr "kuori on annettava polkuineen"
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr ""
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
@@ -48575,25 +48597,25 @@ msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "Odotettiin =-merkkiä PARAMETER-lauseessa kohdassa %C"
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "roskaa ilmaisun %<#pragma GCC pch_preprocess%> lopussa"
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "%s: liian monta arvoa"
@@ -48608,63 +48630,63 @@ msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 msgid "expected %<)%> or %<,%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD ei ole muuttuja"
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD ei ole muuttuja"
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, fuzzy, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr "%qs määrittää %<auto%>:n tiedostoalue-esittelyssä"
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, fuzzy, gcc-internal-format
 msgid "expected constant logical expression"
 msgstr "odotettiin lauseketta"
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -48687,22 +48709,22 @@ msgstr "%<num_threads%>-arvon on oltava positiivinen"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "UNIT-numeron lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, fuzzy, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, fuzzy, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "odotettiin %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> tai %<max%>"
@@ -48712,95 +48734,95 @@ msgstr "odotettiin %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<m
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, fuzzy, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, fuzzy, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "%s: liian monta argumenttia\n"
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "%qs attribuuttia ei huomioida"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, fuzzy, gcc-internal-format
 msgid "too many %<self%> clauses"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, fuzzy, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, fuzzy, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, fuzzy, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "sekä %<long%> että %<void%> esittelymääritteissä"
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
@@ -48810,22 +48832,22 @@ msgstr "%qE määritelty vääränlaisena tunnisteena"
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr ""
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, fuzzy, gcc-internal-format
 msgid "expected %<allocator%> or %<align%>"
 msgstr "odotettiin %<operator%>"
@@ -48836,22 +48858,22 @@ msgstr "odotettiin %<operator%>"
 msgid "duplicate %qs modifier"
 msgstr "kaksois-%qs"
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, fuzzy, gcc-internal-format
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, fuzzy, gcc-internal-format
 msgid "multiple linear modifiers"
 msgstr "ristiriitaiset tyyppimääreet %q+D:lle"
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, fuzzy, gcc-internal-format
 msgid "multiple %<step%> modifiers"
 msgstr "ristiriitaiset tyyppimääreet %q+D:lle"
@@ -48871,62 +48893,62 @@ msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, fuzzy, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "%s ei tue pituusmäärettä %qs %s"
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, fuzzy, gcc-internal-format
 msgid "invalid doacross kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, fuzzy, gcc-internal-format
 msgid "too many %<always%> modifiers"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, fuzzy, gcc-internal-format
 msgid "too many %<close%> modifiers"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, fuzzy, gcc-internal-format
 msgid "too many %<present%> modifiers"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr ""
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, fuzzy, gcc-internal-format
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, fuzzy, gcc-internal-format
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "virheellinen const_double-operandi"
@@ -48941,88 +48963,88 @@ msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "odotettiin %<,%>, %<;%> tai %<}%>"
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, fuzzy, gcc-internal-format
 msgid "expected an OpenACC clause"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "Funktio %qs"
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "käytetty sekä %<__thread%> että %qs"
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, fuzzy, gcc-internal-format
 msgid "expected an OpenMP clause"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, fuzzy, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "rajat määrittelemättömän taulukon epäkelpo käyttö"
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "muuttuja tai kenttä %qs esitelty tyhjäksi"
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<extern%>-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "rajat määrittelemättömän taulukon epäkelpo käyttö"
 
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "rajat määrittelemättömän taulukon epäkelpo käyttö"
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, fuzzy, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr ""
@@ -49037,7 +49059,7 @@ msgstr "%qE on esittelemättä"
 msgid "expected function name"
 msgstr "odotettiin luokan nimeä"
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
@@ -49047,22 +49069,22 @@ msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
@@ -49087,7 +49109,7 @@ msgstr ""
 msgid "modified here"
 msgstr "union määritelty täällä"
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, fuzzy, gcc-internal-format
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
@@ -49127,111 +49149,111 @@ msgstr ""
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "odotettiin %<,%>, %<;%> tai %<}%>"
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, fuzzy, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, fuzzy, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "%s: liian monta arvoa"
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, fuzzy, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "%s: liian monta arvoa"
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, fuzzy, gcc-internal-format
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, fuzzy, gcc-internal-format
 msgid "%qs clause requires %qs clause"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, fuzzy, gcc-internal-format
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, gcc-internal-format
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr ""
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr "roskaa ilmaisun %<#pragma pack%> lopussa"
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<delete%>"
 msgid "unexpected %<else%>"
 msgstr "odotettiin %<delete%>"
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr "roskaa ilmaisun %<#pragma pack%> lopussa"
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "roskaa ilmaisun %<#pragma pack%> lopussa"
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "roskaa ilmaisun %<#pragma pack%> lopussa"
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr ""
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
@@ -49241,27 +49263,27 @@ msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr ""
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, fuzzy, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, fuzzy, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "odotettiin %<,%>, %<;%> tai %<}%>"
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, fuzzy, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, fuzzy, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
@@ -49271,164 +49293,164 @@ msgstr "%<void%> vain parametrina ei ole oikeutettu"
 msgid "expected %<(%> or end of line"
 msgstr "odotettiin %<(%> tai rivin loppu"
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, fuzzy, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, fuzzy, gcc-internal-format
 msgid "not enough nested loops"
 msgstr "liian vähän argumentteja"
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
 # XXXXXXX
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, fuzzy, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, fuzzy, gcc-internal-format
 msgid "unknown selector %qs for context selector set %qs"
 msgstr "Tuntematon -mmacosx-version-min-arvo %qs"
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, fuzzy, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "%s ei tue muotoilua %<%%%c%> %s"
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, fuzzy, gcc-internal-format
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr "tallennusluokan voi antaa vain olioille ja funktioille"
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, fuzzy, gcc-internal-format
 msgid "%<score%> argument must be constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, fuzzy, gcc-internal-format
 msgid "%<score%> argument must be non-negative"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, fuzzy, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "odotettiin merkkijonoliteraalia"
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
@@ -49436,290 +49458,290 @@ msgstr ""
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> selector is not supported yet"
 msgstr "-pipe ei ole tuettu"
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, fuzzy, gcc-internal-format
 msgid "expected context selector set name"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, fuzzy, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "  siirtyy catch-lohkoon"
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, fuzzy, gcc-internal-format
 msgid "variant %qD is not a function"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, fuzzy, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, fuzzy, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, fuzzy, gcc-internal-format
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "# Ei kohde:"
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr "tallennusluokka annettu typenamelle"
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr ""
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, fuzzy, gcc-internal-format
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr "Kaksoiskappale-%s-attribuutti määritelty kohdassa %L"
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%> or %<assumes%>"
 msgstr "tallennusluokka annettu typenamelle"
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, fuzzy, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, fuzzy, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr "edellinen esittely"
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr "edellinen esittely"
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, fuzzy, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr "edellinen esittely"
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, fuzzy, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "edellinen esittely"
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, fuzzy, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr "odotettiin %<(%> tai rivin loppu"
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, fuzzy, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "odotettiin luokan nimeä"
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%qs määrittää %<auto%>:n tiedostoalue-esittelyssä"
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, fuzzy, gcc-internal-format
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, fuzzy, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, fuzzy, gcc-internal-format
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, fuzzy, gcc-internal-format
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, fuzzy, gcc-internal-format
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr "odotettiin %<,%>, %<;%> tai %<}%>"
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, fuzzy, gcc-internal-format
 msgid "expected %qs or %qs"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, fuzzy, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, fuzzy, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, fuzzy, gcc-internal-format
 msgid "expected at least one assumption clause"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, fuzzy, gcc-internal-format
 msgid "expected directive name"
 msgstr "odotettiin luokan nimeä"
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr ""
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, fuzzy, gcc-internal-format
 msgid "unknown assumption clause %qs"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, fuzzy, gcc-internal-format
 msgid "expected assumption clause"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, fuzzy, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%J%qD esitelty avoimeksi kutsumisen jälkeen"
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "parametrilla %u in vaillinainen tyyppi"
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "Käyttö: %s <transaktiotiedosto> <tiedostojärjestelmä>\n"
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, fuzzy, gcc-internal-format
 msgid "no closing brace"
 msgstr "          %s"
@@ -49861,7 +49883,7 @@ msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "taulukon indeksi ei ole kokonaisluku"
@@ -49892,7 +49914,7 @@ msgstr "%qD esitelty viitteenä, mutta alustamatta"
 msgid "enum constant defined here"
 msgstr "lueteltu tyyppi määritelty täällä"
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -50005,17 +50027,17 @@ msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "liian vähän argumentteja funktiolle %qE"
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "vertailu merkkijonoliteraalin kanssa aiheuttaa määrittelemätöntä toimintaa"
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, fuzzy, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "osoittimen ja kokonaisluvun välinen vertailu"
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, fuzzy, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "oliko tarkoitus käyttää loogista negaatiota?"
@@ -50041,7 +50063,7 @@ msgstr "vähennyslaskussa käytetty osoitinta funktioon"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "funktio-osoitinta käytetty laskutoimituksessa"
@@ -50337,7 +50359,7 @@ msgstr "tyyppimuunnos osoittimesta erikokoiseen kokonaislukuun"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "tyyppimuunnos %qT-tyyppisestä funktiokutsusta yhteensopimattomaan tyyppiin %qT"
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "tyyppimuunnos erikokoisesta kokonaisluvusta osoittimeksi"
@@ -50515,7 +50537,7 @@ msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, fuzzy, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
@@ -50717,12 +50739,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "joustavan taulukkojäsenen alustus"
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, fuzzy, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "alustus yhteensopimattomasta osoitintyypistä"
@@ -50732,7 +50754,7 @@ msgstr "alustus yhteensopimattomasta osoitintyypistä"
 msgid "array of inappropriate type initialized from string constant"
 msgstr "sopimattomasta tyypistä koostuva taulukko alustetaan merkkijonovakiosta"
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
@@ -50763,7 +50785,7 @@ msgstr "alustinalkio ei ole vakiolauseke"
 msgid "initializer element is not computable at load time"
 msgstr "alustusalkiota ei pystytä laskemaan latausajankohtana"
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "läpinäkymättömiä vektorityyppejä ei voida alustaa"
@@ -50778,7 +50800,7 @@ msgstr "alustimen lopussa on ylimääräinen lohko"
 msgid "braces around scalar initializer"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "joustavan taulukkojäsenen alustaminen sisäkkäisessä asiayhteydessä"
@@ -50869,7 +50891,7 @@ msgstr "ylimääräisiä alkioita struct-alustimessa"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "Varoita mahdollisesti puuttuvista aaltosuluista alustimissa"
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "joustavan taulukkojäsenen ei-staattinen alustus"
@@ -50909,7 +50931,7 @@ msgstr "ISO C90 kieltää yhdysliteraalit"
 msgid "computed goto must be pointer type"
 msgstr "annettu yhteensopimatonta osoitintyyppiä oleva %d. argumentti funktiolle %qE"
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%>-esitellyllä funktiolla on %<return%>-lause"
@@ -50964,7 +50986,7 @@ msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 msgid "break statement not within loop or switch"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, fuzzy, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -51010,27 +51032,27 @@ msgstr "%qD:n osoite ei tule koskaan olemaan NULL"
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr "%qD:n osoite ei tule koskaan olemaan NULL"
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "Varoita eri enum-tyyppien vertailusta"
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "Varoita eri enum-tyyppien vertailusta"
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, fuzzy, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "liukulukujen vertailu operaattoreilla == ja != on epävarmaa"
@@ -51102,29 +51124,29 @@ msgstr "käytetty unionityypin arvoa, vaikka vaaditaan skalaari"
 msgid "used vector type where scalar is required"
 msgstr "käytetty unionityypin arvoa, vaikka vaaditaan skalaari"
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, fuzzy, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "odotettiin %<operator%>"
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qs määritelty parametrille %qE"
@@ -51135,85 +51157,85 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, fuzzy, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, fuzzy, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, fuzzy, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, fuzzy, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, fuzzy, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, fuzzy, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, fuzzy, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, fuzzy, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, fuzzy, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, fuzzy, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
@@ -51223,17 +51245,17 @@ msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr "parametrin %qD tyyppi on vaillinainen"
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "iteraattorin askellus ei-kokonaislukutyypillä"
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr "parametrin %qD tyyppi on vaillinainen"
@@ -51243,32 +51265,32 @@ msgstr "parametrin %qD tyyppi on vaillinainen"
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, fuzzy, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, fuzzy, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, fuzzy, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, fuzzy, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, fuzzy, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, fuzzy, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
@@ -51298,7 +51320,7 @@ msgstr "bittikentän %qs leveys on nolla"
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "tyypillä %qE on käyttäjän määrittelemä muodostin"
@@ -51308,17 +51330,17 @@ msgstr "tyypillä %qE on käyttäjän määrittelemä muodostin"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, fuzzy, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, fuzzy, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, fuzzy, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
@@ -51333,23 +51355,23 @@ msgstr ""
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, fuzzy, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
@@ -51361,32 +51383,32 @@ msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, fuzzy, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
@@ -51406,7 +51428,7 @@ msgstr "muuttuja %qD esitelty uudelleen funktiona"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
@@ -51416,7 +51438,7 @@ msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
@@ -51426,76 +51448,76 @@ msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, fuzzy, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr ""
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, fuzzy, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, fuzzy, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, fuzzy, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, fuzzy, gcc-internal-format
 msgid "unsupported map expression %qE"
 msgstr "kiintopistevakiot ovat GCC-laajennos"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
@@ -51510,22 +51532,22 @@ msgstr "lähde ei ole osoitin"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, fuzzy, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr "%s: liian monta arvoa"
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, fuzzy, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "__COUNTER__ lavennettu direktiivin sisällä valitsimella -fdirectives-only"
 
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qs määritelty parametrille %qE"
@@ -51535,38 +51557,38 @@ msgstr "%qs määritelty parametrille %qE"
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, fuzzy, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, fuzzy, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, fuzzy, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, fuzzy, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, fuzzy, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
@@ -51835,14 +51857,14 @@ msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  ehdokas odottaa %d argumenttia, %d annettu"
 msgstr[1] "  ehdokas odottaa %d argumenttia, %d annettu"
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -52157,582 +52179,582 @@ msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu ty
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "ehtolausekkeessa etumerkkinen ja etumerkitön tyyppi"
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "%qD:n paluuarvon tyyppi ei ole %<int%>"
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, fuzzy, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "%q#T ei ole luokka eikä nimiavaruus"
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, fuzzy, gcc-internal-format
 msgid "no match for call to %<%T::operator[] (%A)%>"
 msgstr "Ei vastaavuutta"
 
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, fuzzy, gcc-internal-format
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr "Virheellinen järjestelmäkutsu"
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "Funktio %qs:"
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "Funktio %qs:"
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, fuzzy, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr ""
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, fuzzy, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "%<operator new%>:n on palautettava tyyppi %qT"
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, fuzzy, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "tässä yhteydessä"
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "tässä yhteydessä"
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, fuzzy, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "tässä yhteydessä"
 
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "annettu NULL funktion %2$qD ei-osoitinargumenttina %1$P"
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, gcc-internal-format
 msgid "  declared here"
 msgstr "  esitelty täällä"
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "muunnetaan %<false%> osoitintyyppiksi %2$qD:n argumentissa %1$P"
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, fuzzy, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "liikaa aaltosulkeita %qT:n alustimen ympärillä"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 #, fuzzy
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "ei voi muuntaa tyypistä %qT tyyppiin %qT (%s)"
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 #, fuzzy
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr ""
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 #, fuzzy
 msgid "invalid conversion from %qH to %qI"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 #, fuzzy
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 #, fuzzy
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
 # Tämä esiintynee esim. const char* → char* -muunnoksessa.
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, fuzzy, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, fuzzy, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, fuzzy, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi välittää %<...%>:n kautta"
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi vastaanottaa %<...%>:n kautta"
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, fuzzy, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi vastaanottaa %<...%>:n kautta"
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "oletusargumentti annettu %2$q#D:n parametrille %1$d"
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
 # XXX
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, fuzzy, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "%Hswitch-lauseesta puuttuu default-nimike"
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr ""
 
 # Tämä esiintynee esim. const char* → char* -muunnoksessa.
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, fuzzy, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "%J%qD esitelty turhaan uudestaan"
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "liikaa argumentteja muodostimelle %q#D"
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, fuzzy, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr "sijoitus (ei alustus) esittelyssä"
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, fuzzy, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD tyhjentää ei-triviaalintyyppisen objektin %#qT%s"
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, fuzzy, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "sijoitus (ei alustus) esittelyssä"
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr "; käytä kopiosijoitusta sen sijaan"
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "; käytä kopioalustusta sen sijaan"
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "%qD kirjoittaa ei-triviaalisti-kopioitavaan tyyppiin %#qT%s"
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, fuzzy, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr "%q#T-tyyppisiä epä-POD-objekteja ei voi välittää %<...%>:n kautta, ohjelma tulee keskeytymään ajettaessa"
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, fuzzy, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, fuzzy, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, fuzzy, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr "%qD siirtää ei-triviaalisti-kopioitavan tyyppisen %q#T-olion; käytä %<new%>:tä ja %<delete%>:ä"
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT esitelty täällä"
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, fuzzy, gcc-internal-format
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "Kopiomuodostin %qs"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 #, fuzzy
 msgid "cannot convert %qH to %qI"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "päättämätön kutsu funktioon ”%s”: puuttuva ”%c”"
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "päättämätön kutsu funktioon ”%s”: puuttuva ”%c”"
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, fuzzy, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "päättämätön kutsu funktioon ”%s”: puuttuva ”%c”"
 
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, fuzzy, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "%s: valitsin on moniselitteinen; vaihtoehdot:"
 
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "arvon palautus muodostimesta"
 
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "arvon palautus muodostimesta"
 
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "arvon palautus hajottimesta"
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, fuzzy, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr "ISO C++:n mukaan nämä ovat moniselitteisiä siitä huolimatta, että ensimmäisen huonoin muunnos on parempi kuin toisen huonoin:"
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, fuzzy, gcc-internal-format
 msgid "try making the operator a %<const%> member function"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, fuzzy, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 #, fuzzy
 msgid "  for conversion from %qH to %qI"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " ehdokas 1: %q+#F"
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " ehdokas 2: %q+#F"
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++:n mukaan nämä ovat moniselitteisiä siitä huolimatta, että ensimmäisen huonoin muunnos on parempi kuin toisen huonoin:"
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 #, fuzzy
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, fuzzy, gcc-internal-format
 msgid "possibly dangling reference to a temporary"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr ""
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, gcc-internal-format
 msgid "explicit conversion function was not considered"
 msgstr ""
@@ -52788,7 +52810,7 @@ msgid "%q#D cannot be overloaded with %q#D"
 msgstr "käyttämätön muuttuja %q+D"
 
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "edellinen esittely %q+D"
@@ -53209,7 +53231,7 @@ msgstr "joustava taulukkojäsen muuten tyhjässä structissa"
 msgid "next member %q#D declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T uudelleenmääritelty"
@@ -53340,7 +53362,7 @@ msgstr "epäkelpo tallennusluokka funktiolle %qs"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
@@ -53381,7 +53403,7 @@ msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr ""
@@ -53399,7 +53421,7 @@ msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 msgid "%q+E is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -53420,7 +53442,7 @@ msgstr "vertailu ”etumerkitön lauseke < 0” on aina epätosi"
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
@@ -53467,7 +53489,7 @@ msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -53596,18 +53618,18 @@ msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "taulukon tyypillä on vaillinainen alkiotyyppi"
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -53615,470 +53637,470 @@ msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 msgid "%qE is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, fuzzy, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "%qs ei ole tuettu tällä kohteella"
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, fuzzy, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, fuzzy, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, gcc-internal-format
 msgid "allocated here"
 msgstr "varattu täällä"
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
 msgstr ""
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD käytössä ilman prototyyppiä ennen sen määrittelyä"
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, fuzzy, gcc-internal-format
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, fuzzy, gcc-internal-format
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr "alustinalkio ei ole vakiolauseke"
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr ""
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr ""
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, fuzzy, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "alustinalkio ei ole vakiolauseke"
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "use of %qD"
 msgstr "%qD:n virheellinen käyttö"
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr ""
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr ""
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr ""
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr ""
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, fuzzy, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr "%qD:n poistettu määrittely"
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, fuzzy, gcc-internal-format
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "poistettu funktio %q+D"
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, fuzzy, gcc-internal-format
 msgid "pointed-to object declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, fuzzy, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "odotettiin %<template%>"
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, fuzzy, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, fuzzy, gcc-internal-format
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr "hajottimen %qE osoitteen ottaminen"
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, fuzzy, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "virheellinen static_cast-muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, fuzzy, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "virheellinen %%s-arvo"
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "tyyppimuunnos osoittimesta erikokoiseen kokonaislukuun"
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, fuzzy, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, fuzzy, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, fuzzy, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "tallennusluokka %<thread_local%> virheellinen funktiolle %qs"
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "Jako nollalla kohdassa %L"
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, fuzzy, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "taulukon alustus ei-vakiolla"
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, fuzzy, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "Odottamaton %s-lause kohdassa %C"
@@ -54824,7 +54846,7 @@ msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 msgid "no suspend point info for %qD"
 msgstr "%qD:lle ei ole edellistä prototyyppiä"
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -54846,23 +54868,23 @@ msgstr "osoittimet eivät ole sallittuja case-arvoja"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, fuzzy, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
@@ -54883,68 +54905,68 @@ msgstr ""
 msgid "%qD was promoted to an immediate function"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, fuzzy, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "hajottimen %qE osoitteen ottaminen"
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, fuzzy, gcc-internal-format
 msgid "call to consteval function %qE is not a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, fuzzy, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%qD:n osoite tulee aina olemaan %<true%>"
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, fuzzy, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, fuzzy, gcc-internal-format
 msgid "pack expansion of %qE attribute"
 msgstr "%qs-attribuutin virheellinen argumentti"
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, fuzzy, gcc-internal-format
 msgid "use fold expression in the attribute argument instead"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD ei ole tyyppi"
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qT ei ole luokkatyyppi"
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
@@ -54990,7 +55012,7 @@ msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, fuzzy, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "oliko tarkoitus käyttää loogista negaatiota?"
@@ -55375,7 +55397,7 @@ msgstr "edellisestä esittelystä %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "luetellun tyypin jäsenen %q+D uudelleenesittely"
 
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "edellinen esittely %q+D"
@@ -55515,8 +55537,8 @@ msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 msgid "%q#D previously defined here"
 msgstr "%q+#D määritelty aiemmin täällä"
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, fuzzy, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
@@ -55591,53 +55613,38 @@ msgstr "oletusargumentti annettu %2$q#D:n parametrille %1$d"
 msgid "previous specification in %q#D here"
 msgstr "%q+D:n edellinen esittely oli täällä"
 
-#: cp/decl.cc:2285
-#, fuzzy, gcc-internal-format
-msgid "declaration %qD conflicts with builtin"
-msgstr "%q+D:n osoitealue on ristiriidassa edellisen esittelyn kanssa"
-
-#: cp/decl.cc:2288
-#, fuzzy, gcc-internal-format
-msgid "declaration %qD conflicts with import"
-msgstr "nimiavaruuden %qD esittely on ristiriidassa"
-
-#: cp/decl.cc:2289
-#, fuzzy, gcc-internal-format
-msgid "import declared %q#D here"
-msgstr "esitelty täällä"
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, fuzzy, gcc-internal-format
 msgid "conflicting exporting for declaration %qD"
 msgstr "ristiriitainen esittely %q#D"
 
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared here without exporting"
 msgstr "esitelty aiemmin täällä"
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "%q+D:n edellinen määrittely oli täällä"
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "%q+D:n edellinen esittely oli täällä"
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "%qD uudelleenesitellään tarpeettomasti samalla näkyvyysalueella"
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, fuzzy, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr "%qD:n poistettu määrittely"
@@ -55650,44 +55657,44 @@ msgstr "%qD:n poistettu määrittely"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "(mahdollisesti %qT:n määrittelyn perästä puuttuu puolipiste)"
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "%q+D määritelty uudelleen"
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, fuzzy, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, fuzzy, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%J%qD esitelty uudelleen erityyppisenä symbolina"
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%J%qD esitelty uudelleen erityyppisenä symbolina"
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -55695,2507 +55702,2507 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "säiekohtainen esittely %q#D seuraa ei-säiekohtaista esittelyä"
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "ei-säiekohtainen esittely %q#D seuraa säiekohtaista esittelyä"
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "luetellun tyypin jäsenen %q+D uudelleenesittely"
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, fuzzy, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "%q+D:n data-alue on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, fuzzy, gcc-internal-format
 msgid "previous label"
 msgstr "edellinen esittely"
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, gcc-internal-format
 msgid "jump to label %qD"
 msgstr "hyppy nimiöön %qD"
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr "hyppy case-nimiöön"
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr ""
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  täältä"
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, fuzzy, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  ohittaa %q+#D:n alustuksen"
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, fuzzy, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr "  siirtyy try-lohkoon"
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, fuzzy, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, fuzzy, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, fuzzy, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "lauseella ei ole vaikutusta"
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, fuzzy, gcc-internal-format
 msgid "  enters statement expression"
 msgstr "Odotettiin lauseketta %s-lauseessa kohdassa %C"
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, fuzzy, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, fuzzy, gcc-internal-format
 msgid "  enters %<consteval if%> statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, fuzzy, gcc-internal-format
 msgid "  does not destroy %qD"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, fuzzy, gcc-internal-format
 msgid "  does not clean up handled exception"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  ohittaa %q+#D:n alustuksen"
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is a function, not a type"
 msgstr "%qD ei ole funktiomalli"
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T ei ole luokka"
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, fuzzy, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "%<typename %T::%D%> nimeää kohteen %q#T:n, joka ei ole luokkamalli"
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nimeää kohteen %q#T:n, joka ei ole luokkamalli"
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, fuzzy, gcc-internal-format
 #| msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> nimeää %q#T:n, joka ei ole tyyppi"
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, fuzzy, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "dwarfin versio %d ei ole tuettu"
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
 # semi-fuzzy
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, fuzzy, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr "anonyymillä structilla ei voi olla funktiojäseniä"
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "ei argumentteja"
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "ei argumentteja"
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "ei argumentteja"
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "attribuutti jätetty huomioimatta %q+#T:n esittelyssä"
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "%q+#T:n attribuutin on oltava %qs-avainsanan perässä"
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "useita tyyppejä yhdessä esittelyssä"
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "C++:n sisäinen tietotyyppi %qT määritelty uudelleen"
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "tallennusluokan voi antaa vain objekteille ja funktioille"
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "tyypin nimi puuttuu typedef-esittelystä"
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ kieltää nimettömät structit"
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "tallennusluokan voi antaa vain olioille ja funktioille"
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "tallennusluokan voi antaa vain olioille ja funktioille"
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, fuzzy, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "tallennusluokan voi antaa vain olioille ja funktioille"
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "määreet voidaan määrittää vain olioille ja funktioille"
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "tyypin nimi puuttuu typedef-esittelystä"
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%Hprototyypin esittely"
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD on alustettu (käytä __typeof__ sen sijaan)"
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "parametrilla %q+D on vain etukäteisesittely"
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "malliesittelylle %q+D"
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "jäsenen %q+D kaksoiskappale"
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr ""
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "muuttujalla %q#D on alustin, mutta vaillinainen tyyppi"
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "taulukon %q#D alkiot ovat vaillinaista tyyppiä"
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, fuzzy, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "parametrin %qD tyyppi on vaillinainen"
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD esitelty viitteenä, mutta alustamatta"
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, fuzzy, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, fuzzy, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "dwarfin versio %d ei ole tuettu"
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "alustin ei pysty päättelemään taulukon %q+D kokoa"
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD-taulukon koko puuttuu"
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "nollan kokoinen taulukko %qD"
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "%qD:n koko muistissa ei ole tunnettu"
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "%qD:n koko muistissa ei ole vakio"
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "  voit kiertää tämän poistamalla alustimen"
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, fuzzy, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "alustamaton const %qD"
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, fuzzy, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, fuzzy, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, fuzzy, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "liikaa alustimia %qT:lle"
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, fuzzy, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "alustimen ympäriltä puuttuu aaltosulkeet"
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "taulukon %q#D alkiot ovat vaillinaista tyyppiä"
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "muuttuvakokoinen yhdysliteraali"
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D on vaillinaista tyyppiä"
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "skalaariobjekti %qD vaatii yhden alkion alustimeensa"
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "C++98:ssa %qD on alustettava muodostimessa, ei käyttäen %<{...}%>"
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "taulukko %qD alustettu sulkujen sisällä olevalla merkkijonoliteraalilla %qE"
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, fuzzy, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, fuzzy, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "  ohittaa %q+#D:n alustuksen"
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qD esitelty viitteenä, mutta ei ole alustettu"
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "liian vähän argumentteja muodostimelle %q#D"
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "hajottimen %qE osoitteen ottaminen"
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "sijoitus (ei alustus) esittelyssä"
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "%<register%>-tallennusluokkamääritteen käyttö"
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D:n esittelyllä ei ole alustimia"
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "jäsentä %q+D käytetty virheellisesti staattisessa jäsenfunktiossa"
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, fuzzy, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "muuttujalla %qD on alustin, mutta vaillinainen tyyppi"
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "%q+D:n edellinen esittely"
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qE-attribuutti soveltuu vain muuttujiin ja funktioihin"
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "funktio %q#D alustetaan kuin muuttuja"
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 kieltää muuttuvakokoisen taulukon %qE"
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs määritelty tietueen kentälle"
 msgstr[1] "%qs määritelty tietueen kentälle"
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] "%qs määritelty tietueen kentälle"
 msgstr[1] "%qs määritelty tietueen kentälle"
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "Pyydettyä osoitetta ei voi asettaa"
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "Java-luokalla %qT ei voi olla implisiittistä epätriviaalia hajotinta"
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "Java-luokalla %qT ei voi olla implisiittistä epätriviaalia hajotinta"
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "alustin ei pysty päättelemään taulukon %q+D kokoa"
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "%qD-taulukon koko puuttuu"
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "nollan kokoinen taulukko %qD"
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, fuzzy, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "Java-luokalla %qT ei voi olla hajotinta"
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, fuzzy, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "Java-luokalla %qT ei voi olla hajotinta"
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "nimike %qD esitelty muttei määritelty"
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD ei ole luokka eikä nimiavaruus"
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "%qD:n poistettu määrittely"
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, fuzzy, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, fuzzy, gcc-internal-format
 msgid "constrained non-template friend declaration must be a definition"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "%<inline%> tyhjässä esittelyssä"
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "%qD ei ole malli"
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, fuzzy, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, fuzzy, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, fuzzy, gcc-internal-format
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, fuzzy, gcc-internal-format
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, fuzzy, gcc-internal-format
 msgid "explicit object parameter declared here"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "malli C-linkityksellä"
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "virheellinen IACC-argumentti"
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, fuzzy, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "virheellinen loppuliite ”%.*s” kokonaislukuvakiolla"
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, fuzzy, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "virheellinen loppuliite ”%.*s” kokonaislukuvakiolla"
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, fuzzy, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "paluutyyppi on oletuksena %<int%>"
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, fuzzy, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "funktion määrittely esitelty %<auto%>:ksi"
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "%q+D:n edellinen määrittely oli täällä"
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+D:n edellinen määrittely oli täällä"
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, fuzzy, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, fuzzy, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "keskeytysfunktiolla on oltava void-paluutyyppi"
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, fuzzy, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "muuttujalla %qD on alustin, mutta vaillinainen tyyppi"
 
 # semi-fuzzy
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, fuzzy, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ kieltää jäsenen %qD alustuksen"
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "taulukon %qD koolla on epäkokonaislukutyyppi %qT"
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "taulukon koolla on epäkokonaislukutyyppi %qT"
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon %qD"
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon"
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ kieltää muuttuvakokoisen taulukon %qD"
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ kieltää muuttuvakokoisen taulukon"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, fuzzy, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "taulukon koon ylivuoto"
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, fuzzy, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "%qD:n esittely void-taulukkona"
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "luodaan void-taulukko"
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "%qD:n esittely funktioiden taulukkona"
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "luodaan funktioiden taulukko"
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "%qD:n esittely viitteiden taulukkona"
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "luodaan viitteiden taulukko"
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "%qD:n esittely funktiojäsenten taulukkona"
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "luodaan funktiojäsenten taulukkoa"
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "moniulotteisell taulukolla on oltava rajat kaikkiin suuntiin paitsi ensimmäiseen"
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "moniulotteisell taulukolla on oltava rajat kaikkiin suuntiin paitsi ensimmäiseen"
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable-length array of %<auto%>"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, fuzzy, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, fuzzy, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, fuzzy, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "nimetön muuttuja tai kenttä esitelty voidiksi"
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "muuttuja tai kenttä esitelty voidiksi"
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, fuzzy, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "Virheellinen käyttäjänimi ”%s” funktiossa %s, rivillä %d. Keskeytys."
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "määrittelemättömän tyypin %<%s %s%> epäkelpo käyttö"
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "Virheellinen käyttäjänimi ”%s” funktiossa %s, rivillä %d. Keskeytys."
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%qT ei ole luokka eikä nimiavaruus"
 
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "funktion määrittely ei esittele parametrejä"
 
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "vaillinaisen tyypin typedef %qD epäkelpo käyttö"
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%Hprototyypin esittely"
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "yli yksi tietotyyppi esittelymääritteissä"
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ei tue pelkkää %<complex%>-tyyppiä merkityksellä %<double complex%>"
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ kieltää muuttujan %qs esittelyn ilman tyyppiä"
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "kohteen int-tyyppi on kapeampi kuin kohteen char-tyyppi"
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ 1998 ei tue %<long long%> -tyyppiä"
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "sekä %<signed%> että %<unsigned%> määritelty %qs:lle"
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "sekä %<long%> että %<short%> määritelty %qs:lle"
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qE:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with typedef-name %qD"
 msgstr "%qE ei ole typedef eikä sisäinen tyyppi"
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qE ei ole typedef eikä sisäinen tyyppi"
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qE ei ole typedef eikä sisäinen tyyppi"
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, fuzzy, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "epäkelpo osoitintila %qs"
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, fuzzy, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, fuzzy, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "tallennusluokka annettu malliparametrille %qs"
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> luokan esittelyn ulkopuolella"
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "attribuutti jätetty huomioimatta %q+#T:n esittelyssä"
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "virheellinen funktioesittely"
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "attribuutti jätetty huomioimatta %q+#T:n esittelyssä"
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "attribuutti jätetty huomioimatta %q+#T:n esittelyssä"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "useita tallennusluokkia %qs:n esittelyssä"
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "tallennusluokka annettu %qs:lle"
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, fuzzy, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "%<auto%> tiedostoalueen tyhjässä esittelyssä"
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "funktioalue %qs implisiittisesti auto ja esitelty %<__thread%>:ksi"
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, fuzzy, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attribuuttia ei huomioida"
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, fuzzy, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "%qE-attribuuttia ei huomioida %qT-tyyppiselle kentälle"
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "tarpeettomat sulkeet %qs:n esittelyssä"
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, fuzzy, gcc-internal-format
 msgid "remove parentheses"
 msgstr "Odotettiin oikeaa sulkumerkkiä lausekkeessa kohdassa %C"
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, fuzzy, gcc-internal-format
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, fuzzy, gcc-internal-format
 msgid "a function type cannot have an explicit object parameter"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, fuzzy, gcc-internal-format
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, fuzzy, gcc-internal-format
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr ""
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, fuzzy, gcc-internal-format
 msgid "the type of an explicit object member function is a regular function type"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, fuzzy, gcc-internal-format
 msgid "valid explicit object parameter declared here"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, fuzzy, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, fuzzy, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "tyyppimääreet jätetään huomiotta funktion paluutyypissä"
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, fuzzy, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "%qD:n paluuarvon tyyppi ei ole %<int%>"
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs esitelty taulukon palauttavan funktiona"
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<noreturn%>-funktio palauttaa ei-void-arvon"
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "muodostin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "muodostimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "muodostimia ei voi esitellä virtuaalisiksi"
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, fuzzy, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, fuzzy, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, fuzzy, gcc-internal-format
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, fuzzy, gcc-internal-format
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr "mallit eivät voi olla virtuaalisia"
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, fuzzy, gcc-internal-format
 msgid "an explicit object member function cannot be %<static%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be an explicit object member function"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "hajottimilla ei voi olla parametreja"
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, fuzzy, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "ylimääräinen kvalifiointi %<%T::%> jäsenelle %qs"
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, fuzzy, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, fuzzy, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> luokan esittelyn ulkopuolella"
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> tyhjässä esittelyssä"
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, fuzzy, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "vain muodostimen esittely voi olla %<explicit%>"
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, fuzzy, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "funktion määrittely esitelty %<auto%>:ksi"
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "<typedef-virhe>"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, fuzzy, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "kentällä %q+#D on sama nimi kuin luokalla"
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "virheelliset määreet ei-jäsenfunktion tyypissä"
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "<typedef-virhe>"
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, fuzzy, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "%q+D esitelty staattisena, edellinen esittely ei-staattinen"
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, fuzzy, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr "%qD ei ole funktiomalli"
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "parametri esitelty %<auto%>:ksi"
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parametri esitelty %<auto%>:ksi"
 
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon %qD"
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "%qD:n virheellinen käyttö"
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "virheellinen funktioesittely"
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "%qD esitelty staattisesti sisäkkäin"
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "%qD esitelty staattisesti sisäkkäin"
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "Kopiomuodostin %qs"
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "tiedostoa %s ei voi avata"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "nimellä %qT on vaillinainen tyyppi"
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, fuzzy, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, fuzzy, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr "%qE-attribuuttia ei huomioida %qT-tyyppiselle kentälle"
 
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "tallennusluokka %<auto%> virheellinen funktiolle %qs"
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "tallennusluokka %<register%> virheellinen funktiolle %qs"
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "tallennusluokka %<__thread%> virheellinen funktiolle %qs"
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "tallennusluokka %<__thread%> virheellinen funktiolle %qs"
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr "kohdistusta ei voi määritellä %q+D:lle"
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, fuzzy, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, fuzzy, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, fuzzy, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, fuzzy, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "%qD käytössä ilman esittelyä ennen sen määrittelyä"
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs on sekä %<extern%> että alustin"
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "vaillinaisen tyypin typedef %qD epäkelpo käyttö"
 
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "Varoita implisiittisistä funktioesittelyistä"
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parametri %qD virheellisesti esitelty metodityyppi"
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "virheellinen muodostin; tarkoitit todennäköisesti %<%T (const %T&)%>"
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, fuzzy, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, fuzzy, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, fuzzy, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ kieltää ?:-operaattorin ylikuormituksen"
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD:lla ei saa olla vaihtuvaa määrää argumentteja"
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD:n on otettava joko nolla tai yksi argumenttia"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD:n on otettava joko yksi tai kaksi argumenttia"
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD:n on otettava tasan kaksi argumenttia"
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD:n on otettava tasan yksi argumentti"
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD:n on otettava tasan kaksi argumenttia"
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, fuzzy, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "vertailu ”etumerkitön lauseke >= 0” on aina tosi"
 
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, fuzzy, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "<paluuarvo> "
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "<paluuarvo> "
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, fuzzy, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "<paluuarvo> "
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, fuzzy, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "lueteltu tyyppi määritelty täällä"
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "lueteltu tyyppi määritelty täällä"
@@ -58207,116 +58214,101 @@ msgstr "lueteltu tyyppi määritelty täällä"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "jäsennysvirhe malliargumenttien luettelossa"
 
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%qD-viittaus on moniselitteinen"
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, fuzzy, gcc-internal-format
 #| msgid "function template %qD redeclared as a class template"
 msgid "class template %qD redeclared as non-template"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD:llä on sama nimi kuin luokalla, jossa se on esitelty"
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT ei ole malli"
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "on ristiriidassa %q+#D:n edellisen esittelyn kanssa"
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "C++:n sisäinen tietotyyppi %qT määritelty uudelleen"
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, fuzzy, gcc-internal-format
-msgid "cannot declare %qD in a different module"
-msgstr "bittikentän %qD osoitetta ei voi ottaa"
-
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, gcc-internal-format
-msgid "previously declared here"
-msgstr "esitelty aiemmin täällä"
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, fuzzy, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "useita kenttiä unionissa %qT alustettu"
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT määritelty monella suoralla kannoalla"
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT määritelty suoralla virtuaalisella kannalla"
 
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/decl.cc:16984
-#, fuzzy, gcc-internal-format
-msgid "cannot declare %qD in different module"
-msgstr "bittikentän %qD osoitetta ei voi ottaa"
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, fuzzy, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "edellinen määrittely täällä"
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, fuzzy, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, fuzzy, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "cppchar_t:n on oltava etumerkitön tyyppi"
@@ -58325,82 +58317,82 @@ msgstr "cppchar_t:n on oltava etumerkitön tyyppi"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "ylivuoto luetellun tyypin arvoissa"
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, fuzzy, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "return-lause ilman arvoa funktiossa, jonka paluutyyppi on %qT"
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "funktion paluuarvojen tyypit eivät ole yhteensopivia %<volatile%>:n takia"
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, fuzzy, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "ei palautuslausetta funktiossa, joka palauttaa ei-voidin"
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD on jo määritelty"
 
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, fuzzy, gcc-internal-format
 msgid "using %qs"
 msgstr "          %s"
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "%q+D:n oletustyyppi on %<int%>"
@@ -58455,7 +58447,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "malliesittelylle %q+D"
@@ -58465,7 +58457,7 @@ msgstr "malliesittelylle %q+D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, fuzzy, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
@@ -58650,64 +58642,64 @@ msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%>:n ensimmäisen parametrin tyypin on oltava %qT"
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, fuzzy, gcc-internal-format
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qD esitelty uudelleen eri näkyvyydellä"
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, gcc-internal-format
 msgid "%qT has a base %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, gcc-internal-format
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, gcc-internal-format
 msgid "%qT has a base %qT which has internal linkage"
 msgstr ""
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, gcc-internal-format
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qD esitelty uudelleen eri näkyvyydellä"
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr "%J%qF käytetty, mutta ei määritelty"
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but not defined"
 msgstr "%J%qF käytetty, mutta ei määritelty"
@@ -58716,104 +58708,104 @@ msgstr "%J%qF käytetty, mutta ei määritelty"
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "%J%qD esitelty uudelleen ilman linkitystä"
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "%J%qD esitelty uudelleen ilman linkitystä"
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%J%qF käytetty, mutta ei määritelty"
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr "%J%qF käytetty, mutta ei määritelty"
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "%J%qD esitelty uudelleen ilman linkitystä"
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "%J%qD esitelty uudelleen ilman linkitystä"
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q+D:n data-alue on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, fuzzy, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "edellinen esittely %q+D"
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, gcc-internal-format
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q#D"
 msgstr "oletusargumentti annettu %2$q#D:n parametrille %1$d"
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, fuzzy, gcc-internal-format
 msgid "...following parameter %P which has a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, gcc-internal-format
 msgid "implicitly-declared %qD is deprecated"
 msgstr "implisiittisesti esitelty %qD on vanhentunut"
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, fuzzy, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "NULLin muunnos epäosoitintyypiksi"
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "poistettu funktio %q+D"
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, fuzzy, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -58918,7 +58910,7 @@ msgstr "palautettu viittaus paikalliseen muuttujaan %q+D"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
@@ -58928,7 +58920,7 @@ msgstr "%qD:n esittely %qT:n jäsenenä"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD ei ole %qD:n jäsen"
@@ -58953,47 +58945,47 @@ msgstr ""
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, fuzzy, gcc-internal-format
 msgid "  in thrown expression"
 msgstr "LAUSEKE"
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, gcc-internal-format
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr ""
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, gcc-internal-format
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr ""
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, fuzzy, gcc-internal-format
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr "%<%T%>-tyyppinen poikkeus siepataan"
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, fuzzy, gcc-internal-format
 msgid "for type %qT"
 msgstr "abs-funktiolle annettu väärä tyyppiargumentti"
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, gcc-internal-format
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr ""
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr ""
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
 msgstr ""
@@ -59260,12 +59252,12 @@ msgstr "perustyypin %qT kaksoiskappale virheellinen"
 msgid "type %qT is not a direct base of %qT"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, fuzzy, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT ei ole luokkatyyppi"
@@ -59280,12 +59272,12 @@ msgstr "luokalla %qT ei ole %qD-nimistä kenttää"
 msgid "invalid pointer to bit-field %qD"
 msgstr "virheellinen osoitin bittikenttään %qD"
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
@@ -59480,52 +59472,52 @@ msgstr ""
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, fuzzy, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, fuzzy, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr "yhdysliteraalin koko on muuttuva"
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, fuzzy, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "versioviitetaulukolle ei voi varata muistia"
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, fuzzy, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr "%qE on vanhentunut"
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr "lisää eksplisiittinen %<this%>- tai %<*this%>-kaappaus"
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, fuzzy, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "Lambda-funktio"
@@ -59897,228 +59889,273 @@ msgstr "odotettiin %<template%>"
 msgid "encapsulation is malformed"
 msgstr ""
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting global module declaration %#qD"
 msgstr "ristiriitainen esittely %q#D"
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration %q+D"
 msgid "existing declaration %#qD"
 msgstr "esittelyssä %q+D"
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, fuzzy, gcc-internal-format
 #| msgid "missing definition"
 msgid "existing definition %qD"
 msgstr "puuttuva määrittely"
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "... this enumerator %qD"
 msgstr "luetellun tyypin jäsenen %q+D uudelleenesittely"
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, fuzzy, gcc-internal-format
 msgid "enumerator %qD does not match ..."
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr ""
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr ""
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr ""
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, fuzzy, gcc-internal-format
 msgid "recursive lazy load"
 msgstr "    Rekursiiviset jäsenet:\n"
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr ""
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, fuzzy, gcc-internal-format
 msgid "module %qs declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, fuzzy, gcc-internal-format
 msgid "indirect import %qs is not already loaded"
 msgstr "%s%qs%s ei ole sallittu"
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr ""
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr ""
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, fuzzy, gcc-internal-format
 msgid "macro definitions of %qE corrupted"
 msgstr "%q+D:n edellinen määrittely oli täällä"
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, fuzzy, gcc-internal-format
 msgid "inconsistent imported macro definition %qE"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr ""
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr ""
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, fuzzy, gcc-internal-format
 msgid "compiled module file is %qs"
 msgstr "Ei voida poistaa moduulitiedostoa ”%s”: %s"
 
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "compiled module is %sversion %s"
 msgstr "  --version                Näytä kääntäjän versiotiedot\n"
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collect2 version %s\n"
 msgid "compiler is %sversion %s%s%s"
 msgstr "collect2-versio %s\n"
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, fuzzy, gcc-internal-format
 msgid "module %qs found"
 msgstr "Ei löydy"
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr ""
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr ""
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr ""
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr ""
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, gcc-internal-format
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr ""
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, fuzzy, gcc-internal-format
 msgid "fixed tree mismatch"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, fuzzy, gcc-internal-format
 msgid "interface partition is not exported"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module cluster %u: %s"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module: %s"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr ""
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr ""
 
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr ""
 
-#: cp/module.cc:19283
+#: cp/module.cc:19117
+#, fuzzy, gcc-internal-format
+msgid "declaration %qD conflicts with builtin"
+msgstr "%q+D:n osoitealue on ristiriidassa edellisen esittelyn kanssa"
+
+#: cp/module.cc:19122
+#, fuzzy, gcc-internal-format
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr "nimiavaruuden %qD esittely on ristiriidassa"
+
+#: cp/module.cc:19125
+#, fuzzy, gcc-internal-format
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr "nimiavaruuden %qD esittely on ristiriidassa"
+
+#: cp/module.cc:19130
+#, fuzzy, gcc-internal-format
+msgid "import declared attached to module %qs"
+msgstr "esitelty täällä"
+
+#: cp/module.cc:19134
+#, fuzzy, gcc-internal-format
+msgid "import declared in global module"
+msgstr "virtuaalinen ei-luokkafunktio %qs"
+
+#: cp/module.cc:19140
+#, fuzzy, gcc-internal-format
+msgid "conflicting declaration of %qD in module %qs"
+msgstr "malliesittelylle %q+D"
+
+#: cp/module.cc:19143
+#, fuzzy, gcc-internal-format
+msgid "conflicting declaration of %qD in global module"
+msgstr "%q#D:n esittely C-kielen linkityksellä"
+
+#: cp/module.cc:19148
+#, fuzzy, gcc-internal-format
+msgid "previously declared in module %qs"
+msgstr "esitelty aiemmin täällä"
+
+#: cp/module.cc:19152
+#, fuzzy, gcc-internal-format
+msgid "previously declared in global module"
+msgstr "esitelty aiemmin täällä"
+
+#: cp/module.cc:19404
 #, fuzzy, gcc-internal-format
 msgid "reading CMI %qs"
 msgstr "          %s"
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, gcc-internal-format
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, fuzzy, gcc-internal-format
 msgid "during load of pendings for %<%E%s%E%>"
 msgstr "tuntematon valitsin -%s"
@@ -60130,394 +60167,394 @@ msgstr "tuntematon valitsin -%s"
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr ""
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, fuzzy, gcc-internal-format
 msgid "module already declared"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, fuzzy, gcc-internal-format
 #| msgid "In module imported at"
 msgid "module already imported"
 msgstr "Moduulissa, joka tuotu kohdassa"
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, fuzzy, gcc-internal-format
 #| msgid "In module imported at"
 msgid "module %qs imported here"
 msgstr "Moduulissa, joka tuotu kohdassa"
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown Compiled Module Interface: %s"
 msgstr "Tuntematon tiheys: ”%c”"
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr ""
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr ""
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr ""
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, gcc-internal-format
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr ""
 
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, fuzzy, gcc-internal-format
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr "virheellinen esikääntäjän direktiivi #%s"
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr ""
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr ""
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, fuzzy, gcc-internal-format
 msgid "you should use the %<-%s%> option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, fuzzy, gcc-internal-format
 msgid "invalid header name %qs"
 msgstr "virheellinen --param-arvo %qs"
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, fuzzy, gcc-internal-format
 msgid "invalid module name %qs"
 msgstr "virheellinen --param-arvo %qs"
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr ""
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, fuzzy, gcc-internal-format
 msgid "writing CMI %qs"
 msgstr "virhe kirjoitettaessa i-solmua"
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing modules file: %s"
 msgid "not writing module %qs due to errors"
 msgstr "Virhe kirjoitettaessa moduulitiedostoa %s"
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to write compiled module: %s"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, fuzzy, gcc-internal-format
 msgid "unknown header kind %qs"
 msgstr "tls_model-argumentti ei ole merkkijono"
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, fuzzy, gcc-internal-format
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "malliesittelylle %q+D"
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q+D:n data-alue on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, fuzzy, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "muuttujan %q+D koko muistissa ei ole tunnettu"
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, fuzzy, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "ristiriitainen esittely %q#D"
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, fuzzy, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "parametri %qD virheellisesti esitelty metodityyppi"
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "%q+D:n esittely varjostaa sisäänrakennetun funktion"
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "friend-esittely %qD paikallisessa luokassa ilman edeltävää esittelyä"
 
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, fuzzy, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, fuzzy, gcc-internal-format
 msgid "exporting %q#D that does not have external linkage"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here with no linkage"
 msgstr "%q+D esitelty täällä"
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here with internal linkage"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here with module linkage"
 msgstr "%q+D esitelty täällä"
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, fuzzy, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T::%D%> nimeää muodostimen, ei tyyppiä"
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, fuzzy, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, fuzzy, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qE ei ole luokka, nimiavaruus eikä lueteltu tyyppi"
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, fuzzy, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, fuzzy, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a direct base of %qT"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, fuzzy, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr "oliko tarkoitus käyttää loogista negaatiota?"
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "ristiriitainen esittely %q#D"
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> nimeää muodostimen, ei tyyppiä"
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD ei ole luokka eikä nimiavaruus"
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD:n esittely viitteiden taulukkona"
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, fuzzy, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, fuzzy, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qs-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "%<fast_interrupt%>-attribuuttidirektiivi jätetty huomiotta"
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "ehdotettu vaihtoehto:"
 msgstr[1] "ehdotetut vaihtoehdot:"
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, fuzzy, gcc-internal-format
 msgid "  %qE"
 msgstr "%qE on vanhentunut"
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr ""
 
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, fuzzy, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<this%> ei ole käytettävissä staattisissa jäsenfunktioissa"
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr "määriteltiin myöhemmin tässä"
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, fuzzy, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, fuzzy, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "nimiö %qD määritelty täällä"
 
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, fuzzy, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "edellinen määrittely täällä"
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -60542,7 +60579,7 @@ msgstr "tunniste %qE on ristiriidassa C++:n varatun sanan kanssa"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
@@ -60788,7 +60825,7 @@ msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
@@ -60968,7 +61005,7 @@ msgstr ""
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, fuzzy, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "odotettiin lauseketta"
@@ -61023,7 +61060,7 @@ msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 msgid "template-id not allowed for destructor in C++20"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, fuzzy, gcc-internal-format
 msgid "remove the %qs"
 msgstr "Odotettiin oikeaa sulkumerkkiä lausekkeessa kohdassa %C"
@@ -61043,7 +61080,7 @@ msgstr "%qD ei ole mallifunktio"
 msgid "expected unqualified-id"
 msgstr "ID"
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD ei ole malli"
@@ -61093,7 +61130,7 @@ msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
@@ -61128,7 +61165,7 @@ msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr ""
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "%qD:n virheellinen käyttö"
@@ -61153,7 +61190,7 @@ msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
@@ -61303,8 +61340,8 @@ msgstr "tallennusluokka annettu parametrille %qs"
 msgid "capture of non-variable %qE"
 msgstr "%qD ei ole muuttuja"
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q+D esitelty täällä"
@@ -61344,7 +61381,7 @@ msgstr "oletusargumentti määritelty lambda-parametrille"
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr ""
@@ -61469,7 +61506,7 @@ msgstr ""
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
@@ -61531,7 +61568,7 @@ msgstr "%Jparametrin %qD tyyppi on vaillinainen"
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
@@ -61557,7 +61594,7 @@ msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ kieltää lasketut goto-käskyt"
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
@@ -61839,12 +61876,12 @@ msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 msgid "cannot expand initializer for member %qD"
 msgstr "ei voi laajentaa alustinta jäsenelle %<%D%>"
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D esitelty staattisena, edellinen esittely ei-staattinen"
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, fuzzy, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
@@ -62482,7 +62519,7 @@ msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole obj
 msgid "%qT not permitted in template argument"
 msgstr "täsmäämättömät argumentit"
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
@@ -62661,12 +62698,12 @@ msgstr "edellinen %q+#T:n määrittely"
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, gcc-internal-format
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr ""
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "odotettiin %<class%>"
@@ -62870,37 +62907,37 @@ msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 msgid "expression must be enclosed in parentheses"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr ""
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, fuzzy, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, fuzzy, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "virheellinen %<%T::%E%>:n esittely"
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "%J%qD:n edellinen esittely oli täällä"
@@ -62909,439 +62946,439 @@ msgstr "%J%qD:n edellinen esittely oli täällä"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, fuzzy, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, fuzzy, gcc-internal-format
 msgid "template-id not allowed for constructor in C++20"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "nimetyt paluuarvot eivät ole enää tuettuja"
 
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, fuzzy, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "lopetusalkio puuttuu funktiokutsusta"
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "malliesittelylle %q+D"
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "malli C-linkityksellä"
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "    Ei ilmaistuja epäjäseniä\n"
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "malliesittelylle %q+D"
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, fuzzy, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "esittely ei esittele mitään"
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, fuzzy, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, fuzzy, gcc-internal-format
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "%<sizeof...%>-argumentti on ympäröitävä sulkeilla"
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD specifier"
 msgstr "Kaksoiskappale pääsy-tarkenne kohdassa %C"
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, fuzzy, gcc-internal-format
 msgid "%qD specifier conflicts with %qs"
 msgstr "Tuntematon (tyyppi = %d, bitit = %d)\n"
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, fuzzy, gcc-internal-format
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr "%qE ei ole typedef eikä sisäinen tyyppi"
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 ei tue %<long long%> -tyyppiä"
 
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "sekä %<_Sat%> että %<char%> esittelymääritteissä"
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "ylimääräinen %<const%>"
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "kaksois-%qs"
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "odotettiin %<new%>"
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "odotettiin %<delete%>"
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "odotettiin %<return%>"
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "odotettiin %<extern%>"
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "odotettiin %<static_assert%>"
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "odotettiin %<decltype%>"
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "odotettiin %<operator%>"
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "odotettiin %<class%>"
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "odotettiin %<namespace%>"
 
 # XXXXXXX
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "odotettiin %<=%>, %<,%>, %<;%>, %<asm%> tai %<__attribute__%>"
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "<throw-lauseke>"
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "nimiö "
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "Taso 2 ei ole synkronoitu"
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "<throw-lauseke>"
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, fuzzy, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "odotettiin %<(%> tai rivin loppu"
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "odotettiin %<:%> tai %<...%>"
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, fuzzy, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs määritelty parametrille %qE"
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, fuzzy, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qD esitelty uudelleen eri näkyvyydellä"
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "odotettiin %<class%>"
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, fuzzy, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "nimiö %qD määritelty täällä"
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, fuzzy, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "esitelty täällä"
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD esitelty uudelleen eri näkyvyydellä"
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "C++98:ssa %<template%> (selventimenä) on sallittu vain malleissa"
 
 # XXX
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, fuzzy, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, fuzzy, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "%qE ei ole Objective-C-luokkanimi eikä -alias"
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "Odotettiin toista ulottuvuutta taulukkoesittelyssä kohdassa %C"
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "ylimääräinen %qs Objective-C++-metodien välissä"
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qs-attribuuttia ei huomioida %qs:lle"
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "virheellinen vastaanottajatyyppi %qs"
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr "<tuntematon>"
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
@@ -63350,12 +63387,12 @@ msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "Alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
@@ -63365,133 +63402,133 @@ msgstr "Alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr ""
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "epäkelpo alustin"
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, fuzzy, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, fuzzy, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "edellinen esittely"
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, fuzzy, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, fuzzy, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "edellinen esittely"
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, fuzzy, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr "_Peru"
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "Käyttö: %s <transaktiotiedosto> <tiedostojärjestelmä>\n"
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, fuzzy, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, fuzzy, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "tuntematon #pragma GCC coprocessor %E"
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, fuzzy, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, fuzzy, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "Avainsana-argumentti ”%s” kohdassa %L ei ole proseduurissa"
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, fuzzy, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "mallit eivät voi olla virtuaalisia"
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -63521,7 +63558,7 @@ msgstr "muodostimen virheellinen käyttö mallina"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "%qD ei ole nimiavaruuden nimi"
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "%qD ei ole nimiavaruuden nimi"
@@ -63536,170 +63573,170 @@ msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "funktio %qE esitelty implisiittisesti"
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "(mahdollisesti %qT:n määrittelyn perästä puuttuu puolipiste)"
 
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, fuzzy, gcc-internal-format
 msgid "from definition of %q#D"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, fuzzy, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "(mahdollisesti %qT:n määrittelyn perästä puuttuu puolipiste)"
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "(mahdollisesti %qT:n määrittelyn perästä puuttuu puolipiste)"
 
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, fuzzy, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %d"
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD ei ole funktiomalli"
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD ei ole muuttujamalli"
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "%qD:n tyyppi ei täsmää aiemman esittelyn kanssa"
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, fuzzy, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, fuzzy, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "(mahdollisesti %qT:n määrittelyn perästä puuttuu puolipiste)"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "(mahdollisesti %qT:n määrittelyn perästä puuttuu puolipiste)"
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "ensiö"
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "ensiö"
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, fuzzy, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, fuzzy, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, fuzzy, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, fuzzy, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, fuzzy, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "Odotettiin toista ulottuvuutta taulukkoesittelyssä kohdassa %C"
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "funktio %qE esitelty implisiittisesti"
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, fuzzy, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, fuzzy, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, fuzzy, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD ei ole mallifunktio"
@@ -63712,154 +63749,154 @@ msgstr "%qD ei ole mallifunktio"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, fuzzy, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "funktio %qE esitelty implisiittisesti"
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, fuzzy, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, fuzzy, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, fuzzy, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr "        %s"
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%J%qD:n esittely varjostaa parametria"
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "%qs:n esittelyssä tyyppi on oletuksena %<int%>"
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "ensiö"
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, fuzzy, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, fuzzy, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "liian monta argumenttia funktiolle %qE"
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "ensiö"
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, fuzzy, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "%Jparametrin nimi puuttuu parametrilistasta"
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, fuzzy, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "%Jparametrin nimi puuttuu parametrilistasta"
 
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 msgstr[1] "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
@@ -63868,47 +63905,47 @@ msgstr "%qD:lla ei voi olla oletusargumentteja"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%Jparametrin nimi puuttuu parametrilistasta"
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "%qD-malli esitelty"
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, fuzzy, gcc-internal-format
 msgid "template class without a name"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
@@ -63918,507 +63955,507 @@ msgstr "useita tallennuspaikkoja esittelymääritteissä"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD ei ole malli"
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, fuzzy, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, fuzzy, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "  odotettiin tyyppiä, saatiin %qT"
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  mutta %d vaaditaan"
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, fuzzy, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD with different constraints"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT ei ole malli"
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qs:n esittelyssä tyyppi on oletuksena %<int%>"
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "%J%qD:n edellinen esittely oli täällä"
 msgstr[1] "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "%J%qD:n edellinen esittely oli täällä"
 msgstr[1] "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, fuzzy, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "%q+D esitelty uudelleen erityyppisenä symbolina"
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "redeclared here"
 msgstr "esitelty täällä"
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "varjostunut esittely on täällä"
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D with different constraints"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, fuzzy, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, fuzzy, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "%Juseita parametreja nimellä %qD"
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, fuzzy, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  täsmäämättömät tyypit %qT ja %qT"
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qE-attribuuttia ei huomioida %qE:lle"
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, fuzzy, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, fuzzy, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  odotettiin %qT-tyyppistä vakiota, saatiin %qT"
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, fuzzy, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  odotettiin luokkamallia, saatiin %qE"
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  odotettiin tyyppiä, saatiin %qE"
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  odotettiin tyyppiä, saatiin %qT"
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  odotettiin tyyppiä, saatiin %qT"
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  odotettiin tyyppiä, saatiin %qE"
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "attribuutille %qs annettu väärä määrä argumentteja"
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "attribuutille %qs annettu väärä määrä argumentteja"
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, fuzzy, gcc-internal-format
 msgid "provided for %qD"
 msgstr "nimellä %qD"
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, fuzzy, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, fuzzy, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "%qT ei ole malli"
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qD ei ole muuttuja"
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, fuzzy, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, fuzzy, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "joustava taulukkojäsen unionissa"
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, fuzzy, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE ei ole esittelyn alussa"
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "  täsmäämättömät tyypit %qT ja %qT"
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "  täsmäämättömät tyypit %qT ja %qT"
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "%q+D määritelty uudelleen"
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "mismatched argument pack lengths (%d vs %d)"
 msgstr "  täsmäämättömät tyypit %qT ja %qT"
@@ -64436,223 +64473,223 @@ msgstr "  täsmäämättömät tyypit %qT ja %qT"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "muuttujalla %qD on funktiotyyppi"
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "esittelyssä %q+D"
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "taulukon palauttava funktio"
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "funktion palauttava funktio"
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, fuzzy, gcc-internal-format
 msgid "forming reference to void"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "luodaan void-taulukko"
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%Jcase-arvo %qs ei ole luetellussa tyypissä"
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "alustinalkio ei ole vakiolauseke"
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "void-lausekkeen epäkelpo käyttö"
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, fuzzy, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "Käytä rekistereitä argumenttien välittämiseen"
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, fuzzy, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qE attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "attribuutille %qE annettu väärä määrä argumentteja"
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "käytetään virheellistä kenttää %qD"
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT on/käyttää anonyymiä tyyppiä"
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "ohjelman alustusta yritettäessä"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 #, fuzzy
 msgid "%s %#qS"
 msgstr ""
@@ -64660,82 +64697,82 @@ msgstr ""
 "%s, %s, %s, %s,\n"
 "%s, %s ja %s.\n"
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "funktio %qE esitelty implisiittisesti"
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, fuzzy, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "jäsenen %q+D kaksoiskappale"
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ kieltää metodiosoittimen käytön vähennyslaskussa"
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ kieltää metodiosoittimen käytön vähennyslaskussa"
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "jäsenen %q+D kaksoiskappale"
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, fuzzy, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "%q+D:n edellinen esittely oli täällä"
@@ -64747,163 +64784,163 @@ msgstr "%q+D:n edellinen esittely oli täällä"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "staattinen tai tyyppimääreitä ei-parametrisessa taulukkoesittelijässä"
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "%qT ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, fuzzy, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, fuzzy, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, fuzzy, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Tiedostoa ”%s” on jo tarkasteltu.\n"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, fuzzy, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "ei voi emuloida %qs"
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "%qE:n muunnos tyypistä %qT tyyppiin %qT ei ole yksiselitteinen"
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, fuzzy, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, fuzzy, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "alustusalkio ei ole vakio"
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, fuzzy, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "alustusalkio ei ole vakio"
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, fuzzy, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "alustusalkio ei ole vakio"
 
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
@@ -65109,633 +65146,633 @@ msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "%<for%>-silmukan alkuesittelyt ovat sallittuja vain C99-tilassa"
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, fuzzy, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr "täsmäämättömät argumentit"
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, fuzzy, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, fuzzy, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr "%qE:a saatetaan käyttää alustamattomana tässä funktiossa"
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "ei argumentteja"
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr "%<this%> ei ole käytettävissä staattisissa jäsenfunktioissa"
 
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, gcc-internal-format
 msgid "use explicit object parameter %qs instead"
 msgstr ""
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, fuzzy, gcc-internal-format
 msgid "name the explicit object parameter"
 msgstr "staattinen tai tyyppimääreitä ei-parametrisessa taulukkoesittelijässä"
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> ei ole käytettävissä staattisissa jäsenfunktioissa"
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> before it is valid"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> after it is valid"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, fuzzy, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE ei ole tyyppiä %qT"
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "ei-objektityyppinen yhdysliteraali %qT"
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, fuzzy, gcc-internal-format
 msgid "%<auto{x}%> cannot be constrained"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, fuzzy, gcc-internal-format
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, fuzzy, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "tallennusluokka annettu typenamelle"
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "malliesittelylle %q+D"
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, fuzzy, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "jäsentä %q+D käytetty virheellisesti staattisessa jäsenfunktiossa"
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "        %qD"
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, fuzzy, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, fuzzy, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "poistettu funktio %q+D"
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, fuzzy, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "poistettu funktio %q+D"
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, fuzzy, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "poistettu funktio %q+D"
 
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "täsmäämättömät argumentit"
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, fuzzy, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, fuzzy, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE ei ole tyyppi"
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, fuzzy, gcc-internal-format
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr ""
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, fuzzy, gcc-internal-format
 msgid "%<__type_pack_element%> index is out of range"
 msgstr "sulkumerkkien käyttö laskulausekkeen ympärillä on suositeltavaa |-operandissa"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "tarpeeton tyyppimääre tyhjässä esittelyssä"
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, fuzzy, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi vastaanottaa %<...%>:n kautta"
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member mapping %qE not supported"
 msgstr "Muodostin %qs"
 
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "tyypillä %qE on käyttäjän määrittelemä muodostin"
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, fuzzy, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "ISO C kieltää nollan kokoisen taulukon %qE"
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, fuzzy, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "tyypillä %qE on käyttäjän määrittelemä muodostin"
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, fuzzy, gcc-internal-format
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, fuzzy, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, fuzzy, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, fuzzy, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, fuzzy, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, fuzzy, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, fuzzy, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, fuzzy, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "%qE ei ole malli"
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, fuzzy, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "%qE ei ole malli"
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, fuzzy, gcc-internal-format
 msgid "%<filter%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%s:n arvon on oltava kokonaisluku"
 
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%Jparametrin %qD tyyppi on vaillinainen"
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, fuzzy, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr ""
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr ""
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr ""
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr ""
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %s"
 msgid "static assertion failed: %.*s"
 msgstr "staattinen väite epäonnistui: %s"
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "ei-vakio ehto staattiselle väitteelle"
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, fuzzy, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, fuzzy, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr ""
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr ""
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "  odotettiin luokkamallia, saatiin %qE"
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, fuzzy, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "ei-tuettu argumentti funktiolle %<__builtin_return_address%>"
@@ -65743,1181 +65780,1181 @@ msgstr "ei-tuettu argumentti funktiolle %<__builtin_return_address%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, fuzzy, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "osoitealueattribuuttia ei voi määritellä paikallisille muuttujille"
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, fuzzy, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, gcc-internal-format
 msgid " declared here"
 msgstr " esitelty täällä"
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, fuzzy, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, fuzzy, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "nimellä %qT on vaillinainen tyyppi"
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, fuzzy, gcc-internal-format
 msgid "%qD is not public"
 msgstr "        %qD"
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, fuzzy, gcc-internal-format
 msgid "%qD is mutable"
 msgstr "%qD ei ole muuttuja"
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, fuzzy, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr "%qD ei ole tyyppi"
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr "%qE-attribuutti pätee vain funktiotyyppeihin"
 
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "%qE-attribuutti pätee vain funktiotyyppeihin"
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "osoitealueattribuuttia ei voi määritellä paikallisille muuttujille"
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "%qE-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, fuzzy, gcc-internal-format
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, fuzzy, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, fuzzy, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%qE-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "universaali merkki %.*s ei ole kelvollinen tunniste"
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "universaali merkki %.*s ei ole kelvollinen tunniste"
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "nolla nollaosoitinvakiona"
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, fuzzy, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu tyyppimuunnos"
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä muunnoksesta puuttuu tyyppimuunnos"
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu tyyppimuunnos"
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ kieltää vertailun %<void *%>-osoittimen ja funktio-osoittimen välillä"
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ kieltää muunnoksen %<void *%>-osoittimen ja funktio-osoittimen välillä"
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ kieltää ehtolausekkeen %<void *%>-osoittimen ja funktio-osoittimen välillä"
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, fuzzy, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu tyyppimuunnos"
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, fuzzy, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä muunnoksesta puuttuu tyyppimuunnos"
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu tyyppimuunnos"
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, fuzzy, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "?:-lausekkeen operandeilla on eri tyypit, %qT ja %qT"
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, fuzzy, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "?:-lausekkeen operandeilla on eri tyypit, %qT ja %qT"
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "Jäsenfunktio %qs"
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "epäkelpo %<sizeof%>-avainsanan soveltaminen bittikenttään"
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "epäkelpo %<sizeof%>-avainsanan soveltaminen funktiotyyppiin"
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "%<__alignof%>-avainsanaa sovellettu bittikenttään"
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "epäkelpo %<sizeof%>-avainsanan soveltaminen funktiotyyppiin"
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "taulukon koolla on epäkokonaislukutyyppi %qT"
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ kieltää merkkijonovakion muuntamisen %qT:ksi"
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "vanhentunut tyyppimuunnos merkkijonovakiosta tyyppiin %qT"
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "pyyntö jäsenen %qs käsittelyyn jossain, joka ei ole tietue tai unioni"
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "pyyntö jäsenen %qs käsittelyyn jossain, joka ei ole tietue tai unioni"
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
 # semi-fuzzy
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, fuzzy, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "käyttämätön muuttuja %q+D"
 
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> ei ole luokan jäsen"
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "ei voida kasvattaa osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "joustavan taulukkojäsenen sisältävän tietueen epäkelpo käyttö"
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "joustavan taulukkojäsenen sisältävän tietueen epäkelpo käyttö"
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, fuzzy, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "taulukon indeksi on taulukkorajojen yläpuolella"
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, fuzzy, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "ISO C kieltää %<register%>-taulukon indeksoinnin"
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, fuzzy, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "%qE esittelemättä (ensimmäinen käyttökerta tässä funktiossa)"
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ kieltää %<::main%>-funktion kutsumisen ohjelmasta"
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE:a saatetaan käyttää alustamattomana tässä funktiossa"
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "funktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "liikaa argumentteja muodostimelle %q#D"
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "liian vähän argumentteja muodostimelle %q#D"
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "liikaa argumentteja jäsenfunktiolle %q#D"
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "liian vähän argumentteja jäsenfunktiolle %q#D"
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "liikaa argumentteja funktiolle %q#D"
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "liian vähän argumentteja funktiolle %q#D"
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "liikaa argumentteja metodille %q#D"
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "liian vähän argumentteja funktiolle %q#D"
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "liikaa argumentteja funktiolle"
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "liian vähän argumentteja funktiolle"
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will never be NULL"
 msgid "the address %qE will never be NULL"
 msgstr "%qD:n osoite ei tule koskaan olemaan NULL"
 
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "%qD:n osoite ei tule koskaan olemaan NULL"
 
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, fuzzy, gcc-internal-format
 #| msgid "the compiler can assume that the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr "kääntäjä voi olettaa, että %qD:n osoite ei koskaan ole NULL"
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr ""
 
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "kääntäjä voi olettaa, että %qD:n osoite ei koskaan ole NULL"
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, fuzzy, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä muunnoksesta puuttuu tyyppimuunnos"
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, fuzzy, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä muunnoksesta puuttuu tyyppimuunnos"
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, fuzzy, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu tyyppimuunnos"
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, fuzzy, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu tyyppimuunnos"
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, fuzzy, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu tyyppimuunnos"
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, fuzzy, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, fuzzy, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, fuzzy, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu tyyppimuunnos"
 
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, fuzzy, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr "erilaisten osoitintyyppien %qT ja %qT välisestä vertailusta puuttuu tyyppimuunnos"
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, fuzzy, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL-arvon käyttö laskutoimituksessa"
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ kieltää osoittimen ja kokonaisluvun vertailun"
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, fuzzy, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "osoittimen ja kokonaisluku nollan suuruusvertailu"
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, fuzzy, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr "ei-liukulukuargumentti kutsussa funktiolle %qE"
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ kieltää %<void *%>-tyyppisen osoittimen käytön vähennyslaskussa"
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ kieltää funktio-osoittimen käytön vähennyslaskussa"
 
 # semi-fuzzy; onko metodi tässä luokan jäsenfunktio ja yllä muu funktio?
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ kieltää metodiosoittimen käytön vähennyslaskussa"
 
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, fuzzy, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ei voida kasvattaa osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "muodostimen %qE osoitteen ottaminen"
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "hajottimen %qE osoitteen ottaminen"
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, fuzzy, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "id="
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, fuzzy, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr ""
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr ""
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, fuzzy, gcc-internal-format
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr "keskeytyskäsittelijät eivät voi olla MIPS16-funktioita"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, fuzzy, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "väliaikaismuuttujan osoitteen ottaminen"
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ kieltää %<::main%>-funktion osoitteen ottamisen"
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "yritys ottaa bittikentän osoite"
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, fuzzy, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "odotettiin lauseketta"
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, fuzzy, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "oliko tarkoitus käyttää loogista negaatiota?"
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ kieltää enumin lisäyksen"
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ kieltää enumin vähentämisen"
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "ei voida kasvattaa osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ kieltää %qT-tyyppisen osoittimen kasvattamisen"
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ kieltää %qT-tyyppisen osoittimen vähentämisen"
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "ei voi ottaa %<this%>:in osoitetta, joka on rvalue-lauseke"
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, fuzzy, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, fuzzy, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "halutaan globaalin rekisterimuuttujan %qD osoite"
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "esittely ei esittele mitään"
 
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, fuzzy, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "%qE ei nimeä tyyppiä"
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "tyyppimuunnos tyypistä %qT tyyppiin %qT hylkää määreet"
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, fuzzy, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast-muunnos tyypistä %qT tyyppiin %qT hylkää määreet"
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast-muunnos tyypistä %qT tyyppiin %qT hylkää määreet"
 
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "tarpeeton tyyppimuunnos tyyppiin %qT"
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, fuzzy, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "tyyppimääreet jätetään huomiotta funktion paluutyypissä"
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, fuzzy, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "virheellinen static_cast-muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "nimellä %qT on vaillinainen tyyppi"
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 #, fuzzy
 msgid "converting from %qH to %qI"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, fuzzy, gcc-internal-format
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "virheellinen static_cast-muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 #, fuzzy
 msgid "cast from %qH to %qI loses precision"
 msgstr "muunnoksessa tyypistä %qT tyyppiin %qT menetetään tarkkuutta"
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 #, fuzzy
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "muunnos epäyhteensopivien jäsenosoitintyyppien %qH ja %qI välillä"
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 #, fuzzy
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "muunnos tyypistä %qT tyyppiin %qT kasvattaa kohdetyypin vaadittua kohdistusta"
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "tyyppimuunnos funktio-osoittimen ja olio-osoittimen välillä on ehdollisesti tuettu"
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "virheellinen const_cast tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "virheellinen const_cast tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ kieltää tyyppimuunnoksen taulukkotyyppiin %qT"
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "virheellinen tyyppimuunnos funktiotyyppiin %qT"
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qE from type %qT to type %qT"
 msgid "moving %qE of type %qT to itself"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr "poista %<std::move%>-kutsu"
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, fuzzy, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "%q#T ei ole luokka eikä nimiavaruus"
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, fuzzy, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "ei-vakio taulukon indeksi alustimessa"
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "vaillinaiset tyypit %qT:n sijoituksessa tyyppiin %qT"
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "taulukkoa käytetty alustimena"
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "virheellinen taulukkosijoitus"
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, fuzzy, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "Jäsenfunktio %qs"
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, fuzzy, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "Jäsenfunktio %qs"
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, fuzzy, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "Jäsenfunktio %qs"
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 #, fuzzy
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 #, fuzzy
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 #, fuzzy
 msgid "cannot convert %qH to %qI in return"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 #, fuzzy
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, fuzzy, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, fuzzy, gcc-internal-format
 msgid "returning pointer to temporary"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, fuzzy, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "palautettu viittaus paikalliseen muuttujaan %q+D"
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, fuzzy, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "nimiö %qD määritelty täällä"
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, fuzzy, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "palautettu osoite paikalliseen muuttujaan %q+D"
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, fuzzy, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "%s: liian monta arvoa"
 
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, fuzzy, gcc-internal-format
 msgid "redundant move in initialization"
 msgstr "%s: liian monta arvoa"
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "arvon palautus hajottimesta"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "arvon palautus muodostimesta"
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return-lause ilman arvoa funktiossa, jonka paluutyyppi on %qT"
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "taulukon palauttava funktio"
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, fuzzy, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "return-lause ilman arvoa funktiossa, jonka paluutyyppi on %qT"
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, fuzzy, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> ei saa palauttaa NULLia ellei esittely ole %<throw()%> (tai -fcheck-new ole voimassa)"
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, fuzzy, gcc-internal-format
 msgid "not eliding copy on return from %qD"
 msgstr "epäkelpo vektorityyppi attribuutille %qs"
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr ""
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, fuzzy, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "virheellinen %%s-arvo"
@@ -67138,157 +67175,157 @@ msgstr ""
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "muodostinsyntaksia on käytetty, mutta %qT-tyypin muodostinta ei ole esitelty"
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "%qE:n kaventava muunnos tyypistä %qT tyyppiin %qT { }:n sisällä"
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, fuzzy, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, fuzzy, gcc-internal-format
 msgid "initializer-string for %qT is too long"
 msgstr "merkkitaulukon alustusmerkkijono on liian pitkä"
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, fuzzy, gcc-internal-format
 msgid "remove %<{ }%> around initializer"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "puuttuva alustin jäsenelle %qD"
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "%qD:n tyyppi ei täsmää aiemman esittelyn kanssa"
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "alustettavassa unionissa ei ole kenttää %qD"
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, fuzzy, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "ylimääräisiä alkioita union-alustimessa"
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, fuzzy, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "PRINT_OPERAND null-osoitin"
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "PRINT_OPERAND_ADDRESS, null-osoitin"
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "PRINT_OPERAND_ADDRESS, null-osoitin"
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE:a saatetaan käyttää alustamattomana tässä funktiossa"
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, fuzzy, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "sijoitus yhteensopimattomasta osoitintyypistä"
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "tyyppimuunnos määrittää taulukkotyypin"
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, fuzzy, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, fuzzy, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "epäkelpo %qs:n soveltaminen tyhjään tyyppiin"
@@ -68281,7 +68318,7 @@ msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava vakio"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "epäkelpo osoitintila %qs"
@@ -69608,7 +69645,7 @@ msgstr "Kaksoiskappale %s-spesifikaatio kohdassa %C"
 msgid "deferred type parameter at %C"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "odotettiin kokonaislukulauseketta"
@@ -69823,7 +69860,7 @@ msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava väh
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
@@ -70624,7 +70661,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr "Odotetiin muodollista argumenttiluetteloa funktiomäärittelyssä kohdassa %C"
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
@@ -71431,12 +71468,12 @@ msgstr ""
 msgid "are_identical_variables: Bad type"
 msgstr ""
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr ""
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr ""
@@ -71685,273 +71722,273 @@ msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 msgid "check_init_expr(): Unknown expression type"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, fuzzy, gcc-internal-format
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, fuzzy, gcc-internal-format
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, fuzzy, gcc-internal-format
 msgid "Specification function %qs at %L must be PURE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, fuzzy, gcc-internal-format
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentti ”%1$s” kohdassa %3$L ei saa olla OPTIONAL"
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, fuzzy, gcc-internal-format
 msgid "check_restricted(): Unknown expression type"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L must be PURE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr ""
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr "Yhteensopimattomat tasot %d ja %d sijoituksessa kohdassa %L"
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "%<__builtin_args_info%>-funktion argumentti puuttuu"
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr "virheellinen %%L-arvo"
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Illegal assignment to external procedure at %L"
 msgstr "Iteraattoriaskel kohdassa %L ei voi olla nolla"
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "Yhteensopimattomat tasot %d ja %d sijoituksessa kohdassa %L"
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "Yhteensopimattomat tasot %d ja %d sijoituksessa kohdassa %L"
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "Yhteensopimattomat tasot %d ja %d sijoituksessa kohdassa %L"
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr ""
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Yhteensopimattomat tyypit DATA-lauseessa kohdassa %L; yritettiin muuntaa tyyppi %s tyypiksi %s"
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, fuzzy, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, fuzzy, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Käskyfunktio ”%s” on virheellinen proseduuriosoitinsijoituksessa kohdassa %L"
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Käskyfunktio ”%s” on virheellinen proseduuriosoitinsijoituksessa kohdassa %L"
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Sisäinen proseduuri ”%s” on virheellinen proseduuriosoittimessa kohdassa %L"
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, fuzzy, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Eri tyypit osoitinsijoituksessa kohdassa %L; yritettiin tyypin %s sijoitusta tyyppiin %s"
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Yhteensopimattomat tasot %d ja %d sijoituksessa kohdassa %L"
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Yhteensopimattomat tasot %d ja %d sijoituksessa kohdassa %L"
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
@@ -71959,192 +71996,192 @@ msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr ""
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr ""
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Sisäinen proseduuri ”%s” on virheellinen proseduuriosoittimessa kohdassa %L"
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Sisäinen proseduuri ”%s” on virheellinen proseduuriosoittimessa kohdassa %L"
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, fuzzy, gcc-internal-format
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "vektoriylivuoto lausekkeessa"
@@ -72165,8 +72202,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "Luodaan väliaikainen komentotiedosto %s\n"
@@ -72246,7 +72283,7 @@ msgstr "ylivuoto vakiolausekkeessa"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -72381,12 +72418,12 @@ msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
@@ -73256,7 +73293,7 @@ msgstr "Muunnos tyypistä %s tyyppiin %s kohdassa %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "Ei voi muuntaa tyyppiä %s tyyppiin %s kohdassa %L"
@@ -73807,7 +73844,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
@@ -73973,6 +74010,11 @@ msgstr "Kokonaisluvun ylivuoto"
 msgid "check_charlen_present(): length not set"
 msgstr ""
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr ""
+
 #: fortran/match.cc:118
 #, fuzzy, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
@@ -74374,7 +74416,7 @@ msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
@@ -74898,82 +74940,82 @@ msgstr "Syntaksivirhe PROTECTED-lauseessa kohdassa %C"
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "Syntaksivirhe PROTECTED-lauseessa kohdassa %C"
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Odottamaton CASE-lause kohdassa %C"
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Syntaksivirhe CASE-spesifikaatiossa kohdassa %C"
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Odottamaton TYPE IS -lause kohdassa %C"
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Syntaksivirhe TYPE IS -spesifikaatiossa kohdassa %C"
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Syntaksvirhe CLASS IS -spesifikaatiossa kohdassa %C"
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr "Odottamaton END-lause kohdassa %C"
 
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr "Syntaksivirhe CASE-spesifikaatiossa kohdassa %C"
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "Odottamaton %s-lause WHERE-lohkossa kohdassa %C"
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, fuzzy, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "Nimiö ”%s” kohdassa %C ei täsmää IF nimiön ”%s” kanssa"
@@ -76402,8 +76444,8 @@ msgstr "%<void%> vain parametrina ei ole oikeutettu"
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "decltypen argumentin on oltava lauseke"
@@ -78774,12 +78816,12 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta ei käytetty"
@@ -78899,7 +78941,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
@@ -79299,278 +79341,283 @@ msgstr "muuttuvakokoista objektia ei voi alustaa"
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, fuzzy, gcc-internal-format
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr "luodaan viitteiden taulukko"
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Ei voi muuntaa tyyppiä %s tyyppiin %s kohdassa %L"
 
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, fuzzy, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%qE on vanhentunut"
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "Invalid array reference at %L"
+msgstr "Taulukkoviite rajojen ulkopuolella"
+
+#: fortran/resolve.cc:6433
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "<tyyppivirhe>"
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, fuzzy, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, fuzzy, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, fuzzy, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "Iteraattoriaskel kohdassa %L ei voi olla nolla"
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "tulosta ei voi kirjoittaa: %s"
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, fuzzy, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
@@ -79579,284 +79626,284 @@ msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABL
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-nimiö kohdassa %L menee CASE-nimiön päälle kohdassa %L"
 
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %d-kaltainen"
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Tämä pikanäppäin on jo käytössä toiminnolle %s"
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "”%s” ei ole kelvollinen makron nimi, sillä se on C++:n operaattori"
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "CASE-nimiö kohdassa %L menee CASE-nimiön päälle kohdassa %L"
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Syntaksivirhe PROTECTED-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Varsinainen argumentti kohteelle ”%s” ei voi olla oletetunkokoinen taulukko kohdassa %L"
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Haarautuminen kohdassa %L voi aiheuttaa ikisilmukan"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
@@ -79864,213 +79911,213 @@ msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Odottamaton %s-lause WHERE-lohkossa kohdassa %C"
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Sijoitus FORALL-indeksimuuttujaan kohdassa %L"
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "Lohkonimiö ei ole sopiva IF-lauseelle kohdassa %C"
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr "CHARACTER-lauseke kohdassa %L on typistetty (%d/%d)"
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, fuzzy, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, fuzzy, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected initialization expression in CASE at %C"
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "Odotettiin alustuslauseketta CASE-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "virheellinen %%L-arvo"
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Käyttämätön parameteri ”%s” esitelty kohdassa %L"
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
@@ -80078,114 +80125,114 @@ msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Merkkijonon pituus kohdassa %L on liian suuri"
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, fuzzy, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "kolme pistettä sisältävä parametriluettelo ei sovellu tyhjään parametrinimiluettelon esittelyyn"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, fuzzy, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava valemuuttuja"
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Varattavalla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Ulkoisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Tyhjällä ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
@@ -80193,887 +80240,887 @@ msgstr ""
 "  tai:  %s -l [SIGNAALI]...\n"
 "  tai:  %s -t [SIGNAALI]...\n"
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, fuzzy, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Ulkoisella objektilla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-funktiolla ”%s” kohdassa %L täytyy olla skalaaritulos"
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla taulukkoarvoinen"
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla osoitinarvoinen"
 
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla puhdas"
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla rekursiivinen"
 
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Valeproseduurilla ”%s” kohdassa %C ei voi olla geneeristä rajapintaa"
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, fuzzy, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa INTENT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa RESULT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL-attribuutti on ristiriidassa FUNCTION-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, fuzzy, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "%qD:n on otettava tasan yksi argumentti"
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, fuzzy, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla perittyä tyyppiä ”%s”"
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla perittyä tyyppiä ”%s”"
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr ""
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla perittyä tyyppiä ”%s”"
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla skalaari"
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, fuzzy, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, fuzzy, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Ristiriita funktioargumentin attribuuteissa kohdassa %C"
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, fuzzy, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "kolme pistettä sisältävä parametriluettelo ei sovellu tyhjään parametrinimiluettelon esittelyyn"
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, fuzzy, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa INTENT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "kolme pistettä sisältävä parametriluettelo ei sovellu tyhjään parametrinimiluettelon esittelyyn"
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%Jlohkoattribuutti ei ole sallittu %qD:lle"
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava valemuuttuja"
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Sijoitus FORALL-indeksimuuttujaan kohdassa %L"
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä ALLOCATABLE- että BIND(C)-attribuutit"
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä ALLOCATABLE- että BIND(C)-attribuutit"
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, fuzzy, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "epäkelpo %qs:n soveltaminen tyhjään tyyppiin"
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Tuntematon argumenttiluettelofunktio kohdassa %L"
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, fuzzy, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "Symboli ”%s” kohdassa %C on jo COMMON-lohkossa"
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "Proseduurilla ”%s” kohdassa %C on eksplisiittinen rajapinta ja sillä ei saa olla attribuutteja, jotka on esitelty kohdassa %L"
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-lause kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-constant character length at %L in DATA statement"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-lause kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta ei käytetty"
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta sitä ei voida käyttää"
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, fuzzy, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Ei voi sijoitaa nimettyyn vakioon kohdassa %C"
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, fuzzy, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Syntaksivirhe merkkipituusspesifikaatiossa kohdassa %C"
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "epäkelpo %qs:n soveltaminen tyhjään tyyppiin"
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla merkkijono"
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava %4$s"
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava %4$s"
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
@@ -81618,330 +81665,330 @@ msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr "Kaksoiskappale-%s-attribuutti määritelty kohdassa %L"
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, fuzzy, gcc-internal-format
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr "Kaksoiskappale-%s-attribuutti määritelty kohdassa %L"
+
+#: fortran/symbol.cc:508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr "Odottamaton %s-lause BLOCK DATA -lohkossa kohdassa %C"
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, fuzzy, gcc-internal-format
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "Kaksoiskappale-%s-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr "Kaksoiskappale-%s-attribuutti määritelty kohdassa %L"
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, fuzzy, gcc-internal-format
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr "Kaksoiskappale-%s-attribuutti määritelty kohdassa %L"
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr ""
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr ""
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "Kaksoiskappale-%s-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr "Kaksoiskappale VALUE-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr ""
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "Kaksoiskappale-%s-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "Kaksoiskappale SAVE-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "Kaksoiskappale VALUE-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Kaksoiskappale VALUE-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Kaksoiskappale-%s-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "Kaksoiskappale-%s-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "Tämä pikanäppäin on jo käytössä toiminnolle %s"
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Kaksoiskappale-BIND-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "Kaksoiskappale-BIND-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Kaksoiskappale-EXTENDS-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "virheellinen %%L-arvo"
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Tyhjällä ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Monimerkityksellinen symboli TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "tyhjä esittely"
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "FORMAT-nimiö %d kohdassa %L ei ole määritelty"
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Nimiö ”%s” kohdassa %C ei täsmää IF nimiön ”%s” kanssa"
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "parametri %qD virheellisesti esitelty metodityyppi"
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "Odotettiin päättävää nimeä kohdassa %C"
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Symboli ”%s” kohdassa %C on jo COMMON-lohkossa"
 
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "tyhjä esittely"
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "Symbolia ”%s” käytetään ennen kuin sille määritellään tyyppi kohdassa %L"
@@ -81971,24 +82018,24 @@ msgstr "Odotettiin argumenttiluetteloa kohdassa %C"
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "Odotettiin argumenttiluetteloa kohdassa %C"
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Luodaan väliaikainen komentotiedosto %s\n"
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
@@ -82174,37 +82221,37 @@ msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr "ISO C90 kieltää muuttuvakokoisen taulukon %qE"
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, fuzzy, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "last-op"
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Tuntematon argumenttiluettelofunktio kohdassa %L"
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -82215,17 +82262,17 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, fuzzy, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentti ”%1$s” kohdassa %3$L ei ole kelvollinen ulottuvuusindeksi"
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
@@ -82365,7 +82412,7 @@ msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, fuzzy, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr "vektoriylivuoto lausekkeessa"
@@ -82735,6 +82782,11 @@ msgstr "muuttuja %qD esitelty uudelleen funktiona"
 msgid "function %qD redeclared as variable"
 msgstr "funktio %qD esitelty uudelleen muuttujana"
 
+#: lto/lto-symtab.cc:865
+#, gcc-internal-format
+msgid "previously declared here"
+msgstr "esitelty aiemmin täällä"
+
 #: lto/lto.cc:174
 #, gcc-internal-format
 msgid "%<lto_obj_file_open()%> failed"
@@ -83988,7 +84040,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr ""
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, fuzzy, gcc-internal-format
 msgid "non-objective-c type %qT cannot be caught"
 msgstr "%<%T%>-tyyppinen poikkeus siepataan"
@@ -83998,7 +84050,7 @@ msgstr "%<%T%>-tyyppinen poikkeus siepataan"
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr ""
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, gcc-internal-format
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
 msgstr ""
@@ -84785,6 +84837,10 @@ msgstr ""
 #~ msgid "class template placeholder %qE not permitted in this context"
 #~ msgstr "parametri esitelty %<auto%>:ksi"
 
+#, fuzzy, gcc-internal-format
+#~ msgid "cannot declare %qD in a different module"
+#~ msgstr "bittikentän %qD osoitetta ei voi ottaa"
+
 #, fuzzy, gcc-internal-format
 #~ msgid "cannot define %qD in different module"
 #~ msgstr "%q+D:n virheellinen uudelleenesittely"
@@ -87442,10 +87498,6 @@ msgstr ""
 #~ msgid "Builtin function %s requires the -maltivec option"
 #~ msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#, fuzzy
-#~ msgid "Builtin function %s requires the -mpaired option"
-#~ msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
-
 #, fuzzy
 #~ msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 #~ msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
diff --git a/gcc/po/fr.po b/gcc/po/fr.po
index 691ef6c95e3..c14d5719b71 100644
--- a/gcc/po/fr.po
+++ b/gcc/po/fr.po
@@ -99,7 +99,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 14.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
 "PO-Revision-Date: 2024-05-09 14:43+0200\n"
 "Last-Translator: Frédéric Marchal <fmarchal@perso.be>\n"
 "Language-Team: French <traduc@traduc.org>\n"
@@ -474,7 +474,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr "ne spécifiez pas à la fois -march=… et -mcpu=…"
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 msgid "shared and mdll are not compatible"
 msgstr "shared et mdll ne sont pas compatibles"
 
@@ -19265,16 +19265,16 @@ msgstr "insn non reconnaissable:"
 msgid "insn does not satisfy its constraints:"
 msgstr "insn ne satisfait pas à ses contraintes:"
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "créé et utilisé avec des configurations différentes de « %s »"
 
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "créé et utilisé avec des configurations différentes de %<-fpic%>"
 
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 msgid "created and used with different settings of %<-fpie%>"
 msgstr "créé et utilisé avec des configurations différentes de %<-fpie%>"
 
@@ -19595,7 +19595,7 @@ msgstr "modificateur de longueur dans le format de strfmon"
 msgid "<command-line>"
 msgstr "<ligne-de-commande>"
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "opérande non supporté pour le code « %c »"
@@ -19614,9 +19614,9 @@ msgstr "opérande invalide pour « %%%c »"
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, c-format
 msgid "invalid vector constant"
 msgstr "constante vecteur invalide"
@@ -19636,7 +19636,7 @@ msgstr "opérande incompatible pour « %%%c »"
 msgid "incompatible register operand for '%%%c'"
 msgstr "opérande de registre incompatible pour « %%%c »"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, c-format
 msgid "missing operand"
 msgstr "opérande manquant"
@@ -19665,93 +19665,93 @@ msgstr "mode d'adresse invalide"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "impossible de combiner les vecteurs GNU et SVE dans l'opération binaire"
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "« %%& » utilisé sans référence à un TLS dynamique local"
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, c-format
 msgid "invalid %%J value"
 msgstr "valeur %%J invalide"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, c-format
 msgid "invalid %%r value"
 msgstr "valeur %%r invalide"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, c-format
 msgid "invalid %%R value"
 msgstr "valeur %%R invalide"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, c-format
 msgid "invalid %%N value"
 msgstr "valeur %%N invalide"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, c-format
 msgid "invalid %%P value"
 msgstr "valeur %%P invalide"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, c-format
 msgid "invalid %%h value"
 msgstr "valeur %%h invalide"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, c-format
 msgid "invalid %%L value"
 msgstr "valeur %%L invalide"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, c-format
 msgid "invalid %%m value"
 msgstr "valeur %%m invalide"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, c-format
 msgid "invalid %%M value"
 msgstr "valeur %%M invalide"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, c-format
 msgid "invalid %%U value"
 msgstr "valeur %%U invalide"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, c-format
 msgid "invalid %%s value"
 msgstr "valeur %%s invalide"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, c-format
 msgid "invalid %%C value"
 msgstr "valeur %%C invalide"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, c-format
 msgid "invalid %%E value"
 msgstr "valeur %%E invalide"
 
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "relocalisation unspec inconnue"
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, c-format
 msgid "invalid %%xn code"
 msgstr "valeur %%xn invalide"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, c-format
 msgid "invalid operand address"
 msgstr "adresse d'opérande invalide"
@@ -19844,35 +19844,35 @@ msgstr "UNSPEC invalide comme opérande : %d"
 msgid "unrecognized supposed constant"
 msgstr "constante supposée non reconnue"
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, c-format
 msgid "invalid shift operand"
 msgstr "opérande shift invalide"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "instruction Thumb établie"
 
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instruction établie dans la séquence conditionnelle"
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Opérande non supporté pour le code « %c »"
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -19880,113 +19880,113 @@ msgstr "Opérande non supporté pour le code « %c »"
 msgid "invalid operand for code '%c'"
 msgstr "opérande invalide pour « %c »"
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, c-format
 msgid "instruction never executed"
 msgstr "instruction jamais exécutée"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "code de format Maverick « %c » obsolète"
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "conversion invalide depuis le type %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "conversion invalide vers le type %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "opération non permise sur le type %<bfloat16_t%>"
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "l'opérande d'adresse requiert une contrainte sur le registre X, Y ou Z"
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "les opérandes de %T/%t doivent être reg + const_int:"
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 msgid "bad address, not an I/O address:"
 msgstr "mauvaise adresse, pas une adresse E/S:"
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 msgid "bad address, not a constant:"
 msgstr "mauvaise adresse, pas une constante:"
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 msgid "bad address, not (reg+disp):"
 msgstr "mauvaise adresse, pas (reg+disp):"
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "mauvaise adresse, pas post_inc ou pre_dec:"
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr "erreur interne du compilateur. Mauvaise adresse:"
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "Code « %c » non supporté en virgule fixe:"
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 msgid "internal compiler error.  Unknown mode:"
 msgstr "erreur interne du compilateur. Mode inconnu:"
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 msgid "invalid insn:"
 msgstr "insn invalide :"
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 msgid "incorrect insn:"
 msgstr "insn incorrecte :"
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 msgid "unknown move insn:"
 msgstr "insn de déplacement inconnue :"
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 msgid "bad shift insn:"
 msgstr "insn de décalage erronée :"
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "erreur interne du compilateur. Décalage incorrect:"
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 msgid "unsupported fixed-point conversion"
 msgstr "conversion en virgule fixe non supportée"
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 msgid "variable"
 msgstr "variable"
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 msgid "function parameter"
 msgstr "paramètre de fonction"
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 msgid "structure field"
 msgstr "champ de structure"
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 msgid "return type of function"
 msgstr "type de retour d'une fonction"
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 msgid "pointer"
 msgstr "pointeur"
 
@@ -20022,7 +20022,7 @@ msgstr "opérande non supporté"
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -20341,46 +20341,46 @@ msgstr "l'opérande n'est pas un entier, code d'opérande « R » invalide"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "l'opérande n'est pas un entier spécifique, code d'opérande « R » invalide"
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "opérande invalide pour « %c »"
 
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "contrainte invalide pour l'opérande"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, c-format
 msgid "invalid vector immediate"
 msgstr "immédiat vecteur invalide"
 
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 msgid "unknown insn mode"
 msgstr "mode insn inconnu"
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr "conversion invalide depuis le type %<__bf16%> sans option %<-msse2%>"
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr "conversion invalide depuis le type %<_Float16%> sans option %<-msse2%>"
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr "conversion invalide vers le type %<__bf16%> sans option %<-msse2%>"
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr "conversion invalide vers le type %<_Float16%> sans option %<-msse2%>"
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr "opération non permise sur le type %<__bf16%> sans option %<-msse2%>"
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
 msgstr "opération non permise sur le type %<_Float16%> sans option %<-msse2%>"
 
@@ -20411,7 +20411,7 @@ msgstr "opération invalide sur %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "opérande %%P invalide"
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, c-format
 msgid "invalid %%p value"
 msgstr "valeur %%p invalide"
@@ -20438,29 +20438,29 @@ msgstr "impossible d'utiliser une adresse absolue pas relative à gp"
 msgid "invalid addressing mode"
 msgstr "mode d'adressage invalide"
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, c-format
 msgid "'%%%c' is not a valid operand prefix"
 msgstr "« %%%c » n'est pas un préfixe d'opérande valide"
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "utilisation invalide de « %%%c »"
@@ -20492,7 +20492,7 @@ msgid "post-increment address is not a register"
 msgstr "le post-incrément d'adresse n'est pas un registre"
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 msgid "bad address"
 msgstr "mauvaise adresse"
 
@@ -20650,7 +20650,7 @@ msgstr "adresse constante non supportée :"
 msgid "unsupported memory expression:"
 msgstr "expression mémoire non supportée :"
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, c-format
 msgid "invalid vector operand"
 msgstr "opérande vectoriel invalide"
@@ -20698,242 +20698,242 @@ msgstr "%<-mquad-memory-atomic%> requiert le mode 64 bits"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "%<-mquad-memory%> n'est pas disponible en mode petit-boutiste"
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 msgid "bad move"
 msgstr "mauvais déplacement"
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 msgid "Bad 128-bit move"
 msgstr "Mauvais déplacement sur 128 bits"
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, c-format
 msgid "invalid %%A value"
 msgstr "valeur %%A invalide"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%D value"
 msgstr "valeur %%D invalide"
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, c-format
 msgid "invalid %%e value"
 msgstr "valeur %%e invalide"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, c-format
 msgid "invalid %%f value"
 msgstr "valeur %%f invalide"
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, c-format
 msgid "invalid %%F value"
 msgstr "valeur %%F invalide"
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, c-format
 msgid "invalid %%G value"
 msgstr "valeur %%G invalide"
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, c-format
 msgid "invalid %%j code"
 msgstr "valeur %%j invalide"
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, c-format
 msgid "invalid %%J code"
 msgstr "valeur %%J invalide"
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, c-format
 msgid "invalid %%k value"
 msgstr "valeur %%k invalide"
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, c-format
 msgid "invalid %%K value"
 msgstr "valeur %%K invalide"
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, c-format
 msgid "invalid %%O value"
 msgstr "valeur %%O invalide"
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, c-format
 msgid "invalid %%q value"
 msgstr "valeur %%q invalide"
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, c-format
 msgid "invalid %%t value"
 msgstr "valeur %%t invalide"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, c-format
 msgid "invalid %%T value"
 msgstr "valeur %%T invalide"
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, c-format
 msgid "invalid %%u value"
 msgstr "valeur %%u invalide"
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, c-format
 msgid "invalid %%v value"
 msgstr "valeur %%v invalide"
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, c-format
 msgid "invalid %%V value"
 msgstr "valeur %%V invalide"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, c-format
 msgid "invalid %%x value"
 msgstr "valeur %%x invalide"
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, c-format
 msgid "invalid %%z value"
 msgstr "valeur %%z invalide"
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "valeur %%y invalide, essayez d'utiliser la contrainte « Z »"
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Mélange invalide de types en virgule flottante IEEE 128 bits et IBM 128 bits"
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Argument AltiVec passé à une fonction sans prototype"
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 msgid "Could not generate addis value for fusion"
 msgstr "N'a pu générer de valeur addis pour la fusion"
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Impossible de générer un offset load/store pour la fusion"
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 msgid "Bad GPR fusion"
 msgstr "Mauvaise fusion GPR"
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "conversion invalide depuis le type %<__vector_quad%>"
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "conversion invalide vers le type %<__vector_quad%>"
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "conversion invalide depuis le type %<__vector_pair%>"
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "conversion invalide vers le type %<__vector_pair%>"
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "les références mémoire symboliques sont uniquement supportées sur z10 ou ultérieur"
 
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, c-format
 msgid "cannot decompose address"
 msgstr "adresse indécomposable"
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "opérateur de comparaison invalide pour le modificateur de sortie « E »"
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "référence invalide pour le modificateur de sortie « J »"
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "adresse invalide pour le modificateur de sortie « O »"
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "adresse invalide pour le modificateur de sortie « R »"
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "référence mémoire attendue pour le modificateur de sortie « S »"
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "adresse invalide pour le modificateur de sortie « S »"
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "registre ou expression mémoire attendue pour le modificateur de sortie « N »"
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "registre ou expression mémoire attendue pour le modificateur de sortie « M »"
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "constante invalide pour le modificateur de sortie « %c »"
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "constante invalide - essayez un modificateur de sortie"
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "vecteur constant invalide pour le modificateur de sortie « %c »"
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "expression invalide - essayez un modificateur de sortie"
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "expression invalide pour le modificateur de sortie « %c »"
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 msgid "vector argument passed to unprototyped function"
 msgstr "vecteur passé en argument à une fonction sans prototype"
 
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 msgid "types differ in signedness"
 msgstr "les types diffèrent sur le type signé/non-signé"
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 msgid "binary operator does not support two vector bool operands"
 msgstr "l'opérateur binaire ne supporte pas deux opérandes booléens vectoriels"
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 msgid "binary operator does not support vector bool operand"
 msgstr "l'opérateur binaire ne supporte pas l'opérande booléen vectoriel"
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "l'opérateur binaire ne supporte pas le mélange d'un booléen vectoriel avec un vecteur en virgule flottante"
 
@@ -21124,12 +21124,12 @@ msgstr "({anonyme})"
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> attendu"
@@ -21142,7 +21142,7 @@ msgstr "%<;%> attendu"
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -21151,7 +21151,7 @@ msgstr "%<;%> attendu"
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> attendu"
@@ -21159,7 +21159,7 @@ msgstr "%<)%> attendu"
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> attendu"
@@ -21170,29 +21170,29 @@ msgstr "%<;%>, %<,%> ou %<)%> attendu"
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> attendu"
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> attendu"
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> attendu"
@@ -21202,17 +21202,17 @@ msgstr "%<{%> attendu"
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> attendu"
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> attendu"
@@ -21221,8 +21221,8 @@ msgstr "%<while%> attendu"
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> attendu"
@@ -21232,17 +21232,17 @@ msgid "expected %<.%>"
 msgstr "%<.%> attendu"
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> attendu"
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> attendu"
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> ou %<)%> attendu"
@@ -21250,32 +21250,32 @@ msgstr "%<,%> ou %<)%> attendu"
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> attendu"
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> attendu"
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, gcc-internal-format
 msgid "expected %<else%>"
 msgstr "%<else%> attendu"
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> ou %<}%> attendu"
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr "<message inconnu durant la compilation>"
 
@@ -21283,7 +21283,7 @@ msgstr "<message inconnu durant la compilation>"
 msgid "(anonymous)"
 msgstr "(anonyme)"
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> attendu"
@@ -21298,21 +21298,21 @@ msgstr "étiquette attendue"
 msgid "candidate:"
 msgstr "candidat :"
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 msgid "  after user-defined conversion:"
 msgstr "  après la conversion définie par l'utilisateur :"
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "le candidat est :"
 msgstr[1] "les candidats sont :"
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr "candidat 1 :"
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr "candidat 2 :"
 
@@ -21545,7 +21545,7 @@ msgstr "%r%s:%d:%d:%R   dans l'expansion %<constexpr%> de %qs"
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%R   dans l'expansion %<constexpr%> de %qs"
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 msgid "candidates are:"
 msgstr "les candidats sont :"
 
@@ -21589,48 +21589,48 @@ msgstr "la conversion supprime l'attribut « const »"
 msgid "source type is not polymorphic"
 msgstr "le type source n'est pas polymorphique"
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "type d'argument erroné pour le moins unaire"
 
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "type d'argument erroné pour le plus unaire"
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "type d'argument erroné pour le complément de bit"
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "type d'argument erroné pour abs"
 
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "type d'argument erroné pour la conjugaison"
 
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 msgid "in argument to unary !"
 msgstr "dans l'argument d'un unaire !"
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 msgid "no pre-increment operator for type"
 msgstr "pas d'opérateur de pré-incrémentation pour le type"
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 msgid "no post-increment operator for type"
 msgstr "pas d'opérateur de post-incrémentation pour le type"
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 msgid "no pre-decrement operator for type"
 msgstr "pas d'opérateur de pré-décrémentation pour le type"
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 msgid "no post-decrement operator for type"
 msgstr "pas d'opérateur de post-décrémentation pour le type"
 
@@ -21714,7 +21714,7 @@ msgstr "Fonctionnalité obsolète :"
 msgid "Deleted feature:"
 msgstr "Fonctionnalité supprimée :"
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 msgid "array assignment"
 msgstr "affectation de tableau"
 
@@ -21905,11 +21905,11 @@ msgstr "bloc IF"
 msgid "implied END DO"
 msgstr "END DO implicite"
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 msgid "assignment"
 msgstr "affectation"
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 msgid "pointer assignment"
 msgstr "affectation de pointeur"
 
@@ -22069,47 +22069,47 @@ msgstr "L'opérande de l'opérateur utilisateur %%<%s%%> à %%L est %s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur utilisateur %%<%s%%> à %%L sont %s/%s"
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 msgid "Loop variable"
 msgstr "Variable de boucle"
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 msgid "iterator variable"
 msgstr "variable d'itérateur"
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 msgid "Start expression in DO loop"
 msgstr "Expression de départ dans la boucle DO"
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 msgid "End expression in DO loop"
 msgstr "Expression de fin dans la boucle DO"
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 msgid "Step expression in DO loop"
 msgstr "Expression de pas dans la boucle DO"
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 msgid "DEALLOCATE object"
 msgstr "objet DEALLOCATE"
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 msgid "ALLOCATE object"
 msgstr "objet ALLOCATE"
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 msgid "STAT variable"
 msgstr "variable STAT"
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 msgid "ERRMSG variable"
 msgstr "variable ERRMSG"
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 msgid "item in READ"
 msgstr "élément dans READ"
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 msgid "ACQUIRED_LOCK variable"
 msgstr "variable ACQUIRED_LOCK"
 
@@ -22118,11 +22118,11 @@ msgstr "variable ACQUIRED_LOCK"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "Longueurs de CHARACTER différentes (%ld/%ld) dans le constructeur de tableau"
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Débordement d'entier en calculant la quantité de mémoire à allouer"
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "La valeur du paramètre PDT LEN « %s » n'est pas en accord avec celle dans la déclaration fictive"
@@ -22137,12 +22137,12 @@ msgstr "La longueur réelle de la chaîne ne correspond pas à celle déclarée
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "La longueur réelle de la chaîne est plus courte que celle déclarée pour l'argument fictif « %s » (%ld/%ld)"
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "La cible du remappage de rang est trop petite (%ld < %ld)"
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 msgid "Assignment of scalar to unallocated array"
 msgstr "Assignation d'un scalaire à un tableau non alloué"
 
@@ -22151,81 +22151,81 @@ msgstr "Assignation d'un scalaire à un tableau non alloué"
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Longueurs de caractères inégales (%ld/%ld) dans %s"
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr "Argument POS (%ld) hors des limites 0:%ld dans l'intrinsèque BTEST"
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "Argument POS (%ld) hors limite 0:%ld dans l'intrinsèque %s"
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr "Argument POS (%ld) hors limite 0:%ld dans l'intrinsèque IBITS"
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr "Argument LEN (%ld) hors limite 0:%ld dans l'intrinsèque IBITS"
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) dans l'intrinsèque IBITS"
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, c-format
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "Argument SHIFT (%ld) hors limite 0:%ld dans l'intrinsèque %s"
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr "Argument SHIFT (%ld) hors limites -%ld:%ld dans l'intrinsèque ISHIFT"
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr "Argument SIZE (%ld) hors limite 1:%ld dans l'intrinsèque ISHFTC"
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr "Argument SHIFT (%ld) hors limite -%ld:%ld dans l'intrinsèque ISHFTC"
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "L'argument NCOPIES de l'intrinsèque REPEAT est négatif (sa valeur est %ld)"
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "L'argument NCOPIES de l'intrinsèque REPEAT est trop grand"
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, c-format
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "Argument FROMPOS (%ld) hors limite 0:%d dans l'intrinsèque MVBITS"
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "Argument LEN (%ld) hors limite 0:%d dans l'intrinsèque MVBITS"
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, c-format
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "Argument TOPOS (%ld) hors limite 0:%d dans l'intrinsèque MVBITS"
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) dans l'intrinsèque MVBITS"
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) dans l'intrinsèque MVBITS"
@@ -22247,15 +22247,15 @@ msgstr "L'étiquette assignée n'est pas une étiquette cible"
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Numéro d'image %d invalide dans SYNC IMAGES"
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr "La boucle itère sans fin"
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 msgid "Loop variable has been modified"
 msgstr "La variable de boucle a été modifiée"
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 msgid "DO step value is zero"
 msgstr "La valeur de pas de DO est zéro"
 
@@ -22331,7 +22331,7 @@ msgid "expected boolean type"
 msgstr "type booléen attendu"
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "entier attendu"
@@ -22394,7 +22394,7 @@ msgstr "pas assez d'arguments"
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "trop d'arguments"
@@ -23018,7 +23018,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "%<-mrelax%> est uniquement supporté pour le PIC RTP"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction %s à %C"
@@ -23455,8 +23455,8 @@ msgstr "l'attribut %qE est ignoré car il est en conflit avec l'attribut %qs"
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "déclaration précédente ici"
@@ -23473,7 +23473,7 @@ msgstr "directive d'attribut %qE ignorée"
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr "directive d'attribut de portée %<%E::%E%> ignorée"
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, gcc-internal-format
 msgid "wrong number of arguments specified for %qE attribute"
 msgstr "nombre erroné d'arguments spécifié pour l'attribut %qE"
@@ -23483,7 +23483,7 @@ msgstr "nombre erroné d'arguments spécifié pour l'attribut %qE"
 msgid "expected %i or more, found %i"
 msgstr "%i ou plus attendu, %i trouvé"
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "expected %i, found %i"
 msgstr "%i attendu, %i trouvé"
@@ -23550,12 +23550,12 @@ msgstr "les attributs de type sont ignorés après que le type ait déjà été
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -23564,7 +23564,7 @@ msgstr "les attributs de type sont ignorés après que le type ait déjà été
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -23586,8 +23586,8 @@ msgstr "attribut %qE ignoré"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "attribut %<target%> manquant pour %qD avec plusieurs versions"
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "déclaration précédente de %qD"
@@ -23696,7 +23696,7 @@ msgstr "impossible de lire le profil de la fonction depuis %s"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "le décalage %qwi est hors des limites de la chaîne constante"
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE déclaré ici"
@@ -23801,7 +23801,7 @@ msgstr "argument 0 invalide pour %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, gcc-internal-format
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "utilisation invalide de %<__builtin_va_arg_pack ()%>"
@@ -23823,42 +23823,42 @@ msgstr "le deuxième argument de %<__builtin_longjmp%> doit être 1"
 msgid "target format does not support infinity"
 msgstr "le format cible ne supporte pas l'infini"
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> utilisé dans une fonction ayant des arguments fixes"
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "nombre erroné d'arguments pour la fonction %<va_start%>"
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> appelé sans argument"
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "nombre erroné d'arguments pour la fonction %<__builtin_next_arg%>"
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "le deuxième paramètre de %<va_start%> n'est pas le dernier argument nommé"
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "le comportement est indéfini quand le second paramètre de %<va_start%> est déclaré avec le stockage %<register%>"
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, gcc-internal-format
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr "le premier argument de %qD doit être un pointeur et le second une constante entière"
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, gcc-internal-format
 msgid "last argument of %qD is not integer constant between 0 and 3"
 msgstr "le dernier argument de %qD n'est pas une constante entière entre 0 et 3"
@@ -24904,12 +24904,12 @@ msgstr "l'attribut %<weakref%> est ignoré car la variable est initialisée"
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F utilisé mais jamais défini"
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F déclaré %<static%> mais jamais défini"
@@ -25461,7 +25461,7 @@ msgstr "%<region_array%> ne correspond pas à %<region_tree%>"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "%<lp_array%> ne correspond pas à %<region_tree%>"
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, gcc-internal-format
 msgid "%qs failed"
 msgstr "%qs a échoué"
@@ -25491,17 +25491,17 @@ msgstr "ordre de stockage inverse pour le mode %s"
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr "écriture de %wu bits de données hors des limites de l'objet de destination, les données ont été tronquées dans %wu bits"
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, gcc-internal-format
 msgid "call to %qs declared with attribute error: %s"
 msgstr "appel à %qs déclaré avec une erreur d'attribut : %s"
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, gcc-internal-format
 msgid "call to %qs declared with attribute warning: %s"
 msgstr "appel à %qs déclaré avec un avertissement d'attribut : %s"
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
 msgstr "on suppose que le débordement signé n'a pas lieu lors de la simplification de %<X - Y %s 0%> en %<X %s Y%>"
@@ -25536,7 +25536,7 @@ msgstr "la constante de grande taille en virgule fixe a été tronquée implicit
 msgid "comparison is always %d due to width of bit-field"
 msgstr "la comparaison est toujours %d en raison de la largeur du champ de bits"
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "suppose qu'un débordement signé n'a pas lieu quand le test de la plage est simplifié"
@@ -25700,7 +25700,7 @@ msgstr "erreur à l'obtention des temps du processus: %m"
 msgid "%s signal terminated program %s"
 msgstr "le signal %s a terminé le programme %s"
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, gcc-internal-format
 msgid "unrecognized command-line option %qs"
 msgstr "option %qs non reconnue sur la ligne de commande"
@@ -25963,7 +25963,7 @@ msgstr "la spec multilib %qs est invalide"
 msgid "multilib exclusions %qs is invalid"
 msgstr "les exclusions multilib %qs sont invalides"
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "le sélecteur multilib %qs %qs est invalide"
@@ -26262,22 +26262,22 @@ msgstr "%qD la limite spécifiée %E excède la taille de la destination %E"
 msgid "%qD specified bound %E equals source length"
 msgstr "la limite spécifiée par %qD (%E) est égale la longueur de la destination"
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, gcc-internal-format
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr "le membre tableau flexible %qD n'a pas de bits de remplissage bien définis pour %qs"
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr "la gestion du champ de bits PDP11 est non supportée dans %qs"
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s not supported for variable length aggregates"
 msgstr "%s n'est pas supporté pour des agrégats de longueur variable"
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "%s not supported on this target"
 msgstr "%s n'est pas supporté sur cette cible"
@@ -26318,16 +26318,16 @@ msgid "function returns address of local variable"
 msgstr "la fonction retourne l'adresse d'une variable locale"
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, gcc-internal-format
@@ -26339,366 +26339,366 @@ msgstr "déclaré ici"
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr "argument %<nonnull%> %qD comparé à NULL"
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr "la sortie de %qE peut être tronquée avant le dernier caractère de format"
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr "la sortie de %qE peut être tronquée avant le dernier caractère de format"
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr "%qE peut écrire un zéro terminal au delà de la fin de la destination"
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr "%qE écrit un zéro terminal au delà de la fin de la destination"
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] "la directive %<%.*s%> écrit %wu octet dans une région dont la taille est %wu"
 msgstr[1] "la directive %<%.*s%> écrit %wu octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] "la sortie de la directive %<%.*s%> peut être tronquée en écrivant %wu octet dans une région dont la taille est %wu"
 msgstr[1] "la sortie de la directive %<%.*s%> peut être tronquée en écrivant %wu octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] "la sortie de la directive %<%.*s%> a été tronquée en écrivant %wu octet dans une région dont la taille est %wu"
 msgstr[1] "la sortie de la directive %<%.*s%> a été tronquée en écrivant %wu octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr "la sortie de la directive %<%.*s%> peut être tronquée en écrivant jusqu'à %wu octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr "la sortie de la directive %<%.*s%> a été tronquée en écrivant jusqu'à %wu octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr "la directive %<%.*s%> écrit jusqu'à %wu octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "la sortie de la directive %<%.*s%> peut être tronquée en écrivant probablement %wu octets ou plus dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "la sortie de la directive %<%.*s%> a été tronquée en écrivant probablement %wu octets ou plus dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr "la directive %<%.*s%> écrit probablement %wu octets ou plus dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "la sortie de la directive %<%.*s%> peut être tronquée en écrivant entre %wu et %wu octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "la sortie de la directive %<%.*s%> a été tronquée en écrivant entre %wu et %wu octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr "la directive %<%.*s%> écrit entre %wu et %wu octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr "la sortie de la directive %<%.*s%> peut être tronquée en écrivant %wu octets ou plus dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr "la sortie de la directive %<%.*s%> a été tronquée en écrivant %wu ou plus d'octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr "la directive %<%.*s%> écrit %wu ou plus d'octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] "la directive %<%.*s%> écrit %wu octet dans une région dont la taille est comprise entre %wu et %wu"
 msgstr[1] "la directive %<%.*s%> écrit %wu octets dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] "la sortie de la directive %<%.*s%> peut être tronquée en écrivant %wu octet dans une région dont la taille est comprise entre %wu et %wu"
 msgstr[1] "la sortie de la directive %<%.*s%> peut être tronquée en écrivant %wu octets dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] "la sortie de la directive %<%.*s%> a été tronquée en écrivant %wu octet dans une région dont la taille est comprise entre %wu et %wu"
 msgstr[1] "la sortie de la directive %<%.*s%> a été tronquée en écrivant %wu octets dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "la sortie de la directive %<%.*s%> peut être tronquée en écrivant jusqu'à %wu octets dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "la sortie de la directive %<%.*s%> a été tronquée en écrivant jusqu'à %wu octets dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "la directive %<%.*s%> écrit jusqu'à %wu octets dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "la sortie de la directive %<%.*s%> peut être tronquée en écrivant probablement %wu octets ou plus dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "la sortie de la directive %<%.*s%> a été tronquée en écrivant probablement %wu octets ou plus dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "la directive %<%.*s%> écrit probablement %wu octets ou plus dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "la sortie de la directive %<%.*s%> peut être tronquée en écrivant entre %wu et %wu octets dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "la sortie de la directive %<%.*s%> a été tronquée en écrivant entre %wu et %wu octets dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "la directive %<%.*s%> écrit entre %wu et %wu octets dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "la sortie de la directive %<%.*s%> peut être tronquée en écrivant %wu octets ou plus dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "la sortie de la directive %<%.*s%> a été tronquée en écrivant %wu octets ou plus dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "la directive %<%.*s%> écrit %wu octets ou plus dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr "l'argument de la directive %<%.*s%> est nul"
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr "la sortie de la directive %<%.*s%> qui a %wu octets dépasse la taille minimum requise de 4095"
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr "la sortie de la directive %<%.*s%> qui contient entre %wu et %wu octets dépasse la taille minimum requise de 4095"
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr "la sortie de la directive %<%.*s%> qui contient entre %wu et %wu octets peut dépasser la taille minimum requise de 4095"
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr "la sortie de la directive %<%.*s%> qui a %wu octets dépasse %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr "la sortie de la directive %<%.*s%> qui contient entre %wu et %wu octets dépasse %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "la sortie de la directive %<%.*s%> qui a %wu octets fait déborder le résultat au delà de %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "la sortie de la directive %<%.*s%> qui contient entre %wu et %wu octets fait déborder le résultat au delà de %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr "la sortie de la directive %<%.*s%> qui contient entre %wu et %wu octets peut faire déborder le résultat au delà de %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr "l'argument de la directive %<%.*s%> n'est pas une chaîne avec un zéro terminal"
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, gcc-internal-format
 msgid "referenced argument declared here"
 msgstr "l'argument référencé est déclaré ici"
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] "on suppose que la sortie de la directive occupe %wu octet"
 msgstr[1] "on suppose que la sortie de la directive occupe %wu octets"
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "argument de directive %qE"
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr "argument de directive dans la plage [%E, %E]"
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr "utilise la plage [%E, %E] pour l'argument de la directive"
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgid_plural "%qE output %wu bytes into a destination of size %wu"
 msgstr[0] "%qE écrit %wu octet dans une destination dont la taille est %wu"
 msgstr[1] "%qE écrit %wu octets dans une destination dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr "%qE écrit entre %wu et %wu octets dans une destination dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr "%qE écrit %wu octets ou plus (%wu supposé) dans une destination dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr "%qE écrit %wu octets ou plus dans une destination dont la taille est %wu"
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
 msgstr[0] "%qE écrit %wu octet"
 msgstr[1] "%qE écrit %wu octets"
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes"
 msgstr "%qE écrit entre %wu et %wu octets"
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr "%qE écrit %wu octets ou plus (%wu supposé)"
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes"
 msgstr "%qE écrit %wu octets ou plus"
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr "la largeur de la directive %<%.*s%> est hors limites"
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr "la précision de la directive %<%.*s%> est hors limites"
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr "%qE les arguments %Z et peut-être %Z recouvrent l'objet de destination %qE"
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 msgid "%qE argument %Z overlaps destination object %qE"
 msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] "%qE l'argument %Z recouvre l'objet destination %qE"
 msgstr[1] "%qE les arguments %Z recouvrent l'objet destination %qE"
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 msgid "%qE argument %Z may overlap destination object %qE"
 msgid_plural "%qE arguments %Z may overlap destination object %qE"
 msgstr[0] "%qE l'argument %Z peut recouvrir l'objet destination %qE"
 msgstr[1] "%qE les arguments %Z peuvent recouvrir l'objet destination %qE"
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr "l'objet destination référencé par l'argument 1 qualifié avec %<restrict%> était déclaré ici"
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr "la limite spécifiée %wu excède la taille maximale de l'objet (%wu)"
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr "la limite spécifiée %wu excède %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, gcc-internal-format
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr "la plage de la limite spécifiée [%wu, %wu] excède %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, gcc-internal-format
 msgid "null destination pointer"
 msgstr "pointeur de destination nul"
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr "la limite spécifiée %wu dépasse la taille %wu de l'objet de destination"
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, gcc-internal-format
 msgid "null format string"
 msgstr "chaîne de format nulle"
@@ -27435,12 +27435,12 @@ msgstr "utilisation d'un pointeur ballant vers %qD"
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD déclaré ici"
@@ -28206,7 +28206,7 @@ msgstr "le jeton %u a %<x-location == %u%>"
 msgid "token %u has %<y-location == %u%>"
 msgstr "le jeton %u a %<y-location == %u%>"
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "utilisation invalide de l'attribut %<fallthrough%>"
@@ -28550,17 +28550,17 @@ msgstr "le nom %qs est défini à une valeur différente dans une autre unité d
 msgid "mismatching definition"
 msgstr "définition non concordante"
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr "fnsummary invalide dans un flux LTO"
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr "le résumé en ligne ipa est manquant dans le fichier d'entrée"
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, gcc-internal-format
 msgid "IPA modref summary is missing in input file"
 msgstr "le résumé de modref IPA est manquant dans le fichier d'entrée"
@@ -29624,72 +29624,72 @@ msgstr "erreur d'écriture des enregistrements optimisés dans %qs : %s"
 msgid "error closing optimization records %qs"
 msgstr "erreur lors de la fermeture des enregistrements optimisés %qs"
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, gcc-internal-format
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "l'option %qs en ligne de commande n'est pas supportée par cette configuration"
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "argument manquant à %qs"
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr "l'argument de %qs devrait être un entier non négatif optionnellement suivi d'une unité de taille"
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer"
 msgstr "l'argument de %qs doit être un entier non négatif"
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, gcc-internal-format
 msgid "argument to %qs is not between %d and %d"
 msgstr "l'argument de %qs n'est pas entre %d et %d"
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, gcc-internal-format
 msgid "invalid argument in option %qs"
 msgstr "argument invalide pour l'option %qs"
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr "%qs est spécifié plusieurs fois dans la même option"
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, gcc-internal-format
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr "%qs est mutuellement exclusif avec %qs et ne peuvent pas être spécifiées ensemble"
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, gcc-internal-format
 msgid "unrecognized argument in option %qs"
 msgstr "argument non reconnu pour l'option %qs"
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "les arguments valables pour %qs sont: %s; vouliez vous utiliser %qs ?"
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "les arguments valables pour %qs sont: %s"
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "l'option %qs n'est plus supportée"
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, gcc-internal-format
 msgid "argument to %qs is bigger than %d"
 msgstr "l'argument pour %qs est plus grand que %d"
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, gcc-internal-format
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
 msgstr "%<COLLECT_GCC_OPTIONS%> mal formé"
@@ -29763,8 +29763,8 @@ msgstr "l'argument de %<-O%> doit être un entier non négatif, %<g%>, %<s%>, %<
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, gcc-internal-format
 msgid "%qs is incompatible with %qs"
 msgstr "%qs est incompatible avec %qs"
@@ -30479,7 +30479,7 @@ msgstr "une variable-registre globale suit une définition de fonction"
 msgid "register of %qD used for multiple global register variables"
 msgstr "le registre de %qD est utilisé pour plusieurs variables-registre globales"
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "en conflit avec %qD"
@@ -30930,42 +30930,42 @@ msgstr "la section de l'alias %q+D doit correspondre à la section de sa cible"
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "%<__builtin_saveregs%> n'est pas supporté par cette cible"
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, gcc-internal-format
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "l'argument %qs n'est pas supporté pour %qs sur cette cible"
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, gcc-internal-format
 msgid "nested functions not supported on this target"
 msgstr "fonctions imbriquées pas supportées sur cette cible"
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, gcc-internal-format
 msgid "nested function trampolines not supported on this target"
 msgstr "trampolines de fonctions imbriquées pas supportés sur cette cible"
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "les constructeurs globaux ne sont pas supportés sur cette cible"
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "les destructeurs globaux ne sont pas supportés sur cette cible"
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, gcc-internal-format
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "l'attribut %<target%> n'est pas supporté sur cette machine"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, gcc-internal-format
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "l'attribut %<target_version%> n'est pas supporté sur cette machine"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, gcc-internal-format
 msgid "%<#pragma GCC target%> is not supported for this machine"
 msgstr "%<#pragma GCC target%> n'est pas supporté pour cette machine"
@@ -32078,82 +32078,82 @@ msgstr "le BB %i a une arête incorrecte"
 msgid "BB %i has incorrect fallthru edge"
 msgstr "le BB %i a une arête fallthru incorrecte"
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr "la fonction %q+F ne peut jamais être copiée car elle reçoit un « goto » non local"
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr "la fonction %q+F ne peut jamais être copiée car elle sauvegarde l'adresse d'une étiquette locale dans une variable statique"
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr "la fonction %q+F ne peut jamais être mise en ligne car elle utilise « alloca » (ce qui sera outrepassé en utilisant l'attribut « always_inline »)"
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr "la fonction %q+F ne peut jamais être mise en ligne parce qu'elle utilise setjmp"
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr "la fonction %q+F ne peut jamais être mise en ligne parce qu'elle utilise une liste variable d'arguments"
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr "la fonction %q+F ne peut jamais être mise en ligne parce qu'elle utilise setjmp-longjmp pour gérer les exceptions"
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr "la fonction %q+F ne peut jamais être mise en ligne parce qu'elle utilise un « goto » qui n'est pas local"
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr "la fonction %q+F ne peut jamais être mise en ligne parce qu'elle utilise %<__builtin_return%> ou %<__builtin_apply_args%>"
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr "la fonction %q+F ne peut jamais être mise en ligne parce qu'elle contient un « goto » calculé"
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr "la fonction %q+F ne peut jamais être mise en ligne parce qu'elle a un argument VLA"
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr "la fonction %q+F ne peut jamais être mise en ligne parce que cela est supprimé par l'utilisation de %<-fno-inline%>"
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr "la fonction %q+F ne peut jamais être mise en ligne parce qu'elle utilise des attributs en conflit avec la mise en ligne"
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, gcc-internal-format
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr "la mise en ligne a échoué dans l'appel à %<always_inline%> %q+F: %s"
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr "appelé d'ici"
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, gcc-internal-format
 msgid "called from this function"
 msgstr "appelé depuis cette fonction"
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, gcc-internal-format
 msgid "inlining failed in call to %q+F: %s"
 msgstr "la mise en ligne a échoué dans l'appel à %q+F: %s"
@@ -32209,27 +32209,27 @@ msgstr "attribut de spec fn « %s » invalide"
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr "attribut de spec fn « %s » invalide arg %i"
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr "le pointeur %qs est nul"
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, gcc-internal-format
 msgid "in a call to non-static member function %qD"
 msgstr "dans un appel à la fonction membre non statique %qD"
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr "argument %u nul où un non-nul est attendu"
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "dans un appel à la fonction interne %qD"
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, gcc-internal-format
 msgid "in a call to function %qD declared %qs"
 msgstr "dans un appel à la fonction %qD déclarée %qs"
@@ -32433,7 +32433,7 @@ msgstr "%qs est utilisé sans avoir été initialisé"
 msgid "%qs may be used uninitialized"
 msgstr "%qs pourrait être utilisé sans être initialisé"
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD a été déclaré ici"
@@ -32663,7 +32663,7 @@ msgstr "la condition vectorielle sera développée à la pièce"
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "l'opération de brassage vectoriel sera développée à la pièce"
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr "la vectorisation n'a pas eu lieu pour une boucle simd"
@@ -32678,122 +32678,122 @@ msgstr "élément non constant dans un CONSTRUCTOR constant"
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr "élément avec des effets de bord dans un CONSTRUCTOR sans effets de bord"
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "les tableaux de fonctions ne sont pas pertinents"
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "le type retourné par une fonction ne peut être une fonction"
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "vérification de l'arbre: %s, obtenu %s dans %s, à %s:%d"
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "vérification de l'arbre: n'attendait aucun parmi %s, obtenu %s dans %s, à %s:%d"
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "vérification de l'arbre: attendait la classe %qs, obtenu %qs (%s) dans %s, à %s:%d"
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "vérification de l'arbre: on n'attendait pas la classe %qs, obtenu %qs (%s) dans %s, à %s:%d"
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, gcc-internal-format
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr "vérification de l'arbre: attendait %<omp_clause %s%>, obtenu %s dans %s, à %s:%d"
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "vérification de l'arbre: attendait un arbre contenant la structure %qs, obtenu %qs dans %s, à %s:%d"
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr "vérification de l'arbre: accès à elt %d de %<tree_int_cst%> avec %d elts dans %s, à %s:%d"
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr "vérification de l'arbre: accès à elt %d de %<tree_vec%> avec %d elts dans %s, à %s:%d"
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "vérification de l'arbre: opérande accédé %d de %s avec %d opérandes dans %s, à %s:%d"
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, gcc-internal-format
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "vérification de l'arbre: opérande accédé %d de %<omp_clause %s%> avec %d opérandes dans %s, à %s:%d"
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD est obsolète: %s"
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD est obsolète"
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE est obsolète: %s"
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE est obsolète"
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "le type est obsolète: %s"
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "le type est obsolète"
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, gcc-internal-format
 msgid "%qD is unavailable: %s"
 msgstr "%qD n'est pas disponible : %s"
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, gcc-internal-format
 msgid "%qD is unavailable"
 msgstr "%qD n'est pas disponible"
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, gcc-internal-format
 msgid "%qE is unavailable: %s"
 msgstr "%qE n'est pas disponible : %s"
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, gcc-internal-format
 msgid "%qE is unavailable"
 msgstr "%qE n'est pas disponible"
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, gcc-internal-format, gfc-internal-format
 msgid "type is unavailable: %s"
 msgstr "le type n'est pas disponible : %s"
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, gcc-internal-format
 msgid "type is unavailable"
 msgstr "le type n'est pas disponible"
@@ -32818,262 +32818,262 @@ msgstr "le type n'est pas disponible"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr "la variante du type diffère sur %s"
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr "la variante du type a un %<TYPE_SIZE_UNIT%> différent"
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr "%<TYPE_SIZE_UNIT%> de la variante du type"
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr "%<TYPE_SIZE_UNIT%> du type"
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr "variante du type avec %<TYPE_ALIAS_SET_KNOWN_P%>"
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr "la variante du type a un %<TYPE_VFIELD%> différent"
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr "la variante du type a un %<TYPE_BINFO%> différent"
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr "%<TYPE_BINFO%> de la variante du type"
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr "%<TYPE_BINFO%> du type"
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr "la variante du type a un %<TYPE_FIELDS%> différent"
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "le premier désaccord est le champ"
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, gcc-internal-format
 msgid "and field"
 msgstr "et le champ"
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr "la variante du type a un %<TREE_TYPE%> différent"
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr "%<TREE_TYPE%> de la variante du type"
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr "%<TREE_TYPE%> du type"
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "le type n'est pas compatible avec sa variante"
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is not an opaque type"
 msgstr "le type %s n'est pas un type opaque"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is not with opaque mode"
 msgstr "le type %s n'est pas avec un mode opaque"
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr "le type %s diffère sur %<TYPE_MODE%>"
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr "le type %s diffère sur %<TYPE_SIZE%>"
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr "le type %s diffère sur %<TYPE_ALIGN%>"
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr "le type %s diffère sur %<TYPE_USER_ALIGN%>"
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, gcc-internal-format
 msgid "main variant is not defined"
 msgstr "la variante principale n'est pas définie"
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr "%<TYPE_MAIN_VARIANT%> a un %<TYPE_MAIN_VARIANT%> différent"
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr "%<TYPE_CANONICAL%> a un %<TYPE_CANONICAL%> différent"
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr "%<TYPE_CANONICAL%> n'est pas compatible"
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr "le %<TYPE_MODE%> de %<TYPE_CANONICAL%> n'est pas compatible"
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr "le %<TYPE_CANONICAL%> de la variante principale n'est pas la variante principale"
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr "%<TYPE_VFIELD%> n'est pas %<FIELD_DECL%> ni %<TREE_LIST%>"
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr "%<TYPE_NEXT_PTR_TO%> n'est pas %<POINTER_TYPE%>"
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr "%<TYPE_NEXT_REF_TO%> n'est pas %<REFERENCE_TYPE%>"
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr "%<TYPE_BINFO%> n'est pas %<TREE_BINFO%>"
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr "le type %<TYPE_BINFO%> n'est pas %<TYPE_MAIN_VARIANT%>"
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr "%<TYPE_METHOD_BASETYPE%> n'est pas un enregistrement ni une union"
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr "%<TYPE_OFFSET_BASETYPE%> n'est pas un enregistrement ni une union"
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr "%<TYPE_ARRAY_MAX_SIZE%> pas %<INTEGER_CST%>"
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr "%<TYPE_MAX_VALUE_RAW%> non NULL"
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr "le champ %<TYPE_LANG_SLOT_1 (binfo)%> est non NULL"
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr "la valeur de l'enum n'est pas %<CONST_DECL%> ou %<INTEGER_CST%>"
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr "le type de la valeur de l'enum n'est pas %<INTEGER_TYPE%> et n'est pas convertible en l'enum"
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr "le nom de la valeur de l'enum n'est pas %<IDENTIFIER_NODE%>"
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "le %<TYPE_DOMAIN%> du tableau n'est pas d'un type entier"
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "%<TYPE_FIELDS%> défini dans un type incomplet"
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr "arbre erroné dans la liste %<TYPE_FIELDS%>"
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr "%<TYPE_CACHED_VALUES_P%> est %i tandis que %<TYPE_CACHED_VALUES%> est %p"
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr "%<TYPE_CACHED_VALUES%> n'est pas %<TREE_VEC%>"
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr "mauvaise entrée %<TYPE_CACHED_VALUES%>"
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr "%<TREE_PURPOSE%> n'est pas NULL dans la liste %<TYPE_ARG_TYPES%>"
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr "entrée erronée dans la liste %<TYPE_ARG_TYPES%>"
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr "le champ %<TYPE_VALUES_RAW%> n'est pas NULL"
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr "%<TYPE_CACHED_VALUES_P%> est défini alors qu'il ne le devrait pas"
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr "%<TYPE_METHOD_BASETYPE%> n'est pas la variante principale"
@@ -33289,7 +33289,7 @@ msgstr "les définitions d'alias ne sont pas supportées dans cette configuratio
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "l'attribut de visibilité n'est pas supporté dans cette configuration; ignoré"
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr "%+qD sans l'attribut %<retain%> et %qD avec l'attribut %<retain%> sont placés dans une section avec le même nom"
@@ -33493,7 +33493,7 @@ msgstr "l'attribut %qE est ignoré car %qD n'est pas une variable"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "l'attribut %qE est ignoré car %qD n'est pas une variable locale"
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "l'attribut %qE n'a d'effet que sur les objets publics"
@@ -33675,7 +33675,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr "l'attribut %qE est ignoré car il n'est pas défini sur une variable"
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for local variables"
 msgstr "l'attribut %qE ne peut être spécifié pour des variables locales"
@@ -33990,7 +33990,7 @@ msgstr "%qD n'est pas compatible avec %qD"
 msgid "%qE argument is not a function"
 msgstr "l'argument de %qE n'est pas une fonction"
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "le message déprécié n'est pas une chaîne"
@@ -34496,7 +34496,7 @@ msgstr "le C++ ISO ne permet pas l'utilisation de %<alignof%> sur un type foncti
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr "le C ISO ne permet pas l'utilisation de %<_Alignof%> sur un type fonction"
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, gcc-internal-format
 msgid "invalid application of %qs to a void type"
 msgstr "utilisation invalide de %qs sur un type void"
@@ -34628,17 +34628,17 @@ msgstr "l'attribut %<fallthrough%> est spécifié plusieurs fois"
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "l'attribut %<fallthrough%> est spécifié avec un paramètre"
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "trop peu d'arguments pour la fonction %qE"
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, gcc-internal-format
@@ -34762,166 +34762,166 @@ msgstr "tentative de prendre l'adresse du membre %qD qui est un champ de bits d'
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "l'index %E désigne un offset plus grand que la taille de %qT"
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "la taille du tableau est trop grande"
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "le type %qT de l'opérande est incompatible avec l'argument %d de %qE"
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, gcc-internal-format
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "argument de type pointeur ou de type entier attendu pour l'argument 1"
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr "les deux arguments doivent être compatibles"
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "nombre d'arguments incorrect pour la fonction %qE"
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "l'argument 1 de %qE doit être un type pointeur non void"
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr "l'argument 1 de %qE doit être un pointeur vers un type complet"
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "l'argument 1 de %qE doit être un pointeur vers un type ayant une taille constante"
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "l'argument 1 de %qE doit être un pointeur vers un objet de taille non nulle"
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "l'argument %d de %qE doit être un type pointeur"
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "l'argument %d de %qE doit être un pointeur vers un type ayant une taille constante"
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "l'argument %d de %qE doit être un pointeur vers une fonction"
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "désaccord de taille dans l'argument %d de %qE"
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr "l'argument %d de %qE doit être un pointeur vers un type %<const%>"
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, gcc-internal-format
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr "l'argument %d de %qE perd le qualificatif %<const%>"
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr "l'argument %d de %qE ne peut pas être un pointeur vers un type %<volatile%>"
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, gcc-internal-format
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr "l'argument %d de %qE perd le qualificatif %<volatile%>"
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "modèle mémoire non entier pour l'argument %d de %qE"
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "modèle mémoire invalide pour l'argument %d de %qE"
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr "cette cible ne défini pas de barrière de spéculation; votre programme s'exécutera quand même correctement mais des spéculations incorrectes pourraient ne pas être restreintes"
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "la valeur de l'index est hors limites"
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "la conversion du scalaire %qT vers le vecteur %qT implique une troncature"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "la fonction interne %qE doit être appelée directement"
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr "la taille du tableau %qE n'est pas une expression constante"
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr "la taille du tableau n'est pas une expression constante"
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr "la taille %qE du tableau %qE est négative"
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, gcc-internal-format
 msgid "size %qE of array is negative"
 msgstr "la taille %qE du tableau est négative"
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr "la taille %qE du tableau %qE excède la taille maximale %qE de l'objet"
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr "la taille %qE du tableau excède la taille maximale %qE de l'objet"
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "la taille du tableau %qE excède la taille maximale %qE de l'objet"
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr "la taille du tableau excède la taille maximale %qE de l'objet"
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr "la variable d'environnement %s doit fournir un entier non négatif plus petit que ou égal à %wd"
@@ -35545,7 +35545,7 @@ msgstr "la constante entière est trop grande pour le type %<unsigned _BitInt(%d
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr "la constante entière est trop grande pour le type %<_BitInt(%d)%>"
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, gcc-internal-format
 msgid "%<_BitInt(%d)%> is not supported on this target"
 msgstr "%<_BitInt(%d)%> n'est pas supporté sur cette cible"
@@ -35625,7 +35625,7 @@ msgstr "concaténation non standard de chaînes littérales non supportée"
 msgid "traditional C rejects string constant concatenation"
 msgstr "le C traditionnel rejette la concaténation de chaînes constantes"
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr "%<#pragma omp critical%> avec la clause %<hint%> requiert un nom sauf quand %<omp_sync_hint_none%> est utilisé"
@@ -35680,7 +35680,7 @@ msgstr "type de dépendance %<depobj%> spécifié dans la clause %<depend%> d'un
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "le modificateur %<iterator%> ne peut pas être spécifié sur une construction %<depobj%>"
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "type invalide pour la variable d'itération %qE"
@@ -35695,17 +35695,17 @@ msgstr "variable d'itération %<_Atomic%> %qE"
 msgid "%qE is not initialized"
 msgstr "%qE n'est pas initialisé"
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "prédicat de contrôle manquant"
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "prédicat de contrôle invalide"
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "expression d'incrémentation manquante"
@@ -35715,7 +35715,7 @@ msgstr "expression d'incrémentation manquante"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr "l'incrément n'est pas la constante 1 ou -1 pour la condition %<!=%>"
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "expression d'incrémentation invalide"
@@ -35800,7 +35800,7 @@ msgstr "modificateur de réduction %<task%> invalide sur une construction pas co
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr "clause %<inscan%> %<reduction%> sur une construction autre que %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr "%qD spécifié dans la clause %<allocate%> mais pas dans dans la clause de privatisation explicite"
@@ -35810,7 +35810,7 @@ msgstr "%qD spécifié dans la clause %<allocate%> mais pas dans dans la clause
 msgid "%qD is not a function argument"
 msgstr "%qD n'est pas un argument de fonction"
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "champ de bits %qE dans la clause %qs"
@@ -36402,7 +36402,7 @@ msgid "wrong type argument to %s"
 msgstr "argument de type erroné pour %s"
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -37329,36 +37329,38 @@ msgid "comparison between two arrays"
 msgstr "comparaison entre deux tableaux"
 
 #: c-family/c-warn.cc:3832
-#, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+#, fuzzy, gcc-internal-format
+#| msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr "utiliser le %<+%> unaire qui dégrade les opérandes vers des pointeurs ou %<&%D[0] %s &%D[0]%> pour comparer les adresses"
 
-#: c-family/c-warn.cc:3836
-#, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+#: c-family/c-warn.cc:3839
+#, fuzzy, gcc-internal-format
+#| msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr "utilisez %<&%D[0] %s &%D[0]%> pour comparer les adresses"
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr "le résultat de %<%wu^%wu%> est %wu ; vouliez-vous utiliser %<1 << %wu%> (%wu) ?"
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr "le résultat de %<%wu^%wu%> est %wu ; vouliez-vous utiliser %<1LL << %wu%> ?"
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr "le résultat de %<%wu^%wu%> est %wu ; vouliez-vous utiliser une exponentiation ?"
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr "le résultat de %<%wu^%wu%> est %wu ; vouliez-vous utiliser %<1e%wu%> ?"
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr "vous pouvez supprimer ces avertissements en utilisant une constante hexadécimale (%wx au lieu de %wd)"
@@ -37567,117 +37569,117 @@ msgstr "l'argument de %<-misr-secure=%d%> n'est pas entre 0 et 3"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr "dans l'option %<-mcache-block-size=X%>, les valeurs valides pour X sont: 4, 8, 16, 32, 64, 128, 256, ou 512"
 
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr "%<-march=%s%>: l'extension %qs apparaît plus d'une fois"
 
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr "%<-march=%s%>: l'extension %qs est une extension standard a une seule lettre non supportée"
 
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr "%<-march=%s%>: l'extension %qs commence par « z » mais c'est une extension standard non supportée"
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr "%<-march=%s%>: l'extension %qs commence par « s » mais c'est une extension superviseur standard non supportée"
 
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr "%<-march=%s%>: l'extension %qs commence par « x » mais c'est une extension non standard non supportée"
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, gcc-internal-format
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr "%<-march=%s%>: nombre attendu après %<%dp%>"
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr "%<-march=%s%>: pour %<%s%dp%dp?%>, un numéro de version avec plus de deux niveaux n'est pas supporté"
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr "%<-march=%s%>: la chaîne ISA doit commencer par rv32 ou rv64"
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr "%<-march=%s%>: rv%de n'est pas une ISA de base valable"
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr "la version de %<g%> sera omise, veuillez spécifier la version pour chaque extension individuellement."
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr "%<-march=%s%>: le premier sous-ensemble ISA doit être %<e%>, %<i%> ou %<g%>"
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, gcc-internal-format
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr "%<-march=%s%>: pas une extension a une seule lettre. %<%c%>"
 
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr "%<-march=%s%>: l'extension zcf est uniquement supportée dans rv32"
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr "%<-march=%s%>: conflits z*inx avec les extensions en virgule flottante"
 
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, gcc-internal-format
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr "%<-march=%s%>: l'extension l'extension requiert l'extension i"
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr "%<-march=%s%> zcd est en conflit avec zcmt"
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr "%<-march=%s%> zcd est en conflit avec zcmp"
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr "%<-march=%s%>: xtheadvector est en conflit avec l'extension vectorielle ou sa sous-extension"
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "%<-march=%s%>: le nom de %s doit avoir plus d'une lettre"
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr "%<-march=%s%> %s doit être séparé par %<_%>"
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, gcc-internal-format
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr "%<-march=%s%>: i, e ou g doit être la première extension"
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "%<-mcpu=%s%>: CPU inconnu"
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr "Impossible de trouver un ensemble multi bibliothèques pour %<-march=%s%>/%<-mabi=%s%>"
@@ -38075,12 +38077,12 @@ msgstr "adresse sur 64 bits attendue mais l'argument 1 a %d bits"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "adresse sur 64 bits attendue mais l'argument 2 a %d bits"
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC aarch64%> existe une chaîne en paramètre"
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "option %qs inconnue pour %<#pragma GCC aarch64%>"
@@ -38644,7 +38646,7 @@ msgstr "le passage de paramètre pour l'argument de type %qT a changé dans GCC
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "le passage de paramètre pour l'argument de type %qT a changé dans GCC 9.1"
@@ -38720,12 +38722,12 @@ msgid "unknown tuning option (%s)"
 msgstr "option d'ajustement inconnue (%s)"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr "%<-mstack-protector-guard=global%> et %<-mstack-protector-guard-offset=%qs%> incompatibles"
 
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr "%<-mstack-protector-guard-offset%> et %<-mstack-protector-guard-reg%> doivent être utilisés tous les deux avec %<-mstack-protector-guard=sysreg%>"
@@ -38736,7 +38738,7 @@ msgid "specify a system register with a small string length"
 msgstr "spécifie un registre système avec une chaîne de courte longueur"
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs n'est pas un décalage valide dans %qs"
@@ -38916,9 +38918,9 @@ msgstr "le pragma ou l'attribut %<target(\"%s\")%> n'autorise pas de forme néga
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "le pragma ou l'attribut %<target(\"%s=%s\")%> n'est pas valide"
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "l'argument %<target%> de l'attribut n'est pas une chaîne"
@@ -38970,18 +38972,18 @@ msgid "virtual function multiversioning not supported"
 msgstr "des versions multiples de fonctions virtuelles ne sont pas supportées"
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "les versions multiples requièrent %<ifunc%> qui n'est pas supporté sur cette cible"
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr "le passage de paramètre pour l'argument de type %qT avec des membres %<[[no_unique_address]]%> a changé dans %{GCC 10.1%}"
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr "le passage par paramètre pour l'argument de type %qT quand C++17 est activé a changé pour correspondre à C++14 %{dans GCC 10.1%}"
 
@@ -38994,8 +38996,8 @@ msgstr "le passage de paramètre pour l'argument de type %qT a changé dans %{GC
 msgid "lane %wd out of range %wd - %wd"
 msgstr "avenue %wd hors des limites %wd - %wd"
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "simdlen %wd non supportée"
@@ -39005,7 +39007,7 @@ msgstr "simdlen %wd non supportée"
 msgid "GCC does not currently support return type %qT for simd"
 msgstr "GCC ne supporte actuellement pas le type de retour %qT pour simd"
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "type de retour %qT non supporté pour simd"
@@ -39015,7 +39017,7 @@ msgstr "type de retour %qT non supporté pour simd"
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr "GCC ne supporte actuellement pas un argument de type %qT pour simd"
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "type d'argument %qT non supporté pour simd"
@@ -39105,8 +39107,8 @@ msgstr "latence de la cache L%d inconnue pour %s"
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "valeur %qs erronée pour %<-mmemory-latency%>"
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr "fcode interne erroné"
@@ -39226,18 +39228,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "l'argument de l'attribut %qE n'est pas « ilink » ni « firq »"
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -39351,7 +39353,7 @@ msgid "argument of %qE attribute is missing"
 msgstr "l'argument de l'attribut %qE est manquant"
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "l'attribut %qE n'accepte qu'une constante entière comme argument"
@@ -39371,23 +39373,23 @@ msgstr "l'attribut %qE ne s'applique qu'à des types"
 msgid "argument of %qE attribute ignored"
 msgstr "l'argument de l'attribut %qE est ignoré"
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "l'attribut %qE ne s'applique qu'aux variables"
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "les alternatives ne sont pas autorisées dans la sortie du fanion %<asm%>"
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr "sortie du fanion %<asm%> %qs inconnue"
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "type invalide pour la sortie du fanion %<asm%>"
@@ -39629,7 +39631,7 @@ msgstr "le processeur cible ne supporte pas les instructions THUMB"
 msgid "target CPU does not support unaligned accesses"
 msgstr "le processeur cible ne supporte pas les accès non alignés"
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr "Cette architecture ne supporte pas les instructions de protection de branche"
@@ -39679,7 +39681,7 @@ msgstr "la frontière de la taille de la structure peut seulement être 8 ou 32"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC est incompatible avec %<-msingle-pic-base%>"
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "le mode FDPIC n'est pas supporté en mode Thumb-1"
@@ -39785,7 +39787,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr "argument de type %qT pas permis avec %<-mgeneral-regs-only%>"
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "le passage de paramètre pour l'argument de type %qT a changé dans GCC 7.1"
@@ -39825,42 +39827,42 @@ msgstr "l'attribut %qE n'a pas d'effet sur les fonctions statiques"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "l'attribut %qE ne s'applique qu'au type de base d'un pointeur vers une fonction"
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr "l'accès à un stockage local au thread n'est actuellement pas supporté avec %<-mpure-code%> ou %<-mslow-flash-data%>"
 
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd hors des limites %wd - %wd"
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "incapable de calculer la position réelle des paramètres sur la pile"
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Saut lointain thumb1 inattendu"
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "pas de registre bas disponible pour dépiler les registres hauts"
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "les routines du service d'interruption ne peuvent pas être codées en mode Thumb-1"
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "%<-fstack-check=specific%> pour Thumb-1"
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "fpu invalide pour l'attribut ou le pragma cible %qs"
@@ -39868,22 +39870,22 @@ msgstr "fpu invalide pour l'attribut ou le pragma cible %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "la sélection automatique du fpu n'est actuellement pas permise ici"
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "architecture invalide pour l'attribut ou le pragma cible %qs"
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "attribut ou pragma cible %qs inconnu"
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "fanions %<asm%> non supportés en mode thumb1"
@@ -39937,161 +39939,161 @@ msgstr "architectures de cœurs supportées:%s"
 msgid "unknown core architecture %qs specified with %qs"
 msgstr "architecture de cœur %qs inconnue spécifiée avec %qs"
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, gcc-internal-format
 msgid "%<-fpic%> is not supported"
 msgstr "%<-fpic%> n'est pas supporté"
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, gcc-internal-format
 msgid "%<-fPIC%> is not supported"
 msgstr "%<-fPIC%> n'est pas supporté"
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, gcc-internal-format
 msgid "%<-fpie%> is not supported"
 msgstr "%<-fpie%> n'est pas supporté"
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, gcc-internal-format
 msgid "%<-fPIE%> is not supported"
 msgstr "%<-fPIE%> n'est pas supporté"
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "les attributs de fonction %qs et %qs sont mutuellement exclusifs"
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "la fonction avec l'attribut %qs ne peut pas avoir d'argument"
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "la fonction avec l'attribut %qs ne peut pas retourner une valeur"
 
 # %s est « interrupt » ou « signal » non traduit.
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, gcc-internal-format
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs semble être un gestionnaire avec l'attribut %qs mal orthographié, il manque le préfixe %<__vector%>"
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr "%qs est un identificateur réservé de AVR-LibC. Envisagez %<#include <avr/interrupt.h>%> avant d'utiliser la macro %qs"
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, gcc-internal-format
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr "%qs est un identificateur déprécié de AVR-LibC. Envisagez %<#include <avr/interrupt.h>%> ou %<#include <compat/deprecated.h>%> avant d'utiliser la macro %qs"
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr "%<builtin_return_address%> ne contient que 2 octets d'adresse"
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr "l'offset du pointeur par rapport au symbole peut être incorrect"
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr "accès à la mémoire des données avec une adresse mémoire du programme"
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr "accès à la mémoire du programme avec une adresse mémoire des données"
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr "registre fixe %s utilisé pour passer un paramètre à la fonction"
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "l'écriture dans l'espace d'adresses %qs n'est pas supportée"
 
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "l'attribut %qE ne s'applique qu'aux variables statiques"
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "l'attribut %qE n'est supporté que par les cœurs Tiny réduits"
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, gcc-internal-format
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr "l'adresse de l'attribut %qE est hors limites 0x%x%s0x%x"
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr "les attributs %s et %qE fournissent tous les deux une adresse"
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "attribut %qE sur une variable non volatile"
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "les espaces d'adresses ne sont pas supportés pour les périphériques Tiny réduits"
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "l'espace d'adresses %qs n'est pas supporté pour les périphériques avec une taille de flash jusqu'à %d Kio"
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr "un pointeur visant l'espace d'adresses %qs doit être « const » dans %qT"
 
 # %s est un texte non traduit tel que « variable », « function parameter », « structure field »,…
 # J'ai soumis le bug 79453 pour demander de créer des messages spécifiques à chaque cas.
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr "un pointeur visant l'espace d'adresses %qs doit être const dans le/la %s %q+D"
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, gcc-internal-format
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr "la variable %q+D avec l'attribut %qs doit être placée dans le stockage statique"
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr "la variable %q+D doit être « const » pour être placée dans une section en lecture seule à l'aide de %qs"
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, gcc-internal-format
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr "la déclaration de l'attribut statique %qs pour %q+D a besoin d'une adresse"
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr "seules les variables non initialisées peuvent être placées dans la section %<.noinit%>"
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, gcc-internal-format
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr "variable %q+D avec une initialisation dynamique placée dans la zone mémoire du programme"
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "variable non initialisée %q+D placée dans la zone mémoire du programme"
@@ -40100,42 +40102,42 @@ msgstr "variable non initialisée %q+D placée dans la zone mémoire du programm
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, gcc-internal-format
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr "la variable %q+D avec l'attribut %qs ne doit pas avoir d'initialiseur"
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%q+D a les attributs incompatibles %qs et %qs"
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr "l'architecture %qs n'est supportée que par l'assembleur"
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "conversion depuis l'espace d'adresses %qs vers l'espace d'adresses %qs"
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "%s attend une constante entière à la compilation"
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%s attend une constante sous forme d'entier long à la compilation comme premier argument"
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr "arrondir à %d bits n'a pas d'effet pour une valeur en virgule fixe avec %d bits fractionnels"
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr "le résultat de l'arrondi sera toujours 0"
@@ -40271,7 +40273,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "appel indirect dans une fonction, ceci n'est pas supporté par eBPF"
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, gcc-internal-format
@@ -40890,8 +40892,8 @@ msgstr "l'argument de l'intrinsèque %<xabort%> doit être une valeur immédiate
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr "les versions de fonctions ne peuvent pas être marquées avec %<gnu_inline%>, des corps de fonctions doivent être générés"
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "le modèle de code %s ne supporte pas le mode PIC"
@@ -40957,255 +40959,255 @@ msgstr "trop de plages de tailles spécifiées dans l'option %qs"
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "paramètre inconnu dans l'option %<-mtune-ctrl%>: %s"
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "la psABI du MCU Intel n'est pas supportée dans le mode %s"
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> est déprécié; utilisez plutôt %<-mtune=k8%> ou %<-mtune=generic%> selon ce qui est approprié"
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> est déprécié; utilisez plutôt %<target(\"tune=k8\")%> ou %<target(\"tune=generic\")%> selon ce qui est approprié"
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr "le support de %<-mtune=knl%> sera retiré dans GCC 15"
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr "le support de %<target(\"tune=knl\")%> sera retiré dans GCC 15"
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr "le support de %<-mtune=knm%> sera retiré dans GCC 15"
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr "le support de %<target(\"tune=knm\")%> sera retiré dans GCC 15"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "%<-mstringop-strategy=rep_8byte%> pas supporté pour du code 32 bits"
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, gcc-internal-format
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "%<-mapxf%> pas supporté pour du code 32 bits"
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, gcc-internal-format
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr "l'option %<-mapx-features=%> n'est pas supportée pour du code 32 bits"
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "%<-muintr%> pas supporté pour du code 32 bits"
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "option %<-mlam=%> : [u48|u57] pas supportée pour du code 32 bits"
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "le mode d'adresse %qs n'est pas supporté en mode %s bits"
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-mabi=ms%> pas supporté avec l'ABI X32"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "%<-mabi=%s%> n'est pas supportée avec %<-fsanitize=address%>"
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "%<-mabi=%s%> n'est pas supportée avec %<-fsanitize=kernel-address%>"
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "%<-mabi=%s%> n'est pas supportée avec %<-fsanitize=thread%>"
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr "%<-mlam=u48%> n'est pas compatible avec le Hardware-assisted AddressSanitizer, outrepasser pour %<-mlam=u57%>"
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "le modèle de code %qs n'est pas supporté en mode %s bits"
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "le modèle de code %qs n'est pas supporté en mode x32"
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "%<-masm=intel%> n'est pas supporté dans cette configuration"
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "mode %i bits pas compilé"
 
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "le processeur %<generic%> ne peut être utilisé qu'avec l'option %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "le processeur %<generic%> ne peut être utilisé qu'avec l'attribut %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "le processeur %<intel%> ne peut être utilisé qu'avec l'option %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "le processeur %<intel%> ne peut être utilisé qu'avec l'attribut %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "le processeur sélectionné ne supporte pas le jeu d'instructions x86-64"
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr "le support de %<-march=knl%> sera retiré dans GCC 15"
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr "le support de %<target(\"arch=knl\")%> sera retiré dans GCC 15"
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr "le support de %<-march=knm%> sera retiré dans GCC 15"
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr "le support de %<target(\"arch=knm\")%> sera retiré dans GCC 15"
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, gcc-internal-format
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "valeur %qs erronée pour l'option %<-march=%>"
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "valeur %qs erronée pour l'attribut %<target(\"arch=\")%>"
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'option %<-march=%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'attribut %<target(\"arch=\")%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "les arguments valides pour l'option %<-march=%> sont: %s"
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "les arguments valides pour l'attribut %<target(\"arch=\")%> sont: %s"
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "valeur %qs erronée pour l'option %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "valeur %qs erronée pour l'attribut %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'option %<-mtune=%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'attribut %<target(\"tune=\")%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "les arguments valides pour l'option %<-mtune=%> sont: %s"
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "les arguments valides pour l'attribut %<target(\"tune=\")%> sont: %s"
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "%<-mregparm%> est ignoré en mode 64 bits"
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "%<-mregparm%> est ignoré avec la psABI du MCU Intel"
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "%<-mregparm=%d%> n'est pas entre 0 et %d"
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "%<-m96bit-long-double%> n'est pas compatible avec cette cible"
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> est ignoré en mode 64 bits"
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> est ignoré en mode 64 bits"
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr "%<-mno-evex512%> ou %<-mno-avx512XXX%> ne peuvent pas désactiver les instructions AVX10 quand AVX10.1-512 est disponible"
@@ -41213,290 +41215,290 @@ msgstr "%<-mno-evex512%> ou %<-mno-avx512XXX%> ne peuvent pas désactiver les in
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr "Utiliser %<-mevex512%> sans fonctionnalités AVX512 activée mais avec AVX10.1 va simplement ne pas activer les fonctionnalités AVX512 ou AVX10.1-512, utilise 256 comme taille vectorielle max"
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr "Conflit de taille vectorielle entre AVX10.1 et AVX512, utilise 512 comme taille vectorielle max"
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr "%<-mno-avx512XXX%> ne sait pas désactiver les instructions AVX10 quand AVX10 est disponible"
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> ne sait pas désactiver les instructions AVX512 quand %<-mavx512XXX%>"
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "%<-mpreferred-stack-boundary%> n'est pas supporté pour cette cible"
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> n'est pas entre %d et %d"
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "%<-mincoming-stack-boundary=%d%> n'est pas entre %d et 12"
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%<-mnop-mcount%> n'est pas compatible avec cette cible"
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "%<-mnop-mcount%> n'est pas implémenté pour %<-fPIC%>"
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> utilisé sans que SSE soit activé"
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> utilisé sans que SSE soit activé"
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "jeu d'instructions SSE désactivé, l'arithmétique 387 est utilisée"
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "jeu d'instructions 387 désactivé, l'arithmétique SSE est utilisée"
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "le sondage de la pile requiert %<-maccumulate-outgoing-args%> pour être correcte"
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "le sondage de la pile requiert %<target(\"accumulate-outgoing-args\")%> pour être correcte"
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "le registre ebp fixé requiert %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "le registre ebp fixé requiert %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "%<-mfentry%> n'est pas supporté en 32 bits en combinaison avec %<-fpic%>"
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%<-mno-fentry%> n'est pas compatible avec SEH (gestionnaire d'exceptions structuré)"
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "%<-mcall-ms2sysv-xlogues%> n%'est actuellement pas supporté avec SEH"
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "option inconnue pour %<-mrecip=%s%>"
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs n'est pas un nombre valable dans %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs n'est pas un décalage valable dans %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs n'est pas un registre de base valable dans %<-mstack-protector-guard-reg=%>"
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr "%<-fcf-protection=full%> n'est pas activé par %<-fhardened%> car il a été spécifié sur la ligne de commande"
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%<-fcf-protection%> n'est pas compatible avec cette cible"
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "les attributs d'interruption et nus sont incompatibles"
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "les attributs %qs et %qs sont incompatibles"
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr "seul le format de débogage DWARF est supporté pour les routines de service d'interruptions"
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> et %<-mcmodel=large%> sont incompatibles"
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mindirect-branch%> et %<-fcf-protection%> sont incompatibles"
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> et %<-mcmodel=large%> sont incompatibles"
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mfunction-return%> et %<-fcf-protection%> sont incompatibles"
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "les instructions %s ne sont pas autorisées dans la routine de service exception"
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "les instructions %s ne sont pas autorisées dans la routine de service d'interruption"
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "les instructions %s ne sont pas autorisées dans la fonction avec l%'attribut %<no_caller_saved_registers%>"
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "les attributs fastcall et regparm sont incompatibles"
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "les attributs regparam et thiscall sont incompatibles"
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "l'attribut %qE requiert un argument de type constante entière"
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "l'argument pour l'attribut %qE est plus grand que %d"
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "les attributs fastcall et cdecl sont incompatibles"
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "les attributs fastcall et stdcall sont incompatibles"
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "les attributs fastcall et thiscall sont incompatibles"
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "les attributs stdcall et cdecl sont incompatibles"
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "les attributs stdcall et fastcall sont incompatibles"
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "les attributs stdcall et thiscall sont incompatibles"
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "les attributs cdecl et thiscall sont incompatibles"
 
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "l'attribut %qE est utilisé pour une méthode qui n'est pas une classe"
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "l'attribut incompatible %qE est ignoré"
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "l'attribut %qE est uniquement disponible en 32 bits"
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "l'argument de l'attribut %qE n'est ni zéro ni un"
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "l'attribut %qE requiert un argument de type constante chaîne de caractères"
 
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "l'argument de l'attribut %qE n'est pas (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "la routine de service d'interruption devrait avoir un pointeur comme premier argument"
 
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "la routine de service d'interruption devrait avoir %qs comme deuxième argument"
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "la routine de service d'interruption ne peut avoir qu'un argument de type pointeur et un argument entier optionnel"
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "la routine de service d'interruption doit retourner %<void%>"
@@ -41687,46 +41689,46 @@ msgstr "taille d'opérande non supportée pour un registre étendu"
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "opérande non entier utilise avec le code d'opérande %<z%>"
 
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr "l'ABI de passage de paramètres pour la classe vide %qT change avec %<-fabi-version=12%> (GCC 8)"
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr "l'alignement des champs de %<_Atomic %T%> ont changé dans %{GCC 11.1%}"
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, gcc-internal-format
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr "pas de registre disponible pour profiler %<-mcmodel=large%s%>"
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "le profilage %<-mcmodel=large%> avec PIC n'est pas supporté"
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr "%<__bfloat16%> est redéfini du typedef %<short%> en un réel %<__bf16%> depuis GCC 13.1, soyez attentif aux conversions implicites entre %<__bf16%> et %<short%>; un transtypage binaire explicite pourrait être nécessaire ici"
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "modèle mémoire spécifique à l'architecture inconnu"
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr "%<HLE_ACQUIRE%> n'est pas utilisé avec le modèle mémoire %<ACQUIRE%> ou un autre plus contraignant"
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr "%<HLE_RELEASE%> n'est pas utilisé avec le modèle mémoire %<RELEASE%> ou un autre plus contraignant"
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr "%<-fexcess-precision=16%> n'est pas compatible avec %<-mfpmath=387%>"
@@ -41746,8 +41748,8 @@ msgstr "définition d'un membre de données statique %q+D de la classe importée
 msgid "malformed %<#pragma builtin%>"
 msgstr "%<#pragma builtin%> mal composé"
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, gcc-internal-format
 msgid "invalid argument of %qE attribute"
 msgstr "argument invalide dans l'attribut %qE"
@@ -41802,12 +41804,12 @@ msgstr "%<PRINT_OPERAND%>: Ponctuation %<%c%> inconnue"
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr "%<PRINT_OPERAND%> pointeur nul"
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "l'argument %d de la fonction interne doit être une constante dans la plage %d à %d"
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, gcc-internal-format
 msgid "failed to expand built-in function"
 msgstr "échec lors du développement de la fonction interne"
@@ -41933,17 +41935,17 @@ msgstr "le modèle de code %qs n'est pas compatible avec %s"
 msgid "%qs cannot be used for compiling a shared library"
 msgstr "%qs ne peut pas être utilisé pour compiler une bibliothèque partagée"
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr "l'attribut %qE ne peut être spécifié pour des variables locales au thread"
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for register variables"
 msgstr "l'attribut %qE ne peut être spécifié pour des variables registres"
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, gcc-internal-format
 msgid "multiple %qE attribute"
 msgstr "attribut %qE multiple"
@@ -42044,12 +42046,12 @@ msgstr "plusieurs attributs d'interruption ne sont pas permis"
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr "%<interrupt_thread%> est disponible uniquement sur fido"
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "l'expression limitant la pile n'est pas supportée"
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not supported on this target"
 msgstr "%<-fexcess-precision=16%> n'est pas supporté pour cette cible"
@@ -42090,7 +42092,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr "%<-mxl-multiply-high%> requiert %<-mno-xl-soft-mul%>"
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "l'attribut %qE requiert une chaîne comme argument"
@@ -42130,132 +42132,132 @@ msgstr "le vecteur d'interruption de l'attribut %qE n'est pas %<vector=(sw0|sw1|
 msgid "argument to %qE attribute is not intstack"
 msgstr "l'argument de l'attribut %qE n'est pas « intstack »"
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr "l'ABI pour passer une valeur contenant des champs de bits de largeur zéro avant un champ en virgule flottante 64 bits adjacent a changé dans GCC %{12.1%}"
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr "l'ABI pour retourner une valeur contenant des champs de bits de largeur zéro mais étant par ailleurs un agrégat avec uniquement un ou deux champs en virgule flottante a été changée dans GCC %{12.1%}"
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr "l'ABI pour retourner une valeur avec des bases C++17 vides mais étant par ailleurs un agrégat avec uniquement un ou deux champs en virgule flottante a été changée dans GCC %{12.1%}"
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, gcc-internal-format
 msgid "cannot handle inconsistent calls to %qs"
 msgstr "ne peut traiter des appels inconstants à %qs"
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr "l'attribut %<interrupt%> requiert un processeur MIPS32r2 ou supérieur"
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr "les gestionnaires d'interruptions ne peuvent pas être des fonctions MIPS16"
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr "%<-fstack-check=specific%> pas implémenté pour MIPS16"
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, gcc-internal-format
 msgid "built-in function %qE not supported for MIPS16"
 msgstr "la fonction interne %qE n'est pas supportée pour un MIPS16"
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, gcc-internal-format
 msgid "%qs does not support MIPS16 code"
 msgstr "%qs ne supporte pas le code MIPS16"
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr "PIC MIPS16 pour des ABI autres que o32 et o64"
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, gcc-internal-format
 msgid "MIPS16 %<-mxgot%> code"
 msgstr "code %<-mxgot%> MIPS16"
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, gcc-internal-format
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr "code MIPS16 %<hard-float%> pour des ABI autres que o32 et o64"
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, gcc-internal-format
 msgid "MSA MIPS16 code"
 msgstr "code MIPS16 MSA"
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, gcc-internal-format
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr "MIPS16 requiert %<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported combination: %s"
 msgstr "combinaison non supportée: %s"
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, gcc-internal-format
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr "%<-%s%> est en conflit avec d'autres options d'architecture, lesquelles spécifient un processeur %s"
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, gcc-internal-format
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr "%<-march=%s%> n'est pas compatible avec l'ABI sélectionnée"
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr "%<-mgp64%> utilisé avec un processeur 32 bits"
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, gcc-internal-format
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr "%<-mgp32%> utilisé avec une ABI 64 bits"
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr "%<-mgp64%> utilisé avec une ABI 32 bits"
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "l'architecture %qs ne supporte pas %<-mfp32%>"
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr "%<-mgp32%> et %<-mfp64%> peuvent uniquement être combinés si la cible supporte les instructions mfhc1 et mthc1"
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr "%<-mgp32%> et %<-mfp64%> peuvent uniquement être combinés en utilisant l'ABI o32"
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr "%<-mfpxx%> peut uniquement être utilisé avec l'ABI o32"
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr "%<-march=%s%> requiert %<-mfp32%>"
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr "%<-mfpxx%> requiert %<-mlra%>"
@@ -42265,117 +42267,117 @@ msgstr "%<-mfpxx%> requiert %<-mlra%>"
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, gcc-internal-format
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr "la combinaison de %qs et %qs est incompatible avec %qs"
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, gcc-internal-format
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr "l'architecture %qs ne supporte pas les instructions de branchement probable"
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, gcc-internal-format
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr "l'architecture %qs ne supporte pas les instructions madd ou msub"
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr "l'architecture %qs ne supporte pas les registres impairs en simple précision"
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, gcc-internal-format
 msgid "unsupported combination: %qs%s %s"
 msgstr "combinaison non supportée: %qs%s %s"
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, gcc-internal-format
 msgid "unsupported combination: %qs %s"
 msgstr "combinaison non supportée: %qs %s"
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, gcc-internal-format
 msgid "cannot generate position-independent code for %qs"
 msgstr "impossible de produire du code indépendant de la position pour %qs"
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, gcc-internal-format
 msgid "position-independent code requires %qs"
 msgstr "le code indépendant de la position requiert %qs"
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr "%<-mno-gpopt%> à besoin de %<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr "impossible d'utiliser des accès à de petites données pour %qs"
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr "l'architecture %qs ne supporte pas %<-m%s=legacy%>"
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr "l'architecture %qs ne supporte pas %<-m%s=2008%>"
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, gcc-internal-format
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr "%<-mips3d%> requiert %<-mpaired-single%>"
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, gcc-internal-format
 msgid "%qs must be used with %qs"
 msgstr "%qs doit être utilisé avec %qs"
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, gcc-internal-format
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr "%<-mmsa%> doit être utilisé avec %<-mfp64%> et %<-mhard-float%>"
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, gcc-internal-format
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr "l'architecture %qs ne supporte pas les instructions en simple précision appariées (paired-single)"
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr "%qs requiert une cible qui fourni l'instruction %qs"
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, gcc-internal-format
 msgid "the %qs architecture does not support DSP instructions"
 msgstr "l'architecture %qs ne supporte pas les instructions DSP"
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, gcc-internal-format
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr "%<-mloongson-mmi%> doit être utilisé avec %<-mhard-float%>"
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, gcc-internal-format
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr "%<-mloongson-ext2%> doit être utilisé avec %<-mloongson-ext%>"
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, gcc-internal-format
 msgid "%qs requires branch-likely instructions"
 msgstr "%qs requiert les instructions de branchement probable"
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, gcc-internal-format
 msgid "the %qs architecture does not support the synci instruction"
 msgstr "l'architecture %qs ne supporte pas l'instruction synci"
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr "profilage de fonction mips16"
@@ -43244,57 +43246,57 @@ msgstr "%<#pragma riscv intrinsic%> existe une chaîne en paramètre"
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "option %qs inconnue pour %<#pragma riscv intrinsic%>"
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr "architecture inattendue pour l'attribut %<target()%> : doit commencer par + ou rv"
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr "architecture inattendue pour l'attribut %<target()%> : mauvaise chaîne %<%s%> rencontrée"
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, gcc-internal-format
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr "pour l'attribut %<target()%> : l'architecture apparaît plusieurs fois"
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, gcc-internal-format
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr "pour l'attribut %<target()%> : le cpu apparaît plusieurs fois"
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr "pour l'attribut %<target()%> : CPU %qs inconnu"
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, gcc-internal-format
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr "pour l'attribut %<target()%> : TUNE apparaît plusieurs fois"
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr "pour l'attribut %<target()%> : TUNE %qs inconnu"
 
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, gcc-internal-format
 msgid "malformed %<target()%> attribute"
 msgstr "l'attribut %<target()%> est mal composé"
 
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, gcc-internal-format
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "l'attribut %<target(\"%s\")%> n'accepte pas d'argument"
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, gcc-internal-format
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr "attribut %<target(\"%s\")%> inconnu"
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> attribute"
 msgstr "l'attribut %<target(\"%s\")%> est mal composé"
@@ -43354,172 +43356,196 @@ msgstr "ne peut lever ou intercepter une exception sur le type RVV %qT"
 msgid "capture by copy of RVV type %qT"
 msgstr "capture par copie du type RVV %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, fuzzy, gcc-internal-format
+#| msgid "built-in function %qE requires the %qs ISA extension"
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr "la fonction interne %qE requiert l'extension ISA %qs"
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, fuzzy, gcc-internal-format
+#| msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr "%s %qT requiert l'extension ISA zve32f, zve64f, zve64d ou v"
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, fuzzy, gcc-internal-format
+#| msgid "built-in function %qE requires the %qs ISA extension"
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr "la fonction interne %qE requiert l'extension ISA %qs"
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, fuzzy, gcc-internal-format
+#| msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr "%s %qT requiert l'extension ISA zve64x, zve64f, zve64d ou v"
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, gcc-internal-format
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr "la fonction interne %qE requiert l'extension ISA %qs"
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, gcc-internal-format
 msgid "no matching function call to %qE with empty arguments"
 msgstr "pas d'appel de fonction concordant pour %qE avec des arguments vides"
 
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "processeur %qs inconnu pour %<-mtune%>"
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, gcc-internal-format
 msgid "this operation requires the RVV ISA extension"
 msgstr "cette opération requiert l'extension de l'ISA RVV"
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr "vous pouvez activer RVV en utilisant l'option %<-march%> sur la ligne de commande ou en utilisant l'attribut ou le pragma %<target%>"
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "l'ABI pour des structures aplaties avec un champ de bits d'une taille non nulle a changé dans GCC 10"
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, gcc-internal-format
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr "le type RVV %qT ne peut pas être passé en argument à une fonction sans prototype"
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, gcc-internal-format
 msgid "%s %qT requires the V ISA extension"
 msgstr "%s %qT requiert l'extension ISA V"
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, gcc-internal-format
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr "%s %qT requiert l'extension ISA zve64x, zve64f, zve64d ou v"
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, gcc-internal-format
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr "%s %qT requiert l'extension ISA zvfhmin ou zvfh"
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, gcc-internal-format
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr "%s %qT requiert l'extension ISA zve32f, zve64f, zve64d ou v"
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, gcc-internal-format
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr "%s %qT requiert l'extension ISA zve64d ou v"
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr "%s %qT requiert la longueur de vecteur minimale %qd mais %qd est fourni"
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, gcc-internal-format
 msgid "function attribute %qs requires the V ISA extension"
 msgstr "l'attribut de fonction %qs requiert l'extension ISA V"
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "l'argument de l'attribut %qE n'est pas %<\"user\"%>, %<\"supervisor\"%> ou %<\"machine\"%>"
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr "%qs est uniquement supporté quand %<-mrvv-vector-bits=zvl%> est spécifié"
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, gcc-internal-format
 msgid "%qs applied to non-RVV type %qT"
 msgstr "%qs appliqué au type non-RVV %qT"
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, gcc-internal-format
 msgid "%qs requires an integer constant"
 msgstr "%qs requiert une constante entière"
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr "talle de vecteur RVV %qd invalide, la taille attendue est %qd sur base du LMUL de type %qs"
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "%<-mdiv%> requiert %<-march%> pour incorporer l'extension %<M%>"
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr "Le GCC RISC-V actuel ne supporte pas un VLEN plus grand que 4096 bits pour l'extension « V »"
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr "Le GCC RISC-V actuel ne supporte pas RVV en mode gros boutiste"
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, gcc-internal-format
 msgid "code model %qs with %qs"
 msgstr "modèle de code %qs avec %qs"
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "l'ABI demandée requiert %<-march%> pour incorporer l'extension %qc"
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr "rv32e requiert l'ABI ilp32e"
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, gcc-internal-format
 msgid "rv64e requires lp64e ABI"
 msgstr "rv64e requiert l'ABI lp64e"
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr "z*inx requiert l'ABI ilp32, ilp32e, lp64 ou lp64e"
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "l'ABI requiert %<-march=rv%d%>"
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> doit être entre %d et %d"
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr "l'attribut RISC-V ELF %<-mriscv-attribute%> requiert GNU as 2.32 [%<-mriscv-attribute%>]"
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs n'est pas un registre de base valable dans %qs"
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs n'est pas un nombre valide dans %qs"
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "la fonction %qs ne peut pas avoir un type d'interruption différent"
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr "impossible d'allouer le registre vl pour %qs sur cette cible"
@@ -43769,32 +43795,32 @@ msgstr "la fonction interne %qs n'accepte que 2 arguments"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "la fonction interne %qs n'accepte que 3 arguments"
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "%<vec_lvsl%> est déprécié pour les petits boutistes; utilisation d'une affectation pour des chargements et des stockages non alignés"
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "%<vec_lvsr%> est déprécié pour les petits boutistes; utilisation d'une affectation pour des chargements et des stockages non alignés"
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, gcc-internal-format
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr "passer l'argument %d de %qE abandonne le qualificatif %qs du type pointé"
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "combinaison invalide de paramètres pour l'intrinsèque Altivec %qs"
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, gcc-internal-format
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr "l'interne surchargé %qs est implémenté par l'interne %qs"
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%qs n'est pas supporté dans cette configuration du compilateur"
@@ -43834,29 +43860,22 @@ msgstr "utilisation invalide d'un opérande MMA de type %qs comme paramètre de
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "vecteur GCC passé par référence: extension ABI non standard sans aucune garantie de compatibilité"
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, gcc-internal-format
-msgid "%qs requires the ELFv2 ABI"
-msgstr "%qs exige l'ABI ELFv2"
-
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "trame de pile trop grande"
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported number of nops before function entry (%u)"
 msgstr "nombre de nops non supporté avant l'entrée de la fonction (%u)"
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%qs utilise le registre r29"
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "Une trame de pile plus grande que 2G n'est pas supportée par %<-fsplit-stack%>"
@@ -43982,107 +44001,118 @@ msgstr "%qs a besoin d'un registre de base valable"
 msgid "unknown option for %<%s=%s%>"
 msgstr "option inconnue pour %<%s=%s%>"
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4837
+#, fuzzy, gcc-internal-format
+#| msgid "%qs requires the ELFv2 ABI"
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr "%qs exige l'ABI ELFv2"
+
+#: config/rs6000/rs6000.cc:4855
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs est déprécié et recommandé dans aucune circonstance"
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr "%qs est un type opaque et vous ne pouvez pas le remplacer avec d'autres valeurs"
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "pas de profilage du code 64 bits pour cette ABI"
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "Vous ne pouvez pas prendre l'adresse d'une fonction imbriquée si vous utilisez l'option %qs"
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "l'utilisation de %<long double%> dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "l'utilisation des types booléens dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "l'utilisation de %<complex%> dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "l'utilisation de types décimaux en virgule flottante dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "l'utilisation de %<long%> dans les types AltiVec est invalide pour du code 64 bits sans %qs"
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "l'utilisation de %<long%> dans les types Altivec est obsolète; utilisez %<int%>"
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "l'utilisation de %<long long%> dans les types AltiVec est invalide sans %qs"
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "l'utilisation de %<double%> dans les types AltiVec est invalide sans %qs"
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "processeur %qs invalide pour %s\"%s\"%s"
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s n'est pas permis"
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s est invalide"
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> désactive %<-m%s%>"
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "l'attribut %<target_clones%> requiert GLIBC (2.23 ou plus récent) qui exporte des bits de capacité matérielle"
 
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Des versions multiples de fonctions virtuelles ne sont pas supportées"
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr "le résultat de l'instruction xxspltidp n'est pas défini pour des valeurs d'entrée sous-normales"
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "le type %<__vector_quad%> requiert l'option %qs"
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr "le type %<__vector_pair%> requiert l'option %qs"
@@ -44127,7 +44157,7 @@ msgstr "Les instructions du FPU RX ne supportent pas les NaN et les infinis"
 msgid "builtin %qs can only be used on vector types"
 msgstr "la fonction interne %qs peut uniquement être utilisée sur des types vectoriels."
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "valeur constante requise pour l'argument %2$d de la fonction interne %1$qF"
@@ -44197,225 +44227,225 @@ msgstr "la variante correspondant à %qs est obsolète"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "l'argument constant %d de la fonction interne %qF est hors limite pour le type cible"
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr "l'argument constant %d de la fonction interne %qF est invalide (%s)"
 
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr "l'argument constant %d de la fonction interne %qF est hors limite (0-%wu)"
 
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr "l'argument constant %d de la fonction interne %qF est hors limite (%wd-%wd)"
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr "la fonction interne %qF n'est pas supportée sans %<-mhtm%> (par défaut avec %<-march=zEC12%> et supérieur)"
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr "la fonction interne %qF requiert %<-mvx%> (par défaut avec %<-march=z13%> et supérieur)"
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher"
 msgstr "La fonction interne %qF requiert z14 ou supérieur"
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher"
 msgstr "La fonction interne %qF requiert z15 ou supérieur"
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "fonction interne surchargée non résolue"
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "icode de fonction interne erroné"
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "argument %d invalide pour la fonction interne %qF"
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "l'attribut %qE demandé n'est pas une paire de constantes entières non négatives séparées par une virgule ou est trop grand (max. %d)"
 
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "l'argument de l'attribut %qE n'est pas (keep|thunk|thunk-extern)"
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "la taille totale des variables locales excède la limite de l'architecture"
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr "la taille de la trame de la fonction %qs est de %wd octets ; elle dépasse la limite de %d octets de la pile fournie par l'utilisateur ; un déroutement inconditionnel est ajouté"
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr "la taille de la trame de la fonction %qs est de %wd octets ; c'est plus que la moitié de la taille de la pile ; le contrôle dynamique ne serait pas fiable. Aucun contrôle n'est généré pour cette fonction"
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "la taille de la trame de %qs est de %wd octets"
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs utilise l'allocation de pile dynamique"
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr "le passage de paramètre pour l'argument de type %qT avec des membres de champs de bits de largeur nulle a changé dans GCC 12"
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "les fonctions imbriquées ne savent pas être profilées avec %<-mfentry%> sur un s390"
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "l'ABI 64 bits n'est pas supportée en mode ESA/390"
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr "thunk-inline est uniquement supporté avec %<-mindirect-branch-jump%>"
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "le support des vecteurs matériels n'est pas disponible sur %s"
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "le support des vecteurs matériels n'est pas disponible avec %<-msoft-float%>"
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr "les instructions décimales en virgule flottante matérielles ne sont pas disponibles sur %s"
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, gcc-internal-format
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr "les instructions décimales en virgule flottante matérielles ne sont pas disponibles en mode ESA/390"
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr "%<-mhard-dfp%> ne peut être utilisé en conjonction avec %<-msoft-float%>"
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> ne sont pas supportés en combinaison"
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "la taille de la pile doit être plus grande que la valeur de la protection de la pile"
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "la taille de la pile ne peut pas être plus grande que 64k"
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "%<-mstack-guard%> implique l'utilisation de %<-mstack-size%>"
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr "%<-mtpf-trace-hook-prologue-check%> requiert un entier dans la plage 0-4095"
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr "%<-mtpf-trace-hook-prologue-target%> requiert un entier dans la plage 0-4095"
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr "%<-mtpf-trace-hook-epilogue-check%> requiert un entier dans la plage 0-4095"
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr "%<-mtpf-trace-hook-epilogue-target%> requiert un entier dans la plage 0-4095"
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%<-mfentry%> est supporté uniquement sur des processeurs 64 bits"
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "les arguments de %qs doivent être des entiers non négatifs"
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "l'argument de %qs est trop grand (max. %d)"
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr "%<-mno-pic-data-is-text-relative%> ne peut pas être utilisé sans %<-fpic%>/%<-fPIC%>"
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, gcc-internal-format
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr "l'argument %<target%> de l'attribut %qs est inconnu"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "la valeur %qs n'est pas supportée par l'attribut %<target%>"
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, gcc-internal-format
 msgid "invalid cc output constraint: %qs"
 msgstr "contrainte de sortie cc invalide : %qs"
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, gcc-internal-format
 msgid "multiple cc output constraints not supported"
 msgstr "contraintes de sortie cc multiples non supportées"
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, gcc-internal-format
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr "le spécificateur %<asm%> pour la sortie de cc est en conflit avec la liste d'écrasement de %<asm%>"
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, gcc-internal-format
 msgid "invalid type for cc output constraint"
 msgstr "type invalide pour la contrainte de sortie de cc"
@@ -44837,8 +44867,8 @@ msgstr "l'attribut %qE n'a pas d’effet"
 msgid "attribute %qs applies to array types only"
 msgstr "l'attribut %qs s'applique seulement aux types tableaux"
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "la valeur void n'a pas été ignorée comme elle aurait dû l'être"
@@ -44913,7 +44943,7 @@ msgstr "le type du tableau %q+D est complété de manière incompatible avec une
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr "la déclaration sous-spécifiée de %qE est déjà déclaré dans cette portée"
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "défini initialement ici"
@@ -45145,7 +45175,7 @@ msgstr "la déclaration de %q+D masque la déclaration précédente de quelque c
 msgid "declaration of %qD shadows a parameter"
 msgstr "la déclaration de %qD masque un paramètre"
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "la déclaration de %qD masque une déclaration globale"
@@ -45155,7 +45185,7 @@ msgstr "la déclaration de %qD masque une déclaration globale"
 msgid "declaration of %qD shadows a previous local"
 msgstr "la déclaration de %qD masque la déclaration locale précédente"
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "la déclaration masquée est ici"
@@ -45220,7 +45250,7 @@ msgstr "%qE non déclaré (première utilisation dans cette fonction)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "chaque identificateur non déclaré est rapporté une seule fois pour chaque fonction dans laquelle il apparaît"
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "l'étiquette %qE est référencée à l'extérieur de toute fonction"
@@ -45255,7 +45285,7 @@ msgstr "saut dans l'expression d'une instruction"
 msgid "duplicate label declaration %qE"
 msgstr "déclaration de l'étiquette %qE en double"
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "étiquette %qD dupliquée"
@@ -45290,7 +45320,7 @@ msgstr "le « switch » saute dans l'expression d'une instruction"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE est défini comme un mauvais type de balise"
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "attribut %qE appliqué à %qD avec un type de retour void"
@@ -45432,12 +45462,12 @@ msgstr "le C90 ISO ne supporte pas %<[*]%> dans les déclarateurs de tableau"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> n'est pas permis ailleurs que dans la portée du prototype d'une fonction"
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, gcc-internal-format
 msgid "%<omp::%s%> not allowed to be specified in this context"
 msgstr "%<omp::%s%> ne peut pas être spécifié dans ce contexte"
@@ -45447,7 +45477,7 @@ msgstr "%<omp::%s%> ne peut pas être spécifié dans ce contexte"
 msgid "%q+D is usually a function"
 msgstr "%q+D est habituellement une fonction"
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "aucune déclaration précédente pour %qD"
@@ -45523,7 +45553,7 @@ msgstr "impossible de mettre un objet avec un champ volatile dans un registre"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "%<const %qD%> non initialisé est invalide en C++"
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D dans la directive de déclaration de cible n'a pas de type pour lequel une correspondance peut être établie (mappable type)"
@@ -45708,7 +45738,7 @@ msgstr "classe de stockage spécifiée pour le paramètre %qE"
 msgid "storage class specified for unnamed parameter"
 msgstr "classe de stockage spécifiée pour le paramètre sans nom"
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "classe de stockage spécifiée pour un typename"
@@ -45771,7 +45801,7 @@ msgstr "déclaration de %qE comme un tableau de fonctions"
 msgid "declaration of type name as array of functions"
 msgstr "déclaration du nom de type comme un tableau de fonctions"
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "utilisation invalide d'une structure ayant un membre qui est un tableau flexible"
@@ -45877,7 +45907,7 @@ msgstr "nom de type déclaré comme une fonction retournant un tableau"
 msgid "function definition has qualified void return type"
 msgstr "la définition de la fonction a un type de retour « void » qualifié"
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "les qualificatifs de type sont ignorés sur le type retourné par la fonction"
@@ -46004,7 +46034,7 @@ msgstr "le C ISO interdit les fonctions de type volatile ou constante"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "un membre d'une structure ou d'une union ne peut pas avoir de type modifié par une variable"
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variable ou champ %qE déclaré « void »"
@@ -46109,7 +46139,7 @@ msgstr "fonction non imbriquée avec un type modifié par une variable"
 msgid "object with variably modified type must have no linkage"
 msgstr "un objet avec un type modifié par une variable ne peut pas avoir de classe de liaison"
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "la déclaration de fonction n'est pas un prototype"
@@ -46200,17 +46230,17 @@ msgstr "redéfinition imbriquée de %<union %E%>"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "redéfinition imbriquée de %<struct %E%>"
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "définir le type dans l'expression %qs est invalide en C++"
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, gcc-internal-format
 msgid "%qT defined in underspecified object initializer"
 msgstr "%qT est défini dans l'initialiseur de l'objet sous-spécifié"
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "la déclaration ne déclare rien du tout"
@@ -46240,596 +46270,596 @@ msgstr "une structure vide a une taille 0 en C et une taille 1 en C++"
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr "une union vide a une taille 0 en C et une taille 1 en C++"
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "l'union n'a aucun membre nommé"
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "l'union n'a aucun membre"
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "la structure n'a aucun membre nommé"
 
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "la structure n'a aucun membre"
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "tableau flexible comme membre de l'union"
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "le tableau flexible n'est pas le dernier membre à la fin de la structure"
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "tableau flexible comme membre d'une structure sans aucun membre nommé"
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, gcc-internal-format
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr "la structure contenant un membre tableau flexible n'est pas le dernier membre à la fin d'une autre structure"
 
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "le type %qT est trop grand"
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, gcc-internal-format
 msgid "type punning toggles scalar storage order"
 msgstr "le transtypage à la barbare inverse l'ordre de stockage scalaire"
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "une union ne peut pas être rendue transparente"
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, gcc-internal-format
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr "redéfinition d'une struct ou union %qT avec un type modifié par une variable"
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, gcc-internal-format
 msgid "redefinition of struct or union %qT"
 msgstr "redéfinition d'une struct ou union %qT"
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "redéfinition imbriquée de %<enum %E%>"
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "redéclaration de %<enum %E%>"
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr "%<enum%> déclaré avec mais défini sans type sous-jacent fixe"
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "le mode spécifié est trop petit pour les valeurs énumérées"
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "les valeurs de l'énumération excèdent les limites du plus grand entier"
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, gcc-internal-format
 msgid "enumeration values exceed range of %qs"
 msgstr "les valeurs de l'énumération excèdent la plage de %qs"
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, gcc-internal-format
 msgid "conflicting redefinition of enum %qT"
 msgstr "redéfinition de enum %qT conflictuelle"
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "la valeur de l'énumérateur pour %qE n'est pas une constante entière"
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "la valeur de l'énumérateur pour %qE n'est pas une expression constante entière"
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "débordement dans les valeurs de l'énumération"
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, gcc-internal-format
 msgid "enumerator value outside the range of underlying type"
 msgstr "la valeur de l'énumération est en dehors de la plage du type sous-jacent"
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, gcc-internal-format
 msgid "enumerator value outside the range of %qs"
 msgstr "la valeur de l'énumération est en dehors de la plage de %qs"
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr "le C ISO restreint les valeurs de l'énumérateur à la plage d'un %<int%> avant C23"
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "la fonction à mettre en ligne %qD a reçu l'attribut %qs"
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "le type du retour est un type incomplet"
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "le type du retour devient %<int%> par défaut"
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "%q+D est définie comme fonction variadique sans prototype"
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "aucun prototype précédent pour %qD"
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD a été utilisé sans prototype avant sa définition"
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD a été utilisé sans déclaration avant sa définition"
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "le type de retour de %qD n'est pas %<int%>"
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "type de retour qualifié avec %<_Atomic%> pour %qD"
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD est normalement une fonction non statique"
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "déclaration de paramètres selon l'ancien style dans la définition de fonction prototypée"
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "le C traditionnel rejette les définitions de fonctions de style C ISO"
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr "le C ISO ne supporte pas l'omission des noms des paramètres dans les définitions de fonctions avant C23"
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "définition de fonction selon l'ancien style"
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "nom du paramètre manquant dans la liste des paramètres"
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD déclaré comme un non paramètre"
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "plusieurs paramètres nommés %qD"
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "paramètre %qD déclaré avec le type « void »"
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "le type de %qD devient %<int%> par défaut"
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "le paramètre %qD a un type incomplet"
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "déclaration du paramètre %qD mais pas de tel paramètre"
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "le nombre d'arguments ne concorde pas avec celui du prototype interne"
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "le nombre d'arguments ne concorde pas avec celui du prototype"
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "déclaration de prototype"
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "l'argument promu %qD ne concorde pas avec le prototype interne"
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "l'argument promu %qD ne concorde pas avec le prototype"
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "l'argument %qD ne concorde pas avec le prototype interne"
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "l'argument %qD ne concorde pas avec le prototype"
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "« return » manquant dans une fonction devant retourner une valeur"
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "le paramètre %qD est défini mais pas utilisé"
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "les déclarations initiales de boucles %<for%> ne sont permises qu'en mode C99 et C11"
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "utilisez l'option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> ou %<-std=gnu11%> pour compiler votre code"
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "le C90 ISO ne supporte pas les déclarations initiales de la boucle %<for%>"
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "déclaration de la variable statique %qD dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "déclaration de la variable %<extern%> %qD dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> déclarée dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> déclarée dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> déclarée dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "déclaration de %qD (qui n'est pas une variable) dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "les qualificatifs d'espace d'adresses %qs et %qs sont incompatibles"
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "spécificateur de déclaration %qE dupliqué"
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "classes de stockage multiples dans les spécificateurs de la déclaration"
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, gcc-internal-format
 msgid "%qs used with %<auto%>"
 msgstr "%qs utilisé avec %<auto%>"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, gcc-internal-format
 msgid "%<auto%> used with %<constexpr%>"
 msgstr "%<auto%> utilisé avec %<constexpr%>"
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "deux types de données ou plus dans le spécificateur de déclaration"
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> est trop long pour GCC"
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "le C90 ISO ne supporte pas %<long long%>"
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "le C90 ISO ne supporte pas les types « complex »"
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "le C ISO ne supporte pas les types saturants"
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE dupliqué"
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "le C ISO ne supporte pas les types %<__int%d%>"
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> n'est pas supporté sur cette cible"
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "le C90 ISO ne supporte pas les types booléens"
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr "le C ISO ne supporte pas le type %<_Float%d%s%> avant C23"
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<_Float%d%s%> n'est pas supporté sur cette cible"
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr "le C ISO ne supporte pas les virgules flottantes décimales avant C23"
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "les types en virgule fixe ne sont pas supportés pour cette cible"
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "le C ISO ne supporte pas les types en virgule fixe"
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, gcc-internal-format
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr "l'argument %<_BitInt%> n'est pas une expression constante entière"
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr "l'argument %<_BitInt%> %qE n'est pas une expression constante entière positive"
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr "l'argument %<_BitInt%> %qE est plus grand que %<BITINT_MAXWIDTH%> %qd"
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "la recherche de %qD par le C++ retournerait un champ, pas un type"
 
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE échoue a être un typedef ou un type interne"
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE n'est pas au début de la déclaration"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE utilisé avec %<auto%>"
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE utilisé avec %<register%>"
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE utilisé avec %<typedef%>"
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, gcc-internal-format
 msgid "%qE used with %<constexpr%>"
 msgstr "%qE utilisé avec %<constexpr%>"
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "le C99 ISO ne supporte pas %qE"
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "le C90 ISO ne supporte pas %qE"
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> avant %<extern%>"
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> avant %<static%>"
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, gcc-internal-format
 msgid "%<typedef%> used with %<auto%>"
 msgstr "%<typedef%> utilisé avec %<auto%>"
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, gcc-internal-format
 msgid "%qE used with %<extern%>"
 msgstr "%qE utilisé avec %<extern%>"
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, gcc-internal-format
 msgid "%qE used with %qs"
 msgstr "%qE utilisé avec %qs"
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "%<_Thread_local%> ou %<__thread%> dupliqué"
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs utilisé avec %qE"
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, gcc-internal-format
 msgid "%<constexpr%> used with %qE"
 msgstr "%<constexpr%> utilisé avec %qE"
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> est utilisé sans %<_Fract%> ou %<_Accum%>"
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "le C ISO ne supporte pas un simple %<complex%> signifiant %<double complex%>"
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, gcc-internal-format
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr "le C ISO ne supporte pas la déduction de type avec %<auto%> avant C23"
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr "%<__auto_type%> suivi des attributs %<[[]]%>"
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "le C ISO interdit les types entiers complexes"
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, gcc-internal-format
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr "l'argument de %<signed _BitInt%> doit être au moins 2"
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, gcc-internal-format
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr "le C ISO ne supporte pas %<%s_BitInt(%d)%> avant C23"
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "le combinateur %<#pragma omp declare reduction%> fait référence à la variable %qD qui n'est ni %<omp_out%> ni %<omp_in%>"
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "l'initialiseur %<#pragma omp declare reduction%> fait référence à la variable %qD qui n'est ni %<omp_priv%> ni %<omp_orig%>"
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "décalage vers la gauche d'une valeur négative"
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "le compteur de décalages vers la gauche est négatif"
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "le compteur de décalages vers la droite est négatif"
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "compteur de décalages vers la gauche >= à la largeur du type"
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "compteur de décalages vers la droite >= à la largeur du type"
@@ -46859,7 +46889,7 @@ msgstr "marqueur de conflit de contrôle de version dans le fichier"
 msgid "to match this %qs"
 msgstr "pour correspondre à ce %qs"
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "fin de ligne attendue"
@@ -46869,8 +46899,8 @@ msgstr "fin de ligne attendue"
 msgid "ISO C forbids an empty translation unit"
 msgstr "le C ISO interdit une unité de traduction vide"
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr "%qs sans %qs correspondant"
@@ -46910,9 +46940,9 @@ msgstr "nom de type %qE inconnu; vouliez-vous utiliser %qs ?"
 msgid "unknown type name %qE"
 msgstr "nom de type %qE inconnu"
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "spécificateurs de déclaration attendus"
@@ -46942,7 +46972,7 @@ msgstr "attribut %<fallthrough%> au plus haut niveau"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, identificateur ou %<(%> attendu"
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "les attributs de préfixes sont ignorés pour les méthodes"
@@ -46962,7 +46992,7 @@ msgstr "attribut inattendu"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "l'attribut %<fallthrough%> n'est pas suivi par %<;%>"
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, gcc-internal-format
 msgid "%<assume%> attribute not followed by %<;%>"
 msgstr "l'attribut %<assume%> n'est pas suivi par %<;%>"
@@ -47053,7 +47083,7 @@ msgstr "l'expression dans l'assertion statique n'est pas une constante"
 msgid "static assertion failed: %E"
 msgstr "échec de l'assertion statique: %E"
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "l'assertion statique a échoué"
@@ -47124,10 +47154,10 @@ msgstr "un enum vide est invalide"
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "identificateur attendu"
@@ -47278,7 +47308,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr "les boucles internes doivent être parfaitement imbriquées avec la clause %<reduction%> %<inscan%>"
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr "mélange de directives OpenMP avec des attributs et la syntaxe pragma sur la même instruction"
@@ -47288,8 +47318,8 @@ msgstr "mélange de directives OpenMP avec des attributs et la syntaxe pragma su
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr "attribut OpenMP %<omp::decl%> sur une instruction"
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs attribute argument"
 msgstr "nom de directive OpenMP inconnue dans l'argument de l'attribut %qs"
@@ -47463,12 +47493,12 @@ msgstr "le C ISO interdit l'omission du terme central de l'expression %<?:%>"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr "la division %<sizeof (%T) / sizeof (%T)%> ne calcule pas le nombre d'éléments dans le tableau"
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "le premier opérande %<sizeof%> a été déclaré ici"
@@ -47615,7 +47645,7 @@ msgstr "le C90 ISO ne supporte pas l'identificateur prédéfini %<__func__%>"
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, gcc-internal-format
 msgid "expected expression"
 msgstr "expression attendue"
@@ -47935,12 +47965,12 @@ msgstr "une déclaration de méthode objective-c est attendue"
 msgid "no type or storage class may be specified here,"
 msgstr "aucun type ni classe de stockage ne peut être spécifié ici,"
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr "liste d'attributs de propriété vide"
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, gcc-internal-format
 msgid "missing property attribute"
 msgstr "attribut de propriété manquant"
@@ -47950,57 +47980,57 @@ msgstr "attribut de propriété manquant"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "attribut de propriété %<%s%s%> inconnu"
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "attribut de propriété inconnu"
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "%<=%> attendu après Objective-C %qE"
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr "nom de sélecteur %qE attendu"
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr "les noms des méthodes « setter » doivent être terminés par %<:%>"
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> requiert une expression d'affectation qui est évaluée en une constante entière non négative plus petite que %u"
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr "du code intervenant ne peut pas contenir des directives OpenMP"
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> ne peut être utilisé que dans des instructions composées"
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> doit être dans la portée au niveau du fichier"
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp scan%> ne peut être utilisé que dans une construction de boucle avec la clause %<inscan%> %<reduction%>"
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> ne peut être utilisé que dans une construction %<#pragma omp sections%>"
@@ -48010,25 +48040,25 @@ msgstr "%<#pragma omp section%> ne peut être utilisé que dans une construction
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr "%<#pragma %s%> peut uniquement être utilisé dans la portée du fichier"
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "instruction « for », « while » ou « do » attendue"
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> doit être le premier"
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "trop de clauses %qs"
@@ -48043,63 +48073,63 @@ msgstr "l'expression doit être fondamentale"
 msgid "expected %<)%> or %<,%>"
 msgstr "%<)%> ou %<,%> attendu"
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD n'est pas une variable"
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD n'est pas une variable pointeur"
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "l'argument « collapse » a besoin d'une expression entière constante positive"
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> ou %<present%> attendu"
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, gcc-internal-format
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr "%<none%>, %<shared%>, %<private%> ou %<firstprivate%> attendu"
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, gcc-internal-format
 msgid "expected constant logical expression"
 msgstr "expression logique constante attendue"
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<data%>, %<update%>, %<enter%> ou %<exit%> attendu"
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<data%> attendu"
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "trop de %<if%> avec le modificateur %qs"
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "trop de clauses %<if%>"
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "trop de clauses %<if%> sans modificateur"
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "si une clause %<if%> a un modificateur, alors toutes les clauses %<if%> doivent utiliser un modificateur"
@@ -48122,22 +48152,22 @@ msgstr "la valeur de %<num_threads%> doit être positive"
 msgid "%<num_tasks%> value must be positive"
 msgstr "la valeur de %<num_tasks%> doit être positive"
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "la valeur de %<grainsize%> doit être positive"
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "la valeur de %<priority%> doit être positive ou nulle"
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "expression entière constante attendue avec une valeur sync-hint valide"
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "%<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> ou %<default%> attendu"
@@ -48147,94 +48177,94 @@ msgstr "%<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> ou %
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr "%<scalar%>, %<aggregate%>, %<pointer%> ou %<all%> attendu"
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "trop de clauses %<defaultmap%> avec la catégorie %qs"
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "trop de clauses %<defaultmap%> avec une catégorie non spécifiée"
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "l'expression %qs doit être un entier"
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "la valeur de %qs doit être positive"
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "trop d'arguments pour %<static%>"
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "argument inattendu"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "l'argument %<tile%> a besoin d'une constante entière positive"
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, gcc-internal-format
 msgid "too many %<self%> clauses"
 msgstr "trop de clauses %<self%>"
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, gcc-internal-format
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr "%<reproducible%> ou %<unconstrained%%> attendu"
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "%<concurrent%> attendu"
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "%<team%>, %<parallel%> ou %<thread%> attendu"
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "les arguments ordonnés ont besoin d'une expression entière constante positive"
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> ou identificateur attendu"
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "les deux modificateurs %<monotonic%> et %<nonmonotonic%> sont spécifiés"
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "schedule %<runtime%> ne prend pas de paramètre %<chunk_size%>"
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "schedule %<auto%> ne prend pas de paramètre %<chunk_size%>"
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "la taille du fragment doit être positive"
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "type d'ordonnancement invalide"
@@ -48244,22 +48274,22 @@ msgstr "type d'ordonnancement invalide"
 msgid "%<num_teams%> value must be positive"
 msgstr "la valeur de %<num_teams%> doit être positive"
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr "la borne inférieure %<num_teams%> %qE est plus grande que la borne supérieure %qE"
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "la valeur de %<thread_limit%> doit être positive"
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "l'expression d'alignement %<aligned%> doit être une expression entière constante positive"
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, gcc-internal-format
 msgid "expected %<allocator%> or %<align%>"
 msgstr "%<allocator%> ou %<align%> attendu"
@@ -48269,22 +48299,22 @@ msgstr "%<allocator%> ou %<align%> attendu"
 msgid "duplicate %qs modifier"
 msgstr "modificateur %qs dupliqué"
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr "l'expression d'allocation de la clause %<allocate%> a le type %qT plutôt que %<omp_allocator_handle_t%>"
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, gcc-internal-format
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr "dans la clause %<allocate%>, l'argument du modificateur %<align%> doit être une expression entière constante positive qui est une puissance de deux"
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, gcc-internal-format
 msgid "multiple linear modifiers"
 msgstr "modificateurs linéaires multiples"
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, gcc-internal-format
 msgid "multiple %<step%> modifiers"
 msgstr "modificateurs %<step%> multiples"
@@ -48304,62 +48334,62 @@ msgstr "l'expression %<safelen%> doit être une expression entière constante po
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "l'expression %<simdlen%> doit être une expression entière constante positive"
 
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "le modificateur %<iterator%> est incompatible avec %qs"
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "type de « depend » invalide"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, gcc-internal-format
 msgid "invalid doacross kind"
 msgstr "type de « doacross » invalide"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, gcc-internal-format
 msgid "too many %<always%> modifiers"
 msgstr "trop de modificateurs %<always%>"
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, gcc-internal-format
 msgid "too many %<close%> modifiers"
 msgstr "trop de modificateurs %<close%>"
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, gcc-internal-format
 msgid "too many %<present%> modifiers"
 msgstr "trop de modificateurs %<present%>"
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr "clause %<map%> avec un modificateur de type map autre que %<always%>, %<close%> ou %<present%>"
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "type de « map » invalide"
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr "le modificateur de périphérique %<ancestor%> pas précédé de la directive %<requires%> avec la clause %<reverse_offload%>"
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, gcc-internal-format
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr "%<ancestor%> ou %<device_num%> attendu"
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, gcc-internal-format
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr "l'expression de la clause %<device%> doit être évaluée à %<1%>"
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "type de « dist_schedule » invalide"
@@ -48374,88 +48404,88 @@ msgstr "type de « proc_bind » invalide"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<host%>, %<nohost%> ou %<any%> attendu"
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr "le gestionnaire d'événement de la clause %<detach%> a le type %qT plutôt que %<omp_event_handle_t%>"
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, gcc-internal-format
 msgid "expected an OpenACC clause"
 msgstr "clause OpenACC attendue"
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs n'est pas valide pour %qs"
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr "les clauses dans un trait %<simd%> devraient être séparées par des %<,%>"
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs doit être la première clause de %qs"
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, gcc-internal-format
 msgid "expected an OpenMP clause"
 msgstr "clause OpenMP attendue"
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "pas de clause valide spécifiée dans %<#pragma acc declare%>"
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "section de tableau dans %<#pragma acc declare%>"
 
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD doit être une variable globale dans %<#pragma acc declare link%>"
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "clause OpenACC invalide au niveau global du fichier"
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "utilisation invalide de la variable %<extern%> %qD dans %<#pragma acc declare%>"
 
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "utilisation invalide de la variable %<global%> %qD dans %<#pragma acc declare%>"
 
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "%qD doit être une variable déclarée dans la même portée que %<#pragma acc declare%>"
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "variable %qD utilisée plus d'une fois avec %<#pragma acc declare%>"
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<data%> attendu après %<#pragma acc %s%>"
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> n'a pas clause de mouvement de données"
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr "la construction %<host_data%> requiert la clause %<use_device%>"
@@ -48470,7 +48500,7 @@ msgstr "%qE n'a pas été déclaré"
 msgid "expected function name"
 msgstr "nom de fonction attendu"
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD ne fait pas référence à une fonction"
@@ -48480,22 +48510,22 @@ msgstr "%qD ne fait pas référence à une fonction"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> n'est pas immédiatement suivi d'une déclaration ou d'une définition de fonction"
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> n'est pas immédiatement suivi d'une seule déclaration ou définition de fonction"
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> doit être appliqué avant l'utilisation"
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> doit être appliqué avant la définition"
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> doit contenir au moins une clause %<device%> ou %<host%> ou %<self%>"
@@ -48520,7 +48550,7 @@ msgstr "la variable %qD utilisée dans la clause %<allocator%> ne peut pas être
 msgid "modified here"
 msgstr "modifié ici"
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, gcc-internal-format
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
 msgstr "l'argument de la clause %<align%> doit être une expression de constante entière positive qui est une puissance de deux"
@@ -48560,110 +48590,110 @@ msgstr "la clause %<allocator%> requiert un allocateur prédéfini car %qD est s
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr "%<#pragma omp allocate%> pour des variables statiques comme %qD n'est pas encore supporté"
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "clause %<read%>, %<write%>,  %<update%> ou %<capture%> attendue"
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr "%<seq_cst%>, %<acquire%> ou %<relaxed%> attendu"
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "clause %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> ou %<hint%> attendue"
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "trop de clauses atomiques"
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "trop de clauses d'ordre de mémoire"
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, gcc-internal-format
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr "la clause %qs est incompatible avec les clauses %<read%> ou %<write%>"
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, gcc-internal-format
 msgid "%qs clause requires %qs clause"
 msgstr "la clause %qs requiert la clause %qs"
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr "%<#pragma omp atomic write%> est incompatible avec la clause %<acquire%> fournie implicitement par une directive %<requires%>"
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr "%<#pragma omp atomic read%> est incompatible avec la clause %<release%> fournie implicitement par une directive %<requires%>"
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr "%<#pragma omp atomic read%> est incompatible avec la clause %<release%>"
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr "%<#pragma omp atomic write%> est incompatible avec la clause %<acquire%>"
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, gcc-internal-format
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr "la comparaison %<==%> est attendue dans la condition %<if%>"
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, gcc-internal-format
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr "la comparaison %<==%>, %<<%> ou %<>%> est attendue dans la condition %<if%>"
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr "forme invalide de %<#pragma omp atomic compare%>"
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, gcc-internal-format
 msgid "unexpected %<else%>"
 msgstr "%<else%> attendu"
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, gcc-internal-format
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr "forme invalide de %<pragma omp atomic compare%>"
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "forme invalide de %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "opération invalide pour %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr "la clause %<weak%> requiert une comparaison d'égalité atomique"
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> utilise deux expressions différentes pour la mémoire"
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "l'expression %<depobj%> n'est pas une expression l-valeur"
@@ -48673,27 +48703,27 @@ msgstr "l'expression %<depobj%> n'est pas une expression l-valeur"
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr "l'expression %<destroy%> n'est pas une expression l-valeur"
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr "l'expression %<destroy%> %qE devrait être la même que l'argument %<depobj%> %qE"
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr "%<in%>, %<out%>, %<inout%>, %<mutexinoutset%> ou %<inoutset%> attendu"
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "clause %<depend%>, %<destroy%> ou %<update%> attendue"
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "%<seq_cst%>, %<acq_rel%>, %<release%> ou %<acquire%> attendu"
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr "liste %<flush%> spécifiée avec une clause d'ordre de mémoire"
@@ -48703,163 +48733,163 @@ msgstr "liste %<flush%> spécifiée avec une clause d'ordre de mémoire"
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> ou fin de ligne attendue"
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr "%<[[omp::directive(%s)]]%> doit être le seul attribut spécifié dans une instruction"
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr "%<#pragma omp scan%> avec zéro instruction exécutable précédente"
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "%<inclusive%> ou %<exclusive%> attendu"
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<#pragma omp scan%> attendu"
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr "%<#pragma omp scan%> avec zéro instruction exécutable suivante"
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "déclaration ou initialisation d'itération attendue"
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, gcc-internal-format
 msgid "not enough nested loops"
 msgstr "pas assez de boucles imbriquées"
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "le paramètre de la clause %<ordered%> est plus petit que %<collapse%>"
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "instruction « for » attendue"
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "la variable d'itération %qD ne devrait pas être « firstprivate »"
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> avec la clause %qs ne peut être utilisé qu'avec des instructions composées"
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> attendu après %qs"
 
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> attendu"
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> avec un type avec correspondance autre que %<to%>, %<from%>, %<tofrom%> ou %<alloc%> sur un clause %<map%>"
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp target data%> doit contenir au moins une clause %<map%>, %<use_device_ptr%> ou %<use_device_addr%>"
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> doit contenir au moins une clause %<from%> ou %<to%>"
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> avec un type avec correspondance autre que %<to%>, %<tofrom%> ou %<alloc%> sur une clause %<map%>"
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> doit contenir au moins une clause %<map%>"
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> avec un type « map » autre que %<from%>, %<tofrom%>, %<release%> ou %<delete%> sur une clause %<map%>"
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> doit contenir au moins une clause %<map%>"
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> avec un type avec correspondance autre que %<to%>, %<from%>, %<tofrom%> ou %<alloc%> sur une clause %<map%>"
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp declare %s%> doit être suivi d'une déclaration ou une définition de fonction ou un autre %<#pragma omp declare %s%>"
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> doit être suivi d'une déclaration ou une définition de fonction"
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "nom de sélecteur de trait attendu"
 
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, gcc-internal-format
 msgid "unknown selector %qs for context selector set %qs"
 msgstr "sélecteur %qs inconnu pour l'ensemble %qs du sélecteur de contexte"
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "le sélecteur %qs n'accepte aucune propriété"
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, gcc-internal-format
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr "%<score%> ne peut pas être spécifié dans les traits dans le trait-selector-set %qs"
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, gcc-internal-format
 msgid "%<score%> argument must be constant integer expression"
 msgstr "l'argument %<score%> doit être une expression entière constante"
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, gcc-internal-format
 msgid "%<score%> argument must be non-negative"
 msgstr "l'argument %<score%> doit être non négatif"
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "identificateur ou chaîne littérale attendus"
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "la propriété doit être une expression entière constante"
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "les propriétés pour le sélecteur %<simd%> ne peuvent pas être spécifiées dans %<metadirective%>"
@@ -48867,290 +48897,290 @@ msgstr "les propriétés pour le sélecteur %<simd%> ne peuvent pas être spéci
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, gcc-internal-format
 msgid "%<requires%> selector is not supported yet"
 msgstr "le sélecteur %<requires%> n'est pas encore supportée"
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, gcc-internal-format
 msgid "expected context selector set name"
 msgstr "nom de l'ensemble du sélecteur de contexte attendu"
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "%<match%> attendu"
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, gcc-internal-format
 msgid "variant %qD is not a function"
 msgstr "le variant %qD n'est pas une fonction"
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "le variant %qD et la base %qD ont des types incompatibles"
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr "le variant %qD est interne"
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare %s%> pas immédiatement suivi d'une déclaration ou une définition de fonction"
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare %s%> pas immédiatement suivi par une seule déclaration ou définition de fonction"
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr "%qD est spécifié à la fois dans les clauses declare target %<link%> et %qs"
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr "%qD est spécifié à la fois dans les clauses declare target %<link%> et %<to%> ou des clauses %<enter%>"
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr "la directive avec uniquement des clauses %<device_type%> ou %<indirect%>"
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, gcc-internal-format
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr "la clause %<device_type%> doit spécifier « any » lorsqu'elle est utilisée avec une clause %<indirect%>"
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> attendu"
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, gcc-internal-format
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr "%<declare target%> ou %<assumes%> attendu"
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr "%<#pragma omp end declare target%> sans %<#pragma omp declare target%> correspondant ou %<#pragma omp begin declare target%>"
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr "%qs dans la syntaxe d'attribut est terminé par %qs dans la syntaxe pragma"
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, gcc-internal-format
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr "%qs dans la syntaxe pragma est terminé par %qs dans la syntaxe d'attribut"
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, gcc-internal-format
 msgid "expected %<declare%> or %<assumes%>"
 msgstr "%<declare%> ou %<assumes%> attendu"
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr "%<#pragma omp declare reduction%> pas au niveau d'un fichier ou d'un bloc"
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr "type arithmétique prédéclaré dans %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr "fonction ou type tableau dans %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, gcc-internal-format
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr "type qualifié par %<_Atomic%> dans %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr "type qualifié par const, volatile ou restrict dans %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr "redéclaration de %qs %<#pragma omp declare reduction%> pour le type %qT"
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "%<#pragma omp declare reduction%> précédent"
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr "%<omp_priv%> ou nom de fonction attendu"
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "nom de fonction %<(%> attendu"
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "un des arguments de l'appel de l'initialisation devrait être %<&omp_priv%>"
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%<simd%>, %<reduction%>, %<target%> ou %<variant%> attendu"
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr "%<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> ou %<seq_cst%> attendu"
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr "clause %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> ou %<atomic_default_mem_order%> attendue"
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr "clause %qs utilisée lexicalement après la construction de la première cible ou l'API de déchargement"
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr "plus d'une clause %<atomic_default_mem_order%> dans une même unité de compilation"
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr "clause %<atomic_default_mem_order%> utilisée lexicalement après la première construction %<atomic%> sans clause d'ordre de mémoire"
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr "%<pragma omp requires%> requiert au moins une clause"
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, gcc-internal-format
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr "type %qT de taille nulle dans la clause %<reduction%>"
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, gcc-internal-format
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "type %qT de taille variable dans la clause %<reduction%>"
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, gcc-internal-format
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr "clause %<at%>, %<severity%> ou %<message%> attendue"
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, gcc-internal-format
 msgid "expected %qs or %qs"
 msgstr "%qs ou %qs attendu"
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, gcc-internal-format
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr "%<#pragma omp error%> avec une clause %<at(execution)%> peut uniquement être utilisé dans des instructions composées"
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr "%<pragma omp error%> rencontrée : %s"
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr "%<pragma omp error%> rencontrée"
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, gcc-internal-format
 msgid "expected at least one assumption clause"
 msgstr "au moins une clause de présomption est attendue"
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, gcc-internal-format
 msgid "expected directive name"
 msgstr "nom de directive attendu"
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr "nom de directive OpenMP inconnue dans l'argument de la clause %qs"
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr "directive %<%s%s%s%s%s%> mentionnée simultanément dans les clauses %<absent%> et %<contains%>"
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr "directive %<%s%s%s%s%s%> mentionnée plusieurs fois dans les clauses %qs"
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, gcc-internal-format
 msgid "unknown assumption clause %qs"
 msgstr "clause de présomption %qs inconnue"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, gcc-internal-format
 msgid "expected assumption clause"
 msgstr "clause de présomption attendue"
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE est déclaré %<threadprivate%> après la première utilisation"
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "la variable automatique %qE ne peut être %<threadprivate%>"
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE a un type incomplet"
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> sans avoir activé le support pour la mémoire transactionnelle"
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> à l'intérieur de %<__transaction_relaxed%>"
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "le %<__transaction_cancel%> extérieur n'est pas dans un %<__transaction_atomic%> extérieur ou une fonction %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> pas à l'intérieur de %<__transaction_atomic%>"
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, gcc-internal-format
 msgid "no closing brace"
 msgstr "pas d'accolade fermante"
@@ -49291,7 +49321,7 @@ msgstr "déréférencement d'un pointeur %<void *%>"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "la valeur de l'indice n'est ni un tableau ni un pointeur ni un vecteur"
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "l'indice du tableau n'est pas un entier"
@@ -49321,7 +49351,7 @@ msgstr "%qD sous-spécifié référencé dans son initialiseur"
 msgid "enum constant defined here"
 msgstr "constante enum définie ici"
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> sur le tableau %qE en paramètre de fonction retournera la taille de %qT"
@@ -49434,17 +49464,17 @@ msgstr "conversion implicite de %qT en %qT lors du passage de l'argument à la f
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "trop peu d'arguments pour la fonction interne %qE %u attendus"
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "une comparaison avec une chaîne littérale produit un résultat non spécifié"
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "comparaison entre un pointeur et la constante caractère zéro"
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "vouliez-vous déréférencer le pointeur ?"
@@ -49469,7 +49499,7 @@ msgstr "pointeur vers une fonction utilisé dans une soustraction"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "arithmétique sur un pointeur vers un type incomplet"
 
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "arithmétique sur un pointeur vers un agrégat vide"
@@ -49762,7 +49792,7 @@ msgstr "transtypage d'un pointeur vers un entier de taille différente"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "transtypage d'un appel de fonction de type %qT vers le type %qT ne correspondant pas"
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "transtypage vers un pointeur depuis un entier de taille différente"
@@ -49934,7 +49964,7 @@ msgstr "le membre de gauche de l'affectation pourrait être un candidat pour un
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "le membre de gauche de l'initialisation pourrait être un candidat pour un attribut de format"
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "le type de retour pourrait être un candidat pour un attribut de format"
@@ -50134,12 +50164,12 @@ msgstr "l'initialiseur de %<constexpr%> pour un type réel est de type complexe"
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr "l'initialiseur de %<constexpr%> pour un type en virgule flottante binaire est de type décimal"
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "initialisation d'un membre de tableau flexible"
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "impossible d'initialiser un tableau de %qT depuis une chaîne de caractères littérale avec un tableau de type %qT"
@@ -50149,7 +50179,7 @@ msgstr "impossible d'initialiser un tableau de %qT depuis une chaîne de caract
 msgid "array of inappropriate type initialized from string constant"
 msgstr "tableau d'un type inapproprié initialisé avec une chaîne constante"
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "utilisation invalide d'un tableau n'étant pas une l-valeur"
@@ -50180,7 +50210,7 @@ msgstr "un élément de l'initialisation n'est pas une expression constante"
 msgid "initializer element is not computable at load time"
 msgstr "un élément de l'initialisation n'est pas évaluable lors du chargement"
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "type de vecteur opaque ne peut être initialisé"
@@ -50195,7 +50225,7 @@ msgstr "groupe d'accolades superflu à la fin de l'initialisation"
 msgid "braces around scalar initializer"
 msgstr "accolades autour d'une initialisation d'un scalaire"
 
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "initialisation d'un membre de tableau flexible dans un contexte imbriqué"
@@ -50285,7 +50315,7 @@ msgstr "trop d'éléments dans l'initialisation de la structure"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "initialisation par position de champs dans une %<struct%> qui est déclarée avec l'attribut %<designated_init%>"
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "initialisation non statique d'un membre de tableau flexible"
@@ -50325,7 +50355,7 @@ msgstr "le C ISO interdit %<goto *expr;%>"
 msgid "computed goto must be pointer type"
 msgstr "le goto calculé doit être un type pointeur"
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "la fonction est déclarée avec %<noreturn%> mais elle utilise l'instruction %<return%>"
@@ -50380,7 +50410,7 @@ msgstr "étiquette %<default%> en dehors de tout « switch »"
 msgid "break statement not within loop or switch"
 msgstr "mot-clé « break » à l'extérieur de toute boucle ou « switch »"
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -50426,27 +50456,27 @@ msgstr "la comparaison sera toujours %<false%> car l'adresse de %qE ne sera jama
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr "la comparaison sera toujours %<true%> car l'adresse de %qE ne sera jamais NULL"
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "comparaison de vecteurs avec des types d'éléments différents"
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "comparaison de vecteurs avec des nombres d'éléments différents"
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "comparaison entre les types %qT et %qT"
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "n'a pu trouver un type entier de la même taille que %qT"
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "comparer des nombres flottants à l'aide de %<==%> ou %<!=%> n'est pas sûr"
@@ -50518,29 +50548,29 @@ msgstr "valeur de type « union » utilisée là où un scalaire est requis"
 msgid "used vector type where scalar is required"
 msgstr "valeur de type « vector » utilisée là où un scalaire est requis"
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> doit spécifier l'une des clauses %<parallel%>, %<for%>, %<sections%> ou %<taskgroup%>"
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "modificateur de clause %<cancel%> %<if%> attendus"
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> doit spécifier l'une des clauses %<parallel%>, %<for%>, %<sections%> ou %<taskgroup%>"
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD n'est pas une variable dans la clause %qs"
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE n'est pas une variable dans la clause %qs"
@@ -50551,86 +50581,86 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%> %qD dans la clause %qs"
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD est une variable « threadprivate » dans la clause %qs"
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "la borne inférieure %qE de la section du tableau n'a pas un type entier"
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "la longueur %qE de la section du tableau n'a pas un type entier"
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "pointeur unique attendu dans la clause %qs"
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "section de tableau ayant une longueur nulle dans la clause %qs"
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "l'expression de longueur doit être spécifiée pour un type tableau dont la limite est inconnue"
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "limite inférieure négative dans la section du tableau dans la clause %qs"
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "longueur négative dans la section du tableau dans la clause %qs"
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "limite inférieure %qE au delà de la taille de la section du tableau dans la clause %qs"
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "longueur %qE au delà de la taille de la section du tableau dans la clause %qs"
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "limite supérieure %qE au delà de la taille de la section du tableau dans la clause %qs"
 
 # Ce message ne veut absolument rien dire !
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr "pour une fonction tableau, l'expression de longueur du paramètre doit être spécifiée"
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "l'expression de longueur doit être spécifiée pour un type pointeur"
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "la section du tableau n'est pas contigüe dans la clause %qs"
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE n'a pas un type pointeur ou tableau"
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "l'itérateur %qD n'a pas le type entier ni le type pointeur"
@@ -50640,17 +50670,17 @@ msgstr "l'itérateur %qD n'a pas le type entier ni le type pointeur"
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "l'itérateur %qD a le type qualifié par %<_Atomic%>"
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr "l'itérateur %qD à le type qualifié par « const »"
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "pas de l'itérateur avec un type non entier"
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr "l'itérateur %qD a un pas de zéro"
@@ -50660,32 +50690,32 @@ msgstr "l'itérateur %qD a un pas de zéro"
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr "le type de l'itérateur %qD fait référence à l'itérateur extérieur %qD"
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr "l'expression de début fait référence à l'itérateur extérieur %qD"
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr "l'expression de fin fait référence à l'itérateur extérieur %qD"
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr "l'expression de pas fait référence à l'itérateur extérieur %qD"
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr "pointeur attendu dans la clause %qs"
 
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "clauses %<inscan%> et non-%<inscan%> %<reduction%> sur la même construction"
 
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr "clause %<inscan%> %<reduction%> avec une section de tableau"
@@ -50715,7 +50745,7 @@ msgstr "type de taille variable %qT dans la clause %qs"
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE a un type invalide pour %<reduction(%s)%>"
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "réduction définie par l'utilisateur pas trouvée pour %qE"
@@ -50725,17 +50755,17 @@ msgstr "réduction définie par l'utilisateur pas trouvée pour %qE"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "type d'élément de longueur variable dans la table de la clause %<reduction%>"
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "la clause %<nowait%> ne doit pas être utilisée avec %<copyprivate%>"
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE doit être %<threadprivate%> pour %<copyin%>"
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
 msgstr "le modificateur ne devrait pas être spécifié dans la clause %<linear%> sur des constructions %<simd%> ou %<for%> lorsque les modificateurs OpenMP 5.2 ne sont pas utilisés"
@@ -50750,23 +50780,23 @@ msgstr "clause linéaire appliquée à une variable non entière non pointeur de
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "%<_Atomic%> %qD dans la clause %<linear%>"
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "le pas %qE de la clause %<linear%> n'est ni une constante ni un paramètre"
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE n'est pas une variable dans la clause %qs"
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, gcc-internal-format
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses de partage de données"
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses de réduction"
@@ -50778,32 +50808,32 @@ msgstr "%qE apparaît plus d'une fois dans les clauses de données"
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses de données"
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD apparaît à la fois dans les clauses « data » et « map »"
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE n'est pas une variable dans la clause %<firstprivate%>"
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE n'est pas une variable dans la clause %<lastprivate%>"
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE n'est pas une variable dans la clause %<aligned%>"
@@ -50823,7 +50853,7 @@ msgstr "%<_Atomic%> %qD dans la clause %<aligned%>"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE apparaît plus d'une fois dans les clause %<aligned%>"
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE n'est pas une variable dans la clause %<nontemporal%>"
@@ -50833,7 +50863,7 @@ msgstr "%qE n'est pas une variable dans la clause %<nontemporal%>"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE apparaît plus d'une fois dans les clauses %<nontemporal%>"
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qE n'est pas une variable dans la clause %<allocate%>"
@@ -50843,76 +50873,76 @@ msgstr "%qE n'est pas une variable dans la clause %<allocate%>"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE apparaît plus d'une fois dans les clause %<allocate%>"
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr "clause %<depend%> avec le type de dépendance %<depobj%> sur une section de tableau"
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr "%<omp_all_memory%> utilisé avec le type %<depend%> autre que %<out%> ou %<inout%>"
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr "%qE n'est pas une une expression l-valeur ni une section de tableau dans la clause %qs"
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr "%qE n'a pas le type %<omp_depend_t%> dans la clause %<depend%> avec le type de dépendance %<depobj%>"
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr "%qE ne devrait pas avoir le type %<omp_depend_t%> dans la clause %<depend%> avec un type de dépendance autre que %<depobj%>"
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "la section du tableau n'a pas un type pour lequel une correspondance peut être établie (mappable type) dans la clause %qs"
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, gcc-internal-format
 msgid "unsupported map expression %qE"
 msgstr "expression map %qE non supportée"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses de mouvement"
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses « map »"
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD n'a pas un type pour lequel la correspondance peut être établie (mappable type) dans la clause %qs"
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE n'est ni une variable ni un nom de fonction dans la clause %qs"
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE apparaît plus d'une fois dans la même directive %<declare target%>"
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD n'est pas un argument dans la clause %<uniform%>"
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE n'est pas un argument dans la clause %<uniform%>"
@@ -50927,23 +50957,23 @@ msgstr "la variable %qs n'est pas un pointeur"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "la variable %qs n'est ni un pointeur ni un tableau"
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "la clause %<order%> ne doit pas être utilisée avec %<ordered%>"
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr "trop de clauses %qs dans une construction de tâche"
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "la clause %<inbranch%> est incompatible avec %<notinbranch%>"
 
 # le premier %qs est un mot non traduit tel que « private », « shared » ou « threadprivate ».
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE est prédéterminé %qs pour %qs"
@@ -50953,38 +50983,38 @@ msgstr "%qE est prédéterminé %qs pour %qs"
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "%qE qualifié avec %<const%> peut uniquement apparaître dans les clauses %<shared%> ou %<firstprivate%>"
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "la valeur de la clause %<simdlen%> est plus grande que la valeur de la clause %<safelen%>"
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "modificateur d'ordonnancement %<nonmonotonic%> spécifié en même temps que la clause %<ordered%>"
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "clause %qs spécifiée en même temps que la clause %<inscan%> %<reduction%>"
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "le pas de la clause %<linear%> est un paramètre %qD pas spécifié dans la clause %<uniform%>"
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "la clause %<nogroup%> ne doit pas être utilisée avec la clause %<reduction%>"
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr "la clause %<detach%> ne doit pas être utilisée avec la clause %<mergeable%>"
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr "l'identificateur de l'événement d'une clause %<detach%> ne devrait pas être dans une clause qui partage des données"
@@ -51249,14 +51279,14 @@ msgstr "  pas de conversion connue pour convertir %qH en %qI"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  pas de conversion connue pour convertir l'argument %d depuis %qH vers %qI"
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  le candidat attend au moins %d argument, %d fourni(s)"
 msgstr[1] "  le candidat attend au moins %d arguments, %d fourni(s)"
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -51565,553 +51595,553 @@ msgstr "l'expression conditionnelle entre le type en virgule flottante %qT et le
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "type énuméré et non énuméré dans l'expression conditionnelle"
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "pas de %<%D(int)%> déclaré pour l'opérateur suffixé %qs, on essaie avec l'opérateur préfixé à la place"
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "pas de %<%D(int)%> déclaré pour l'opérateur suffixé %qs"
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr "en C++20, cette comparaison appelle la fonction actuelle récursivement avec les arguments inversés"
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "le type de retour de %qD n'est pas %qs"
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr "utilisé comme candidat réécrit pour la comparaison de %qT et %qT"
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "comparaison entre %q#T et %q#T"
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, gcc-internal-format
 msgid "no match for call to %<%T::operator[] (%A)%>"
 msgstr "pas de concordance pour l'appel à %<%T::operator[] (%A)%>"
 
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, gcc-internal-format
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr "l'appel à %<%T::operator[] (%A)%> est ambigu"
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr "le nettoyage pendant une exception pour cet opérateur « new » avec placement sélectionne %<operator delete%> sans placement"
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD est une fonction de désallocation habituelle (sans placement) en C++14 (ou avec %<-fsized-deallocation%>)"
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD est une fonction de désallocation habituelle (sans placement)"
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "pas de fonction de désallocation correspondante pour %qD"
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr "le destructeur delete %qD ne peut pas utilisé pour libérer la mémoire allouée si l'initialisation lève une exception car l'objet n'est pas encore construit"
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "pas de %<operator %s%> adapté pour %qT"
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "%q#D est privé dans ce contexte"
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "déclaré privé ici"
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%q#D est protégé dans ce contexte"
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "déclaré protégé ici"
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D est inaccessible dans ce contexte"
 
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "passage de NULL pour l'argument non pointeur %P de %qD"
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, gcc-internal-format
 msgid "  declared here"
 msgstr "  déclaré ici"
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "conversion vers un type non pointeur %qT à partir de NULL"
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "conversion de %<false%> vers un type pointeur pour l'argument %P de %qD"
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "conversion de %<false%> vers le type pointeur %qT"
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  initialisation de l'argument %P de %qD"
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les conversions vers des tableaux aux limites inconnues sont uniquement disponibles avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "trop d'accolades autour de l'initialiseur pour %qT"
 
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "la conversion vers %qH depuis %qI requiert une initialisation directe"
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr "le C++ ISO n'autorise pas la conversion vers %qH à partir de %qI avec un plus grand rang de conversion"
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr "le C++ ISO n'autorise pas la conversion vers %qH à partir de %qI avec des rangs de conversion pas ordonnés"
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "la conversion définie par l'utilisateur de %qH vers %qI est invalide"
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 msgid "invalid conversion from %qH to %qI"
 msgstr "conversion invalide de %qH vers %qI"
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "la conversion de la liste d'initialisation vers %qT utiliserait le constructeur explicite %qD"
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "en C++11 et au delà, un constructeur par défaut peut être explicite"
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "impossible de lier la référence d'une r-valeur de type %qH à une l-valeur de type %qI"
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr "impossible de lier la référence d'une l-valeur non constante de type %qH à une valeur de type %qI"
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "impossible de lier la référence d'une l-valeur non constante de type %qH à une r-valeur de type %qI"
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "impossible de lier la référence d'une l-valeur de type %qH à une r-valeur de type %qI"
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "impossible de lier la référence de type %qH vers %qI à cause des limites différentes des tableaux"
 
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "lier la référence du type %qH à %qI abandonne les qualificatifs"
 
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "ne peut lier le champ de bits %qE avec %qT"
 
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "ne peut lier le champs empaqueté %qE avec %qT"
 
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "ne peut lier la r-valeur %qE avec %qT"
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "conversion implicite de %qH en %qI lors du passage de l'argument à la fonction"
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr "l'énumération %qT dans une portée limitée est passée au travers de %<...%> en tant que %qT avant %<-fabi-version=6%> et en tant que %qT après"
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "le passage d'objets du type %q#T non trivialement copiables au travers de %<...%> est supporté conditionnellement"
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "impossible de recevoir le type référencé %qT au travers de %<...%>"
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "la réception d'objets du type %q#T non trivialement copiables au travers de %<...%> est supporté conditionnellement"
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "évaluation récursive de l'argument par défaut pour %q#D"
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "l'appel à %qD utilise l'argument par défaut du paramètre %P qui n'est pas encore défini"
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "l'argument de l'appel de fonction pourrait être un candidat pour un attribut de format"
 
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "utilisation d'une fonction ayant plusieurs versions sans version par défaut"
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr "utilisez %<-fdiagnostics-all-candidates%> pour afficher tous les candidats considérés"
 
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "le passage de %qT comme argument %<this%> abandonne les qualificatifs"
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  dans l'appel de %qD"
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT n'est pas une base accessible de %qT"
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "passage des arguments à l'élision du constructeur hérité %qD"
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "l'affectation depuis le %<initializer_list%> temporaire n'étend pas la durée de vie du tableau sous-jacent"
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr "écriture %qD vers un objet de type %#qT sans affectation par copie triviale"
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "écriture %qD vers un objet de type non trivial %#qT%s"
 
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr "écriture %qD vers un objet de type %#qT avec le membre %qs de %qD"
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr "écriture %qD vers un objet de type %#qT contenant un pointeur vers le membre de donnée%s"
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr "; utilisez plutôt une affectation ou une initialisation par valeur"
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "; utilisez plutôt une affectation"
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "; utilisez plutôt une initialisation par valeur"
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD effacement d'un objet de type %#qT sans affectation par copie triviale%s"
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD effacement d'un objet du type non trivial %#qT%s"
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr "%qD effacement d'un objet de type %#qT contenant un pointeur vers un membre%s"
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "; utilisez plutôt une affectation par copie ou une initialisation par copie"
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr "; utilisez plutôt une affectation par copie"
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "; utilisez plutôt une initialisation par copie"
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD écriture dans un objet de type %#qT sans affectation par copie triviale%s"
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "%qD écriture dans un objet du type non trivialement copiable %#qT%s"
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr "%qD écriture dans un objet avec un constructeur par copie supprimé"
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr "%qD copie un objet du type non trivial %#qT depuis un tableau de %#qT"
 
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr "%qD copie un objet de type %#qT avec le membre %qs de %qD depuis un tableau de %#qT; utilisez plutôt une affectation ou une initialisation par copie"
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr "%qD écriture dans un objet du type non trivial %#qT laisse %wu octets inchangés"
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr "%qD écriture dans un objet du type non trivial %#qT laisse %wu octet inchangé"
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "%qD déplacement d'un objet du type non trivialement copiable %#qT; utilisez plutôt %<new%> et %<delete%>"
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr "%qD déplacement d'un objet de type %#qT avec un constructeur par copie supprimé; utilisez plutôt %<new%> et %<delete%>"
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr "%qD déplacement d'un objet de type %#qT avec un destructeur supprimé"
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr "%qD déplacement d'un objet du type non trivial %#qT et de taille %E dans une région de taille %E"
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT déclaré ici"
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, gcc-internal-format
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr "l'argument %u dans l'appel à la fonction %qE est un pointeur vers un type non trivialement copiable (%qT)"
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "le constructeur délègue à lui-même"
 
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 msgid "cannot convert %qH to %qI"
 msgstr "ne peut convertir %qH en %qI"
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "pas de fonction concordante pour l'appel à %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "pas de fonction concordante pour l'appel à %<%T::%s%E(%A)%#V%>"
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "appel à la non fonction %qD"
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "ne peut appeler le constructeur %<%T::%D%> directement"
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "pour un transtypage de style « fonction », enlevez le %<::%D%> redondant"
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "pas de fonction concordante pour l'appel de %<%s(%A)%>"
 
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "appel ambigu à la surcharge %<%s(%A)%>"
 
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "appel à %q#D qui est pur virtuel depuis un initialisateur qui n'est pas un membre statique"
 
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "appel à %q#D qui est pur virtuel depuis le constructeur"
 
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "appel à %q#D qui est pur virtuel depuis le destructeur"
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "impossible d'appeler la fonction membre %qD sans objet"
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "le passage de %qT choisi %qT au lieu de %qT"
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, gcc-internal-format
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr "le C++20 indique que ceux-ci sont ambigus même si le second est inversé :"
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, gcc-internal-format
 msgid "try making the operator a %<const%> member function"
 msgstr "essayez de rendre l'opérateur une fonction membre %<const%>"
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "choix de %qD à la place de %qD"
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 msgid "  for conversion from %qH to %qI"
 msgstr "  pour la conversion de %qH vers %qI"
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  parce que la séquence de conversion pour l'argument est meilleure"
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "désaccord dans l'argument par défaut lors de la résolution de la surcharge"
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " candidat 1: %q#F"
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " candidat 2: %q#F"
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "le C++ ISO indique que ceux-ci sont ambigus même si la plus mauvaise conversion pour le premier est meilleures que la plus mauvaise conversion pour le second:"
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "une limite temporaire sur %qD existe uniquement jusqu'à la sortie du constructeur"
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "initialisation invalide pour une référence non constante du type %qH à partir d'une r-valeur de type %qI"
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "initialisation invalide pour une référence du type %qH à partir d'une expression de type %qI"
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, gcc-internal-format
 msgid "possibly dangling reference to a temporary"
 msgstr "est peut-être une référence ballante vers un temporaire"
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr "le temporaire a été détruit à la fin de l'expression complète %qE"
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, gcc-internal-format
 msgid "explicit conversion function was not considered"
 msgstr "la fonction de conversion explicite n'a pas été considérée"
@@ -52158,7 +52188,7 @@ msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q#D ne peut pas être surchargé par %q#D"
 
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "déclaration précédente de %q#D"
@@ -52579,7 +52609,7 @@ msgstr "membre tableau flexible %qD dans %q#T par ailleurs vide"
 msgid "next member %q#D declared here"
 msgstr "membre %q#D suivant déclaré ici"
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redéfinition de %q#T"
@@ -52711,7 +52741,7 @@ msgstr "type invalide pour le paramètre %d de la fonction %<constexpr%> %q+#D"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr "les lambdas ne sont implicitement %<constexpr%> qu'à partir du C++17"
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les destructeurs %<constexpr%> sont uniquement disponible avec %<-std=c++20%> ou %<-std=gnu++20%>"
@@ -52752,7 +52782,7 @@ msgstr "le corps de la fonction %<constexpr%> %qD n'est pas une unique instructi
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%qD n'est pas utilisable comme une fonction %<constexpr%> car:"
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr "destruction de %qE en dehors de sa durée de vie"
@@ -52770,7 +52800,7 @@ msgstr "l'appel %<constexpr%> déborde au delà de la fin de la fonction"
 msgid "%q+E is not a constant expression"
 msgstr "%q+E n'est pas une expression constante"
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -52791,7 +52821,7 @@ msgstr "%qE est évalué à « faux »"
 msgid "failed %<assume%> attribute assumption"
 msgstr "la supposition de l'attribut %<assume%> a échoué"
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, gcc-internal-format
 msgid "call to internal function %qE"
@@ -52838,7 +52868,7 @@ msgstr "%qT est une classe de base ambigüe du type dynamique %qT de son opéran
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr "le type dynamique %qT de son opérande n'a pas une classe de base publique %qT non ambigüe"
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -52966,18 +52996,18 @@ msgstr "la valeur %qE de l'indice du tableau est hors des limites du tableau de
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "l'indice de tableau non nul %qE est utilisé avec un tableau de type %qT dont les limites sont inconnues"
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "accès à un élément non initialisé du tableau"
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "déréférencement d'un pointeur nul dans %qE"
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -52985,469 +53015,469 @@ msgstr "déréférencement d'un pointeur nul dans %qE"
 msgid "%qE is not a constant expression"
 msgstr "%qE n'est pas une expression constante"
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "le mutable %qD n'est pas utilisable dans une expression constante"
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "accès au membre non initialisé %qD"
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "accès au membre %qD au lieu du membre initialisé %qD dans l'expression constante"
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "%qs n'est pas une expression constante car %qT est un type union"
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "%qs n'est pas une expression constante car %qT contient un type union"
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "%qs n'est pas une expression constante car %qT est un type pointeur"
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "%qs n'est pas une expression constante car %qT contient un type pointeur"
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "%qs n'est pas une expression constante car %qT est un type référence"
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "%qs n'est pas une expression constante car %qT contient un type référence"
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "%qs n'est pas une expression constante car %qT est un type pointeur vers un membre"
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "%qs n'est pas une expression constante car %qT contient un type pointeur vers un membre"
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "%qs n'est pas une expression constante car %qT est volatile"
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "%qs n'est pas une expression constante car %qT contient un sous-objet volatile"
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "%qs ne peut pas être évalué de manière constante sur la cible"
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr "%qs ne peut pas être évalué de manière constante car le type est trop grand"
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr "%qs ne peut pas être évalué de manière constante car l'argument ne sait pas être encodé"
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "%qs accès à un octet non initialisé à l'offset %d"
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "%qs ne peut pas être évalué de manière constante car l'argument ne sait pas être interprété"
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "accès à la valeur de %qE au travers d'une gl-valeur %qT dans une expression constante"
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "utilisation d'un stockage alloué après sa désallocation dans une expression constante"
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, gcc-internal-format
 msgid "allocated here"
 msgstr "alloué ici"
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
 msgstr "accès à %qE en dehors de sa durée de vie"
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "le contenu d'un stockage non initialisé n'est pas utilisable dans une expression constante"
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "la valeur de %qD n'est pas utilisable dans une expression constante"
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD utilisé dans sa propre initialisation"
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D n'est pas const"
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D est volatile"
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD n'a pas été initialisé par une expression constante"
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD n'a pas été déclaré %<constexpr%>"
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD n'a pas un type entier ou énuméré"
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, gcc-internal-format
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr "modifier un stockage alloué après désallocation n'est pas une expression constante"
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, gcc-internal-format
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr "modifie %qE en dehors de sa durée de vie n'est pas une expression constante"
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, gcc-internal-format
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr "détruire %qE en dehors de l'évaluation courante n'est pas une expression constante"
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, gcc-internal-format
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr "la modification de %qE en dehors de l'évaluation courante n'est pas une expression constante"
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr "changement du membre actif d'une union de %qD à %qD n'est pas une expression constante avant C++20"
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr "%qD ne commence pas implicitement sa durée de vie car %qT n'a pas un constructeur par défaut trivial non supprimé, utilisez plutôt %<std::construct_at%>"
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr "l'initialisation de %qD requiert une expression d'accès à un membre comme opérande de gauche dans l'assignement"
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "changement du membre actif d'une union de %qD à %qD durant l'initialisation"
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "l'instruction n'est pas une expression constante"
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "le décompte des itérations de la boucle %<constexpr%> dépasse la limite permise %d (utilisez %<-fconstexpr-loop-limit=%> pour augmenter la limite)"
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "l'assembleur en ligne n'est pas une expression constante"
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr "seul de l'assembleur en ligne non évalué est autorisé dans une fonction %<constexpr%> en C++20"
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, gcc-internal-format
 msgid "use of %qD"
 msgstr "utilisation de %qD"
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr "sa valeur peut varier entre les versions du compilateur ou avec des fanions %<-mtune%> ou %<-mcpu%> différents"
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr "si son utilisation fait partie d'une ABI publique, changez-le pour utiliser plutôt une variable constante que vous définissez"
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr "la valeur par défaut pour les réglages actuels du processeur est %d octets"
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr "vous pouvez stabiliser cette valeur avec %<--param hardware_destructive_interference_size=%d%> ou désactiver cet avertissement avec %<-Wno-interference-size%>"
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "la valeur %qE du type %qT n'est pas une expression constante"
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "le décompte des opérations d'évaluation de %<constexpr%> dépasse la limite permise %wd (utilisez %<-fconstexpr-ops-limit=%> pour augmenter la limite)"
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr "le contrôle passe au travers de la définition de %qD avec une durée de stockage limitée au thread"
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, gcc-internal-format
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "le contrôle passe au travers de la définition de %qD avec une durée de stockage statique"
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporaire du type %qT non littéral dans une expression constante"
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "un %<reinterpret_cast%> n'est pas une expression constante"
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "conversion depuis le type pointeur %qT vers le type arithmétique %qT dans une expression constante"
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr "le transtypage de %qT n'est pas permis dans une expression constante car le type pointé %qT n'est pas similaire à %qT"
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, gcc-internal-format
 msgid "pointed-to object declared here"
 msgstr "l'objet pointé est déclaré ici"
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr "le transtypage depuis %qT n'est pas permis dans une expression constante car %qE ne pointe pas vers un objet"
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr "le transtypage depuis %qT n'est pas autorisé dans une expression constante avant C++26"
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "%qE n'est pas une expression constante tant que la classe %qT est encore incomplète"
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> n'est pas une expression constante"
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "l'expression %qE n'est pas une expression constante"
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> n'est pas une expression constante"
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "le prédicat du contrat est faux dans une expression constante"
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "template-id %qE inattendu"
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr "un concept de fonction doit être appelé"
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "l'adresse d'un appel à %qs n'est pas une expression constante"
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "l'expression %qE du sous-type %s est inattendue"
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE n'est pas une expression constante car il fait référence aux sous-objets mutables de %qT"
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE n'est pas une expression constante car il fait référence à une variable incomplètement initialisée"
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qE n'est pas une expression constante car il fait référence à un résultat de %<operator new%>"
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qE n'est pas une expression constante car le stockage alloué n'a pas été désalloué"
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr "l'évaluation immédiate retourne l'adresse de la fonction immédiate %qD"
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, gcc-internal-format
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr "l'évaluation constante retourne l'adresse de la fonction immédiate %qD"
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "conversion l-valeur vers r-valeur d'une l-valeur volatile %qE avec le type %qT"
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "la capture lambda de %qE n'est pas une expression constante"
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "car il est utilisé comme gl-valeur"
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "%<reinterpret_cast%> d'un entier vers un pointeur"
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "prendre l'adresse avec address-of d'un objet %qE qui est local au thread ou a un stockage automatique n'est pas une expression constante"
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "utilisation de %<this%> dans une expression constante"
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "expression lambda dans une expression constante avant C++17"
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "l'expression new n'est pas une expression constante avant C++20"
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "les fonctions virtuelles ne peuvent pas être %<constexpr%> avant C++20"
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "l'expression %<typeid%> n'est pas une expression constante car %qE est un type polymorphique"
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "transtypage vers le type non entier %qT dans une expression constante"
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "%qD défini %<thread_local%> dans un contexte %<constexpr%>"
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "%qD défini %<static%> dans un contexte %<constexpr%>"
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "la division par zéro n'est pas une expression constante"
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> n'est pas une expression constante"
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "aucune des branches de %<if%> est une expression constante"
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "initialisation d'un tableau non constant"
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "la définition d'une étiquette dans une fonction %<constexpr%> est uniquement disponible avec %<-std=c++2b%> ou %<-std=gnu++2b%>"
 
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "arbre syntaxique abstrait (AST=Abstract Syntax Tree) de type %s inattendu"
@@ -54158,7 +54188,7 @@ msgstr "l'argument de direction de %<__builtin_core_promise%> doit être une con
 msgid "no suspend point info for %qD"
 msgstr "aucune information du point de suspension pour %qD"
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr "%qE est fourni par %qT mais il n'est pas utilisable avec la fonction ayant la signature %qD"
@@ -54178,23 +54208,23 @@ msgstr "les expressions temporisables ne sont pas permises dans les gestionnaire
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "les tableaux de longueur variable ne sont pas encore supportés dans les coroutines"
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr "%qE est fourni par %qT mais %qE n'est pas marqué avec %<throw()%> ou %<noexcept%>"
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr "%qE est marqué avec %<throw()%> ou %<noexcep%> mais aucun %<get_return_object_on_allocation_failure%> utilisable est fourni par %qT"
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr "%qE est fourni par %qT mais %<std::nothrow%> n'est pas trouvé"
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr "impossible d'initialiser un objet retourné de type %qT avec une r-valeur de type %<void%>"
@@ -54214,68 +54244,68 @@ msgstr "%qD a été promu en une fonction immédiate car son corps contient une
 msgid "%qD was promoted to an immediate function"
 msgstr "%qD a été promu en une fonction immédiate"
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "prise de l'adresse d'une fonction immédiate %qD"
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, gcc-internal-format
 msgid "call to consteval function %qE is not a constant expression"
 msgstr "l'appel à la fonction consteval %qE n'est pas une expression constante"
 
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%<throw%> appellera toujours %<terminate%>"
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "en C++11, les destructeurs sont %<noexcept%> par défaut"
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr "en C++11, ce %<throw%> appellera %<terminate%> car les destructeurs sont %<noexcept%> par défaut"
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "l'attribut %qE est ignoré après un %qE antérieur"
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, gcc-internal-format
 msgid "pack expansion of %qE attribute"
 msgstr "comprimer l'expansion de l'attribut %qE"
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, gcc-internal-format
 msgid "use fold expression in the attribute argument instead"
 msgstr "utiliser plutôt une expression de repli (fold) dans l'argument de l'attribut"
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD n'est pas un type"
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qD n'est pas un type de classe"
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qD n'a pas le type %<const char *%>"
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%qD n'a pas un type entier"
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr "%<std::source_location::__impl%> ne contient pas uniquement que des membres de données non-statiques %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> et %<_M_column%>"
@@ -54316,7 +54346,7 @@ msgstr "conversion vers le type référencé non const %q#T depuis une r-valeur
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "la conversion depuis %qH vers %qI écarte les qualificatifs"
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "le transtypage de %qT vers %qT ne déréférence pas le pointeur"
@@ -54699,7 +54729,7 @@ msgstr "par rapport à la déclaration précédente de %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "la redéclaration de %qD diffère de %qs dans la déclaration précédente"
 
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "déclaration précédente de %qD"
@@ -54839,8 +54869,8 @@ msgstr "déclaration %<pragma omp declare reduction%> précédente"
 msgid "%q#D previously defined here"
 msgstr "%q#D précédemment défini ici"
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q#D précédemment déclaré ici"
@@ -54915,53 +54945,38 @@ msgstr "argument par défaut donné pour le paramètre %d de %q#D"
 msgid "previous specification in %q#D here"
 msgstr "la spécification précédente dans %q#D est ici"
 
-#: cp/decl.cc:2285
-#, gcc-internal-format
-msgid "declaration %qD conflicts with builtin"
-msgstr "la déclaration %qD est en conflit avec la fonction interne"
-
-#: cp/decl.cc:2288
-#, gcc-internal-format
-msgid "declaration %qD conflicts with import"
-msgstr "la déclaration %qD est en conflit avec l'import"
-
-#: cp/decl.cc:2289
-#, gcc-internal-format
-msgid "import declared %q#D here"
-msgstr "l'import a déclaré %q#D ici"
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, gcc-internal-format
 msgid "conflicting exporting for declaration %qD"
 msgstr "export conflictuel pour la déclaration %qD"
 
 # la phrase fait référence à une variable ou une fonction (cf les deux messages ci-dessus) d'où le féminin
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, gcc-internal-format
 msgid "previously declared here without exporting"
 msgstr "précédemment déclarée ici sans export"
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "la définition précédente de %qD est ici"
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "la déclaration précédente de %qD est ici"
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "fonction %qD déclarée %<[[noreturn]]%> mais sa première déclaration ne l'était pas"
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "déclaration redondante de %qD dans la même étendue"
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr "définition supprimée de %qD n'est pas la première déclaration"
@@ -54974,44 +54989,44 @@ msgstr "définition supprimée de %qD n'est pas la première déclaration"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "spécialisation explicite de %qD après la première utilisation"
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%qD: attribut de visibilité ignoré car il est en conflit avec la déclaration précédente"
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "redéfinition de %q#D"
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD est en conflit avec la fonction utilisée"
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D pas déclaré dans une classe"
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D redéclaré en ligne avec l'attribut %<gnu_inline%>"
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D redéclaré en ligne sans l'attribut %<gnu_inline%>"
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr "l'opérateur de comparaison %q+D est remis au défaut après sa première déclaration"
@@ -55019,2502 +55034,2502 @@ msgstr "l'opérateur de comparaison %q+D est remis au défaut après sa premièr
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "la redéclaration de l'ami %q#D ne peut pas avoir d'arguments de patron par défaut"
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "la déclaration locale au thread de %q#D suit la déclaration non locale au thread"
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "la déclaration non locale au thread de %q#D suit la déclaration locale au thread"
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "redéclaration de %q#D"
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "redéclaration redondante du membre statique %<constexpr%> %qD"
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "l'étiquette locale %qE est en conflit avec l'étiquette existante"
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, gcc-internal-format
 msgid "previous label"
 msgstr "étiquette précédente"
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, gcc-internal-format
 msgid "jump to label %qD"
 msgstr "saut à l'étiquette %qD"
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr "saut à l'étiquette du « case »"
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr "  comme cible possible d'un goto calculé"
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  à partir d'ici"
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  sort du block structuré OpenMP"
 
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  croise l'initialisation de %q#D"
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr "  entre dans le bloc %<try%>"
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "  entre dans le bloc %<catch%>"
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  entre dans le bloc structuré OpenMP"
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "  entre dans l'instruction synchronisée ou atomique"
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, gcc-internal-format
 msgid "  enters statement expression"
 msgstr "  entre dans l'expression de l'instruction"
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "  entre dans l'instruction %<constexpr if%>"
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, gcc-internal-format
 msgid "  enters %<consteval if%> statement"
 msgstr "  entre dans l'instruction %<consteval if%>"
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, gcc-internal-format
 msgid "  does not destroy %qD"
 msgstr "  ne détruit pas %qD"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, gcc-internal-format
 msgid "  does not clean up handled exception"
 msgstr "  ne nettoie pas l'exception traitée"
 
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  passe outre l'initialisation de %q#D"
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "%qD utilisé sans arguments du patron"
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, gcc-internal-format
 msgid "%qD is a function, not a type"
 msgstr "%qD est une fonction, pas un type"
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T n'est pas une classe"
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "pas de patron de classe nommé %q#T dans %q#T"
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "pas de type nommé %q#T dans %q#T"
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "la recherche de %qT dans %qT est ambigüe"
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nomme %q#T qui n'est pas un patron de classe"
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> nomme %q#D qui n'est pas un type"
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "les paramètres du patron ne correspondent pas au patron %qD"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "%<-faligned-new=%d%> n'est pas une puissance de deux"
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr "%<--param destructive-interference-size=%d%> est plus petit que %d"
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr "%<--param destructive-interference-size=%d%> est plus petit que %<--param l1-cache-line-size=%d%>"
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr "%<--param constructive-interference-size=%d%> est plus petit que %d"
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr "%<--param constructive-interference-size=%d%> est plus grand que %<--param l1-cache-line-size=%d%>"
 
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D est invalide; une union anonyme ne peut avoir que des membres de données publiques non statiques"
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "cette flexibilité est dépréciée et sera supprimée"
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr "struct anonyme avec des classes de base"
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "le membre %q+#D avec un constructeur n'est pas permis dans un agrégat anonyme"
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "le membre %q+#D avec un destructeur n'est pas permis dans un agrégat anonyme"
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "le membre %q+#D avec un opérateur d'affectation par copie n'est pas permis dans un agrégat anonyme"
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "attribut ignoré dans la déclaration de %q#T"
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "l'attribut pour %q#T doit suivre le mot-clé %qs"
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "types multiples dans une déclaration"
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "redéclaration du type interne C++ %qT"
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> peut seulement être spécifié pour des déclarations de variables ou de fonctions"
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "nom de type manquant dans la déclaration typedef"
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "le C++ ISO interdit les structures anonymes"
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> peut seulement être spécifié pour des fonctions"
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> peut seulement être spécifié pour des fonctions"
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> peut seulement être spécifié à l'intérieur d'une classe"
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> peut seulement être spécifié pour des constructeurs"
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "une classe de stockage peut seulement être spécifiée pour des objets et des fonctions"
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> peut seulement être spécifié pour des objets et des fonctions"
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> a été ignoré dans cette déclaration"
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%qs ne peut pas être utilisé pour des déclarations de types"
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "attribut ignoré dans l'instanciation explicite de %q#T"
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "aucun attribut peut être appliqué à une instanciation explicite"
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "les attributs sont ignorés s'ils sont appliqués à la classe de type %qT en dehors de la définition"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "attributs ignorés car ils sont appliqués au type dépendent %qT sans déclaration associée"
 
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD est initialisé (utilisez plutôt %qs)"
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "la déclaration de %q#D est %<extern%> et est initialisée"
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "la définition de %q#D est marquée %<dllimport%>"
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D n'est pas un membre de donnée statique de %q#T"
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "la déclaration du patron non membre de %qD"
 
 # le message ci-dessous est la suite de celui juste ci-dessus
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "ne correspond pas à la déclaration du patron membre ici"
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "le C++ ISO ne permet pas que %<%T::%D%> soit défini comme %<%T::%D%>"
 
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "initialisation en double de %qD"
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "la déclaration de %q#D en dehors de la classe n'est pas une définition"
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr "la déclaration externe avec la portée bloc %q#D ne doit pas être attachée à un module nommé"
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%qD défini %<thread_local%> dans la fonction %qs est uniquement disponible avec %<-std=c++2b%> ou %<-std=gnu++2b%>"
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%qD défini %<static%> dans la fonction %qs est uniquement disponible avec %<-std=c++2b%> ou %<-std=gnu++2b%>"
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "la variable %q#D a un initialiseur mais a un type incomplet"
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "les éléments du tableau %q#D ont un type incomplet"
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "l'agrégat %q#D a un type incomplet et ne peut être défini"
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD est déclaré comme référence mais n'est pas initialisé"
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "nom utilisé dans une initialisation par désignation dans le style GNU pour un tableau"
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "nom %qD utilisé dans une initialisation par désignation dans le style GNU pour un tableau"
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "les initialisations par désignation non triviales ne sont pas supportées"
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "le champ désigné par l'indicateur C99 %qE n'est pas une expression constante entière"
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "l'initialisation n'a pu déterminer la taille de %qD"
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "taille de tableau manquante dans %qD"
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "tableau %qD de taille zéro"
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "la taille de stockage de %qD n'est pas connue"
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "la taille de stockage de %qD n'est pas constante"
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "désolé: les sémantiques de la variable en ligne %q#D sont erronées (vous obtiendrez de multiples copies)"
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "désolé: les sémantiques de la fonction statique en ligne %q#D sont erronées (vous obtiendrez de multiples copies)"
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "vous pouvez contourner cela en enlevant l'initialiseur"
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "%<const %D%> non initialisé"
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "variable %qD non initialisée dans une fonction %<constexpr%>"
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "variable %qD non initialisée dans un contexte %<constexpr%>"
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T n'a pas de constructeur par défaut fourni par l'utilisateur"
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "le constructeur n'est pas défini par l'utilisateur car le constructeur par défaut est explicitement demandé dans le corps de la classe"
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "et le constructeur implicitement défini n'initialise pas %q#D"
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "type %qT invalide pour initialiser un vecteur de type %qT"
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "l'initialisation de %qT doit être entre accolades"
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> utilisé dans une initialisation par désignation dans le style GNU pour la classe %qT"
 
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "la requête pour le membre %qD est ambiguë"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT n'a pas de membre de données non statique nommé %qD"
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD n'est pas un membre direct de %qT"
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "initialisation invalide pour %q#D"
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "le champ désigné par l'indicateur C99 %qE est hors de l'initialisation de l'agrégat"
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "trop d'éléments d'initialisation pour %qT"
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "accolades autour de l'initialiseur scalaire pour le type %qT"
 
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "trop d'accolades autour de l'initialiseur scalaire pour le type %qT"
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "accolades manquantes autour de l'initialisation pour %qT"
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "la liaison structurée à le type incomplet %qT"
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "les éléments du tableau %q#T ont un type incomplet"
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "littéral composé de taille variable"
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D a un type incomplet"
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "l'objet scalaire %qD requiert un élément dans l'initialisation"
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "en C++98, %qD doit être initialisé par un constructeur et non par %<{...}%>"
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "le tableau %qD est initialisé par la chaîne littérale entre parenthèses %qE"
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "initialisation invalide pour un membre statique avec constructeur"
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "l'initialisation non constante dans la classe est invalide pour le membre statique %qD"
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "l'initialisation non constante dans la classe est invalide pour le membre statique pas en ligne %qD"
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(une initialisation en dehors de la classe est requise)"
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "la référence %qD est initialisée avec elle-même"
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "n'a pu trouver la déclaration du variant"
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%<declare variant%> sur le constructeur %qD"
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "%<declare variant%> sur le destructeur %qD"
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "%<declare variant%> sur %qD par défaut"
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr "%<declare variant%> sur %qD supprimé"
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%<declare variant%> sur %qD virtuel"
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "affectation (pas une initialisation) dans la déclaration"
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "le C++17 ISO n'autorise pas le spécificateur de classe de stockage %<register%>"
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "spécificateur de classe de stockage %<register%> utilisé"
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "la déclaration de %q#D n'est pas initialisée"
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "l'initialisation pour %<decltype(auto) %D%> a un type fonction (avez-vous oublié les %<()%> ?)"
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, gcc-internal-format
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "le type déduit %qT pour %qD est incomplet"
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "le concept de variable n'a pas d'initialisation"
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "masque la déclaration précédente du type de %q#D"
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%<constinit%> peut uniquement être appliqué à une variable avec une durée de stockage statique ou au niveau du thread"
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "la fonction %q#D est initialisée comme une variable"
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "impossible de décomposer le type de la classe %qT car il a une structure anonyme comme membre"
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "impossible de décomposer le type de la classe %qT car il a une union anonyme comme membre"
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "impossible de décomposer le membre inaccessible %qD de %qT"
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "impossible de décomposer le type de classe %qT: lui et sa classe de base %qT ont des membres de données non statiques"
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "impossible de décomposer le type de classe %qT: ses classes de base %qT et %qT ont des membres de données non statiques"
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "la liaison structurée fait référence au type incomplet %qT"
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "impossible de décomposer le tableau de longueur variable %qT"
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%u nom fourni pour la liaison structurée"
 msgstr[1] "%u noms fournis pour la liaison structurée"
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] "seulement %u nom fourni pour la liaison structurée"
 msgstr[1] "seulement %u noms fournis pour la liaison structurée"
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] "alors que %qT se décompose en %wu élément"
 msgstr[1] "alors que %qT se décompose en %wu éléments"
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "impossible de décomposer le vecteur de longueur variable %qT"
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> n'est pas une expression constante entière"
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "alors que %qT se décompose en %E éléments"
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr "%<std::tuple_element<%u, %T>::type%> est %<void%>"
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "dans l'initialisation de la variable de liaison structurée %qD"
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "impossible de décomposer le type union %qT"
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "impossible de décomposer le type %qT qui n'est ni une classe ni un tableau"
 
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "impossible de décomposer le type de fermeture lambda %qT"
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "la liaison structurée fait référence au type de classe incomplet %qT"
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "impossible de décomposer le type de classe %qT sans membre de donnée non statique"
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "la variable non locale %qD déclarée %<__thread%> a besoin d'une initialisation dynamique"
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "la variable non locale %qD déclarée %<__thread%> a un destructeur non trivial"
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "%<thread_local%> en C++11 permet l'initialisation et la destruction dynamique"
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "l'initialisation n'a pu déterminer la taille de %qT"
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "taille du tableau manquante dans %qT"
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "tableau %qT de taille zéro"
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "le destructeur pour la classe étrangère %qT ne peut pas être un membre"
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "le constructeur pour la classe étrangère %qT ne peut pas être un membre"
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD est déclaré comme une variable %<virtual%>"
 
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de variable"
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD déclaré comme un paramètre %<virtual%>"
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD déclaré comme un paramètre %<inline%>"
 
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de paramètre"
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD déclaré comme un type %<virtual%>"
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD déclaré comme un type %<inline%>"
 
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de type"
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD déclaré comme un champ %<virtual%>"
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD déclaré comme un champ %<inline%>"
 
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de champ"
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D déclaré comme un ami"
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D déclaré avec une spécification d'exception"
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "la définition de %qD n'est pas dans l'espace de noms incluant %qT"
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "la fonction membre statique %q#D est déclarée avec des qualificatifs de type"
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "le concept %q#D est déclaré avec des paramètres de fonction"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "le concept %q#D est déclaré avec un type de retour déduit"
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "le concept %q#D a le type de retour %qT qui n'est pas %<bool%>"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "le concept %qD n'a pas de définition"
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "un concept de fonction ne peut pas être contraint"
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "contraintes sur une fonction sans patron"
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, gcc-internal-format
 msgid "constrained non-template friend declaration must be a definition"
 msgstr "la déclaration amie hors patron et contrainte doit être une définition"
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr "le patron de la fonction amie avec des contraintes qui dépendent de paramètres extérieures au patron doit être une définition"
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "définition de la spécialisation explicite %qD dans la déclaration amie"
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "utilisation invalide du template-id %qD dans la déclaration du patron primaire"
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "les arguments par défaut ne sont pas permis dans la déclaration de la spécialisation du patron ami %qD"
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> n'est pas permis dans la déclaration de la spécialisation du patron ami %qD"
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "la déclaration amie de %qD spécifie des arguments par défaut et n%'est pas une définition"
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "ne peut déclarer %<::main%> comme étant un patron"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "ne peut déclarer %<::main%> comme étant à mettre en ligne"
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "ne peut déclarer %<::main%> comme étant %qs"
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "ne peut déclarer %<::main%> comme étant static"
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "la fonction non membre %qD ne peut pas avoir de qualificatif CV"
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "la fonction membre statique %qD ne peut pas avoir de qualificatif CV"
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, gcc-internal-format
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr "la fonction membre objet explicite %qD ne peut pas avoir de qualificatif CV"
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "la fonction non membre %qD ne peut pas avoir de qualificatif de référence"
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "la fonction membre statique %qD ne peut pas avoir de qualificatif de référence"
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, gcc-internal-format
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr "la fonction membre objet explicite %qD ne peut pas avoir de qualificatif de référence"
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, gcc-internal-format
 msgid "explicit object parameter declared here"
 msgstr "le paramètre objet explicite est déclaré ici"
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "le guide de déduction %qD doit être déclaré dans la même portée que %qT"
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "le guide de déduction %qD doit avoir le même accès que %qT"
 
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "le guide de déduction %qD ne peut pas avoir un corps de fonction"
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "opérateur littéral avec une classe de liaison C"
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD a une liste d'arguments invalide"
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "le suffixe entier %qs est masqué par l'implémentation"
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "le suffixe en virgule flottante %qs est masqué par l'implémentation"
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "les suffixes d'opérateurs littéraux qui ne sont pas précédés par %<_%> sont réservés pour une standardisation future"
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD doit être une fonction non membre"
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> doit retourner %<int%>"
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "définition de %qD déclaré implicitement"
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "définition de %qD explicitement par défaut"
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D explicitement par défaut ici"
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "pas de fonction membre %q#D déclarée dans la classe %qT"
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "ne peut déclarer %<::main%> comme variable globale"
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "une variable qui n'est pas un patron ne peut pas avoir %<concept%>"
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr "le concept doit être défini au niveau de l'espace de noms"
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "un concept doit avoir le type %<bool%>"
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "un concept variable ne peut pas être contraint"
 
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "initialisation intra-classe du membre de donnée statique %q#D d'un type incomplet"
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> est requis pour l'initialisation intra-classe du membre de donnée statique %q#D d'un type non entier"
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "initialisation intra-classe du membre de donnée statique %q#D du type non littéral"
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "initialisation intra-classe invalide du membre de donnée statique du type non entier %qT"
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "le C++ ISO interdit l'initialisation intra-classe du membre statique non constant %qD"
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "le C++ ISO interdit l'initialisation du membre constant %qD du type non entier %qT"
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "la taille du tableau %qD a le type non entier %qT"
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "la taille du tableau a le type non entier %qT"
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "la taille du tableau %qD n'est pas une expression constante de type entier"
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "la taille du tableau n'est pas une expression constante entière"
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "le C++ ISO interdit le tableau de taille zéro %qD"
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "le C++ ISO interdit le tableau de taille zéro"
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "le C++ ISO interdit le tableau de taille variable %qD"
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "le C++ ISO interdit le tableau de taille variable"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "le tableau de taille variable %qD est utilisé"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "le tableau de taille variable est utilisé"
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "débordement dans la dimension du tableau"
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%qD est déclaré comme tableau de type à remplacer dans un patron %qT"
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr "création d'un tableau de type à remplacer dans un patron %qT"
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "déclaration de %qD comme un tableau de « void »"
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "création d'un tableau « void »"
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "déclaration de %qD comme un tableau de fonctions"
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "création d'un tableau de fonctions"
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "déclaration de %qD comme un tableau de références"
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "création d'un tableau de références"
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "déclaration de %qD comme un tableau de fonctions membres"
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "création d'un tableau de fonctions membres"
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "la déclaration de %qD comme tableau multidimensionnel doit avoir des bornes pour chaque dimension excepté la première"
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "le tableau multidimensionnel doit avoir des bornes pour chaque dimension excepté la première"
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr "tableau de taille variable de %<auto%>"
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "la spécification d'un type retourné pour un constructeur est invalide"
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration d'un constructeur"
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "la spécification d'un type retourné pour un destructeur est invalide"
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration d'un destructeur"
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "type de retour spécifié pour %<operator %T%>"
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration de %<operator %T%>"
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "type de retour spécifié pour le guide de déduction"
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration du guide de déduction"
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "paramètre de patron %qT, qui est lui-même un patron, dans la déclaration du guide de déduction"
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "%<decl-specifier%> dans la déclaration du guide de déduction"
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "variable non nommée ou champ déclaré void"
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variable ou champ déclaré void"
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "spécificateur %<inline%> invalide pour la variable %qD déclarée au niveau du bloc"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "les variables « inline » sont uniquement disponibles avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT en tant que type plutôt qu'un simple %<decltype(auto)%>"
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "%<decltype(auto)%> ne peut pas être qualifié avec CV"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "utilisation invalide du nom qualifié %<::%D%>"
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "utilisation invalide du nom qualifié %<%T::%D%>"
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "utilisation invalide du nom qualifié %<%D::%D%>"
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%q#T n'est pas une classe ou un espace de noms"
 
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "déclaration de %qE comme non fonction"
 
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "déclaration de %qE comme non membre"
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "declarator-id manquant; utilisation du mot réservé %qD"
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "la définition de fonction ne déclare aucun paramètre"
 
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "déclaration de %qD comme non fonction"
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "déclaration de %qD comme %<typedef%>"
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "déclaration de %qD comme paramètre"
 
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr "%qs et %qs spécifiés tous les deux"
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%qs ne peut pas apparaître dans une déclaration typedef"
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr "au plus un seul spécificateur %<constinit%> ou %<constexpr%> peut être utilisé"
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "au moins deux types de données dans la déclaration de %qs"
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "le C++ ISO n'accepte pas qu'un simple %<complex%> signifie %<double complex%>"
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "le C++ ISO interdit la déclaration de %qs sans type"
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> n'est pas supporté par la cible"
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "le C++ ISO ne supporte pas %<__int%d%> pour %qs"
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> et %<unsigned%> spécifiés ensemble"
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> et %<short%> spécifiés ensemble"
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qs spécifié avec %qT"
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, gcc-internal-format
 msgid "%qs specified with typedef-name %qD"
 msgstr "%qs spécifié avec le nom typedef %qD"
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs spécifié avec %<decltype%>"
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qs spécifié avec %<typeof%>"
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "« complex » invalide pour %qs"
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr "liste d'arguments de patron manquante après %qE ; pour la déduction, le type à remplacer doit être suivi d'un simple declarator-id"
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "le membre %qD ne peut pas être déclaré à la fois %<virtual%> et %<static%>"
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "le membre %qD peut être déclaré à la fois %<virtual%> et %<constexpr%> uniquement avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "la déclaration typedef est invalide dans la déclaration du paramètre"
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "classe de stockage spécifiée pour le paramètre %qs du patron"
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "classe de stockage spécifiée pour le paramètre %qs"
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "un paramètre ne peut pas être déclaré %qs"
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> en dehors de la déclaration de classe"
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "la déclaration d'une liaison structurée ne peut pas être %qs"
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les déclarations de liaisons structurées peuvent être %qs uniquement en %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "la liaison structurée qualifiée avec %<volatile%> est dépréciée"
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "une déclaration de liaison structurée ne peut pas avoir le %<auto%> du C++98"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "une déclaration de liaison structurée ne peut pas avoir le type %qT"
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "le type doit être un %<auto%> qualifié avec CV ou une référence à un %<auto%> qualifié avec CV"
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "une déclaration de liaison structurée ne peut pas avoir la contrainte %<auto%> de type %qT"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "classes de stockage multiples dans la déclaration de %qs"
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "classe de stockage spécifiée pour %qs"
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "fonction imbriquée %qs déclarée %<extern%>"
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "la déclaration de %qs hors de toute fonction spécifie %<auto%>"
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs dans le champ de la fonction est implicitement déclaré auto et déclaré %<__thread%>"
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "spécificateurs de classe de stockage invalides dans les déclarations de fonctions amies"
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attribut ignoré"
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "un attribut qui appartient à un spécificateur de type est ignoré"
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "parenthèses inutiles dans la déclaration de %qs"
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr "retirez les parenthèses"
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, gcc-internal-format
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "la fonction membre objet explicite est uniquement disponible avec %<-std=c++23%> ou %<-std=gnu++23%>"
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, gcc-internal-format
 msgid "a function type cannot have an explicit object parameter"
 msgstr "un type de fonction ne peut pas avoir de paramètre objet explicite"
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, gcc-internal-format
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr "un pointeur vers un type de fonction ne peut pas avoir de paramètre d'objet explicite"
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, gcc-internal-format
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr "un pointer vers un type de fonction membre ne peut pas avoir de paramètre objet explicite"
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr "le type d'un pointeur vers une fonction membre d'objet explicite est un pointeur régulier vers un type de fonction"
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, gcc-internal-format
 msgid "the type of an explicit object member function is a regular function type"
 msgstr "le type d'une fonction membre d'un objet explicite est un type de fonction régulier"
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr "seul le premier paramètre d'une fonction membre peut être déclaré comme un paramètre objet explicite"
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "valid explicit object parameter declared here"
 msgstr "le paramètre objet explicite valide est déclaré ici"
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "clause « requires » sur le type de retour"
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "la fonction %qs utilise le spécificateur de type %<auto%> sans type de retour à la fin"
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "le type de retour déduit est uniquement disponible avec %<-std=c++14%> ou %<-std=gnu++14%>"
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "une fonction virtuelle ne peut pas avoir un type de retour déduit"
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "la fonction %qs avec un type de retour à la fin a %qT comme étant son type au lieu d'un simple %<auto%>"
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "la fonction %qs avec un type de retour à la fin a %<decltype(auto)%> comme étant son type au lieu d'un simple %<auto%>"
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "utilisation invalide de %<decltype(auto)%>"
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "type de classe %qD déduit dans le type de retour de la fonction"
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "le guide de déduction pour %qT doit avoir un type de retour à la fin"
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "le type de retour %qT à la fin du guide de déduction n'est pas une spécialisation de %qT"
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "le type de retour à la fin est uniquement disponible avec %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "la fonction %qs avec le type de retour à la fin n'est pas déclarée avec le spécificateur de type %<auto%>"
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "une fonction de conversion ne peut pas avoir de type de retour à la fin"
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "le type de retour qualifié avec %<volatile%> est déprécié"
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs déclaré comme une fonction retournant une fonction"
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs déclaré comme une fonction retournant un tableau"
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "le type de retour %<constinit%> pour une fonction n'est pas permis"
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "le destructeur ne peut être une fonction membre statique"
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "le constructeur ne peut être une fonction membre statique"
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "les destructeurs ne peuvent pas être qualifiés avec CV"
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "les constructeurs ne peuvent pas être qualifiés avec CV"
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "les destructeurs ne peuvent pas être qualifiés comme des références"
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "les constructeurs ne peuvent pas être qualifiés comme des références"
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "les constructeurs ne peuvent pas être déclarés %<virtual%>"
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "les fonctions virtuelles ne peuvent pas être amies"
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "la déclaration amie n'est pas dans la définition de la classe"
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "ne peut définir la fonction amie %qs dans une définition de classe locale"
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr "la définition de la fonction amie %qs ne peut pas avoir son nom qualifié avec %<::%>"
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr "la définition de la fonction amie %qs ne pas avoir son nom qualifié avec %<%D::%>"
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, gcc-internal-format
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr "la fonction non membre ne peut pas avoir de paramètre objet explicite"
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr "une fonction membre d'objet explicite ne peut pas être %<virtual%>"
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<static%>"
 msgstr "une fonction membre d'objet explicite ne peut pas être %<static%>"
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, gcc-internal-format
 msgid "%qD cannot be an explicit object member function"
 msgstr "%qD ne peut pas être une fonction membre d'un objet explicite"
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destructeurs ne peuvent pas avoir de paramètre"
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "ne peut déclarer un pointeur vers %q#T"
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "ne peut déclarer une référence vers %q#T"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "ne peut déclarer un pointeur vers le membre %q#T"
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "ne peut déclarer une référence vers le type de fonction qualifié %qT"
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "ne peut déclarer un pointeur vers le type de fonction qualifié %qT"
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "ne peut déclarer une référence vers %q#T qui n'est pas un typedef ou un argument vers un type d'un patron"
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD utilisé comme un déclarateur"
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "les fonctions membres sont implicitement amies de leur classe"
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "qualification %<%T::%> additionnelle sur le membre %qs"
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "ne peut définir la fonction membre %<%T::%s%> à l'intérieur de %qT"
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "ne peut déclarer la fonction membre %<%T::%s%> à l'intérieur de %qT"
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "ne peut déclarer le membre %<%T::%s%> à l'intérieur de %qT"
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "le non paramètre %qs ne peut pas être un paquet de paramètres"
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "les membres de données ne peuvent pas avoir le type %qT modifié par une variable"
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "le paramètre ne peut pas avoir le type %qT modifié par une variable"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> en dehors de la déclaration de la classe"
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> dans une déclaration amie"
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "seuls les déclarations de constructeurs et les opérateurs de conversion peuvent être %<explicit%>"
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "le non membre %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "le membre non objet %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "la fonction %qs ne peut pas être déclarée %<mutable%>"
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "%<static%> %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "%<const%> %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "la référence %qs ne peut pas être déclarée %<mutable%>"
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "typedef ne peut pas être une définition de fonction"
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "typedef ne peut pas être une définition de fonction membre"
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<auto%> n'est pas autorisé dans une déclaration de synonyme"
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef déclaré %<auto%>"
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "clause « requires » sur un typedef"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "le nom du typedef ne peut pas être un nom de spécificateur imbriqué"
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "le C++ ISO interdit le type imbriqué %qD avec le même nom que la classe englobante"
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> spécifié pour la déclaration d'une classe amie"
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "les paramètres du patron ne peuvent pas être amis"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "une déclaration amie requiert le mot-clé « class », c-à-d. %<friend class %T::%D%>"
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "une déclaration amie requiert le mot-clé « class », c-à-d %<friend %#T%>"
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "tentative de rendre amie la classe %qT au niveau de la portée globale"
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "qualificatifs invalides sur un type de fonction non membre"
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "clause « requires » sur type-id"
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "déclaration abstraite %qT utilisée comme déclaration"
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "clause « requires » dans la déclaration du type non fonction %qT"
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "ne peut utiliser %<::%> dans la déclaration d'un paramètre"
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "ne peut déclarer un paramètre avec %<decltype(auto)%>"
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr "liste d'arguments de patron manquante après %qE ; type à remplacer pour le patron non permis dans le paramètre"
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr "ou utilisez %<auto%> pour le patron de fonction abrégé"
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "le paramètre %<auto%> n'est pas permis dans ce contexte"
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "paramètre déclaré %<auto%>"
 
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "utilisation invalide du nom de patron %qE sans liste d'arguments"
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "membre de donnée non statique déclaré avec %qT comme type à remplacer"
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "le C++ ISO interdit le membre tableau flexible %qs"
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "le C++ ISO interdit les tableaux flexibles comme membres"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "utilisation invalide de %<::%>"
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "déclaration de la fonction %qD dans un contexte invalide"
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "fonction %qD déclarée %<virtual%> à l'intérieur d'une union"
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD ne peut pas être déclaré %<virtual%> puisqu'il est toujours statique"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "nom qualifié attendu dans la déclaration amie du destructeur %qD"
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "déclaration de %qD comme membre de %qT"
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "un destructeur ne peut pas être %qs"
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "nom qualifié attendu dans la déclaration amie pour le constructeur %qD"
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "un constructeur ne peut pas être un %<concept%>"
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "un concept ne peut être une fonction membre"
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%qD ne peut pas être %qs"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "spécialisation du patron de variable %qD déclaré comme une fonction"
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "le patron de variable a été déclaré ici"
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "le champ %qD a le type incomplet %qT"
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "le nom %qT a un type incomplet"
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE n'est ni une fonction ni une fonction membre; il ne peut pas être déclaré ami"
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "le champ sans nom n'est ni une fonction ni une fonction membre; il ne peut pas être déclaré ami"
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr "un attribut qui appartient à une déclaration amie qui n'est pas une définition est ignorée"
 
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "membre de donnée statique %qE déclaré %qs"
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "le membre statique %<constexpr%> %qD doit avoir une initialisation"
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "le membre de donnée non statique %qE est déclaré %qs"
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "la classe de stockage %<auto%> est invalide pour la fonction %qs"
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "la classe de stockage %<register%> est invalide pour la fonction %qs"
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "la classe de stockage %<__thread%> est invalide pour la fonction %qs"
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "la classe de stockage %<thread_local%> est invalide pour la fonction %qs"
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, gcc-internal-format
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr "le spécificateur %<constinit%> est invalide pour la fonction %qs"
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "le spécificateur de type « virt-specifier » sur %qs n'est pas permis en dehors d'une définition de classe"
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "le spécificateur %<static%> est invalide pour la fonction %qs déclarée en dehors de la portée globale"
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "le spécificateur %<inline%> est invalide pour la fonction %qs déclarée en dehors de la portée globale"
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "fonction non classe virtuelle %qs"
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs défini en dehors d'un contexte de classe"
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs déclaré en dehors d'un contexte de classe"
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "ne peut déclarer la fonction membre %qD comme ayant une classe de liaison statique"
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "ne peut déclarer une fonction statique à l'intérieur d'une autre fonction"
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> ne peut pas être utilisé lors de la définition (contrairement à la déclaration) d'un membre de donnée statique"
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "membre statique %qD déclaré %<register%>"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "ne peut explicitement déclarer le membre %q#D comme ayant une classe de liaison externe"
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "la déclaration de la variable %<constexpr%> %qD n'est pas une définition"
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "une variable ne peut pas être déclarée %<consteval%>"
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initialisé et déclaré %<extern%>"
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs a, à la fois, %<extern%> et une initialisation"
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "l'argument par défaut %qE utilise %qD"
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "l'argument par défaut %qE utilise la variable locale %qD"
 
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "utilisation invalide du type %qT qualifié CV dans la déclaration du paramètre"
 
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "utilisation invalide du type %<void%> dans la déclaration du paramètre"
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "le paramètre qualifié avec %<volatile%> est obsolète"
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "le paramètre %qD est incorrectement déclaré comme type de méthode"
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "le paramètre %qD inclut un pointeur vers un tableau %qT dont les bornes sont inconnues"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "le paramètre %qD inclut une référence vers un tableau %qT dont les bornes sont inconnues"
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "constructeur invalide; vous vouliez probablement utiliser %<%T (const %T&)%>"
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD ne peut pas être déclaré dans un espace de noms"
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD ne peut pas être déclaré statique"
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "%qD doit être une fonction membre non statique"
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "%qD doit être une fonction membre"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "%qD peut être une fonction membre statique uniquement avec %<-std=c++23%> ou %<-std=gnu++23%>"
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD doit être soit une fonction membre non statique ou une fonction non membre"
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD doit avoir un argument de type classe ou énuméré"
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "le C++ ISO interdit la surcharge de %<operator ?:%>"
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD ne doit pas avoir un nombre variables d'arguments"
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD doit avoir zéro ou un argument"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD doit avoir un ou deux arguments"
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "%qD suffixé doit avoir %<int%> comme argument"
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "%qD suffixé doit avoir %<int%> comme second argument"
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD ne doit avoir aucun argument"
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD doit avoir exactement un argument"
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD doit avoir exactement deux arguments"
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD ne peut avoir d'arguments par défaut"
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "la conversion de %qT vers %<void%> n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "la conversion de %qT en une référence vers le même type n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "la conversion de %qT vers le même type n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "la conversion de %qT en une référence vers une classe de base %qT n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "la conversion de %qT vers une classe de base %qT n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "%qD défini par l'usager évalue toujours les 2 arguments"
 
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "%qD préfixé devrait retourner %qT"
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "%qD suffixé devrait retourner %qT"
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD devrait retourner par valeur"
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "utilisation du paramètre du type de patron %qT après %qs"
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "utilisation de la spécialisation du patron d'alias %qT après %qs"
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "utilisation du nom de typedef %qD après %qs"
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD a une déclaration précédente ici"
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT référé en tant que %qs"
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT a une déclaration précédente ici"
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "il est fait référence à %qT comme un enum"
@@ -57526,116 +57541,100 @@ msgstr "il est fait référence à %qT comme un enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "argument du patron requis pour %<%s %T%>"
 
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "la référence à %qD est ambiguë"
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr "le patron de classe %qD est redéclaré comme un non patron"
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD a le même nom que la classe dans laquelle il est déclaré"
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT n'est pas un patron"
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "vous voulez peut-être ajouter %<%T::%> explicitement"
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "utilisation de l'enum %q#D sans déclaration précédente"
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redéclaration de %qT sous une forme qui n'est pas un patron"
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, gcc-internal-format
-msgid "cannot declare %qD in a different module"
-msgstr "ne peut déclarer %qD dans un module différent"
-
-# la phrase fait référence à une variable ou une fonction (cf les deux messages ci-dessus) d'où le féminin
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, gcc-internal-format
-msgid "previously declared here"
-msgstr "précédemment déclarée ici"
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "l'union dérivée %qT est invalide"
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT est défini avec des bases directes multiples"
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT est défini avec des bases virtuelles directes"
 
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "le type de base %qT n'est pas un « struct » ou une « class »"
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "type récursif %qT non défini"
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "le type de base dupliqué %qT est invalide"
 
-#: cp/decl.cc:16984
-#, gcc-internal-format
-msgid "cannot declare %qD in different module"
-msgstr "ne peut déclarer %qD dans un module différent"
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "non concordance entre un enum simple et un enum fortement typé pour %q#T"
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "définition précédente ici"
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "désaccord dans le type sous-jacent de l'enum %q#T"
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "types sous-jacents différents dans l'enum %q#T"
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "le type sous-jacent %qT de %qT doit être un type entier"
@@ -57644,83 +57643,83 @@ msgstr "le type sous-jacent %qT de %qT doit être un type entier"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "aucun type entier ne peut représenter toutes les valeurs de l'énumération pour %qT"
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "les valeurs énumérées de %qD doivent être de type entier ou une énumération simple (donc, pas fortement typée)"
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "la valeur de l'énumération pour %qD n'est pas une constante entière"
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "la valeur incrémentée de l'énumération est trop grande pour %<unsigned long%>"
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "la valeur incrémentée de l'énumération est trop grande pour %<long%>"
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "débordement dans les valeurs de l'énumération à %qD"
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "la valeur de l'énumération %qE est en dehors de la plage du type sous-jacent %qT"
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "définition multiple de %q#T"
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "le type retourné %q#T est incomplet"
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> devrait retourner une référence à %<*this%>"
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "« return » manquant dans une fonction retournant %qT"
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "seul un type de retour %<auto%> évident peut être déduit en %<void%>"
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "« return » manquant dans une fonction %<constexpr%> devant retourner une valeur"
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD est déjà défini dans la classe %qT"
 
 # le %qs est un nom de région non traduit tel que « parallel », « task », « teams ».
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, gcc-internal-format
 msgid "using %qs"
 msgstr "en utilisant %qs"
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "utilisation de %qD avant la déduction de %<auto%>"
@@ -57775,7 +57774,7 @@ msgstr "ne peut détruire une fonction.  Seuls les pointeurs vers des objets son
 msgid "deleting %qT is undefined"
 msgstr "la destruction de %qT est non définie"
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "déclaration du patron de %q#D"
@@ -57785,7 +57784,7 @@ msgstr "déclaration du patron de %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "la liste des paramètres du patron fournie ne correspond pas aux paramètres du patron de %qD"
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "le destructeur %qD est déclaré en tant que patron membre"
@@ -57969,64 +57968,64 @@ msgstr "la destruction de %<operator delete%> doit être une fonction de désall
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> prend le type %qT comme premier paramètre"
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr "%qT a un champ %q#D dont le type n'a pas de classe de liaison"
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT a un champ %qD dont le type dépend du type %qT qui n'a pas de classe de liaison"
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr "%qT a un champ %q#D dont le type a une classe de liaison interne"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr "%qT a un champ %q#D dont le type utilise l'espace de noms anonyme"
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT est déclaré avec une plus grande visibilité que le type de son champs %qD"
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, gcc-internal-format
 msgid "%qT has a base %qT which has no linkage"
 msgstr "%qT a la base %qT qui n'a pas de classe de liaison"
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, gcc-internal-format
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr "%qT a la base %qT qui dépend du type %qT qui n'a pas de classe de liaison"
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, gcc-internal-format
 msgid "%qT has a base %qT which has internal linkage"
 msgstr "%qT a la base %qT qui a une classe de liaison interne"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, gcc-internal-format
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr "%qT a la base %qT qui utilise l'espace de noms anonyme"
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT est déclaré avec une plus grande visibilité que sa base %qT"
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr "%q#D, déclaré avec un type non nommé, est utilisé mais jamais défini"
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but not defined"
 msgstr "%q#D, déclaré avec un type non nommé, est utilisé mais jamais défini"
@@ -58035,104 +58034,104 @@ msgstr "%q#D, déclaré avec un type non nommé, est utilisé mais jamais défin
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "un type non nommé sans classe de liaison est utilisé pour déclarer la variable %q#D avec une classe de liaison"
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "un type non nommé sans classe de liaison est utilisé pour déclarer la fonction %q#D avec une classe de liaison"
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q#D ne réfère pas au type non qualifié, aussi n'est-il pas utilisé pour la liaison"
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q#D, déclaré avec le type local %qT, est utilisé mais jamais défini"
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr "%q#D, déclaré avec le type local %qT, est utilisé mais pas défini ici"
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "le type %qT sans classe de liaison est utilisé pour déclarer la variable %q#D avec une classe de liaison"
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "le type %qT sans classe de liaison est utilisé pour déclarer la fonction %q#D avec une classe de liaison"
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "la décoration de %q#D qui abouti à %qE entre en conflit avec une décoration précédente"
 
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "décoration précédente de %q#D"
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, gcc-internal-format
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr "un %<-fabi-version=%> plus récent (ou =0) évite cette erreur avec un changement de décoration"
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr "le programme devrait aussi définir %qD"
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "la fonction en ligne %qD est utilisée mais n'a jamais été définie"
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q#D"
 msgstr "argument par défaut manquant pour le paramètre %P de %q#D"
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, gcc-internal-format
 msgid "...following parameter %P which has a default argument"
 msgstr "...suivant le paramètre %P qui a un argument par défaut"
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, gcc-internal-format
 msgid "implicitly-declared %qD is deprecated"
 msgstr "%qD déclaré implicitement est déprécié"
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr "car %qT a un %qD fourni par l'utilisateur"
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "conversion d'une fonction lambda qui utilise %<...%> en pointeur de fonction"
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "utilisation de la fonction supprimée %qD"
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "utilisation de la fonction %qD avec des contraintes non satisfaites"
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "utilisation du paquet de paramètres intégré %qD en dehors d'un patron"
@@ -58237,7 +58236,7 @@ msgstr "la référence à %<%T::%D%> est ambiguë"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD n'est pas un membre de %qT; vouliez-vous employer %qs ?"
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD n'est pas un membre de %qT"
@@ -58247,7 +58246,7 @@ msgstr "%qD n'est pas un membre de %qT"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD n'est pas un membre de %qD; vouliez-vous employer %qs ?"
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD n'est pas un membre de %qD"
@@ -58272,47 +58271,47 @@ msgstr "le traitement des exceptions est désactivé, utilisez %<-fexceptions%>
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr "exception générée sur un NULL avec le type entier au lieu du type pointeur"
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, gcc-internal-format
 msgid "  in thrown expression"
 msgstr "  dans l'expression de l'exception générée"
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, gcc-internal-format
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr "impossible de déclarer le paramètre de %<catch%> comme étant une r-valeur faisant référence au type %qT"
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, gcc-internal-format
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr "impossible de générer une exception de type %qT car il implique des types de taille variable"
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, gcc-internal-format
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr "impossible d'intercepter une exception de type %qT car il implique des types de taille variable"
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, gcc-internal-format
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr "une exception du type %qT sera interceptée par un gestionnaire précédent"
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, gcc-internal-format
 msgid "for type %qT"
 msgstr "pour le type %qT"
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, gcc-internal-format
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr "le gestionnaire %<...%> doit être le dernier gestionnaire de son bloc « try »"
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr "l'expression « noexcept » est évaluée à %<false%> à cause de l'appel à %qD"
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
 msgstr "mais %qD ne génère pas d'exception; peut-être devrait-il être déclaré %<noexcept%>"
@@ -58579,12 +58578,12 @@ msgstr "le type %qT n'est pas une base directe ou virtuelle de %qT"
 msgid "type %qT is not a direct base of %qT"
 msgstr "le type %qT n'est pas une base directe de %qT"
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "le tableau doit être initialisé avec une initialisation entre accolades"
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT n'est pas un type de classe"
@@ -58599,12 +58598,12 @@ msgstr "le type incomplet %qT n'a pas de membre %qD"
 msgid "invalid pointer to bit-field %qD"
 msgstr "pointeur invalide vers le champ de bits %qD"
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "utilisation invalide de la fonction membre non statique %qD"
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "utilisation invalide du membre de donnée non statique %qD"
@@ -58799,52 +58798,52 @@ msgstr "la destruction d'un objet de la classe abstraite %qT qui a un destructeu
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "la destruction d'un objet de la classe polymorphique %qT qui a un destructeur non virtuel pourrait produire un comportement indéfini"
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "le type passé au delete vectoriel n'est ni un pointeur ni un type tableau"
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr "le tableau avec une limite déterminée à l'exécution ne peut pas être capturée par copie, uniquement par référence"
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr "capture du type modifié par une variable %qT qui n'est pas un tableau N3639 avec une limite déterminée à l'exécution"
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr "car le type %qT des éléments du tableau a une taille variable"
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "ne peut capturer %qE par référence"
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "capture par copie du type incomplet %qT"
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr "tentative de capturer %qD dans une instanciation d'une lambda générique"
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr "la capture implicite de %qE via %<[=]%> est dépréciée en C++20"
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr "ajoutez la capture %<this%> ou %<*this%> explicitement"
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> n'a pas été capturé pour cette fonction lambda"
@@ -59218,224 +59217,279 @@ msgstr "format d'encapsulation ou type inattendu"
 msgid "encapsulation is malformed"
 msgstr "l'encapsulation est mal composée"
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, gcc-internal-format
 msgid "conflicting global module declaration %#qD"
 msgstr "déclaration de module global %#qD conflictuelle"
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, gcc-internal-format
 msgid "existing declaration %#qD"
 msgstr "déclaration %#qD existante"
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, gcc-internal-format
 msgid "definition of %qD does not match"
 msgstr "la définition de %qD ne concorde pas"
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, gcc-internal-format
 msgid "existing definition %qD"
 msgstr "définition %qD existante"
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, gcc-internal-format
 msgid "... this enumerator %qD"
 msgstr "... cet énumérateur %qD"
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, gcc-internal-format
 msgid "enumerator %qD does not match ..."
 msgstr "l'énumérateur %qD ne concorde pas avec ..."
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr "énumérateurs supplémentaires commençant par %qD"
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr "la plage d'énumération diffère"
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr "%q#D fait référence à l'entité avec liaison interne %q#D"
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, gcc-internal-format
 msgid "recursive lazy load"
 msgstr "chargement tardif à la demande récursif"
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr "impossible d'importer le module dans sa propre portée"
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, gcc-internal-format
 msgid "module %qs declared here"
 msgstr "le module %qs est déclaré ici"
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, gcc-internal-format
 msgid "indirect import %qs is not already loaded"
 msgstr "l'import indirect %qs n'est pas déjà chargé"
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr "l'import %qs a un CRC non concordant"
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr "impossible de représenter les emplacements sources des imports supplémentaires"
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr "pas d'export de %<#define %E%> car il est un mot-clé"
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, gcc-internal-format
 msgid "macro definitions of %qE corrupted"
 msgstr "la définition de macro de %qE est corrompue"
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, gcc-internal-format
 msgid "inconsistent imported macro definition %qE"
 msgstr "définition de macro %qE importée de manière inconsistante"
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr "%<#undef %E%>"
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr "%<#define %s%>"
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, gcc-internal-format
 msgid "compiled module file is %qs"
 msgstr "le fichier du module compilé est %qs"
 
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, gcc-internal-format, gfc-internal-format
 msgid "compiled module is %sversion %s"
 msgstr "le module compilé est %sversion %s"
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, gcc-internal-format, gfc-internal-format
 msgid "compiler is %sversion %s%s%s"
 msgstr "le compilateur est %sversion %s%s%s"
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, gcc-internal-format
 msgid "module %qs found"
 msgstr "module %qs trouvé"
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr "module d'en-tête attendu, module %qs trouvé"
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr "module %qs attendu, module d'en-tête trouvé"
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr "désaccord dans la CRC du module %qs"
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr "la cible et l'hôte sont %qs:%qs, %qs:%qs attendu"
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr "le dialecte du langage %qs diffère, %qs attendu"
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, gcc-internal-format
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr "le module contient OpenMP, utilisez %<-fopenmp%> pour l'activer"
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, gcc-internal-format
 msgid "fixed tree mismatch"
 msgstr "désaccord dans l'arbre fixe"
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, gcc-internal-format
 msgid "interface partition is not exported"
 msgstr "la partition de l'interface n'est pas exportée"
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module cluster %u: %s"
 msgstr "échec de la lecture de la grappe %u du module compilé : %s"
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module: %s"
 msgstr "échec de la lecture du module compilé : %s"
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr "envisagez d'utiliser %<-fno-module-lazy%>, augmenter la valeur de %<-param-lazy-modules=%u%> ou d'augmenter la limite des descripteurs de fichiers par processus"
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr "les imports doivent être construit avant d'être importés"
 
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr "retour à la porte pour un problème mécanique"
 
+#: cp/module.cc:19117
+#, gcc-internal-format
+msgid "declaration %qD conflicts with builtin"
+msgstr "la déclaration %qD est en conflit avec la fonction interne"
+
+#: cp/module.cc:19122
+#, fuzzy, gcc-internal-format
+#| msgid "declaration %qD conflicts with import"
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr "la déclaration %qD est en conflit avec l'import"
+
+#: cp/module.cc:19125
+#, fuzzy, gcc-internal-format
+#| msgid "declaration %qD conflicts with import"
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr "la déclaration %qD est en conflit avec l'import"
+
+#: cp/module.cc:19130
+#, fuzzy, gcc-internal-format
+#| msgid "import declared %q#D here"
+msgid "import declared attached to module %qs"
+msgstr "l'import a déclaré %q#D ici"
+
+#: cp/module.cc:19134
+#, fuzzy, gcc-internal-format
+#| msgid "import-declaration must be at global scope"
+msgid "import declared in global module"
+msgstr "la déclaration d'import doit être dans la portée globale"
+
+#: cp/module.cc:19140
+#, fuzzy, gcc-internal-format
+#| msgid "conflicting declaration of template %q#D"
+msgid "conflicting declaration of %qD in module %qs"
+msgstr "déclaration conflictuelle du patron %q#D"
+
+#: cp/module.cc:19143
+#, fuzzy, gcc-internal-format
+#| msgid "conflicting declaration of %q#D with %qL linkage"
+msgid "conflicting declaration of %qD in global module"
+msgstr "déclaration conflictuelle de %q#D avec la classe de liaison %qL"
+
+# la phrase fait référence à une variable ou une fonction (cf les deux messages ci-dessus) d'où le féminin
+#: cp/module.cc:19148
+#, fuzzy, gcc-internal-format
+#| msgid "previously declared as %s"
+msgid "previously declared in module %qs"
+msgstr "précédemment déclarée comme %s"
+
+# la phrase fait référence à une variable ou une fonction (cf les deux messages ci-dessus) d'où le féminin
+#: cp/module.cc:19152
+#, fuzzy, gcc-internal-format
+#| msgid "previously declared as %s"
+msgid "previously declared in global module"
+msgstr "précédemment déclarée comme %s"
+
 # le %qs est un nom de région non traduit tel que « parallel », « task », « teams ».
-#: cp/module.cc:19283
+#: cp/module.cc:19404
 #, gcc-internal-format
 msgid "reading CMI %qs"
 msgstr "lecture du CMI %qs"
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E%>"
 msgstr "échec du chargement de la liaison %<%E%s%E%>"
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr "échec du chargement de la liaison %<%E%s%E@%s%>"
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr "durant le chargement de la liaison %<%E%s%E%>"
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr "durant le chargement de la liaison %<%E%s%E@%s%>"
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, gcc-internal-format
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr "échec lors du chargement des pendings pour %<%E%s%E%>"
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, gcc-internal-format
 msgid "during load of pendings for %<%E%s%E%>"
 msgstr "durant le chargement des pendings pour %<%E%s%E%>"
@@ -59447,391 +59501,391 @@ msgstr "durant le chargement des pendings pour %<%E%s%E%>"
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr "import du module nommé %qs à l'intérieur d'un bloc de liaison du langage"
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, gcc-internal-format
 msgid "module already declared"
 msgstr "module déjà déclaré"
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, gcc-internal-format
 msgid "module already imported"
 msgstr "module déjà importé"
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, gcc-internal-format
 msgid "module %qs imported here"
 msgstr "module %qs importé ici"
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown Compiled Module Interface: %s"
 msgstr "Interface de module compilé inconnue : %s"
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr "impossible de déterminer la traduction %<#include%> de %s : %s"
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr "inclusion %qs traduite en import"
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr "inclusion %qs traitée textuellement"
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, gcc-internal-format
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr "les modules C++ sont incompatibles avec les en-têtes précompilés"
 
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, gcc-internal-format
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr "les modules C++ sont incompatibles avec le prétraitement traditionnel"
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr "la sortie de débogage de macro peut être incomplète avec les modules"
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr "les dépendances du module requièrent un prétraitement"
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, gcc-internal-format
 msgid "you should use the %<-%s%> option"
 msgstr "vous devriez utiliser l'option %<-%s%>"
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, gcc-internal-format
 msgid "invalid header name %qs"
 msgstr "nom d'en-tête %qs invalide"
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, gcc-internal-format
 msgid "invalid module name %qs"
 msgstr "nom de module %qs invalide"
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr "%<-fmodule-only%> utilisé pour une non-interface"
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, gcc-internal-format
 msgid "writing CMI %qs"
 msgstr "écriture CMI %qs"
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, gcc-internal-format
 msgid "not writing module %qs due to errors"
 msgstr "pas d'écriture du module %qs à cause d'erreurs"
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to write compiled module: %s"
 msgstr "échec de l'écriture du module compilé : %s"
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, gcc-internal-format
 msgid "unknown header kind %qs"
 msgstr "type d'en-tête %qs inconnu"
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, gcc-internal-format
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr "la déclaration indépendante du nom est uniquement disponible avec %<-std=c++2c%> ou %<-std=gnu++2c%>"
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "redéclaration de %q#D avec des paramètres de patron différents"
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D entre en conflit avec une déclaration précédente"
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D cache le constructeur pour %q#D"
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "déclarations conflictuelles de l'édition de liens du langage C %q#D"
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "à cause de spécifications d'exceptions différentes"
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "le paramètre lambda %qD a été déclaré précédemment comme une capture"
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "la déclaration de %q#D masque un paramètre"
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "la déclaration de %qD masque un membre de %qT"
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "déclaration amie %qD dans la classe locale sans déclaration locale antérieure"
 
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %<%s(%E)%> %p %d"
 
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d"
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, gcc-internal-format
 msgid "exporting %q#D that does not have external linkage"
 msgstr "export de %q#D qui n'a pas un lien externe"
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, gcc-internal-format
 msgid "%q#D declared here with no linkage"
 msgstr "%q#D déclaré ici sans liaison"
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, gcc-internal-format
 msgid "%q#D declared here with internal linkage"
 msgstr "%q#D déclaré ici avec un lien externe"
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, gcc-internal-format
 msgid "%q#D declared here with module linkage"
 msgstr "%q#D déclaré ici avec une liaison de module"
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T%s%D%> nomme le destructeur"
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "déclaration « using » pour un non membre au niveau de la portée de la classe"
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<using%> avec la portée énumérée %q#T uniquement disponible avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qT n'est pas une classe, un espace de noms ou une énumération"
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "la déclaration « using » non membre nomme le constructeur de %qT"
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "déclaration « using » pour un membre en dehors de la portée de la classe"
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, gcc-internal-format
 msgid "%qT is not a direct base of %qT"
 msgstr "%qT n'est pas une base directe de %qT"
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr "vouliez-vous utiliser %<using enum %T::%D%> ?"
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "%qD n'a pas été déclaré dans %qD"
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "la déclaration « using » ne peut pas nommer l'espace de nom %qD"
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> nomme le constructeur dans %qT"
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "la déclaration de %qD n'est pas dans l'espace de noms entourant %qD"
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "qualificatifs explicites dans la déclaration de %qD"
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD aurait dû être déclaré à l'intérieur de %qD"
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD n'a pas été déclaré dans %qD"
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "uniquement ici comme un %<friend%>"
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "l'attribut %qD requiert un seul argument NTBS"
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "l'attribut %qD n'a pas de signification puisque les membres de l'espace de noms anonyme obtiennent des symboles locaux"
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "l'attribut %qD est ignoré sur l'espace de noms anonyme"
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "l'attribut %qD est ignoré sur l'espace de noms pas en ligne"
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "la directive d'attribut %qD est ignorée"
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "limite maximale de %d espaces de noms recherchés pour %qE"
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "alternative suggérée:"
 msgstr[1] "alternatives suggérées:"
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr "%<std::%s%> est défini dans l'en-tête %qs ; cela peut probablement être corrigé en ajoutant %<#include %s%>"
 
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<std::%s%> est uniquement disponible à partir de %s"
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "la macro %qs n'a pas encore été définie"
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr "elle a été définie ici plus tard"
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "la déclaration de %<std::initializer_list%> ne correspond pas à %<#include <initializer_list>%> et n%'est pas un patron"
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "la directive « using » %<strong%> n'est plus supportée"
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr "vous pouvez utiliser un espace de noms en ligne à la place"
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, gcc-internal-format
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr "%<omp::%E%> ne peut pas être spécifié dans ce contexte"
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "impossible d'imbriquer plus de %d espaces de noms"
 
 # %qs est le nom d'une procédure d'où le féminin
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%<namespace %E%> est ambigu"
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "l'alias de l'espace de noms %qD n'est pas permis ici, on suppose %qD"
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "un espace de nom en ligne doit être spécifié à la définition initiale"
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD défini ici"
 
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "l'espace de noms %s %qD est en conflit avec la définition atteignable"
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "définition atteignable %s ici"
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX entre dans %<pop_everything ()%>"
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr "XXX quitte %<pop_everything ()%>"
@@ -59856,7 +59910,7 @@ msgstr "l'identificateur %qE est un mot clé en C++20"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr "%<LEXER_DEBUGGING_ENABLED_P%> n'est pas défini à vrai"
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> pas immédiatement suivi par une déclaration ou une définition de fonction"
@@ -60102,7 +60156,7 @@ msgstr "le %<constinit%> du C++20 est uniquement disponible avec %<-std=c++20%>
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<concept%> uniquement disponible avec %<-std=c++20%> ou %<-fconcepts%>"
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<requires%> uniquement disponible avec %<-std=c++20%> ou %<-fconcepts%>"
@@ -60283,7 +60337,7 @@ msgstr "les expressions-instructions ne sont pas permises en dehors des fonction
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "les expressions fold sont uniquement disponibles avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "expression primaire attendue"
@@ -60338,7 +60392,7 @@ msgstr "%<~auto%> est uniquement disponible avec %<-std=c++14%> ou %<-std=gnu++1
 msgid "template-id not allowed for destructor in C++20"
 msgstr "template-id n'est pas permis pour un destructeur en C++20"
 
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, gcc-internal-format
 msgid "remove the %qs"
 msgstr "retirez le %qs"
@@ -60358,7 +60412,7 @@ msgstr "nom du typedef %qD utilisé comme déclaration de destructeur"
 msgid "expected unqualified-id"
 msgstr "unqualified-id attendu"
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD n'est pas un patron"
@@ -60408,7 +60462,7 @@ msgstr "les types ne peuvent pas être définis dans une expression %<typeid%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_addressof%>"
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_launder%>"
@@ -60443,7 +60497,7 @@ msgstr "des types ne peuvent pas être définis dans des appels %<__builtin_clas
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr "un indice multidimensionnel ne peut pas être utilisé dans une section de tableau OpenMP"
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "utilisation invalide de %qD"
@@ -60468,7 +60522,7 @@ msgstr "le C++ ISO ne permet pas %<alignof%> avec un non type"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "les types ne peuvent pas être définis dans des expressions %<noexcept%>"
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "les types ne peuvent pas être définis dans une expression %qs"
@@ -60618,8 +60672,8 @@ msgstr "initialisation vide pour la capture par initialisation d'une fonction la
 msgid "capture of non-variable %qE"
 msgstr "capture de %qE qui n'est pas une variable"
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D déclaré ici"
@@ -60659,7 +60713,7 @@ msgstr "argument par défaut spécifié pour un paramètre lambda"
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "la déclaration d'un paramètre avant des spécificateurs de déclarations lambda est uniquement optionnelle avec %<-std=c++2b%> ou %<-std=gnu++2b%>"
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr "une lambda avec capture ne peut pas avoir un paramètre objet explicite d'un type sans rapport"
@@ -60784,7 +60838,7 @@ msgstr "%<if consteval%> requiert une instruction composée"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "l'instruction init dans des instructions de sélection est uniquement disponible avec %<-std=c++17%> ou %<-std=gnu++17%>"
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "instruction de sélection attendue"
@@ -60846,7 +60900,7 @@ msgstr "l'expression %<for%> parcourant une plage de type %qT a un type incompat
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "types différents pour « begin » et « end » de l'instruction %<for%> parcourant une plage: %qT et %qT"
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "instruction d'itération attendue"
@@ -60872,7 +60926,7 @@ msgstr "%<goto%> dans une fonction %<constexpr%> uniquement disponible avec %<-s
 msgid "ISO C++ forbids computed gotos"
 msgstr "le C++ ISO interdit les gotos calculés"
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "instruction de saut attendue"
@@ -61153,12 +61207,12 @@ msgstr "seuls les constructeurs prennent des initialisions membres"
 msgid "cannot expand initializer for member %qD"
 msgstr "impossible de développer l'initialisation du membre %qD"
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "l'initialisation en mémoire pour %qD suit la délégation du constructeur"
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "la délégation du constructeur suit l'initialisation en mémoire pour %qD"
@@ -61797,7 +61851,7 @@ msgstr "arguments de patron manquants après %qE"
 msgid "%qT not permitted in template argument"
 msgstr "%qT pas permis dans un argument de patron"
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, gcc-internal-format
 msgid "invalid use of %qT"
@@ -61976,12 +62030,12 @@ msgstr "définition précédente de %q#T"
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, gcc-internal-format
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr "paquet de paramètres non déroulés dans la classe locale d'un lambda"
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "mot-clé de type classe (class ou struct) attendu"
@@ -62184,37 +62238,37 @@ msgstr "l'attribut de préfixe « using » est uniquement disponible avec %<-s
 msgid "expression must be enclosed in parentheses"
 msgstr "l'expression doit être comprise entre parenthèses"
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr "%<requires%> additionnel manquant pour démarrer une expression « requires »"
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr "teste si un id de concept est une expression valide ; ajoutez %<requires%> pour vérifier la satisfaction"
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr "le type de résultat n'est pas un contrainte de type simple"
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "l'exigence sur le type de retour n'est pas une contrainte de type"
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "la syntaxe %<template<>%> est requise pour spécialiser %<%T::%E%>"
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "déclaration invalide de %<%T::%E%>"
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "trop peu de listes de paramètres pour le patron"
@@ -62223,437 +62277,437 @@ msgstr "trop peu de listes de paramètres pour le patron"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "trop de listes de paramètres pour le patron"
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, gcc-internal-format
 msgid "template-id not allowed for constructor in C++20"
 msgstr "template-id n'est pas permis pour un constructeur en C++20"
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "les valeurs nommées à retourner ne sont plus supportées"
 
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr "le C++ ISO n'a pas adopté les patrons d'opérateurs de chaînes littérales prenant un paquet d'arguments de caractères"
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "le patron de l'opérateur littéral %qD a une liste de paramètres invalide. On attendait un paquet de paramètres de type non patron %<<char...>%> ou un unique paramètre non-type de type class"
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "le patron de l'opérateur littéral %qD a une liste de paramètres invalide. On attendait un paquet de paramètres de type non patron tel que %<<char...>%>"
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr "les introductions de patrons ne font pas partie des concepts C++20 ; utilisez %qs pour l'activer"
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "pas de concept correspondant pour l'introduction du patron"
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "déclaration invalide du patron membre dans la classe locale"
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "patron avec liaison C"
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "spécialisation explicite invalide"
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "déclaration de patron de %<typedef%>"
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "une déclaration de patron de classe ne doit rien déclarer d'autre"
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "une spécialisation explicite de patron ne peut pas avoir une classe de stockage"
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> devrait être %<> >%> à l'intérieur d'une liste d'arguments de patron imbriqués"
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "le %<>>%> est faux, utilisez %<>%> pour terminer la liste d'arguments du patron"
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, gcc-internal-format
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr "%qs devrait être %qs pour terminer une liste d'arguments du patron"
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "l'argument %<sizeof...%> doit être entouré de parenthèses"
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "utilisation invalide de %qD dans la spécification de la classe de liaison"
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, gcc-internal-format
 msgid "duplicate %qD specifier"
 msgstr "spécificateur %qD multiple"
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, gcc-internal-format
 msgid "%qD specifier conflicts with %qs"
 msgstr "le spécificateur %qD est en conflit avec %qs"
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> avant %qD"
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, gcc-internal-format
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr "le spécificateur %qD est en conflit avec %<typedef%>"
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "le C++ ISO 1998 ne permet pas %<long long%>"
 
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "%<__thread%> et %<thread_local%> sont tous les deux spécifiés"
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "%qD dupliqué"
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs dupliqué"
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> attendu"
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> attendu"
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> attendu"
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> attendu"
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> attendu"
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> attendu"
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> attendu"
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> attendu"
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> attendu"
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> attendu"
 
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> attendu"
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> attendu"
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> attendu"
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> attendu"
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> attendu"
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "%<auto%> attendu"
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> attendu"
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> attendu"
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> attendu"
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> attendu"
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> attendu"
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> attendu"
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "%<co_yield%> attendu"
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> attendu"
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> attendu"
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> attendu"
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> attendu"
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> ou %<::%> attendu"
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> ou %<template%> attendu"
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr "clé d'énumération redondante dans %<enum%s%> en référence à %q#T"
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "étiquette %qs utilisée en nommant %q#T"
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T a été précédemment déclaré ici"
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "clé de classe %qs redondante en référence à %q#T"
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT est déclaré avec clé de classe %qs non concordante"
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr "retirez la clé de classe ou remplacez là par %qs"
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "remplacez la clé de classe avec %qs"
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "%qT est défini en tant que %qs ici"
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "%qT déclaré en tant que %qs pour la première fois ici"
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD redéclaré avec un accès différent"
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "en C++98, %<template%> (afin de lever une ambigüité) est seulement permis à l'intérieur des patrons"
 
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "fin de fichier dans l'argument par défaut"
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "construction Objective-C++ %<@%D%> mal placée"
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "récepteur de message objective-c++ attendu"
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "un ou des argument(s) de message objective-c++ est/sont attendu(s)"
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> doit spécifier un type comme un argument"
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "nom de sélecteur Objective-C++ invalide"
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "une déclaration de méthode objective-c++ est attendue"
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "les attributs de méthodes doivent être spécifiés à la fin"
 
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "%qs égaré entre des méthodes Objective-C++"
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "type invalide pour la variable d'instance"
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "identificateur attendu après %<@protocol%>"
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "des attributs ne peuvent pas être spécifiés avant le mot-clé %<@%D%> en Objective-C++"
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "les attributs de préfixes sont ignorés avant %<@%D%>"
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "type invalide pour une propriété"
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr "attribut de propriété %qE inconnu"
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "liste d'expressions entières attendue"
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "l'expression %<wait%> doit être un nombre entier"
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr "%<scalar%>, %<aggregate%> ou %<all%> attendu"
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "identificateur de réduction invalide"
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "des types ne peuvent pas être définis dans des types d'itérateurs"
@@ -62662,12 +62716,12 @@ msgstr "des types ne peuvent pas être définis dans des types d'itérateurs"
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "%<#pragma omp allocated%> n'est pas encore supporté"
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "une initialisation entre parenthèses n'est pas permise dans une boucle %<for%> de OpenMP"
@@ -62677,133 +62731,133 @@ msgstr "une initialisation entre parenthèses n'est pas permise dans une boucle
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "clause %<ordered%> avec un paramètre sur une boucle %<for%> basée sur une portée"
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "la variable d'itération %qD ne devrait pas être une réduction"
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp declare %s%> suivi de %<#pragma omp declare %s%>"
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr "la directive OpenMP autre que %<declare simd%> ou %<declare variant%> appartient à une déclaration"
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "clause d'initialisation invalide"
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "expression id (arguments) attendue"
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "un des arguments de l'appel de l'initialisation devrait être %<omp_priv%> ou %<&omp_priv%>"
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "des types ne peuvent pas être définis dans une liste de types de réductions"
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "type arithmétique %qT prédéclaré dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "type tableau ou fonction %qT dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "type référence %qT dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "un qualificatif %<const%>, %<volatile%> ou %<__restrict%> est appliqué au type %qT dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> nomme un ensemble de surcharges"
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD ne fait pas référence à une fonction à l'intérieur de l'espace de noms"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr "%<atomic_cancel%>"
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> sans avoir activé le support pour la mémoire transactionnelle"
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> sans avoir activé le support pour la mémoire transactionnelle"
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "le %<__transaction_cancel%> extérieur n'est pas à l'intérieur d'un %<__transaction_atomic%> extérieur"
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  ou une fonction %<transaction_may_cancel_outer%>"
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "%<#pragma GCC pch_preprocess%> mal composé"
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp require%> peut uniquement être utilisé dans la portée du fichier ou de l'espace de noms"
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, gcc-internal-format
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp assume%> peut uniquement être utilisé dans la portée du fichier ou de l'espace de noms"
 
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, gcc-internal-format
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr "%<#pragma GCC %s%> doit être à l'intérieur d'une fonction"
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr "la compilation multi source n'est pas implémentée pour le C++"
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "les types à remplacer ne sont pas permis dans ce contexte"
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "les patrons implicites ne peuvent pas être %<virtual%>"
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr "édition de liens %<extern \"C\"%> démarrée ici"
@@ -62833,7 +62887,7 @@ msgstr "les patrons de classe englobants ne sont pas explicitement spécialisés
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "la spécialisation de %qD doit apparaître dans la portée de l'espace de noms"
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "spécialisation de %qD dans différents espaces de noms"
@@ -62848,170 +62902,170 @@ msgstr "  à partir de la définition de %q#D"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "instanciation explicite de %qD dans l'espace de noms %qD (qui n'englobe pas l'espace de noms %qD)"
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "le nom de la classe masque le paramètre de patron %qD qui est lui-même un patron"
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "spécialisation du patron d'alias %qD"
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "spécialisation explicite du non patron %qT"
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "spécialisation de %qT après instanciation"
 
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, gcc-internal-format
 msgid "from definition of %q#D"
 msgstr "à partir de la définition de %q#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "spécialisation de %qT après instanciation %qT"
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "la spécialisation du patron de %qD n'est pas permise par le C++ ISO"
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "spécialisation de %qD après instanciation"
 
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %#qD"
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD n'est pas un patron de fonction"
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD n'est pas un patron de variable"
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "template-id %qD pour %q+D ne concorde avec aucune déclaration de patron"
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "on a vu %d %<template<>%>, on a besoin de %d pour spécialiser un patron de fonction membre"
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "spécialisation de patron %qD ambiguë pour %q+D"
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "les patrons de variables sont uniquement disponibles avec %<-std=c++14%> ou %<-std=gnu++14%>"
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "trop d'en-têtes de patrons pour %qD (devrait être %d)"
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr "des membres d'une classe spécialisée explicitement sont définis sans en-tête de patron"
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "une spécialisation explicite de %qD en dehors de son espace de noms doit utiliser un spécificateur de nom imbriqué"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "une instanciation explicite de %qD en dehors de son espace de noms doit utiliser un spécificateur de nom imbriqué"
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "il pourrait manquer des attributs dans la spécialisation explicite de %q#D"
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "attributs de patron principal %s manquant"
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "attribut de patron principal %s manquant"
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr "template-id %qE dans la déclaration de patron primaire"
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "liste de paramètres de patron utilisée dans une instanciation explicite"
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "définition fournie pour une instanciation explicite"
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "trop de listes de paramètres de patron dans la déclaration de %qD"
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "trop peu de listes de paramètres de patron dans la déclaration de %qD"
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "la spécialisation explicite de %qD doit être introduite par %<template <>%>"
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "la spécialisation explicite doit être déclarée %<concept%>"
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "la spécialisation partielle du non type %qE n'est pas permise"
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "la spécialisation partielle de la non variable ou non classe %qE n'est pas permise"
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "argument par défaut spécifié dans la spécialisation explicite"
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD n'est pas un patron de fonction"
@@ -63024,154 +63078,154 @@ msgstr "%qD n'est pas un patron de fonction"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "spécialisation d'une fonction membre spéciale déclarée implicitement"
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "pas de fonction membre %qD déclarée dans %qT"
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "la déclaration amie %qD n'est pas visible par la spécialisation explicite"
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, gcc-internal-format
 msgid "friend declaration here"
 msgstr "déclaration amie ici"
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "spécialisation explicite du concept de fonction %qD"
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "l'argument de %<__integer_pack%> doit être compris entre 0 et %d"
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "l'expansion de l'initialisation de base %qT ne contient pas de paquet de paramètres"
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "le motif d'expansion %qT ne contient pas de paquet de paramètres"
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "le motif d'expansion %qE ne contient pas de paquet de paramètres"
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "les paquets de paramètres ne sont pas étendus avec %<...%>"
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr "        %s"
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "la déclaration du paramètre de patron %q+D masque le paramètre de patron"
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "la déclaration de %q+#D masque un paramètre de patron"
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "le paramètre de patron %qD est déclaré ici"
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "spécialisation du concept de variable %q#D"
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "les paramètres du patron ne peuvent pas être déduits dans la spécialisation partielle:"
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "la spécialisation partielle %q+D ne spécialise aucun argument du patron; pour définir le patron primaire, retirez la liste d'arguments du patron"
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "la spécialisation partielle %q+D ne spécialise aucun argument du patron et n'a pas plus de contrainte que le patron primaire; pour définir le patron primaire, retirez la liste d'arguments du patron"
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "le patron primaire ici"
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "la spécialisation partielle n'est pas plus spécialisée que le patron primaire car elle remplace des paramètres multiples par une expansion d'un paquet"
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "trop d'arguments pour la spécialisation partielle %qT"
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "la spécialisation partielle de %qD n'est pas plus spécialisée que"
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "le patron primaire %qD"
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "l'argument %qE du paquet de paramètres doit être à la fin de la liste des arguments du patron"
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "l'argument %qT du paquet de paramètres doit être à la fin de la liste des arguments du patron"
 
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "le type %qT de l'argument %qE du patron dépend d'un paramètre du patron"
 msgstr[1] "le type %qT de l'argument %qE du patron dépend de paramètres du patron"
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "la déclaration de %qD rend ambigüe l'instanciation précédente du patron pour %qD"
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "spécialisation partielle de %qD après l'instanciation de %qD"
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "pas d'argument par défaut pour %qD"
@@ -63180,47 +63234,47 @@ msgstr "pas d'argument par défaut pour %qD"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "le paquet de paramètres %q+D doit être à la fin de la liste des paramètres du patron"
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans la redéclaration d'un ami d'un patron d'une fonction"
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans les déclarations d'un ami d'un patron"
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans des patrons de fonctions sans %<-std=c++11%> ou %<-std=gnu++11%>"
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans des spécialisations partielles"
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "argument par défaut pour le paramètre de patron pour la classe englobant %qD"
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "patron %qD déclaré"
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "patron de classe sans nom"
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "le patron de membre %qD ne peut pas avoir de spécificateur virtuel (virt-specifier)"
@@ -63230,506 +63284,506 @@ msgstr "le patron de membre %qD ne peut pas avoir de spécificateur virtuel (vir
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "déclaration de patron %qD invalide"
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "définition de patron d'un non patron %q#D"
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "on attendait %d niveaux de paramètres du patron pour %q#D mais on en a obtenu %d"
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "a obtenu %d paramètres de patron pour %q#D"
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "a obtenu %d paramètres de patron pour %q#T"
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  mais %d son requis"
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "les arguments du patron %qD ne correspondent pas à ceux du patron original %qD"
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "utilisez %<template<>%> pour une spécialisation explicite"
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, gcc-internal-format
 msgid "redeclaration of %qD with different constraints"
 msgstr "redéclaration de %qD avec des contraintes différentes"
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT n'est pas un type de patron"
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "spécificateurs de patron pas spécifiés dans la déclaration de %qD"
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "redéclaré avec %d paramètre dans le patron"
 msgstr[1] "redéclaré avec %d paramètres dans le patron"
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "la déclaration précédente %qD utilisait %d paramètre dans le patron"
 msgstr[1] "la déclaration précédente %qD utilisait %d paramètres dans le patron"
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "paramètre %q+#D du patron"
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "redéclaré ici comme %q#D"
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, gcc-internal-format
 msgid "redeclared here"
 msgstr "redéclaré ici"
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "déclaration du paramètre de patron %q+#D avec des contraintes différentes"
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "la déclaration originale apparaît ici"
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, gcc-internal-format
 msgid "redeclaration of %q#D with different constraints"
 msgstr "redéclaration de %q#D avec des contraintes différentes"
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE n'est pas un argument de patron valide pour le type %qT"
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "il doit être l'adresse d'une fonction avec une classe de liaison externe"
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "il doit être le nom d'une fonction avec une classe de liaison externe"
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qD n'a pas de classe de liaison"
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qD n'a pas de classe de liaison externe"
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "il doit être un pointeur vers un membre de la forme %<&X::Y%>"
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "car il est un membre de %qT"
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  n%'a pu déduire le paramètre %qD du patron"
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  les types %qT et %qT ont des qualificatifs CV incompatibles"
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  types %qT et %qT non concordants"
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  le paramètre %qD du patron n'est pas un paquet de paramètres mais l'argument %qD en est un"
 
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  l'argument %qE du patron ne correspond pas à la constante %qE qui est un pointeur vers un membre"
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE n'est pas équivalent à %qE"
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  déduction du paquet de paramètres inconsistante entre %qT et %qT"
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  types déduits conflictuels pour le paramètre %qT (%qT et %qT)"
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  valeurs déduites conflictuelles pour le paramètre non type %qE (%qE et %qE)"
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  le type tableau %qT dimensionné par une variable n'est pas un argument de patron valable"
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  le type fonction membre %qT n'est pas un argument de patron valable"
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  ne peut convertir %qE (type %qT) vers le type %qT"
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT est une classe de base ambigüe de %qT"
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT n'est pas dérivé de %qT"
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  les paramètres du patron d'un argument de patron qui est lui-même un patron sont inconsistants avec les autres arguments déduits pour le patron"
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  impossible de déduire un patron pour %qT depuis le type non patron %qT"
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "  l'argument de patron %qE ne correspond pas à %qE"
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qE n'est pas une variable ni une fonction"
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE n'est pas un argument de patron valable de type %qT en C++98 car %qD n'a pas une classe de liaison externe"
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qD n'a pas de classe de liaison"
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "l'adresse de %qD n'est pas un argument de patron valable"
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "l'adresse du sous-objet %qT de %qD n'est pas un argument de patron valable"
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "l'adresse de %qD n'est pas un argument de patron valable car elle n'a pas une durée de stockage statique"
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD n'est pas un argument de patron valable car %qD est une variable, pas une adresse d'une variable"
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE n'est pas un argument de patron valable pour %qT car ce n'est pas l'adresse d'une variable"
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car les chaînes littérales ne peuvent jamais être utilisées dans ce contexte"
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "dans l'argument de patron pour le type %qT"
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "l'argument de patron %qE pour le type %qT n'est pas une constante durant la compilation"
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT à cause de conflits dans les qualificatifs CV"
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car ce n'est pas une l-valeur"
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D n'est pas un argument de patron valable pour le type %qT car une variable de référence n'a pas une adresse constante"
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car il est un pointeur"
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "essayez d'utiliser %qE à la place"
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car il est du type %qT"
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "les attributs sur l'argument %qT du patron sont ignorés"
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "les attributs dans l'argument %qE du patron sont ignorés"
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "nom de classe injecté %qD utilisé comme argument de patron qui est lui-même un patron"
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "utilisation invalide du destructeur %qE comme un type"
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "pour faire référence à un membre type d'un paramètre de patron, utilisez %<typename %E%>"
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "non concordance de type/valeur pour l'argument %d dans la liste des paramètres du patron de %qD"
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  on attendait une constante de type %qT, on a obtenu %qT"
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "  l'argument de patron ambigu pour le paramètre de patron non type est traité comme un type fonction"
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  on attendait un patron de classe, on a obtenu %qE"
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  on attendait un type, on a obtenu %qE"
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  on attendait un type, on a obtenu %qT"
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  on attendait un patron de classe, on a obtenu %qT"
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  on attendait un patron de type %qD, on a obtenu %qT"
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "désaccord de contrainte à l'argument %d dans la liste des paramètres du patron pour %qD"
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  on attendait %qD, on a obtenu %qD"
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "impossible de convertir l'argument %qE du patron de %qT vers %qT"
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "l'argument %d du patron est invalide"
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "nombre erroné d'arguments du patron (%d, devrait être %d)"
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "nombre erroné d'arguments du patron (%d, devrait être au moins %d)"
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "fournis pour %qD"
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "argument d'expansion du paquet pour le paramètre non paquet %qD du patron d'alias %qD"
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argument d'expansion du paquet pour le paramètre non paquet %qD du concept %qD"
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "ainsi, toute instanciation avec un paquet de paramètres non vide serait mal formée"
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D n'est pas un patron de fonction"
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "type non patron %qT utilisé comme un patron"
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "pour la déclaration du patron %q+D"
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "échec de la contrainte du patron pour %qD"
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "utilisation du patron de variable invalide %qE"
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "la profondeur d'instanciation du patron excède le maximum qui est %d (utilisez %<-ftemplate-depth=%> pour augmenter le maximum)"
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "l'argument du score doit être une expression entière constante"
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "l'argument du score doit être non négatif"
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "la propriété doit être une expression entière constante ou une chaîne littérale"
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "membre tableau flexible %qD dans l'union"
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "repli de l'expansion vide sur %O"
 
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE n'est pas le motif entier de l'expansion du paquet"
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "les longueurs des paquets d'arguments sont en désaccord durant l'expansion de %qT"
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "les longueurs des paquets d'arguments sont en désaccord durant l'expansion de %qE"
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "  lors de l'instanciation de l'argument par défaut pour l'appel à %qD"
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "création d'un pointeur vers la fonction membre d'un type non classe %qT"
 
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, gcc-internal-format, gfc-internal-format
 msgid "mismatched argument pack lengths (%d vs %d)"
 msgstr "les longueurs des paquets d'arguments sont en désaccord (%d vs %d)"
@@ -63747,301 +63801,301 @@ msgstr "les longueurs des paquets d'arguments sont en désaccord (%d vs %d)"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "la variable %qD a un type fonction"
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "type de paramètre %qT invalide"
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "dans la déclaration de %q+D"
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "fonction retournant un tableau"
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "fonction retournant une fonction"
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "formation d'une référence vers void"
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "formation d'un pointeur vers le type de référence %qT"
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "formation d'une référence vers le type de référence %qT"
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "formation d'un pointeur vers le type de fonction qualifié %qT"
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "formation d'une référence vers le type de fonction qualifié %qT"
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "création d'un pointeur vers le membre d'un type non classe %qT"
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "création d'un pointeur vers le type de référence au membre %qT"
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "création d'un pointeur vers le membre de type void"
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "création d'un tableau de %qT"
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr "%qD est instancié pour un paquet vide"
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT n'est pas un type class, struct ou union"
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT est résolu en %qT qui n'est pas un type d'énumération"
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT est résolu en %qT qui n'est pas un type de classe"
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "utilisation de %qs dans le patron"
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "le type qualifié %qT ne correspond pas au nom du destructeur ~%qT"
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "le nom dépendant %qE est analysé comme un non type, mais son instanciation produit un type"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "utilisez %<typename %E%> si un type est désiré"
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "l'initialiseur pour %q#D est développé en une liste vide d'expressions"
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "utilisation invalide de l'expression d'expansion d'un paquet"
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "utilisez %<...%> pour dérouler le paquet d'arguments"
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "initialisation vide dans l'initialisation par capture de la fonction lambda"
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD n'a pas été déclaré dans cette portée et aucune déclaration a été trouvée par le recherche dépendant des arguments au point d'instanciation"
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "les déclarations dans la base dépendante %qT ne sont pas trouvées par une recherche non qualifiée"
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "utilisez plutôt %<this->%D%>"
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "utilisez plutôt %<%T::%D%>"
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD déclaré ici, plus loin dans l'unité de traduction"
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_convertvector%>"
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, gcc-internal-format
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "nombre erroné d'arguments pour l'attribut %<assume%>"
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT n'est pas une classe ou un espace de noms"
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD n'est pas une classe ou un espace de noms"
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "utilisation du champ %qD invalide"
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT est/utilise un type anonyme"
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "l'argument du patron pour %qD utilise le type local %qT"
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT est un type modifié par une variable"
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "l'expression intégrale %qE n'est pas une constante"
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  tentative d'instancier %qD"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "instanciation de patron ambiguë pour %q#T"
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "instanciation de patron ambiguë pour %q#D"
 
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instanciation explicite du non patron %q#D"
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "instanciation explicite du concept de variable %q#D"
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "instanciation explicite du concept de fonction %q#D"
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD n'est pas un membre de données statique d'un patron de classe"
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "aucun patron correspondant trouvé pour %qD"
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "le type %qT pour l'instanciation explicite %qD ne correspond pas au type déclaré %qT"
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "instanciation explicite de %q#D"
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "instanciation explicite dupliquée pour %q#D"
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "le C++ ISO 1998 interdit l'utilisation de %<extern%> sur des instanciations explicites"
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "classe de stockage %qD appliquée à l'instanciation du patron"
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instanciation explicite du patron non classe %qD"
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "instanciation explicite du type non patron %qT"
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "instanciation explicite de %q#T avant la définition de patron"
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "le C++ ISO interdit l'utilisation de %qE sur des instanciations explicites"
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "instanciation explicite dupliquée de %q#T"
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "la spécification d'exception %qD dépend d'elle-même"
@@ -64053,163 +64107,163 @@ msgstr "la spécification d'exception %qD dépend d'elle-même"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "instanciation explicite de %qD mais pas de définition disponible"
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "la profondeur d'instanciation du patron excède le maximum de %d lors de l'instanciation de %q+D, peut-être via la génération de la table virtuelle (utilisez %<-ftemplate-depth=%> pour augmenter le maximum)"
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les paramètres de patrons non typés du type classe déduit sont uniquement disponibles avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%qT n'est pas un type valide pour un paramètre non type du patron car il n'est pas structurel"
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "les paramètres de patrons non typés du type classe sont uniquement disponibles avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "le paramètre non type du patron est invalide"
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T n'est pas un type valide pour un paramètre non type du patron"
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "le mot-clé %<template%> n'est pas permis dans declarator-id"
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "un concept ne peut être contraint"
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "le concept %qE n'est pas dans la portée de l'espace de noms"
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr "le concept %qE a plusieurs listes de paramètres de patrons"
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "la déduction à partir d'une liste d'initialisation entre accolades requiert %<#include <initializer_list>%>"
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "le patron %qT ne peut être déduit et il est utilisé sans arguments de patron"
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "la déduction du patron synonyme est uniquement disponible avec %<-std=c++20%> ou %<-std=gnu++20%>"
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr "utilisez directement %qD à la place"
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "impossible de déduire les arguments du patron pour l'initialisation par copie de %qT car il n'a pas de guides de déduction non explicites ou de constructeur déclaré par l'utilisateur"
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "impossible de déduire les arguments du patron de %qT car il n'a pas de guides de déduction viables"
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "la déduction des arguments du patron de classe a échoué:"
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "les guides de déduction explicites ne sont pas pris en compte pour l'initialisation par copie"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "la déduction de l'argument du patron de classe pour %qT a échoué : guide de déduction explicite sélectionné dans l'initialisation par copie de liste"
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "guide de déduction explicite déclaré ici"
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "%qT peut ne pas avoir l'intention de supporter la déduction d'argument pour un patron de classe"
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr "ajoutez un guide de déduction pour supprimer cet avertissement"
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "l'initialisation par liste directe de %<auto%> requiert exactement un élément"
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "pour la déduction de %<std::initializer_list%>, utilisez l'initialisation par liste copiée (c-à-d ajoutez %<=%> avant le %<{%>)"
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "impossible de déduire le type de retour de la lambda à partir de %qE"
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "impossible de déduire %qT à partir de %qE"
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "les contraintes sur le type à remplacer ne sont pas satisfaites"
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "l'initialisation déduite ne satisfait pas les contraintes du type à remplacer"
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "le type retourné déduit ne satisfait pas les contraintes du type à remplacer"
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "le type déduit pour l'expression ne satisfait pas les contraintes du type à remplacer"
 
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "utilisation invalide de %qT dans un argument de patron"
@@ -64415,631 +64469,631 @@ msgstr "le type de l'opérande %<asm%> %qE n'a pas pu être déterminé"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "les déclarations %<__label__%> sont uniquement permises à l'intérieur des fonctions"
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "utilisation invalide du membre %qD dans une fonction membre statique"
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, gcc-internal-format
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr "utilisation invalide du membre %qD dans le constructeur de contrat %<pre%>"
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, gcc-internal-format
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr "utilisation invalide du membre %qD dans le destructeur de contrat %<post%>"
 
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr "%qE arguments de patron manquants"
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr "une expression-instruction est un contexte insuffisant pour la résolution d'une surcharge"
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr "impossible d'appeler un concept comme une fonction"
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "le destructeur n'accepte pas d'argument"
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, gcc-internal-format
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr "%<this%> n'est pas disponible pour les fonctions membres d'objet explicite"
 
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, gcc-internal-format
 msgid "use explicit object parameter %qs instead"
 msgstr "utilisez plutôt le paramètre objet explicite %qs"
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, gcc-internal-format
 msgid "name the explicit object parameter"
 msgstr "nom du paramètre objet explicite"
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> n'est pas disponible pour les fonctions membres statiques"
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, gcc-internal-format
 msgid "invalid use of %<this%> before it is valid"
 msgstr "utilisation invalide de %<this%> avant qu'il soit valide"
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, gcc-internal-format
 msgid "invalid use of %<this%> after it is valid"
 msgstr "utilisation invalide de %<this%> après qu'il soit valide"
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "utilisation invalide de %<this%> dans une fonction non membre"
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "utilisation invalide de %<this%> hors de toute fonction"
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "étendue de qualification invalide dans le nom du pseudo-destructeur"
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "le type qualifié %qT ne concorde pas avec le nom du destructeur ~%qT"
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE n'est pas un type %qT"
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "littéral composé du type non objet %qT"
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, gcc-internal-format
 msgid "%<auto{x}%> cannot be constrained"
 msgstr "%<auto{x}%> ne peut être contraint"
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, gcc-internal-format
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<auto{x}%> est uniquement disponible avec %<-std=c++2b%> ou %<-std=gnu++2b%>"
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "les paramètres de type du patron doivent utiliser le mot-clé %<class%> ou %<typename%>"
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "utilisation invalide du type %qT comme valeur par défaut pour un paramètre de patron qui est lui-même un patron"
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "argument par défaut invalide pour un paramètre de patron qui est un patron"
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "définition de %q#T à l'intérieur d'une liste de paramètres de patron"
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "définition invalide du type qualifié %qT"
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "spécification de classe de base invalide"
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "impossible de capturer le membre %qD d'une union anonyme"
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD n'est pas capturé"
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "la lambda n'a pas de capture par défaut"
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr "la lambda dans la classe locale %q+T ne sait pas capturer des variables du contexte englobant"
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "utilisation d'une variable locale avec un stockage automatique dans la fonction contenante"
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "utilisation d'un paramètre dans la fonction contenante"
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "utilisation du paramètre en dehors du corps de la fonction"
 
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr "arguments de patron manquants"
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "le paramètre %qD du patron, du type %qT, n'est pas permis dans une expression constante intégrale parce qu'il n'est pas d'un type intégral ou énuméré"
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "utilisation du patron de classe %qT comme expression"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "l'accès au membre %qD est ambigu dans un réseau d'héritages multiples"
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD ne peut pas apparaître dans une expression constante"
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "le type de %qE est inconnu"
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT n'est pas un type énuméré"
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr "l'index %<__type_pack_element%> n'est pas une constante entière"
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr "l'index %<__type_pack_element%> est négatif"
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is out of range"
 msgstr "l'index %<__type_pack_element%> est hors limites"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "Le paquet de paramètres %<__bases%> est uniquement valable dans la déclaration d'un patron"
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "impossible d'appliquer %<offsetof%> au destructeur %<~%T%>"
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "impossible d'appliquer %<offsetof%> à la fonction membre %qD"
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "impossible d'appliquer %<offsetof%> à la fonction membre"
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "impossible d'appliquer %<offsetof%> à un énumérateur %qD"
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr "l'utilisation de %<offsetof%> à l'intérieur du type %qT (qui ne respecte pas l'agencement standard) est supporté conditionnellement"
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, gcc-internal-format
 msgid "pointer-to-member mapping %qE not supported"
 msgstr "la correspondance d'un pointeur vers un membre %qE n'est pas supportée"
 
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "la recherche de la réduction définie par l'utilisateur est ambiguë"
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "%qE dans la clause %<reduction%> est un tableau de taille nulle"
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE a le type const pour %<reduction%>"
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "réduction définie par l'utilisateur avec une initialisation du constructeur pour la classe de base %qT"
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, gcc-internal-format
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr "modificateur autre que %<val%> spécifié dans la clause %<linear%> sur des constructions %<simd%> ou %<for%> en utilisant des modificateurs OpenMP 5.2"
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr "la clause linéaire avec le modificateur %qs est appliquée à la variable non référence ayant le type %qT"
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "clause linéaire appliquée à la variable non entière non pointeur ayant le type %qT"
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "l'expression du pas de « linear » doit être un entier"
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> est autorisé dans OpenMP uniquement dans les clauses %<declare simd%>"
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD n'est pas une variable dans la clause %qs"
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD n'est pas une variable dans la clause %<firstprivate%>"
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD n'est pas une variable dans la clause %<lastprivate%>"
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "l'expression statique %<gang%> doit être un entier"
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "la valeur statique de %<gang%> doit être positive"
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "l'expression numérique de %<gang%> doit être un entier"
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "l'expression de longueur de %<vector%> doit être un entier"
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "l'expression numérique de %<worker%> doit être un entier"
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "la valeur numérique de %<gang%> doit être positive"
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "la valeur de longueur de %<vector%> doit être positive"
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "la valeur numérique de %<worker%> doit être positive"
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "l'expression de taille des tranches d'ordonnancement doit être un entier"
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "l'expression de longueur de %qs doit être un entier"
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "l'expression de longueur %qs doit être une expression entière constante positive"
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "l'expression de %<async%> doit être un entier"
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "l'expression de %<thread_limit%> doit être un entier"
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "l'identifiant de %<device%> doit être entier"
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "l'expression de la taille des tranches de %<dist_schedule%> doit être un entier"
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD n'est pas une variable dans la clause %<aligned%>"
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE dans la clause %<aligned%> n'est ni un pointeur ni un tableau ni une référence vers un pointeur ou un tableau"
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses %<aligned%>"
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "l'expression d'alignement de la clause %<aligned%> doit être un entier"
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD n'est pas une variable dans la clause %<nontemporal%>"
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses %<nontemporal%>"
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%<this%> n'est pas autorisé dans la clause %<allocate%>"
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD n'est pas une variable dans la clause %<allocate%>"
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses %<allocate%>"
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr "%qD n'est pas une expression l-valeur ni une section de tableau dans une clause %qs"
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "patron %qE dans la clause %qs"
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "nom de fonction surchargée %qE dans la clause %qs"
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "l'expression de %<grainsize%> doit être un entier"
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "l'expression de %<priority%> doit être un entier"
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "l'expression %<hint%> doit être un nombre entier"
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "l'expression %<hint%> doit être une expression entière constante"
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, gcc-internal-format
 msgid "%<filter%> expression must be integral"
 msgstr "l'expression %<filter%> doit être un nombre entier"
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "la variable %qs n'est ni un pointeur ni une référence à un pointeur"
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "la variable %qs n'est ni un pointeur ni un tableau ni une référence à un pointeur ou un tableau"
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "l'argument de %<tile%> doit être de type entier"
 
 # Cette traduction aurait du sens si on pouvait changer l'ordre des %. Je n'arrive pas à savoir si c'est possible.
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "%<const%> qualifiant %qE sans membre %<mutable%> ne peut apparaître que dans les clauses %<shared%> ou %<firstprivate%>"
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD n'est pas un fichier, un espace de noms ou une variable déclarée dans un bloc"
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "la directive %<threadprivate%> %qE n'est pas dans la définition de %qT"
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "la différence entre %qE et %qD n'est pas un type entier"
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> utilisé avec la variable d'itération de classe %qE"
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> utilise deux expressions différentes pour la mémoire"
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr "le message de %<static_assert%> doit être une chaîne littérale ou un objet avec les membres %<size%> et %<data%>"
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr "le message de %<static_assert%> doit avoir une %<size()%> qui peut être implicitement convertie en %<std::size_t%>"
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr "le message de %<static_assert%> doit avoir une %<data()%> qui peut être implicitement convertie en %<const char *%>"
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr "le message de %<static_assert%> doit avoir une %<size()%> qui est une expression constante"
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr "le message de %<static_assert%> a une %<size()%> %qE trop grande"
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr "le message de %<static_assert%> doit avoir une %<data()[%d]%> qui est une expression constante"
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr "le message de %<static_assert%> doit avoir une %<data()%> qui est une expression constante du noyau"
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, gcc-internal-format
 msgid "static assertion failed: %.*s"
 msgstr "l'assertion statique a échoué : %.*s"
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "condition non constante pour l'assertion statique"
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "l'argument de %<decltype%> doit être une expression"
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%<decltype%> ne sait pas résoudre l'adresse d'une fonction surchargée"
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr "%<__builtin_is_pointer_interconvertible_with_class%> a besoin d'un seul argument"
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr "l'argument de %<__builtin_is_pointer_interconvertible_with_class%> n'est pas un pointeur vers un membre"
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr "%<__builtin_is_corresponding_member%> n'est pas bien défini pour des unions anonymes"
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr "%<__builtin_is_corresponding_member%> a besoin de deux arguments"
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr "l'argument de %<__builtin_is_corresponding_member%> n'est pas un pointeur vers un membre"
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "%qD n'est pas un patron de classe ou un alias"
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "l'opérande de l'expression fold n'a aucun paquet de paramètres non déroulé"
 
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "les deux arguments dans le fold binaire ont des paquets de paramètres non déroulés"
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "aucun paquet de paramètres non déroulés dans le fold binaire"
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "l'argument de %<__builtin_launder%> n'est pas un pointeur"
@@ -65047,1158 +65101,1158 @@ msgstr "l'argument de %<__builtin_launder%> n'est pas un pointeur"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr "%<__builtin_bit_cast%> a le type de destination %qT qui est un type tableau"
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr "%<__builtin_bit_cast%> a le type de destination %qT qui n'est pas trivialement copiable"
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr "%<__builtin_bit_cast%> a le type source %qT qui n'est pas trivialement copiable"
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr "%<__builtin_bit_cast%> a la taille source %qE qui n'est pas égale à la taille du type destination %qE"
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "les qualificatifs %qV ne peuvent pas être appliqués à %qT"
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "expression instruction dans une expression constante"
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr "%<-fabi-version=13%> (GCC 8.2) corrige la convention d'appel pour %qT qui a changé accidentellement en 8.1"
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr "%<-fabi-version=12%> (GCC 8.1) change accidentellement la convention d'appel pour %qT"
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, gcc-internal-format
 msgid " declared here"
 msgstr " déclaré ici"
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr "la convention d'appel pour %qT change avec %<-fabi-version=13%> (GCC 8.2)"
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr " car tous ses constructeurs par copie et déplacement sont supprimés"
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "la classe de base %qT n'est pas publique"
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, gcc-internal-format
 msgid "%qD is not public"
 msgstr "%qD n'est pas public"
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, gcc-internal-format
 msgid "%qD is mutable"
 msgstr "%qD n'est pas mutable"
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr "%qD a un type non structurel"
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr "l'attribut %qE peut uniquement être appliqué aux fonctions ou aux paramètres"
 
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr "l'argument de l'attribut %qE doit être une constante de chaîne de caractères"
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "l'attribut %qE peut uniquement être appliqué aux fonctions ou aux classes ou aux types énumérés"
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "l'attribut %qE peut uniquement être appliqué aux membres de données non statiques"
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, gcc-internal-format
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "l'attribut %qE ne peut pas être appliqué à un champ de bits"
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "l'attribut %qE ne prend pas d'argument"
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "l'attribut %qE du C++ ISO ne s'applique pas aux fonctions; il est traité comme %<[[gnu::%E]]%>"
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, gcc-internal-format
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "le %<init_priority%> demandé n'est pas une constante entière"
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "l'attribut %qE peut uniquement être utilisé sur les définitions dans la portée du fichier d'objets de type classe"
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "le %<init_priority%> %i demandé est hors des limites [0, %i]"
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "le %<init_priority%> %i demandé est réservé pour un usage interne"
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "la redéclaration de %qD ajoute l'étiquette d'ABI %qE"
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "l'attribut %qE requiert des arguments"
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "les arguments de l'attribut %qE doivent être des chaînes littérales étroites"
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "les arguments de l'attribut %qE doivent contenir des identificateurs valables"
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%c%> n'est pas un premier caractère valable pour un identificateur"
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%c%> n'est pas un caractère valable dans un identificateur"
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "attribut %qE appliqué au type %qT qui n'est ni une classe ni un enum"
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "attribut %qE appliqué à %qT après sa définition"
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "l'attribut %qE est ignoré car il est appliqué à l'instanciation du patron %qT"
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "l'attribut %qE est ignoré car il est appliqué à la spécialisation du patron %qT"
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "attribut %qE appliqué à %qD qui n'est ni une fonction ni une variable"
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "attribut %qE appliqué à la déclaration extern \"C\" %qD"
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, gcc-internal-format
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr "l'argument de l'attribut %qE doit être une expression qui est évaluée à vrai ou faux"
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "zéro comme constante de pointeur nul"
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "vérification de %<lang_*%> : échec dans %s, à %s:%d"
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "la comparaison entre des pointeurs de types distincts %qT et %qT a besoin d'un transtypage"
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "la conversion entre des pointeurs de types distincts %qT et %qT a besoin d'un transtypage"
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "l'expression conditionnelle entre des pointeurs de types distincts %qT et %qT a besoin d'un transtypage"
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "le C++ ISO interdit la comparaison entre les pointeurs de type %<void *%> et les pointeurs de fonctions"
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "le C++ ISO interdit la conversion entre les pointeurs de type %<void *%> et les pointeurs de fonctions"
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "le C++ ISO interdit l'expression conditionnelle entre les pointeurs de type %<void *%> et les pointeurs de fonctions"
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "la comparaison entre des pointeurs vers des membres de types distincts %qT et %qT a besoin d'un transtypage"
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "la conversion entre des pointeurs vers des membres de types distincts %qT et %qT a besoin d'un transtypage"
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "l'expression conditionnelle entre des pointeurs vers des membres de types distincts %qT et %qT a besoin d'un transtypage"
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "les types canoniques diffèrent pour les types identiques %qT et %qT"
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "nœud de type canonique identique pour les types différents %qT et %qT"
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "application invalide de %qs à une fonction membre"
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "application invalide de %<sizeof%> sur un champ de bits"
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "le C++ ISO interdit l'application de %<sizeof%> à une expression d'un type de fonction"
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "application invalide de %<__alignof%> sur un champ de bits"
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "le C++ ISO interdit l'application de %<__alignof%> à une expression d'un type de fonction"
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "l'argument de %<alignas%> a le type non entier %qT"
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "utilisation invalide de la fonction membre non statique de type %qT"
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "le C++ ISO interdit la conversion d'une chaîne constante vers %qT"
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "conversion obsolète de la chaîne constante vers %qT"
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "requête du membre %qD dans %qE, lequel est le type pointeur %qT (vous avez peut-être oublié d'utiliser %<->%> ?)"
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "requête du membre %qD dans %qE, lequel est de type non classe %qT"
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "utilisation invalide du membre de donnée non statique %qE"
 
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "accès invalide au membre de donnée non statique %qD dans la base virtuelle d'un objet NULL"
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "l'objet de type %qT ne correspond pas au nom du destructeur ~%qT"
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "le type devant être détruit est %qT, mais le destructeur réfère à %qT"
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "le champ %q#D peut être accessible via %q#D"
 
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T n'a pas de membre nommé %qE"
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%q#T n'a pas de membre nommé %qE; vouliez-vous utiliser %q#D ? (accessible via %q#D)"
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%q#T n'a pas de membre nommé %qE; vouliez-vous utiliser %q#D ? (pas accessible depuis ce contexte)"
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T n'a pas de membre nommé %qE; vouliez-vous utiliser %qE ?"
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> n'est pas un membre de %qT"
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT n'est pas une base de %qT"
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD n'est pas une fonction patron membre"
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT n'est pas un type pointeur vers un objet"
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "utilisation invalide de l'indexation de tableau sur un pointeur vers un membre"
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "utilisation invalide du %<*%> unaire sur un pointeur vers un membre"
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "utilisation invalide de la conversion implicite d'un pointeur vers un membre"
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr "l'opérande de gauche de %<->*%> doit être un pointeur vers une classe mais il est un pointeur vers un membre du type %qT"
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "indice manquant dans la référence du tableau"
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "l'accès indicé du tableau est déclaré %<register%>"
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "la valeur indicée n'est ni un tableau ni un pointeur"
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "objet manquant dans l'usage de %qE"
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "le C++ ISO interdit l'appel de %<::main%> depuis l'intérieur du programme"
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "il faut utiliser %<.*%> ou %<->*%> pour appeler une fonction via un pointeur vers un membre dans %<%E (...)%>, par ex: %<(... ->* %E) (...)%>"
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE ne peut pas être utilisé comme une fonction"
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD ne peut pas être utilisé comme une fonction"
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "l'expression ne peut pas être utilisée comme une fonction"
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "trop d'arguments pour le constructeur %q#D"
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "pas assez d'arguments pour le constructeur %q#D"
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "trop d'arguments pour la fonction membre %q#D"
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "trop peu d'arguments pour la fonction membre %q#D"
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "trop d'arguments pour la fonction %q#D"
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "trop peu d'arguments pour la fonction %q#D"
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "trop d'arguments pour la méthode %q#D"
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "pas assez d'arguments pour la méthode %q#D"
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "trop d'arguments pour la fonction"
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "trop peu d'arguments pour la fonction"
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "le paramètre %P de %qD a un type incomplet %qT"
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "le paramètre %P a un type incomplet %qT"
 
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, gcc-internal-format
 msgid "the address %qE will never be NULL"
 msgstr "l'adresse de %qE ne sera jamais NULL"
 
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "l'adresse de %qD ne sera jamais NULL"
 
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr "le compilateur peut supposer que l'adresse de %qE ne sera jamais NULL"
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr "comparaison du résultat de l'addition de pointeur %qE et NULL"
 
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "le compilateur peut supposer que l'adresse de %qD ne sera jamais NULL"
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr "opération au niveau des bits entre les types énumérés différents %qT et %qT"
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "l'opération au niveau des bits entre les types énumérés différents %qT et %qT est dépréciée"
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr "arithmétique entre des types énumérés différents %qT et %qT"
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "l'arithmétique entre des types énumérés différents %qT et %qT est dépréciée"
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr "comparaison du type énuméré %qT avec le type en virgule flottante %qT"
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr "comparaison du type en virgule flottante %qT avec le type énuméré %qT"
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr "la comparaison du type énuméré %qT avec le type en virgule flottante %qT est dépréciée"
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "la comparaison du type en virgule flottante %qT avec le type énuméré %qT est dépréciée"
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr "arithmétique entre le type énuméré %qT et le type en virgule flottante %qT"
 
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr "arithmétique entre le type en virgule flottante %qT et le type énuméré %qT"
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "l'arithmétique entre le type énuméré %qT et le type en virgule flottante %qT est déprécié"
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "l'arithmétique entre le type en virgule flottante %qT et le type énuméré %qT est déprécié"
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "suppose un transtypage vers le type %qT depuis la fonction surchargée"
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL utilisé en arithmétique"
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "le C++ ISO interdit la comparaison entre un pointeur et un entier"
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "les types des opérandes sont %qT et %qT"
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr "comparaison à trois voies de vecteurs"
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "comparaison ordonnée d'un pointeur avec un zéro entier (%qT et %qT)"
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr "comparaison non ordonnée sur un argument n'étant pas en virgule flottante"
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "conversion implicite de %qH vers %qI pour correspondre à d'autres opérandes de l'expression binaire"
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "les opérandes des types %qT et %qT sont invalides pour le %qO binaire"
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "le C++ ISO interdit l'utilisation d'un pointeur de type %<void *%> dans une soustraction"
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "le C++ ISO interdit l'utilisation d'un pointeur vers une fonction dans une soustraction"
 
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "le C++ ISO interdit l'utilisation d'un pointeur vers une méthode dans une soustraction"
 
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "utilisation invalide d'un pointeur vers un type incomplet dans un pointeur arithmétique"
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "prise de l'adresse du destructeur %qD"
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "prise de l'adresse du destructeur %qD"
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "utilisation invalide de %qE pour former un pointeur vers une fonction membre"
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  un qualified-id est requis"
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "les parenthèses autour de %qE ne peuvent pas être utilisées pour former un pointeur vers une fonction membre"
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "le C++ ISO interdit de prendre l'adresse d'une fonction membre non statique non qualifié ou entre parenthèses pour former un pointeur vers une fonction membre. Utilisez %<&%T::%D%>"
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr "le C++ ISO interdit de prendre l'adresse d'une fonction membre non statique non qualifié ou entre parenthèses pour former un pointeur vers une fonction membre d'un objet explicite"
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "le C++ ISO interdit de prendre l'adresse d'une fonction membre liée pour former un pointeur vers une fonction membre. Utilisez %<&%T::%D%>"
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr "le C++ ISO interdit de prendre l'adresse d'une fonction membre liée pour former un pointeur vers une fonction membre d'un objet explicite"
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, gcc-internal-format
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr "un pointeur vers une fonction membre d'un objet explicite peut seulement être formé avec %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "prise de l'adresse d'une r-valeur"
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "le C++ ISO interdit de prendre l'adresse de la fonction %<::main%>"
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "ne peut créer un pointeur vers le membre de référence %qD"
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "tentative de prendre l'adresse d'un champ de bits"
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<~%> sur une expression de type %<bool%>"
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "vouliez-vous utiliser le non logique (%<!%>) ?"
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "le C++ ISO interdit d'incrémenter un enum"
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "le C++ ISO interdit de décrémenter un enum"
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "ne peut incrémenter un pointeur vers le type incomplet %qT"
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "ne peut décrémenter un pointeur vers le type incomplet %qT"
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "le C++ ISO interdit d'incrémenter un pointeur du type %qT"
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "le C++ ISO interdit de décrémenter un pointeur du type %qT"
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr "l'expression %qs du type qualifié avec %<volatile%> est dépréciée"
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr "l'utilisation d'un opérande du type %qT dans %<operator--%> est interdite"
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr "l'utilisation d'un opérande du type %qT dans %<operator++%> est interdite en C++17"
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr "l'utilisation d'un opérande du type %qT dans %<operator++%> est dépréciée"
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "ne peut prendre l'adresse de %<this%> qui est une expression r-valeur"
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "adresse de la variable registre explicite %qD requise"
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "adresse requise pour %qD qui est déclaré %<register%>"
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "une initialisation par liste pour un type non classe ne doit pas être entre parenthèses"
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "la liste d'expressions est traitée comme une expression composée dans l'initialisation"
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "la liste d'expressions est traitée comme une expression composée dans l'initialisation mémoire"
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "la liste d'expressions est traitée comme une expression composée dans le transtypage fonctionnel"
 
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "la liste d'expressions dans « %s » est traitée comme une expression composée"
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "pas de contexte pour résoudre le type de %qE"
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "le transtypage du type %qT vers le type %qT élimine les qualificatifs"
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "utiliser %<static_cast%> pour transtyper du type %qT vers le type %qT élimine les qualificatifs"
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "utiliser %<reinterpret_cast%> pour transtyper du type %qT vers le type %qT élimine les qualificatifs"
 
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "transtypage inutile vers le type %q#T"
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "les qualificatifs de type sont ignorés sur le type résultant du transtypage"
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "%<static_cast%> invalide depuis le type %qT vers le type %qT"
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "le type classe %qT est incomplet"
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 msgid "converting from %qH to %qI"
 msgstr "conversion de %qH vers %qI"
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, gcc-internal-format
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "transtypage invalide d'une expression pr-valeur du type %qT vers le type %qT"
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 msgid "cast from %qH to %qI loses precision"
 msgstr "le transtypage de %qH vers %qI perd en précision"
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr "transtypage entre types de fonctions incompatibles de %qH vers %qI"
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "transtypage entre des pointeurs incompatibles vers des types membres de %qH vers %qI"
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "le transtypage de %qH vers %qI augmente l'alignement requis pour le type ciblé"
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "le transtypage entre un pointeur vers une fonction et un pointeur vers un objet est supporté conditionnellement"
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "transtypage invalide à partir du type %qT vers le type %qT"
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "utilisation invalide de %<const_cast%> avec le type %qT qui n'est pas un pointeur, une référence, ni un type pointeur vers une donnée membre"
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "utilisation invalide de %<const_cast%> avec le type %qT qui est un pointeur ou une référence à un type fonction"
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "%<const_cast%> invalide d'une r-valeur du type %qT vers le type %qT"
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "%<const_cast%> invalide à partir du type %qT vers le type %qT"
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "le C++ ISO interdit le transtypage vers un type tableau %qT"
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "transtypage invalide vers le type fonction %qT"
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, gcc-internal-format
 msgid "moving %qE of type %qT to itself"
 msgstr "déplacement de %qE de type %qT sur lui-même"
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr "supprime l'appel à %<std::move%>"
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  lors de l'évaluation de %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "affectation à un tableau depuis une liste d'initialisation"
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "types incompatibles dans l'affectation de %qT vers %qT"
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "tableau utilisé comme initialisation"
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "affectation de tableau invalide"
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   dans la conversion d'un pointeur vers une fonction membre"
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "conversion d'un pointeur vers un membre via la base virtuelle %qT"
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   dans la conversion d'un pointeur vers un membre"
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "conversion invalide vers le type %qT à partir du type %qT"
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "ne peut convertir %qH en %qI dans l'argument par défaut"
 
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "ne peut convertir %qH en %qI dans le passage d'argument"
 
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "ne peut convertir %qH en %qI dans l'initialisation"
 
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 msgid "cannot convert %qH to %qI in return"
 msgstr "ne peut convertir %qH en %qI dans le retour"
 
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "ne peut convertir %qH en %qI dans l'affectation"
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "le paramètre %qP de %qD pourrait être un candidat pour un attribut de format"
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "le paramètre pourrait être un candidat pour un attribut de format"
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "la cible de la conversion pourrait être une candidate pour un attribut de format"
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "la cible de l'initialisation pourrait être une candidate pour un attribut de format"
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "le membre de gauche de l'affectation pourrait être un candidat pour un attribut de format"
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "dans le passage de l'argument %P de %qD"
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "retourne une référence vers un temporaire"
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, gcc-internal-format
 msgid "returning pointer to temporary"
 msgstr "retourne un pointeur vers un temporaire"
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "retourner une %<initializer_list%> temporaire n'étend pas la durée de vie du tableau sous-jacent"
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "référence vers la variable locale %qD retournée"
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr "retourner la variable %<initializer_list%> locale %qD n'étend pas la durée de vie du tableau sous-jacent"
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "adresse de l'étiquette %qD retournée"
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "adresse de la variable locale %qD retournée"
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr "déplacer un objet temporaire empêche l'élision de la copie"
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr "déplacer un objet local dans une instruction de retour empêche l'élision de la copie"
 
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "déplacement redondant dans l'instruction de retour"
 
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, gcc-internal-format
 msgid "redundant move in initialization"
 msgstr "déplacement redondant dans l'initialisation"
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "retourne une valeur depuis un destructeur"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "ne peut retourner depuis le gestionnaire d'un try..catch sur tout le constructeur"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "retourne une valeur depuis un constructeur"
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "instruction « return » sans valeur dans une fonction retournant %qT"
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "liste d'initialisation retournée"
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "les types incohérents %qT et %qT sont déduits du type retourné par la lambda"
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "déduction incohérente pour le type de retour auto: %qT et puis %qT"
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "instruction « return » avec une valeur dans une fonction retournant %qT"
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> ne doit pas retourner NULL à moins qu'il soit déclaré %<throw()%> (ou %<-fcheck-new%> est actif)"
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, gcc-internal-format
 msgid "not eliding copy on return from %qD"
 msgstr "copie non élidée au retour de %qD"
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr "copie non élidée au retour dans %qD"
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "utilisation d'une r-valeur comme l-valeur"
@@ -66419,155 +66473,155 @@ msgstr "fonction surchargée sans information contextuelle de type"
 msgid "insufficient contextual information to determine type"
 msgstr "information contextuelle insuffisante pour déterminer le type"
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "syntaxe de constructeur utilisée mais aucun constructeur déclaré pour le type %qT"
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "la variable %<constinit%> %qD n'a pas une initialisation constante"
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "la conversion réductrice de %qE depuis %qH vers %qI est mal formée en C++11"
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "conversion réductrice de %qE depuis %qH vers %qI"
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "l'expression a une valeur constante mais elle n'est pas une expression constante du C++"
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, gcc-internal-format
 msgid "initializer-string for %qT is too long"
 msgstr "la chaîne d'initialisation pour %qT est trop longue"
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr "l'initialisation d'une classe de base du type %qT résulte en un découpage d'objet"
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, gcc-internal-format
 msgid "remove %<{ }%> around initializer"
 msgstr "enlever %<{ }%> autour d'un initialiseur"
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "impossible d'initialiser l'agrégat du type %qT avec un littéral composé"
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "initialisation manquante pour le membre %qD"
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "le membre %qD est une référence non initialisée"
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "membre %qD avec des champs de référence non initialisés"
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "l'ordre du désignateur pour le champ %qD ne correspond pas à l'ordre de la déclaration dans %qT"
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "pas de champ %qD trouvé dans l'union initialisée"
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "valeur d'index au lieu d'un nom de champ dans l'initialisation de l'union"
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "délégation de pointeur circulaire détectée"
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "l'opérande de base de %<->%> a un type non pointeur %qT"
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "le résultat de %<operator->()%> est un non pointeur"
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "l'opérande de base de %<->%> n'est pas un pointeur"
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE ne peut pas être utilisé comme pointeur de membre puisqu'il est de type %qT"
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "ne peut appliquer le pointeur membre %qE à %qE lequel est d'un type non classe %qT"
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "le pointeur vers le type membre %qT est incompatible avec le type d'objet %qT"
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "le type pointeur vers une fonction membre %qT requiert une r-valeur"
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "le type pointeur vers une fonction membre %qT requiert une l-valeur"
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "le type pointeur vers une fonction membre %qT requiert une l-valeur avant C++20"
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "transtypage fonctionnel vers le type tableau %qT"
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "%<auto(x)%> ne peut être contraint"
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<auto(x)%> est uniquement disponible avec %<-std=c++2b%> ou %<-std=gnu++2b%>"
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "l'initialisation par valeur du type référence est invalide"
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "appel à la fonction %qD qui génère une exception du type incomplet %q#T"
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "appel à une fonction qui génère une exception du type incomplet %q#T"
@@ -67545,7 +67599,7 @@ msgstr "La constante littérale BOZ à %L ne peut pas être un argument effectif
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "Les arguments de %qs à %L et %L ne peuvent pas être tous les deux des constantes littérales BOZ"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "Utilisation invalide de la constant littérale BOZ à %L"
@@ -68868,7 +68922,7 @@ msgstr "Mauvaise spécification INTENT à %C"
 msgid "deferred type parameter at %C"
 msgstr "paramètre de type différé à %C"
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Expression INTEGER scalaire attendue à %L"
@@ -69083,7 +69137,7 @@ msgstr "Le composant %qs avec CLASS à %C doit être allouable ou un pointeur"
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Le composant tableau de structures à %C doit avoir une forme explicite ou différée"
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "Le composant %qs à %C est déjà déclaré à %L"
@@ -69884,7 +69938,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr "Liste d'arguments formels attendue dans la définition de la fonction à %C"
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "L'attribut BIND(C) à %L peut uniquement être utilisé pour des variables ou des blocs communs"
@@ -70691,12 +70745,12 @@ msgstr "identical_array_ref(): dimensions incohérentes"
 msgid "are_identical_variables: Bad type"
 msgstr "are_identical_variables: Mauvais type"
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr "L'argument effectif de INTENT(%s) à %L pourrait interférer avec l'argument effectif à %L."
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr "gfc_check_dependency: on attendait une EXPR_VARIABLE"
@@ -70944,273 +70998,273 @@ msgstr "Le paramètre %qs à %L n'a pas été déclaré ou est une variable qui
 msgid "check_init_expr(): Unknown expression type"
 msgstr "check_init_expr(): Type d'expression inconnu"
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr "La fonction de spécification %qs à %L ne peut pas être une fonction-instruction"
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr "La fonction de spécification %qs à %L ne peut pas être une fonction interne"
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, gcc-internal-format
 msgid "Specification function %qs at %L must be PURE"
 msgstr "La fonction de spécification %qs à %L doit être PURE"
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr "La fonction de spécification %qs à %L ne peut pas être RECURSIVE"
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, gcc-internal-format
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr "L'argument muet %qs n'est pas autorisé dans l'expression à %L"
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr "L'argument muet %qs à %L ne peut pas être OPTIONAL"
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr "L'argument muet %qs à %L ne peut pas être INTENT(OUT)"
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr "La variable %qs ne peut pas apparaître dans l'expression à %L"
 
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, gcc-internal-format
 msgid "check_restricted(): Unknown expression type"
 msgstr "check_restricted(): Type d'expression inconnu"
 
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr "L'expression à %L doit être du type INTEGER et non %s"
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, gcc-internal-format
 msgid "Function %qs at %L must be PURE"
 msgstr "La fonction %qs à %L doit être PURE"
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr "L'expression à %L doit être un scalaire"
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr "débordement de optype_msgid :%d"
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr "Rangs incompatibles dans %s (%d et %d) à %L"
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "Forme différente pour %s à %L sur la dimension %d (%d et %d)"
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr "L'affectation à un part_ref LEN ou KIND à %L n'est pas permis"
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr "%qs à %L n'est pas une VALUE"
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal assignment to external procedure at %L"
 msgstr "Affectation illégale à une procédure externe à %L"
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "Rangs incompatibles %d et %d dans l'affectation à %L"
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "Le type de la variable est inconnu dans l'affectation à %L"
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "NULL apparaît dans le membre de droite de l'affectation à %L"
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "Une fonction avec la valeur d'un POINTER apparaît dans le membre de droite de l'affectation à %L"
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr "La constante littérale BOZ près de %L ne peut pas être assignée à la variable %qs"
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr "L'affectation à un composant KIND ou LEN d'un type paramétrisé à %L n'est pas permis"
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Types incompatibles dans l'instruction DATA à %L; tentative de conversion de %s en %s"
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "La cible de l'affectation du pointeur n'est pas un POINTER à %L"
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "%qs dans l'affectation de pointeur à %L ne peut pas être une l-valeur puisqu'il est une procédure"
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Spécification de limites attendue pour %qs à %L"
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Spécification des limites pour %qs dans une affectation de pointeur à %L"
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "Le pas ne doit pas être présent à %L"
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr "Le remappage de rang requiert une liste de spécifications %<borne-inf : borne-sup%> à %L"
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr "Liste de %<borne-inf :%> ou liste de %<borne-inf : borne-sup%> attendue à %L"
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "L'objet pointeur à %L ne sera point un co-index"
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Affectation de pointeur de procédure invalide à %L"
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Le résultat de la fonction %qs est invalide comme cible de procédure dans l'affectation du pointeur de procédure à %L"
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "L'interface abstraite %qs est invalide dans l'affectation du pointeur de procédure à %L"
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "La fonction-instruction %qs est invalide dans l'affectation du pointeur de procédure à %L"
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "La procédure interne %qs est invalide dans l'affectation du pointeur de procédure à %L"
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "L'intrinsèque %qs à %L est invalide dans une affectation du pointeur de procédure"
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "La procédure élémentaire non intrinsèque %qs est invalide dans l'affectation du pointeur de procédure à %L"
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "Désaccord dans l'affectation du pointeur de procédure à %L: désaccord dans la convention d'appel"
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "Désaccord d'interface dans l'affectation du pointeur de procédure à %L: %qs n'est pas une sous-routine"
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Interface explicite requise pour le composant %qs à %L: %s"
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Interface explicite requise pour %qs à %L: %s"
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Interface non concordante dans l'affectation du pointeur de procédure à %L: %s"
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr "La cible du pointeur de procédure %qs à %L doit être un intrinsèque, associé à l'hôte or à use, référencé ou avoir l'attribut EXTERNAL"
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr "La cible de l'affectation du pointeur ne peut pas être une constante à %L"
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr "L'objet pointeur de données à %L doit être polymorphique illimité ou être d'un type avec l'attribut BIND ou SEQUENCE pour être compatible avec une cible polymorphique illimitée"
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Types différents dans une affectation de pointeur à %L; tentative d'affecter %s à %s"
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Paramètres de type de sous-type différents dans l'affectation de pointeur à %L"
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Rangs différents dans l'affectation du pointeur à %L"
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "La cible du remappage du rang est plus petite que la taille du pointeur (%ld < %ld) à %L"
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "La cible du remappage du rang doit avoir le rang 1 ou être simplement contigüe à %L"
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "La cible du remappage du rang n'a pas le rang 1 à %L"
@@ -71218,192 +71272,192 @@ msgstr "La cible du remappage du rang n'a pas le rang 1 à %L"
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "La cible de données à %L n'aura point de co-index"
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "L'expression cible dans l'affectation de pointeur à %L doit fournir un pointeur comme résultat"
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr "Tableau de taille nulle détecté à %L où une entité avec l'attribut TARGET est attendu"
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "La cible de l'affectation du pointeur dans l'expression d'initialisation n'a pas l'attribut TARGET à %L"
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, gcc-internal-format, gfc-internal-format
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr "Chaque indice de la spécification cible à %L doit être une expression constante"
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr "Les points de départ et de fin de la sous-chaîne de spécification de cible à %L doivent être des expressions constantes"
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "La cible de l'affectation du pointeur n'est ni TARGET ni POINTER à %L"
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Mauvaise cible dans l'affectation du pointeur dans la procédure PURE à %L"
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Affectation de pointeur avec un indice de vecteur dans le membre de droite à %L"
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "La cible de l'affectation du pointeur a l'attribut PROTECTED à %L"
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr "Affectation à un pointeur contigu depuis une cible non contigüe à %L"
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "Le pointeur à %L dans l'affectation de pointeur pourrait vivre plus longtemps que la cible pointée"
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "La cible de l'initialisation de pointeur à %L ne doit pas être ALLOCATABLE"
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "La cible de l'initialisation du pointeur à %L ne doit pas avoir l'attribut TARGET"
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "La cible de l'initialisation du pointeur à %L doit avoir l'attribut SAVE"
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "La cible de l'initialisation du pointeur de procédure à %L ne peut pas être un pointeur de procédure"
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "La procédure interne %qs est invalide dans l'initialisation du pointeur de procédure à %L"
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "La procédure fictive %qs est invalide dans l'initialisation du pointeur de procédure à %L"
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr "generate_isocbinding_initializer(): mauvais type iso_c_binding, %<c_ptr%> ou %<c_funptr%> attendu"
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Fonctions pointeurs dans le contexte de la définition de variable (%s) à %L"
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Expression non variable dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Constante nommée %qs dans le contexte de la définition de variable (%s) à %L"
 
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qs dans le contexte de définition de variable (%s) à %L n'est pas une variable"
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Non POINTER dans le contexte d'association de pointeur (%s) à %L"
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Type inaccessible dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_EVENT dans un contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, gcc-internal-format
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr "Requête de paramètre %qs pour %qs dans le contexte de la définition de variable (%s) à %L"
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Argument muet %qs avec INTENT(IN) dans un contexte d'association de pointeur (%s) à %L"
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Argument muet %qs avec INTENT(IN) dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "La variable %qs est PROTECTED et ne peut pas apparaître dans le contexte d'association de pointeur (%s) à %L"
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "La variable %qs est PROTECTED et ne peut pas apparaître dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "La variable %qs ne peut pas apparaître dans le contexte de définition de variable (%s) à %L dans la procédure PURE"
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr "%qs à %L associé à la cible vecteur indexé ne peut pas être utilisé dans le contexte de définition de variable (%s)"
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "%qs à %L associé a une expression ne peut pas être utilisé dans un contexte de définition de variable (%s)"
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, gcc-internal-format
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr "%qs à %L est associé a un pointeur qui cible une fonction qui est utilisé dans un contexte de définition de variable (%s)"
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "Le nom associé %qs ne peut pas apparaître dans le contexte de définition de variable (%s) à %L car sa cible à %L ne le peut pas non plus"
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "Éléments avec la même valeur à %L et %L dans l'indice de vecteur dans le contexte de définition de variable (%s)"
@@ -71424,8 +71478,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Identifiant illégal dans copy_walk_reduction_arg"
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "Création d'un tableau temporaire à %L"
@@ -71505,7 +71559,7 @@ msgstr "La variable %qs à %L a une valeur non définie à l'intérieur de la bo
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "La variable %qs à %L n'est pas définissable à l'intérieur de la boucle commençant à %L comme argument INTENT(INOUT) de la fonction %qs"
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr "Le code pour réallouer le tableau allouable à %L sera ajouté"
@@ -71640,12 +71694,12 @@ msgstr "Le premier argument de l'affectation définie à %L doit être INTENT(OU
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Le deuxième argument de l'affection définie à %L doit être INTENT(IN)"
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Le premier argument de l'interface de l'opérateur à %L doit être INTENT(IN)"
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Le deuxième argument de l'interface de l'opérateur à %L doit être INTENT(IN)"
@@ -72515,7 +72569,7 @@ msgstr "Conversion de %s vers %s à %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "Impossible de convertir %s en %s à %L"
@@ -73066,7 +73120,7 @@ msgstr "NAMELIST %qs dans l'instruction READ à %L contient le symbole %qs qui n
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "L'objet NAMELIST %qs dans la liste de noms %qs à %L est polymorphique et requiert une procédure d'entrée/sortie définie"
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "Objet NAMELIST %qs dans la liste de noms %qs à %L avec des composants ALLOCATABLE ou POINTER"
@@ -73232,6 +73286,11 @@ msgstr "débordement de l'identificateur : %d"
 msgid "check_charlen_present(): length not set"
 msgstr "check_charlen_present(): longueur non définie"
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr ""
+
 #: fortran/match.cc:118
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
@@ -73633,7 +73692,7 @@ msgstr "Le code STOP à %L doit être un caractère par défaut avec KIND=%d"
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "Le code STOP à %L doit être un entier par défaut avec KIND=%d"
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr "Le spécificateur QUIET à %L doit être un scalaire LOGICAL"
@@ -74156,83 +74215,83 @@ msgstr "erreur d'analyse dans l'instruction SELECT TYPE à %C"
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "Le sélecteur dans SELECT TYPE à %C n'est pas une variable nommée; utilisez associate-name=>"
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr "Instruction SELECT RANK à %C"
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr "Le sélecteur de SELECT RANK à %C doit être une variable de rang tacite"
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "erreur d'analyse dans l'instruction SELECT RANK à %C"
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Instruction CASE inattendue à %C"
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Erreur de syntaxe dans la spécification CASE à %C"
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Instruction TYPE IS inattendue à %C"
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr "La spécification de type ne spécifiera point un type dérivé d'une séquence ou un type avec l'attribut BIND dans SELECT TYPE à %C [F2003:C815]"
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr "Tous les paramètres de type LEN dans l'instruction TYPE IS à %C doivent être ASSUMED"
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Erreur de syntaxe dans la spécification TYPE IS à %C"
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Erreur de syntaxe dans la spécification CLASS IS à %C"
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr "Instruction RANK inattendue à %C"
 
 # %s est toujours « INTEGER » et rien d'autre
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "L'expression SELECT RANK CASE à %C doit être une constante entière scalaire"
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr "La valeur de l'expression SELECT RANK CASE à %C ne peut pas être inférieure à zéro ou plus grande que %d"
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr "Erreur de syntaxe dans la spécification RANK à %C"
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "Instruction ELSEWHERE à %C pas englobée dans un bloc WHERE"
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "L'étiquette %qs à %C ne correspond pas à l'étiquette %qs de WHERE"
@@ -75651,8 +75710,8 @@ msgstr "Le paramètre de la clause ORDERED est plus petit que COLLAPSE à %L"
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr "la clause ORDER ne doit pas être utilisée avec ORDERED à %L"
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "La clause IF à %L requiert une expression LOGICAL scalaire"
@@ -78026,12 +78085,12 @@ msgstr "L'intrinsèque %qs déclaré INTRINSIC à %L n'est pas disponible avec l
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "La procédure non RECURSIVE %qs du module %s s'appelle peut-être elle-même récursivement dans la procédure %qs. Déclarez la RECURSIVE ou utilisez %<-frecursive%>"
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "La procédure non RECURSIVE %qs à %L semble s'appeler elle-même récursivement. Déclarez la RECURSIVE ou utilisez %<-frecursive%>"
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "L'étiquette %d référencée à %L n'est jamais définie"
@@ -78151,7 +78210,7 @@ msgstr "Déclaration explicite manquante avec l'attribut EXTERNAL pour le symbol
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "La fonction %qs à %L n'a pas de type IMPLICIT, vouliez-vous employer %qs ?"
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "La fonction %qs à %L n'a pas de type IMPLICIT"
@@ -78552,281 +78611,287 @@ msgstr "La variable de type tacite %s à %L n'aura point de référence à un so
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "La variable de rang tacite %s à %L n'aura point de référence à un sous-objet"
 
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, gcc-internal-format
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr "La variable scalaire %qs a une référence à un tableau à %L"
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable %qs, utilisée dans une expression de spécification, est référencée à %L avant l'instruction ENTRY dans laquelle elle est un paramètre"
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable %qs est utilisée à %L avant l'instruction ENTRY dans laquelle elle est un paramètre"
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Sous-objet polymorphique d'un objet co-indexé à %L"
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Objet co-indexé avec un sous-composant allouable polymorphique à %L"
 
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "L'utilisation de la variable %qs à %L est obsolète"
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Bad array reference at %L"
+msgid "Invalid array reference at %L"
+msgstr "Mauvaise référence à un tableau à %L"
+
+#: fortran/resolve.cc:6433
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr "%qs à %L est associé à l'hôte à %L dans une procédure contenue avec une procédure interne du même nom"
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "Erreur dans l'appel avec type lié à %L"
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "L'objet passé à %L doit être scalaire"
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "L'objet de base pour l'appel de composant pointeur de procédure à %L est du type ABSTRACT %qs"
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "L'objet de base pour l'appel de procédure liée au type à %L est du type ABSTRACT %qs"
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "L'objet de base pour l'appel de procédure liée au type NOPASS à %L doit être scalaire"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Aucune liaison spécifique correspondante pour l'appel à GENERIC %qs à %L"
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs à %L devrait être une SUBROUTINE"
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs à %L devrait être une FUNCTION"
 
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Mauvais type d'expression"
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s à %L doit être un scalaire"
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s à %L doit être un entier"
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s à %L doit être INTEGER"
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "L'expression de pas dans la boucle DO à %L ne peut pas être zéro"
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "La boucle DO à %L sera exécutée zéro fois"
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "La boucle DO à %L est indéfinie car elle déborde"
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "La boucle DO à %L est indéfinie car elle déborde vers le bas"
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "Le nom d'index FORALL à %L doit être un INTEGER scalaire"
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "L'expression de départ de FORALL à %L doit être un INTEGER scalaire"
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "L'expression de fin de FORALL à %L doit être un INTEGER scalaire"
 
 # %s est toujours « INTEGER » et rien d'autre
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "L'expression de pas de FORALL à %L doit être un %s scalaire"
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "L'expression de pas de FORALL à %L ne peut pas être zéro"
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "L'index %qs de FORALL ne peut pas apparaître dans une spécification de triplet à %L"
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "L'objet allouable à %L doit être ALLOCATABLE ou un POINTER"
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Objet allouable co-indexé à %L"
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "L'expression source à %L doit être scalaire ou avoir le même rang que l'objet allouable à %L"
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "L'expression source à %L et l'objet allouable à %L doivent avoir la même forme"
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Le type de l'entité à %L a un type incompatible avec l'expression source à %L"
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "L'objet allouable à %L et l'expression source à %L auront le même paramètre de sous-type"
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "L'expression source à %L n'aura ni le type LOCK_TYPE ni un composant LOCK_TYPE si l'objet allouable à %L est un co-tableau"
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "L'expression source à %L n'aura ni le type EVENT_TYPE ni un composant EVENT_TYPE si l'objet allouable à %L est un co-tableau"
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "L'allocation de %s du type de base ABSTRACT à %L requiert une spécification de type ou une expression source"
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "L'allocation de %s à %L avec la spécification de type requiert la même longueur de caractères dans le paramètre que dans la déclaration"
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Spécification de tableau requise dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Une spécification de tableau ou une expression SOURCE= avec une valeur tableau est requise dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Spécification de co-tableau requise dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Mauvaise spécification de co-tableau dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr "La co-borne supérieure est plus petite que la co-borne inférieure à %L"
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr "La co-borne supérieure est plus petite que la co-borne inférieure 1 à %L"
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Mauvaise spécification de tableau dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs ne doit pas apparaître dans la spécification de tableau à %L dans la même instruction ALLOCATE où il est lui-même alloué"
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "%<*%> attendu dans la spécification du co-index dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "La variable stat à %L doit être une variable INTEGER scalaire"
 
 # les deux %s sont le même mot-clé "ALLOCATE" ou "DEALLOCATE" utilisés une fois comme mot et comme instruction, merde les mecs, ils pourraient faire attention aux traducteurs…
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable stat à %L ne sera point qualifiée par %s dans la même instruction %s"
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG à %L est inutile sans la balise STAT"
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "La variable ERRMSG à %L sera une variable CHARACTER du scalaire par défaut"
 
 # les deux %s sont le même mot-clé "ALLOCATE" ou "DEALLOCATE" utilisés une fois comme mot et comme instruction, merde les mecs, ils pourraient faire attention aux traducteurs…
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable errmsg à %L ne sera point qualifiée par %s dans la même instruction %s"
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "L'objet alloué à %L apparaît aussi à %L"
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "L'objet alloué à %L est un sous-objet d'un objet à %L"
@@ -78835,284 +78900,284 @@ msgstr "L'objet alloué à %L est un sous-objet d'un objet à %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "L'étiquette CASE à %L chevauche l'étiquette CASE à %L"
 
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "L'expression dans l'instruction CASE à %L doit être du type %s"
 
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "L'expression dans l'instruction CASE à %L doit être du sous-type %d"
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "L'expression dans l'instruction CASE à %L doit être scalaire"
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "L'expression de sélection dans le GOTO calculé à %L doit être une expression entière scalaire"
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "L'argument de l'instruction SELECT à %L ne peut pas être %s"
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "L'argument de l'expression SELECT à %L doit être une expression scalaire"
 
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "L'expression dans l'instruction CASE à %L n'est pas dans la plage de %s"
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "Le DEFAULT CASE à %L ne peut pas être suivi par un second DEFAULT CASE à %L"
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Une plage logique n'est pas permise dans l'instruction CASE à %L"
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "La valeur logique constante est répétée dans l'instruction CASE à %L"
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "La spécification d'étendue à %L ne peut jamais correspondre à quoi que ce soit"
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Le bloc SELECT CASE logique à %L a plus de deux cas"
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "L'entité associante %qs à %L est un pointeur de procédure"
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Le type dérivé %qs ne peut pas être utilisé comme une variable à %L"
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "L'entité associante %qs à %L est un nom de procédure"
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr "L'expression de sélecteur associant à %L donne une procédure"
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Le sélecteur à %L ne peut pas NULL()"
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Le sélecteur à %L n'a pas de type"
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Le nom associé %qs à %L est utilisé comme tableau"
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "Le sélecteur CLASS à %L a besoin d'un temporaire qui n'est pas encore implémenté"
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Le sélecteur sera polymorphique dans l'instruction SELECT TYPE à %L"
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Le sélecteur à %L ne doit pas être co-indexé"
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS à %L chevauche TYPE IS à %L"
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Le type dérivé %qs à %L doit être extensible"
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Le type dérivé %qs à %L doit être une extension de %qs"
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Type intrinsèque %qs inattendu à %L"
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "La spécification de type à %L doit spécifier que chaque paramètre de type de longueur est tacite"
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Bloc CLASS IS en double dans l'instruction SELECT TYPE à %L"
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr "RANK DEFAULT à %L est répété à %L"
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr "RANK (*) à %L est répété à %L"
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr "RANK (%i) à %L est répété à %L"
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr "RANK (*) à %L ne peut pas être utilisé avec un pointeur ou un sélecteur allouable à %L"
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Contexte invalide pour l'intrinsèque NULL () à %L"
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "La procédure DTIO %s à %L doit être récursive"
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas être polymorphique à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants POINTER à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants de pointeur de procédure"
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants ALLOCATABLE à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants PRIVATE"
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants PRIVATE à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "L'élément de transfert de données à %L ne peut pas être une référence complète à un tableau de taille tacite"
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "La variable verrou à %L doit être un scalaire de type LOCK_TYPE"
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "La variable d'événement à %L doit être un scalaire de type EVENT_TYPE"
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "L'argument variable d'événement à %L doit être un co-tableau ou co-indexé"
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "L'argument variable d'événement à %L doit être un co-tableau mais pas co-indexé"
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "L'argument STAT= à %L doit être une variable INTEGER scalaire"
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "L'argument ERRMSG= à %L doit être une variable CHARACTER scalaire"
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "L'argument ACQUIRED_LOCK= à %L doit être une variable LOGICAL scalaire"
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "L'argument UNTIL_COUNT= à %L doit être une expression INTEGER scalaire"
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "L'argument imageset à %L doit être une expression scalaire ou INTEGER de rang 1"
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "L'argument imageset à %L doit être entre 1 et num_images()"
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "L'instruction à %L n'est pas une instruction cible valable pour l'instruction de branchement à %L"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Le branchement à %L peut conduire à une boucle infinie"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "L'instruction GOTO à %L quitte une construction CRITICAL pour l'étiquette à %L"
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "L'instruction GOTO à %L quitte une construction DO CONCURRENT pour l'étiquette à %L"
@@ -79120,212 +79185,212 @@ msgstr "L'instruction GOTO à %L quitte une construction DO CONCURRENT pour l'é
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "L'étiquette à %L n'est pas dans le même bloc que l'instruction GOTO à %L"
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "Le masque WHERE à %L a une forme inconsistante"
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "La cible de l'affectation WHERE à %L a une forme inconsistante"
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Affectation définie par l'utilisateur non ELEMENTAL dans WHERE à %L"
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Instruction non supportée à l'intérieur de WHERE à %L"
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Affectation à une variable d'index FORALL à %L"
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "Le FORALL avec l'index %qs n'est pas utilisé dans le membre de gauche de l'affectation à %L et, par conséquent, pourrait causer de multiples affectations à cet objet"
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "Construction FORALL à %L"
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "Le nom d'index de FORALL à %L doit être une variable scalaire de type entier"
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Une construction de boucle FORALL extérieure a déjà un index avec ce nom à %L"
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "La clause WHERE/ELSEWHERE à %L requiert un tableau LOGICAL"
 
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Mauvais type de bloc"
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr "La variable dans l'assignation ordinaire à %L est un composant pointeur de procédure"
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, gcc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr "L'expression CHARACTER sera tronquée dans l'affectation (%wd/%wd) à %L"
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "L'expression co-indexée à %L est affectée à une variable de type dérivé avec un composant POINTER dans une procédure PURE"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr "Dans un sous-programme pure, un argument fictif INTENT(IN) ne sera point utilisé comme l'expression à %L d'une instruction d'affectation intrinsèque dans laquelle la variable est d'un type dérivé si le type dérivé a un composant pointeur à n'importe quel niveau de la sélection du composant."
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Affectation à une variable co-indexée à %L dans une procédure PURE"
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "L'affectation à un co-tableau polymorphique à %L n'est pas permise"
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Affectation à une variable polymorphique allouable à %L"
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "L'affectation à une variable polymorphique allouable à %L requiert %<-frealloc-lhs%>"
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr "La variable non allouable ne doit pas être polymorphique dans l'affectation intrinsèque à %L – vérifiez qu'il existe une sous-routine spécifique correspondante pour l'opérateur %<=%>"
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "La variable co-indexée ne doit pas avoir un composant ultimement allouable dans l'affectation à %L"
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "À FAIRE: la/les affectation(s) liée(s) au type à %L n'ont pas été réalisées car des références multiples à des parties de tableaux apparaîtraient dans des expressions intermédiaires."
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Affectation à une procédure pointeur à %L"
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Le résultat de la fonction dans le membre de gauche de l'affectation à %L doit avoir l'attribut pointeur."
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "L'argument TEAM de %qs à %L doit être une expression scalaire de type TEAM_TYPE"
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "L'argument TEAM NUMBER pour FROM TEAM à %L doit être un INTEGER scalaire"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "L'instruction ASSIGNED GOTO à %L requiert une variable INTEGER scalaire"
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Une étiquette cible n'a pas été affectée à la variable %qs à %L"
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "L'instruction RETURN alternatif à %L requiert un spécificateur de retour SCALAR-INTEGER"
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "Assignation intrinsèque attendue dans OMP WORKSHARE à %L"
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "L'instruction ASSIGN à %L requiert une variable scalaire INTEGER par défaut"
 
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "NULL invalide à %L"
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "L'instruction IF arithmétique à %L requiert une expression scalaire REAL ou INTEGER"
 
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Pas d'expression dans le DO WHILE"
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "La condition de sortie de la boucle DO WHILE à %L doit être une expression LOGICAL scalaire"
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "La clause de masque FORALL à %L requiert une expression scalaire LOGICAL"
 
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Mauvais code d'instruction"
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "L'utilisation du paramètre %qs déclaré à %L est obsolète"
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "La variable %qs avec l'étiquette de liaison %qs à %L utilise le même identificateur global que l'entité à %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "La variable %qs du module %qs avec l'étiquette de liaison %qs à %L utilise le même identificateur global que l'entité à %L du module %qs"
@@ -79333,1001 +79398,1001 @@ msgstr "La variable %qs du module %qs avec l'étiquette de liaison %qs à %L uti
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "La procédure %qs avec l'étiquette de liaison %qs à %L utilise le même identificateur global que l'entité à %L"
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "La longueur de chaîne à %L est trop grande"
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Le tableau allouable %qs à %L doit avoir une forme différée ou un rang tacite"
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "L'objet scalaire %qs à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Le pointeur tableau %qs à %L doit avoir une forme différée ou un rang tacite"
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Le tableau %qs à %L ne peut pas avoir une forme différée"
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Le type %qs de la variable CLASS %qs à %L n'est pas extensible"
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "La variable CLASS %qs à %L doit être muette, allouable ou pointeur"
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Le type %qs ne peut pas être associé à un hôte à %L car il est bloqué par un objet incompatible du même nom déclaré à %L"
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "SAVE implicite pour la variable module %qs à %L, nécessaire à cause de l'initialisation par défaut"
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "L'entité %qs à %L a un paramètre de type différé et requiert soit l'attribut POINTER ou ALLOCATABLE"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Le tableau %qs à %L du module ou du programme principal doit avoir une forme constante"
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "L'entité avec une longueur de caractère tacite à %L doit être un argument muet ou un PARAMETER"
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs à %L doit avoir une longueur de caractère constante dans ce contexte"
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "La variable COMMON %qs à %L doit avoir une longueur de caractère constante"
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "L'allouable %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "L'externe %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Le muet %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "L'intrinsèque %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Le résultat de fonction %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Le tableau automatique %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s à %L"
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "La fonction-instruction %qs avec une valeur de caractère à %L doit avoir une longueur constante"
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs est d'un type PRIVATE et ne peut pas être un argument muet de %qs, qui est PUBLIC à %L"
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "La procédure %qs dans l'interface PUBLIC %qs à %L prend des arguments muets de %qs qui est PRIVATE"
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "La fonction %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "L'objet externe %qs à %L ne peut pas avoir d'initialisation"
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "La fonction ELEMENTAL %qs à %L doit avoir un résultat scalaire"
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "La fonction-instruction %qs à %L ne peut pas avoir l'attribut pointeur ou allouable"
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas avoir la valeur d'un tableau"
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas avoir la valeur d'un pointeur"
 
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas être pure"
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas être récursive"
 
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Fonction CHARACTER(*) %qs à %L"
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Le pointeur de procédure %qs à %L ne sera point élémental"
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "La procédure muette %qs à %L ne sera point élémentale"
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "La variable résultat %qs de la fonction à %L de la fonction élémentale %qs n'aura point l'attribut ALLOCATABLE ou POINTER"
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut SAVE dans %qs à %L"
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut INTENT dans %qs à %L"
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut RESULT dans %qs à %L"
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "L'attribut EXTERNAL est en conflit avec l'attribut FUNCTION dans %qs à %L"
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Le résultat du pointeur de procédure %qs à %L n'a pas d'attribut pointeur"
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Désaccord sur l'attribut ELEMENTAL entre MODULE PROCEDURE à %L et son interface dans %s"
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Désaccord sur l'attribut PURE entre MODULE PROCEDURE à %L et son interface dans %s"
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Désaccord sur l'attribut RECURSIVE entre MODULE PROCEDURE à %L et son interface dans %s"
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s entre la déclaration MODULE PROCEDURE dans MODULE %qs et la déclaration à %L dans (SUB)MODULE %qs"
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr "L'interface de %qs à %L doit être explicite"
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "La procédure FINAL %qs à %L n'est pas une SUBROUTINE"
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "La procédure FINAL à %L doit avoir exactement un argument"
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "L'argument de la procédure FINAL à %L doit être du type %qs"
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr "La procédure FINAL à %L avec un argument de rang tacite doit être le seul finaliseur avec le même genre/type (F2018: C790)"
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être un POINTER"
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être OPTIONAL"
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être INTENT(OUT)"
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "La procédure FINAL non scalaire à %L devrait avoir un argument de forme tacite"
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "La procédure FINAL %qs déclarée à %L a le même rang (%d) que %qs"
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr "Seules des procédures FINAL tableaux déclarées pour le type dérivé %qs à %L, une scalaire est également suggérée à moins qu'un finaliseur de rang tacite a été déclaré"
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs et %qs ne peuvent pas être FUNCTION/SUBROUTINE mixte pour GENERIC %qs à %L"
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs et %qs pour GENERIC %qs à %L sont ambigus"
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Liaison spécifique %qs non définie comme cible du GENERIC %qs à %L"
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs à %L doit cibler une liaison spécifique, %qs est GENERIC aussi"
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC %qs à %L ne peut écraser la liaison spécifique avec le même nom"
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "L'opérateur lié au type à %L ne peut pas être NOPASS"
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs doit être une procédure de module ou une procédure externe avec une interface explicite à %L"
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "La procédure %qs avec PASS(%s) à %L n'a pas d'argument %qs"
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "La procédure %qs avec PASS à %L doit avoir au moins un argument"
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Argument muet passé comme objet non polymorphique de %qs à %L"
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être du type dérivé %qs"
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être du type paramétré dérivé %qs"
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr "Tous les paramètres de type LEN de l'argument muet %qs de %qs à %L doivent être ASSUMED."
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "L'argument muet de type objet passé de %qs à %L doit être scalaire"
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "L'argument muet de type objet passé de %qs à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "L'argument muet de type objet passé de %qs à %L ne peut pas être POINTER"
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "La procédure %qs à %L a le même nom qu'un composant de %qs"
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "La procédure %qs à %L a le même nom qu'un composant hérité de %qs"
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Le type dérivé %qs déclaré à %L doit être ABSTRACT car %qs est DEFERRED et pas redéfini"
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Le composant co-tableau %qs à %L doit être allouable avec une forme différée"
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Le composant %qs à %L ayant TYPE(C_PTR) ou TYPE(C_FUNPTR) ne sera point un co-tableau"
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Le composant %qs à %L avec le composant co-tableau sera un scalaire non pointeur, non allouable"
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Le composant %qs à %L a l'attribut CONTIGUOUS mais n'est pas un pointeur de tableau"
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Le composant %qs du type BIND(C) à %L doit avoir la longueur un"
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Le composant pointeur de procédure %qs avec PASS(%s) à %L n'a pas d'argument %qs"
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Le composant pointeur de procédure %qs avec PASS à %L doit avoir au moins un argument"
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être du type dérivé %qs"
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être scalaire"
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L ne peut pas avoir l'attribut POINTER"
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Le composant %qs de %qs à %L a le même nom qu'une procédure liée au type héritée"
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "La longueur de caractère du composant %qs doit être une expression de spécification constante à %L"
 
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "L'expression de longueur de caractère du composent %qs à %L doit être du type INTEGER et non %s"
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Le composant caractère %qs de %qs à %L avec une longueur différée doit être POINTER ou ALLOCATABLE"
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "le composant %qs est un type PRIVATE et ne peut pas être un composant de %qs, qui est PUBLIC à %L"
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Le composant polymorphique %s à %L dans le type %s SEQUENCE ou BIND(C)"
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Le composant %s du type SEQUENCE déclaré à %L n'a pas l'attribut SEQUENCE"
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Initialisations conflictuelles dans l'union à %L et %L"
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Puisque l'extension du type %qs à %L a un composant co-tableau, le type parent %qs en aura un aussi"
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Le type dérivé non extensible %qs à %L ne peut pas être ABSTRACT"
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Le type paramétrisé %qs n'a pas de composant correspondant au paramètre %qs à %L"
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Nom générique %qs de la fonction %qs à %L étant le même nom que le type dérivé à %L"
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Le type dérivé %qs à %L n'a pas été déclaré"
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Le tableau de taille tacite %qs dans la liste de noms %qs à %L n'est pas permis"
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Objet tableau NAMELIST %qs avec la forme tacite dans la liste de noms %qs à %L"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Objet tableau NAMELIST %qs avec la forme non constante dans la liste de noms %qs à %L"
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Objet NAMELIST %qs avec une longueur de caractère non constante dans la liste de noms %qs à %L"
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a été déclaré PRIVATE et ne peut pas être membre de la liste de noms PUBLIC %qs à %L"
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a des composants PRIVATE associés à USE et ne peut pas être membre de la liste de noms %qs à %L"
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a des composants PRIVATE et ne peut pas être un membre de la liste de noms PUBLIC %qs à %L"
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut NAMELIST dans %qs à %L"
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Le tableau paramètre %qs à %L ne peut pas être automatique ou de forme différée"
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Le PARAMETER %qs implicitement typé à %L ne concorde pas avec le type IMPLICIT ultérieur"
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Type dérivé incompatible dans PARAMETER à %L"
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "La variable CLASS %qs à %L ne peut pas avoir l'attribut PARAMETER"
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "L'entité %qs à %L a un paramètre LEN différé %qs et requiert soit l'attribut POINTER ou soit l'attribut ALLOCATABLE"
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "L'objet AUTOMATIC %qs à %L ne doit pas avoir l'attribut SAVE ou être une variable déclarée dans le programme principal, un module ou un sous-module(F08/C513)"
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "L'objet %qs à %L avec des paramètres de type ASSUMED doit être fictif ou un sélecteur SELECT TYPE(F08/4.2)"
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Désolé, les composants allouables/pointeurs dans des co-tableaux de types polymorphiques (CLASS) à %L ne sont pas supportés"
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr "%<omp_all_memory%>, déclaré à %L, peut uniquement être utilisé dans la clause OpenMP DEPEND"
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "L'attribut PROTECTED est en conflit avec l'attribut EXTERNAL à %L"
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut PROTECTED à %L"
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs à %L a l'attribut CONTIGUOUS mais il n'est pas un pointeur de tableau ou un tableau de forme tacite ou de rang tacite"
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Mauvaise spécification pour le tableau de taille tacite à %L"
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Le tableau de taille tacite à %L doit être un argument muet"
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Le tableau de forme tacite à %L doit être un argument muet"
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Le tableau de rang tacite à %L doit être un argument muet"
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Le tableau de rang tacite à %L ne peut pas avoir les attributs VALUE ou CODIMENSION"
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Le symbole à %L n'est pas une variable MUETTE"
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs à %L ne peut pas avoir l'attribut VALUE car ce n'est pas un argument muet"
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "La variable muette caractère %qs à %L avec l'attribut VALUE doit avoir une longueur constante"
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "La variable muette caractère %qs, interopérable avec le C, à %L avec l'attribut VALUE doit avoir la longueur un"
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Le type dérivé %qs à %L est du type %qs qui n'a pas été défini"
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera un argument muet"
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera du type TYPE(*) ou d'un type intrinsèque numérique"
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK ne peut pas avoir les attributs ALLOCATABLE, CODIMENSION, POINTER ou VALUE"
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK ne peut pas avoir l'attribut INTENT(OUT)"
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera soit un scalaire ou un tableau de taille tacite"
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Le type tacite de la variable %s à %L est uniquement permis pour des variables muettes"
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable de type tacite %s à %L ne peut pas avoir les attributs ALLOCATABLE, CODIMENSION, POINTER ou VALUE"
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "La variable de type tacite %s à %L ne peut pas avoir l'attribut INTENT(OUT)"
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "La variable de type tacite %s à %L ne sera point un tableau de forme explicite"
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "La variable %qs à %L ne peut pas être BIND(C) car elle n'est ni un bloc COMMON ni déclarée au niveau du module"
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "La variable BIND(C) %qs à %L doit avoir la longueur un"
 
 # %s est soit « parameter » ou « variable » sans traduction
 # voir bug #80195
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs à %L du type dérivé PRIVATE %qs"
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "La variable %s à %L du type LOCK_TYPE ou avec un sous-composant de type LOCK_TYPE doit être un co-tableau"
 
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "La variable %s à %L du type EVENT_TYPE ou avec un sous-composant du type EVENT_TYPE doit être un co-tableau"
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "L'argument muet INTENT(OUT) %qs à %L est ASSUMED SIZE et, par conséquent, ne peut pas avoir une initialisation par défaut"
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "L'argument muet %qs à %L qui est LOCK_TYPE ne sera point INTENT(OUT)"
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "L'argument muet %qs à %L qui est EVENT_TYPE ne sera point INTENT(OUT)"
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Le résultat %qs de la fonction à %L ne sera point un co-tableau et n'aura point un composant co-tableau"
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "La variable %qs à %L du TYPE(C_PTR) ou TYPE(C_FUNPTR) ne sera point un co-tableau"
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "La variable %qs à %L avec un composant co-tableau doit être un scalaire non pointeur, non allouable qui n'est pas un co-tableau"
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "La variable %qs à %L est un co-tableau qui n'est pas ALLOCATABLE, SAVE ni un argument muet"
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "La variable co-tableau %qs à %L n'aura pas de co-dimensions avec une forme différée"
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "La variable co-tableau allouable %qs à %L doit avoir une forme différée"
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "La variable %qs à %L est INTENT(OUT) et ne peut donc pas être un co-tableau allouable ou avoir des composants co-tableaux"
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "La variable muette co-tableau %qs à %L n'est pas permise dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Argument muet LOGICAL %qs à %L avec le sous-type non C_Bool dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Variable résultat LOGICAL %qs à %L avec le sous-type non C_Bool dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "La liste de noms %qs ne peut pas être un argument de la sous-routine ou de la fonction à %L"
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Le threadprivate à %L n'est pas sauvegardé avec SAVE"
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "La variable !$OMP DECLARE TARGET %qs à %L n'est pas sauvegardée avec SAVE"
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "Entité définissable attendue près de %L"
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "L'élément BLOCK DATA %qs à %L doit être dans COMMON"
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "Le tableau DATA %qs à %L doit être spécifié dans une déclaration précédente"
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "L'élément DATA %qs à %L ne peut pas avoir un co-index"
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "L'élément DATA %qs à %L est un pointeur et doit donc être un tableau à part entière"
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr "L'objet DATA près de %L a l'attribut pointeur et la valeur DATA correspondante n'est pas une cible de donnée initiale valable"
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "L'élément DATA %qs à %L ne peut pas avoir l'attribut ALLOCATABLE"
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Section de tableau non constante à %L dans l'instruction DATA"
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "L'instruction DATA à %L a plus de variables que de valeurs"
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant character length at %L in DATA statement"
 msgstr "Longueur de caractère non constante à %L dans l'instruction DATA"
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Le début de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "La fin de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Le pas de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "le pas de la boucle DO implicite à %L ne sera point zéro"
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "L'instruction DATA à %L a plus de valeurs que de variables"
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "L'étiquette %d à %L est définie mais non utilisée"
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "L'étiquette %d à %L est définie mais ne peut pas être utilisée"
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L doit avoir l'attribut SEQUENCE pour être un objet EQUIVALENCE"
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L ne peut pas avoir des composants ALLOCATABLE pour être un objet EQUIVALENCE"
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "La variable de type dérivé %qs à %L avec une initialisation par défaut ne peut pas être dans une EQUIVALENCE avec une variable dans COMMON"
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L avec un ou des composants pointeurs ne peut pas être dans un objet EQUIVALENCE"
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Erreur de syntaxe dans l'instruction EQUIVALENCE à %L"
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Soit aucun ou tous les objets dans l'ensemble EQUIVALENCE à %L aura l'attribut PROTECTED"
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Le membre %qs du bloc COMMON à %L ne peut pas être un objet EQUIVALENCE dans la procédure pure %qs"
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "La constante nommée %qs à %L ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Le tableau %qs à %L avec des limites non constantes ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Le composant de structure %qs à %L ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "La sous-chaîne à %L a une longueur zéro"
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Référence à elle-même dans l'expression de longueur de caractère pour %qs à %L"
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fonction PUBLIC %qs à %L du type PRIVATE %qs"
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs à %L n'a pas de type IMPLICIT"
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "La procédure opérateur utilisateur %qs à %L doit être une FUNCTION"
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "La procédure opérateur utilisateur %qs à %L ne peut pas être une longueur de caractère tacite"
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "La procédure opérateur utilisateur %qs à %L doit avoir au moins un argument"
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Le premier argument de l'interface opérateur à %L ne peut pas être optionnel"
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Le deuxième argument de l'interface opérateur à %L ne peut pas être optionnel"
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "L'interface opérateur à %L doit avoir, au plus, deux arguments"
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "La procédure contenue %qs à %L d'une procédure PURE doit aussi être PURE"
@@ -80871,127 +80936,127 @@ msgstr "La variable %qs implicitement déclarée à %L peut ne pas être interop
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr "Le résultat de la fonction %qs à %L n'a pas de type IMPLICIT"
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr "L'attribut %s est en conflit avec l'attribut %s à %L"
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, gcc-internal-format
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr "L'attribut %s est en conflit avec l'attribut %s dans %qs à %L"
+
+#: fortran/symbol.cc:508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr "L'attribut %s n'est pas permis dans le BLOCK DATA de l'unité de programme à %L"
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "Le nom de groupe de la liste de noms à %L ne peut pas avoir l'attribut SAVE"
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, gcc-internal-format
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr "La procédure interne %qs à %L est en conflit avec l'argument DUMMY"
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "Pointeur de procédure à %C"
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "Attribut %s appliqué à %s %s à %L"
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) appliqué à %s %s à %L"
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, gcc-internal-format, gfc-internal-format
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr "L'attribut %s est en conflit avec l'attribut %s à %L"
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, gcc-internal-format
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr "L'attribut %s est en conflit avec l'attribut %s dans %qs à %L"
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "Impossible de changer les attributs du symbole associé à USE à %L"
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "Impossible de changer les attributs du symbole %s associé à USE à %L"
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "Attribut %s spécifié en double à %L"
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr "ALLOCATABLE spécifié en dehors du corps de INTERFACE à %L"
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr "Attribut AUTOMATIC spécifié en double à %L"
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "CODIMENSION spécifié pour %qs en dehors du corps de son INTERFACE à %L"
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "DIMENSION spécifié pour %qs en dehors du corps de son INTERFACE à %L"
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "Le pointé Cray à %L apparaît dans plusieurs instructions pointer()"
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "Attribut PROTECTED spécifié en double à %L"
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "L'attribut SAVE à %L ne peut pas être spécifié dans une procédure PURE"
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "Attribut SAVE spécifié en double à %L"
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "Attribut SAVE spécifié en double à %L"
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Attribut VOLATILE spécifié en double à %L"
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr "L'attribut VOLATILE à %L ne peut pas être spécifié dans une procédure PURE"
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Attribut ASYNCHRONOUS spécifié en double à %L"
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "L'attribut %s de %qs est en conflit avec l'attribut %s à %L"
 
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -81000,203 +81065,203 @@ msgstr ""
 "La procédure %s à %L est déjà déclarée comme procédure %s.\n"
 "F2008: Une affectation à une fonction pointeur est ambigüe si elle est la première instruction exécutable après la spécification du bloc. Veuillez ajouter n'importe quel autre type d'instruction exécutable avant elle. FIXME"
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "La procédure %s à %L est déjà déclarée comme procédure %s"
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) est en conflit avec INTENT(%s) à %L"
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "La spécification ACCESS à %L a déjà été spécifiée"
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "L'attribut BIND est spécifié en double à %L"
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "BIND(C) à %L"
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "L'attribut EXTENDS est spécifié en double à %L"
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "EXTENDS à %L"
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Le symbole %qs à %L a déjà une interface explicite"
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "%qs à %L a des attributs spécifiés en dehors du corps de son INTERFACE"
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "Le symbole %qs à %L est en conflit avec le symbole du module %qs, associé à USE à %L"
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Le symbole %qs à %L a déjà le type de base %s"
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "La procédure %qs à %L ne peut pas avoir le type de base %s"
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Le symbole %qs à %L ne peut pas avoir de type"
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Le composant %qs à %C est déjà dans le type parent à %L"
 
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Le symbole %qs à %C est ambigu"
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Le type dérivé %qs à %C est utilisé avant sa définition"
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Le composant %qs à %C est un composant PRIVATE de %qs"
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "%qs à %C n'est pas un membre de la structure %qs; vouliez-vous employer %qs ?"
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs à %C n'est pas un membre de la structure %qs"
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Étiquette d'instruction %d dupliquée à %L et %L"
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "L'étiquette %d à %C est déjà référencée comme cible d'un branchement"
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "L'étiquette %d à %C est déjà référencée comme une étiquette de format"
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr "Instruction de fin de DO qui n'est pas END DO ou CONTINUE avec l'étiquette %d à %C"
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Étiquette %d à %C précédemment utilisée comme étiquette de FORMAT"
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Étiquette %d à %C précédemment utilisée comme cible de branchement"
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "Étiquette de fin de DO %d partagée à %C"
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr "Instruction DO étiquetée à %L"
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Le nom %qs à %C est une référence ambigüe à %qs depuis le module %qs"
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "Le nom %qs à %C est une référence ambigüe à %qs depuis l'unité de programme actuelle"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Le symbole %qs à %C a déjà été associée à un hôte"
 
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr "verify_bind_c_derived_type(): Le symbole donné est NULL de manière inattendue"
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Le type dérivé %qs, déclaré à %L, doit avoir l'attribut BIND pour être interopérable avec le C"
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "Le type dérivé %qs avec l'attribut BIND(C) à %L est vide et peut être inaccessible pour le processeur C compagnon"
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Le composant %qs à %L ne peut pas avoir l'attribut POINTER car il est un membre du type dérivé BIND(C) %qs à %L"
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "Le composant pointeur de procédure %qs à %L ne peut pas être un membre du type dérivé BIND(C) %qs à %L"
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Le composant %qs à %L ne peut pas avoir l'attribut ALLOCATABLE car il est un membre du type dérivé BIND(C) %qs à %L"
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "Le composant %qs dans le type dérivé %qs à %L peut ne pas être interopérable avec le C bien que le type dérivé %qs soit BIND(C)"
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "Le composant %qs dans le type dérivé %qs à %L peut ne pas être interopérable avec le C"
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Le type dérivé %qs à %L ne peut pas avoir l'attribut SEQUENCE car il est BIND(C)"
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "Le symbole %qs est utilisé à %L avant qu'un type lui soit assigné"
@@ -81226,24 +81291,24 @@ msgstr "Initialisations inégales et se chevauchant dans EQUIVALENCE à %L"
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "Initialisations inégales et se chevauchant dans EQUIVALENCE à %C"
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr "Le constructeur de structure à %C a été finalisé. Cette fonctionnalité a été enlevée par f08/0011. Utilisez -std=f2018 ou -std=gnu pour éliminer la finalisation."
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "Le nombre d'éléments dans le constructeur du tableau à %L requiert une augmentation de la limite supérieure permise %d. Voyez l'option %<-fmax-array-constructor%>"
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Création d'un temporaire pour le tableau à %L dans l'argument %qs"
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "mauvais type d'expression durant le parcours (%d)"
@@ -81429,37 +81494,37 @@ msgstr "La valeur de retour %qs de la fonction %qs est déclarée à %L mais ne
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr "Désolé, !$ACC DECLARE à %L n'est pas permis dans une construction BLOCK"
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr "Impossible de calculer la longueur du tableau de caractères à %L."
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr "Du code pour réallouer la variable allouable à %L va être ajouté"
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Désolé, un accès co-indexé à un objet polymorphique illimité à %L n'est pas supporté"
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Désolé, un accès co-indexé à un composant polymorphique illimité à %L n'est pas supporté"
 
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Op intrinsèque inconnue"
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Fonction de liste d'arguments inconnue à %L"
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr "Si le remappage des limites est spécifié à %L, la cible du pointeur ne sera point NULL"
@@ -81470,17 +81535,17 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "Fonction intrinsèque %qs (%d) non reconnue"
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "L'argument %<dim%> de l'intrinsèque %s à %L n'est pas un index de dimension valide"
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "Désolé, le composant de l'événement du type dérivé à %L n'est pas encore supporté"
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "La variable d'événement à %L ne sera point co-indexée"
@@ -81620,7 +81685,7 @@ msgstr "Désolé, le composant verrou du type dérivé à %L n'est pas encore su
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr "Désolé, seul le support pour les entiers du sous-type %d est implémenté pour l'ensemble d'images à %L"
 
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr "gfc_trans_select(): Mauvais type pour l'expression case"
@@ -81986,6 +82051,12 @@ msgstr "variable %qD redéclarée comme une fonction"
 msgid "function %qD redeclared as variable"
 msgstr "fonction %qD redéclarée comme une variable"
 
+# la phrase fait référence à une variable ou une fonction (cf les deux messages ci-dessus) d'où le féminin
+#: lto/lto-symtab.cc:865
+#, gcc-internal-format
+msgid "previously declared here"
+msgstr "précédemment déclarée ici"
+
 #: lto/lto.cc:174
 #, gcc-internal-format
 msgid "%<lto_obj_file_open()%> failed"
@@ -83223,7 +83294,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr "%<-fobjc-sjlj-exceptions%> est ignoré pour %<-fgnu-runtime%>"
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, gcc-internal-format
 msgid "non-objective-c type %qT cannot be caught"
 msgstr "le type non-objective-c %qT ne peut être intercepté"
@@ -83233,7 +83304,7 @@ msgstr "le type non-objective-c %qT ne peut être intercepté"
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr "%<-fobjc-sjlj-exceptions%> est le seul système d'exceptions supporté pour %<-fnext-runtime%> avec un argument de %<-fobjc-abi-version%> inférieur à 2"
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, gcc-internal-format
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
 msgstr "%<-fobjc-sjlj-exceptions%> est ignoré pour %<-fnext-runtime%> lorsque %<-fobjc-abi-version%> est plus grand que 1"
@@ -83303,6 +83374,14 @@ msgstr "paramètre %qE inutilisé"
 msgid "are you trying to break %s? how dare you?"
 msgstr "essayez-vous de casser %s ? Comment osez vous ?"
 
+#, gcc-internal-format
+#~ msgid "cannot declare %qD in a different module"
+#~ msgstr "ne peut déclarer %qD dans un module différent"
+
+#, gcc-internal-format
+#~ msgid "cannot declare %qD in different module"
+#~ msgstr "ne peut déclarer %qD dans un module différent"
+
 #, no-c-format
 #~ msgid "turn on quadruple tracing (internal switch)"
 #~ msgstr "activer le traçage quadrupôle (commutateur interne)."
diff --git a/gcc/po/hr.po b/gcc/po/hr.po
index 61a7d208da1..ef271ee8572 100644
--- a/gcc/po/hr.po
+++ b/gcc/po/hr.po
@@ -3,13 +3,13 @@
 # This file is distributed under the same license as the gcc package.
 #
 # Tomislav Krznar <tomislav.krznar@gmail.com>, 2012, 2022.
-# Božidar Putanec <bozidarp@yahoo.com>, 2022, 2023.
+# Božidar Putanec <bozidarp@yahoo.com>, 2022, 2023, 2024.
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 14.1.0\n"
+"Project-Id-Version: gcc 14.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
-"PO-Revision-Date: 2024-05-09 18:08-0700\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
+"PO-Revision-Date: 2024-08-02 17:19+0200\n"
 "Last-Translator: Božidar Putanec <bozidarp@yahoo.com>\n"
 "Language-Team: Croatian <lokalizacija@linux.hr>\n"
 "Language: hr\n"
@@ -387,7 +387,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr "nemojte istovremeno specificirati -march=... i -mcpu=..."
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 msgid "shared and mdll are not compatible"
 msgstr ""
 
@@ -19171,16 +19171,16 @@ msgstr "neprepoznati insn:"
 msgid "insn does not satisfy its constraints:"
 msgstr "insn ne zadovoljava svoja ograničenja:"
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "stvoren i korišten s različitim postavkama ‘%s”"
 
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "stvoren i korišten s različitim postavkama %<-fpic%>"
 
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 msgid "created and used with different settings of %<-fpie%>"
 msgstr "stvoren i korišten s različitim postavkama of %<-fpie%>"
 
@@ -19503,7 +19503,7 @@ msgstr ""
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "nepodržani operand za kȏd ‘%c’"
@@ -19522,9 +19522,9 @@ msgstr "nevaljani operand za ‘%%%c’"
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, c-format
 msgid "invalid vector constant"
 msgstr "nevaljana vektorska konstanta"
@@ -19544,7 +19544,7 @@ msgstr "nekompatibilan operand za ‘%%%c’"
 msgid "incompatible register operand for '%%%c'"
 msgstr "nekompatibilan operand registra za ‘%%%c’"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, c-format
 msgid "missing operand"
 msgstr "nema operanda"
@@ -19573,93 +19573,93 @@ msgstr "nevaljani način adresiranja"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "ne mogu se kombinirati GNU i SVE vektori u binarnoj operaciji"
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "‘%%&’ je upotrebljen bez ikakve dinamičke TLS referencije"
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, c-format
 msgid "invalid %%J value"
 msgstr "nevaljana %%J vrijednost"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, c-format
 msgid "invalid %%r value"
 msgstr "nevaljana %%r vrijednos"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, c-format
 msgid "invalid %%R value"
 msgstr "nevaljana %%R vrijednost"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, c-format
 msgid "invalid %%N value"
 msgstr "nevaljana %%N vrijednost"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, c-format
 msgid "invalid %%P value"
 msgstr "nevaljana %%P vrijednost"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, c-format
 msgid "invalid %%h value"
 msgstr "nevaljana %%h vrijednost"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, c-format
 msgid "invalid %%L value"
 msgstr "nevaljana %%L vrijednost"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, c-format
 msgid "invalid %%m value"
 msgstr "nevaljana %%m vrijednost"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, c-format
 msgid "invalid %%M value"
 msgstr "nevaljana %%M vrijednost"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, c-format
 msgid "invalid %%U value"
 msgstr "nevaljana %%U vrijednost"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, c-format
 msgid "invalid %%s value"
 msgstr "nevaljana %%s vrijednost"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, c-format
 msgid "invalid %%C value"
 msgstr "nevaljana %%C vrijednost"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, c-format
 msgid "invalid %%E value"
 msgstr "nevaljana %%E vrijednost"
 
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "nepoznata relokacija unspec"
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, c-format
 msgid "invalid %%xn code"
 msgstr "nevaljani %%xn kȏd"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, c-format
 msgid "invalid operand address"
 msgstr "nevaljani operand adrese"
@@ -19752,35 +19752,35 @@ msgstr "nevaljani UNSPEC kao operand: %d"
 msgid "unrecognized supposed constant"
 msgstr "neprepoznata pretpostavljena konstanta"
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, c-format
 msgid "invalid shift operand"
 msgstr "nevaljani operand pomaka (shift)"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "predviđena Thumb instrukcija"
 
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "predviđena instrukcija u uvjetnoj sekvenciji"
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Nepodržani operand za kȏd ‘%c’"
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -19788,113 +19788,113 @@ msgstr "Nepodržani operand za kȏd ‘%c’"
 msgid "invalid operand for code '%c'"
 msgstr "nevaljani operand za kȏd ‘%c’"
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, c-format
 msgid "instruction never executed"
 msgstr "instrukcija nije nikada izvršena"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "zastarjela Maverick format kȏd ‘%c’"
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "nevaljana konverzija od tipa %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "nevaljana konverzija u tip %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "nelegalna operacija na tipu %<bfloat16_t%>"
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "operand adrese zahtjeva ograničenje za for X, Y, ili Z registar"
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "operandi za %T/%t moraju biti reg + const_int:"
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 msgid "bad address, not an I/O address:"
 msgstr "loša adresa, nije U/I (I/O) adresa:"
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 msgid "bad address, not a constant:"
 msgstr "loša adresa, nije konstanta:"
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 msgid "bad address, not (reg+disp):"
 msgstr "loša adresa, nije (reg+disp):"
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "loša adresa, nije post_inc ili pre_dec:"
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr "interna greška kompajlera. Loša adresa:"
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "Nepodržani kȏd ‘%c’ za nepomični zarez (fixed-point):"
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 msgid "internal compiler error.  Unknown mode:"
 msgstr "interna greška kompajlera. Nepozat način rada:"
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 msgid "invalid insn:"
 msgstr "nevaljani insn:"
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 msgid "incorrect insn:"
 msgstr "netočni insn:"
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 msgid "unknown move insn:"
 msgstr "nepoznati insn za pomicanje, kopiranje:"
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 msgid "bad shift insn:"
 msgstr "loš pomak (shift) insn:"
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "interna greška kompajlera. Netočni pomak (shift):"
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 msgid "unsupported fixed-point conversion"
 msgstr "nepodržana konverzija nepomičnog zareza (fixed-point conversion)"
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 msgid "variable"
 msgstr "varijabla"
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 msgid "function parameter"
 msgstr "parametar funkcije"
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 msgid "structure field"
 msgstr "strukturno polje"
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 msgid "return type of function"
 msgstr "vrati tip funkcije"
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 msgid "pointer"
 msgstr "kazaljka (pointer)"
 
@@ -19930,7 +19930,7 @@ msgstr ""
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -20249,46 +20249,46 @@ msgstr "operand nije cijeli broj, nevaljani operand kȏd ‘R’"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operand nije određeni cijeli broj, nevaljani operand kȏd ‘R’"
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "nevaljani operand kȏd ‘%c’"
 
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "nevaljano ograničenje za operand"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, c-format
 msgid "invalid vector immediate"
 msgstr "nevaljana vektorska konstanta"
 
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 msgid "unknown insn mode"
 msgstr "nepoznati insn način"
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr "nevaljana konverzija od tipa %<__bf16%> bez opcije %<-msse2%> "
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr "nevaljana konverzija od tipa %<_Float16%> bez opcije %<-msse2%>"
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr "nevaljana konverzija u tip %<__bf16%> bez opcije %<-msse2%>"
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr "nevaljana konverzija u tip %<_Float16%> bez opcije %<-msse2%>"
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr "nelegalna operacija na tipu%<__bf16%> bez opcije %<-msse2%>"
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
 msgstr "nelegalna operacija na tipu %<_Float16%> bez opcije %<-msse2%>"
 
@@ -20319,7 +20319,7 @@ msgstr ""
 msgid "invalid %%P operand"
 msgstr ""
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, c-format
 msgid "invalid %%p value"
 msgstr ""
@@ -20346,29 +20346,29 @@ msgstr ""
 msgid "invalid addressing mode"
 msgstr ""
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, c-format
 msgid "'%%%c' is not a valid operand prefix"
 msgstr ""
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr ""
@@ -20400,7 +20400,7 @@ msgid "post-increment address is not a register"
 msgstr ""
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 msgid "bad address"
 msgstr ""
 
@@ -20558,7 +20558,7 @@ msgstr ""
 msgid "unsupported memory expression:"
 msgstr ""
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, c-format
 msgid "invalid vector operand"
 msgstr "nevaljani vektorski operand"
@@ -20606,242 +20606,242 @@ msgstr ""
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 msgid "bad move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, c-format
 msgid "invalid %%A value"
 msgstr "nevaljana %%A vrijednost"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%D value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, c-format
 msgid "invalid %%e value"
 msgstr "nevaljana %%e vrijednost"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, c-format
 msgid "invalid %%O value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, c-format
 msgid "invalid %%t value"
 msgstr "nevaljani %%t kȏd"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, c-format
 msgid "invalid %%V value"
 msgstr "nevaljana %%V vrijednost"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, c-format
 msgid "invalid %%x value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, c-format
 msgid "invalid %%z value"
 msgstr "nevaljani %%z kȏd"
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 msgid "AltiVec argument passed to unprototyped function"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 msgid "Could not generate addis value for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr ""
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, c-format
 msgid "cannot decompose address"
 msgstr ""
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 msgid "vector argument passed to unprototyped function"
 msgstr ""
 
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -21032,12 +21032,12 @@ msgstr "({anoniman})"
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "očekivano je %<;%>"
@@ -21050,7 +21050,7 @@ msgstr "očekivano je %<;%>"
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -21059,7 +21059,7 @@ msgstr "očekivano je %<;%>"
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "očekivano je %<)%>"
@@ -21067,7 +21067,7 @@ msgstr "očekivano je %<)%>"
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "očekivano je %<]%>"
@@ -21078,29 +21078,29 @@ msgstr "očekivano je %<;%>, %<,%> ili %<)%>"
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "očekivano je %<(%>"
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "očekivano je %<[%>"
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "očekivano je %<{%>"
@@ -21110,17 +21110,17 @@ msgstr "očekivano je %<{%>"
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "očekivano je %<:%>"
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "očekivano je %<while%>"
@@ -21129,8 +21129,8 @@ msgstr "očekivano je %<while%>"
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "očekivano je %<,%>"
@@ -21140,17 +21140,17 @@ msgid "expected %<.%>"
 msgstr "očekivano je %<.%>"
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "očekivano je %<@end%>"
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "očekivano je %<>%>"
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "očekivano je %<,%> ili %<)%>"
@@ -21158,32 +21158,32 @@ msgstr "očekivano je %<,%> ili %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "očekivano je %<=%>"
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "očekivano je %<}%>"
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, gcc-internal-format
 msgid "expected %<else%>"
 msgstr "očekivano %<else%>"
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr ""
 
@@ -21191,7 +21191,7 @@ msgstr ""
 msgid "(anonymous)"
 msgstr ""
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr ""
@@ -21206,22 +21206,22 @@ msgstr "očekivana je oznaka"
 msgid "candidate:"
 msgstr ""
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 msgid "  after user-defined conversion:"
 msgstr ""
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr ""
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr ""
 
@@ -21453,7 +21453,7 @@ msgstr ""
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 msgid "candidates are:"
 msgstr ""
 
@@ -21497,48 +21497,48 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr ""
 
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
 
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 msgid "in argument to unary !"
 msgstr ""
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -21616,7 +21616,7 @@ msgstr ""
 msgid "Deleted feature:"
 msgstr ""
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 msgid "array assignment"
 msgstr ""
 
@@ -21807,11 +21807,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 msgid "assignment"
 msgstr ""
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 msgid "pointer assignment"
 msgstr ""
 
@@ -21971,47 +21971,47 @@ msgstr ""
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -22020,11 +22020,11 @@ msgstr ""
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr ""
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
@@ -22039,12 +22039,12 @@ msgstr ""
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -22053,81 +22053,81 @@ msgstr ""
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, c-format
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, c-format
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, c-format
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
@@ -22149,15 +22149,15 @@ msgstr ""
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 msgid "Loop variable has been modified"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 msgid "DO step value is zero"
 msgstr ""
 
@@ -22233,7 +22233,7 @@ msgid "expected boolean type"
 msgstr ""
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "očekivan je cijeli broj"
@@ -22296,7 +22296,7 @@ msgstr ""
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr ""
@@ -22920,7 +22920,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr ""
@@ -23356,8 +23356,8 @@ msgstr ""
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr ""
@@ -23374,7 +23374,7 @@ msgstr ""
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr ""
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, gcc-internal-format
 msgid "wrong number of arguments specified for %qE attribute"
 msgstr ""
@@ -23384,7 +23384,7 @@ msgstr ""
 msgid "expected %i or more, found %i"
 msgstr "očekivano je %i ili više, pronađeno %i"
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "expected %i, found %i"
 msgstr "očekivano je %i, pronađeno je %i"
@@ -23451,12 +23451,12 @@ msgstr ""
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -23465,7 +23465,7 @@ msgstr ""
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -23487,8 +23487,8 @@ msgstr "zanemareni atribut %qE"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr ""
@@ -23599,7 +23599,7 @@ msgstr ""
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr ""
@@ -23704,7 +23704,7 @@ msgstr ""
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, gcc-internal-format
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
@@ -23726,42 +23726,42 @@ msgstr ""
 msgid "target format does not support infinity"
 msgstr ""
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr ""
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr ""
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr ""
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr ""
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr ""
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, gcc-internal-format
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr ""
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, gcc-internal-format
 msgid "last argument of %qD is not integer constant between 0 and 3"
 msgstr ""
@@ -24806,12 +24806,12 @@ msgstr ""
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr ""
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -25360,7 +25360,7 @@ msgstr ""
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr ""
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, gcc-internal-format
 msgid "%qs failed"
 msgstr ""
@@ -25390,17 +25390,17 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, gcc-internal-format
 msgid "call to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, gcc-internal-format
 msgid "call to %qs declared with attribute warning: %s"
 msgstr ""
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
 msgstr ""
@@ -25435,7 +25435,7 @@ msgstr ""
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -25598,7 +25598,7 @@ msgstr "nije uspjelo dobiti izlazni status: %m"
 msgid "%s signal terminated program %s"
 msgstr "signal %s je prekinuo (završio) program %s"
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, gcc-internal-format
 msgid "unrecognized command-line option %qs"
 msgstr "neprepoznata opcija na naredbenom retku %qs"
@@ -25860,7 +25860,7 @@ msgstr ""
 msgid "multilib exclusions %qs is invalid"
 msgstr ""
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "nevaljani ‘multilib’ odabir %qs %qs"
@@ -26159,22 +26159,22 @@ msgstr ""
 msgid "%qD specified bound %E equals source length"
 msgstr ""
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, gcc-internal-format
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr ""
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr ""
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s not supported for variable length aggregates"
 msgstr ""
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "%s not supported on this target"
 msgstr ""
@@ -26215,16 +26215,16 @@ msgid "function returns address of local variable"
 msgstr "funkcija vraća adresu lokalne varijable"
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, gcc-internal-format
@@ -26236,27 +26236,27 @@ msgstr ""
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -26264,7 +26264,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
@@ -26272,7 +26272,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
@@ -26280,67 +26280,67 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
@@ -26348,7 +26348,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -26356,7 +26356,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -26364,122 +26364,122 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, gcc-internal-format
 msgid "referenced argument declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
@@ -26487,22 +26487,22 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, gcc-internal-format
 msgid "directive argument %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgid_plural "%qE output %wu bytes into a destination of size %wu"
@@ -26510,22 +26510,22 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
@@ -26533,80 +26533,80 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 msgid "%qE argument %Z overlaps destination object %qE"
 msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 msgid "%qE argument %Z may overlap destination object %qE"
 msgid_plural "%qE arguments %Z may overlap destination object %qE"
 msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, gcc-internal-format
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, gcc-internal-format
 msgid "null destination pointer"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, gcc-internal-format
 msgid "null format string"
 msgstr ""
@@ -27345,12 +27345,12 @@ msgstr ""
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr ""
@@ -28123,7 +28123,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr ""
@@ -28473,17 +28473,17 @@ msgstr ""
 msgid "mismatching definition"
 msgstr ""
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr ""
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, gcc-internal-format
 msgid "IPA modref summary is missing in input file"
 msgstr ""
@@ -29546,72 +29546,72 @@ msgstr ""
 msgid "error closing optimization records %qs"
 msgstr ""
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, gcc-internal-format
 msgid "command-line option %qs is not supported by this configuration"
 msgstr ""
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr ""
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr ""
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer"
 msgstr ""
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, gcc-internal-format
 msgid "argument to %qs is not between %d and %d"
 msgstr ""
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, gcc-internal-format
 msgid "invalid argument in option %qs"
 msgstr ""
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr ""
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, gcc-internal-format
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr ""
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, gcc-internal-format
 msgid "unrecognized argument in option %qs"
 msgstr ""
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr ""
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr ""
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr ""
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, gcc-internal-format
 msgid "argument to %qs is bigger than %d"
 msgstr ""
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, gcc-internal-format
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
 msgstr "deformirani %<COLLECT_GCC_OPTIONS%>"
@@ -29685,8 +29685,8 @@ msgstr ""
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, gcc-internal-format
 msgid "%qs is incompatible with %qs"
 msgstr ""
@@ -30394,7 +30394,7 @@ msgstr ""
 msgid "register of %qD used for multiple global register variables"
 msgstr ""
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr ""
@@ -30844,42 +30844,42 @@ msgstr ""
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr ""
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, gcc-internal-format
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "argument %qs nije podržan za %qs na ovom cilju"
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, gcc-internal-format
 msgid "nested functions not supported on this target"
 msgstr ""
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, gcc-internal-format
 msgid "nested function trampolines not supported on this target"
 msgstr ""
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr ""
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr ""
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, gcc-internal-format
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "atribut %<target%> nije podržan na ovom računalu"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, gcc-internal-format
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "atribut %<target_version%> nije podržan na ovom računalu"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, gcc-internal-format
 msgid "%<#pragma GCC target%> is not supported for this machine"
 msgstr ""
@@ -31992,82 +31992,82 @@ msgstr ""
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr ""
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr ""
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr ""
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr ""
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr ""
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr ""
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr ""
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr ""
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr ""
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr ""
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr ""
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr ""
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, gcc-internal-format
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr ""
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr ""
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, gcc-internal-format
 msgid "called from this function"
 msgstr ""
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, gcc-internal-format
 msgid "inlining failed in call to %q+F: %s"
 msgstr ""
@@ -32122,27 +32122,27 @@ msgstr ""
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, gcc-internal-format
 msgid "in a call to non-static member function %qD"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, gcc-internal-format
 msgid "in a call to function %qD declared %qs"
 msgstr ""
@@ -32353,7 +32353,7 @@ msgstr ""
 msgid "%qs may be used uninitialized"
 msgstr ""
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr ""
@@ -32583,7 +32583,7 @@ msgstr ""
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -32598,122 +32598,122 @@ msgstr ""
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr ""
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "povratni tip funkcije ne može biti funkcija"
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, gcc-internal-format
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, gcc-internal-format
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr ""
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr ""
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr ""
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr ""
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr ""
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr ""
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, gcc-internal-format
 msgid "%qD is unavailable: %s"
 msgstr ""
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, gcc-internal-format
 msgid "%qD is unavailable"
 msgstr ""
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, gcc-internal-format
 msgid "%qE is unavailable: %s"
 msgstr ""
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, gcc-internal-format
 msgid "%qE is unavailable"
 msgstr ""
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, gcc-internal-format, gfc-internal-format
 msgid "type is unavailable: %s"
 msgstr ""
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, gcc-internal-format
 msgid "type is unavailable"
 msgstr ""
@@ -32738,262 +32738,262 @@ msgstr ""
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr ""
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is not an opaque type"
 msgstr "tip %s nije neproziran tip"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is not with opaque mode"
 msgstr ""
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr ""
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr ""
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, gcc-internal-format
 msgid "main variant is not defined"
 msgstr ""
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr ""
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr ""
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -33208,7 +33208,7 @@ msgstr ""
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr ""
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr ""
@@ -33410,7 +33410,7 @@ msgstr ""
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr ""
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr ""
@@ -33592,7 +33592,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr ""
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for local variables"
 msgstr ""
@@ -33907,7 +33907,7 @@ msgstr ""
 msgid "%qE argument is not a function"
 msgstr ""
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
@@ -34412,7 +34412,7 @@ msgstr ""
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr ""
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, gcc-internal-format
 msgid "invalid application of %qs to a void type"
 msgstr ""
@@ -34543,17 +34543,17 @@ msgstr ""
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr ""
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, gcc-internal-format
@@ -34677,166 +34677,166 @@ msgstr ""
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr ""
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, gcc-internal-format
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr ""
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr ""
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr ""
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr ""
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr ""
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr ""
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr ""
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr ""
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr ""
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr ""
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr ""
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, gcc-internal-format
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr ""
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr ""
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, gcc-internal-format
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr ""
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr ""
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr ""
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr ""
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr ""
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr ""
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, gcc-internal-format
 msgid "size %qE of array is negative"
 msgstr ""
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -35459,7 +35459,7 @@ msgstr ""
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr ""
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, gcc-internal-format
 msgid "%<_BitInt(%d)%> is not supported on this target"
 msgstr "%<_BitInt(%d)%> nije podržan na ovom cilju"
@@ -35539,7 +35539,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr ""
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -35594,7 +35594,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -35609,17 +35609,17 @@ msgstr ""
 msgid "%qE is not initialized"
 msgstr ""
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr ""
@@ -35629,7 +35629,7 @@ msgstr ""
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr ""
@@ -35714,7 +35714,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -35724,7 +35724,7 @@ msgstr ""
 msgid "%qD is not a function argument"
 msgstr "%qD nije argument funkcije"
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
@@ -36316,7 +36316,7 @@ msgid "wrong type argument to %s"
 msgstr ""
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -37246,35 +37246,35 @@ msgstr ""
 
 #: c-family/c-warn.cc:3832
 #, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3836
+#: c-family/c-warn.cc:3839
 #, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr ""
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr ""
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr ""
@@ -37483,117 +37483,117 @@ msgstr ""
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, gcc-internal-format
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, gcc-internal-format
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, gcc-internal-format
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, gcc-internal-format
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr ""
@@ -37991,12 +37991,12 @@ msgstr ""
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr ""
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr ""
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr ""
@@ -38561,7 +38561,7 @@ msgstr ""
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
@@ -38637,12 +38637,12 @@ msgid "unknown tuning option (%s)"
 msgstr "nepoznata tuning opcija (%s)"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
@@ -38653,7 +38653,7 @@ msgid "specify a system register with a small string length"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr ""
@@ -38833,9 +38833,9 @@ msgstr ""
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
@@ -38887,18 +38887,18 @@ msgid "virtual function multiversioning not supported"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
@@ -38911,8 +38911,8 @@ msgstr ""
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr ""
@@ -38922,7 +38922,7 @@ msgstr ""
 msgid "GCC does not currently support return type %qT for simd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
@@ -38932,7 +38932,7 @@ msgstr ""
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr ""
@@ -39022,8 +39022,8 @@ msgstr ""
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr ""
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr ""
@@ -39143,18 +39143,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr ""
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -39268,7 +39268,7 @@ msgid "argument of %qE attribute is missing"
 msgstr ""
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr ""
@@ -39288,23 +39288,23 @@ msgstr ""
 msgid "argument of %qE attribute ignored"
 msgstr ""
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr ""
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr ""
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr ""
@@ -39546,7 +39546,7 @@ msgstr ""
 msgid "target CPU does not support unaligned accesses"
 msgstr ""
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr ""
@@ -39596,7 +39596,7 @@ msgstr ""
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr ""
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr ""
@@ -39702,7 +39702,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -39742,42 +39742,42 @@ msgstr ""
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr ""
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr ""
@@ -39785,22 +39785,22 @@ msgstr ""
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr ""
@@ -39854,158 +39854,158 @@ msgstr ""
 msgid "unknown core architecture %qs specified with %qs"
 msgstr ""
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, gcc-internal-format
 msgid "%<-fpic%> is not supported"
 msgstr ""
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, gcc-internal-format
 msgid "%<-fPIC%> is not supported"
 msgstr ""
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, gcc-internal-format
 msgid "%<-fpie%> is not supported"
 msgstr ""
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, gcc-internal-format
 msgid "%<-fPIE%> is not supported"
 msgstr ""
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr ""
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr ""
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr ""
 
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, gcc-internal-format
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr ""
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, gcc-internal-format
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr ""
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr ""
 
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr ""
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr ""
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, gcc-internal-format
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr ""
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr ""
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr ""
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr ""
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, gcc-internal-format
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr ""
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, gcc-internal-format
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr ""
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, gcc-internal-format
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr ""
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr ""
@@ -40014,42 +40014,42 @@ msgstr ""
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, gcc-internal-format
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr ""
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr ""
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr ""
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr ""
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr ""
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr ""
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -40185,7 +40185,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr ""
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, gcc-internal-format
@@ -40804,8 +40804,8 @@ msgstr ""
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr ""
@@ -40871,255 +40871,255 @@ msgstr ""
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, gcc-internal-format
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "%<-mapxf%> nije podržan za 32-bitni kod"
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, gcc-internal-format
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr ""
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, gcc-internal-format
 msgid "bad value %qs for %<-march=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr ""
@@ -41127,290 +41127,290 @@ msgstr ""
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr ""
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr ""
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
@@ -41601,46 +41601,46 @@ msgstr ""
 msgid "non-integer operand used with operand code %<z%>"
 msgstr ""
 
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, gcc-internal-format
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr ""
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr ""
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr ""
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr ""
@@ -41660,8 +41660,8 @@ msgstr ""
 msgid "malformed %<#pragma builtin%>"
 msgstr ""
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, gcc-internal-format
 msgid "invalid argument of %qE attribute"
 msgstr ""
@@ -41716,12 +41716,12 @@ msgstr ""
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr ""
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr ""
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, gcc-internal-format
 msgid "failed to expand built-in function"
 msgstr ""
@@ -41847,17 +41847,17 @@ msgstr ""
 msgid "%qs cannot be used for compiling a shared library"
 msgstr ""
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr ""
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for register variables"
 msgstr ""
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, gcc-internal-format
 msgid "multiple %qE attribute"
 msgstr ""
@@ -41958,12 +41958,12 @@ msgstr ""
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not supported on this target"
 msgstr ""
@@ -42004,7 +42004,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr ""
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr ""
@@ -42044,132 +42044,132 @@ msgstr ""
 msgid "argument to %qE attribute is not intstack"
 msgstr ""
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, gcc-internal-format
 msgid "cannot handle inconsistent calls to %qs"
 msgstr ""
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr ""
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr ""
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr ""
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, gcc-internal-format
 msgid "built-in function %qE not supported for MIPS16"
 msgstr ""
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, gcc-internal-format
 msgid "%qs does not support MIPS16 code"
 msgstr ""
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr ""
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, gcc-internal-format
 msgid "MIPS16 %<-mxgot%> code"
 msgstr ""
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, gcc-internal-format
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr ""
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, gcc-internal-format
 msgid "MSA MIPS16 code"
 msgstr ""
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, gcc-internal-format
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr ""
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported combination: %s"
 msgstr ""
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, gcc-internal-format
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr ""
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, gcc-internal-format
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr ""
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, gcc-internal-format
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr ""
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr ""
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr ""
@@ -42179,117 +42179,117 @@ msgstr ""
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, gcc-internal-format
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, gcc-internal-format
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, gcc-internal-format
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr ""
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, gcc-internal-format
 msgid "unsupported combination: %qs%s %s"
 msgstr ""
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, gcc-internal-format
 msgid "unsupported combination: %qs %s"
 msgstr ""
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, gcc-internal-format
 msgid "cannot generate position-independent code for %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, gcc-internal-format
 msgid "position-independent code requires %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr ""
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr ""
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr ""
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, gcc-internal-format
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr ""
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, gcc-internal-format
 msgid "%qs must be used with %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, gcc-internal-format
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr ""
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, gcc-internal-format
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr ""
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, gcc-internal-format
 msgid "the %qs architecture does not support DSP instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, gcc-internal-format
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr ""
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, gcc-internal-format
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr ""
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, gcc-internal-format
 msgid "%qs requires branch-likely instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, gcc-internal-format
 msgid "the %qs architecture does not support the synci instruction"
 msgstr ""
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr ""
@@ -43158,57 +43158,57 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, gcc-internal-format
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, gcc-internal-format
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, gcc-internal-format
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, gcc-internal-format
 msgid "malformed %<target()%> attribute"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, gcc-internal-format
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, gcc-internal-format
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> attribute"
 msgstr ""
@@ -43268,172 +43268,192 @@ msgstr ""
 msgid "capture by copy of RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, gcc-internal-format
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, gcc-internal-format
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, gcc-internal-format
 msgid "no matching function call to %qE with empty arguments"
 msgstr ""
 
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, gcc-internal-format
 msgid "this operation requires the RVV ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, gcc-internal-format
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr ""
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, gcc-internal-format
 msgid "%s %qT requires the V ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, gcc-internal-format
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, gcc-internal-format
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, gcc-internal-format
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, gcc-internal-format
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr ""
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, gcc-internal-format
 msgid "function attribute %qs requires the V ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr ""
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, gcc-internal-format
 msgid "%qs applied to non-RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, gcc-internal-format
 msgid "%qs requires an integer constant"
 msgstr "%qs zahtijeva cijelobrojnu (integer) konstantu"
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr ""
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, gcc-internal-format
 msgid "code model %qs with %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, gcc-internal-format
 msgid "rv64e requires lp64e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr ""
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr ""
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr "ne može dodijeliti vl registar za %qs na ovoom cilju"
@@ -43683,32 +43703,32 @@ msgstr ""
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, gcc-internal-format
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, gcc-internal-format
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%qs nije podržan u ovoj konfiguraciji"
@@ -43748,29 +43768,22 @@ msgstr ""
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, gcc-internal-format
-msgid "%qs requires the ELFv2 ABI"
-msgstr ""
-
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr ""
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported number of nops before function entry (%u)"
 msgstr ""
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr ""
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
@@ -43895,107 +43908,117 @@ msgstr ""
 msgid "unknown option for %<%s=%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4837
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4855
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr ""
@@ -44040,7 +44063,7 @@ msgstr ""
 msgid "builtin %qs can only be used on vector types"
 msgstr ""
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -44110,225 +44133,225 @@ msgstr ""
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr ""
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr ""
 
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr ""
 
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr ""
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher"
 msgstr ""
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher"
 msgstr ""
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr ""
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr ""
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr ""
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr ""
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr ""
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr ""
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr ""
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr ""
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr ""
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr ""
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, gcc-internal-format
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr ""
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, gcc-internal-format
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr ""
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, gcc-internal-format
 msgid "invalid cc output constraint: %qs"
 msgstr "nevaljano cc izlazno ograničenje: %qs"
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, gcc-internal-format
 msgid "multiple cc output constraints not supported"
 msgstr "višestruka cc izlazna ograničenja nisu podržana"
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, gcc-internal-format
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr ""
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, gcc-internal-format
 msgid "invalid type for cc output constraint"
 msgstr "nevaljani tip za cc izlazno ograničenje"
@@ -44750,8 +44773,8 @@ msgstr ""
 msgid "attribute %qs applies to array types only"
 msgstr ""
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -44826,7 +44849,7 @@ msgstr ""
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr ""
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr ""
@@ -45058,7 +45081,7 @@ msgstr ""
 msgid "declaration of %qD shadows a parameter"
 msgstr ""
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -45068,7 +45091,7 @@ msgstr ""
 msgid "declaration of %qD shadows a previous local"
 msgstr ""
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr ""
@@ -45133,7 +45156,7 @@ msgstr ""
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr ""
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
@@ -45168,7 +45191,7 @@ msgstr ""
 msgid "duplicate label declaration %qE"
 msgstr ""
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr ""
@@ -45203,7 +45226,7 @@ msgstr ""
 msgid "%qE defined as wrong kind of tag"
 msgstr ""
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr ""
@@ -45345,12 +45368,12 @@ msgstr ""
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, gcc-internal-format
 msgid "%<omp::%s%> not allowed to be specified in this context"
 msgstr ""
@@ -45360,7 +45383,7 @@ msgstr ""
 msgid "%q+D is usually a function"
 msgstr ""
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr ""
@@ -45436,7 +45459,7 @@ msgstr ""
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr ""
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -45621,7 +45644,7 @@ msgstr ""
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
@@ -45684,7 +45707,7 @@ msgstr ""
 msgid "declaration of type name as array of functions"
 msgstr ""
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr ""
@@ -45790,7 +45813,7 @@ msgstr ""
 msgid "function definition has qualified void return type"
 msgstr ""
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -45917,7 +45940,7 @@ msgstr ""
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr ""
@@ -46022,7 +46045,7 @@ msgstr ""
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr ""
@@ -46112,17 +46135,17 @@ msgstr ""
 msgid "nested redefinition of %<struct %E%>"
 msgstr ""
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, gcc-internal-format
 msgid "%qT defined in underspecified object initializer"
 msgstr ""
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -46152,596 +46175,596 @@ msgstr ""
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr ""
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, gcc-internal-format
 msgid "union has no members"
 msgstr ""
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr ""
 
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr ""
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr ""
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, gcc-internal-format
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr ""
 
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr ""
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, gcc-internal-format
 msgid "type punning toggles scalar storage order"
 msgstr ""
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr ""
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, gcc-internal-format
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr ""
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, gcc-internal-format
 msgid "redefinition of struct or union %qT"
 msgstr ""
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr ""
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr ""
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr ""
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, gcc-internal-format
 msgid "enumeration values exceed range of %qs"
 msgstr ""
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, gcc-internal-format
 msgid "conflicting redefinition of enum %qT"
 msgstr ""
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr ""
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr ""
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, gcc-internal-format
 msgid "enumerator value outside the range of underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, gcc-internal-format
 msgid "enumerator value outside the range of %qs"
 msgstr ""
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr ""
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr ""
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr ""
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr ""
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr ""
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr ""
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr ""
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr ""
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr ""
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr ""
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr ""
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr ""
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr ""
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr ""
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr ""
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr ""
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr ""
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr ""
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr ""
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr ""
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr ""
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr ""
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr ""
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr ""
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, gcc-internal-format
 msgid "%qs used with %<auto%>"
 msgstr ""
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, gcc-internal-format
 msgid "%<auto%> used with %<constexpr%>"
 msgstr ""
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr ""
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr ""
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr ""
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr ""
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr ""
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr ""
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr ""
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr ""
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr ""
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr ""
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr ""
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr ""
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, gcc-internal-format
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr ""
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr ""
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr ""
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, gcc-internal-format
 msgid "%qE used with %<constexpr%>"
 msgstr ""
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr ""
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr ""
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr ""
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr ""
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, gcc-internal-format
 msgid "%<typedef%> used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, gcc-internal-format
 msgid "%qE used with %<extern%>"
 msgstr ""
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, gcc-internal-format
 msgid "%qE used with %qs"
 msgstr ""
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr ""
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, gcc-internal-format
 msgid "%<constexpr%> used with %qE"
 msgstr ""
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, gcc-internal-format
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr ""
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, gcc-internal-format
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr "%<signed _BitInt%> argument mora biti najmanje 2"
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, gcc-internal-format
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr ""
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
@@ -46771,7 +46794,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "očekivan je kraj retka"
@@ -46781,8 +46804,8 @@ msgstr "očekivan je kraj retka"
 msgid "ISO C forbids an empty translation unit"
 msgstr ""
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr ""
@@ -46822,9 +46845,9 @@ msgstr ""
 msgid "unknown type name %qE"
 msgstr ""
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr ""
@@ -46854,7 +46877,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -46874,7 +46897,7 @@ msgstr ""
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, gcc-internal-format
 msgid "%<assume%> attribute not followed by %<;%>"
 msgstr ""
@@ -46965,7 +46988,7 @@ msgstr ""
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
@@ -47036,10 +47059,10 @@ msgstr ""
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
@@ -47190,7 +47213,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr ""
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr ""
@@ -47200,8 +47223,8 @@ msgstr ""
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs attribute argument"
 msgstr ""
@@ -47375,12 +47398,12 @@ msgstr ""
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr ""
@@ -47527,7 +47550,7 @@ msgstr ""
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, gcc-internal-format
 msgid "expected expression"
 msgstr ""
@@ -47847,12 +47870,12 @@ msgstr ""
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr ""
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, gcc-internal-format
 msgid "missing property attribute"
 msgstr ""
@@ -47862,57 +47885,57 @@ msgstr ""
 msgid "unknown property attribute %<%s%s%>"
 msgstr ""
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr ""
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr "očekivano je ime selektora za %qE"
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr ""
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr ""
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -47922,25 +47945,25 @@ msgstr ""
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr ""
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr ""
@@ -47955,63 +47978,63 @@ msgstr ""
 msgid "expected %<)%> or %<,%>"
 msgstr "očekivano %<)%> or %<,%>"
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr ""
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr ""
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "očekivano je %<none%> ili %<present%>"
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, gcc-internal-format
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr "očekivano je %<none%>, %<shared%>, %<private%> ili %<firstprivate%>"
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, gcc-internal-format
 msgid "expected constant logical expression"
 msgstr "očekivan je konstantni logički izraz"
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "očekivano je %<data%>, %<update%>, %<enter%> ili %<exit%>"
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "očekivano je %<data%>"
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -48034,22 +48057,22 @@ msgstr ""
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr ""
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr ""
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr ""
@@ -48059,94 +48082,94 @@ msgstr ""
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr "očekivan je %<scalar%>, %<aggregate%>, %<pointer%> ili %<all%>"
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr ""
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr ""
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "neočekivani argument"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr ""
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, gcc-internal-format
 msgid "too many %<self%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, gcc-internal-format
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr "%<scalar%>, %<aggregate%> or %<pointer%>"
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "očekivano je %<concurrent%>"
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "očekivano je %<teams%>, %<parallel%> ili %<thread%>"
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr ""
@@ -48156,22 +48179,22 @@ msgstr ""
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr ""
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, gcc-internal-format
 msgid "expected %<allocator%> or %<align%>"
 msgstr "očekivano je %<allocator%> ili %<align%>"
@@ -48181,22 +48204,22 @@ msgstr "očekivano je %<allocator%> ili %<align%>"
 msgid "duplicate %qs modifier"
 msgstr ""
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, gcc-internal-format
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr ""
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, gcc-internal-format
 msgid "multiple linear modifiers"
 msgstr "višekratni linearni modifikatori"
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, gcc-internal-format
 msgid "multiple %<step%> modifiers"
 msgstr ""
@@ -48216,62 +48239,62 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr ""
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "nevaljana vrsta ovisnosti"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, gcc-internal-format
 msgid "invalid doacross kind"
 msgstr "nevaljana ‘doacross’ vrsta"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, gcc-internal-format
 msgid "too many %<always%> modifiers"
 msgstr ""
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, gcc-internal-format
 msgid "too many %<close%> modifiers"
 msgstr ""
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, gcc-internal-format
 msgid "too many %<present%> modifiers"
 msgstr ""
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "nevaljana vrsta dodjele"
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr ""
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, gcc-internal-format
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr "očekivano je %<ancestor%> ili %<device_num%>"
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, gcc-internal-format
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr ""
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -48286,88 +48309,88 @@ msgstr ""
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "očekivano je %<host%>, %<nohost%> ili %<any%>"
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, gcc-internal-format
 msgid "expected an OpenACC clause"
 msgstr "očekivana je OpenACC klauzula"
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr ""
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, gcc-internal-format
 msgid "expected an OpenMP clause"
 msgstr "očekivana je OpenMP klauzula"
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "očekivano je %<data%> iza %<#pragma acc %s%>"
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr ""
@@ -48382,7 +48405,7 @@ msgstr ""
 msgid "expected function name"
 msgstr "očekivano je ime funkcije"
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr ""
@@ -48392,22 +48415,22 @@ msgstr ""
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
@@ -48432,7 +48455,7 @@ msgstr ""
 msgid "modified here"
 msgstr "izmijenjeno ovdje"
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, gcc-internal-format
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
 msgstr ""
@@ -48472,110 +48495,110 @@ msgstr ""
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr ""
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "očekivano je %<read%>, %<write%>, %<update%>, ili %<capture%> klauzula"
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr "očekivano je %<seq_cst%>, %<acquire%> ili %<relaxed%>"
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr ""
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr ""
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, gcc-internal-format
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, gcc-internal-format
 msgid "%qs clause requires %qs clause"
 msgstr ""
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, gcc-internal-format
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr "očekivan je %<==%> usporedba u uvjetu %<if%>"
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, gcc-internal-format
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr ""
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr ""
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, gcc-internal-format
 msgid "unexpected %<else%>"
 msgstr "očekivano je %<else%>"
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, gcc-internal-format
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr ""
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr ""
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr ""
@@ -48585,27 +48608,27 @@ msgstr ""
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr "izraz %<destroy%> nije izraz lvalue"
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr ""
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr "očekivano %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> ili %<inoutset%>"
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "očekivano je %<depend%>, %<destroy%> ili %<update%> klauzula"
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "očekivano je %<seq_cst%>, %<acq_rel%>, %<release%> ili %<acquire%>"
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -48615,163 +48638,163 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr ""
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "očekivano je %<inclusive%> ili %<exclusive%> klauzula"
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "očekivano je %<#pragma omp scan%>"
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr ""
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, gcc-internal-format
 msgid "not enough nested loops"
 msgstr ""
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr ""
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "očekivano je %<for%> iza %qs"
 
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "očekivano je %<point%>"
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr ""
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, gcc-internal-format
 msgid "expected trait selector name"
 msgstr ""
 
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, gcc-internal-format
 msgid "unknown selector %qs for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, gcc-internal-format
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr ""
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, gcc-internal-format
 msgid "%<score%> argument must be constant integer expression"
 msgstr "argument %<score%> mora biti konstantan cjelobrojni izraz"
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, gcc-internal-format
 msgid "%<score%> argument must be non-negative"
 msgstr "argument %<score%> ne smije biti negativan"
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr ""
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
@@ -48779,290 +48802,290 @@ msgstr ""
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, gcc-internal-format
 msgid "%<requires%> selector is not supported yet"
 msgstr "%<requires%> selektor još nije podržan"
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, gcc-internal-format
 msgid "expected context selector set name"
 msgstr "očekivano je ime konteksta skupa selektora"
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "očekivano je %<match%>"
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, gcc-internal-format
 msgid "variant %qD is not a function"
 msgstr ""
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr ""
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, gcc-internal-format
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "očekivano je %<target%>"
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, gcc-internal-format
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr "očekivano %<declare target%> ili %<assumes%>"
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr ""
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr ""
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, gcc-internal-format
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr ""
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, gcc-internal-format
 msgid "expected %<declare%> or %<assumes%>"
 msgstr "očekivano %<declare%> ili %<assumes%>"
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, gcc-internal-format
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr ""
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "očekivano je function-name %<(%>"
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "očekivano je %<simd%>, %<reduction%>, %<target%> ili %<variant%>"
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr "očekivano je %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> ili %<seq_cst%>"
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, gcc-internal-format
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, gcc-internal-format
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, gcc-internal-format
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr "očekivano je %<at%>, %<severity%> ili %<message%> klauzula"
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, gcc-internal-format
 msgid "expected %qs or %qs"
 msgstr "očekivano je %qs ili %qs"
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, gcc-internal-format
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr ""
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr ""
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, gcc-internal-format
 msgid "expected at least one assumption clause"
 msgstr "očekivana je barem jedna klauzula pretpostavki"
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, gcc-internal-format
 msgid "expected directive name"
 msgstr "očekivano je ime direktive"
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr ""
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, gcc-internal-format
 msgid "unknown assumption clause %qs"
 msgstr "nepoznata klauzula pretpostavki %qs"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, gcc-internal-format
 msgid "expected assumption clause"
 msgstr "očekivana je klauzula pretpostavki"
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, gcc-internal-format
 msgid "no closing brace"
 msgstr ""
@@ -49203,7 +49226,7 @@ msgstr ""
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr ""
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr ""
@@ -49233,7 +49256,7 @@ msgstr ""
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -49346,17 +49369,17 @@ msgstr ""
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr ""
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr ""
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr ""
@@ -49381,7 +49404,7 @@ msgstr ""
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -49674,7 +49697,7 @@ msgstr ""
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
@@ -49846,7 +49869,7 @@ msgstr ""
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -50046,12 +50069,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -50061,7 +50084,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr ""
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr ""
@@ -50092,7 +50115,7 @@ msgstr ""
 msgid "initializer element is not computable at load time"
 msgstr ""
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
@@ -50107,7 +50130,7 @@ msgstr ""
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
@@ -50197,7 +50220,7 @@ msgstr ""
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
@@ -50237,7 +50260,7 @@ msgstr ""
 msgid "computed goto must be pointer type"
 msgstr ""
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
@@ -50292,7 +50315,7 @@ msgstr ""
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -50338,27 +50361,27 @@ msgstr ""
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr ""
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr ""
@@ -50430,29 +50453,29 @@ msgstr ""
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr ""
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
@@ -50463,85 +50486,85 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr ""
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr ""
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr ""
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr ""
@@ -50551,17 +50574,17 @@ msgstr ""
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr ""
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr ""
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr ""
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
@@ -50571,32 +50594,32 @@ msgstr ""
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr "očekivan je pokazivač (pointer) u %qs klauzuli"
 
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr ""
@@ -50626,7 +50649,7 @@ msgstr ""
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -50636,17 +50659,17 @@ msgstr ""
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
 msgstr ""
@@ -50661,23 +50684,23 @@ msgstr ""
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, gcc-internal-format
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -50689,32 +50712,32 @@ msgstr ""
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr ""
@@ -50734,7 +50757,7 @@ msgstr ""
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr ""
@@ -50744,7 +50767,7 @@ msgstr ""
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr ""
@@ -50754,76 +50777,76 @@ msgstr ""
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr ""
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, gcc-internal-format
 msgid "unsupported map expression %qE"
 msgstr "nepodržani %qE izraz mape"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
@@ -50838,22 +50861,22 @@ msgstr ""
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr ""
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
@@ -50863,38 +50886,38 @@ msgstr ""
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
@@ -51159,7 +51182,7 @@ msgstr ""
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr ""
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -51167,7 +51190,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -51477,553 +51500,553 @@ msgstr ""
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr ""
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr ""
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr ""
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, gcc-internal-format
 msgid "no match for call to %<%T::operator[] (%A)%>"
 msgstr ""
 
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, gcc-internal-format
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr ""
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr ""
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, gcc-internal-format
 msgid "declared private here"
 msgstr ""
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr ""
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr ""
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr ""
 
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, gcc-internal-format
 msgid "  declared here"
 msgstr ""
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr ""
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr ""
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr ""
 
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr ""
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr ""
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 msgid "invalid conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr ""
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr ""
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr ""
 
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr ""
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr ""
 
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr ""
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr ""
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, gcc-internal-format
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr ""
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 msgid "cannot convert %qH to %qI"
 msgstr ""
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr ""
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, gcc-internal-format
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr ""
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, gcc-internal-format
 msgid "try making the operator a %<const%> member function"
 msgstr ""
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 msgid "  for conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr ""
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr ""
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr ""
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, gcc-internal-format
 msgid "possibly dangling reference to a temporary"
 msgstr ""
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr ""
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, gcc-internal-format
 msgid "explicit conversion function was not considered"
 msgstr ""
@@ -52069,7 +52092,7 @@ msgid "%q#D cannot be overloaded with %q#D"
 msgstr ""
 
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr ""
@@ -52490,7 +52513,7 @@ msgstr ""
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr ""
@@ -52621,7 +52644,7 @@ msgstr ""
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
@@ -52662,7 +52685,7 @@ msgstr ""
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr ""
@@ -52680,7 +52703,7 @@ msgstr ""
 msgid "%q+E is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -52701,7 +52724,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, gcc-internal-format
 msgid "call to internal function %qE"
@@ -52748,7 +52771,7 @@ msgstr ""
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -52876,18 +52899,18 @@ msgstr ""
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr ""
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -52895,469 +52918,469 @@ msgstr ""
 msgid "%qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr ""
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr ""
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr ""
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr ""
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr ""
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr ""
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr ""
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr ""
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr ""
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr ""
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr ""
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, gcc-internal-format
 msgid "allocated here"
 msgstr ""
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
 msgstr ""
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr ""
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr ""
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr ""
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, gcc-internal-format
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, gcc-internal-format
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, gcc-internal-format
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, gcc-internal-format
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr ""
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr ""
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr ""
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, gcc-internal-format
 msgid "use of %qD"
 msgstr ""
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr ""
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr ""
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr ""
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr ""
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, gcc-internal-format
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, gcc-internal-format
 msgid "pointed-to object declared here"
 msgstr "pointed-to objekt deklariran ovdje"
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr ""
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr ""
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr ""
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr ""
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, gcc-internal-format
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr ""
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr ""
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
@@ -54067,7 +54090,7 @@ msgstr ""
 msgid "no suspend point info for %qD"
 msgstr ""
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -54087,23 +54110,23 @@ msgstr "‘await’ izraz nije dopušten u rukovateljima (handlers)"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr ""
@@ -54123,68 +54146,68 @@ msgstr "%qD je promovirana u trenutnu funkciju jer njezino tijelo sadrži izraz
 msgid "%qD was promoted to an immediate function"
 msgstr "%qD je promovirana u trenutnu funkciju"
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr ""
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, gcc-internal-format
 msgid "call to consteval function %qE is not a constant expression"
 msgstr ""
 
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, gcc-internal-format
 msgid "pack expansion of %qE attribute"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, gcc-internal-format
 msgid "use fold expression in the attribute argument instead"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
@@ -54225,7 +54248,7 @@ msgstr ""
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -54608,7 +54631,7 @@ msgstr ""
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr ""
 
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr ""
@@ -54748,8 +54771,8 @@ msgstr ""
 msgid "%q#D previously defined here"
 msgstr ""
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr ""
@@ -54824,52 +54847,37 @@ msgstr ""
 msgid "previous specification in %q#D here"
 msgstr ""
 
-#: cp/decl.cc:2285
-#, gcc-internal-format
-msgid "declaration %qD conflicts with builtin"
-msgstr ""
-
-#: cp/decl.cc:2288
-#, gcc-internal-format
-msgid "declaration %qD conflicts with import"
-msgstr ""
-
-#: cp/decl.cc:2289
-#, gcc-internal-format
-msgid "import declared %q#D here"
-msgstr ""
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, gcc-internal-format
 msgid "conflicting exporting for declaration %qD"
 msgstr ""
 
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, gcc-internal-format
 msgid "previously declared here without exporting"
 msgstr "ranije deklarirana ovdje bez izvoza (exporting)"
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr ""
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr ""
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr ""
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr ""
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr ""
@@ -54882,44 +54890,44 @@ msgstr ""
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr ""
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr ""
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr ""
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr ""
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr ""
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -54927,741 +54935,741 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr ""
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr ""
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, gcc-internal-format
 msgid "jump to label %qD"
 msgstr ""
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr ""
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr ""
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, gcc-internal-format
 msgid "  from here"
 msgstr ""
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr ""
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr ""
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr ""
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, gcc-internal-format
 msgid "  enters statement expression"
 msgstr ""
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, gcc-internal-format
 msgid "  enters %<consteval if%> statement"
 msgstr ""
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, gcc-internal-format
 msgid "  does not destroy %qD"
 msgstr "  ne uništi %qD"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, gcc-internal-format
 msgid "  does not clean up handled exception"
 msgstr ""
 
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr ""
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr ""
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, gcc-internal-format
 msgid "%qD is a function, not a type"
 msgstr ""
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr ""
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr ""
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr ""
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr ""
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr ""
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr ""
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr ""
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr ""
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr ""
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr ""
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr ""
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr ""
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr ""
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr ""
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr ""
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr ""
 
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr ""
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr ""
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr ""
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr ""
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr ""
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr ""
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr ""
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr ""
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr ""
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr ""
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr ""
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr ""
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr ""
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr ""
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr ""
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr ""
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr ""
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr ""
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr ""
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr ""
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, gcc-internal-format
 msgid "deduced type %qT for %qD is incomplete"
 msgstr ""
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr ""
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr ""
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr ""
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -55669,7 +55677,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -55677,7 +55685,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -55685,1746 +55693,1746 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr ""
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr ""
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr ""
 
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr ""
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr ""
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr ""
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr ""
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr ""
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr ""
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, gcc-internal-format
 msgid "constrained non-template friend declaration must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr ""
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr ""
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, gcc-internal-format
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, gcc-internal-format
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, gcc-internal-format
 msgid "explicit object parameter declared here"
 msgstr ""
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "deduction guide %qD mora imati isti pristup kao %qT"
 
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr ""
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr ""
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr ""
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr ""
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr ""
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr ""
 
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr ""
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr ""
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr ""
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr ""
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr ""
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr ""
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr ""
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr ""
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr ""
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr ""
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr ""
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr ""
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr ""
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr ""
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr ""
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr ""
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr ""
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr ""
 
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr ""
 
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr ""
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr ""
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr ""
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr ""
 
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr ""
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr ""
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr ""
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr ""
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr ""
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr ""
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, gcc-internal-format
 msgid "%qs specified with typedef-name %qD"
 msgstr ""
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr ""
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr ""
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr ""
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr ""
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr ""
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr ""
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr ""
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr ""
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr ""
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs opseg funkcije je implicitno auto i deklariran kao %<__thread%>"
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr ""
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr ""
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr ""
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, gcc-internal-format
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "eksplicitna funkcija člana objekta dostupna je samo s %<-std=c++23%> ili %<-std=gnu++23%>"
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, gcc-internal-format
 msgid "a function type cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, gcc-internal-format
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, gcc-internal-format
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr ""
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, gcc-internal-format
 msgid "the type of an explicit object member function is a regular function type"
 msgstr ""
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "valid explicit object parameter declared here"
 msgstr ""
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr ""
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr ""
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, gcc-internal-format
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr ""
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, gcc-internal-format
 msgid "%qD cannot be an explicit object member function"
 msgstr "%qD ne može biti eksplicitna funkcija člana objekta"
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr ""
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr ""
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr ""
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr ""
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr ""
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr ""
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr ""
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr ""
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr ""
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr ""
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr ""
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr ""
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr ""
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr ""
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr ""
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr ""
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr ""
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%qD ne može bit %qs"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr ""
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr ""
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, gcc-internal-format
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr ""
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr ""
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr ""
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "%qD mora biti član funkcije"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr ""
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr ""
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -57436,115 +57444,100 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr ""
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr ""
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, gcc-internal-format
-msgid "cannot declare %qD in a different module"
-msgstr ""
-
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, gcc-internal-format
-msgid "previously declared here"
-msgstr "ranije deklarirana ovdje"
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.cc:16984
-#, gcc-internal-format
-msgid "cannot declare %qD in different module"
-msgstr ""
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr ""
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -57553,82 +57546,82 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr ""
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr ""
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr ""
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, gcc-internal-format
 msgid "using %qs"
 msgstr "koristimo %qs"
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -57683,7 +57676,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr ""
@@ -57693,7 +57686,7 @@ msgstr ""
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr ""
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -57877,64 +57870,64 @@ msgstr ""
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr ""
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, gcc-internal-format
 msgid "%qT has a base %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, gcc-internal-format
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, gcc-internal-format
 msgid "%qT has a base %qT which has internal linkage"
 msgstr ""
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, gcc-internal-format
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr ""
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but not defined"
 msgstr ""
@@ -57943,104 +57936,104 @@ msgstr ""
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr ""
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr ""
 
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr ""
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, gcc-internal-format
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr ""
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q#D"
 msgstr ""
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, gcc-internal-format
 msgid "...following parameter %P which has a default argument"
 msgstr ""
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, gcc-internal-format
 msgid "implicitly-declared %qD is deprecated"
 msgstr ""
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "funkcija %qD se koristi s nezadovoljenim ograničenjima"
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -58145,7 +58138,7 @@ msgstr ""
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr ""
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr ""
@@ -58155,7 +58148,7 @@ msgstr ""
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr ""
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr ""
@@ -58180,47 +58173,47 @@ msgstr ""
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr ""
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, gcc-internal-format
 msgid "  in thrown expression"
 msgstr ""
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, gcc-internal-format
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr ""
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, gcc-internal-format
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr ""
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, gcc-internal-format
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr ""
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, gcc-internal-format
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr ""
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, gcc-internal-format
 msgid "for type %qT"
 msgstr ""
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, gcc-internal-format
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr ""
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr ""
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
 msgstr ""
@@ -58487,12 +58480,12 @@ msgstr ""
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr ""
@@ -58507,12 +58500,12 @@ msgstr ""
 msgid "invalid pointer to bit-field %qD"
 msgstr ""
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr ""
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr ""
@@ -58707,52 +58700,52 @@ msgstr ""
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr ""
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr ""
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr ""
@@ -59123,223 +59116,268 @@ msgstr ""
 msgid "encapsulation is malformed"
 msgstr ""
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, gcc-internal-format
 msgid "conflicting global module declaration %#qD"
 msgstr ""
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, gcc-internal-format
 msgid "existing declaration %#qD"
 msgstr ""
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, gcc-internal-format
 msgid "definition of %qD does not match"
 msgstr ""
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, gcc-internal-format
 msgid "existing definition %qD"
 msgstr ""
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, gcc-internal-format
 msgid "... this enumerator %qD"
 msgstr ""
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, gcc-internal-format
 msgid "enumerator %qD does not match ..."
 msgstr ""
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr ""
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr ""
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr ""
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, gcc-internal-format
 msgid "recursive lazy load"
 msgstr ""
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr ""
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, gcc-internal-format
 msgid "module %qs declared here"
 msgstr ""
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, gcc-internal-format
 msgid "indirect import %qs is not already loaded"
 msgstr ""
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr ""
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr ""
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, gcc-internal-format
 msgid "macro definitions of %qE corrupted"
 msgstr ""
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, gcc-internal-format
 msgid "inconsistent imported macro definition %qE"
 msgstr ""
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr ""
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr ""
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, gcc-internal-format
 msgid "compiled module file is %qs"
 msgstr ""
 
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, gcc-internal-format, gfc-internal-format
 msgid "compiled module is %sversion %s"
 msgstr "kompilirani modul je %sversion %s"
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, gcc-internal-format, gfc-internal-format
 msgid "compiler is %sversion %s%s%s"
 msgstr "kompajler je %sversion %s%s%s"
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, gcc-internal-format
 msgid "module %qs found"
 msgstr ""
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr ""
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr ""
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr ""
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr ""
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, gcc-internal-format
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr ""
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, gcc-internal-format
 msgid "fixed tree mismatch"
 msgstr ""
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, gcc-internal-format
 msgid "interface partition is not exported"
 msgstr ""
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module cluster %u: %s"
 msgstr ""
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module: %s"
 msgstr "nije uspjelo pročitati kompilirani modul: %s"
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr ""
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr ""
 
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr ""
 
-#: cp/module.cc:19283
+#: cp/module.cc:19117
+#, gcc-internal-format
+msgid "declaration %qD conflicts with builtin"
+msgstr ""
+
+#: cp/module.cc:19122
+#, gcc-internal-format
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr ""
+
+#: cp/module.cc:19125
+#, gcc-internal-format
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr ""
+
+#: cp/module.cc:19130
+#, gcc-internal-format
+msgid "import declared attached to module %qs"
+msgstr ""
+
+#: cp/module.cc:19134
+#, gcc-internal-format
+msgid "import declared in global module"
+msgstr ""
+
+#: cp/module.cc:19140
+#, gcc-internal-format
+msgid "conflicting declaration of %qD in module %qs"
+msgstr ""
+
+#: cp/module.cc:19143
+#, gcc-internal-format
+msgid "conflicting declaration of %qD in global module"
+msgstr ""
+
+#: cp/module.cc:19148
+#, gcc-internal-format
+msgid "previously declared in module %qs"
+msgstr "ranije deklarirano u modulu %qs"
+
+#: cp/module.cc:19152
+#, gcc-internal-format
+msgid "previously declared in global module"
+msgstr "ranije deklarirano u globalnom modulu"
+
+#: cp/module.cc:19404
 #, gcc-internal-format
 msgid "reading CMI %qs"
 msgstr "čitamo CMI %qs"
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E%>"
 msgstr "nije uspjelo učitati vezanja %<%E%s%E%>"
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, gcc-internal-format
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr "nije uspjelo učitati jedinice na čekanju za %<%E%s%E%>"
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, gcc-internal-format
 msgid "during load of pendings for %<%E%s%E%>"
 msgstr ""
@@ -59351,297 +59389,297 @@ msgstr ""
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr ""
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, gcc-internal-format
 msgid "module already declared"
 msgstr ""
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, gcc-internal-format
 msgid "module already imported"
 msgstr ""
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, gcc-internal-format
 msgid "module %qs imported here"
 msgstr ""
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown Compiled Module Interface: %s"
 msgstr ""
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr ""
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr ""
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr ""
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, gcc-internal-format
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr ""
 
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, gcc-internal-format
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr ""
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr ""
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr ""
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, gcc-internal-format
 msgid "you should use the %<-%s%> option"
 msgstr ""
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, gcc-internal-format
 msgid "invalid header name %qs"
 msgstr ""
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, gcc-internal-format
 msgid "invalid module name %qs"
 msgstr ""
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr ""
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, gcc-internal-format
 msgid "writing CMI %qs"
 msgstr ""
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, gcc-internal-format
 msgid "not writing module %qs due to errors"
 msgstr ""
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to write compiled module: %s"
 msgstr "nije uspjelo zapisati kompilirani modul: %s"
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, gcc-internal-format
 msgid "unknown header kind %qs"
 msgstr ""
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, gcc-internal-format
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr "deklaracije neovisne o imenu dostupne su samo s %<-std=c++2c%> ili %<-std=gnu++2c%>"
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr ""
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr ""
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D skriva konstruktora za %q#D"
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr ""
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr ""
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr ""
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr ""
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr ""
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr ""
 
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr ""
 
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d"
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, gcc-internal-format
 msgid "exporting %q#D that does not have external linkage"
 msgstr ""
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, gcc-internal-format
 msgid "%q#D declared here with no linkage"
 msgstr ""
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, gcc-internal-format
 msgid "%q#D declared here with internal linkage"
 msgstr ""
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, gcc-internal-format
 msgid "%q#D declared here with module linkage"
 msgstr ""
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr ""
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr ""
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr ""
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr ""
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, gcc-internal-format
 msgid "%qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr ""
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr ""
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr ""
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -59649,93 +59687,93 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr ""
 
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr ""
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr ""
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr ""
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr ""
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, gcc-internal-format
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr ""
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr ""
 
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr ""
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr ""
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -59760,7 +59798,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -60006,7 +60044,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
@@ -60186,7 +60224,7 @@ msgstr ""
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr ""
@@ -60241,7 +60279,7 @@ msgstr ""
 msgid "template-id not allowed for destructor in C++20"
 msgstr ""
 
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, gcc-internal-format
 msgid "remove the %qs"
 msgstr ""
@@ -60261,7 +60299,7 @@ msgstr ""
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr ""
@@ -60311,7 +60349,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr ""
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr ""
@@ -60346,7 +60384,7 @@ msgstr ""
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr ""
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr ""
@@ -60371,7 +60409,7 @@ msgstr ""
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr ""
@@ -60521,8 +60559,8 @@ msgstr ""
 msgid "capture of non-variable %qE"
 msgstr ""
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr ""
@@ -60562,7 +60600,7 @@ msgstr ""
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr ""
@@ -60687,7 +60725,7 @@ msgstr ""
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
@@ -60749,7 +60787,7 @@ msgstr ""
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
@@ -60775,7 +60813,7 @@ msgstr ""
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
@@ -61056,12 +61094,12 @@ msgstr ""
 msgid "cannot expand initializer for member %qD"
 msgstr ""
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -61699,7 +61737,7 @@ msgstr ""
 msgid "%qT not permitted in template argument"
 msgstr ""
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, gcc-internal-format
 msgid "invalid use of %qT"
@@ -61878,12 +61916,12 @@ msgstr ""
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, gcc-internal-format
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr ""
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
@@ -62085,37 +62123,37 @@ msgstr ""
 msgid "expression must be enclosed in parentheses"
 msgstr ""
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr ""
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr ""
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr ""
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr ""
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -62124,437 +62162,437 @@ msgstr ""
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, gcc-internal-format
 msgid "template-id not allowed for constructor in C++20"
 msgstr ""
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, gcc-internal-format
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, gcc-internal-format
 msgid "duplicate %qD specifier"
 msgstr ""
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, gcc-internal-format
 msgid "%qD specifier conflicts with %qs"
 msgstr ""
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, gcc-internal-format
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr ""
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr ""
 
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr ""
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr ""
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr ""
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr ""
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr ""
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr ""
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr ""
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr ""
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr ""
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr ""
 
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr ""
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr ""
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr ""
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr ""
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "očekivano je %<auto%>"
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr ""
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "očekivano je %<co_yield%>"
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr ""
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr ""
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr ""
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr ""
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr ""
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr ""
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr ""
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr ""
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr ""
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, gcc-internal-format
 msgid "expected integer expression list"
 msgstr ""
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr "očekivano je %<scalar%>, %<aggregate%>, %<all%>"
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr ""
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr ""
@@ -62563,12 +62601,12 @@ msgstr ""
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr ""
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
@@ -62578,133 +62616,133 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr ""
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr ""
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr ""
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr ""
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr ""
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, gcc-internal-format
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr ""
 
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, gcc-internal-format
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr ""
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr ""
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr ""
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -62734,7 +62772,7 @@ msgstr ""
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
@@ -62749,170 +62787,170 @@ msgstr ""
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr ""
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr ""
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr ""
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, gcc-internal-format
 msgid "from definition of %q#D"
 msgstr ""
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr ""
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr ""
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr ""
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr ""
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr ""
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr ""
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr ""
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr ""
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr ""
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr ""
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr ""
@@ -62925,137 +62963,137 @@ msgstr ""
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr ""
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr ""
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, gcc-internal-format
 msgid "friend declaration here"
 msgstr ""
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr ""
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr ""
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr ""
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr ""
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr ""
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr ""
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr ""
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr ""
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr ""
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -63063,17 +63101,17 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr ""
@@ -63082,47 +63120,47 @@ msgstr ""
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr ""
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -63132,62 +63170,62 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr ""
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr ""
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr ""
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, gcc-internal-format
 msgid "redeclaration of %qD with different constraints"
 msgstr "ponovna deklaracija %qD s drukčijim ograničenjima"
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr ""
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -63195,7 +63233,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -63203,437 +63241,437 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr ""
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, gcc-internal-format
 msgid "redeclared here"
 msgstr "ponovno deklarirano ovdje"
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr ""
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr ""
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, gcc-internal-format
 msgid "redeclaration of %q#D with different constraints"
 msgstr "ponovljena deklaracija %q#D s drugačijim ograničenjima"
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr ""
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr ""
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr ""
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr ""
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr ""
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr ""
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr ""
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr ""
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr ""
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr ""
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr ""
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr ""
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr ""
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr ""
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr ""
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr ""
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr ""
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr ""
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr ""
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr ""
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr ""
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr ""
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, gcc-internal-format, gfc-internal-format
 msgid "mismatched argument pack lengths (%d vs %d)"
 msgstr ""
@@ -63651,301 +63689,301 @@ msgstr ""
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr ""
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr ""
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr ""
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "funkcija vraća polje"
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "funkcija vraća funkciju"
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr ""
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr ""
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, gcc-internal-format
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr ""
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr ""
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr ""
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr ""
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 msgid "%s %#qS"
 msgstr ""
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr ""
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -63957,163 +63995,163 @@ msgstr ""
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr ""
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr ""
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr ""
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr ""
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr ""
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr ""
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr ""
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "ograničenja rezerviranog mjesta nisu zadovoljena"
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "izvedeni povratni tip ne zadovoljava ograničenja rezerviranog mjesta"
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "izvedeni povratni tip ne zadovoljava ograničenja rezerviranog mjesta"
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "izvedeni povratni tip ne zadovoljava ograničenja rezerviranog mjesta"
 
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr ""
@@ -64319,630 +64357,630 @@ msgstr ""
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr ""
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr ""
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, gcc-internal-format
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr ""
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, gcc-internal-format
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr ""
 
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr ""
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr ""
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr ""
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, gcc-internal-format
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr ""
 
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, gcc-internal-format
 msgid "use explicit object parameter %qs instead"
 msgstr ""
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, gcc-internal-format
 msgid "name the explicit object parameter"
 msgstr ""
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr ""
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, gcc-internal-format
 msgid "invalid use of %<this%> before it is valid"
 msgstr ""
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, gcc-internal-format
 msgid "invalid use of %<this%> after it is valid"
 msgstr ""
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr ""
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr ""
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr ""
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, gcc-internal-format
 msgid "%<auto{x}%> cannot be constrained"
 msgstr ""
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, gcc-internal-format
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr ""
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr ""
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr ""
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr ""
 
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr ""
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr ""
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr ""
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr ""
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is out of range"
 msgstr "index %<__type_pack_element%> je izvan raspona"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr ""
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, gcc-internal-format
 msgid "pointer-to-member mapping %qE not supported"
 msgstr ""
 
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, gcc-internal-format
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr ""
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr ""
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr ""
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr ""
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr ""
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr ""
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr ""
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr ""
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, gcc-internal-format
 msgid "%<filter%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr ""
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr ""
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr ""
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr ""
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr ""
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, gcc-internal-format
 msgid "static assertion failed: %.*s"
 msgstr ""
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr ""
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr ""
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr ""
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr ""
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr ""
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr ""
@@ -64950,1158 +64988,1158 @@ msgstr ""
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr ""
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr ""
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, gcc-internal-format
 msgid " declared here"
 msgstr ""
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr ""
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, gcc-internal-format
 msgid "%qD is not public"
 msgstr ""
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, gcc-internal-format
 msgid "%qD is mutable"
 msgstr ""
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr ""
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr ""
 
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr ""
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr ""
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr ""
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, gcc-internal-format
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr ""
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr ""
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr ""
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, gcc-internal-format
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr ""
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr ""
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr ""
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr ""
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr ""
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr ""
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr ""
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr ""
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr ""
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr ""
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr ""
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr ""
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, gcc-internal-format
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr ""
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr ""
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr ""
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr ""
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr ""
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr ""
 
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr ""
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr ""
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr ""
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr ""
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr ""
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr ""
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr ""
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr ""
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr ""
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr ""
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr ""
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr ""
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr ""
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr ""
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, gcc-internal-format
 msgid "the address %qE will never be NULL"
 msgstr ""
 
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr ""
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr ""
 
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr ""
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr ""
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr ""
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr ""
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr ""
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr ""
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr ""
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr ""
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, gcc-internal-format
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr ""
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr ""
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr ""
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr ""
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr ""
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr ""
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr ""
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr ""
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr ""
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 msgid "converting from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, gcc-internal-format
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr ""
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr ""
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, gcc-internal-format
 msgid "moving %qE of type %qT to itself"
 msgstr ""
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr ""
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr ""
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr ""
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr ""
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 msgid "cannot convert %qH to %qI in default argument"
 msgstr ""
 
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr ""
 
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 msgid "cannot convert %qH to %qI in initialization"
 msgstr ""
 
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 msgid "cannot convert %qH to %qI in return"
 msgstr ""
 
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 msgid "cannot convert %qH to %qI in assignment"
 msgstr ""
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr ""
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, gcc-internal-format
 msgid "returning pointer to temporary"
 msgstr ""
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr ""
 
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, gcc-internal-format
 msgid "redundant move in initialization"
 msgstr ""
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr ""
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, gcc-internal-format
 msgid "not eliding copy on return from %qD"
 msgstr ""
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr ""
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr ""
@@ -66322,155 +66360,155 @@ msgstr ""
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr ""
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr ""
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr ""
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, gcc-internal-format
 msgid "initializer-string for %qT is too long"
 msgstr ""
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, gcc-internal-format
 msgid "remove %<{ }%> around initializer"
 msgstr ""
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr ""
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr ""
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -67448,7 +67486,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr ""
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr ""
@@ -68771,7 +68809,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -68986,7 +69024,7 @@ msgstr ""
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr ""
@@ -69787,7 +69825,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
@@ -70594,12 +70632,12 @@ msgstr ""
 msgid "are_identical_variables: Bad type"
 msgstr ""
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr ""
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr ""
@@ -70847,273 +70885,273 @@ msgstr ""
 msgid "check_init_expr(): Unknown expression type"
 msgstr ""
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr ""
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr ""
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, gcc-internal-format
 msgid "Specification function %qs at %L must be PURE"
 msgstr ""
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr ""
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, gcc-internal-format
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr ""
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr ""
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr ""
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr ""
 
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, gcc-internal-format
 msgid "check_restricted(): Unknown expression type"
 msgstr ""
 
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, gcc-internal-format
 msgid "Function %qs at %L must be PURE"
 msgstr ""
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr ""
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr ""
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr ""
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr ""
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr ""
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal assignment to external procedure at %L"
 msgstr ""
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr ""
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr ""
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr ""
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr ""
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr ""
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
@@ -71121,192 +71159,192 @@ msgstr ""
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr ""
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr ""
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, gcc-internal-format, gfc-internal-format
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr ""
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr ""
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr ""
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr ""
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, gcc-internal-format
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, gcc-internal-format
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr ""
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -71327,8 +71365,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr ""
@@ -71408,7 +71446,7 @@ msgstr ""
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -71543,12 +71581,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -72418,7 +72456,7 @@ msgstr ""
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr ""
@@ -72969,7 +73007,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -73135,6 +73173,11 @@ msgstr ""
 msgid "check_charlen_present(): length not set"
 msgstr ""
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr ""
+
 #: fortran/match.cc:118
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
@@ -73536,7 +73579,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr ""
@@ -74059,82 +74102,82 @@ msgstr ""
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr ""
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr ""
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr ""
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr ""
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr ""
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr ""
 
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr ""
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr ""
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -75550,8 +75593,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -77914,12 +77957,12 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -78039,7 +78082,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -78438,278 +78481,283 @@ msgstr ""
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, gcc-internal-format
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr ""
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid array reference at %L"
+msgstr ""
+
+#: fortran/resolve.cc:6433
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs se ne smije pojaviti u specifikaciji polja pri %L u istoj ALLOCATE izjavi gdje je i sam dodijeljen"
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -78718,284 +78766,284 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -79003,212 +79051,212 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, gcc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr ""
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -79216,999 +79264,999 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr ""
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr ""
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr ""
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr ""
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr ""
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant character length at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr ""
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr ""
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -80752,330 +80800,330 @@ msgstr ""
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr ""
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, gcc-internal-format
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr ""
+
+#: fortran/symbol.cc:508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr ""
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr ""
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, gcc-internal-format
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr ""
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr ""
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, gcc-internal-format, gfc-internal-format
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr ""
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, gcc-internal-format
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr ""
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr ""
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr ""
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr ""
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr ""
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr ""
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr ""
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr ""
 
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr ""
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr ""
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr ""
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -81105,24 +81153,24 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -81308,37 +81356,37 @@ msgstr ""
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr ""
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr ""
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -81349,17 +81397,17 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr ""
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr ""
@@ -81499,7 +81547,7 @@ msgstr ""
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr ""
@@ -81865,6 +81913,11 @@ msgstr "varijable %qD je ponovno deklarirana kao funkcija"
 msgid "function %qD redeclared as variable"
 msgstr "funkcija %qD je ponovno deklarirana kao varijabla"
 
+#: lto/lto-symtab.cc:865
+#, gcc-internal-format
+msgid "previously declared here"
+msgstr "ranije deklarirana ovdje"
+
 #: lto/lto.cc:174
 #, gcc-internal-format
 msgid "%<lto_obj_file_open()%> failed"
@@ -83102,7 +83155,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr ""
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, gcc-internal-format
 msgid "non-objective-c type %qT cannot be caught"
 msgstr ""
@@ -83112,7 +83165,7 @@ msgstr ""
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr ""
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, gcc-internal-format
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
 msgstr ""
diff --git a/gcc/po/id.po b/gcc/po/id.po
index 156aa92cf72..bbdda773c9f 100644
--- a/gcc/po/id.po
+++ b/gcc/po/id.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 4.4.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
 "PO-Revision-Date: 2009-11-10 09:00+0700\n"
 "Last-Translator: Arif E. Nugroho <arif_endro@yahoo.com>\n"
 "Language-Team: Indonesian <translation-team-id@lists.sourceforge.net>\n"
@@ -446,7 +446,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr "Jangan spesifikasikan baik -march=... dan -mcpu=..."
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 msgid "shared and mdll are not compatible"
 msgstr "shared dan mdll tidak kompatibel"
 
@@ -21402,18 +21402,18 @@ msgstr "insn tidak dikenal:"
 msgid "insn does not satisfy its constraints:"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "dibuat dan digunakan dengan konfigurasi berbeda dari '%s'"
 
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "dibuat dan digunakan dengan konfigurasi berbeda dari -fpic"
 
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 #, fuzzy
 #| msgid "created and used with different settings of -fpie"
 msgid "created and used with different settings of %<-fpie%>"
@@ -21741,7 +21741,7 @@ msgstr "pemodifikasi panjang dalam format strfmon"
 msgid "<command-line>"
 msgstr "<baris-perintah>"
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "unsupported operand for code '%c'"
@@ -21762,9 +21762,9 @@ msgstr "operan tidak valid untuk kode '%c'"
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid vector constant"
@@ -21787,7 +21787,7 @@ msgstr "operan tidak valid untuk kode '%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, c-format
 msgid "missing operand"
 msgstr "hilang operan"
@@ -21822,93 +21822,93 @@ msgstr "alamat tidak valid"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "operan tidak valid dalam operasi binary"
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, c-format
 msgid "invalid %%J value"
 msgstr "nilai %%J tidak valid"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, c-format
 msgid "invalid %%r value"
 msgstr "nilai %%r tidak valid"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, c-format
 msgid "invalid %%R value"
 msgstr "nilai %%R tidak valid"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, c-format
 msgid "invalid %%N value"
 msgstr "nilai %%N tidak valid"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, c-format
 msgid "invalid %%P value"
 msgstr "nilai %%P tidak valid"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, c-format
 msgid "invalid %%h value"
 msgstr "nilai %%h tidak valid"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, c-format
 msgid "invalid %%L value"
 msgstr "nilai %%L tidak valid"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, c-format
 msgid "invalid %%m value"
 msgstr "nilai %%m tidak valid"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, c-format
 msgid "invalid %%M value"
 msgstr "nilai %%M tidak valid"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, c-format
 msgid "invalid %%U value"
 msgstr "nilai %%U tidak valid"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, c-format
 msgid "invalid %%s value"
 msgstr "nilai %%s tidak valid"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, c-format
 msgid "invalid %%C value"
 msgstr "nilai %%C tidak valid"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, c-format
 msgid "invalid %%E value"
 msgstr "nilai %%E tidak valid"
 
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "relokasi unspek tidak diketahui"
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, c-format
 msgid "invalid %%xn code"
 msgstr "kode %%xn tidak valid"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid operand address"
@@ -22011,36 +22011,36 @@ msgstr "UNSPEC tidak valid sebagai operan"
 msgid "unrecognized supposed constant"
 msgstr "konstanta yang diharapkan tidak dikenal"
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, c-format
 msgid "invalid shift operand"
 msgstr "operan shift tidak valid"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "instruksi Thumb terprediksi"
 
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instruksi terprediksi dalam urutan berkondisi"
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "Unsupported operand for code '%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -22048,129 +22048,129 @@ msgstr "operan tidak valid untuk kode '%c'"
 msgid "invalid operand for code '%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, c-format
 msgid "instruction never executed"
 msgstr "instruksi tidak pernah dijalankan"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "konversi dari %<__fpreg%> tidak valid"
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "konversi tidak valid ke tipe %qT dari tipe %qT"
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "alamat operan membutuhkan batasan untuk X, Y, atau Z register"
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 #, fuzzy
 #| msgid "output operand %d must use %<&%> constraint"
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "keluaran operan %d harus menggunakan batasan %<&%>"
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 #, fuzzy
 #| msgid "bad address, not (reg+disp):"
 msgid "bad address, not an I/O address:"
 msgstr "alamat buruk, bukan (reg+disp):"
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 #, fuzzy
 #| msgid "address offset not a constant"
 msgid "bad address, not a constant:"
 msgstr "ofset alamat bukan sebuah konstanta"
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 msgid "bad address, not (reg+disp):"
 msgstr "alamat buruk, bukan (reg+disp):"
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "alamat buruk, bukan post_inc atau pre_dec:"
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr "internal kompiler error. Alamat buruk:"
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 msgid "internal compiler error.  Unknown mode:"
 msgstr "internal kompiler error. Kode tidak diketahui:"
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 msgid "invalid insn:"
 msgstr "insn tidak valid:"
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 msgid "incorrect insn:"
 msgstr "insn tidak benar:"
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 msgid "unknown move insn:"
 msgstr "insn move tidak dikenal:"
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 msgid "bad shift insn:"
 msgstr "shift insn buruk:"
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "internal kompiler error. shift tidak benar:"
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 #, fuzzy
 #| msgid "invalid types in fixed-point conversion"
 msgid "unsupported fixed-point conversion"
 msgstr "tipe tidak valid dalam konversi titik tetap"
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 msgid "variable"
 msgstr ""
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "function parameter"
 msgstr "redefinisi dari parameter %q+D"
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 msgid "structure field"
 msgstr ""
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 #, fuzzy
 #| msgid "function return type cannot be function"
 msgid "return type of function"
 msgstr "tipe kembali fungsi tidak dapat berupa fungsi"
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 msgid "pointer"
 msgstr ""
 
@@ -22209,7 +22209,7 @@ msgstr "operan tidak terduga"
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -22545,55 +22545,55 @@ msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "kode operan '%c' tidak valid"
 
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "batasan untuk operan tidak valid"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, fuzzy, c-format
 #| msgid "invalid controlling predicate"
 msgid "invalid vector immediate"
 msgstr "predikat pengontrol tidak valid"
 
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 msgid "unknown insn mode"
 msgstr "mode insn tidak diketahui"
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr "konversi dari %<__fpreg%> tidak valid"
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr "konversi dari %<__fpreg%> tidak valid"
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr "konversi ke %<__fpreg%> tidak valid"
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr "konversi tidak valid ke tipe %qT dari tipe %qT"
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
 msgstr ""
 
@@ -22625,7 +22625,7 @@ msgstr "operasi di %<__fpreg%> tidak valid"
 msgid "invalid %%P operand"
 msgstr "operan %%P tidak valid"
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, c-format
 msgid "invalid %%p value"
 msgstr "nilai %%p tidak valid"
@@ -22656,29 +22656,29 @@ msgstr ""
 msgid "invalid addressing mode"
 msgstr "alamat tidak valid"
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, c-format
 msgid "'%%%c' is not a valid operand prefix"
 msgstr "'%%%c' bukan sebuah awalan operan yang valid"
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "penggunaan dari '%%%c' tidak valid"
@@ -22710,7 +22710,7 @@ msgid "post-increment address is not a register"
 msgstr "alamat post-increment bukan sebuah register"
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 msgid "bad address"
 msgstr "alamat buruk"
 
@@ -22884,7 +22884,7 @@ msgstr "kombinasi tidak didukung: %s"
 msgid "unsupported memory expression:"
 msgstr "diduga ekspresi integer"
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, fuzzy, c-format
 #| msgid "invalid %%c operand"
 msgid "invalid vector operand"
@@ -22939,275 +22939,275 @@ msgstr ""
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "tes buruk"
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%A value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%D value"
 msgstr "nilai %%D tidak valid"
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, c-format
 msgid "invalid %%f value"
 msgstr "nilai %%f tidak valid"
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, c-format
 msgid "invalid %%F value"
 msgstr "nilai %%F tidak valid"
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, c-format
 msgid "invalid %%G value"
 msgstr "nilai %%G tidak valid"
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, c-format
 msgid "invalid %%j code"
 msgstr "kode %%j tidak valid"
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, c-format
 msgid "invalid %%J code"
 msgstr "kode %%J tidak valid"
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, c-format
 msgid "invalid %%k value"
 msgstr "nilai %%k tidak valid"
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, c-format
 msgid "invalid %%K value"
 msgstr "nilai %%K tidak valid"
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, c-format
 msgid "invalid %%O value"
 msgstr "nilai %%O tidak valid"
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, c-format
 msgid "invalid %%q value"
 msgstr "nilai %%q tidak valid"
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, c-format
 msgid "invalid %%T value"
 msgstr "nilai %%T tidak valid"
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, c-format
 msgid "invalid %%u value"
 msgstr "nilai %%u tidak valid"
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, c-format
 msgid "invalid %%v value"
 msgstr "nilai %%v tidak valid"
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, c-format
 msgid "invalid %%x value"
 msgstr "nilai %%x tidak valid"
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "nilai %%ytidak valid, coba menggunakan batasan 'Z'"
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Argumen AltiVec dilewatkan ke fungsi yang tidak berprototipe"
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Jangan hasilkan sebuah titik keluar tunggal untuk setiap fungsi"
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "tidak dapat menghasilkan reloads untuk:"
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "konversi dari %<__fpreg%> tidak valid"
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "konversi ke %<__fpreg%> tidak valid"
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "konversi dari %<__fpreg%> tidak valid"
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "konversi ke %<__fpreg%> tidak valid"
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, c-format
 msgid "cannot decompose address"
 msgstr "tidak dapat menguraikan alamat"
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'b'"
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid reference for 'J' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'b'"
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, fuzzy, c-format
 #| msgid "invalid operand for 'O' modifier"
 msgid "invalid address for 'O' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'O'"
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'R' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'b'"
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'S' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'b'"
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant for output modifier '%c'"
 msgstr "operan tidak valid untuk pemodifikasi 'o'"
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, fuzzy, c-format
 #| msgid "invalid operand output code"
 msgid "invalid constant - try using an output modifier"
 msgstr "operan kode keluaran tidak valid"
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "operan tidak valid untuk pemodifikasi 'o'"
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, fuzzy, c-format
 #| msgid "invalid expression for min lvalue"
 msgid "invalid expression - try using an output modifier"
 msgstr "ekspresi tidak valid untuk minimal lvalue"
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid expression for output modifier '%c'"
 msgstr "operan tidak valid untuk pemodifikasi 'o'"
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "Argumen AltiVec dilewatkan ke fungsi yang tidak berprototipe"
 
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "target penunjuk dalam kembali berbeda dalam signedness"
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -23411,12 +23411,12 @@ msgstr "<anonim>"
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "diduga %<,%>"
@@ -23429,7 +23429,7 @@ msgstr "diduga %<,%>"
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -23438,7 +23438,7 @@ msgstr "diduga %<,%>"
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -23447,7 +23447,7 @@ msgstr "diduga %<{%>"
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -23461,30 +23461,30 @@ msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "diduga %<(%>"
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
 msgstr "diduga %<{%>"
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "diduga %<{%>"
@@ -23494,18 +23494,18 @@ msgstr "diduga %<{%>"
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
@@ -23515,8 +23515,8 @@ msgstr "diduga %<{%>"
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -23529,19 +23529,19 @@ msgid "expected %<.%>"
 msgstr "diduga %<{%>"
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -23550,34 +23550,34 @@ msgstr "diduga %<,%> atau %<,%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "diduga %<=%>"
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<else%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "diduga %<#pragma omp section%> atau %<}%>"
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr ""
 
@@ -23587,7 +23587,7 @@ msgstr ""
 msgid "(anonymous)"
 msgstr "<anonim>"
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -23606,13 +23606,13 @@ msgstr "Diduga nama"
 msgid "candidate:"
 msgstr "kandidat 1:"
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 #, fuzzy
 #| msgid "type %qs has a user-defined constructor"
 msgid "  after user-defined conversion:"
 msgstr "tipe %qs memiliki sebuah konstruktor yang didefinisikan pengguna"
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -23620,11 +23620,11 @@ msgid_plural "candidates are:"
 msgstr[0] "kandidat 1:"
 msgstr[1] "kandidat 1:"
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr "kandidat 1:"
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr "kandidat 2:"
 
@@ -23908,7 +23908,7 @@ msgstr ""
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 msgid "candidates are:"
 msgstr "kandidat adalah:"
 
@@ -23968,54 +23968,54 @@ msgstr "konversi ke %qT mengubah nilai konstanta %qT"
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "tipe argumen salah ke unary minus"
 
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "tipe argume salah ke unary plus"
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "tipe argumen salah ke bit-complement"
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "tipe argumen salah ke abs"
 
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "tipe argumen salah ke konjugasi"
 
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "tipe argume salah ke unary plus"
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 #, fuzzy
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "no pre-increment operator for type"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 #, fuzzy
 #| msgid "cannot decrement a pointer to incomplete type %qT"
 msgid "no pre-decrement operator for type"
 msgstr "tidak dapat mengurangi penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -24098,7 +24098,7 @@ msgstr ""
 msgid "Deleted feature:"
 msgstr ""
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 msgid "array assignment"
 msgstr "penempatan array"
 
@@ -24295,11 +24295,11 @@ msgstr "blok IF"
 msgid "implied END DO"
 msgstr "Diimplikasikan END DO"
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 msgid "assignment"
 msgstr "assignment"
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 msgid "pointer assignment"
 msgstr "assignmen penunjuk"
 
@@ -24497,59 +24497,59 @@ msgstr "Operan dari operator pengguna '%s' di %%L adalah %s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operan dari operator pengguna '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 #, fuzzy
 #| msgid "%qD is not a variable"
 msgid "iterator variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "ekspresi sebagai operan tidak valid"
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "DEALOKASIKAN "
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "ALOKASIKAN "
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -24559,11 +24559,11 @@ msgstr ""
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "Pajang KARAKTER berbeda (%d/%d) dalam konstruktor array di %L"
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
@@ -24580,12 +24580,12 @@ msgstr "Argumen aktual berisi terlalu sedikit elemen untuk argumen dummy '%s' (%
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Argumen aktual berisi terlalu sedikit elemen untuk argumen dummy '%s' (%lu/%lu) di %L"
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -24595,84 +24595,84 @@ msgstr ""
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Panjang karakter tidak sama (%ld/%ld) dalam %s di %L"
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, c-format
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, fuzzy, c-format
 #| msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Argumen NCOPIES dari REPEAT intrinsik adalah negatif di %L"
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 #, fuzzy
 #| msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "Argumen NCOPIES dari REPEAT intrinsik adalah terlalu besar di %L"
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, c-format
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, c-format
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
@@ -24698,15 +24698,15 @@ msgstr ""
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 msgid "Loop variable has been modified"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 msgid "DO step value is zero"
 msgstr ""
 
@@ -24798,7 +24798,7 @@ msgid "expected boolean type"
 msgstr "diduga bukan tuple"
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -24880,7 +24880,7 @@ msgstr "tidak ada argumen"
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments for format"
 msgid "too many arguments"
@@ -25625,7 +25625,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "-mrelax hanya didukung untuk RTP PIC"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Sintaks error dalam pernyataan %s di %C"
@@ -26118,8 +26118,8 @@ msgstr "%qE atribut konflik dengan atribut %s"
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration here"
@@ -26139,7 +26139,7 @@ msgstr "%qs atribut direktif diabaikan"
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr "%qs atribut direktif diabaikan"
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments specified for %qE attribute"
@@ -26151,7 +26151,7 @@ msgstr "jumlah dari argumen salah dispesifikasikan untuk atribut %qs"
 msgid "expected %i or more, found %i"
 msgstr "diduga %<(%> atau akhir dari baris"
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %i, found %i"
@@ -26221,12 +26221,12 @@ msgstr "tipe atribut diabaikan setelah tipe telah didefinisikan"
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -26235,7 +26235,7 @@ msgstr "tipe atribut diabaikan setelah tipe telah didefinisikan"
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -26257,8 +26257,8 @@ msgstr "%qE atribut diabaikan"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %qD"
@@ -26377,7 +26377,7 @@ msgstr "tidak dapat menemukan berkas untuk class %s"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "ofset diluar dari jangkauan dari konstanta string"
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qE declared here"
@@ -26493,7 +26493,7 @@ msgstr "hilang argumen ke \"%s\""
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, fuzzy, gcc-internal-format
 #| msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
@@ -26517,45 +26517,45 @@ msgstr "%<__builtin_longjmp%> argumen kedua harus berupa 1"
 msgid "target format does not support infinity"
 msgstr "format target tidak mendukung infinity"
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, fuzzy, gcc-internal-format
 #| msgid "%<va_start%> used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> digunakan dalam fungsi dengan argumen tetap"
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "jumlah dari argumen ke fungsi %<va_start%> salah"
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> dipanggil tanpa sebuah argumen"
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "parameter kedua dari %<va_start%> bukan argumen bernama terakhir"
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, fuzzy, gcc-internal-format
 #| msgid "undefined behaviour when second parameter of %<va_start%> is declared with %<register%> storage"
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "perilaku tidak terdefinisi ketika parameter kedua dari %<va_start%> dideklarasikan dengan penyimpanan %<register%>"
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr "%K argumen pertama dari %D harus berupa sebuah penunjuk, integer kedua konstanta"
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, fuzzy, gcc-internal-format
 #| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "last argument of %qD is not integer constant between 0 and 3"
@@ -27675,12 +27675,12 @@ msgstr "%qE atribut diabaikan karena %qT telah didefinisikan"
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F digunakan tetapi tidak pernah didefinisikan"
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
@@ -28280,7 +28280,7 @@ msgstr "array tidak cocok dengan daerah pohon"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "array tidak cocok dengan daerah pohon"
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, gcc-internal-format
 msgid "%qs failed"
 msgstr ""
@@ -28310,19 +28310,19 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, fuzzy, gcc-internal-format
 #| msgid "%Kcall to %qs declared with attribute error: %s"
 msgid "call to %qs declared with attribute error: %s"
 msgstr "%K panggilan ke %qs dideklarasikan dengan atribut error: %s"
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, fuzzy, gcc-internal-format
 #| msgid "%Kcall to %qs declared with attribute warning: %s"
 msgid "call to %qs declared with attribute warning: %s"
 msgstr "%K panggilan ke %qs dideklarasikan dengan atribut peringatan: %s"
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, fuzzy, gcc-internal-format
 #| msgid "assuming signed overflow does not occur when simplifying && or || to & or |"
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
@@ -28362,7 +28362,7 @@ msgstr "konstanta titik-tetap besar secara implisit dipotong ke tipe titik-tetap
 msgid "comparison is always %d due to width of bit-field"
 msgstr "perbandingan selalu %d karena lebar dari bit-field"
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "diasumsikan signed overflow tidak terjadi ketika menyederhanakan pemeriksaan jangkauan"
@@ -28546,7 +28546,7 @@ msgstr "gagal untuk memperoleh waktu pemrosesan"
 msgid "%s signal terminated program %s"
 msgstr "Gunakan nama alternatif register"
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized command-line option %qs"
@@ -28839,7 +28839,7 @@ msgstr "spesifikasi multilib '%s' tidak valid"
 msgid "multilib exclusions %qs is invalid"
 msgstr "ekslusi multilib '%s' tidak valid"
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, fuzzy, gcc-internal-format
 #| msgid "multilib select '%s' is invalid"
 msgid "multilib select %qs %qs is invalid"
@@ -29176,23 +29176,23 @@ msgstr ""
 msgid "%qD specified bound %E equals source length"
 msgstr ""
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, gcc-internal-format
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr ""
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr ""
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "%s not supported for variable length aggregates"
 msgstr "%s tidak didukung untuk fungsi nested"
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spe not supported in this target"
 msgid "%s not supported on this target"
@@ -29237,16 +29237,16 @@ msgid "function returns address of local variable"
 msgstr "fungsi mengembalikan alamat dari variabel lokal"
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, fuzzy, gcc-internal-format
@@ -29259,369 +29259,369 @@ msgstr "%q+D dideklarasikan disini"
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, gcc-internal-format
 msgid "referenced argument declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "directive argument %qE"
 msgstr "pilihan argumen %qs tidak valid"
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, fuzzy, gcc-internal-format
 #| msgid "%s expects an integer literal in the range [%d, %d]."
 msgid "directive argument in the range [%E, %E]"
 msgstr "%s diduga sebuah integer literal dalam jangkauan [%d, %d]."
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgid_plural "%qE output %wu bytes into a destination of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 msgid "%qE argument %Z overlaps destination object %qE"
 msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 msgid "%qE argument %Z may overlap destination object %qE"
 msgid_plural "%qE arguments %Z may overlap destination object %qE"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, gcc-internal-format
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, fuzzy, gcc-internal-format
 #| msgid "Maintain backchain pointer"
 msgid "null destination pointer"
 msgstr "jaga backchain penunjuk"
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, fuzzy, gcc-internal-format
 #| msgid "%s in format string at %L"
 msgid "null format string"
@@ -30384,12 +30384,12 @@ msgstr "mode pointer tidak valid %qs"
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -31205,7 +31205,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of attribute %<fallthrough%>"
@@ -31560,17 +31560,17 @@ msgstr ""
 msgid "mismatching definition"
 msgstr "hilang definisi"
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr ""
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, gcc-internal-format
 msgid "IPA modref summary is missing in input file"
 msgstr ""
@@ -32701,82 +32701,82 @@ msgstr "error menulis ke %s: %m"
 msgid "error closing optimization records %qs"
 msgstr "Lakukan optimisasi cross-jumping"
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, fuzzy, gcc-internal-format
 #| msgid "command line option %qs is not supported by this configuration"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "pilihan baris perintah %qs tidak didukung dalam konfigurasi ini"
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"%s\""
 msgid "missing argument to %qs"
 msgstr "hilang argumen ke \"%s\""
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr "argumen ke \"%s\" seharusnya sebuah integer tidak negatif"
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "argument to %qs should be a non-negative integer"
 msgstr "argumen ke \"%s\" seharusnya sebuah integer tidak negatif"
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, fuzzy, gcc-internal-format
 #| msgid "%sregparm=%d%s is not between 0 and %d"
 msgid "argument to %qs is not between %d and %d"
 msgstr "%sregparm=%d%s tidak berada diantara 0 dan %d"
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid argument in option %qs"
 msgstr "tipe argumen tidak valid dari %qs"
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr ""
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, gcc-internal-format
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr ""
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized argument in option %qs"
 msgstr "pilihan baris perintah \"%s\" tidak dikenal"
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "pilihan %qs tidak lagi didukung"
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qs is bigger than %d"
 msgstr "argumen ke atribut %qs lebih besar daripada %d"
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, gcc-internal-format
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
 msgstr ""
@@ -32857,8 +32857,8 @@ msgstr "argumen ke \"%s\" seharusnya sebuah integer tidak negatif"
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%qs is incompatible with %qs"
@@ -33638,7 +33638,7 @@ msgstr "variabel register global mengikuti sebuah definisi fungsi"
 msgid "register of %qD used for multiple global register variables"
 msgstr "register digunakan untuk dua variabel register global"
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, fuzzy, gcc-internal-format
 #| msgid "  conflict with %q+D"
 msgid "conflicts with %qD"
@@ -34116,47 +34116,47 @@ msgstr ""
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "__builtin_saveregs tidak didukung oleh target ini"
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "-fdata-sections tidak didukung untuk target ini"
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, fuzzy, gcc-internal-format
 #| msgid "global destructors not supported on this target"
 msgid "nested functions not supported on this target"
 msgstr "global desktruktor tidak didukung di target ini"
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, fuzzy, gcc-internal-format
 #| msgid "-ffunction-sections not supported for this target"
 msgid "nested function trampolines not supported on this target"
 msgstr "-ffunction-sections tidak didukung untuk target ini"
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "global konstruktor tidak didukung di target ini"
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "global desktruktor tidak didukung di target ini"
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute is not supported on this machine"
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "atribut target tidak didukung di platform ini"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute is not supported on this machine"
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "atribut target tidak didukung di platform ini"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "%<#pragma GCC target%> is not supported for this machine"
@@ -35383,89 +35383,89 @@ msgstr "BB %i pernyataan terakhir memiliki daerah set tidak benar"
 msgid "BB %i has incorrect fallthru edge"
 msgstr "insn salah dalam ujung fallthru"
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it receives a non-local goto"
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr "fungsi %q+F tidak akan dapat inline karena ini menerima sebuah goto bukan lokal"
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it saves address of local label in a static variable"
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr "fungsi %q+F tidak akan dapat inline karena ini menyimpan alamat dari label lokal dalam sebuah variabel statis"
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr "fungsi %q+F tidak akan dapat terinline karena ini menggunakan alloca (override menggunaka always_inline atribut)"
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr "fungsi %q+F tidak akan dapat inline karena ini menggunakan setjmp"
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr "fungsi %q+F tidak akan dapat inline karena ini menggunakan daftar argumen variabel"
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr "fungsi %q+F tidak akan dapat inline karena ini menggunakan penanganan setjmp-longjmp exception"
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr "fungsi %q+F tidak akan dapat inline karena ini menggunakan goto tidak lokal"
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses __builtin_return or __builtin_apply_args"
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr "fungsi %q+F tidak akan dapat inline karena ini menggunakan __builtin_return atau __builtin_apply_args"
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr "fungsi %q+F tidak akan dapat inline karena ini berisi sebuah goto yang dihitung"
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr "fungsi %q+F tidak akan dapat inline karena ini menggunakan daftar argumen variabel"
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it is suppressed using -fno-inline"
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr "fungsi %q+F tidak akan inline karena ini ditekan menggunakan -fno-inline"
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr "fungsi %q+F tidak akan inline karena ini menggunakan atribut yang konflik dengan inline"
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, fuzzy, gcc-internal-format
 #| msgid "inlining failed in call to %q+F: %s"
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr "inlining gagal dalam panggilan ke %q+F: %s"
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr "dipanggil dari sini"
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, fuzzy, gcc-internal-format
 #| msgid "from this location"
 msgid "called from this function"
 msgstr "dari lokasi ini"
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, gcc-internal-format
 msgid "inlining failed in call to %q+F: %s"
 msgstr "inlining gagal dalam panggilan ke %q+F: %s"
@@ -35525,29 +35525,29 @@ msgstr "tipe vektori tidak valid untuk atribut %qE"
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr "tipe vektori tidak valid untuk atribut %qE"
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "in a call to non-static member function %qD"
 msgstr "penggunaan tidak valid dari anggota fungsi %qD bukan statis"
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "in a call to built-in function %qD"
 msgstr "argumen ke fungsi bawaan tidak valid"
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, fuzzy, gcc-internal-format
 #| msgid "no member function %qD declared in %qT"
 msgid "in a call to function %qD declared %qs"
@@ -35763,7 +35763,7 @@ msgstr "%qE tidak terinisialisasi"
 msgid "%qs may be used uninitialized"
 msgstr "%qD mungkin digunakan tidak terinisialisasi dalam fungsi ini"
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "%qD was declared here"
@@ -36004,7 +36004,7 @@ msgstr ""
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -36019,135 +36019,135 @@ msgstr ""
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "array dari fungsi tidak berarti"
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "tipe kembali fungsi tidak dapat berupa fungsi"
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "pemeriksaan pohon: %s, memiliki %s dalam %s, di %s:%d"
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diduga kosong dari %s, memiliki %s dalam %s, di %s:%d"
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diduga kelas %qs, memiliki %qs (%s) dalam %s, di %s:%d"
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "pemeriksaan pohon: tidak menduga kelas %qs, memiliki %qs (%s dalam %s, di %s:%d"
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diduga omp_clause %s, memiliki %s dalam %s, di %s:%d"
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diduga pohon yang berisi struktur %qs, memiliki %qs dalam %s, di %s:%d"
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diakses elt %d dari tree_vec dengan %d elts dalam %s, di %s:%d"
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diakses elt %d dari tree_vec dengan %d elts dalam %s, di %s:%d"
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diakses operan %d dari %s dengan %d operan dalam %s, di %s:%d"
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diakses operan %d dari omp_clause %s dengan %d operan dalam %s, di %s:%d"
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated: %s"
 msgstr "%qs sudah ditinggalkan"
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated"
 msgstr "%qs sudah ditinggalkan"
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated: %s"
 msgstr "%qs sudah ditinggalkan"
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated"
 msgstr "%qs sudah ditinggalkan"
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type is deprecated"
 msgid "type is deprecated: %s"
 msgstr "tipe sudah ditinggalkan"
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "tipe sudah ditinggalkan"
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is unavailable: %s"
 msgstr "%qD bukan sebuah variabel"
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is unavailable"
 msgstr "%qD bukan sebuah variabel"
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qE is unavailable: %s"
 msgstr "%qD bukan sebuah variabel"
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qE is unavailable"
 msgstr "%qD bukan sebuah variabel"
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, gcc-internal-format, gfc-internal-format
 msgid "type is unavailable: %s"
 msgstr ""
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "type is unavailable"
@@ -36173,268 +36173,268 @@ msgstr "%qD bukan sebuah variabel"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "type is not compatible with its variant"
 msgstr "assert: %s adalah assign kompatibel dengan %s"
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qT is not a template type"
 msgid "type %s is not an opaque type"
 msgstr "%qT bukan sebuah tipe template"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "type %s is not with opaque mode"
 msgstr "tipe %qT bukan sebuah dasar langsung dari %qT"
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr ""
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr ""
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable \"%s\" not defined"
 msgid "main variant is not defined"
 msgstr "variabel lingkungan \"%s\" tidak terdefinisi"
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "ukuran dari array %qs memiliki tipe bukan integer"
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has an incomplete type"
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "%qD memiliki tipe tidak lengkap"
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -36673,7 +36673,7 @@ msgstr "%J definisi alias tidak didukung dalam konfigurasi ini"
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "visibility atribut tidak didukung dalam konfigurasi ini; diabaikan"
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr ""
@@ -36903,7 +36903,7 @@ msgstr "%qE atribut diabaikan karena %qT telah didefinisikan"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "%qE atribut diabaikan karena %qT telah didefinisikan"
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE atribut hanya memiliki efek dalam objek publik"
@@ -37106,7 +37106,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr "%qs atribut hanya berlaku ke variabel"
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for local variables"
@@ -37466,7 +37466,7 @@ msgstr "%qD tidak dideklarasikan dalam %qD"
 msgid "%qE argument is not a function"
 msgstr "membersihkan argumen bukan sebuah fungsi"
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, fuzzy, gcc-internal-format
 #| msgid "version attribute is not a string"
 msgid "deprecated message is not a string"
@@ -38016,7 +38016,7 @@ msgstr "ISO C++ melarang mengaplikasikan %<__alignof%> ke sebuah ekspresi dari t
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr "new tidak dapat diaplikasikan ke sebuah fungsi tipe"
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, gcc-internal-format
 msgid "invalid application of %qs to a void type"
 msgstr "aplikasi tidak valid dari %qs ke sebuah tipe void"
@@ -38158,17 +38158,17 @@ msgstr ""
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "terlalu sediki argumen ke fungsi %qE"
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, gcc-internal-format
@@ -38305,132 +38305,132 @@ msgstr "mencoba untuk mengambil alamat dari bit-field anggota struktur %qD"
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "ukuran dari array terlalu besar"
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "tipe tidak kompatibel untuk argumen %d dari %qE"
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "melewatkan argumen %d dari %qE membuat penunjuk dari integer tanpa sebuah cast"
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "both arguments must be compatible"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, fuzzy, gcc-internal-format
 #| msgid "not enough arguments to function %qE"
 msgid "incorrect number of arguments to function %qE"
 msgstr "tidak cukup argumen ke fungsi %qE"
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "argumen ke %qs harus berupa sebuah 2 bit unsigned literal"
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr "aritmetik di penunjuk ke sebuah tipe tidak lengkap"
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "%K argumen pertama dari %D harus berupa sebuah penunjuk, integer kedua konstanta"
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "%K argumen pertama dari %D harus berupa sebuah penunjuk, integer kedua konstanta"
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE from incompatible pointer type"
 msgid "argument %d of %qE must be a pointer type"
 msgstr "melewatkan argumen %d dari %qE dari tipe penunjuk yang tidak kompatibel"
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "argumen %d dari %qE mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "melewatkan argumen %d dari %qE membuat integer dari penunjuk tanpa sebuah cast"
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "size mismatch in argument %d of %qE"
 msgstr "Tipe/tingkat tidak cocok dalam argumen '%s' di %L"
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr "melewatkan argumen %d dari %qE membuat integer dari penunjuk tanpa sebuah cast"
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr "melewatkan argumen %d dari %qE mengabaikan pengkualifikasi dari tipe target penunjuk"
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr "argumen %d dari %qE mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr "melewatkan argumen %d dari %qE mengabaikan pengkualifikasi dari tipe target penunjuk"
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "non-integer memory model argument %d of %qE"
 msgstr "tipe tidak kompatibel untuk argumen %d dari %qE"
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid memory model argument %d of %qE"
 msgstr "tipe argumen tidak valid dari %qs"
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, fuzzy, gcc-internal-format
 #| msgid "index in dimension %d is out of bounds at %L"
 msgid "index value is out of bound"
 msgstr "indeks dalam dimensi %d diluar dari jangkauan di %L"
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qT to vector %qT involves truncation"
@@ -38438,59 +38438,59 @@ msgstr "konversi dari %qT ke %qT adalah ambigu"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D cannot be declared weak"
 msgid "built-in function %qE must be directly called"
 msgstr "fungsi inline %q+D tidak dapat dideklarasikan lemah"
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "size of array %qE is not a constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array is not a constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "ukuran dari array %qs adalah negatif"
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "ukuran dari array negatif"
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "ukuran dari array %qs adalah negatif"
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -39158,7 +39158,7 @@ msgstr "konstanta integer terlalu besar untuk tipe %qs"
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr "konstanta integer terlalu besar untuk tipe %qs"
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<_BitInt(%d)%> is not supported on this target"
@@ -39245,7 +39245,7 @@ msgstr "tidak didukung bukan-standar pemotongan dari string literals"
 msgid "traditional C rejects string constant concatenation"
 msgstr "tradisional C menolak pemotongan konstanta string"
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -39301,7 +39301,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "tipe tidak valid untuk iterasi variabel %qE"
@@ -39317,17 +39317,17 @@ msgstr "%Htipe tidak valid untuk iterasi variabel %qE"
 msgid "%qE is not initialized"
 msgstr "%qE tidak terinisialisasi"
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "hilang predikat pengontrol"
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "predikat pengontrol tidak valid"
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "hilang ekspresi peningkatan"
@@ -39337,7 +39337,7 @@ msgstr "hilang ekspresi peningkatan"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "ekspresi peningkatan tidak valid"
@@ -39429,7 +39429,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -39440,7 +39440,7 @@ msgstr ""
 msgid "%qD is not a function argument"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
@@ -40096,7 +40096,7 @@ msgid "wrong type argument to %s"
 msgstr "tipe argumen salah ke abs"
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -41104,35 +41104,35 @@ msgstr "perbandingan antara %q#T dan %q#T"
 
 #: c-family/c-warn.cc:3832
 #, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3836
+#: c-family/c-warn.cc:3839
 #, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr ""
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr ""
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr ""
@@ -41362,119 +41362,119 @@ msgstr "%sregparm=%d%s tidak berada diantara 0 dan %d"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, gcc-internal-format
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, gcc-internal-format
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, gcc-internal-format
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, fuzzy, gcc-internal-format
 #| msgid "-mcpu=%s conflicts with -march=%s"
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr "-mcpu=%s konflik dengan -march=%s"
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, fuzzy, gcc-internal-format
 #| msgid "-mcpu=%s conflicts with -march=%s"
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr "-mcpu=%s konflik dengan -march=%s"
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, gcc-internal-format
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr ""
@@ -41919,13 +41919,13 @@ msgstr "diduga %qT tetapi argumen memiliki tipe %qT"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "diduga %qT tetapi argumen memiliki tipe %qT"
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC optimize%> is not a string or number"
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC optimize%> bukan sebuah string atau angka"
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of #pragma GCC java_exceptions"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
@@ -42554,7 +42554,7 @@ msgstr ""
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
@@ -42635,12 +42635,12 @@ msgid "unknown tuning option (%s)"
 msgstr "fungsi spesifikasi '%s' tidak diketahui"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
@@ -42652,7 +42652,7 @@ msgid "specify a system register with a small string length"
 msgstr "Spesifikasikan pengurutan alokasi register"
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
@@ -42844,9 +42844,9 @@ msgstr ""
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
@@ -42903,19 +42903,19 @@ msgid "virtual function multiversioning not supported"
 msgstr "ekspresi batas stack tidak didukung"
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "__builtin_eh_return tidak didukung dalam target ini"
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
@@ -42928,8 +42928,8 @@ msgstr ""
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %wd"
@@ -42941,7 +42941,7 @@ msgstr "kombinasi tidak didukung: %s"
 msgid "GCC does not currently support return type %qT for simd"
 msgstr "ISO C tidak mendukung tipe yang bersaturasi"
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
@@ -42951,7 +42951,7 @@ msgstr ""
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd"
@@ -43053,8 +43053,8 @@ msgstr "L%d cache latensi tidak diketahui untuk %s"
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "nilai buruk %qs untuk -mmemory-latency"
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr "fcode bawaan buruk"
@@ -43185,18 +43185,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "argumen dari atribut %qs bukan \"ilink1\" atau \"ilink2\""
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -43321,7 +43321,7 @@ msgid "argument of %qE attribute is missing"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute allows only an integer constant argument"
@@ -43345,24 +43345,24 @@ msgstr "atribut %qs hanya berlaku ke fungsi tipe"
 msgid "argument of %qE attribute ignored"
 msgstr "%qE atribut diabaikan"
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only applies to variables"
 msgstr "%qs atribut hanya berlaku ke variabel"
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr ""
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid type for %<asm%> flag output"
@@ -43625,7 +43625,7 @@ msgstr "target CPU tidak mendukung instruksi THUMB"
 msgid "target CPU does not support unaligned accesses"
 msgstr "target CPU tidak mendukung kode ARM"
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support branch-likely instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -43682,7 +43682,7 @@ msgstr "ukuran batas struktur hanya dapat diset ke %s"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC tidak kompatibel dengan -msingle-pic-base"
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
@@ -43797,7 +43797,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -43841,44 +43841,44 @@ msgstr "%qE atribut hanya memiliki efek dalam objek publik"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "atribut %qs hanya berlaku ke fungsi tipe"
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "tidak dapat menghitung lokasi ril dari parameter terstack"
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Tidak terduga akhir dari modul"
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "tidak ada register bawah yang tersedia unruk popping register atas"
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "Interrupt Sevice Routines tidak dapat dikodekan dalam mode Thumb"
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -43887,24 +43887,24 @@ msgstr "tipe vektori tidak valid untuk atribut %qE"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "tipe vektori tidak valid untuk atribut %qE"
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "nama register: %s tidak dikenal"
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "%<asm%> flags not supported in thumb1 mode"
@@ -43966,173 +43966,173 @@ msgstr ""
 msgid "unknown core architecture %qs specified with %qs"
 msgstr "tidak ada nama class dispesifikasikan dengan %qs"
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "%<-fpic%> is not supported"
 msgstr "-pipe tidak didukung"
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "%<-fPIC%> is not supported"
 msgstr "-pipe tidak didukung"
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "%<-fpie%> is not supported"
 msgstr "-pipe tidak didukung"
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe tidak didukung"
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, fuzzy, gcc-internal-format
 #| msgid "-G and -static are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-G dan -static adalah mutually exclusive"
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have arguments"
 msgstr "%qD tidak dapat memiliki argumen baku"
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, fuzzy, gcc-internal-format
 #| msgid "Function does not return a value"
 msgid "%qs function cannot return a value"
 msgstr "Fungsi tidak mengembalikan sebuah nilai"
 
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, fuzzy, gcc-internal-format
 #| msgid "%qs appears to be a misspelled signal handler"
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs sepertinya salah nama signal handler"
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, gcc-internal-format
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Number of registers used to pass integer arguments"
 msgid "fixed register %s used to pass parameter to function"
 msgstr "Jumlah dari register yang digunakan untuk melewati argumen integer"
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D not supported"
 msgid "writing to address space %qs not supported"
 msgstr "deklarasi lemah dari %q+D tidak didukung"
 
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "%qs atribut hanya berlaku ke variabel"
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variadic functions"
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "%qE atribut hanya berlaku untuk fungsi variadic"
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, gcc-internal-format
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr ""
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute on non-volatile variable"
 msgstr "%qs atribut hanya berlaku ke variabel"
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr ""
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr ""
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, gcc-internal-format
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr ""
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, gcc-internal-format
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, fuzzy, gcc-internal-format
 #| msgid "only uninitialized variables can be placed in the .noinit section"
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr "hanya variabel yang belum terinisialisasi yang dapat ditempatkan dalam daerah .noinit"
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, fuzzy, gcc-internal-format
 #| msgid "only initialized variables can be placed into program memory area"
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr "hanya variabel terinisialisasi yang dapat ditempatkan kedalam daerah memori aplikasi"
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, fuzzy, gcc-internal-format
 #| msgid "only initialized variables can be placed into program memory area"
 msgid "uninitialized variable %q+D put into program memory area"
@@ -44142,48 +44142,48 @@ msgstr "hanya variabel terinisialisasi yang dapat ditempatkan kedalam daerah mem
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr "Dapat dialokasikan '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "atribut %qs tidak kompatibel diabaikan"
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, fuzzy, gcc-internal-format
 #| msgid "MCU %qs supported for assembler only"
 msgid "architecture %qs supported for assembler only"
 msgstr "MCU %qs hanya didukung untuk perakit saja"
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "conversion from address space %qs to address space %qs"
 msgstr "Konversi dari %s ke %s di %L"
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of module in string constant"
 msgid "%s expects a compile time integer constant"
 msgstr "Tidak terduga akhir dari modul dalam konstanta string"
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -44339,7 +44339,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr ""
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, gcc-internal-format
@@ -45034,8 +45034,8 @@ msgstr "argumen selanjutnya ke terakhir harus berupa sebuah 8 bit immediate"
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "model kode %s tidak mendukung kode PIC"
@@ -45109,281 +45109,281 @@ msgstr "tidak ada nama class dispesifikasikan dengan %qs"
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64 bit ABI tidak didukung di mode ESA/390"
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated.  Use %stune=k8%s or %stune=generic%s instead as appropriate."
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%smtune=x86-64%s sudah ditinggalkan. Lebih baik gunakan %stune=k8%s atau %stune=generic%s yang lebih sesuai."
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated.  Use %stune=k8%s or %stune=generic%s instead as appropriate."
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%smtune=x86-64%s sudah ditinggalkan. Lebih baik gunakan %stune=k8%s atau %stune=generic%s yang lebih sesuai."
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "-mcmodel= tidak didukung di sistem 32 bit"
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr "-fdata-sections tidak didukung untuk target ini"
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mcmodel= tidak didukung di sistem 32 bit"
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mgp64%> used with a 32-bit ABI"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-mgp64%> digunakan dengan sebuah ABI 32 bit"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-m%s tidak didukung dalam konfigurasi ini"
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-bit mode tidak terkompile"
 
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "CPU yang anda pilih tidak mendukung set instruksi x86-64"
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %qs for -mcpu switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "nilai buruk %qs untuk pilihan -mcpu"
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %sarch=%s %s"
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "nilai (%s) buruk untuk pilihan %sarch=%s %s"
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %<%s%> for -mtune= switch"
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "nilai %<%s%> buruk untuk pilihan -mtune="
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %stune=%s %s"
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "nilai (%s) buruk untuk %stune=%s %s"
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_return_address%>"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "argumen ke %<__builtin_return_address%> tidak valid"
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, fuzzy, gcc-internal-format
 #| msgid "%sregparm%s is ignored in 64-bit mode"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "%sregparm%s diabaikan dalam mode 64 bit"
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, fuzzy, gcc-internal-format
 #| msgid "%sregparm=%d%s is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "%sregparm=%d%s tidak berada diantara 0 dan %d"
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s diabaikan dalam mode 64 bit"
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s diabaikan dalam mode 64 bit"
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr ""
@@ -45391,322 +45391,322 @@ msgstr ""
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr ""
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "-fprefetch-loop-array tidak didukung untuk target ini"
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, fuzzy, gcc-internal-format
 #| msgid "%spreferred-stack-boundary=%d%s is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s tidak berada diantara %d dan 12"
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, fuzzy, gcc-internal-format
 #| msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d tidak berada diantara %d dan 12"
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "inter-module optimisasi tidak diimplementasikan untuk C++"
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparam%s digunakan tanpa SSE aktif"
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparam%s digunakan tanpa SSE aktif"
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "set instruksi SSE non-aktif, menggunakan 387 aritmetik"
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "set instruksi 387 non-aktif, menggunakan aritmetik SSE"
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring unknown option %q.*s in %<-fdump-%s%>"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "mengabaikan pilihan tidak dikenal %q.*s dalam %<-fdump-%s%>"
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr ""
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "atribut stdcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, fuzzy, gcc-internal-format
 #| msgid "ms_abi and sysv_abi attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "atribut ms_abi dan sysv_abi tidak kompatibel"
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s dan -mcall-%s tidak kompatibel"
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s dan -mcall-%s tidak kompatibel"
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, fuzzy, gcc-internal-format
 #| msgid "%Hattributes are not allowed on a function-definition"
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%Hatribut tidak diijinkan dalam sebuah definisi fungsi"
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "atribut fastcall dan regparm tidak kompatibel"
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "argumen ke atribut %qs lebih besar daripada %d"
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "atribut fastcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "atribut stdcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE atribut diabaikan dalam tipe bukan-class"
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "atribut %qs tidak kompatibel diabaikan"
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only available for 64-bit"
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qs atribut hanya tersedia untuk 64 bit"
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires a string constant argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "Interrupt Sevice Routines tidak dapat dikodekan dalam mode Thumb"
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
@@ -45918,50 +45918,50 @@ msgstr "ukuran operan tidak didukung untuk register ekstended"
 msgid "non-integer operand used with operand code %<z%>"
 msgstr ""
 
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 #, fuzzy
 #| msgid "the mangling of %<va_list%> has changed in GCC 4.4"
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr "mangling dari %<va_list%> telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, fuzzy, gcc-internal-format
 #| msgid "no low registers available for popping high registers"
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr "tidak ada register bawah yang tersedia unruk popping register atas"
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr ""
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr ""
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown architecture '%s'"
 msgid "unknown architecture specific memory model"
 msgstr "Arsitektur '%s' tidak dikenal"
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr ""
@@ -45984,8 +45984,8 @@ msgstr "definisi dari anggota data statis %q+D dari class dllimport"
 msgid "malformed %<#pragma builtin%>"
 msgstr "salah bentuk #pragma builtin"
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid argument of %qE attribute"
@@ -46048,13 +46048,13 @@ msgstr "PRINT_OPERAND: Punctuation '%c' tidak diketahui"
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr "PRINT_OPERAND penunjuk kosong"
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "argumen 1 dari __builtin_spe_predicate harus berupa sebuah konstanta"
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, fuzzy, gcc-internal-format
 #| msgid "failed to reclaim unneeded function"
 msgid "failed to expand built-in function"
@@ -46185,19 +46185,19 @@ msgstr "assert: %s adalah assign kompatibel dengan %s"
 msgid "%qs cannot be used for compiling a shared library"
 msgstr "%s tidak digunakan dalam asm disini"
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr "atribut `%s' tidak dapat dispesifikasikan untuk variabel lokal"
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for register variables"
 msgstr "atribut `%s' tidak dapat dispesifikasikan untuk variabel lokal"
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "multiple %qE attribute"
@@ -46315,12 +46315,12 @@ msgstr "multiple atribut interupsi tidak diijinkan"
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr "interrupt_thread hanya tersedia di fido"
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "ekspresi batas stack tidak didukung"
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-fexcess-precision=16%> is not supported on this target"
@@ -46364,7 +46364,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr ""
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "%qE attribute requires a string argument"
@@ -46410,140 +46410,140 @@ msgstr ""
 msgid "argument to %qE attribute is not intstack"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, gcc-internal-format
 msgid "cannot handle inconsistent calls to %qs"
 msgstr "tidak dapat menangani panggilan tidak konsisten ke %qs"
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr ""
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr ""
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr ""
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qs not supported for MIPS16"
 msgid "built-in function %qE not supported for MIPS16"
 msgstr "fungsi bawaan %qs tidak didukung untuk MIPS16"
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, gcc-internal-format
 msgid "%qs does not support MIPS16 code"
 msgstr "%qs tidak mendukung kode MIPS16"
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr "MIPS16 PIC untuk ABI selain dari o32 dan o64"
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, fuzzy, gcc-internal-format
 #| msgid "MIPS16 -mxgot code"
 msgid "MIPS16 %<-mxgot%> code"
 msgstr "MIPS16 -mxgot kode"
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, fuzzy, gcc-internal-format
 #| msgid "hard-float MIPS16 code for ABIs other than o32 and o64"
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr "hard-float MIPS16 kode untuk ABI selain dari o32 dan o64"
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, fuzzy, gcc-internal-format
 #| msgid "Generate MIPS16 code"
 msgid "MSA MIPS16 code"
 msgstr "Hasilkan kode MIPS16"
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr "%<-mno-gpopt%> membutuhkan %<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported combination: %s"
 msgstr "kombinasi tidak didukung: %s"
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, gcc-internal-format
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr "%<-%s%> konflik dengan pilihan arsitektur lain, yang menspesifikasikan sebuah %s prosesor"
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, gcc-internal-format
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr "%<-mgp64%> digunakan dengan sebuah prosesor 32 bit"
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, gcc-internal-format
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr "%<-mgp32%> digunakan dengan sebuah ABI 64 bit"
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr "%<-mgp64%> digunakan dengan sebuah ABI 32 bit"
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support branch-likely instructions"
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "arsitektur %qs tidak mendukung instruksi branch-likely"
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr "%<-mgp32%> dan %<-mfp64%> hanya dapat dikombinasikan jika target mendukung instruksi mfhc1 dan mthc1"
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr "%<-mgp32%> dan %<-mfp64%> hanya dapat dikombinasikan ketika menggunakan ABI o32"
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr "%<-mgp32%> dan %<-mfp64%> hanya dapat dikombinasikan ketika menggunakan ABI o32"
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr "%<-mips3d%> membutuhkan %<-mpaired-single%>"
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgid "%<-mfpxx%> requires %<-mlra%>"
@@ -46554,128 +46554,128 @@ msgstr "%<-mips3d%> membutuhkan %<-mpaired-single%>"
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr "assert: %s adalah assign kompatibel dengan %s"
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, gcc-internal-format
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr "arsitektur %qs tidak mendukung instruksi branch-likely"
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support paired-single instructions"
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr "aristektur %qs tidak mendukung instruksi paired-single"
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support paired-single instructions"
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr "aristektur %qs tidak mendukung instruksi paired-single"
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported combination: %qs%s %s"
 msgstr "kombinasi tidak didukung: %s"
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported combination: %qs %s"
 msgstr "kombinasi tidak didukung: %s"
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, fuzzy, gcc-internal-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "cannot generate position-independent code for %qs"
 msgstr "Hasilkan kode bebas posisi jika memungkinkan (mode besar)"
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, fuzzy, gcc-internal-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "position-independent code requires %qs"
 msgstr "Hasilkan kode bebas posisi jika memungkinkan (mode besar)"
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr "%<-mno-gpopt%> membutuhkan %<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr "tidak dapat menggunakan data-kecil akses untuk %qs"
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support paired-single instructions"
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr "aristektur %qs tidak mendukung instruksi paired-single"
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support branch-likely instructions"
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr "arsitektur %qs tidak mendukung instruksi branch-likely"
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, gcc-internal-format
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr "%<-mips3d%> membutuhkan %<-mpaired-single%>"
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, gcc-internal-format
 msgid "%qs must be used with %qs"
 msgstr "%qs harus digunakan dengan %qs"
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, gcc-internal-format
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr ""
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, gcc-internal-format
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr "aristektur %qs tidak mendukung instruksi paired-single"
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr "%qs membutuhkan sebuah target yang menyediakan instruksi %qs"
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support branch-likely instructions"
 msgid "the %qs architecture does not support DSP instructions"
 msgstr "arsitektur %qs tidak mendukung instruksi branch-likely"
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, gcc-internal-format
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr ""
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, gcc-internal-format
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr ""
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, gcc-internal-format
 msgid "%qs requires branch-likely instructions"
 msgstr "%qs membutuhkan instruksi branch-likely"
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support branch-likely instructions"
 msgid "the %qs architecture does not support the synci instruction"
 msgstr "arsitektur %qs tidak mendukung instruksi branch-likely"
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr "mips16 fungsi profiling"
@@ -47621,60 +47621,60 @@ msgstr "%<#pragma GCC optimize%> bukan sebuah string atau angka"
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "sampah diakhir dari %<#pragma reset_options%>"
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, gcc-internal-format
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, gcc-internal-format
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute is not supported on this machine"
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr "atribut target tidak didukung di platform ini"
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "malformed %<target()%> attribute"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, gcc-internal-format
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "malformed %<target(\"%s\")%> attribute"
@@ -47742,185 +47742,206 @@ msgstr "tidak dapat mengubah tipe %qT ke tipe %qT"
 msgid "capture by copy of RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, gcc-internal-format
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, fuzzy, gcc-internal-format
+#| msgid "built-in function %qs not supported for MIPS16"
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr "fungsi bawaan %qs tidak didukung untuk MIPS16"
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, fuzzy, gcc-internal-format
 #| msgid "mangling function-style cast with more than one argument"
 msgid "no matching function call to %qE with empty arguments"
 msgstr "mangling function-style cast dengan lebih dari satu argumen"
 
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "nilai %s tidak diketahui untuk pilihan -mfpu"
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, gcc-internal-format
 msgid "this operation requires the RVV ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI dari melewatkan structure dengan anggota float kompleks telah berubah dalam GCC 4.4"
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr "Argumen AltiVec dilewatkan ke fungsi yang tidak berprototipe"
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, gcc-internal-format
 msgid "%s %qT requires the V ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, gcc-internal-format
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, gcc-internal-format
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, gcc-internal-format
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, gcc-internal-format
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr ""
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, gcc-internal-format
 msgid "function attribute %qs requires the V ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "argumen dari atribut %qs bukan \"ilink1\" atau \"ilink2\""
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr ""
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not of type %qT"
 msgid "%qs applied to non-RVV type %qT"
 msgstr "%qE bukan dari tipe %qT"
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qs requires an integer constant"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support ARM mode"
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr "target CPU tidak mendukung kode ARM"
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs with %qs"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, gcc-internal-format
 msgid "rv64e requires lp64e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr ""
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, fuzzy, gcc-internal-format
 #| msgid "%spreferred-stack-boundary=%d%s is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s tidak berada diantara %d dan 12"
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr ""
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr ""
@@ -48198,34 +48219,34 @@ msgstr "%s hanya menerima 2 argumen"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s hanya menerima 2 argumen"
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr "melewatkan argumen %d dari %qE mengabaikan pengkualifikasi dari tipe target penunjuk"
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "kombinasi parameter untuk AltiVec intrinsik tidak valid"
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, gcc-internal-format
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
@@ -48269,30 +48290,23 @@ msgstr "operang tidak valid untuk tipe %qT dan %qT ke binari %qO"
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektor dilewatkan dengan referensi: bukan ekstensi standar ABI dengan tidak ada garansi kompabilitas"
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, gcc-internal-format
-msgid "%qs requires the ELFv2 ABI"
-msgstr ""
-
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "stack frame terlalu besar"
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported number of nops before function entry (%u)"
 msgstr ""
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, fuzzy, gcc-internal-format
 #| msgid "Use registers r2 and r5"
 msgid "%qs uses register r29"
 msgstr "Gunakan register r2 dan r5"
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
@@ -48430,116 +48444,126 @@ msgstr "Butuh sebuah call-clobbered target register"
 msgid "unknown option for %<%s=%s%>"
 msgstr "Operator tidak dikenal '%s' di %%L"
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4837
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4855
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "tidak ada profiling dari kode 64 bit untuk ABI ini"
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "tidak dapat mengambil alamat dari %<this%>, yang merupakan ekspresi rvalue"
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "penggunaan dari %<long double%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "penggunaan dari tipe boolean dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "penggunaan dari %<complex%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, fuzzy, gcc-internal-format
 #| msgid "use of decimal floating point types in AltiVec types is invalid"
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "penggunaan dari tipe titik pecahan desimal dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "penggunaan dari %<long%> dalam tipe AltiVec tidak valid untuk kode 64 bit"
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "penggunaan dari %<long%> dalam tipe AltiVec sudah ditinggalkan; gunakan %<int%>"
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "penggunaan dari %<long long%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "penggunaan dari %<double%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type %qT for %qE"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "tipe abstrak tidak valid %qT untuk %qE"
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<#pragma%> is not allowed here"
 msgid "%s%qs%s is not allowed"
 msgstr "%H%<#pragma%> tidak diijinkan disini"
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "spesifikasi '%s' tidak valid"
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "ekspresi batas stack tidak didukung"
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr ""
@@ -48588,7 +48612,7 @@ msgstr ""
 msgid "builtin %qs can only be used on vector types"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -48663,248 +48687,248 @@ msgstr "%qs sudah ditinggalkan"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "konstanta argumen diluar dari jangkauan untuk %qs"
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr "template argumen %d tidak valid"
 
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr "konstanta argumen diluar dari jangkauan untuk %qs"
 
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr "konstanta argumen diluar dari jangkauan untuk %qs"
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher"
 msgstr ""
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher"
 msgstr ""
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, fuzzy, gcc-internal-format
 #| msgid "unresolved overload for Altivec builtin %qF"
 msgid "unresolved overloaded builtin"
 msgstr "tidak teresolf overload untuk Altivec bawaan %qF"
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, fuzzy, gcc-internal-format
 #| msgid "bad builtin code"
 msgid "bad builtin icode"
 msgstr "kode bawaan buruk"
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "invalid argument %d for builtin %qF"
 msgstr "argumen ke fungsi bawaan tidak valid"
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "ukuran total dari variabel lokal melebihi batas arsitektur"
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr ""
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr ""
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "ukuran frame dari %qs adalah "
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs menggunakan alokasi dinamis stack"
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr ""
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "fungsi nested %qs dideklarasikan %<extern%>"
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64 bit ABI tidak didukung di mode ESA/390"
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Hardware decimal floating point instructions not available on %s"
 msgid "hardware vector support not available on %s"
 msgstr "Instruksi perangkat keras titik pecahan desimal tidak tersedia di %s"
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Hardware decimal floating point instructions not available on %s"
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr "Instruksi perangkat keras titik pecahan desimal tidak tersedia di %s"
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, fuzzy, gcc-internal-format
 #| msgid "Hardware decimal floating point instructions not available in ESA/390 mode"
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr "Instruksi perangkat keras titik pecahan desimal tidak tersedia dalam mode ESA/390"
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, fuzzy, gcc-internal-format
 #| msgid "-mhard-dfp can't be used in conjunction with -msoft-float"
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr "-mhard-dfp tidak dapat digunakan dalam konjungsi dengan -msoft-float"
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float tidak didukung dalam kombinasi"
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "ukuran stack harus lebih besar dari nilai penjaga stack"
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "ukuran stack harus lebih besar  dari 64k"
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard mengimplikasikan penggunaan dari -mstack-size"
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute is supported only for SH2A"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "atribut %qs tidak didukung hanya untuk SH2A"
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "argumen ke \"%s\" seharusnya sebuah integer tidak negatif"
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "argumen ke atribut %qs lebih besar daripada %d"
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "batas stact tidak didukung dalam target ini"
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "invalid cc output constraint: %qs"
 msgstr "pilihan argumen %qs tidak valid"
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, fuzzy, gcc-internal-format
 #| msgid "multiple interrupt attributes not allowed"
 msgid "multiple cc output constraints not supported"
 msgstr "multiple atribut interupsi tidak diijinkan"
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, fuzzy, gcc-internal-format
 #| msgid "asm-specifier for variable %qs conflicts with asm clobber list"
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr "asm-specifier untuk variabel %qs konflik dengan daftar asm clobber"
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, fuzzy, gcc-internal-format
 #| msgid "invalid types in nop conversion"
 msgid "invalid type for cc output constraint"
@@ -49385,8 +49409,8 @@ msgstr "%qE atribut diabaikan"
 msgid "attribute %qs applies to array types only"
 msgstr "%qs atribut hanya berlaku ke variabel"
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "nilai void tidak diabaikan karena ini seharusnya"
@@ -49464,7 +49488,7 @@ msgstr "tipe dari array %q+D dilengkapi secara tidak kompatibel dengan inisialis
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr "%qD telah dideklarasikan dalam lingkup ini"
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, fuzzy, gcc-internal-format
 #| msgid "%Joriginal definition appeared here"
 msgid "originally defined here"
@@ -49717,7 +49741,7 @@ msgstr "deklarasi dari %q+D membayangi bukan-variabel sebelumnya"
 msgid "declaration of %qD shadows a parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "deklarasi dari %qD membayangi sebuah deklarasi global"
@@ -49727,7 +49751,7 @@ msgstr "deklarasi dari %qD membayangi sebuah deklarasi global"
 msgid "declaration of %qD shadows a previous local"
 msgstr "deklarasi dari %qD membayangi sebuah lokal sebelumnya"
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
 msgid "shadowed declaration is here"
@@ -49801,7 +49825,7 @@ msgstr "%H%qE tidak dideklarasikan (pertama digunakan dalam fungsi ini)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "%H (Setiap identifier yang tidak dideklarasikan hanya dilaporkan sekali)"
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "label %qE direferensikan diluar dari fungsi apapun"
@@ -49838,7 +49862,7 @@ msgstr "melompat kedalam pernyataan ekspresi"
 msgid "duplicate label declaration %qE"
 msgstr "duplikasi deklarasi label %qE"
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "duplikasi label %qD"
@@ -49876,7 +49900,7 @@ msgstr "melompat kedalam pernyataan ekspresi"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%H%qE didefinisikan sebagai jenis salah dari tag"
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute applied to %qD with void return type"
@@ -50032,12 +50056,12 @@ msgstr "ISO C90 tidak mendukung %<[*]%> array pendeklarasi"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> tidak diijinkan dalam hal lain selain lingkup prototipe fungsi"
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<this%> may not be used in this context"
 msgid "%<omp::%s%> not allowed to be specified in this context"
@@ -50048,7 +50072,7 @@ msgstr "%H%<this%> mungkin tidak digunakan dalam konteks ini"
 msgid "%q+D is usually a function"
 msgstr "%q+D biasanya sebuah fungsi"
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
@@ -50131,7 +50155,7 @@ msgstr "tidak dapat meletakan objek dengan bagian volatile kedalam register"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "tidak terinisialisasi const %qD"
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -50335,7 +50359,7 @@ msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 msgid "storage class specified for unnamed parameter"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "class penyimpanan dispesifikasikan untuk nama tipe"
@@ -50408,7 +50432,7 @@ msgstr "deklarasi dari %qs sebagai array dari fungsi"
 msgid "declaration of type name as array of functions"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "penggunaan tidak valid dari struktur dengan anggota array fleksibel"
@@ -50531,7 +50555,7 @@ msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah array"
 msgid "function definition has qualified void return type"
 msgstr "definisi fungsi memiliki pengkualifikasi tipe kembali void"
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tipe pengkualifikasi diabaikan di tipe kembali fungsi"
@@ -50675,7 +50699,7 @@ msgstr "ISO C melarang tipe fungsi const atau volatile"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "sebuah anggota dari sebuah struktur atau union tidak dapat memiliki sebuah tipe variabel termodifikasi"
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variabel atau field %qE dideklarasikan void"
@@ -50794,7 +50818,7 @@ msgstr "melompat kedalam lingkup dari pengidentifikasi dengan tipe variabel dapa
 msgid "object with variably modified type must have no linkage"
 msgstr "objek dengan tipe variabel termodifikasi harus tidak memiliki hubungan"
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "deklarasi fungsi bukan sebuah prototipe"
@@ -50889,18 +50913,18 @@ msgstr "nested redefinisi dari %<union %E%>"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "nested redefinisi dari %<struct %E%>"
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, fuzzy, gcc-internal-format
 #| msgid "unknown field %qE specified in initializer"
 msgid "%qT defined in underspecified object initializer"
 msgstr "field %qE tidak dikenal dispesifikasikan dalam penginisialisasi"
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "redeklarasi tidak mendeklarasikan apapun"
@@ -50932,386 +50956,386 @@ msgstr ""
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union tidak memiliki anggota bernama"
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union tidak memiliki anggota"
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "struct tidak memiliki anggota bernama"
 
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct tidak memiliki anggota"
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
 msgstr "%J anggota array fleksibel dalam union"
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member not at end of struct"
 msgstr "%J anggota array fleksibel tidak diakhir dari struct"
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in a struct with no named members"
 msgstr "%J anggota array fleksibel dalam union"
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr "%J anggota array fleksibel tidak diakhir dari struct"
 
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "type %qT is too large"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, gcc-internal-format
 msgid "type punning toggles scalar storage order"
 msgstr ""
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union tidak dapat dibuat transparan"
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, fuzzy, gcc-internal-format
 #| msgid "a member of a structure or union cannot have a variably modified type"
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr "sebuah anggota dari sebuah struktur atau union tidak dapat memiliki sebuah tipe variabel termodifikasi"
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %<struct %E%>"
 msgid "redefinition of struct or union %qT"
 msgstr "redefinisi dari %<struct %E%>"
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "nested redefinisi dari %<enum %E%>"
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "redeklarasi dari %<enum %E%>"
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
 msgstr "mode yang dispesifikasikan terlalu kecil untuk nilai enumerasi"
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "nilai enumerasi melebihi jangkauan dari integer terbesar"
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration values exceed range of largest integer"
 msgid "enumeration values exceed range of %qs"
 msgstr "nilai enumerasi melebihi jangkauan dari integer terbesar"
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of %<enum %E%>"
 msgid "conflicting redefinition of enum %qT"
 msgstr "nested redefinisi dari %<enum %E%>"
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "nilai pengenumerasi untuk %qE bukan sebuah konstanta integer"
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "nilai pengenumerasi untuk %qE bukan sebuah konstanta integer"
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "overflow dalam nilai enumerasi"
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value outside the range of underlying type"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "enumerator value outside the range of %qs"
 msgstr "ISO C melarang nilai pengenumerasi ke jangkauan dari %<int%>"
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr "ISO C melarang nilai pengenumerasi ke jangkauan dari %<int%>"
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute %qs"
 msgstr "fungsi inline %q+D memberikan atribut noinline"
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "tipe kembali adalah sebuah tipe tidak lengkap"
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "tipe baku kembali ke %<int%>"
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about global functions without prototypes"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "Peringatkan mengenai fungsi global tanpa prototipe"
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, fuzzy, gcc-internal-format
 #| msgid "no previous prototype for %q+D"
 msgid "no previous prototype for %qD"
 msgstr "tidak ada prototipe sebelumnya untuk %q+D"
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D telah digunakan dengan tidak ada prototipe sebelum definisinya"
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no declaration before its definition"
 msgid "%qD was used with no declaration before its definition"
 msgstr "%q+D telah digunakan tanpa deklarasi sebelum definisinya"
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %<int%>"
 msgstr "tipe kembali dari %q+D bukan %<int%>"
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is normally a non-static function"
 msgstr "%q+D secara normal sebuah fungsi bukan-statis"
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style parameter declarations in prototyped function definition"
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "%J deklarasi parameter gaya lama dalam definisi fungsi prototipe"
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtraditional C rejects ISO C style function definitions"
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "%J tradisional C menolak gaya ISO C definisi fungsi"
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr ""
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "old-style function definition"
 msgstr "%J definisi fungsi gaya-lama"
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name missing from parameter list"
 msgid "parameter name missing from parameter list"
 msgstr "%J nama parameter hilang dari daftar parameter"
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "%qD declared as a non-parameter"
 msgstr "%q+D dideklarasikan sebagai sebuah bukan-parameter"
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, fuzzy, gcc-internal-format
 #| msgid "multiple parameters named %q+D"
 msgid "multiple parameters named %qD"
 msgstr "multiple parameter bernama %q+D"
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "parameter %qD declared with void type"
 msgstr "parameter %q+D dideklarasikan dengan tipe void"
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, fuzzy, gcc-internal-format
 #| msgid "type of %q+D defaults to %<int%>"
 msgid "type of %qD defaults to %<int%>"
 msgstr "tipe dari %q+D baku ke %<int%>"
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "parameter %qD has incomplete type"
 msgstr "parameter %q+D memiliki tipe tidak lengkap"
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, fuzzy, gcc-internal-format
 #| msgid "declaration for parameter %q+D but no such parameter"
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "deklarasi untuk parameter %q+D tetapi tidak ada parameter seperti itu"
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "jumlah dari argumen tidak cocok dengan prototipe bawaan"
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "jumlah dari argumen tidak cocok prototipe"
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "deklarasi prototipe"
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "argumen dipromosikan %qD tidak cocok dengan prototipe bawaan"
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "argumen dipromosikan %qD tidak cocok dengan prototipe"
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "argumen %qD tidak cocok dengan prototipe bawaan"
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argumen %qD tidak cocok dengan prototipe"
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
 msgstr "parameter %qD dinisialisasi"
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declarations are only allowed in C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> deklarasi inisial loop hanya diijinkan dalam mode C99"
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, fuzzy, gcc-internal-format
 #| msgid "use option -std=c99 or -std=gnu99 to compile your code"
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "gunakan pilihan -std=c99 atau -std=gnu99 untuk mengkompile kode anda"
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 tidak mendukung %<[*]%> array pendeklarasi"
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of static variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "deklarasi dari variabel statis %q+D dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "deklarasi dari variabel %<extern%> %q+D dalam %<for> inisial deklarasi loop"
 
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> dideklarasikan dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> dideklarasikan dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> dideklarasikan dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of non-variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "deklarasi dari bukan-variabel %q+D dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "multiple class penyimpanan dalam deklarasi penspesifikasi"
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qs used with %<auto%>"
@@ -51319,273 +51343,273 @@ msgstr "%<__thread%> digunakan dengan %<auto%>"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%<auto%> used with %<constexpr%>"
 msgstr "%<__thread%> digunakan dengan %<register%>"
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "dua atau lebih tipe data dalam penspesifikasi deklarasi"
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> terlalu panjang untuk GCC"
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 tidak mendukung tipe kompleks"
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C tidak mendukung tipe yang bersaturasi"
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "duplikasi %qE"
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support fixed-point types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C tidak mendukung tipe titik tetap"
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "batas stact tidak didukung dalam target ini"
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 tidak mendukung tipe kompleks"
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support the %<%%%s%c%> %s format"
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr "%s tidak mendukung format %<%%%s%c%> %s"
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "batas stact tidak didukung dalam target ini"
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr "ISO C tidak mendukung titik pecahan desimal"
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "tipe titik tetap tidak didukung untuk target ini"
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C tidak mendukung tipe titik tetap"
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr ""
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE gagal untuk menjadi sebuah typedef atau tipe bawaan"
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE tidak berada di awal dari deklarasi"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> digunakan dengan %<auto%>"
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> digunakan dengan %<register%>"
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> digunakan dengan %<typedef%>"
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<constexpr%>"
 msgstr "%<__thread%> digunakan dengan %<register%>"
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s tidak mendukung %s"
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> sebelum %<extern%>"
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> sebelum %<static%>"
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%<typedef%> used with %<auto%>"
 msgstr "%<__thread%> digunakan dengan %<auto%>"
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<extern%>"
 msgstr "%<__thread%> digunakan dengan %<register%>"
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qE used with %qs"
 msgstr "%qs harus digunakan dengan %qs"
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs used with %qE"
 msgstr "%qs harus digunakan dengan %qs"
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%<constexpr%> used with %qE"
 msgstr "%<_thread%> digunakan dengan %qE"
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> digunakan tanpa %<_Fract%> atau %<_Accum%>"
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C tidak mendukung plain %<complex%> yang berarti %<double complex%>"
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr "ISO C90 tidak mendukung %<[*]%> array pendeklarasi"
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C tidak mendukung tipe integer kompleks"
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, fuzzy, gcc-internal-format
 #| msgid "Fixed line length must be at least seven."
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr "Panjang baris tetap harus paling tidak tujuh."
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support %<~%> for complex conjugation"
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr "ISO C tidak mendukung %<~%> untuk konjugasi kompleks"
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "jumlah geser kiri negatif"
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "jumlah geser kiri negatif"
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "jumlah geser kanan negatif"
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "jumlah geser kiri >= lebar dari tipe"
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "jumlah geser kanan >= lebar dari tipe"
@@ -51618,7 +51642,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -51629,8 +51653,8 @@ msgstr "Tidak terduga akhir dari modul"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C melarang sebuah satuan terjemahan kosong"
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr ""
@@ -51672,9 +51696,9 @@ msgstr "nama register %qs tidak dikenal dalam %<asm%>"
 msgid "unknown type name %qE"
 msgstr "nama register: %s tidak dikenal"
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "diduga penspesifikasi deklarasi"
@@ -51708,7 +51732,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "diduga pengidentifikasi atau %<(%>"
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -51732,7 +51756,7 @@ msgstr "Diduga nama atribut bit"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "atribut daerah tidak diijinkan untuk %q+D"
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<assume%> attribute not followed by %<;%>"
@@ -51832,7 +51856,7 @@ msgstr "ekspresi integral %qE bukan konstan"
 msgid "static assertion failed: %E"
 msgstr "static assertion gagal: %E"
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
@@ -51911,10 +51935,10 @@ msgstr "template argumen %d tidak valid"
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "diduga pengidentifikasi"
@@ -52075,7 +52099,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr ""
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr ""
@@ -52085,8 +52109,8 @@ msgstr ""
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs attribute argument"
 msgstr ""
@@ -52269,12 +52293,12 @@ msgstr "ISO C melarang mengabaikan term tengah dari sebuah ekspresi ?:"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -52443,7 +52467,7 @@ msgstr "ISO C90 tidak mendukung %<[*]%> array pendeklarasi"
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, gcc-internal-format
 msgid "expected expression"
 msgstr "diduga ekspresi"
@@ -52793,12 +52817,12 @@ msgstr "diduga penspesifikasi deklarasi"
 msgid "no type or storage class may be specified here,"
 msgstr "kelas penyimpanan dispesifikasikan untuk %qs"
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr ""
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, fuzzy, gcc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing property attribute"
@@ -52810,62 +52834,62 @@ msgstr "hilang atribut Code"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "Operator tidak dikenal '%s' di %%L"
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<}%> before %<else%>"
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "diduga %<}%> sebelum %<else%>"
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected %qE selector name"
 msgstr "diduga nama class"
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr ""
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma GCC pch_preprocess%> harus menjadi pertama"
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp section%> hanya bisa digunakan dalam %<#pragma omp section%> konstruk"
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> hanya bisa digunakan dalam %<#pragma omp section%> konstruk"
@@ -52876,26 +52900,26 @@ msgstr "%<#pragma omp section%> hanya bisa digunakan dalam %<#pragma omp section
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr "%<#pragma omp flush%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "diduga pernyataan for"
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> harus menjadi pertama"
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "terlalu banyak %qs clauses"
@@ -52912,71 +52936,71 @@ msgstr "num_threads ekspresi harus integral"
 msgid "expected %<)%> or %<,%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr "diduga %<=%>, %<,%>, %<,%>, %<asm%> atau %<__attribute__%>"
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected constant logical expression"
 msgstr "diduga ekspresi integer"
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<data%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -53000,25 +53024,25 @@ msgstr "%<num_threads%> nilai harus positif"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "diduga ekspresi integer"
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
@@ -53030,107 +53054,107 @@ msgstr "diduga %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, atau %<||%>"
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<static%> arguments"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected element"
 msgid "unexpected argument"
 msgstr "Elemen tidak diduga"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "argumen atribut %qs bukan sebuah konstanta integer"
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<self%> clauses"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<concurrent%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "diduga %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, atau %<||%>"
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "baik %<long%> dan %<void%> dalam penspesifikasi deklarasi"
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "jadwal %<runtime%> tidak mengambil sebuah parameter %<chunk_size%>"
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "penjadwalan %<auto%> tidak mengambil sebuah parameter %<chunk_size%>"
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "jenis penjadwalan tidak valid"
@@ -53141,24 +53165,24 @@ msgstr "jenis penjadwalan tidak valid"
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr ""
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<allocator%> or %<align%>"
@@ -53170,24 +53194,24 @@ msgstr "diduga %<,%> atau %<,%>"
 msgid "duplicate %qs modifier"
 msgstr "%Hduplikasi %qs"
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, fuzzy, gcc-internal-format
 #| msgid "multiple inline callers"
 msgid "multiple linear modifiers"
 msgstr "multiple pemanggil inline"
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, gcc-internal-format
 msgid "multiple %<step%> modifiers"
 msgstr ""
@@ -53210,70 +53234,70 @@ msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "assert: %s adalah assign kompatibel dengan %s"
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "jenis penjadwalan tidak valid"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid doacross kind"
 msgstr "jenis penjadwalan tidak valid"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<always%> modifiers"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<close%> modifiers"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<present%> modifiers"
 msgstr "terlalu banyak berkas masukan"
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "topeng tidak valid"
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr ""
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, gcc-internal-format
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr ""
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -53291,93 +53315,93 @@ msgstr "jenis penjadwalan tidak valid"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected an OpenACC clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs harus digunakan dengan %qs"
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected an OpenMP clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "deklarasi dari variabel %<extern%> %q+D dalam %<for> inisial deklarasi loop"
 
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "diduga sebuah string setelah %<#pragma message%>"
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr ""
@@ -53394,7 +53418,7 @@ msgstr "%H%qE belum pernah dideklarasikan"
 msgid "expected function name"
 msgstr "diduga nama class"
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qD does not refer to a function"
@@ -53405,23 +53429,23 @@ msgstr "%q+D bukan sebuah fungsi,"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> harus muncul sebelum deklarasi dari %D, abaikan"
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
@@ -53448,7 +53472,7 @@ msgstr ""
 msgid "modified here"
 msgstr "'E' pemodifikasi"
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
@@ -53489,119 +53513,119 @@ msgstr ""
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr ""
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>, %<,%>, %<;%>, %<}%> or %<__attribute__%>"
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "diduga %<:%>, %<,%>, %<,%>, %<}%> atau %<__attribute__%>"
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, gcc-internal-format
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, gcc-internal-format
 msgid "%qs clause requires %qs clause"
 msgstr ""
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr "diduga %<(%> atau akhir dari baris"
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, gcc-internal-format
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr ""
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr "operator tidak valid untuk %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "unexpected %<else%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr "operator tidak valid untuk %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "operator tidak valid untuk %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "operator tidak valid untuk %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr ""
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%<depobj%> expression is not lvalue expression"
@@ -53613,30 +53637,30 @@ msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr ""
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr "diduga %<=%>, %<,%>, %<,%>, %<asm%> atau %<__attribute__%>"
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "diduga %<=%>, %<,%>, %<,%>, %<asm%> atau %<__attribute__%>"
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -53646,178 +53670,178 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "diduga %<(%> atau akhir dari baris"
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr "%<#pragma omp taskwait%> hanya  boleh digunakan dalam pernyataan compound"
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<}%> before %<else%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "diduga %<}%> sebelum %<else%>"
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr "%<#pragma omp taskwait%> hanya  boleh digunakan dalam pernyataan compound"
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "diduga iterasi deklarasi atau inisialisasi"
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, fuzzy, gcc-internal-format
 #| msgid "not enough perfectly nested loops"
 msgid "not enough nested loops"
 msgstr "tidak cukup secara sempurna nested loops"
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "diduga pernyataan for"
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "iterasi variabel %qD seharusnya bukan first private"
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr ""
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> harus muncul sebelum deklarasi dari %D, abaikan"
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, fuzzy, gcc-internal-format
 #| msgid "Expected attribute bit name"
 msgid "expected trait selector name"
 msgstr "Diduga nama atribut bit"
 
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, gcc-internal-format
 msgid "unknown selector %qs for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr "%<friend%> hanya dapat dispesifikasikan didalam sebuah kelas"
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<score%> argument must be constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, fuzzy, gcc-internal-format
 #| msgid "last argument must be an immediate"
 msgid "%<score%> argument must be non-negative"
 msgstr "argumen terakhir harus berupa sebuah immediate"
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "diduga string literal"
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "property must be constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
@@ -53825,310 +53849,310 @@ msgstr ""
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, gcc-internal-format
 msgid "%<requires%> selector is not supported yet"
 msgstr ""
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected context selector set name"
 msgstr "diduga nama class"
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<match%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "variant %qD is not a function"
 msgstr "%q+D bukan sebuah fungsi,"
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "elemen dari array %q#D memiliki tipe tidak lengkap"
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, gcc-internal-format
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr ""
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr ""
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, gcc-internal-format
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr ""
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<declare%> or %<assumes%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, gcc-internal-format
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "diduga %<#pragma omp section%> atau %<}%>"
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<omp_priv%> or function-name"
 msgstr "diduga %<(%> atau akhir dari baris"
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected function-name %<(%>"
 msgstr "diduga pengidentifikasi atau %<(%>"
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "diduga %<=%>, %<,%>, %<,%>, %<asm%> atau %<__attribute__%>"
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr "diduga %<=%>, %<,%>, %<,%>, %<asm%> atau %<__attribute__%>"
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, gcc-internal-format
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "%qE memiliki tipe tidak valid untuk %<reduction%>"
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %qs or %qs"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr ""
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr ""
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected at least one assumption clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected directive name"
 msgstr "diduga nama class"
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr ""
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown assumption clause %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected assumption clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE dideklarasikan %<threadprivate%> setelah penggunaan pertama"
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "variabel otomatis %qE tidak dapat berupa %<threadprivate%>"
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE memiliki tipe tidak lengkap"
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "no closing brace"
@@ -54280,7 +54304,7 @@ msgstr "dereferensi penunjuk %<void *%>"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "nilai subscripted adalah bukan array ataupun penunjuk"
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "array subscrip bukan sebuah integer"
@@ -54311,7 +54335,7 @@ msgstr "%qD dideklarasikan sebagai referensi tetapi tidak terinisialisasi"
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -54432,18 +54456,18 @@ msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C+
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "terlalu sediki argumen ke fungsi %qE"
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "perbandingan dengan string literal menghasilkan perilaku yang tidak dispesifikasikan"
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "perbandingan diantara penunjuk dan integer"
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -54470,7 +54494,7 @@ msgstr "penunjuk ke sebuah fungsi digunakan dalam pengurangan"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "aritmetik di penunjuk ke sebuah tipe tidak lengkap"
 
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -54791,7 +54815,7 @@ msgstr "cast dari penunjuk ke integer dari ukuran berbeda"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "cast dari panggilan fungsi dari tipe %qT ke tipe yang tidak cocok %qT"
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "cast ke penunjuk dari integer dari ukuran yang berbeda"
@@ -54991,7 +55015,7 @@ msgstr "penempatan sisi tangan-kiri mungkin menjadi sebuah kandidat untuk sebuah
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "inisialisasi sisi tangan kiri mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "tipe kembali mungkin berupa sebuah kandidat untuk sebuah atribut format"
@@ -55209,12 +55233,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "inisialisasi dari sebuah anggota array fleksibel"
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -55224,7 +55248,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr "array dari tipe yang tidak sesuai terinisialisasi dari konstanta string"
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "penggunaan tidak valid dari bukan-lvalue array"
@@ -55256,7 +55280,7 @@ msgstr "elemen penginisialisasi bukan sebuah konstanta"
 msgid "initializer element is not computable at load time"
 msgstr "elemen penginisialisasi tidak dapat dihitung di waktu load"
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "tipe vektor opaque tidak dapat diinisialisasi"
@@ -55271,7 +55295,7 @@ msgstr "kelebihan grup kurung diakhir dari penginisialisasi"
 msgid "braces around scalar initializer"
 msgstr "kurung disekitar penginisialisasi skalar"
 
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "inisialisasi dari anggota array fleksibel dalam sebuah konteks bertelur"
@@ -55365,7 +55389,7 @@ msgstr "kelebihan elemen dalam struktur penginisialisasi"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "inisialisasi tidak statis dari sebuah anggota array fleksibel"
@@ -55406,7 +55430,7 @@ msgstr "ISO C melarang %<goto *expr;%>"
 msgid "computed goto must be pointer type"
 msgstr "tidak dapat mengubah ke sebuah tipe penunjuk"
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "fungsi dideklarasikan %<noreturn%> memiliki sebuah pernyataan %<return%>"
@@ -55463,7 +55487,7 @@ msgstr "%<default%> label tidak dalam sebuah pernyataan switch"
 msgid "break statement not within loop or switch"
 msgstr "pernyataan break tidak dalam loop atau switch"
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -55509,28 +55533,28 @@ msgstr ""
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr ""
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about comparison of different enum types"
 msgid "comparing vectors with different element types"
 msgstr "Peringatkan mengenai perbandingan dari tipe enum yang berbeda"
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "perbandingan diantara tipe %qT dan %qT"
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
@@ -55607,31 +55631,31 @@ msgstr "menggunaka nilai tipe union dimana skalar dibutuhkan"
 msgid "used vector type where scalar is required"
 msgstr "menggunakan nilai tipe struct dimana skalar dibutuhkan"
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
@@ -55644,93 +55668,93 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%Hterlalu banyak %qs clauses"
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "ukuran dalam array baru harus memiliki tipe integral"
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "ukuran dalam array baru harus memiliki tipe integral"
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected single pointer in %qs clause"
 msgstr "diduga string literal"
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array %qs is used"
 msgid "zero length array section in %qs clause"
 msgstr "array dengan panjang bervariabel %qs digunakan"
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array %qs is used"
 msgid "negative length in array section in %qs clause"
 msgstr "array dengan panjang bervariabel %qs digunakan"
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Salin bagian array kedalam sebuah blok kontinu dalam masukan prosedur"
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE does not have class type"
 msgid "%qE does not have pointer or array type"
 msgstr "%H%qE tidak memiliki tipe kelas"
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, fuzzy, gcc-internal-format
 #| msgid "throwing NULL, which has integral, not pointer type"
 msgid "iterator %qD has neither integral nor pointer type"
@@ -55741,19 +55765,19 @@ msgstr "melemparkan KOSONG, yang memiliki integral, bukan tipe penunjuk"
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr ""
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "iterator %qD has const qualified type"
 msgstr "bit-field %qs memiliki tipe tidak valid"
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "iterator step with non-integral type"
 msgstr "bit-field %qD dengan tipe bukan integral"
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
@@ -55763,33 +55787,33 @@ msgstr ""
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected pointer in %qs clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr ""
@@ -55821,7 +55845,7 @@ msgstr "array dengan panjang bervariabel %qs digunakan"
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE memiliki tipe tidak valid untuk %<reduction(%s)%>"
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -55832,17 +55856,17 @@ msgstr ""
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "array dengan panjang bervariabel digunakan"
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE harus berupa %<threadprivate%> untuk %<copyin%>"
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
 msgstr ""
@@ -55857,24 +55881,24 @@ msgstr ""
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in reduction clauses"
@@ -55887,33 +55911,33 @@ msgstr "%qE muncul lebih dari sekali dalam clause data"
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE bukan sebuah variabel dalam clause %<firstprivate%>"
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE bukan sebuah variabel dalam clause %<lastprivate%>"
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -55936,7 +55960,7 @@ msgstr ""
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<nontemporal%> clause"
@@ -55948,7 +55972,7 @@ msgstr "%qE bukan sebuah variabel dalam clause %qs"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<allocate%> clause"
@@ -55960,84 +55984,84 @@ msgstr "%qE bukan sebuah variabel dalam clause %qs"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr ""
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression in array specification at %C"
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr "Diduga ekspresi dalam spesifikasi array di %C"
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported map expression %qE"
 msgstr "kombinasi tidak didukung: %s"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
@@ -56055,23 +56079,23 @@ msgstr "%s variabel %qs private dalam konteks luar"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "tipe dari vektor delete bukan penunjuk ataupun tipe array"
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %qs clauses on a task construct"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE adalah predetermined %qs untuk %qs"
@@ -56081,38 +56105,38 @@ msgstr "%qE adalah predetermined %qs untuk %qs"
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
@@ -56420,14 +56444,14 @@ msgstr "  untuk konversi dari %qT ke %qT"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  untuk konversi dari %qT ke %qT"
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -56773,620 +56797,620 @@ msgstr ""
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "tipe enumeral dan bukan enumeral dalam ekspresi kondisional"
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "tidak ada %<%D(int%> dideklarasikan untuk postfix %qs, mencoba operator prefix sebaliknya"
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, fuzzy, gcc-internal-format
 #| msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "tidak ada %<%D(int%> dideklarasikan untuk postfix %qs, mencoba operator prefix sebaliknya"
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "tipe kembali dari %q+D bukan %<int%>"
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "perbandingan antara %q#T dan %q#T"
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to %<(%T) (%A)%>"
 msgid "no match for call to %<%T::operator[] (%A)%>"
 msgstr "tidak ada yang cocok untuk panggilan ke %<(%T) (%A)%>"
 
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, fuzzy, gcc-internal-format
 #| msgid "call of %<(%T) (%A)%> is ambiguous"
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr "panggilan dari %<(%T) (%A)%> adalah ambigu"
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%q+D secara normal sebuah fungsi bukan-statis"
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "tidak ada dealokasi fungsi yang berhubungan untuk %qD"
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr ""
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "tidak cocok %<operator %s%> untuk %qT"
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "dalam konteks ini"
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared private here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "dalam konteks ini"
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared protected here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D tidak dapat diakses"
 
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "melewatkan koson ke argumen bukan penunjuk %P dari %qD"
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "  declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "mengubah ke tipe bukan penunjuk %qT dari KOSONG"
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "mengubah %<false%> ke tipe penunjuk untuk argumen %P dari %qD"
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, fuzzy, gcc-internal-format
 #| msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "mengubah %<false%> ke tipe penunjuk untuk argumen %P dari %qD"
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  inisialisasi argumen %P dari %qD"
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "terlalu banyak kurung diantara penginisialisasi untuk %qT"
 
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr ""
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr ""
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "konversi dari %qT ke %qT tidak valid"
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "konversi dari %qT ke %qT tidak valid"
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "mengubah ke %qT untuk daftar penginisialisasi akan menggunakan konstruktor eksplist %qD"
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "hanya deklarasi dari konstruktor yang dapan berupa %<explicit%>"
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 #, fuzzy
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "cast tidak valid dari sebuah ekspresi rvalue dari tipe %qT ke tipe %qT"
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr "inisialisasi dari referensi bukan const dari tipe %qT dari sebuah tipe sementara %qT tidak valid"
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "inisialisasi dari referensi bukan const dari tipe %qT dari sebuah tipe sementara %qT tidak valid"
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "inisialisasi dari referensi dari tipe %qT dari ekspresi dari tipe %qT tidak valid"
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 #, fuzzy
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "konversi dari %qT ke %qT mengabaikan kualifikasi"
 
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "tidak dapat mengikat bitfield %qE ke %qT"
 
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "tidak dapat mengikat packed field %qE ke %qT"
 
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "tidak dapat mengikat rvalue %qE ke %qT"
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "tidak dapat melewatkan objek dari tipe bukan POD %q#T melalui %<...%>; panggilan akan dibatalkan pada saat waktu-jalan"
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "tidak dapat menerima objek dari tipe bukan POD %q#T melalui %<...%>; panggilan akan dibatalkan pada saat waktu-jalan"
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "evaluasi rekursi dari argumen baku untuk %q#D"
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, fuzzy, gcc-internal-format
 #| msgid "the default argument for parameter %d of %qD has not yet been parsed"
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "argumen baku untuk parameter %d dari %qD belum diparse"
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "argumen dari fungsi panggilan mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr ""
 
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "melewatkan %qT sebagai %<this%> argumen dari %q#D mengabaikan kualifier"
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  dalam panggilan ke %qD"
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT bukan sebuah dasar yang bisa diakses dari %qT"
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "Hilang argumen ke %s intrinsik di %L"
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "penempatan (tidak terinisialisasi) dalam deklarasi"
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "lebih baik gunakan #include"
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of reference"
 msgid "; use value-initialization instead"
 msgstr "nilai-inisialisasi dari referensi"
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "penempatan (tidak terinisialisasi) dalam deklarasi"
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "lebih baik gunakan #include"
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of reference"
 msgid "; use copy-initialization instead"
 msgstr "nilai-inisialisasi dari referensi"
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%#qT declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, gcc-internal-format
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr ""
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "tidak pasangan fungsi untuk panggilan ke %<%T::%s(%A)%#V%>"
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "tidak pasangan fungsi untuk panggilan ke %<%T::%s(%A)%#V%>"
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "panggilan ke bukan-fungsi %qD"
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, fuzzy, gcc-internal-format
 #| msgid "mangling function-style cast with more than one argument"
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "mangling function-style cast dengan lebih dari satu argumen"
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "tidak ada fungsi yang cocok untuk panggilan ke %<%D(%A)%>"
 
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "panggilan dari overloaded %<%s(%A)%> adalah ambigu"
 
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT memiliki anggota data tidak statis bernama %qD"
 
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "mengembalikan sebuah nilai dari sebuah konstruktor"
 
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "mengembalikan sebuah nilai dari sebuah destruktor"
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "tidak dapat memanggil anggota fungsi %qD tanpa objek"
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "melewatkan %qT memilih %qT diatas %qT"
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr "ISO C++ mengatakan bahwa ini adalah ambigu, meskipun melalui konversi terburuk untuk yang pertama lebih baik daripada konversi terburuk untuk yang kedua:"
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "try making the operator a %<const%> member function"
 msgstr "%qD harus berupa sebuah anggota fungsi tidak statis"
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "memilih %qD diatas %qD"
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  untuk konversi dari %qT ke %qT"
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  karena urutan konversi untuk argumen lebih baik"
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "argumen baku tidak cocok dalam kelebihan beban resolusi"
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr " kandidat 1: %q+#F"
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr " kandidat 2: %q+#F"
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ mengatakan bahwa ini adalah ambigu, meskipun melalui konversi terburuk untuk yang pertama lebih baik daripada konversi terburuk untuk yang kedua:"
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "inisialisasi dari referensi bukan const dari tipe %qT dari sebuah tipe sementara %qT tidak valid"
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "inisialisasi dari referensi dari tipe %qT dari ekspresi dari tipe %qT tidak valid"
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "possibly dangling reference to a temporary"
 msgstr "mengembalikan referensi ke sementara"
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr ""
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, fuzzy, gcc-internal-format
 #| msgid "%s: definition of function '%s' not converted\n"
 msgid "explicit conversion function was not considered"
@@ -57440,7 +57464,7 @@ msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D tidak dapat overloaded"
 
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %q#D"
@@ -57910,7 +57934,7 @@ msgstr "%J anggota array fleksibel dalam sebaliknya struct kosong"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redefinisi dari %q#T"
@@ -58051,7 +58075,7 @@ msgstr "tipe kembali abstrak tidak valid untuk fungsi %q+#D"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
@@ -58096,7 +58120,7 @@ msgstr ""
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr ""
@@ -58115,7 +58139,7 @@ msgstr ""
 msgid "%q+E is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
@@ -58137,7 +58161,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
@@ -58188,7 +58212,7 @@ msgstr "%qT adalah sebuah dasar ambigu dari %qT"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
@@ -58332,20 +58356,20 @@ msgstr "%H array subscript diluar dari cakupan array"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "dereferensi penunjuk %<void *%>"
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -58354,516 +58378,516 @@ msgstr "dereferensi penunjuk %<void *%>"
 msgid "%qE is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr ""
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr ""
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini adalah sebuah penunjuk"
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr ""
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr ""
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr ""
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "parameter template %qD dari tipe %qT tidak diijinkan dalam sebuah ekspresi konstanta integral karena ini bukan tipe integral atau enumerasi"
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr ""
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr ""
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot be used in asm here"
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "%s tidak digunakan dalam asm disini"
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr ""
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "allocated here"
 msgstr "dipanggil dari sini"
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
 msgstr ""
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not initialized"
 msgid "%qD used in its own initializer"
 msgstr "%qE tidak terinisialisasi"
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q#D is not const"
 msgstr "%q#T bukan sebuah kelas"
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is private"
 msgid "%q#D is volatile"
 msgstr "%q+#D adalah private"
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD belum pernah dideklarasikan dalam lingkup ini"
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "%Hekspresi dalam pendeklarasi new harus memiliki integral atau tipe enumerasi"
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, gcc-internal-format
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr "deklarasi dari %q#D diluar dari kelas bukan sebuah definisi"
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, gcc-internal-format
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, gcc-internal-format
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr ""
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr ""
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr ""
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "inline assembly is not a constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "use of %qD"
 msgstr "penggunaan tidak valid dari %qD"
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr ""
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr ""
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr ""
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr ""
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, gcc-internal-format
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "tipe enumeral dan bukan enumeral dalam ekspresi kondisional"
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, fuzzy, gcc-internal-format
 #| msgid "cast from type %qT to type %qT casts away constness"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr "parameter template %qD dari tipe %qT tidak diijinkan dalam sebuah ekspresi konstanta integral karena ini bukan tipe integral atau enumerasi"
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, gcc-internal-format
 msgid "pointed-to object declared here"
 msgstr ""
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr "parameter template %qD dari tipe %qT tidak diijinkan dalam sebuah ekspresi konstanta integral karena ini bukan tipe integral atau enumerasi"
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr ""
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant expression"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "overflow dalam konstanta ekspresi"
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "contract predicate is false in constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a class template, got %qE"
 msgid "unexpected template-id %qE"
 msgstr "  diduga sebuah template kelas, diperoleh %qE"
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, fuzzy, gcc-internal-format
 #| msgid "non-function in gimple call"
 msgid "function concept must be called"
 msgstr "bukan fungsi dalam panggilan gimple"
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "diduga ekspresi"
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, gcc-internal-format
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "cast tidak valid dari sebuah ekspresi rvalue dari tipe %qT ke tipe %qT"
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away constness"
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "reinterpret_cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "new-expression is not a constant expression before C++20"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "division by zero is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "overflow dalam konstanta ekspresi"
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "indeks array bukan konstan dalam penginisialisasi"
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
@@ -59668,7 +59692,7 @@ msgstr "argumen ketiga ke %<__builtin_prefetch%> harus berupa sebuah konstan"
 msgid "no suspend point info for %qD"
 msgstr "tidak ada prototipe sebelumnya untuk %q+D"
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -59691,23 +59715,23 @@ msgstr "penunjuk tidak diijinkan sebagai nilai case"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "array dengan panjang bervariabel %qs digunakan"
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, fuzzy, gcc-internal-format
 #| msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
@@ -59729,77 +59753,77 @@ msgstr ""
 msgid "%qD was promoted to an immediate function"
 msgstr "%qD bukan sebuah fungsi template"
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "taking address of an immediate function %qD"
 msgstr "penggunaan tidak valid dari anggota fungsi %qD bukan statis"
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "call to consteval function %qE is not a constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "alamat dari %qD akan selalu dievaluasi sebagai %<true%>"
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "pack expansion of %qE attribute"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, fuzzy, gcc-internal-format
 #| msgid "%Hparse error in template argument list"
 msgid "use fold expression in the attribute argument instead"
 msgstr "%Hparse error dalam daftar argumen template"
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD bukan sebuah tipe"
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qD is not a class type"
 msgstr "%qT bukan sebuah tipe kelas"
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE does not have class type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "%H%qE tidak memiliki tipe kelas"
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE does not have class type"
 msgid "%qD does not have integral type"
 msgstr "%H%qE tidak memiliki tipe kelas"
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
@@ -59852,7 +59876,7 @@ msgstr "inisialisasi dari referensi bukan const dari tipe %qT dari sebuah tipe s
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "konversi dari %qT ke %qT mengabaikan kualifikasi"
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "casting %qT ke %qT tidak medereferensi penunjuk"
@@ -60283,7 +60307,7 @@ msgstr "dari deklarasi sebelumnya %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "deklarasi friend %qD dalam kelas lokal tanpa deklarasi sebelumnya"
 
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -60448,8 +60472,8 @@ msgstr "deklarasi sebelumnya bukan fungsi %q+#D"
 msgid "%q#D previously defined here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D previously declared here"
@@ -60533,59 +60557,41 @@ msgstr "argumen baku diberikan untuk parameter %d dari %q#D"
 msgid "previous specification in %q#D here"
 msgstr "setelah spesifikasi sebelumnya dalam %q+#D"
 
-#: cp/decl.cc:2285
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of namespace %qD conflicts with"
-msgid "declaration %qD conflicts with builtin"
-msgstr "deklarasi dari namespace %qD konflik dengan"
-
-#: cp/decl.cc:2288
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of namespace %qD conflicts with"
-msgid "declaration %qD conflicts with import"
-msgstr "deklarasi dari namespace %qD konflik dengan"
-
-#: cp/decl.cc:2289
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration %q+#D here"
-msgid "import declared %q#D here"
-msgstr "deklarasi sebelumnya %q+#D disini"
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting exporting for declaration %qD"
 msgstr "konflik deklarasi %q#D"
 
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, gcc-internal-format
 msgid "previously declared here without exporting"
 msgstr ""
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD here"
 msgstr "definisi sebelumnya dari %q+D ada disini"
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD here"
 msgstr "deklarasi sebelumnya dari %q+D ada disini"
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, fuzzy, gcc-internal-format
 #| msgid "function declared %<noreturn%> has a %<return%> statement"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "fungsi dideklarasikan %<noreturn%> memiliki sebuah pernyataan %<return%>"
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "deklarasi redundansi dari %qD dalam lingkup sama"
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, fuzzy, gcc-internal-format
 #| msgid "deleted definition of %qD"
 msgid "deleted definition of %qD is not first declaration"
@@ -60599,50 +60605,50 @@ msgstr "definisi terhapus dari %qD"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "spesisialisasi eksplisit dari %qD setelah penggunaan pertama"
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D: visibility attribute ignored because it"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%q+D: atribut visibility diabaikan karenanya"
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "redefinition of %q#D"
 msgstr "redefinisi dari %q#T"
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%qD conflicts with used function"
 msgstr "%q#D konflik dengan deklarasi sebelumnya menggunakan %q#D"
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%q#D not declared in class"
 msgstr "%qD tidak dideklarasikan dalam %qD"
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, fuzzy, gcc-internal-format
 #| msgid "%qs redeclared with conflicting %qs attributes"
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%qs redeklarasi konflik dengan atribut %qs"
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, fuzzy, gcc-internal-format
 #| msgid "%qs redeclared with conflicting %qs attributes"
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%qs redeklarasi konflik dengan atribut %qs"
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -60650,812 +60656,812 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "%qD tidak dapat memiliki argumen baku"
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, fuzzy, gcc-internal-format
 #| msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "thread-local deklarasi dari %q+D mengikuti deklarasi bukan-thread-lokal"
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, fuzzy, gcc-internal-format
 #| msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "non-thread-local deklarasi dari %q+D mengikuti deklarasi thread-local"
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D"
 msgid "redeclaration of %q#D"
 msgstr "deklarasi dari %q#D"
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "deklarasi redundansi dari %qD dalam lingkup sama"
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, gcc-internal-format
 msgid "jump to label %qD"
 msgstr "lompat ke label %qD"
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr "lompat ke case label"
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr ""
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  dari sini"
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  keluar OpenMP structured block"
 
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  menyilangi inisialisasi dari %q+#D"
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  memasuki blok percobaan"
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  mamasuki blok penangkapan"
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  memasuki blok terstruktur OpenMP"
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, fuzzy, gcc-internal-format
 #| msgid "jump into statement expression"
 msgid "  enters statement expression"
 msgstr "melompat kedalam pernyataan ekspresi"
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, gcc-internal-format
 msgid "  enters %<consteval if%> statement"
 msgstr ""
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "  does not destroy %qD"
 msgstr "%s tidak mendukung %s"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, gcc-internal-format
 msgid "  does not clean up handled exception"
 msgstr ""
 
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  melewati inisialisasi dari %q+#D"
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "%qD digunakan tanpa parameter template"
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is a function, not a type"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T bukan sebuah kelas"
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "tidak ada tempat kelas yang bernama %q#T dalam %q#T"
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, fuzzy, gcc-internal-format
 #| msgid "no class template named %q#T in %q#T"
 msgid "no type named %q#T in %q#T"
 msgstr "tidak ada tempat kelas yang bernama %q#T dalam %q#T"
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "konversi dari %qT ke %qT adalah ambigu"
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> nama %q#T, yang bukan sebuah class template"
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, fuzzy, gcc-internal-format
 #| msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> nama %q#T, yang bukan sebuah tipe"
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "parameter template tidak cocok dengan template"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "alignmen yang diminta bukan kelipatan dari 2"
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D tidak valid; sebuah anonymous union hanya dapat mempunnya anggota data tidak statis"
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous struct not inside named type"
 msgid "anonymous struct with base classes"
 msgstr "anonymous struct tidak didalam tipe bernama"
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "anggota %q+#D dengan konstruktor tidak diijinkan dalam kumpulan anonymous"
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "anggota %q+#D dengan desktruktor tidak diijinkan dalam kumpulan anoymous"
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "anggota %q+#D dengan operator penempatan salin tidak diperbolehkan dalam kumpulan anonymous"
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "atribut diabaikan dalam deklarasi dari %q+#T"
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, fuzzy, gcc-internal-format
 #| msgid "attribute for %q+#T must follow the %qs keyword"
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "atribut untuk %q+#T harus mengikuti kata kunci %qs"
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "multiple tipe dalam satu deklarasi"
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "redeklarasi dari C++ tipe bawaan %qT"
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "hilang nama-tipe dalam typedef-deklarasi"
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ menghambat struct anonymous"
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> hanya dapat dispesifikasikan didalam sebuah kelas"
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> hanya dapat dispesifikasikan untuk konstruktor"
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "sebuah kelas penyimpanan hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "kualifier hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "kualifier hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "kualifier hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "sebuah kelas penyimpanan hanya dapat dispesifikasikan untuk objek dan fungsi"
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> telah diabaikan dalam deklarasi ini"
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qs cannot be used for type declarations"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "atribut diabaikan di template instantiation"
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class"
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "mengabaikan atribut yang diaplikasikan ke tipe kelas %qT diluar dari definisi"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "mengabaikan atribut yang diaplikasikan ke tipe dependen %qT tanpa sebuah deklarasi yang berasosiasi"
 
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use decltype instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD diinisialisasi (lebih baik gunakan decltype)"
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "deklarasi dari %q#D memiliki %<extern%> dan terinisialisasi"
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "definisi dari %q#D ditandai %<dllimport%>"
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D bukan sebuah anggota data bukan-statis dari %qT"
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "template deklarasi dari %q#D"
 
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "deklarasi anggota template %qD tidak valid"
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ tidak mengijinkan %<%T::%D%> untuk didefinisikan sebagai %<%T::%D%>"
 
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "duplikasi inisialisasi dari %qD"
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "deklarasi dari %q#D diluar dari kelas bukan sebuah definisi"
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr ""
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variabel %q#D memiliki penginisialisasi tetapi tipe tidak lengkap"
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elemen dari array %q#D memiliki tipe tidak lengkap"
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "kumpulan %q#D memiliki tipe tidak lengkap dan tidak dapat didefinisikan"
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD dideklarasikan sebagai referensi tetapi tidak terinisialisasi"
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "nama digunakan dalam sebuah gaya GNU diperuntukan penginisialisasi untuk sebuah array"
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "nama %qD digunakan dalam sebuah gaya GNU didesign penginisialisasi untuk sebuah array"
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "bukan trivial designated penginisialisasi tidak didukung"
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "penginisialisasi gagal untuk menentukan ukuran dari %qD"
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "ukuran array hilang dalam %qD"
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "array berukuran-nol %qD"
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t known"
 msgid "storage size of %qD isn%'t known"
 msgstr "ukuran penyimpanan dari %q+D tidak diketahui"
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "ukuran penyimpanan dari %q+D bukan konstant"
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "maaf: semantik dari fungsi inline data statis %q+#D salah (anda akan berputar putar dengan beberap salinan)"
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "maaf: semantik dari fungsi inline data statis %q+#D salah (anda akan berputar putar dengan beberap salinan)"
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "%J  anda dapat memperbaiki ini dengan menghapus penginisialisasi"
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "tidak terinisialisasi const %qD"
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "variabel register %qD digunakan dalam fungsi nested"
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized member %qD with %<const%> type %qT"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%J anggota tidak terinisialisasi %qD dengan %<const%> tipe %qT"
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "tipe %qs memiliki sebuah konstruktor yang didefinisikan pengguna"
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "tipe tidak valid %qT sebagai penginisialisasi untuk sebuah vektor dari tipe %qT"
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "penginisialisasi untuk %qT harus berupa kurung dilingkupi"
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "nama %qD digunakan dalam sebuah gaya GNU didesign penginisialisasi untuk sebuah array"
 
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "permintaan untuk anggota %qD adalah ambigu"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT memiliki anggota data tidak statis bernama %qD"
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD bukan sebuah anggota dari %qT"
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "terlalu banyak penginisialisasi untuk %qT"
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "kurung disekitar penginisialisasi skalar untuk tipe %qT"
 
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "kurung disekitar penginisialisasi skalar untuk tipe %qT"
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "hilang kurung diantara penginisialisasi untuk %qT"
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %P has incomplete type %qT"
 msgid "structured binding has incomplete type %qT"
 msgstr "parameter %P memiliki tipe tidak lengkap %qT"
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "elemen dari array %q#T memiliki tipe tidak lengkap"
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ukuran-variabel compound literals"
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "%qD memiliki tipe tidak lengkap"
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "objek skalar %qD membutuhkan satu elemen dalam penginisialisasi"
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "dalam C++98 %qD harus diinisialisasi dengan konstruktor, bukan dengan %<{...}%>"
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "array %qD diinisialisasi dengan tanda kurung string literal %qE"
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "penginisialisasi tidak valid untuk anggota statis  dengan konstruktor"
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ melarang dalam kelas inisialisasi dari anggota statis bukan const %qD"
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ melarang dalam kelas inisialisasi dari anggota statis bukan const %qD"
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(diluar dari kelas inisialisasi dibutuhkan)"
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "parameter %qD dinisialisasi"
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%> tidak dalam sebuah deklarasi"
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "redeklarasi dari enumerator %q+D"
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "redeklarasi dari enumerator %q+D"
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "deklarasi dari template %q#D"
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "%<declare variant%> on deleted %qD"
 msgstr "deklarasi dari template %q#D"
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "penempatan (tidak terinisialisasi) dalam deklarasi"
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "kelas penyimpanan dispesifikasikan untuk %qs"
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "deklarasi dari %q#D tidak memiliki penginisialisasi"
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "tipe kembali %q#T tidak lengkap"
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "objek berukuran-variabel tidak boleh diinisialisasi"
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "membayangi tipe deklarasi sebelumnya dari %q#D"
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "fungsi %q#D telah dinisialisasi seperti sebuah variabel"
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  tidak dapat menggunakan obsolete binding di %q+D karena ini memiliki sebuah desktruktor"
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT adalah sebuah dasar tidak dapat diakses dari %qT"
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, fuzzy, gcc-internal-format
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qs"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 melarang array dengan panjang bervariabel %qs"
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Hinitializer provided for function"
 msgid "%u name provided for structured binding"
@@ -61463,1940 +61469,1940 @@ msgid_plural "%u names provided for structured binding"
 msgstr[0] "%Hpenginisialisasi disediakan untuk fungsi"
 msgstr[1] "%Hpenginisialisasi disediakan untuk fungsi"
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T"
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, fuzzy, gcc-internal-format
 #| msgid "initialization string truncated to match variable at %L"
 msgid "in initialization of structured binding variable %qD"
 msgstr "inisialisasi dari string terpotong untuk mencocokan dengan variabel di %L"
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "tidak dapat menguraikan alamat"
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, fuzzy, gcc-internal-format
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "tidak dapat menjalankan %<offsetof%> ke anggota data statis %qD"
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "penginisialisasi gagal untuk menentukan ukuran dari %qD"
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "ukuran array hilang dalam %qD"
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "array berukuran-nol %qD"
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "desktruktor untuk alien kelas %qT tidak dapat berupa sebuah anggota"
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruktor untuk alien kelas %qT tidak dapt berupa sebuah anggota"
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D dideklarasikan sebagai sebuah friend"
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D dideklarasikan dengan spesifikasi eksepsi"
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "definisi dari %qD tidak dalam namespace melingkupi %qT"
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "anggota fungsi statis %q#D dideklarasikan dengan tipe pengkualifikasi"
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%q+D dideklarasikan sebagai sebuah bukan-parameter"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "parameter %q+D dideklarasikan dengan tipe void"
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "metoda Java %qD memiliki tipe kembali %qT bukan Java"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "concept %qD has no definition"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a function concept cannot be constrained"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD bukan sebuah fungsi template"
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "constrained non-template friend declaration must be a definition"
 msgstr "deklarasi friend tidak dalam definisi kelas"
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "mendifinisikan eksplisit spesialisasi %qD dalam deklarasi friend"
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "penggunaan tidak valid dari template-id %qD dalam deklarasi dari primary template"
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "argumen baku tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "deklarasi dari %q#D diluar dari kelas bukan sebuah definisi"
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi sebuah template"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi inline"
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi statis"
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi statis"
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "fungsi bukan-anggota %qD tidak dapat memiliki cv-kualifier"
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "anggota fungsi statis %qD tidak dapat memiliki cv kualifier"
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr "anggota fungsi statis %qD tidak dapat memiliki cv kualifier"
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "fungsi bukan-anggota %qD tidak dapat memiliki cv-kualifier"
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "anggota fungsi statis %qD tidak dapat memiliki cv kualifier"
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr "anggota fungsi statis %qD tidak dapat memiliki cv kualifier"
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "explicit object parameter declared here"
 msgstr "tipe parameter template %qT dideklarasikan %<friend%>"
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, fuzzy, gcc-internal-format
 #| msgid "Binding at %C must have the same access as already defined binding '%s'"
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "Binding di %C harus memiliki akses sama seperti telah didefinisikan binding '%s'"
 
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate with C linkage"
 msgid "literal operator with C linkage"
 msgstr "%Htemplate dengan C linkage"
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "%qD has invalid argument list"
 msgstr "pilihan argumen %qs tidak valid"
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "%qD harus berupa sebuah anggota fungsi tidak statis"
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> harus kembali %<int%>"
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "definisi dari secara implisit dideklarasikan %qD"
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "definisi dari secara implisit dideklarasikan %qD"
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "bukan %q#D anggota fungsi dideklarasikan dalam kelas %qT"
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi sebuah template"
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "variabel otomatis %qE tidak dapat berupa %<threadprivate%>"
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, fuzzy, gcc-internal-format
 #| msgid "strong using only meaningful at namespace scope"
 msgid "concept must be defined at namespace scope"
 msgstr "strong using hanya berarti di lingkup namespace"
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "objek berukuran-variabel tidak boleh diinisialisasi"
 
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ melarang dalam kelas inisialisasi dari anggota statis bukan const %qD"
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ melarang inisialisasi dari anggota constant %qD dari bukan integral tipe %qT"
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "ukuran dari array %qD memiliki tipe bukan integral %qT"
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "ukuran dari array memiliki tipe %qT bukan integral"
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ melarang array berukuran-nol %qD"
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ melarang array berukuran-nol"
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ melarang array dengan variabel panjang %qD"
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ melarang array dengan variabel panjang"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "array dengan panjang bervariabel  %qD digunakan"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "array dengan panjang bervariabel digunakan"
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "overflow dalam dimensi array"
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr ""
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "creating array of template placeholder type %qT"
 msgstr "membuat penunjuk ke anggota referensi tipe %qT"
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "deklarasi dari %qs sebagai dari voids"
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of void"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of functions"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of references"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "creating array of function members"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklarasi dari %qD sebagai array multidimensi harus memiliki batasan untuk seluruh dimensi kecuali yang pertama"
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "array multidimensi harus memiliki batasan untuk seluruh dimensi kecuali yang pertama"
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable-length array of %<auto%>"
 msgstr "array dengan panjang bervariabel digunakan"
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "spesifikasi tipe kembali untuk konstruktor tidak valid"
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "spesifikasi tipe kembali untuk desktruktor tidak valid"
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "tipe kembali yang dispesifikasikan untuk %<operator %T%>"
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "spesifikasi tipe kembali untuk desktruktor tidak valid"
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "terlalu banyak daftar parameter template dalam deklarasi dari %qD"
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "penspesifikasi konflik dalam deklarasi dari %qs"
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "variabel tidak bernama atau field dideklarasikan void"
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variabel atau field dideklarasikan void"
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "%<inline%> penspesifikasi tidak valid untuk fungsi %qs dideklarasikan diluar dari lingkup global"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "penggunaan tidak valid dari nama kualifikasi %<::%D%>"
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "penggunaan tidak valid dari nama kualifikasi %<%T::%D%>"
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "penggunaan tidak valid dari nama kualifikasi %<%D::%D%>"
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT bukan sebuah class atau namespace"
 
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "deklarasi dari %qD sebagai bukan anggota"
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "id pendeklarasi hilang; menggunaka kata reserved %qD"
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "definisi fungsi tidak mendeklarasikan parameter"
 
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "deklarasi dari %qD sebagai %s"
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, fuzzy, gcc-internal-format
 #| msgid "missing type-name in typedef-declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "hilang nama-tipe dalam typedef-deklarasi"
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "dua atau lebih tipe data dalam deklarasi dari %qs"
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C tidak mendukung plain %<complex%> yang berarti %<double complex%>"
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ melarang deklarasi dari %qs dengan tidak ada tipe"
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs tidak didukung oleh target ini"
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ 1998 does not support %<long long%>"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ 1998 tidak mendukung %<long long%>"
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, fuzzy, gcc-internal-format
 #| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> dan %<unsigned%> dispesifikasikan bersama untuk %qs"
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> dan %<short%> dispesifikasikan bersama untuk %qs"
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "%qs specified with %qT"
 msgstr "tidak ada nama class dispesifikasikan dengan %qs"
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, gcc-internal-format
 msgid "%qs specified with typedef-name %qD"
 msgstr ""
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs tidak dispesifikan dalam parallel yang melingkupi"
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> digunakan dengan %<typedef%>"
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "kompleks tidak valid untuk %qs"
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "anggota %qD tidak dapat dideklarasikan baik virtual dan statis"
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "anggota %qD tidak dapat dideklarasikan baik virtual dan statis"
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "type deklarasi tidak valid dalam parameter deklarasi"
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for template parameter %qs"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a parameter cannot be declared %qs"
 msgstr "parameter template tidak dapat berupa friends"
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> diluar deklarasi kelas"
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "atribut diabaikan dalam deklarasi dari %q+#T"
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "atribut diabaikan dalam deklarasi dari %q+#T"
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr ""
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "multiple storage kelas dalam deklarasi dari %qs"
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "kelas penyimpanan dispesifikasikan untuk %qs"
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "fungsi nested %qs dideklarasikan %<extern%>"
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "top-level deklarasi dari %qs menspesifikasikan %<auto%>"
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "lingkup-fungsi %qs secara implisit auto dan dideklarasikan %<__thread%>"
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "spesifikasi kelas penyimpanan tidak valid dalam deklarasi fungsi friend"
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "%qE atribut diabaikan"
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "multiple storage kelas dalam deklarasi dari %qs"
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "Diduga parenthesis kiri"
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "a function type cannot have an explicit object parameter"
 msgstr "Fungsi '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, gcc-internal-format
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr "penunjuk ke anggota fungsi digunakan dalam aritmetik"
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr ""
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, gcc-internal-format
 msgid "the type of an explicit object member function is a regular function type"
 msgstr ""
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "valid explicit object parameter declared here"
 msgstr ""
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function uses %<auto%> type specifier without late return type"
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs fungsi menggunakan penspesifikasi tipe %<auto%> tanpa tipe kembali late"
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with late return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs fungsi dengan tipe kembali late memiliki %qT sebagai tipenya daripada plain %<auto%>"
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with late return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "%qs fungsi dengan tipe kembali late memiliki %qT sebagai tipenya daripada plain %<auto%>"
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "penggunaan tidak valid dari %<auto%>"
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "tipe pengkualifikasi diabaikan di tipe kembali fungsi"
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with late return type not declared with %<auto%> type specifier"
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs fungsi dengan tipe kembali late tidak dideklarasikan dengan penspesifikasi tipe %<auto%>"
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah fungsi"
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah array"
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<noreturn%> fungsi mengembalikan nilai bukan-void"
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "constructor cannot be static member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be cv-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "deklarasi friend tidak dalam definisi kelas"
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "tidak dapat mendefinisikan fungsi friend %qs dalam sebuah definisi lokal kelas"
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr "fungsi bukan-anggota %qD tidak dapat memiliki cv-kualifier"
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr "anggota fungsi statis %qD tidak dapat memiliki cv kualifier"
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD cannot be an explicit object member function"
 msgstr "%qD harus berupa sebuah anggota fungsi tidak statis"
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruktor mungkin tidak memiliki parameter"
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T"
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T anggota"
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T, yang bukan sebuah typedef atau sebuah argumen tipe template"
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD digunakan sebagai sebuah pendeklarasi"
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "anggota fungsi secara implisit friends dari kelasnya"
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "ekstra kualifikasi %<%T::%> di anggota %qs"
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "tidak dapat mendefinisikan anggota fungsi %<%T::%s%> dalam %<%T%>"
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member %<%T::%s%> within %qT"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "tidak dapat mendeklarasikan anggota %<%T::%s%> dalam %qT"
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "tidak dapat mendeklarasikan anggota %<%T::%s%> dalam %qT"
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "bukan parameter %qs tidak dapat menjadi parameter pack"
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "anggota member tidak boleh memiliki tipe variabel termodifikasi %qT"
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter mungkin tidak memiliki tipe variabel termodifikasi %qT"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> diluar deklarasi kelas"
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> dalam deklarasi kosong"
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "hanya deklarasi dari konstruktor yang dapan berupa %<explicit%>"
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "bukan-anggota %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "anggota bukan-objek %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "fungsi %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "statis %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "const %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "fungsi %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, fuzzy, gcc-internal-format
 #| msgid "%Hattributes are not allowed on a function-definition"
 msgid "typedef may not be a function definition"
 msgstr "%Hatribut tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "typedef may not be a member function definition"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<[*]%> not allowed in other than a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%H%<[*]%> tidak diijinkan selain dalam sebuah deklarasi"
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, fuzzy, gcc-internal-format
 #| msgid "parameter declared %<auto%>"
 msgid "typedef declared %<auto%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%J typedef nama mungkin berupa sebuah nested-name-specifier"
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ melarang tipe nested %qD dengan nama sama seperti kelas yang melingkupi"
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> dispesifikan untuk deklarasi kelas friend"
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "parameter template tidak dapat berupa friends"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "deklarasi friend membutuhkan kunci kelas, i.e. %<friend class %T::%D%>"
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "deklarasi friend membutuhkan class-key, i.e. %<friend %#T%>"
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "mencoba untuk membuat kelas %qT sebuah friend dari lingkup global"
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "kualifier tidak valid di tipe fungsi bukan anggota"
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "deklarasi abstrak %qT digunakan sebagai deklarasi"
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "redeklarasi dari C++ tipe bawaan %qT"
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "tidak dapat menggunakan %<::%> dalam parameter deklarasi"
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "tidak dapat mendeklarasikan parameter %q+D untuk menjadi tipe abstrak %qT"
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%H%<this%> mungkin tidak digunakan dalam konteks ini"
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of template-name %qE without an argument list"
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "%Hpenggunaan tidak vlaid dari nama template %qE tanpa sebuah daftar argumen"
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ melarang array berukuran-nol %qD"
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 tidak mendukung keanggotaan array fleksibel"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "penggunaan tidak valid dari %<::%>"
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "deklarasi dari C fungsi %q#D konflik dengan"
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "fungsi %qD dideklarasikan virtual didalam sebuah union"
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD tidak dapat dideklarasikan virtual, karena itu selalu statis"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "diduga nama yang dikualifikasikan dalam deklarasi friend untuk destruktor %qD"
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "deklarasi dari %qD sebagai anggota dari %qT"
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "a destructor cannot be %qs"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "diduga kualifikasi nama dalam deklarasi friend untuk konstruktor %qD"
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "a constructor cannot be %<concept%>"
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "tidak dapat membuka %s"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "spesialisasi dari anggota fungsi spesial secara implist dideklarasikan"
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "variabel atau field dideklarasikan void"
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "field %qD memiliki tipe tidak lengkap"
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "nama %qT memiliki tipe tidak lengkap"
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE bukan fungsi atau anggota fungsi; tidak dapat dideklarasikan sebagai friend"
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE bukan fungsi atau anggota fungsi; tidak dapat dideklarasikan sebagai friend"
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "static data member %qE declared %qs"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "kelas penyimpanan %<auto%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "kelas penyimpanan %<register%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "kelas penyimpanan %<__thread%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "kelas penyimpanan %<__thread%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr "%<inline%> penspesifikasi tidak valid untuk fungsi %qs dideklarasikan diluar dari lingkup global"
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, fuzzy, gcc-internal-format
 #| msgid "%Han asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "%Hsebuah spesifikasi asm tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> dispesifikasikan tidak valid untuk fungsi %qs dideklarasikan diluar lingkup global"
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<inline%> penspesifikasi tidak valid untuk fungsi %qs dideklarasikan diluar dari lingkup global"
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtual bukan kelas fungsi %qs"
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs didefinisikan dalam sebuah lingkup bukan kelas"
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, fuzzy, gcc-internal-format
 #| msgid "%qs defined in a non-class scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qs didefinisikan dalam sebuah lingkup bukan kelas"
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "tidak dapat mendeklarasikan anggota fungsi %qD untuk memiliki linkage statis"
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "tidak dapat mendeklarasikan fungsi statis didalam fungsi lainnya"
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> mungkin tidak digunakan ketika mendefinisikan (terbalik untuk deklarasi) sebuah anggota data statis"
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "tidak dapat secara eksplisit mendeklarasikan anggota %q#D untuk memiliki extern linkage"
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "deklarasi dari variabel %<extern%> %q+D dalam %<for> inisial deklarasi loop"
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "statis %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs diinisialisasi dan dideklarasi %<extern%>"
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs keduanya memiliki %<extern> dan penginisialisasi"
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "argumen baku %qE menggunakan variabel lokal %qD"
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "argumen baku %qE menggunakan variabel lokal %qD"
 
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "penspesifikasi kelas penyimpanan dalam parameter deklarasi"
 
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "tidak dapat menggunakan %<::%> dalam parameter deklarasi"
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qD secara tidak valid dideklarasikan tipe metode"
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameter %qD includes %s ke array dari ikatan tidak dikenal %qT"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parameter %qD includes %s ke array dari ikatan tidak dikenal %qT"
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "konstruktor tidak valid; anda mungkin bermaksud %<%T (const %T&)%>"
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD mungkin tidak dideklarasikan dalam sebuah namespace"
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD tidak boleh dideklarasikan sebagai statis"
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD harus berupa sebuah anggota fungsi tidak statis"
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a member function"
 msgstr "%qD harus berupa sebuah anggota fungsi tidak statis"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD harus baik sebuah anggota fungsi tidak statis atau bukan anggota fungsi"
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD harus memiliki sebuah argumen dari kelas atau tipe enumerasi"
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ melarang overloading operator ?:"
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD tidak boleh memiliki argumen dengan jumlah bervariabel"
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD harus mengambil baik nol atau satu argumen"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD harus mengambil baik satu atau dua argumen"
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfix %qD harus mengambil %<int%> sebagai argumennya"
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfix %qD harus mengambil %<int%> sebagai argumen keduanya"
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD harus mengambil secara tepat dua argumen"
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD harus mengambil secara tepat satu argumen"
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD harus mengambil secara tepat dua argumen"
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD tidak dapat memiliki argumen baku"
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "definisi-pengguna %qD selalu mengevaluasikan kedua argumen"
 
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "prefix %qD seharusnya mengembalikan %qT"
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "postfix %qD seharusnya mengembalikan %qT"
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD seharusnya kembali dengan nilai"
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization %qD for %q+D"
 msgid "using alias template specialization %qT after %qs"
 msgstr "spesialisasi template ambigu %qD untuk %q+D"
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "menggunakan typedef-name %qD setelah %qs"
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D telah dideklarasikan sebelumnya disini"
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT mereferensikan sebagai %qs"
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T telah dideklarasikan sebelumnya disini"
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT direferensikan sebagai enum"
@@ -63408,121 +63414,103 @@ msgstr "%qT direferensikan sebagai enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "argumen template dibutuhkan untuk %<%s %T%>"
 
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfunction template %qD redeclared as a class template"
 msgid "class template %qD redeclared as non-template"
 msgstr "%Htemplate fungsi %qD redeklarasikan sebagai sebuah template kelas"
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD memiliki nama sama seperti kelas yang telah dideklarasikan"
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT mungkin bukan sebuah template"
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "penggunaan dari enum %q#D tanpa deklarasi sebelumnya"
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redeklarasi dari %qT sebagai bukan-template"
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare %qD to be a bit-field type"
-msgid "cannot declare %qD in a different module"
-msgstr "tidak dapat mendeklarasikan %qD untuk menjadi sebuah tipe bit-field"
-
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, fuzzy, gcc-internal-format
-#| msgid "%Jpreviously used here"
-msgid "previously declared here"
-msgstr "%J sebelumnya digunakan disini"
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "union turunan %qT tidak valid"
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "tipe %qT tidak sebuah langsung atau virtual base dari %qT"
 
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "tipe base %qT gagal untuk menjadi sebuah struct atau tipe kelas"
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "tipe rekursif %qT tidak terdefinisi"
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "duplikasi tipe dasar %qT tidak valid"
 
-#: cp/decl.cc:16984
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare %qD to be a bit-field type"
-msgid "cannot declare %qD in different module"
-msgstr "tidak dapat mendeklarasikan %qD untuk menjadi sebuah tipe bit-field"
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%J definisi sebelumnya disini"
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -63532,90 +63520,90 @@ msgstr "tipe yang digaris bawahi %<%T%> dari %<%T%> harus berupa sebuah tipe int
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "tidak ada tipe integral yang dapat merepresentasikan seluruh dari nilai enumerasi untuk %qT"
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "nilai enumerasi untuk %qD bukan sebuah konstanta integer"
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "nilai enumerasi untuk %qD bukan sebuah konstanta integer"
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "overflow dalam nilai enumerasi di %qD"
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "multiple definisi dari %q#T"
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "tipe kembali %q#T tidak lengkap"
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> seharusnya mengembalikan referensi ke %<*this%>"
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "tipe kembali fungsi tidak kompatibel karena %<volatile%>"
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD telah didefinisikan dalam kelas %qT"
 
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, fuzzy, gcc-internal-format
 #| msgid "try using %qE instead"
 msgid "using %qs"
 msgstr "lebih baik coba gunakan %qE"
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -63671,7 +63659,7 @@ msgstr "tidak dapat menghapus sebuah fungsi. Hanya penunjuk-ke-objek yang valid
 msgid "deleting %qT is undefined"
 msgstr "menghapus %qT tidak terdefinisi"
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "template deklarasi dari %q#D"
@@ -63682,7 +63670,7 @@ msgstr "template deklarasi dari %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "daftar parameter template yang disediakan tidak cocok dengan paramter template dari %qD"
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "destruktor %qD dideklarasikan sebagai anggota template"
@@ -63882,73 +63870,73 @@ msgstr ""
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> mengambil tipe %qT sebagai parameter pertama"
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr "%qT memiliki sebuah field %qD yang tipe menggunakan namespace anonymous"
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT memiliki sebuah field %qD yang tipe menggunakan namespace anonymous"
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr "%qT memiliki sebuah field %qD yang tipe menggunakan namespace anonymous"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr "%qT memiliki sebuah field %qD yang tipe menggunakan namespace anonymous"
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT dideklarasikan dengan visibility lebih besar dari tipe dari fieldnya %qD"
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT which has no linkage"
 msgstr "%qT memiliki sebuah base %qT yang menggunakan tipe namespace anonymous"
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr "%qT memiliki sebuah base %qT yang menggunakan tipe namespace anonymous"
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT which has internal linkage"
 msgstr "%qT memiliki sebuah base %qT yang menggunakan tipe namespace anonymous"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr "%qT memiliki sebuah base %qT yang menggunakan tipe namespace anonymous"
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT dideklarasikan dengan visibility lebih besar dari basenya %qT"
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but not defined"
 msgstr ""
@@ -63957,115 +63945,115 @@ msgstr ""
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D tidak merefer ke tipe tidak terkualifikasi, jadi ini tidak digunakan untuk linkage"
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr ""
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "deklarasi sebelumnya dari %q+#D dengan %qL linkage"
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, fuzzy, gcc-internal-format
 #| msgid "section of %q+D conflicts with previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "daerah dari %q+D konflik dengan deklarasi sebelumnya"
 
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous mangling %q#D"
 msgstr "deklarasi sebelumnya %q+D"
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, gcc-internal-format
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "fungsi inline %q+D digunakan tetapi tidak pernah didefinisikan"
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, fuzzy, gcc-internal-format
 #| msgid "default argument missing for parameter %P of %q+#D"
 msgid "default argument missing for parameter %P of %q#D"
 msgstr "argumen baku hilang untuk parameter %P dari %q+#Ddd"
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, fuzzy, gcc-internal-format
 #| msgid "%H%sparameter pack cannot have a default argument"
 msgid "...following parameter %P which has a default argument"
 msgstr "%H%s parameter pack tidak dapat memiliki sebuah argumen baku"
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "implicitly-declared %qD is deprecated"
 msgstr "definisi dari secara implisit dideklarasikan %qD"
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, fuzzy, gcc-internal-format
 #| msgid "deleted function %q+D"
 msgid "use of deleted function %qD"
 msgstr "fungsi %q+D terhapus"
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -64190,7 +64178,7 @@ msgstr "%Hreferensi ke %<%T::%D%> adalah ambigu"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD bukan sebuah anggota dari %qT"
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD bukan sebuah anggota dari %qT"
@@ -64201,7 +64189,7 @@ msgstr "%qD bukan sebuah anggota dari %qT"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%H%qD bukan sebuah anggota dari %qD"
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is not a member of %qD"
 msgid "%qD is not a member of %qD"
@@ -64230,52 +64218,52 @@ msgstr "penanganan eksespsi dinon-aktifkan, gunakan -fexception untuk mengaktifk
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr "melemparkan KOSONG, yang memiliki integral, bukan tipe penunjuk"
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, gcc-internal-format
 msgid "  in thrown expression"
 msgstr "  dalam ekspresi thrown"
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr "tidak dapat mendeklarasikan parameter %q+D untuk menjadi tipe abstrak %qT"
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create type information for type %qT because it involves types of variable size"
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr "tidak dapat membuat tipe informasi untuk tipe %qT karena ini melibatkan tipe dari ukuran variabel"
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create type information for type %qT because it involves types of variable size"
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr "tidak dapat membuat tipe informasi untuk tipe %qT karena ini melibatkan tipe dari ukuran variabel"
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexception of type %qT will be caught"
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr "%H eksepsi dari tipe %qT tidak akan ditangkap"
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, gcc-internal-format
 msgid "for type %qT"
 msgstr ""
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<...%> handler must be the last handler for its try block"
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr "%H%<...%> penanganan seharusnya penanganan terakhir untuk blok cobanya"
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr ""
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
 msgstr ""
@@ -64566,12 +64554,12 @@ msgstr "tipe %qT tidak sebuah langsung atau virtual base dari %qT"
 msgid "type %qT is not a direct base of %qT"
 msgstr "tipe %qT bukan sebuah dasar langsung dari %qT"
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "array harus diinisialisasi dengan sebuah kurung melingkupi penginisialisasi"
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT bukan sebuah tipe kelas"
@@ -64586,12 +64574,12 @@ msgstr "tipe tidak lengkap %qT tidak memiliki anggota %qD"
 msgid "invalid pointer to bit-field %qD"
 msgstr "penunjuk tidak valid ke bit-field %qD"
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "penggunaan tidak valid dari anggota fungsi %qD bukan statis"
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "penggunaan tidak valid dari anggota data tidak statis %qD"
@@ -64801,55 +64789,55 @@ msgstr ""
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "tipe dari vektor delete bukan penunjuk ataupun tipe array"
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, fuzzy, gcc-internal-format
 #| msgid "compound literal has variable size"
 msgid "because the array element type %qT has variable size"
 msgstr "compound literal memiliki ukuran variabel"
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot capture %qE by reference"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, fuzzy, gcc-internal-format
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "capture by copy of incomplete type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<this%> was not captured for this lambda function"
@@ -65249,238 +65237,290 @@ msgstr "diduga deklarasi atau pernyataan"
 msgid "encapsulation is malformed"
 msgstr ""
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting global module declaration %#qD"
 msgstr "konflik deklarasi %q#D"
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration %q+D"
 msgid "existing declaration %#qD"
 msgstr "dalam deklarasi %q+D"
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, fuzzy, gcc-internal-format
 #| msgid "extern declaration of %q#D doesn't match"
 msgid "definition of %qD does not match"
 msgstr "deklarasi extern dari %q#D tidak cocok"
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, fuzzy, gcc-internal-format
 #| msgid "missing definition"
 msgid "existing definition %qD"
 msgstr "hilang definisi"
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "... this enumerator %qD"
 msgstr "redeklarasi dari enumerator %q+D"
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "enumerator %qD does not match ..."
 msgstr "argumen dari tipe %qT tidak cocok dengan %qT"
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr ""
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr ""
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr ""
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, gcc-internal-format
 msgid "recursive lazy load"
 msgstr ""
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr ""
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "module %qs declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, gcc-internal-format
 msgid "indirect import %qs is not already loaded"
 msgstr ""
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr ""
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr ""
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "macro definitions of %qE corrupted"
 msgstr "  dari definisi dari %q+#D"
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, fuzzy, gcc-internal-format
 #| msgid "inconsistent instance variable specification"
 msgid "inconsistent imported macro definition %qE"
 msgstr "spesifikasi variabel instance tidak konsisten"
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr ""
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr ""
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete module file '%s': %s"
 msgid "compiled module file is %qs"
 msgstr "tidak dapat menghapus berkas modul '%s': %s"
 
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collect2 version %s"
 msgid "compiled module is %sversion %s"
 msgstr "collect2 versi %s"
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collect2 version %s"
 msgid "compiler is %sversion %s%s%s"
 msgstr "collect2 versi %s"
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs not found"
 msgid "module %qs found"
 msgstr "field %qs tidak ditemukan"
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr ""
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr ""
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr ""
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr ""
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, gcc-internal-format
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr ""
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, gcc-internal-format
 msgid "fixed tree mismatch"
 msgstr ""
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "interface partition is not exported"
 msgstr "ekspresi batas stack tidak didukung"
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module cluster %u: %s"
 msgstr ""
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module: %s"
 msgstr ""
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr ""
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr ""
 
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr ""
 
-#: cp/module.cc:19283
+#: cp/module.cc:19117
+#, fuzzy, gcc-internal-format
+#| msgid "declaration of namespace %qD conflicts with"
+msgid "declaration %qD conflicts with builtin"
+msgstr "deklarasi dari namespace %qD konflik dengan"
+
+#: cp/module.cc:19122
+#, fuzzy, gcc-internal-format
+#| msgid "declaration of namespace %qD conflicts with"
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr "deklarasi dari namespace %qD konflik dengan"
+
+#: cp/module.cc:19125
+#, fuzzy, gcc-internal-format
+#| msgid "friend declaration %qD in local class without prior declaration"
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr "deklarasi friend %qD dalam kelas lokal tanpa deklarasi sebelumnya"
+
+#: cp/module.cc:19130
+#, gcc-internal-format
+msgid "import declared attached to module %qs"
+msgstr ""
+
+#: cp/module.cc:19134
+#, gcc-internal-format
+msgid "import declared in global module"
+msgstr ""
+
+#: cp/module.cc:19140
+#, fuzzy, gcc-internal-format
+#| msgid "conflicting declaration %q#D"
+msgid "conflicting declaration of %qD in module %qs"
+msgstr "konflik deklarasi %q#D"
+
+#: cp/module.cc:19143
+#, fuzzy, gcc-internal-format
+#| msgid "conflicting declaration %q#D"
+msgid "conflicting declaration of %qD in global module"
+msgstr "konflik deklarasi %q#D"
+
+#: cp/module.cc:19148
+#, fuzzy, gcc-internal-format
+#| msgid "previous declaration of %qs"
+msgid "previously declared in module %qs"
+msgstr "deklarasi sebelumnya dari %qs"
+
+#: cp/module.cc:19152
+#, fuzzy, gcc-internal-format
+#| msgid "previous declaration of %qs"
+msgid "previously declared in global module"
+msgstr "deklarasi sebelumnya dari %qs"
+
+#: cp/module.cc:19404
 #, fuzzy, gcc-internal-format
 #| msgid "creating %s"
 msgid "reading CMI %qs"
 msgstr "membuat %s"
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, gcc-internal-format
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, gcc-internal-format
 msgid "during load of pendings for %<%E%s%E%>"
 msgstr ""
@@ -65492,430 +65532,430 @@ msgstr ""
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr ""
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' already declared"
 msgid "module already declared"
 msgstr "Simbol '%s' telah terdeklarasi"
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, gcc-internal-format
 msgid "module already imported"
 msgstr ""
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, gcc-internal-format
 msgid "module %qs imported here"
 msgstr ""
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown Compiled Module Interface: %s"
 msgstr ""
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr ""
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr ""
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr ""
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, gcc-internal-format
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr ""
 
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, fuzzy, gcc-internal-format
 #| msgid "Enable traditional preprocessing"
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr "Aktifkan preprosesing tradisional"
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr ""
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr ""
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, gcc-internal-format
 msgid "you should use the %<-%s%> option"
 msgstr ""
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter %qs"
 msgid "invalid header name %qs"
 msgstr "parameter %qs tidak valid"
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, fuzzy, gcc-internal-format
 #| msgid "%s: invalid file name: %s\n"
 msgid "invalid module name %qs"
 msgstr "%s: nama berkas tidak valid: %s\n"
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr ""
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, fuzzy, gcc-internal-format
 #| msgid "error writing %qs"
 msgid "writing CMI %qs"
 msgstr "error menulis %qs"
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing modules file: %s"
 msgid "not writing module %qs due to errors"
 msgstr "Error menulis berkas modul: %s"
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to write compiled module: %s"
 msgstr ""
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown header kind %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared with %d template parameter(s)"
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "redeklarasikan dengan %d parameter template"
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D konflik dengan deklarasi sebelumnya menggunakan %q#D"
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D menyembunyikan konstruktor untuk %q#T"
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "konflik deklarasi %q#D"
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "karena perbedaan eksepsi spesifikasi"
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "parameter %qD secara tidak valid dideklarasikan tipe metode"
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "deklarasi dari %q#D membayangi sebuah parameter"
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "deklarasi dari %qD sebagai anggota dari %qT"
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "deklarasi friend %qD dalam kelas lokal tanpa deklarasi sebelumnya"
 
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, gcc-internal-format
 msgid "exporting %q#D that does not have external linkage"
 msgstr ""
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as reference but not initialized"
 msgid "%q#D declared here with no linkage"
 msgstr "%qD dideklarasikan sebagai referensi tetapi tidak terinisialisasi"
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD redeclared with different access"
 msgid "%q#D declared here with internal linkage"
 msgstr "%H%qD redeklarasi dengan akses berbeda"
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "%q#D declared here with module linkage"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names destructor"
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T::%D%> names desktruktor"
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "using-declaration untuk bukan-anggota di class scope"
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qT bukan sebuah class atau namespace"
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr ""
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "using-declaration untuk bukan-anggota di class scope"
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "%qT is not a direct base of %qT"
 msgstr "tipe %qT bukan sebuah dasar langsung dari %qT"
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared in %qD"
 msgstr "%qD tidak dideklarasikan dalam %qD"
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD not in a namespace surrounding %qD"
 msgid "using-declaration may not name namespace %qD"
 msgstr "deklarasi dari %qD bukan dalam sebuah lingkup namespace %qD"
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> names konstruktor dalam %qT"
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "deklarasi dari %qD bukan dalam sebuah lingkup namespace %qD"
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "eksplisit kualifikasi dalam deklarasi dari %qD"
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD seharusnya telah dideklarasikan didalam %qD"
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD tidak dideklarasikan dalam %qD"
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D dideklarasikan sebagai sebuah friend"
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD atribut membutuhkan sebuah argumen NTBS tunggal"
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD atribut tidak berarti karena anggota dari anonymous namespace memperoleh simbol lokal"
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "atribut %qD direktif diabaikan"
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %qE"
 msgstr "  %q+#D"
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr ""
 
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<this%> tidak tersedia untuk anggota fungsi static"
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr ""
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "it was later defined here"
 msgstr "%J%qD telah dideklarasikan disini"
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnamed return values are no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "%Hnilai kembali bernama tidak lagi didukung"
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<this%> may not be used in this context"
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr "%H%<this%> mungkin tidak digunakan dalam konteks ini"
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD mungkin tidak dideklarasikan dalam sebuah namespace"
 
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "'%s' di %L adalah ambigu"
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "namespace alias %qD tidak diijinkan disini, diasumsikan %qD"
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD defined here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, fuzzy, gcc-internal-format
 #| msgid "address area of %q+D conflicts with previous declaration"
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "daerah alamat dari %q+D konflik dengan deklarasi sebelumnya"
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "reachable %s definition here"
 msgstr "%J definisi sebelumnya disini"
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX memasuki pop_everything ()\n"
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -65944,7 +65984,7 @@ msgstr "pengidentifikasi %<%s%> akan menjadi sebuah kata kunci dalam C++0x"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -66233,7 +66273,7 @@ msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
@@ -66436,7 +66476,7 @@ msgstr "%Hpernyataan ekspresi tidak diijinkan diluar fungsi atau didalam daftar
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected primary-expression"
@@ -66499,7 +66539,7 @@ msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 msgid "template-id not allowed for destructor in C++20"
 msgstr ""
 
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, gcc-internal-format
 msgid "remove the %qs"
 msgstr ""
@@ -66522,7 +66562,7 @@ msgstr "%Htypedef-nama %qD digunakan sebagai desktruktor deklarator"
 msgid "expected unqualified-id"
 msgstr "diduga specifier-qualifier-list"
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD bukan sebuah template"
@@ -66580,7 +66620,7 @@ msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -66619,7 +66659,7 @@ msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr ""
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "penggunaan tidak valid dari %qD"
@@ -66647,7 +66687,7 @@ msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in %qs expressions"
@@ -66817,8 +66857,8 @@ msgstr ""
 msgid "capture of non-variable %qE"
 msgstr "peningkatan dari variabel baca-saja %qD"
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here"
@@ -66861,7 +66901,7 @@ msgstr "argumen baku diberikan untuk parameter %d dari %q#D"
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr ""
@@ -66998,7 +67038,7 @@ msgstr "lvalue dibutuhkan dalam pernyataan asm"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
@@ -67068,7 +67108,7 @@ msgstr "ekspresi pernyataan memiliki tipe tidak lengkap"
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
@@ -67098,7 +67138,7 @@ msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ melarang gotos yang sudah dihitung"
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
@@ -67414,13 +67454,13 @@ msgstr "%Hhanya konstruktor yang mengambil penginisialisasi dasar"
 msgid "cannot expand initializer for member %qD"
 msgstr "%Htidak dapat mengekspand penginisialisasi untuk anggota %<%D%>"
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "deklarasi statis dari %q+D mengikuti deklarasi bukan statis"
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -68147,7 +68187,7 @@ msgstr "hilang target makefile setelah %qs"
 msgid "%qT not permitted in template argument"
 msgstr "%Hparse error dalam daftar argumen template"
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
@@ -68357,12 +68397,12 @@ msgstr "%Hdefinisi sebelumnya dari %q+#T"
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, gcc-internal-format
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr ""
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
@@ -68592,40 +68632,40 @@ msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 msgid "expression must be enclosed in parentheses"
 msgstr "ekspresi pernyataan memiliki tipe tidak lengkap"
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr ""
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "posisi yang diminta bukan sebuah konstanta integer"
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "alignmen yang diminta bukan sebuah konstanta"
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "redeklarasi tidak valid dari %q+D"
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo few template-parameter-lists"
 msgid "too few template-parameter-lists"
@@ -68635,506 +68675,506 @@ msgstr "%Hterlalu sedikit template-parameter-list"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo many template-parameter-lists"
 msgid "too many template-parameter-lists"
 msgstr "%Hterlalu banyak template-parameter-lists"
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, gcc-internal-format
 msgid "template-id not allowed for constructor in C++20"
 msgstr ""
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnamed return values are no longer supported"
 msgid "named return values are no longer supported"
 msgstr "%Hnilai kembali bernama tidak lagi didukung"
 
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "template tidak cocok untuk %qD yang ditemukan"
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid declaration of member template in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "%Hdeklarasi tidak valid dari anggota template dalam kelas lokal"
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate with C linkage"
 msgid "template with C linkage"
 msgstr "%Htemplate dengan C linkage"
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "spesifikasi kelas dasar tidak valid"
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "template declaration of %<typedef%>"
 msgstr "template deklarasi dari %q#D"
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "redeklarasi tidak mendeklarasikan apapun"
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexplicit template specialization cannot have a storage class"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "%Heksplisit template spesialisasi tidak dapat memiliki sebuah kelas penyimpanan"
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> seharusnya %<> >%> didalam sebuah daftar argumen template nested"
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, fuzzy, gcc-internal-format
 #| msgid "%Hspurious %<>>%>, use %<>%> to terminate a template argument list"
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "%Hspurious %<>>%>, gunakan %<>%> untuk mengakhiri sebuah daftar argumen template"
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, fuzzy, gcc-internal-format
 #| msgid "%Hspurious %<>>%>, use %<>%> to terminate a template argument list"
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr "%Hspurious %<>>%>, gunakan %<>%> untuk mengakhiri sebuah daftar argumen template"
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of %qD in linkage specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "%Hpenggunaan tidak valid dari %qD dalam spesifikasi linkage"
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate %qs"
 msgid "duplicate %qD specifier"
 msgstr "%Hduplikasi %qs"
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, fuzzy, gcc-internal-format
 #| msgid "  conflict with %q+D"
 msgid "%qD specifier conflicts with %qs"
 msgstr "  konflik dengan %q+D"
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<__thread%> before %qD"
 msgid "%<__thread%> before %qD"
 msgstr "%H%<__thread%> sebelum %qD"
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, gcc-internal-format
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr ""
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 tidak mendukung %<long long%>"
 
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, fuzzy, gcc-internal-format
 #| msgid "both %<_Sat%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "baik %<_Sat%> dan %<char%> dalam penspesifikasi deklarasi"
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "duplikasi %qE"
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate %qs"
 msgid "duplicate %qs"
 msgstr "%Hduplikasi %qs"
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "diduga pernyataan"
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<auto%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<co_yield%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "diduga %<:%> atau %<...%>"
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs tag digunakan dalam penamaan %q#T"
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%q#T was previously declared here"
 msgstr "%q+T telah dideklarasikan sebelumnya disini"
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared with greater visibility than its base %qT"
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT dideklarasikan dengan visibility lebih besar dari basenya %qT"
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, fuzzy, gcc-internal-format
 #| msgid "template class without a name"
 msgid "replace the class-key with %qs"
 msgstr "template kelas tanpa sebuah nama"
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qT defined as %qs here"
 msgstr "%qT mereferensikan sebagai %qs"
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "%qT first declared as %qs here"
 msgstr "%J%qD telah dideklarasikan disini"
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD redeclared with different access"
 msgid "%qD redeclared with different access"
 msgstr "%H%qD redeklarasi dengan akses berbeda"
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%H%<template%> (sebagai sebuah disambiguator) hanya diijinkan dalam templates"
 
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfile ends in default argument"
 msgid "file ends in default argument"
 msgstr "%Hberkas berakhir dalam argumen baku"
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmisplaced %<@%D%> Objective-C++ construct"
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "%Hsalah tempat %<@%D%> Objective-C++ konstruk"
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<@encode%> must specify a type as an argument"
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%H%<@encode%> harus menspesifikasikan sebuah tipe sebagai sebuah argumen"
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid Objective-C++ selector name"
 msgid "invalid Objective-C++ selector name"
 msgstr "%Hpemilih nama Objective-C++ tidak valid"
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "objective-c++ method declaration is expected"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%J atribut daerah tidak dapat dispesifikasikan untuk variabel lokal"
 
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "invalid type for instance variable"
 msgstr "tipe tidak valid untuk iterasi variabel %qE"
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, fuzzy, gcc-internal-format
 #| msgid "%Hidentifier expected after %<@protocol%>"
 msgid "identifier expected after %<@protocol%>"
 msgstr "%Hpengidentifikasi diduga setelah %<@protocol%>"
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE atribut diabaikan untuk %qE"
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr ""
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "diduga ekspresi integer"
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in iterator type"
@@ -69144,13 +69184,13 @@ msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma vtable no longer supported"
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "#pragma vtable tidak lagi didukung"
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "inisialisasi berkurung tidak diijinkan dalam loop OpenMP %<for%>"
@@ -69160,145 +69200,145 @@ msgstr "inisialisasi berkurung tidak diijinkan dalam loop OpenMP %<for%>"
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "iterasi variabel %qD seharusnya bukan reduksi"
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp section%> hanya bisa digunakan dalam %<#pragma omp section%> konstruk"
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr ""
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "diduga ekspresi"
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD bukan sebuah anggota dari fungsi template"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, fuzzy, gcc-internal-format
 #| msgid "%Hjunk at end of %<#pragma GCC pch_preprocess%>"
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "%Hsampah diakhir dari %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp flush%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC option is not allowed inside functions"
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr "#pragma GCC option tidak diijinkan didalam fungsi"
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "multi-source compilation not implemented for C++"
 msgstr "inter-module optimisasi tidak diimplementasikan untuk C++"
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "konversi baku tidak diijinkan dalam konteks ini"
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "%Htemplate mungkin bukan %<virtual%>"
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -69329,7 +69369,7 @@ msgstr "template kelas yang melingkupi tidak secara eksplisit terspesialisasi"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "spesialisasi dari %qD dalam namespace berbeda"
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "spesialisasi dari %qD dalam namespace berbeda"
@@ -69345,28 +69385,28 @@ msgstr "  dari definisi dari %q+#D"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "eksplisit instantiation dari %qD dalam namespace %qD (yang tidak melingkupi namespace %qD)"
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "nama dari template kelas bayangan parameter template %qD"
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "specialization of alias template %qD"
 msgstr "deklarasi dari template %q#D"
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "spesialisasi eksplisit dari bukan-template %qT"
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "spesialisasi dari %qT setelah instantiation"
 
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "from definition of %q#D"
@@ -69374,157 +69414,157 @@ msgstr "  dari definisi dari %q+#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "spesialisasi %qT setelah instantiation %qT"
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "fungsi template partial spesialisasi %qD tidak diijinkan"
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "spesialisasi dari %qD setelah instansiasi"
 
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a variable template"
 msgstr "%qD bukan sebuah variabel"
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "template-id %qD untuk %q+D tidak cocok dengan deklarasi template apapun"
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "spesialisasi template ambigu %qD untuk %q+D"
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "template tidak cocok untuk %qD yang ditemukan"
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "spesisialisasi eksplisit dari %qD setelah penggunaan pertama"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "eksplisit instantiation dari %qD dalam namespace %qD (yang tidak melingkupi namespace %qD)"
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "spesisialisasi eksplisit dari %qD setelah penggunaan pertama"
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attributes %s"
 msgstr "hilang atribut Code"
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attribute %s"
 msgstr "hilang atribut Code"
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD in declaration of primary template"
 msgid "template-id %qE in declaration of primary template"
 msgstr "template-id %qD dalam deklarasi dari template utama"
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "daftar parameter template digunakan dalam instantiation eksplisit"
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "definisi disediakan untuk instantiation eksplisit"
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "terlalu banyak daftar parameter template dalam deklarasi dari %qD"
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "terlalu sedikit daftar parameter template dalam deklarasi dari %qD"
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "eksplisit spesialisasi dari %qD harus dikenalkan oleh %<template <>%>"
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "spesialisasi eksplisit dari bukan-template %qT"
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "fungsi template partial spesialisasi %qD tidak diijinkan"
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "fungsi template partial spesialisasi %qD tidak diijinkan"
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "argumen baku dispesifikasikan dalam spesialisasi eksplisit"
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD bukan sebuah fungsi template"
@@ -69537,154 +69577,154 @@ msgstr "%qD bukan sebuah fungsi template"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "spesialisasi dari anggota fungsi spesial secara implist dideklarasikan"
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "tidak ada anggota fungsi %qD dideklarasikan dalam %qT"
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "deklarasi friend %qD dalam kelas lokal tanpa deklarasi sebelumnya"
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
 msgid "friend declaration here"
 msgstr "%J membayangi deklarasi ada disini"
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "spesialisasi eksplisit dari bukan-template %qT"
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "Argumen dari ACOS di %L harus berada diantara -1 dan 1"
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, fuzzy, gcc-internal-format
 #| msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "ekspansi penginisialisasi dasar %<%T%> berisi parameter packs"
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%T%> contains no argument packs"
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "pola ekspansi %<%T%> berisi tidak ada argumen packs"
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%E%> contains no argument packs"
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "pola ekspansi %<%E%> berisi tidak ada argumen packs"
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "parameter packs tidak diekspan dengan %<...%>:"
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "          %s"
 msgid "        %s"
 msgstr "          %s"
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "tipe parameter template %qT dideklarasikan %<friend%>"
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "specialization of variable concept %q#D"
 msgstr "spesialisasi eksplisit dari bukan-template %qT"
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "parameter template tidak digunakan dalam spesialisasi partial:"
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "partial spesialisasi %qT tidak menspesialisasikan argumen template apapun"
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "terlalu banyak argumen ke fungsi %qE"
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "partial spesialisasi %qT tidak menspesialisasikan argumen template apapun"
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "primary template %qD"
 msgstr "deklarasi dari template %q#D"
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "parameter pack argumen %qE harus berada di akhir dari daftar argumen template"
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "parameter pack argumen %qT harus berada di akhir dari daftar argumen template"
 
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT of template argument %qE depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -69692,19 +69732,19 @@ msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "tipe %qT dari template argumen %qE tergantung di parameter template"
 msgstr[1] "tipe %qT dari template argumen %qE tergantung di parameter template"
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "spesialisasi dari %qD setelah instansiasi"
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "tidak ada argumen baku untuk %qD"
@@ -69713,53 +69753,53 @@ msgstr "tidak ada argumen baku untuk %qD"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, fuzzy, gcc-internal-format
 #| msgid "parameter pack %qE must be at the end of the template parameter list"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "parameter pack %qE harus berada di akhir dari daftar parameter template"
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "argumen baku tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "parameter template tidak digunakan dalam spesialisasi partial:"
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "parameter template tidak digunakan dalam spesialisasi partial:"
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "argumen baku untuk parameter dari tipe %qT memiliki tipe %qT"
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "parameter %qD dideklarasikan void"
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "template kelas tanpa sebuah nama"
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -69770,64 +69810,64 @@ msgstr "fungsi bukan-anggota %qD tidak dapat memiliki cv-kualifier"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "deklarasi template dari %qD tidak valid"
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "definisi template dari bukan template %q#D"
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "diduga %d tingkat dari parm template untuk %q#D, diperoleh %d"
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "diperoleh %d parameter template untuk %q#D"
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "diperoleh %d parameter template untuk %q#T"
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  tetapi %d dibutuhkan"
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "template argumen ke %qD tidak cocok dengan template asli %qD"
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, fuzzy, gcc-internal-format
 #| msgid "use template<> for an explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "gunakan template<> untuk spesialisasi eksplisit"
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "redeclaration of %qD with different constraints"
 msgstr "deklarasi dari %qF throws exceptions berbeda"
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT bukan sebuah tipe template"
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "penspesifikasi template tidak dispesifikasikan dalam deklarasi dari %qD"
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "redeclared with %d template parameter(s)"
 msgid "redeclared with %d template parameter"
@@ -69835,7 +69875,7 @@ msgid_plural "redeclared with %d template parameters"
 msgstr[0] "redeklarasikan dengan %d parameter template"
 msgstr[1] "redeklarasikan dengan %d parameter template"
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D used %d template parameter(s)"
 msgid "previous declaration %qD used %d template parameter"
@@ -69843,490 +69883,490 @@ msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "deklarasi sebelumnya %q+D digunakan %d parameter template"
 msgstr[1] "deklarasi sebelumnya %q+D digunakan %d parameter template"
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "parameter template %q+#D"
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "redeklarasikan disini sebagai %q#D"
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "redeclared here"
 msgstr "redeklarasikan disini sebagai %q#D"
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "deklarasi dari %qF throws exceptions berbeda"
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, fuzzy, gcc-internal-format
 #| msgid "%Joriginal definition appeared here"
 msgid "original declaration appeared here"
 msgstr "%J definisi asli muncul disini"
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "redeclaration of %q#D with different constraints"
 msgstr "deklarasi dari %qF throws exceptions berbeda"
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "ini harus berupa alamat dari sebuah fungsi dengan hubungan eksternal"
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "ini harus berupa alamat dari sebuah fungsi dengan hubungan eksternal"
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena objek %qD bukan eksternal linkage"
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(sebuah penunjuk ke anggota hanya dapat dibentuk dengan %<&%E%>)"
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qT bukan sebuah anggota dari %qT"
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "diperoleh %d parameter template untuk %q#D"
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "  mismatched types %qT and %qT"
 msgstr "perbandingan diantara tipe %qT dan %qT"
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter pack %qD cannot have a default argument"
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "%Htemplate parameter pack %qD tidak dapat memiliki sebuah argumen baku"
 
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, fuzzy, gcc-internal-format
 #| msgid "template arguments to %qD do not match original template %qD"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "template argumen ke %qD tidak cocok dengan template asli %qD"
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs tidak valid untuk %qs"
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "partial spesialisasi %qT tidak menspesialisasikan argumen template apapun"
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "tidak dapat mengubah tipe %qT ke tipe %qT"
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT adalah sebuah dasar ambigu dari %qT"
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "  %qT is not derived from %qT"
 msgstr "tipe %qT tidak diturunkan dari tipe %qT"
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decrement a pointer to incomplete type %qT"
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "tidak dapat mengurangi penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "argumen dari tipe %qT tidak cocok dengan %qT"
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qE bukan sebuah variabel"
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qE bukan sebuah variabel"
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT"
 msgid "the address of %qD is not a valid template argument"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD bukan sebuah template argumen yang valid karena %qD bukan sebuah variabel, bukan alamat dari sebuah variabel"
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD bukan sebuah template argumen yang valid karena %qD bukan sebuah variabel, bukan alamat dari sebuah variabel"
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena string literal tidak dapat digunakan dalam konteks ini"
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT"
 msgid "in template argument for type %qT"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE bukan sebuah template argumen yang valid untuk tipe %qT karena konflik dalam cv kualifikasi"
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini bukan sebuah lvalue"
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a non-constant expression"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE bukan sebuah template argumen yang valid untuk tipe %qT karena ini bukan sebuah ekspresi konstan"
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini adalah sebuah penunjuk"
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "lebih baik coba gunakan %qE"
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini dari tipe %qT"
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, fuzzy, gcc-internal-format
 #| msgid "Conflict in attributes of function argument at %C"
 msgid "ignoring attributes on template argument %qT"
 msgstr "Konflik dalam atribut dari argumen fungsi di %C"
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring attributes in template argument %qE"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, fuzzy, gcc-internal-format
 #| msgid "name of class shadows template template parameter %qD"
 msgid "injected-class-name %qD used as template template argument"
 msgstr "nama dari template kelas bayangan parameter template %qD"
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of destructor %qD as a type"
 msgid "invalid use of destructor %qE as a type"
 msgstr "%Hpenggunaan tidak valid dari desktruktor %qD memiliki sebuah tipe"
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "merefer ke sebuah anggota tipe dari sebuah parameter template, gunakan %<typename %E%>"
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "tipe/nilai tidak cocok di argumen %d dalam daftar parameter template untuk %qD"
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  diduga sebuah konstanta dari tipe %qT, diperoleh %qT"
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  diduga sebuah template kelas, diperoleh %qE"
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  diduga sebuah tipe, diperoleh %qE"
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  diduga sebuah tipe, diperoleh %qT"
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  diduga sebuah template kelas, diperoleh %qT"
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  diduga sebuah template dari tipe %qD, diperoleh %qD"
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "tipe/nilai tidak cocok di argumen %d dalam daftar parameter template untuk %qD"
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  diduga sebuah tipe, diperoleh %qE"
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "tidak dapat mengubah argumen template %qE ke %qT"
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "template argumen %d tidak valid"
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "jumlah dari argumen template salah (%d, seharusnya %d)"
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "jumlah dari argumen template salah (%d, seharusnya %d)"
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "disediakan untuk %q+D"
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argumen baku diberikan untuk parameter %d dari %q#D"
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "tipe bukan template %qT digunakan sebuah sebuah template"
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "untuk deklarasi template %q+D"
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "template constraint failure for %qD"
 msgstr "template deklarasi dari %q#D"
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "penggunaan dari %qs dalam template"
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "kedalaman template instantiation melebihi maksimal dari %d (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal) instantiating %qD"
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "score argument must be constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, fuzzy, gcc-internal-format
 #| msgid "last argument must be an immediate"
 msgid "score argument must be non-negative"
 msgstr "argumen terakhir harus berupa sebuah immediate"
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "property must be constant integer expression or string literal"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "%J anggota array fleksibel dalam union"
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE tidak berada di awal dari deklarasi"
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "panjang argumen pack tidak cocok akan diekspan %<%T%>"
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "panjang argumen pack tidak cocok ketika mengekspan %<%E%>"
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "redefinisi dari argumen baku untuk %q#D"
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "membuat penunjuk ke anggota fungsi dari tipe bukan kelas %qT"
 
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths (%d vs %d)"
@@ -70345,319 +70385,319 @@ msgstr "panjang argumen pack tidak cocok akan diekspan %<%T%>"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabel %qD memiliki tipe fungsi"
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "tipe parameter %qT tidak valid"
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "dalam deklarasi %q+D"
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "fungsi mengembalikan sebuah array"
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "fungsi mengembalikan sebuah fungsi"
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "membentuk referensi ke void"
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "membentuk %s ke tipe referensi %qT"
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "membentuk %s ke tipe referensi %qT"
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "membuat penunjuk ke anggota referensi tipe %qT"
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "membuat penunjuk ke anggota dari tipe void"
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "membuat array dari %qT"
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT bukan sebuah tipe class, struct, atau union"
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe enumerasi"
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe class"
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "penggunaan dari %qs dalam template"
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "tipe kualifikasi %qT tidak cocok dengan nama destruktor ~%qT"
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "dependent-name %qE diparse sebagai sebuah bukan-tipe, tetapi instantiation menghasilkan sebuah tipe"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "katakan %<typename %E%> jika sebuah tipe adalah berarti"
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in comparison expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "operan tidak valid dalam ekspresi perbandingan"
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "penggunaan tidak valid dari ekspresi ekspansi pack"
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "gunakan %<...%> untuk mengekspan argumen pack"
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%H%qE tidak dideklarasikan disini (bukan dalam sebuah fungsi)"
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "jumlah dari argumen salah dispesifikasikan untuk atribut %qs"
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT bukan sebuah class atau namespace"
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD bukan sebuah class atau namespace"
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "menggunakan field tidak valid %qD"
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT adalah/menggunakan tipe anonymous"
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "argumen template untuk %qD menggunakan tipe lokal %qT"
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT adalah sebuah tipe variabel termodifikasi"
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  mencoba untuk instantiate %qD"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD bukan sebuah anggota data statis dari sebuah template class"
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "template tidak cocok untuk %qD yang ditemukan"
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "tipe %qT untuk instantiation eksplisit %qD tidak cocok dengan tipe yang dideklarasikan %qT"
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "eksplisit instantiation dari %q#D"
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "duplikasi eksplisit instantiation dari %q#D"
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 melarang penggunaan dari %<extern%> di instantiation eksplisit"
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "class penyimpanan %qD diaplikasikan ke template instantiation"
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "eksplisit instantiation dari %q#T sebelum definisi dari template"
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ melarang penggunaan dari %qE di instantiasi eksplisit"
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "duplikasi instansiasi eksplisit dari %q#T"
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -70670,183 +70710,183 @@ msgstr "spesisialisasi eksplisit dari %qD setelah penggunaan pertama"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eksplisit instansiasi dari %qD tetapi tidak ada definisi yang tersedia"
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "kedalaman template instansiasi melebihi maksimal dari %d instantiating %q+D, kemungkinan dari pembuatan tabel virtual (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal)"
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T bukan sebuah tipe valid untuk sebuah parameter template konstan"
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter %qT after %qs"
 msgid "invalid template non-type parameter"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T bukan sebuah tipe valid untuk sebuah parameter template konstan"
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan diluar dari templates"
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, fuzzy, gcc-internal-format
 #| msgid "opaque vector types cannot be initialized"
 msgid "a concept cannot be constrained"
 msgstr "tipe vektor opaque tidak dapat diinisialisasi"
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT bukan sebuah namespace"
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#T inside template parameter list"
 msgid "concept %qE has multiple template parameter lists"
 msgstr "definisi dari %q#T didalam daftar parameter template"
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, fuzzy, gcc-internal-format
 #| msgid "deducing auto from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "deduksi auto dari daftar penginisialisasi dikurung membutuhkan #include <daftar_penginisialisasi>"
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "%qD digunakan tanpa parameter template"
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "use %qD directly instead"
 msgstr "lebih baik gunakan #include"
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "template argumen %d tidak valid"
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "fungsi tidak dipertimbangkan untuk inlining"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, fuzzy, gcc-internal-format
 #| msgid "explicit qualification in declaration of %qD"
 msgid "explicit deduction guide declared here"
 msgstr "eksplisit kualifikasi dalam deklarasi dari %qD"
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, fuzzy, gcc-internal-format
 #| msgid "unable to deduce %qT from %qE"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "tidak dapat mendeduksi %qT dari %qE"
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "tidak dapat mendeduksi %qT dari %qE"
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "invalid use of %qT in template argument"
@@ -71072,692 +71112,692 @@ msgstr "tipe dari operan asm %qE tidak dapat ditentukan"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "deklarasi __label__ hanya diperbolehkan dalam lingkup fungsi"
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "penggunaan tidak valid dari anggota %q+D dalam anggota fungsi statis"
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr "penggunaan tidak valid dari anggota %q+D dalam anggota fungsi statis"
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr "penggunaan tidak valid dari anggota %q+D dalam anggota fungsi statis"
 
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "%qE missing template arguments"
 msgstr "argumen tidak cocok"
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "cannot call a concept as a function"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "argumen ke destruktor tidak diijinkan"
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr "%<this%> tidak tersedia untuk anggota fungsi static"
 
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, gcc-internal-format
 msgid "use explicit object parameter %qs instead"
 msgstr ""
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, gcc-internal-format
 msgid "name the explicit object parameter"
 msgstr ""
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> tidak tersedia untuk anggota fungsi static"
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<this%> before it is valid"
 msgstr "penggunaan tidak valid ari %<this%> di tingkat paling atas"
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<this%> after it is valid"
 msgstr "penggunaan tidak valid ari %<this%> di tingkat paling atas"
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "penggunaan tidak valid dari %<this%> dalam fungsi bukan anggota"
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "penggunaan tidak valid ari %<this%> di tingkat paling atas"
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "tidak valid pengkualifikasi lingkup dalam nama pseudo-destruktor"
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "tipe kualifikasi %qT tidak cocok dengan nama destruktor ~%qT"
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE bukan dari tipe %qT"
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "compound literal dari tipe bukan-objek %qT"
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, gcc-internal-format
 msgid "%<auto{x}%> cannot be constrained"
 msgstr ""
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "tipe parameter template harus menggunakan kata kunci %<class%> atau %<typename%>"
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "penggunaan tidak valid dari tipe %qT sebagai nilai baku untuk sebuah parameter template"
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "argumen baku tidak valid untuk sebuah parameter template template"
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "definisi dari %q#T didalam daftar parameter template"
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "definisi tidak valid dari tipe pengkualifikasi %qT"
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "spesifikasi kelas dasar tidak valid"
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "anggota terproteksi %q+#D dalam union anonymous"
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not captured"
 msgstr "%qD bukan sebuah tipe"
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "penggunaan dari variabel %<auto%> dari fungsi yang berisi"
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of parameter from containing function"
 msgstr "penggunaan dari variabel %<auto%> dari fungsi yang berisi"
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, fuzzy, gcc-internal-format
 #| msgid "alloc_size parameter outside range"
 msgid "use of parameter outside function body"
 msgstr "alloc_size parameter diluar dari jangkauan"
 
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing template arguments"
 msgstr "argumen tidak cocok"
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "parameter template %qD dari tipe %qT tidak diijinkan dalam sebuah ekspresi konstanta integral karena ini bukan tipe integral atau enumerasi"
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "penggunaan dari template class %qT sebagai ekspresi"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "permintaan untuk anggota %qD adalah ambigu dalam multiple inheritance lattice"
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "tipe dari %qE tidak dikenal"
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
 msgstr "%qT bukan sebuah tipe template"
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray bound is not an integer constant"
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr "%Harray bound bukan sebuah konstanta integer"
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr ""
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is out of range"
 msgstr ""
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "penspesifikasi kelas penyimpanan dalam parameter deklarasi"
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke destruktor %<~%T%>"
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke anggota fungsi %qD"
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke anggota fungsi %qD"
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke anggota fungsi %qD"
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, fuzzy, gcc-internal-format
 #| msgid "constructor priorities are not supported"
 msgid "pointer-to-member mapping %qE not supported"
 msgstr "prioritas konstruktor tidak didukung"
 
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE memiliki tipe tidak valid untuk %<reduction%>"
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, gcc-internal-format
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr ""
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD bukan sebuah variabel dalam clause %<firstprivate%>"
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD bukan sebuah variabel dalam clause %<lastprivate%>"
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> static expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> num expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<vector%> length expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<worker%> num expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "schedule chunk ukuran ekspresi harus integral"
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<device%> id must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "schedule chunk ukuran ekspresi harus integral"
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "schedule chunk ukuran ekspresi harus integral"
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr ""
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr ""
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, fuzzy, gcc-internal-format
 #| msgid "reimplementation of class %qs"
 msgid "template %qE in clause %qs"
 msgstr "reimplementasi dari class %qs"
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<hint%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<filter%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, fuzzy, gcc-internal-format
 #| msgid "subscripted value is neither array nor pointer"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "nilai subscripted adalah bukan array ataupun penunjuk"
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> tidak didefinisikan sebagai sebuah tipe pointer"
 
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD bukan berkas, namespace atau blok scope variabel"
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE direktif tidak dalam definisi %qT"
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdifference between %qE and %qD does not have integer type"
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "%Hperbedaan antara %qE dan %qD tidak memiliki tipe integer"
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%Htipe tidak valid untuk iterasi variabel %qE"
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr ""
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr ""
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr ""
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr ""
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed: %.*s"
 msgstr "static assertion gagal: %E"
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "kondisi bukan konstan untuk assertion static"
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "argumen ke decltype harus berupa sebuah ekspresi"
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr ""
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr ""
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr "%<__builtin_next_arg%> dipanggil tanpa sebuah argumen"
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a class or namespace"
 msgid "%qD is not a class or alias template"
 msgstr "%qD bukan sebuah class atau namespace"
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "template argumen %qE melibatkan parameter template"
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -71766,1293 +71806,1293 @@ msgstr "argumen ke %<__builtin_return_address%> tidak didukung"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV kualifier tidak dapat diaplikasikan ke %qT"
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement-expression in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid " declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, fuzzy, gcc-internal-format
 #| msgid "base class %qT has cv qualifiers"
 msgid "base class %qT is not public"
 msgstr "kelas dasar %qT memiliki cv pengkualifikasi"
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not public"
 msgstr "%qD bukan sebuah tipe"
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is mutable"
 msgstr "%qD bukan sebuah variabel"
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has an incomplete type"
 msgid "%qD has a non-structural type"
 msgstr "%qD memiliki tipe tidak lengkap"
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class"
 
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "argumen atribut %qs bukan sebuah konstanta string"
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class"
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class"
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class"
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute takes no arguments"
 msgstr "atribut %J%qE berlaku hanya untuk fungsi"
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr ""
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "permintaan init_priority bukan sebuah konstanta integer"
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "hanya dapat menggunakan atribut %qE di definisi lingkup-berkas dari objek dari tipe class"
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is out of range"
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "permintaan init_priority diluar dari jangkauan"
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is reserved for internal use"
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "permintaan init_priority disimpan untuk penggunaan internal"
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "deklarasi dari %qD sebagai %s"
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "the %qE attribute requires arguments"
 msgstr "%qD atribut membutuhkan sebuah argumen NTBS tunggal"
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> bukan sebuah deklarator yang valid"
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> bukan sebuah deklarator yang valid"
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE atribut diabaikan dalam tipe bukan-class"
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "atribut %J%qE berlaku hanya untuk fungsi"
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute applied to %s %s at %L"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%s atribut diaplikasikan ke %s %s di %L"
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, gcc-internal-format
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr ""
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "zero as null pointer constant"
 msgstr "array bound bukan sebuah konstanta integer"
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, fuzzy, gcc-internal-format
 #| msgid "lang_* check: failed in %s, at %s:%d"
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "pemeriksaan lang_*: gagal dalam %s, di %s:%d"
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "%s diantara tipe penunjuk berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "%s diantara tipe penunjuk berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "%s diantara tipe penunjuk berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type %<void *%> and pointer-to-function"
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ melarang %s diantara penunjuk dari tipe %<void *%> dan penunjuk-ke-fungsi"
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type %<void *%> and pointer-to-function"
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ melarang %s diantara penunjuk dari tipe %<void *%> dan penunjuk-ke-fungsi"
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type %<void *%> and pointer-to-function"
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ melarang %s diantara penunjuk dari tipe %<void *%> dan penunjuk-ke-fungsi"
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "%s diantara penunjuk-ke-anggota tipe berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "%s diantara penunjuk-ke-anggota tipe berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "%s diantara penunjuk-ke-anggota tipe berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, fuzzy, gcc-internal-format
 #| msgid "canonical types differ for identical types %T and %T"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "tipe kanonikal berbeda untuk tipe identik %T dan %T"
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, fuzzy, gcc-internal-format
 #| msgid "same canonical type node for different types %T and %T"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "tipe titik kanonikal sama untuk tipe berbeda %T dan %T"
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "aplikasi tidak valid dari %qs ke anggota fungsi"
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "aplikasi tidak valid dari %<sizeof%> ke sebuah bit-field"
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ melarang mengaplikasikan %<sizeof%> ke sebuah ekspresi dari tipe fungsi"
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "aplikasi tidak valid dari %<__alignof%> ke sebuah bit-field"
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ melarang mengaplikasikan %<__alignof%> ke sebuah ekspresi dari tipe fungsi"
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "ukuran dari array memiliki tipe %qT bukan integral"
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "penggunaan tidak valid dari anggota fungsi %qD bukan statis"
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to %qT"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "konversi sudah ditinggalkan dari konstanta string ke %qT"
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "konversi sudah ditinggalkan dari konstanta string ke %qT"
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, fuzzy, gcc-internal-format
 #| msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "permintaan untuk anggota %qD dalam %qE, yangg tipe bukan class %qT"
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "permintaan untuk anggota %qD dalam %qE, yangg tipe bukan class %qT"
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of nonstatic data member %qE"
 msgid "invalid use of non-static data member %qE"
 msgstr "penggunaan tidak valid dari anggota data tidak statis %qE"
 
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD  of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "akses tidak valid ke anggota data tidak statis %qD dari objek KOSONG"
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "tipe objek %qT tidak cocok dengan nama destruktor ~%qT"
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "tipe yang sedang dihancurkan adalah %qT, tetapi destruktor merefer ke %qT"
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT tidak memiliki anggota bernama %qE"
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT tidak memiliki anggota bernama %qE"
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> bukan sebuah anggota dari %qT"
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT bukan sebuah basis dari %qT"
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD bukan sebuah anggota dari fungsi template"
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT bukan sebuah penunjuk-ke-objek tipe"
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of array indexing on pointer to member"
 msgstr "penggunaan tidak valid dari %qs di penunjuk ke anggota"
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "penggunaan tidak valid dari %qs di penunjuk ke anggota"
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "penggunaan tidak valid dari %qs di penunjuk ke anggota"
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "subscrip hilang dalam referensi array"
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "subscripting array dideklarasikan %<register%>"
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "nilai subscripted adalah bukan array ataupun penunjuk"
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "objek hilang dalam penggunaan dari %qE"
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ melarang pemanggilan %<::main%> dari dalam aplikasi"
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "harus menggunakan %<.*%> atau %<->*%> untuk memanggil penunjuk-ke-anggota fungsi dalam %<%E (...)%>, contoh %<(... ->* %E) (...)%>"
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "%qE tidak dapat digunakan sebagai sebuah fungsi"
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to constructor %q#D"
 msgstr "terlalu banyak argumen ke %s %q+#D"
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to constructor %q#D"
 msgstr "terlalu sedikit argumen ke %s %q+#D"
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to member function %q#D"
 msgstr "terlalu banyak argumen ke fungsi %qE"
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to member function %q#D"
 msgstr "terlalu sediki argumen ke fungsi %qE"
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments to function %q#D"
 msgstr "terlalu banyak argumen ke fungsi %qE"
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "too few arguments to function %q#D"
 msgstr "terlalu sediki argumen ke fungsi %qE"
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to method %q#D"
 msgstr "terlalu banyak argumen ke %s %q+#D"
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to method %q#D"
 msgstr "terlalu sedikit argumen ke %s %q+#D"
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "terlalu banyak argumen ke fungsi"
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "terlalu sedikit argumen ke fungsi"
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameter %P dari %qD memiliki tipe tidak lengkap %qT"
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parameter %P memiliki tipe tidak lengkap %qT"
 
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will never be NULL"
 msgid "the address %qE will never be NULL"
 msgstr "alamat dari %qD tidak akan pernah menjadi KOSONG"
 
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "alamat dari %qD tidak akan pernah menjadi KOSONG"
 
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr "alamat dari %qD tidak akan pernah menjadi KOSONG"
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr ""
 
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "alamat dari %qD tidak akan pernah menjadi KOSONG"
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr "operan ke ?: memiliki tipe berbeda %qT dan %qT"
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types when returning type %qT but %qT was expected"
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "tipe tidak kompatibel ketika mengembalikan tipe %qT tetapi %qT telah diduga"
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, fuzzy, gcc-internal-format
 #| msgid "same canonical type node for different types %T and %T"
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr "tipe titik kanonikal sama untuk tipe berbeda %T dan %T"
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "%s diantara tipe penunjuk berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, fuzzy, gcc-internal-format
 #| msgid "cast from function call of type %qT to non-matching type %qT"
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr "cast dari panggilan fungsi dari tipe %qT ke tipe yang tidak cocok %qT"
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, fuzzy, gcc-internal-format
 #| msgid "cast from function call of type %qT to non-matching type %qT"
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr "cast dari panggilan fungsi dari tipe %qT ke tipe yang tidak cocok %qT"
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types when assigning to type %qT from type %qT"
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr "tipe tidak kompatibel dalam penempatan ke tipe %qT dari tipe %qT"
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "mengasumsikan cast ke tipe %qT dari fungsi overloaded"
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL digunakan dalam aritmetik"
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ melarang perbandingan diantara penunjuk dan integer"
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "operand types are %qT and %qT"
 msgstr "perbandingan diantara tipe %qT dan %qT"
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "perbandingan terurut dari penunjuk dengan integer nol"
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "perbandingan tidak berurut di argumen bukan titik pecahan"
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "operang tidak valid untuk tipe %qT dan %qT ke binari %qO"
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ melarang menggunakan penunjuk dari tipe %<void *%> dalam pengurangan"
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ melarang menggunakan penunjuk ke sebuah fungsi  dalam pengurangan"
 
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ melarang menggunakan penunjuk ke sebuah metoda  dalam pengurangan"
 
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "penggunaan tidak valid dari sebuah penunjuk ke sebuah tipe tidak lengkap dalam aritmetik penunjuk"
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of constructor %qD"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of destructor %qD"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "penggunaan tidak valid dari %qE untuk membentuk sebuah penunjuk ke anggota fungsi"
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  sebuah kualified-id dibutuhkan"
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "tanda kurung disekitar %qE tidak dapat digunakan untuk membentuk sebuah penunjuk-ke-anggota-fungsi"
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ melarang mengambil alamat dari tidak terkualifikasi atau bertanda kurun anggota bukan statis fungsi untuk membentuk sebuah penunjuk ke anggota fungsi. Katakan %<&%T::%D%>"
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr "ISO C++ melarang mengambil alamat dari tidak terkualifikasi atau bertanda kurun anggota bukan statis fungsi untuk membentuk sebuah penunjuk ke anggota fungsi. Katakan %<&%T::%D%>"
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ melarang mengambil alamat dari sebuah anggota fungsi terikat ke sebuah bentuk penunjuk ke anggota fungsi. Katakan %<&%T::%D%>"
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr "ISO C++ melarang mengambil alamat dari sebuah anggota fungsi terikat ke sebuah bentuk penunjuk ke anggota fungsi. Katakan %<&%T::%D%>"
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr "(sebuah penunjuk ke anggota hanya dapat dibentuk dengan %<&%E%>)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "memakai alamat dari sementara"
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ melarang mengambil alamat dari fungsi %<::main%>"
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "tidak dapat membuat penunjuk ke anggota referensi %qD"
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "tidak dapat mengambil alamat dari bit-field %qD"
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ melarang menaikkan sebuah enum"
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ melarang mengurangi sebuah enum"
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "tidak dapat mengurangi penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ melarang meningkatkan sebuah penunjuk dari tipe %qT"
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ melarang mengurangi sebuah penunjuk dari tipe %qT"
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "tidak dapat mengambil alamat dari %<this%>, yang merupakan ekspresi rvalue"
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "alamat dari variabel eksplisit register %qD diminta"
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "alamat yang diminta untuk %qD, yang dideklarasikan %<register%>"
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "penginisialisasi untuk %qT harus berupa kurung dilingkupi"
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in initializer"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in functional cast"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, fuzzy, gcc-internal-format
 #| msgid "cast from type %qT to type %qT casts away constness"
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, fuzzy, gcc-internal-format
 #| msgid "static_cast from type %qT to type %qT casts away constness"
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away constness"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "useless cast to type %q#T"
 msgstr "cast ke fungsi tipe %qT tidak valid"
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "tipe pengkualifikasi diabaikan di tipe kembali fungsi"
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "tidak valid static_cast dari tipe %qT ke tipe %qT"
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "tipe kembali %q#T tidak lengkap"
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "mengubah dari %qT ke %qT"
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "cast tidak valid dari sebuah ekspresi rvalue dari tipe %qT ke tipe %qT"
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "cast dari %qT ke %qT kehilangan presisi"
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 #, fuzzy
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "%s diantara penunjuk-ke-anggota tipe berbeda %qT dan %qT kurang sebuah cast"
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "cast dari %qT ke %qT menaikan alignmen yang dibutuhkan dari tipe target"
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ melarang casting diantara penunjuk ke fungsi dan penunjuk ke objek"
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "cast dari tipe %qT ke tipe %qT tidak valid"
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "penggunaan tidak valid dari const_cast dengan tipe %qT, yang bukan sebuah penunjuk, referensi, ataupun sebuah tipe penunjuk-ke-anggota-data"
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "penggunaan tidak valid dari const_cast dengan tipe %qT, yang merupakan sebuah penunjuk atau referensi ke sebuah tipe fungsi"
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "const_cast tidak valid dari sebuah rvalue dari tipe %qT ke tipe %qT"
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "const_cast dari tipe %qT ke tipe %qT tidak valid"
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ melarang casting ke sebuah tipe array %qT"
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "cast ke fungsi tipe %qT tidak valid"
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qE from type %qT to type %qT"
 msgid "moving %qE of type %qT to itself"
 msgstr "tidak dapat mengubah %qE dari tipe %qT ke tipe %qT"
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  dalam evaluasi dari %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "indeks array bukan konstan dalam penginisialisasi"
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "tipe tidak kompatibel dalam assignmen dari %qT ke %qT"
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "array digunakan sebagai penginisialisasi"
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "assignmen array tidak valid"
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   dalam penunjuk ke anggota fungsi konversi"
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "penunjuk ke anggota konversi melalui basis maya %qT"
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   dalam penunjuk ke anggota konversi"
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "konversi tidak valid ke tipe %qT dari tipe %qT"
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 #, fuzzy
 #| msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "tidak dapat mengubah %qT ke %qT untuk argumen %qP ke %qD"
 
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in return"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "argumen %d dari %qE mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, fuzzy, gcc-internal-format
 #| msgid "return type might be a candidate for a format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "tipe kembali mungkin berupa sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "argumen dari fungsi panggilan mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "argumen dari fungsi panggilan mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, fuzzy, gcc-internal-format
 #| msgid "assignment left-hand side might be a candidate for a format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "penempatan sisi tangan-kiri mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "dalam melewatkan argumen %P dari %q+D"
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "mengembalikan referensi ke sementara"
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "returning pointer to temporary"
 msgstr "mengembalikan referensi ke sementara"
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "referensi ke variabel lokal %q+D dikembalikan"
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "alamat dari variabel lokal %q+D dikembalikan"
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "alamat dari variabel lokal %q+D dikembalikan"
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in return statement"
 msgid "redundant move in return statement"
 msgstr "operan tidak valid dalam pernyataan return"
 
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, fuzzy, gcc-internal-format
 #| msgid "<During initialization>\n"
 msgid "redundant move in initialization"
 msgstr "<Selama inisialisasi>\n"
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "mengembalikan sebuah nilai dari sebuah destruktor"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "tidam dapat kembali dari sebuah penanganan dari sebuah fungsi-coba-blok dari sebuah konstruktor"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "mengembalikan sebuah nilai dari sebuah konstruktor"
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "pernyataan-kembali dengan tidak ada nilai, dalam fungsi mengembalikan %qT"
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "hilang penginisialisasi"
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "pernyataan-kembali dengan tidak ada nilai, dalam fungsi mengembalikan %qT"
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> harus tidak mengembalikan KOSONG kecuali ini dideklarasikan %<throw()%> (atau ada dalam pengaruh -fcheck-new )"
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, gcc-internal-format
 msgid "not eliding copy on return from %qD"
 msgstr ""
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr ""
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -73303,169 +73343,169 @@ msgstr ""
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "sintaks konstruktor digunakan, tetapi tidak ada konstruktor dideklarasikan untuk tipe %qT"
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, fuzzy, gcc-internal-format
 #| msgid "interface %qs does not have valid constant string layout"
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "antar-muka %qs tidak memiliki layout konstanta string yang valid"
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 #, fuzzy
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "menyempitkan konversi %qE dari %qT ke %qT didalam { }"
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 #, fuzzy
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "menyempitkan konversi %qE dari %qT ke %qT didalam { }"
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, fuzzy, gcc-internal-format
 #| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "inisialisasi-string untuk array dari karakter terlalu panjang"
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "kurung disekitar penginisialisasi skalar"
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "tidak dapat menginisialisasi kumpulan dari tipe %qT dengan sebuah kompound literal"
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "anggota %qD referensi tidak terinisialisasi"
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "anggota %qD referensi tidak terinisialisasi"
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q#D does not match any in class %qT"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "prototipe untuk %q#D tidak cocok dengan kelas apapun %qT"
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "tidak ada field %qD ditemukan dalam union sedang diinisialisasi"
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "nilai indeks daripada nama field dalam union penginisialisasi"
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "penunjuk circular delegasi terdeteksi"
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "operan dasar dari %<->%> memiliki tipe bukan penunjuk %qT"
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "hasil dari %<operator->()%> menghasilkan hasil bukan penunjuk"
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "operan dasar dari %<->%> bukan sebuah penunjuk"
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE tidak dapat digunakan sebagai sebuah anggota penunjuk, karena ini adalah tipe %qT"
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "tidak dapat mengaplikasikan anggota penunjuk %qE ke %qE, yang dari tipe bukan class %qT"
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "penunjuk ke anggota tipe %qT tidak kompatibel dengan tipe objek %qT"
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "penunjuk ke anggota fungsi digunakan dalam aritmetik"
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "penunjuk ke anggota fungsi digunakan dalam aritmetik"
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "cast ke fungsi tipe %qT tidak valid"
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr ""
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, fuzzy, gcc-internal-format
 #| msgid "invalid value-initialization of reference types"
 msgid "invalid value-initialization of reference type"
 msgstr "nilai-inisialisasi dari referensi tidak valid"
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "panggilan ke fungsi %qD yang melemparkan tipe tidak lengkap %q#T"
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "panggilan ke fungsi yang melemparkan tipe tidak lengkap %q#T"
@@ -74534,7 +74574,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad kind for logical constant at %C"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -76026,7 +76066,7 @@ msgstr "Spesifikasi INTENT buruk di %C"
 msgid "deferred type parameter at %C"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -76272,7 +76312,7 @@ msgstr ""
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Komponen array dari struktur di %C harus memiliki bentuk eksplisit atau deffered"
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already declared at %L"
@@ -77151,7 +77191,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr "Diduga daftar argumen formal dalam definisi fungsi di %C"
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "atribut BIND(C) di %L hanya dapat digunakan untuk variabel atau blok umum"
@@ -78033,12 +78073,12 @@ msgstr ""
 msgid "are_identical_variables: Bad type"
 msgstr ""
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr "INTENT(%s) argumen aktual di %L mungkin menginterferensi dengan argumen aktual di %L."
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr ""
@@ -78308,302 +78348,302 @@ msgstr "Parameter '%s' di %L belum terdeklarasi atau sebuah variabel, yang tidak
 msgid "check_init_expr(): Unknown expression type"
 msgstr "Diduga tipe ekspresi"
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be a statement function"
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr "Fungsi spesifikasi '%s' di %L tidak dapat berupa sebuah pernyataan fungsi"
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be an internal function"
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr "Spesifikasi fungsi '%s' di %L tidak dapat berupa sebuah internal fungsi"
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L must be PURE"
 msgid "Specification function %qs at %L must be PURE"
 msgstr "Spesifikasi fungsi '%s' di %L harus berupa PURE"
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be RECURSIVE"
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr "Spesifikasi fungsi '%s' di %L tidak dapat REKURSIF"
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' not allowed in expression at %L"
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr "Dummy argumen '%s' tidak diijinkan dalam ekspresi di %L"
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be OPTIONAL"
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa OPSIONAL"
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr "Variabel '%s' tidak dapat muncul dalam ekspresi di %L"
 
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "check_restricted(): Unknown expression type"
 msgstr "Diduga tipe ekspresi"
 
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr "Ekspresi di %L harus berupa tipe INTEGER, ditemukan %s"
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L must be PURE"
 msgid "Function %qs at %L must be PURE"
 msgstr "Fungsi '%s' di %L harus berupa PURE"
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr "Ekspresi di %L harus berupa skalar"
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr ""
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr "Tingkat tidak kompatibel dalam %s (%d dan %d) di %L"
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "Bentuk berbeda untuk %s di %L dalam dimensi %d (%d dan %d)"
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a VALUE"
 msgid "%qs at %L is not a VALUE"
 msgstr "'%s' di %L bukan sebuah NILAI"
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal stride of zero at %L"
 msgid "Illegal assignment to external procedure at %L"
 msgstr "Tidak legal stride dari nol di %L"
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "Tingkat tidak kompatibel %d dan %d dalam penempatan di %L"
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "Tipe variabel adalah TIDAK DIKETAHUI dalam penempatan di %L"
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "NULL muncul di sisi kanan dalam penempatan di %L"
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "POINTER valued function appears on right-hand side of assignment at %L"
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "fungsi dinilai POINTER muncul di sisi kanan dari penempatan di %L"
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr ""
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Tipe tidak kompatibel dalam pernyataan DATA di %L; dicoba mengubah %s ke %s"
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "Penempatan target penunjuk bukan sebuah PENUNJUK di %L"
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "'%s' dalam penempatan penunjuk di %L tidak dapat berupa sebuah nilai-kiri karena iniadalah sebuah prosedur"
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, fuzzy, gcc-internal-format
 #| msgid "Expected bounds specification for '%s' at %L"
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Diduga spesifikasi terikat untuk '%s' di %L"
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Bounds specification for '%s' in pointer assignment at %L"
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Fortran 2003: Spesifikasi terikat untuk '%s' dalam penempatan penunjuk di %L"
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "stack size must not be greater than 64k"
 msgid "Stride must not be present at %L"
 msgstr "ukuran stack harus lebih besar  dari 64k"
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "Objek eksternal '%s' di %L tidak boleh memiliki sebuah penginisialisasi"
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Diduga sebuah prosedur untuk argumen '%s' di %L"
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "duplikasi deklarasi antar-muka untuk class %qs"
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr "Penempatan target penunjuk bukan sebuah PENUNJUK di %L"
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Tipe berbeda dalam penempatan penunjuk di %L; mencoba penempatan dari %s ke %s"
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Jenis parameter berbeda dalam penempatan penunjuk di %L"
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Tingkat berbeda dalam penempatan penunjuk di %L"
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Rank remapping target is not rank 1 at %L"
@@ -78612,205 +78652,205 @@ msgstr "Penempatan target penunjuk bukan sebuah PENUNJUK di %L"
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data target at %L shall not have a coindex"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PENUNJUK"
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Pemilihan ekspresi dalam pernyataan GOTO yang terhitung di %L harus berupa sebuah ekspresi integer skalar"
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr ""
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "Target penempatan penunjuk memiliki atribut PROTECTED di %L"
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr "Argumen dari pernyataan SELECT di %L harus berupa sebuah ekspresi skalar"
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr ""
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Target penempatan penunjun baik bukan TARGET ataupun PENUNJUN di %L"
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Target buruk dalam penempatan penunjuk dalam prosedur PURE di %L"
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Penempatan penunjuk dengan subscrip vektori di rhs di %L"
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Target penempatan penunjuk memiliki atribut PROTECTED di %L"
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Komponen di %C harus memiliki sebuah atribut PENUNJUK"
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Komponen di %C harus memiliki sebuah atribut PENUNJUK"
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Noninteger exponent in an initialization expression at %L"
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2003: eksponen bukan integer dalam sebuah ekspresi inisialisasi di %L"
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, fuzzy, gcc-internal-format
 #| msgid "Argument to '%s' at %L is not a variable"
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "Argumen ke '%s' di %L bukan sebuah variabel"
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, gcc-internal-format
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "Variabel '%s' tidak dapat muncul dalam ekspresi di %L"
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Variabel %s tidak dapat ditempatkan dalam prosedur PURE di %C"
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, gcc-internal-format
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr ""
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -78833,8 +78873,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "Membuat array sementara di %L"
@@ -78924,7 +78964,7 @@ msgstr "Variabel '%s' di %C tidak dapat diredefinisi didalam loop berawal di %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Variabel '%s' di %C tidak dapat diredefinisi didalam loop berawal di %L"
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -79068,12 +79108,12 @@ msgstr "Argumen pertama dari penempatan yang didefinisikan di %L harus berupa IN
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Argumen kedua dari penempatan didefinisikan di %L harus berupa INTENT(IN)"
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Argumen pertama dari antar-muka operator di %L harus berupa INTENT(IN)"
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Argumen kedua dari antar-muka operator di %L harus berupa INTENT(IN)"
@@ -80058,7 +80098,7 @@ msgstr "Konversi dari %s ke %s di %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
@@ -80685,7 +80725,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' in namelist '%s' at %L cannot have ALLOCATABLE components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -80866,6 +80906,11 @@ msgstr "Integer overflow"
 msgid "check_charlen_present(): length not set"
 msgstr ""
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr ""
+
 #: fortran/match.cc:118
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
@@ -81319,7 +81364,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "Penunjuk Cray di %C harus berupa sebuah integer"
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
@@ -81892,91 +81937,91 @@ msgstr "Sintaks error dalam pernyataan TERPROTEKSI di %C"
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "SELECT RANK statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "Sintaks error dalam pernyataan SAVE di %C"
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Diduga pernyataan CASE di %C"
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CASE specification at %C"
 msgstr "Sintaks error dalam spesifikasi CASE di %C"
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Tidak terduga pernyataan END di %C"
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Sintaks error dalam spesifikasi CASE di %C"
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Sintaks error dalam spesifikasi CASE di %C"
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected RANK statement at %C"
 msgstr "Tidak terduga pernyataan END di %C"
 
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL stride expression at %L must be a scalar %s"
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "FORALL stride ekspresi di %L harus berupa sebuah skalar %s"
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in RANK specification at %C"
 msgstr "Sintaks error dalam spesifikasi CASE di %C"
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "pernyataan ELSEWHERE di %C tidak terenklose dalam blok WHERE"
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -83521,8 +83566,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF clause di %L membutuhkan sebuah ekspresi skalara LOGIKAL"
@@ -86130,13 +86175,13 @@ msgstr "Intrinsik '%s' dideklarasikan INTRINSIC di %L tidak tersedia dalam konfi
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Bukan prosedur REKURSIF '%s' di %L mungkin memanggil dirinya sendiri secara rekursif. Deklarasikan itu secara RECURSIVE atau gunakan -frecursive"
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, fuzzy, gcc-internal-format
 #| msgid "Non-RECURSIVE procedure '%s' at %L is possibly calling itself recursively.  Declare it RECURSIVE or use -frecursive"
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Bukan prosedur REKURSIF '%s' di %L mungkin memanggil dirinya sendiri secara rekursif. Deklarasikan itu secara RECURSIVE atau gunakan -frecursive"
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Label %d direferensikan di %L tidak pernah terdefinisi"
@@ -86273,7 +86318,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Fungsi '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -86712,298 +86757,304 @@ msgstr "Intrinsik subroutine '%s' di %L tidak boleh memiliki sebuah penspesifika
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Intrinsik subroutine '%s' di %L tidak boleh memiliki sebuah penspesifikasi tipe"
 
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr "Referensi array buruk di %L"
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s', used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel '%s', digunakan dalam sebuah ekspresi spesifikasi, direferensikan di %L sebelum pernyataan MASUKAN dimana ini adalah sebuah parameter"
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel '%s' digunakan di %L sebelum pernyataan MASUKAN dimana ini adalah sebuah parameter"
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared %s"
 msgid "Using variable %qs at %L is deprecated"
 msgstr "instance variabel %qs dideklarasikan %s"
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Bad array reference at %L"
+msgid "Invalid array reference at %L"
+msgstr "Referensi array buruk di %L"
+
+#: fortran/resolve.cc:6433
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Objek yang dilewatkan di %L harus berupa skalar"
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Argumen '%s' dari prosedur elemental di %L harus berupa skalar"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, fuzzy, gcc-internal-format
 #| msgid "Found no matching specific binding for the call to the GENERIC '%s' at %L"
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Tidak ditemukan pengikatan spesifik yang cocok untuk panggilan ke GENERIC '%s' di %L"
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a SUBROUTINE"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "'%s' di %L seharusnya berupa sebuah SUBROUTINE"
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a FUNCTION"
 msgid "%qs at %L should be a FUNCTION"
 msgstr "'%s' di %L seharusnya berupa sebuah FUNGSI"
 
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Diduga tipe ekspresi"
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s di %L harus berupa sebuah skalar"
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: %s at %L must be integer"
 msgid "%s at %L must be integer"
 msgstr "Featur terhapus: %s di %L harus berupa integer"
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s di %L harus berupa INTEGER"
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL awal ekspresi di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL akhir ekspresi di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL stride ekspresi di %L harus berupa sebuah skalar %s"
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL stride ekspresi di %L tidak dapat berupa nol"
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, fuzzy, gcc-internal-format
 #| msgid "FORALL index '%s' may not appear in triplet specification at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL indeks '%s' mungkin tidak muncul dalam spesifikasi triplet di %L"
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Ekspresi dalam pernyataan ALOKASI di %L harus berupa DAPAT DIALOKASIKAN atau sebuah PENUNJUK"
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "'%s' tidak boleh muncul dalam spesifikasi array di %L dalam pernyataan ALOKASI yang sama dimana ini sendiri dialokasikan"
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Label di %L tidak dalam blok yang sama seperti pernyataan GOTO di %L"
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -87012,310 +87063,310 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE label di %L overlaps dengan CASE label di %L"
 
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %s"
 
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %d"
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa skalar"
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Pemilihan ekspresi dalam pernyataan GOTO yang terhitung di %L harus berupa sebuah ekspresi integer skalar"
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argumen dari pernyataan SELECT di %L tidak dapat berupa %s"
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argumen dari pernyataan SELECT di %L harus berupa sebuah ekspresi skalar"
 
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %s"
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "KASUS BAKU di %L tidak dapat diikuti oleh sebuah KASUS BAKU kedua di %L"
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Jangkauan logikal dalam pernyataan CASE di %L tidak diperbolehkan"
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "constant logical value in CASE statement is repeated at %L"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "nilai logikan konstan dalam pernyataan CASE diulang di %L"
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Spesifikasi jangkauan di %L tidak pernah cocok"
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logikal SELECT CASE blok di %L memiliki lebih dari dua kasus"
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Nama '%s' tidak dapat digunakan sebagai sebuah operator terdefinisi di %C"
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Selector at %L cannot be NULL()"
 msgstr "Langkah iterasi di %L tidak dapat nol"
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Selector at %L has no type"
 msgstr "Fungsi '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Sintaks error dalam pernyataan EKUIVALEN di %L"
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: %s at %L must be integer"
 msgid "Selector at %L must not be coindexed"
 msgstr "Featur terhapus: %s di %L harus berupa integer"
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "CASE label di %L overlaps dengan CASE label di %L"
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L is empty"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Tipe turunan '%s' di %L adalah kosong"
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L is empty"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Tipe turunan '%s' di %L adalah kosong"
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Tidak terduga pernyataan %s di %C"
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid context for NULL() pointer at %%L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Konteks tidak valid untuk penunjuk NULL() di %%L"
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Interface '%s' of procedure '%s' at %L must be explicit"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Antar-muka '%s' dari prosedur '%s' di %L harus berupa eksplisit"
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PENUNJUK"
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PENUNJUK"
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have ALLOCATABLE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN"
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PRIVATE"
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PRIVATE"
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Elemen pemindahan data di %L tidak dapat berupa sebuah referensi lengkap ke sebuah array yang ukurannya diasumsikan"
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "Argumen dim di %L harus berupa skalar"
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "NUM_THREADS clause di %L membutuhkan sebuah ekspresi skalar INTEGER"
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Argumen dari pernyataan SELECT di %L harus berupa sebuah ekspresi skalar"
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Argumen dari ACOS di %L harus berada diantara -1 dan 1"
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Pernyataan di %L bukan sebuah pernyataan pencabangan target yang valid untuk sebuah pernyataan percabangan di %L"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Cabang di %L bisa menyebabkan sebuah loop tak terhingga"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -87323,222 +87374,222 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Label di %L tidak dalam blok yang sama seperti pernyataan GOTO di %L"
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "DIMANA mask di %L memiliki bentuk tidak konsisten"
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "penempatan target WHERE di %L memiliki bentuk tidak konsisten"
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "penempatan bukan-ELEMEN didefinisikan-pengguna dalam WHERE di %L"
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Pernyataan didalam WHERE di %L tidak didukung"
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL dengan indeks '%s' tidak digunakan di sisi kiri dari penempatan di %L dan jadi mungkin menyebabkan penempatan berulang di objek ini"
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Sebuah konstruks FORALL luar telah memiliki sebuah indeks dengan nama ini %L"
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE clause di %L membutuhkan sebuah array LOGIKAL"
 
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr "Ekspresi KARAKTER akan dipotong dalam penempatan (%d/%d) di %L"
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Variabel impure di %L ditempatkan ke sebuah tipe variabel turunan dengan sebuah komponen PENUNJUK dalam sebuah prosedur PURE (12.6)"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "Argumen dari pernyataan SELECT di %L harus berupa sebuah ekspresi skalar"
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "FORALL awal ekspresi di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "pernyataan GOTO ASSIGNED di %L membutuhkan sebuah variabel INTEGER"
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variabel '%s' belum pernah ditempatkan sebuah label target di %L"
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Pernyataan RETURN alternatif di %L membutuhkan sebuah SKALAR-INTEGER return penspesifikasi"
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected initialization expression in CASE at %C"
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "Diduga ekspresi inisialisasi dalam CASE di %C"
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Jenis tidak valid untuk %s di %L"
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Pernyataan aritmetik IF di %L membutuhkan sebuah ekspresi numerik"
 
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Kondisi keluar dari loop DO WHILE di %L harus berupa sebuah ekspresi skalar LOGIKAL"
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL mask clause di %L membutuhkan sebuah ekspresi LOGIKAL"
 
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Pernyataan kode buruk"
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter '%s' declared at %L"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Parameter '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -87546,7 +87597,7 @@ msgstr "Binding label '%s' di %L collides dengan global entity '%s' di %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -87554,1127 +87605,1127 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Binding label '%s' di %L collides dengan global entity '%s' di %L"
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Array dapat dialokasikan '%s' di %L harus memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Objek skalar '%s' di %L mungkin tidak dapat DIALOKASIKAN"
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Penunjuk array '%s' di %L harus memiliki sebuah bentuk deffered"
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Array '%s' di %L tidak dapat memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Tipe '%s' tidak dapat host assosiasi di %L karena ini diblok dengan sebuah objek tidak kompatibel dari nama sama yang dideklarasikan di %L"
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Modul atau array aplikasi utama '%s' di %L harus memiliki bentuk konstan"
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entity dengan panjang karakter diasumsikan di %L harus berupa sebuah argumen dummy atau sebuah PARAMETER"
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' di %L harus memiliki panjang karakter konstan dalam konteks ini"
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "'%s' di %L harus memiliki panjang karakter konstan dalam konteks ini"
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Dapat dialokasikan '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Eksternal '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Dummy '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Intrinsik '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Hasil fungsi '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Array otomatis '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "dalam %s, di %s:%d"
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Pernyataan fungsi nilai-karakter '%s' di %L harus memiliki panjang konstant"
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: '%s' adalah sebuah tipe PRIVATE dan tidak dapat berupa sebuah argumen dummy dari '%s', yang mana ini adalah PUBLIK di %L"
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Procedure '%s' in PUBLIC interface '%s' at %L takes dummy arguments of '%s' which is PRIVATE"
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: Prosedur '%s' dalam antar-muka PUBLIK '%s' di %L memakai argumen dummy dari '%s' dimana ini adalah PRIVATE"
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Fungsi '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Objek eksternal '%s' di %L tidak boleh memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Fungsi ELEMEN '%s' di %L harus memiliki sebuah hasil skalar"
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Pernyataan fungsi '%s' di %L tidak diperbolehkan sebagai argumen aktual"
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat bernilai-array"
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat bernilai-penunjuk"
 
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat pure"
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat rekursif"
 
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat pure"
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Prosedur '%s' dalam %s di %L tidak memiliki antar-muka eksplisit"
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Prosedur dummy '%s' di %C tidak dapat memiliki sebuah antar-muka umum"
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut SAVE dalam '%s' di %L"
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut NAMELIST dalam '%s' di %L"
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, fuzzy, gcc-internal-format
 #| msgid "Interface '%s' of procedure '%s' at %L must be explicit"
 msgid "Interface of %qs at %L must be explicit"
 msgstr "Antar-muka '%s' dari prosedur '%s' di %L harus berupa eksplisit"
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' at %L is not a SUBROUTINE"
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "Prosedur FINAL '%s' di %L bukan sebuah SUBROUTINE"
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Prosedur FINAL di %L harus memiliki tepat satu argumen"
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa tipe '%s'"
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "argumen dari prosedur FINAL di %L harus berupa sebuah PENUNJUK"
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argumen dari prosedur FINAL di %L tidak boleh berupa OPSIONAL"
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa INTENT(OUT)"
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Prosedur FINAL bukan skalar di %L seharusnya memiliki diasumsikan argumen bentuk"
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' declared at %L has the same rank (%d) as '%s'"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "prosedur FINAL '%s' dideklarasikan di %L memiliki tingkat yang sama (%d) seperti '%s'"
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type '%s' defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr "Hanya array prosedur FINAL dideklarasikan untuk tipe turunan '%s' didefinisikan di %L, disarankan juga skalar satu"
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' can't be mixed FUNCTION/SUBROUTINE for GENERIC '%s' at %L"
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "'%s' dan '%s' tidak dapat dicampurkan FUNCTION/SUBROUTINE untuk GENERIC '%s' di %L"
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' for GENERIC '%s' at %L are ambiguous"
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "'%s' dan '%s' untuk GENERIC '%s' di %L adalah ambigu"
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, fuzzy, gcc-internal-format
 #| msgid "Undefined specific binding '%s' as target of GENERIC '%s' at %L"
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Tidak terdefinisi pengikatan spesifik '%s' sebagai target dari GENERIC '%s' di %L"
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L must target a specific binding, '%s' is GENERIC, too"
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC '%s' di %L harus target sebuah pengikatan spesifik, '%s' adalah GENERIC, juga"
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC '%s' di %L tidak dapat overwrite pengikatan spesifik dengan nama sama"
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Langkah iterasi di %L tidak dapat nol"
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must be a module procedure or an external procedure with an explicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "'%s' harus berupa sebuah prosedur modul atau sebuah prosedur eksternal dengan sebuah antar-muka eksplisit di %L"
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prosedur '%s' dengan PASS(%s) di %L tidak memiliki argumen '%s'"
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Prosedur '%s' dengan PASS di %L harus memiliki paling tidak satu argumen"
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, fuzzy, gcc-internal-format
 #| msgid "Polymorphic entities are not yet implemented, non-polymorphic passed-object dummy argument of '%s' at %L accepted"
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "entiti polymorphic belum diimplementasikan, bukan polymorphic objek argumen dummy dilewatkan dari '%s' di %L diterima"
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr ""
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object at %L must be scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Objek yang dilewatkan di %L harus berupa skalar"
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "'%s' argumen dari '%s' instrinsik di %L harus berupa sebuah PENUNJUK"
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Prosedur '%s' di %L memiliki nama sama sebagai sebuah komponen dari '%s'"
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as an inherited component of '%s'"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Prosedur '%s' di %L memiliki nama sama seperti sebuah komponen turunan dari '%s'"
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Penunjuk array '%s' di %L harus memiliki sebuah bentuk deffered"
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Argumen dari ICHAR di %L harus berupa panjang satu"
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prosedur '%s' dengan PASS(%s) di %L tidak memiliki argumen '%s'"
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Prosedur '%s' dengan PASS di %L harus memiliki paling tidak satu argumen"
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumen '%s' dari prosedur elemental di %L tidak dapat memiliki atribut POINTER"
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponen '%s' dari '%s' di %L memiliki nama sama dengan prosedur yang melingkupinya"
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L"
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Panjang karakter dari komponen '%s' butuh untuk menjadi sebuah ekspresi spesifikasi konstan di %L"
 
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be of INTEGER type, found %s"
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "Ekspresi di %L harus berupa tipe INTEGER, ditemukan %s"
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: the component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: Komponen '%s' adalah sebuah tipe PRIVATE dan tidak dapat berupa sebuah komponen dari '%s', yang mana adalah PUBLIK di %L"
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponen %s dari tipe URUTAN dideklarasikan di %L tidak dapat memiliki atribut URUTAN"
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflict in attributes of function argument at %C"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Konflik dalam atribut dari argumen fungsi di %C"
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, fuzzy, gcc-internal-format
 #| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Bukan ekstensible tipe turunan '%s' di %L tidak boleh berupa ABSTRACT"
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE has not been declared"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%H%qE belum pernah dideklarasikan"
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Ukuran array yang diasumsikan '%s' dalam daftar nama '%s' di %C tidak diperbolehkan"
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must not have assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' tidak boleh memiliki bentuk yang diasumsikan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must have constant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' harus memiliki bentuk konstan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must have constant shape in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' harus memiliki bentuk konstan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST objek '%s' telah dideklarasikan PRIVATE dan tidak dapat berupa anggota dari PUBLIK namelist '%s' di %L"
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST objek '%s' memiliki use-associated komponen PRIVATE dan tidak dapat berupa anggota dari daftar-nama '%s' di %L"
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST objek '%s' meemiliki komponen PRIVATE dan tidak dapat berupa anggota dari PUBLIK daftar-nama '%s' di %L"
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut NAMELIST dalam '%s' di %L"
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameter array '%s' di %L tidak dapat berupa otomatis atau bentuk deferred"
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Tipe PARAMETER secara implisit '%s' di %L tidak cocok dengan tipe IMPLISIT kemudian"
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Tipe turunan tidak kompatibel dalam PARAMETER di %L"
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Spesifikasi buruk untuk diasumsikan ukuran array di %C"
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Ukuran array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Simbol di %L bukan sebuah variabel DUMMY"
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "'%s' di %L tidak dapat memiliki VALUE atribut karena ini bukan sebuah argumen dummy"
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Karakter dummy variabel '%s' di %L dengan atribut NILAI harus memiliki panjang konstant"
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C interoperable karakter dummy variabel '%s' di %L dengan atribut NILAI harus memiliki panjang satu"
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Tipe turunana '%s' di %L adalah tipe '%s',  yang mana belum didefinisikan"
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Diasumsikan bentuk array '%s' di %L tidak diijinkan dalam sebuah ekspresi inisialisasi"
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variabel '%s' di %L tidak dapat berupa BIND(C) karena ini bukan sebuah blok UMUM atau dideklarasikan dalam tingkat cakupan modul"
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Argumen dari %s di %L harus berupa panjang satu"
 
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003: PUBLIK %s '%s' di %L dari tipe turunan '%s' PRIVATE"
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) dummy argumen '%s' di %L adalah UKURAN DIASUMSIKAN dan jadi tidak dapat memiliki sebuah penginisialisasi baku"
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Array '%s' di %L tidak dapat memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Array dapat dialokasikan '%s' di %L harus memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Prosedur dummy di %L tidak diperbolehkan dalam prosedur ELEMENTAL"
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Daftar-nama %s tidak dapat diubah namanya dengan assosiasi USE ke %s"
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate di %L bukan SAVEd"
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting list of named entities at %C"
 msgid "Expecting definable entity near %L"
 msgstr "Diduga daftar dari entiti bernama di %C"
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "DATA BLOK elemen '%s' di %L harus berupa dalam COMMON"
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA array '%s' di %L harus dispesifikasikan dalam sebuah deklarasi sebelumnya"
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Dummy '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Daerah array tidak konstant di %L dalam pernyataan DATA"
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "pernyataan DATA di %L memiliki lebih variabel daripada nilai"
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Nonconstant array section at %L in DATA statement"
 msgid "Non-constant character length at %L in DATA statement"
 msgstr "Daerah array tidak konstant di %L dalam pernyataan DATA"
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "pernyataan DATA di %L memiliki lebih banyak nilai daripada variabel"
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Label %d di %L didefinisikan tetapi tidak digunakan"
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Label %d di %L didefinisikan tetapi tidak dapat digunakan"
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L harus memiliki atribut URUTAN untuk menjadi sebuah objek EKUIVALEN"
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN untuk menjadi sebuah objek EKUIVALEN"
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Tipe variabel turunan '%s' di %L dengan inisialisasi baku tidak dapat berada dalam EKUIVALEN dengan sebuah variabel dalam COMMON"
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L dengan komponen penunjuk tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Sintaks error dalam pernyataan EKUIVALEN di %L"
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Baik semua atau kosong dari objek dalam EKUIVALEN set di %L yang memiliki atribut TERPROTEKSI"
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Anggota blok umum '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN dalam prosedur pure '%s'"
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Konstanta bernama '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Array '%s' di %L dengan cakupan tidak-konstan tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Komponen struktur '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Substring di %L memiliki panjang nol"
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, fuzzy, gcc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Panjang karakter berbeda dalam penempatan penunjuk di %L"
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fungsi PUBLIK '%s' di %L tidak dapat berupa tipe PRIVATE '%s'"
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "MASUKAN '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Prosedur operator pengguna '%s' di %L harus berupa sebuah FUNGSI"
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Prosedur operator pengguna '%s' di %L tidak dapat berupa panjang karakter diasumsikan"
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Prosedur operator pengguna '%s' di %L harus memiliki paling tida satu argumen"
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Argumen pertama dari antar-muka operator di %L tidak dapat berupa pilihanonal"
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Argumen kedua dari antar-muka operator di %L tidak dapat berupa pilihanonal"
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Antar-muka operator di %L harus memiliki, paling tidak, dua argumen"
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -89260,364 +89311,364 @@ msgstr "Variabel '%s' secara implisit terdeklarasi di %L mungkin tidak C interop
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr "Hasil fungsi '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr "%s atribut konflik dengan %s atribut di %L"
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, fuzzy, gcc-internal-format
+#| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr "%s atribut konflik dengan %s atribut dalam '%s' di %L"
+
+#: fortran/symbol.cc:508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr "%s atribut tidak diperbolehkan dalam BLOK DATA satuan aplikasi di %L"
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "Argumen '%s' dari prosedur elemental di %L tidak dapat memiliki atribut POINTER"
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, gcc-internal-format
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr ""
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "Procedure pointer at %C"
 msgstr "nama prosedur = %s"
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "%s atribut diaplikasikan ke %s %s di %L"
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) diaplikasikan ke %s %s di %L"
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, gcc-internal-format, gfc-internal-format
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr "%s atribut konflik dengan %s atribut di %L"
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, fuzzy, gcc-internal-format
-#| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr "%s atribut konflik dengan %s atribut dalam '%s' di %L"
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "Tidak dapat mengubah atribut dari USE-assosiasi simbol di %L"
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "Tidak dapat mengubah atribut dari USE-assosiasi simbol %s di %L"
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "Duplikasi atribut %s dispesifikasikan di %L"
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr "ALLOCATABLE dispesifikasikan diluar dari tubuh ANTAR-MUKA di %L"
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate VOLATILE attribute specified at %L"
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr "Duplikasi atribut VOLATILE dispesifikasikan di %L"
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, fuzzy, gcc-internal-format
 #| msgid "DIMENSION specified for '%s' outside its INTERFACE body at %L"
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "DIMENSION dispesifikasikan untuk '%s' diluar dari badan ANTAR-MUKA di %L"
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, fuzzy, gcc-internal-format
 #| msgid "DIMENSION specified for '%s' outside its INTERFACE body at %L"
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "DIMENSION dispesifikasikan untuk '%s' diluar dari badan ANTAR-MUKA di %L"
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "Cray Pointee di %L muncul dalam beberapa pernyataan penunjuk()"
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "Duplikasi atribut TERPROTEKSI dispesifikasikan di %L"
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "atribut SAVE di %L tidak dapat dispesifikasikan dalam sebuah prosedur PURE"
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "Duplikasi SAVE atribut dispesifikasikan di %L"
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "Duplikasi atribut NILAI dispesifikasikan di %L"
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Duplikasi atribut VOLATILE dispesifikasikan di %L"
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr "atribut SAVE di %L tidak dapat dispesifikasikan dalam sebuah prosedur PURE"
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate VALUE attribute specified at %L"
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Duplikasi atribut NILAI dispesifikasikan di %L"
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute of '%s' conflicts with %s attribute at %L"
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "%s atribut dari '%s' konflik dengan %s atribut di %L"
 
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "%s prosedur di %L telah dideklarasikan sebagai %s prosedur"
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) konfliks dengan INTENT(%s) di %L"
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "Spesifikasi AKSES di %L telah dispesifikasikan"
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Duplikasi atribut BIND dispesifikasikan di %L"
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid " BIND(C)"
 msgid "BIND(C) at %L"
 msgstr " BIND(C)"
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Duplikasi atribut EXTENDS dispesifikasikan di %L"
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: EXTENDS at %L"
 msgid "EXTENDS at %L"
 msgstr "Fortran 2003: EXTENDS di %L"
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Simbol '%s' di %L telah memiliki sebuah antar-muka eksplisit"
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has attributes specified outside its INTERFACE body"
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "'%s' di %L memiliki atribut dispesifikasikan diluar dari badan ANTAR-MUKA-nya"
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %C already has a type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Fungsi '%s' di %C telah memiliki sebuah tipe dari %s"
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Prosedur '%s' di %L memiliki nama sama sebagai sebuah komponen dari '%s'"
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Simbol '%s' di %L tidak dapat memiliki sebuah tipe"
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already in the parent type at %L"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Komponen '%s' di %C telah berada dalam tipe induknya di %L"
 
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Simbol '%s' di %C adalah ambigu"
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Tipe turunan '%s' di %C sedang digunakan sebelum itu didefinisikan"
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Komponen '%s' di %C adalah sebuah komponen PRIVATE dari '%s'"
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "'%s' di %C bukan sebuah anggota dari struktur '%s'"
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "'%s' di %C bukan sebuah anggota dari struktur '%s'"
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Duplikasi pernyataan label %d di %L dan %L"
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Label %d di %C telah direferensikan sebagai target percabangan"
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Label %d di %C telah direferensikan sebagai sebuah format label"
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Label %d di %C sebelumnya digunakan sebagai sebuah FORMAT label"
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Label %d di %C sebelumnya digunakan sebagai target percabangan"
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Shared DO termination label %d at %C"
 msgstr "Diduga nama berakhir di %C"
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Labeled DO statement at %L"
 msgstr "Tidak terduga pernyataan END di %C"
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Nama '%s' di C adalah sebuah referensi ambigu ke '%s' dari module '%s'"
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from current program unit"
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "Nama '%s' di %C adalah sebuah referensi ambigu ke '%s' dari satuan aplikasi sekarang"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Simbol '%s' di %C telah diassosiasikan host"
 
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' declared at %L must have the BIND attribute to be C interoperable"
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Tipe turunan '%s' dideklarasikan di %L harus memiliki atribut BIND ke Cinteroperable"
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponen '%s' di %L tidak dapat memiliki atribut PENUNJUK karena ini sebuah anggota tari BIND(C) tipe turunan '%s' di %L"
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponen '%s' di %L tidak dapat memiliki atribut PENUNJUK karena ini sebuah anggota tari BIND(C) tipe turunan '%s' di %L"
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponen '%s' di %L tidak dapat memiliki atribut DAPAT DIALOKASIKAN karena ini sebuah anggota dari tipe turunan BIND(C) '%s' di %L"
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable, even though derived type '%s' is BIND(C)"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "Komponen '%s' dalam tipe turunan '%s' di %L mungkin tidak C interoperabel, walaupun melalui tipe turunan '%s' adalah BIND(C)"
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "Komponen '%s' dalam tipe turunan '%s' di %L mungkin tidak C interoperabel"
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Tipe turunan '%s' di %L tidak dapat memiliki urutan atribut karena ini adalah BIND(C)"
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' is used before it is typed at %L"
 msgid "Symbol %qs is used before it is typed at %L"
@@ -89650,26 +89701,26 @@ msgstr "Overlapping tidak sama penginisialisasi dalam EKUIVALEN di %L"
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "Overlapping tidak sama penginisialisasi dalam EKUIVALEN di %L"
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, fuzzy, gcc-internal-format
 #| msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See -fmax-array-constructor option"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "Jumlah dari elemen dalam konstruktor array di %L membutuhkan sebuah peningkatan dari batas atas %d yang diijinkan. Lihat pilihan -fmax-array-constructor"
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, fuzzy, gcc-internal-format
 #| msgid "Creating array temporary at %L for argument '%s'"
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Membuat array sementara di %L untuk argumen '%s'"
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "tipe ekspresi buruk selama walk (%d)"
@@ -89882,37 +89933,37 @@ msgstr "Nilai kembali dari fungsi '%s' dideklarasikan di %L tidak diset"
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Instrinsik op tidak diketahui"
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Daftar fungsi argumen tidak diketahui di %L"
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -89924,18 +89975,18 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "Fungsi instrinsik %s(%d) tidak dikenal"
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "'dim' argumen dari %s intrinsik di %L bukan sebuah dimensi indeks valid"
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "environment variable \"%s\" not defined"
 msgid "The event variable at %L shall not be coindexed"
@@ -90089,7 +90140,7 @@ msgstr ""
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_trans_select(): Bad type for case expr."
@@ -90504,6 +90555,12 @@ msgstr "field %qs dideklarasikan sebagai sebuah fungsi"
 msgid "function %qD redeclared as variable"
 msgstr "fungsi %q+D redeklarasi sebagai inline"
 
+#: lto/lto-symtab.cc:865
+#, fuzzy, gcc-internal-format
+#| msgid "%Jpreviously used here"
+msgid "previously declared here"
+msgstr "%J sebelumnya digunakan disini"
+
 #: lto/lto.cc:174
 #, gcc-internal-format
 msgid "%<lto_obj_file_open()%> failed"
@@ -91876,7 +91933,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr ""
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, fuzzy, gcc-internal-format
 #| msgid "non-object member %qs cannot be declared %<mutable%>"
 msgid "non-objective-c type %qT cannot be caught"
@@ -91887,7 +91944,7 @@ msgstr "anggota bukan-objek %qs tidak dapat dideklarasikan %<mutable%>"
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr ""
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, gcc-internal-format
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
 msgstr ""
diff --git a/gcc/po/ja.po b/gcc/po/ja.po
index 869bc483956..d6734a6a23b 100644
--- a/gcc/po/ja.po
+++ b/gcc/po/ja.po
@@ -21,7 +21,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 11.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
 "PO-Revision-Date: 2021-05-11 22:47+0900\n"
 "Last-Translator: Hiroshi Takekawa <sian@big.or.jp>\n"
 "Language-Team: Japanese <translation-team-ja@lists.sourceforge.net>\n"
@@ -417,7 +417,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr "-march=... と -mcpu=... の両方を指定しないでください"
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 msgid "shared and mdll are not compatible"
 msgstr "shared と mdll は併用できません"
 
@@ -19219,16 +19219,16 @@ msgstr "認識できない命令:"
 msgid "insn does not satisfy its constraints:"
 msgstr "命令が制約を満たしません:"
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "作成時と使用時で '%s' の設定が異なります"
 
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "作成時と使用時で %<-fpic%> の設定が異なります"
 
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 msgid "created and used with different settings of %<-fpie%>"
 msgstr "作成時と使用時で %<-fpie%> の設定が異なります"
 
@@ -19549,7 +19549,7 @@ msgstr "strfmon 書式の長さ修飾子"
 msgid "<command-line>"
 msgstr "<コマンドライン>"
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
@@ -19568,9 +19568,9 @@ msgstr "コード '%c' に対する無効な被演算子です"
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, c-format
 msgid "invalid vector constant"
 msgstr "無効なベクトル定数です"
@@ -19591,7 +19591,7 @@ msgstr "コード '%c' に対する無効な被演算子です"
 msgid "incompatible register operand for '%%%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, c-format
 msgid "missing operand"
 msgstr "被演算子がありません"
@@ -19620,93 +19620,93 @@ msgstr "無効なアドレスモードです"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "GNU と SVE ベクタの二項演算はできません"
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "局所動的 TLS 参照無しで '%%&' が使用されました"
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, c-format
 msgid "invalid %%J value"
 msgstr "無効な %%J 値"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, c-format
 msgid "invalid %%r value"
 msgstr "無効な %%r 値"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, c-format
 msgid "invalid %%R value"
 msgstr "無効な %%R 値"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, c-format
 msgid "invalid %%N value"
 msgstr "無効な %%N 値"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, c-format
 msgid "invalid %%P value"
 msgstr "無効な %%P 値"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, c-format
 msgid "invalid %%h value"
 msgstr "無効な %%h 値"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, c-format
 msgid "invalid %%L value"
 msgstr "無効な %%L 値"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, c-format
 msgid "invalid %%m value"
 msgstr "無効な %%m 値"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, c-format
 msgid "invalid %%M value"
 msgstr "無効な %%M 値"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, c-format
 msgid "invalid %%U value"
 msgstr "無効な %%U 値"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, c-format
 msgid "invalid %%s value"
 msgstr "無効な %%s 値"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, c-format
 msgid "invalid %%C value"
 msgstr "無効な %%C 値"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, c-format
 msgid "invalid %%E value"
 msgstr "無効な %%E 値"
 
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, c-format
 msgid "unknown relocation unspec"
 msgstr ""
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, c-format
 msgid "invalid %%xn code"
 msgstr "無効な %%xn コード"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, fuzzy, c-format
 msgid "invalid operand address"
 msgstr "無効なアドレスです"
@@ -19802,35 +19802,35 @@ msgstr "被演算子として無効な UNSPEC です"
 msgid "unrecognized supposed constant"
 msgstr "認識できない定数のようなもの"
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, c-format
 msgid "invalid shift operand"
 msgstr "無効なシフト被演算子"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "述語付き Thumb 命令"
 
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "条件シーケンスにある述語付き命令"
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -19838,114 +19838,114 @@ msgstr "コード '%c' に対する無効な被演算子です"
 msgid "invalid operand for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, c-format
 msgid "instruction never executed"
 msgstr "命令は決して実行されません"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "%<bfloat16_t%> からの無効な変換です"
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "%<bfloat16_t%> への無効な変換です"
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "アドレス被演算子は X、Y または Z レジスタに対する制約を要求します"
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 #, fuzzy
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "出力被演算子 %d は %<&%> 制約を使用しなければいけません"
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 msgid "bad address, not an I/O address:"
 msgstr "誤ったアドレスです。I/O アドレスではありません:"
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 msgid "bad address, not a constant:"
 msgstr "誤ったアドレスです。定数ではありません:"
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 msgid "bad address, not (reg+disp):"
 msgstr "誤ったアドレスです。(reg+disp) ではありません:"
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "誤ったアドレスです。post_inc または pre_dec ではありません:"
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr "コンパイラ内部エラー。誤ったアドレス:"
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 msgid "internal compiler error.  Unknown mode:"
 msgstr "コンパイラ内部エラー。不明なモード:"
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 msgid "invalid insn:"
 msgstr "無効な命令:"
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 msgid "incorrect insn:"
 msgstr "正しくない命令:"
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 msgid "unknown move insn:"
 msgstr "不明な move 命令:"
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 msgid "bad shift insn:"
 msgstr "誤ったシフト命令:"
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "コンパイラ内部エラー。正しくないシフト:"
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 msgid "unsupported fixed-point conversion"
 msgstr "サポートしていない固定小数点変換です"
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 msgid "variable"
 msgstr "変数"
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 msgid "function parameter"
 msgstr "関数パラメータ"
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 msgid "structure field"
 msgstr "構造体フィールド"
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 msgid "return type of function"
 msgstr "関数の戻り値の型"
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 msgid "pointer"
 msgstr "ポインタ"
 
@@ -19980,7 +19980,7 @@ msgstr "サポートされていない演算子"
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -20299,54 +20299,54 @@ msgstr "被演算子は条件コードではありません。無効な被演算
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "無効な被演算子コード '%c' です"
 
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "演算子に対する無効な制約です"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, c-format
 msgid "invalid vector immediate"
 msgstr "無効なベクトル直接表記"
 
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 msgid "unknown insn mode"
 msgstr "不明な命令モード"
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 #, fuzzy
 #| msgid "invalid conversion from type %<bfloat16_t%>"
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr "%<bfloat16_t%> からの無効な変換です"
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 #, fuzzy
 #| msgid "invalid conversion from type %<bfloat16_t%>"
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr "%<bfloat16_t%> からの無効な変換です"
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 #, fuzzy
 #| msgid "invalid conversion to type %<bfloat16_t%>"
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr "%<bfloat16_t%> への無効な変換です"
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 #, fuzzy
 #| msgid "invalid conversion to type %<bfloat16_t%>"
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr "%<bfloat16_t%> への無効な変換です"
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
 msgstr ""
 
@@ -20377,7 +20377,7 @@ msgstr "%<__fpreg%> に関する無効な操作です"
 msgid "invalid %%P operand"
 msgstr "無効な %%P 被演算子です"
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, c-format
 msgid "invalid %%p value"
 msgstr "無効な %%p 値です"
@@ -20404,29 +20404,29 @@ msgstr "非 gp 関連の絶対アドレスを使用できません"
 msgid "invalid addressing mode"
 msgstr "無効なアドレスモードです"
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, c-format
 msgid "'%%%c' is not a valid operand prefix"
 msgstr "'%%%c' は有効な被演算子接頭辞ではありません"
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "'%%%c' の無効な使用法です"
@@ -20458,7 +20458,7 @@ msgid "post-increment address is not a register"
 msgstr "後置増分アドレスがレジスタではありません"
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 msgid "bad address"
 msgstr "誤ったアドレスです"
 
@@ -20616,7 +20616,7 @@ msgstr "サポートされていない定数アドレス:"
 msgid "unsupported memory expression:"
 msgstr "固定小数変換内で無効な型です"
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, fuzzy, c-format
 msgid "invalid vector operand"
 msgstr "無効な %%P 被演算子です"
@@ -20670,249 +20670,249 @@ msgstr ""
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "リトルエンディアンモードでコードを生成する"
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 msgid "bad move"
 msgstr "誤った move です"
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 msgid "Bad 128-bit move"
 msgstr "誤った 128 ビット move"
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, c-format
 msgid "invalid %%A value"
 msgstr "無効な %%A 値"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%D value"
 msgstr "無効な %%D 値です"
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, c-format
 msgid "invalid %%e value"
 msgstr "無効な %%e 値"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, c-format
 msgid "invalid %%f value"
 msgstr "無効な %%f 値です"
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, c-format
 msgid "invalid %%F value"
 msgstr "無効な %%F 値です"
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, c-format
 msgid "invalid %%G value"
 msgstr "無効な %%G 値です"
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, c-format
 msgid "invalid %%j code"
 msgstr "無効な %%j コードです"
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, c-format
 msgid "invalid %%J code"
 msgstr "無効な %%J コードです"
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, c-format
 msgid "invalid %%k value"
 msgstr "無効な %%k 値です"
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, c-format
 msgid "invalid %%K value"
 msgstr "無効な %%K 値です"
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, c-format
 msgid "invalid %%O value"
 msgstr "無効な %%O 値です"
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, c-format
 msgid "invalid %%q value"
 msgstr "無効な %%q 値です"
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, c-format
 msgid "invalid %%t value"
 msgstr "無効な %%t 値"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, c-format
 msgid "invalid %%T value"
 msgstr "無効な %%T 値です"
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, c-format
 msgid "invalid %%u value"
 msgstr "無効な %%u 値です"
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, c-format
 msgid "invalid %%v value"
 msgstr "無効な %%v 値です"
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, c-format
 msgid "invalid %%V value"
 msgstr "無効な %%V 値"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, c-format
 msgid "invalid %%x value"
 msgstr "無効な %%x 値です"
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, c-format
 msgid "invalid %%z value"
 msgstr "無効な %%z 値"
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "無効な %%y 値です。'Z' 制約を使用してみてください"
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 #, fuzzy
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "32 ビット乗算命令を有効にする"
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました"
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "各関数で単一の終了点を生成しない"
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "整列されていない load/store 命令を有効にする"
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "%<__vector_quad%> からの無効な変換です"
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "%<__vector_quad%> への無効な変換です"
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 #, fuzzy
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "%<__fpreg%> からの無効な変換です"
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 #, fuzzy
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "%<__fpreg%> への無効な変換です"
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "シンボルによるメモリ参照は z10 またはそれ以降でのみサポートされます"
 
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, c-format
 msgid "cannot decompose address"
 msgstr ""
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "'E' 出力修飾子用の無効な比較演算子です"
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "'J' 出力修飾子用の無効な参照です"
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "'O' 出力修飾子用の無効なアドレスです"
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "'R' 出力修飾子用の無効なアドレスです"
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "'S' 出力修飾子用にはメモリ参照が予期されます"
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "'S' 出力修飾子用の無効なアドレスです"
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "'N' 出力修飾子用にはレジスタまたはメモリ式が予期されます"
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "'M' 出力修飾子用にはレジスタまたはメモリ式が予期されます"
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "出力修飾子 '%c' 用の無効な定数です"
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "無効な定数です - 出力修飾子の使用を試みてください"
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "出力修飾子 '%c' 用の無効な定数です"
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "無効な式です - 出力修飾子の使用を試みてください"
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "出力修飾子 '%c' 用の無効な式です"
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 #, fuzzy
 msgid "vector argument passed to unprototyped function"
 msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました"
 
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 #, fuzzy
 msgid "types differ in signedness"
 msgstr "戻りでのポインタの先の符号が異なります"
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -21112,12 +21112,12 @@ msgstr "({無名})"
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> が予期されます"
@@ -21130,7 +21130,7 @@ msgstr "%<;%> が予期されます"
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -21139,7 +21139,7 @@ msgstr "%<;%> が予期されます"
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> が予期されます"
@@ -21147,7 +21147,7 @@ msgstr "%<)%> が予期されます"
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> が予期されます"
@@ -21158,29 +21158,29 @@ msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> が予期されます"
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> が予期されます"
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> が予期されます"
@@ -21190,17 +21190,17 @@ msgstr "%<{%> が予期されます"
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> が予期されます"
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> が予期されます"
@@ -21209,8 +21209,8 @@ msgstr "%<while%> が予期されます"
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> が予期されます"
@@ -21220,17 +21220,17 @@ msgid "expected %<.%>"
 msgstr "%<.%> が予期されます"
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> が予期されます"
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> が予期されます"
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> または %<)%> が予期されます"
@@ -21238,33 +21238,33 @@ msgstr "%<,%> または %<)%> が予期されます"
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> が予期されます"
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> が予期されます"
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<delete%>"
 msgid "expected %<else%>"
 msgstr "%<delete%> が予期されます"
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> または %<}%> が予期されます"
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr ""
 
@@ -21272,7 +21272,7 @@ msgstr ""
 msgid "(anonymous)"
 msgstr "(無名)"
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> が予期されます"
@@ -21287,21 +21287,21 @@ msgstr "%<__label__%> が予期されます"
 msgid "candidate:"
 msgstr "候補:"
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 #, fuzzy
 msgid "  after user-defined conversion:"
 msgstr "利用者定義命令を有効にする"
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "候補:"
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr "候補 1:"
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr "候補 2:"
 
@@ -21555,7 +21555,7 @@ msgstr "%s:%d:%d:   %qs から実体化されました\n"
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 msgid "candidates are:"
 msgstr "候補:"
 
@@ -21599,48 +21599,48 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "単項マイナスへの引数の型が間違っています"
 
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "単項プラスへの引数の型が間違っています"
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "ビット反転への引数の型が間違っています"
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "abs への引数の型が間違っています"
 
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "複素共役(~)への引数の型が間違っています"
 
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 msgid "in argument to unary !"
 msgstr ""
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -21722,7 +21722,7 @@ msgstr ""
 msgid "Deleted feature:"
 msgstr "演算子が予期されます"
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 msgid "array assignment"
 msgstr "配列代入"
 
@@ -21928,11 +21928,11 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 msgid "assignment"
 msgstr "代入"
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 #, fuzzy
 msgid "pointer assignment"
 msgstr "代入"
@@ -22105,47 +22105,47 @@ msgstr ""
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE オブジェクト"
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 msgid "ALLOCATE object"
 msgstr "ALLOCATE オブジェクト"
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 msgid "STAT variable"
 msgstr "STAT 変数"
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 msgid "ERRMSG variable"
 msgstr "ERRMSG 変数"
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -22154,11 +22154,11 @@ msgstr ""
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr ""
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
@@ -22173,12 +22173,12 @@ msgstr ""
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -22187,81 +22187,81 @@ msgstr ""
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, fuzzy, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "関数 `%s' への引数が少なすぎます"
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, c-format
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, fuzzy, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "関数呼び出しが集合体の値を持っています"
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, fuzzy, c-format
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "関数 `%s' への引数が少なすぎます"
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, fuzzy, c-format
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "関数 `%s' への引数が少なすぎます"
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, fuzzy, c-format
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "関数 `%s' への引数が少なすぎます"
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
@@ -22283,15 +22283,15 @@ msgstr ""
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 msgid "Loop variable has been modified"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 msgid "DO step value is zero"
 msgstr ""
 
@@ -22369,7 +22369,7 @@ msgid "expected boolean type"
 msgstr "整数または真偽型が予期されます"
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "ポインタが予期されます"
@@ -22435,7 +22435,7 @@ msgstr "十分な引数がありません"
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "引数が多すぎます"
@@ -23090,7 +23090,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "-mrelax は RTP PIC 用にのみサポートされています"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
@@ -23536,8 +23536,8 @@ msgstr "%qE 属性は %s 属性と競合します"
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "前方での `%s' の宣言"
@@ -23554,7 +23554,7 @@ msgstr "%qE 属性指示が無視されました"
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr "%qE 属性指示が無視されました"
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, gcc-internal-format
 msgid "wrong number of arguments specified for %qE attribute"
 msgstr "%qE 属性用に間違った数の引数が指定されました"
@@ -23564,7 +23564,7 @@ msgstr "%qE 属性用に間違った数の引数が指定されました"
 msgid "expected %i or more, found %i"
 msgstr "%<(%> またはファイル終端 (EOF) が予期されます"
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "expected %i, found %i"
 msgstr "%<(%> またはファイル終端 (EOF) が予期されます"
@@ -23631,12 +23631,12 @@ msgstr "型が既に定義されているため型属性が無視されました
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -23645,7 +23645,7 @@ msgstr "型が既に定義されているため型属性が無視されました
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -23667,8 +23667,8 @@ msgstr "%qE 属性は無視されました"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "前方での `%s' の宣言"
@@ -23775,7 +23775,7 @@ msgstr "クラス %s 用のファイルを見つけられません。"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "オフセットが定数文字列の境界の外にあります"
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, fuzzy, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qD はここで宣言されています"
@@ -23880,7 +23880,7 @@ msgstr "%qs への有効な引数は次の通りです: %s"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, fuzzy, gcc-internal-format
 #| msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
@@ -23904,42 +23904,42 @@ msgstr "%<__builtin_longjmp%> の第二引数は 1 でなければいけませ
 msgid "target format does not support infinity"
 msgstr "ターゲット形式は無限大をサポートしません"
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, fuzzy, gcc-internal-format
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> が引数の数が固定の関数内で使用されました"
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "関数 %<va_start%> への引数の数が間違っています"
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> が引数無しで呼び出されました"
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%> の第二引数が、最後の名前付き引数ではありません"
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, fuzzy, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "%<va_start%> の第二引数が %<register%> 記憶域の場合の動作は不定です"
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, fuzzy, gcc-internal-format
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr "%K %D の第一引数がポインタ、第二引数が整数定数でなければいけません"
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, fuzzy, gcc-internal-format
 msgid "last argument of %qD is not integer constant between 0 and 3"
 msgstr "%K %D の最後の引数が 0 から 3 の間の整数定数ではありません"
@@ -24986,12 +24986,12 @@ msgstr "%qE 属性は %qT が既に定義されているため無視されます
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F が使用されましたが定義されていません"
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F が %<static%> と宣言されましたが定義されていません"
@@ -25541,7 +25541,7 @@ msgstr "region_array が region_tree と適合しません"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "lp_array が region_tree と適合しません"
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, fuzzy, gcc-internal-format
 msgid "%qs failed"
 msgstr "atexit に失敗しました"
@@ -25571,17 +25571,17 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, fuzzy, gcc-internal-format
 msgid "call to %qs declared with attribute error: %s"
 msgstr "インライン関数 %q+D を弱いとして宣言できません"
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, fuzzy, gcc-internal-format
 msgid "call to %qs declared with attribute warning: %s"
 msgstr "インライン関数 %q+D を弱いとして宣言できません"
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
 msgstr "%<abs (X)%> を %<X%> または %<-X%> へ単純化するときに符号のオーバーフローが発生しないと見なしています"
@@ -25616,7 +25616,7 @@ msgstr "大きな固定小数定数が暗黙的に固定整数型に切り詰め
 msgid "comparison is always %d due to width of bit-field"
 msgstr "ビットフィールド幅のため、比較が常に %d になります"
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -25787,7 +25787,7 @@ msgstr "プロセス時間の取得に失敗しました: %m"
 msgid "%s signal terminated program %s"
 msgstr "代替レジスタ名を使用する"
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, fuzzy, gcc-internal-format
 msgid "unrecognized command-line option %qs"
 msgstr "認識できないコマンドラインオプション %qs です"
@@ -26049,7 +26049,7 @@ msgstr "multilib spec %qs は無効です"
 msgid "multilib exclusions %qs is invalid"
 msgstr ""
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, fuzzy, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "multilib spec %qs は無効です"
@@ -26349,22 +26349,22 @@ msgstr "配列 %qE のサイズが負です"
 msgid "%qD specified bound %E equals source length"
 msgstr ""
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr "構造体の最後ではない所に可変配列メンバがあります"
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr ""
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s not supported for variable length aggregates"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s not supported on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
@@ -26405,16 +26405,16 @@ msgid "function returns address of local variable"
 msgstr "関数が局所変数のアドレスを返します"
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, gcc-internal-format
@@ -26426,355 +26426,355 @@ msgstr "ここで宣言されています"
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, fuzzy, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr "%qE への引数が少なすぎます"
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, fuzzy, gcc-internal-format
 msgid "referenced argument declared here"
 msgstr "%qD はここで宣言されています"
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, fuzzy, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "%qE への引数が少なすぎます"
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, fuzzy, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr "%s は [%d, %d] の範囲内の整数リテラルが予期されます"
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgid_plural "%qE output %wu bytes into a destination of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 msgid "%qE argument %Z overlaps destination object %qE"
 msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 msgid "%qE argument %Z may overlap destination object %qE"
 msgid_plural "%qE arguments %Z may overlap destination object %qE"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, gcc-internal-format
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, fuzzy, gcc-internal-format
 msgid "null destination pointer"
 msgstr "NULL ポインタ"
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, fuzzy, gcc-internal-format
 msgid "null format string"
 msgstr "フォーマット文字列が null です"
@@ -27513,12 +27513,12 @@ msgstr "無効なポインタモード %qs です"
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD はここで宣言されています"
@@ -28274,7 +28274,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "無効な %<auto%> の使用です"
@@ -28612,17 +28612,17 @@ msgstr "%qE がここでは宣言されていません (関数内ではない)"
 msgid "mismatching definition"
 msgstr "定義がありません"
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr ""
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, gcc-internal-format
 msgid "IPA modref summary is missing in input file"
 msgstr ""
@@ -29690,72 +29690,72 @@ msgstr "%s への書き込み中にエラーが発生しました: %m"
 msgid "error closing optimization records %qs"
 msgstr "ジャンプをまたがった最適化を行う"
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, fuzzy, gcc-internal-format
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "コマンドラインオプション %qs はこの設定ではサポートされていません"
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "%qs への引数がありません"
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr "%qs への引数は非負整数であるべきです"
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer"
 msgstr "%qs への引数は非負整数であるべきです"
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is not between %d and %d"
 msgstr "%sregparm=%d%s が 0 と %d の間ではありません"
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, fuzzy, gcc-internal-format
 msgid "invalid argument in option %qs"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, fuzzy, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr "%qE 属性は R8C ターゲット用にはサポートされていません"
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, fuzzy, gcc-internal-format
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr "-mcorea と -mcoreb は併用できません"
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, gcc-internal-format
 msgid "unrecognized argument in option %qs"
 msgstr "オプション %qs 内で認識できない引数です"
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "%qs スイッチは既にサポートされていません"
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is bigger than %d"
 msgstr "%qE 属性への引数が %d より大きいです"
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, fuzzy, gcc-internal-format
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
 msgstr "誤った形式の COLLECT_GCC_OPTIONS です"
@@ -29830,8 +29830,8 @@ msgstr "%qs への引数は非負整数であるべきです"
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with %qs"
 msgstr "RTP PIC は Thumb では使用できません"
@@ -30552,7 +30552,7 @@ msgstr "大域レジスタ変数が関数定義に続いてあります"
 msgid "register of %qD used for multiple global register variables"
 msgstr "レジスタが二つの大域レジスタ変数として使われました"
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "%q+D と型が競合しています"
@@ -31002,44 +31002,44 @@ msgstr ""
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "__builtin_saveregs はこのターゲットではサポートされていません"
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, fuzzy, gcc-internal-format
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, gcc-internal-format
 msgid "nested functions not supported on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, gcc-internal-format
 msgid "nested function trampolines not supported on this target"
 msgstr ""
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "大域コンストラクタはこのターゲットではサポートされていません"
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "大域デストラクタはこのターゲットではサポートされていません"
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute is not supported on this machine"
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "target 属性はこのマシン上ではサポートされていません"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute is not supported on this machine"
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "target 属性はこのマシン上ではサポートされていません"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC target%> is not supported for this machine"
 msgstr "#pragma GCC target はこのマシン用にはサポートされていません"
@@ -32157,83 +32157,83 @@ msgstr ""
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr "関数 %q+F は非局所 goto を受け取るため決して複製されません"
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr "関数 %q+F は静的変数内の局所ラベルのアドレスを保存するため、決して複写されません"
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr "関数 %q+F は alloca を使用しているため決してインライン化されません (always_inline 属性を上書きします)"
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr "関数 %q+F は setjmp を使用しているため決してインライン化されません"
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr "関数 %q+F は可変引数リストを使用しているため決してインライン化されません"
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr "関数 %q+F は setjmp-longjmp 例外処理を使用しているため決してインライン化されません"
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr "関数 %q+F は非局所 goto を使用しているため決してインライン化されません"
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, fuzzy, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr "関数 %q+F は __builtin_return または __builtin_apply_args を使用しているため決してインライン化されません"
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr ""
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr "関数 %q+F は可変引数リストを使用しているため決してインライン化されません"
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, fuzzy, gcc-internal-format
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr "関数 %q+F は -fno-inline を使用して抑止されているため決してインライン化されません"
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr "関数 %q+F はインライン化と競合する属性を使用しているため決してインライン化されません"
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, fuzzy, gcc-internal-format
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr "%q+F 呼び出しのインライン化に失敗しました: %s"
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr "ここから呼び出されました"
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, fuzzy, gcc-internal-format
 msgid "called from this function"
 msgstr "呼び出されたオブジェクト %qE は関数ではありません"
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, gcc-internal-format
 msgid "inlining failed in call to %q+F: %s"
 msgstr "%q+F 呼び出しのインライン化に失敗しました: %s"
@@ -32288,27 +32288,27 @@ msgstr "%qs 属性用の無効なエレメント型です"
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr "無効な %<auto%> の使用です"
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, fuzzy, gcc-internal-format
 msgid "in a call to non-static member function %qD"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, fuzzy, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "組み込み関数への無効な引数です"
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, fuzzy, gcc-internal-format
 msgid "in a call to function %qD declared %qs"
 msgstr "インライン関数 %q+D を弱いとして宣言できません"
@@ -32505,7 +32505,7 @@ msgstr "%qE は初期化されていません"
 msgid "%qs may be used uninitialized"
 msgstr "%qD はこの関数内初期化されずに使用されるかもしれません"
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD はここで定義されています"
@@ -32736,7 +32736,7 @@ msgstr ""
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -32751,127 +32751,127 @@ msgstr ""
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "関数の配列は意味がありません"
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "関数の返す型が関数であってはなりません"
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, fuzzy, gcc-internal-format
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr "RTL 検査: コード `%s' のはずなのに `%s' (%s 中)です (%s:%d)"
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, fuzzy, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr "RTL check: ベクトルの elt %d を最後の elt %d (%s 中)と一緒にアクセスします (%s:%d)"
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, fuzzy, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr "RTL check: ベクトルの elt %d を最後の elt %d (%s 中)と一緒にアクセスします (%s:%d)"
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, fuzzy, gcc-internal-format
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "RTL check: ベクトルの elt %d を最後の elt %d (%s 中)と一緒にアクセスします (%s:%d)"
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qE は廃止されました: %s"
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qE は廃止されました"
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE は廃止されました: %s"
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE は廃止されました"
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "型は廃止されました: %s"
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "型は廃止されました"
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is unavailable: %s"
 msgstr "%qD は変数ではありません"
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is unavailable"
 msgstr "%qD は変数ではありません"
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qE is unavailable: %s"
 msgstr "%qD は変数ではありません"
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qE is unavailable"
 msgstr "%qD は変数ではありません"
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type is deprecated: %s"
 msgid "type is unavailable: %s"
 msgstr "型は廃止されました: %s"
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "type is unavailable"
@@ -32897,263 +32897,263 @@ msgstr "%qD は変数ではありません"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, fuzzy, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qT is not a template type"
 msgid "type %s is not an opaque type"
 msgstr "%qT はテンプレート型ではありません"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is not with opaque mode"
 msgstr ""
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr ""
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr ""
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, fuzzy, gcc-internal-format
 msgid "main variant is not defined"
 msgstr "環境変数 %qs が定義されていません"
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, fuzzy, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "配列 %qE のサイズが非整数型です"
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "フィールド %qE が不完全型を持っています"
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -33369,7 +33369,7 @@ msgstr "この設定では別名定義はサポートされていません"
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "可視性属性はこの設定ではサポートされていません。無視されました"
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr ""
@@ -33573,7 +33573,7 @@ msgstr "%qE 属性は %qT が既に定義されているため無視されます
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "%qE 属性は %qT が既に定義されているため無視されます"
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE 属性は公開オブジェクトに関してのみ効果があります"
@@ -33758,7 +33758,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr "%qE 属性はユニット局所関数に関しては効果がありません"
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for local variables"
 msgstr "%qE 属性は局所変数用には指定できません"
@@ -34073,7 +34073,7 @@ msgstr "%qD は %qD 内では宣言されていません"
 msgid "%qE argument is not a function"
 msgstr "呼び出されたオブジェクトは関数ではありません"
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "廃止された (deprecated) メッセージが文字列ではありません"
@@ -34578,7 +34578,7 @@ msgstr "ISO C++ は名前つき戻り値を許可しません"
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, gcc-internal-format
 msgid "invalid application of %qs to a void type"
 msgstr "%qs をvoid 型へ適用することは無効です"
@@ -34709,17 +34709,17 @@ msgstr "仮引数 `%s' で指定された記憶クラス"
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "仮引数 `%s' で指定された記憶クラス"
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "関数 %qE へ渡す引数が少なすぎます"
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, gcc-internal-format
@@ -34843,166 +34843,166 @@ msgstr "ビットフィールドである構造体のメンバ %qD のアドレ
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "配列のサイズが大きすぎます"
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, fuzzy, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "%d 番目の %qE の引数用の互換性がない型です"
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, fuzzy, gcc-internal-format
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "%d 番目の %qE の引数へ渡すときに整数からキャスト無しにポインタを作成しています"
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, fuzzy, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr "型は全く互換がありません"
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "関数 %qE へ十分な引数がありません"
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "%d 番目の %qE の引数はアドレスでなければいけません"
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr "%K %D の第一引数がポインタ、第二引数が整数定数でなければいけません"
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "%K %D の第一引数がポインタ、第二引数が整数定数でなければいけません"
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "%K %D の第一引数がポインタ、第二引数が整数定数でなければいけません"
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "%d 番目の %qE の引数はアドレスでなければいけません"
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "%d 番目の %qE の引数は format 属性の候補のようです"
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "%d 番目の %qE の引数は %d の倍数でなければいけません"
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, fuzzy, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "引数 %d 個の `%s' を渡します"
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr "%d 番目の %qE の引数は format 属性の候補のようです"
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr "passing argument %d 番目の %qE の引数を渡すときにポインタからキャスト無しに整数を作成しています"
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr "%d 番目の %qE の引数は format 属性の候補のようです"
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr "passing argument %d 番目の %qE の引数を渡すときにポインタからキャスト無しに整数を作成しています"
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, fuzzy, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "%d 番目の %qE の引数用の互換性がない型です"
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "%d 番目の %qE の引数用の互換性がない型です"
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr ""
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, fuzzy, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "%qT から %qT への変換が曖昧です"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "組み込み関数 %qD は単一の引数をとります"
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, fuzzy, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr "定数式が欠けているか無効です"
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr "配列 %qE のサイズが負です"
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array is negative"
 msgstr "配列 `%s' の大きさが負です"
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "配列 %qE のサイズが負です"
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -35629,7 +35629,7 @@ msgstr "整数定数が %<unsigned long%> 型に対して大きすぎます"
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr "整数定数が %<unsigned long%> 型に対して大きすぎます"
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, fuzzy, gcc-internal-format
 msgid "%<_BitInt(%d)%> is not supported on this target"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
@@ -35710,7 +35710,7 @@ msgstr "サポートされていない非標準の文字列リテラルの連結
 msgid "traditional C rejects string constant concatenation"
 msgstr "伝統的な C では文字列定数の連結を拒否します"
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -35765,7 +35765,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "唯一の仮引数となる %<void%> には修飾子がつきません"
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -35780,17 +35780,17 @@ msgstr "%qs が自動変数 %qE 用に指定されています"
 msgid "%qE is not initialized"
 msgstr "%qE は初期化されていません"
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "増分式がありません"
@@ -35800,7 +35800,7 @@ msgstr "増分式がありません"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "無効な増分式です"
@@ -35887,7 +35887,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -35897,7 +35897,7 @@ msgstr ""
 msgid "%qD is not a function argument"
 msgstr "%qD は関数テンプレートではありません"
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
@@ -36495,7 +36495,7 @@ msgid "wrong type argument to %s"
 msgstr "%s への間違った型の引数です"
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -37414,35 +37414,35 @@ msgstr "%qT と %qT の比較です"
 
 #: c-family/c-warn.cc:3832
 #, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3836
+#: c-family/c-warn.cc:3839
 #, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr ""
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr ""
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr ""
@@ -37651,117 +37651,117 @@ msgstr "%sregparm=%d%s が 0 と %d の間ではありません"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr "%<-march=%s%> は選択した ABI とは互換性がありません"
 
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr "%<-mips3d%> は %<-mpaired-single%> が必要です"
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr "%<-mips3d%> は %<-mpaired-single%> が必要です"
 
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr "ビットフィールド命令を使用しない"
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr "-mcpu=%s が -march=%s と競合しています"
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr "-mcpu=%s が -march=%s と競合しています"
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "%<-march=%s%> は選択した ABI とは互換性がありません"
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr "%<-march=%s%> は選択した ABI とは互換性がありません"
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr "%<-march=%s%> は選択した ABI とは互換性がありません"
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, fuzzy, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "レジスタ '%c' が不明です"
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr ""
@@ -38166,12 +38166,12 @@ msgstr "式が予期されます"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "式が予期されます"
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC optimize%> が文字列または番号ではありません"
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, fuzzy, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "不明な #pragma GCC coprocessor %E です"
@@ -38774,7 +38774,7 @@ msgstr ""
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
@@ -38851,12 +38851,12 @@ msgid "unknown tuning option (%s)"
 msgstr "不明な spec 関数 %qs です"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
@@ -38867,7 +38867,7 @@ msgid "specify a system register with a small string length"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs は %qs 用には有効ではありません"
@@ -39047,9 +39047,9 @@ msgstr ""
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "attribute(target(\"%s\")) が不明です"
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "属性 %qE の引数が文字列ではありません"
@@ -39101,18 +39101,18 @@ msgid "virtual function multiversioning not supported"
 msgstr "静的リンクはサポートされていません"
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
@@ -39125,8 +39125,8 @@ msgstr ""
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, fuzzy, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "サポートされていない組み合わせです: %s"
@@ -39136,7 +39136,7 @@ msgstr "サポートされていない組み合わせです: %s"
 msgid "GCC does not currently support return type %qT for simd"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
@@ -39146,7 +39146,7 @@ msgstr ""
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "組み込み関数へのサポートされていない引数の型です"
@@ -39237,8 +39237,8 @@ msgstr "L%d キャッシュレイテンシは %s にとって不明です"
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "-mmemory-latency 用の間違った値 %qs です"
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr "間違った組み込み fcode です"
@@ -39358,18 +39358,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "%qE 属性の引数が \"ilink1\" または \"ilink2\" ではありません"
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -39483,7 +39483,7 @@ msgid "argument of %qE attribute is missing"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qE 属性は整数定数引数のみ許可されています"
@@ -39503,23 +39503,23 @@ msgstr "%qE 属性は関数型にのみ適用できます"
 msgid "argument of %qE attribute ignored"
 msgstr "%qE 属性は無視されました"
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "%qE は変数にのみ適用できます"
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, fuzzy, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr "不明な IRA アルゴリズム %qs です"
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, fuzzy, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "無効な被演算子出力コード"
@@ -39768,7 +39768,7 @@ msgstr "ターゲット CPU は Thumb 命令をサポートしていません"
 msgid "target CPU does not support unaligned accesses"
 msgstr "ターゲット CPU は ARM モードをサポートしていません"
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support branch-likely instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -39819,7 +39819,7 @@ msgstr "構造体サイズ境界は %s にのみ設定できます"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC は -msingle-pic-base と併用できません"
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
@@ -39928,7 +39928,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -39968,42 +39968,42 @@ msgstr "%qE 属性はユニット局所関数に関しては効果がありま
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qE 属性は関数型にのみ適用できます"
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "スタックに積まれた仮引数の実際の位置を計算できません"
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "高位レジスタを pop する為に使用できる低位レジスタがありません"
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, fuzzy, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "%qs 属性用の無効なベクトル型です"
@@ -40011,22 +40011,22 @@ msgstr "%qs 属性用の無効なベクトル型です"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, fuzzy, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "%qs 属性用の無効なベクトル型です"
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, fuzzy, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "target 属性または pragma が SPE ABI を変更します"
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
@@ -40080,159 +40080,159 @@ msgstr "不明なアーキテクチャ %qs です"
 msgid "unknown core architecture %qs specified with %qs"
 msgstr "不明なアーキテクチャ %qs です"
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, fuzzy, gcc-internal-format
 msgid "%<-fpic%> is not supported"
 msgstr "-fpic はサポートされていません"
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, fuzzy, gcc-internal-format
 msgid "%<-fPIC%> is not supported"
 msgstr "-fPIC はサポートされていません"
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, fuzzy, gcc-internal-format
 msgid "%<-fpie%> is not supported"
 msgstr "-fpic はサポートされていません"
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, fuzzy, gcc-internal-format
 msgid "%<-fPIE%> is not supported"
 msgstr "-fPIC はサポートされていません"
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-pedantic と -traditional とは相互排他的です"
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "割り込み関数は引数無しでなければいけません"
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "関数が __fp16 型を返しません"
 
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, fuzzy, gcc-internal-format
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs は綴りが間違ったシグナルハンドラのように見えます"
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, gcc-internal-format
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, fuzzy, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr "'builtin_return_address' がアドレスの 2 バイトのみ含んでいます"
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr "シンボルからのポインタオフセットが間違っているようです"
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr "プログラムメモリアドレスとしてデータメモリをアクセスしています"
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, fuzzy, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr "データメモリアドレスとしてプログラムメモリをアクセスしています"
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr "レジスタの数が整数を引数を渡すために使われる"
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, fuzzy, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "名前付きアドレス空間 (%s と %s) が競合しています"
 
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "%qE 属性は変数および関数へのみ適用できます"
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "%qE 属性は R8C ターゲット用にはサポートされていません"
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr "%qE 属性は効果がありません"
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "%qE は変数にのみ適用できます"
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr ""
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr ""
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr "%qE 属性は変数および関数へのみ適用できます"
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, fuzzy, gcc-internal-format
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, fuzzy, gcc-internal-format
 #| msgid "only uninitialized variables can be placed in the .noinit section"
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr "初期化されていない変数のみ .noinit セクション内に配置できます"
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr "初期化された変数のみプログラムメモリ領域内に配置できます"
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "初期化された変数のみプログラムメモリ領域内に配置できます"
@@ -40241,42 +40241,42 @@ msgstr "初期化された変数のみプログラムメモリ領域内に配置
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr "関数を inline にできません"
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, fuzzy, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "互換性がない %qE 属性は無視されました"
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, fuzzy, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr "MCU %qs はアセンブラのみ用にサポートされています"
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, fuzzy, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "NaN から整数への変換です"
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "文字列定数の中でファイルの終端を検出しました"
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%qs には定数引数が予期されます"
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -40416,7 +40416,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, gcc-internal-format
@@ -41045,8 +41045,8 @@ msgstr "最後の引数の前の引数は 8 ビット即値でなければいけ
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "コードモデル %s は PIC モードをサポートしません"
@@ -41112,255 +41112,255 @@ msgstr "%qs にクラス名が指定されていません"
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "不明なレジスタ名です: %s"
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64 ビット ABI は ESA/390 モード内ではサポートされていません"
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%stune=x86-64%s は廃止されました。代わりに %stune=k8%s または %stune=generic%s の適切な方を使用してください"
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%stune=x86-64%s は廃止されました。代わりに %stune=k8%s または %stune=generic%s の適切な方を使用してください"
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, fuzzy, gcc-internal-format
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "-mcmodel= は 32 ビットシステム上ではサポートされていません"
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, fuzzy, gcc-internal-format
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr "-mcmodel= は 32 ビットシステム上ではサポートされていません"
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, fuzzy, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mcmodel= は 32 ビットシステム上ではサポートされていません"
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, fuzzy, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "-mcmodel= は 32 ビットシステム上ではサポートされていません"
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "-mg でのプロファイルはサポートされていません"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, fuzzy, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-m%s はこの設定ではサポートされていません"
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i ビットモードが使用できるようにコンパイルされていません"
 
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "選択した CPU は x86-64 命令セットをサポートしていません"
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "-mcmodel= スイッチ用の誤った値 %s です"
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "-mcmodel= スイッチ用の誤った値 %s です"
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "-mtune スイッチ用の間違った値 %qs です"
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "-mtune スイッチ用の間違った値 %qs です"
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "%sregparm%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "%sregparm%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "%sregparm=%d%s が 0 と %d の間ではありません"
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, fuzzy, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, fuzzy, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr ""
@@ -41368,290 +41368,290 @@ msgstr ""
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr ""
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "%spreferred-stack-boundary%s はこのターゲットではサポートされていません"
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s が %d と %d の間ではありません"
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, fuzzy, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d が %d と 12 の間ではありません"
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "ret 命令は実装されていません"
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, fuzzy, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparm%s が SSE が有効ではない状態で使用されています"
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparm%s が SSE が有効ではない状態で使用されています"
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 命令セットが無効になっています。 387 数値演算を使用します"
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 命令セットが無効になっています。SSE 数値演算を使用します"
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, fuzzy, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "-mrecip=%s 用の不明なオプションです"
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs は前処理の有効なオプションではありません"
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs は前処理の有効なオプションではありません"
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs は前処理の有効なオプションではありません"
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr ""
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, fuzzy, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, fuzzy, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall と cdecl 属性は併用できません"
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "ms_abi と sysv_abi 属性は互換性がありません"
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, fuzzy, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, fuzzy, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, fuzzy, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, fuzzy, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "2 バイト cop 命令は 64 ビット VLIW モードでは許可されていません"
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "2 バイト cop 命令は 64 ビット VLIW モードでは許可されていません"
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "2 バイト cop 命令は 64 ビット VLIW モードでは許可されていません"
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall と regparm 属性は併用できません"
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam と thiscall 属性は併用できません"
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE 属性には整数定数引数が必要です"
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qE 属性への引数が %d より大きいです"
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall と cdecl 属性は併用できません"
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall と stdcall 属性は併用できません"
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall と thiscall 属性は併用できません"
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall と cdecl 属性は併用できません"
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall と fastcall 属性は併用できません"
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall と thiscall 属性は併用できません"
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl と thiscall 属性は併用できません"
 
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE 属性が非クラスメソッド用に使用されています"
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "互換性がない %qE 属性は無視されました"
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE 属性は 32 ビットでのみ使用できます"
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE 属性は文字列定数引数を必要とします"
 
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
@@ -41846,47 +41846,47 @@ msgstr ""
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "被演算子コード '%c' に無効な被演算子型が使用されました"
 
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, fuzzy, gcc-internal-format
 #| msgid "no low registers available for popping high registers"
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr "高位レジスタを pop する為に使用できる低位レジスタがありません"
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, fuzzy, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "-mcmodel= は 32 ビットシステム上ではサポートされていません"
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr ""
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "不明なアーキテクチャ %qs です"
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, fuzzy, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr "-mno-fentry は SEH と互換性がありません"
@@ -41907,8 +41907,8 @@ msgstr ""
 msgid "malformed %<#pragma builtin%>"
 msgstr "間違った形式の #pragma builtin です"
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, gcc-internal-format
 msgid "invalid argument of %qE attribute"
 msgstr "%qE 属性の無効な引数です"
@@ -41966,12 +41966,12 @@ msgstr "PRINT_OPERAND: 不明な句読点 '%c'"
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr "PRINT_OPERAND NULL ポインタ"
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "%d 番目の %qE の引数は %d...%d の範囲でなければいけません"
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, fuzzy, gcc-internal-format
 msgid "failed to expand built-in function"
 msgstr "組み込み関数を認識する"
@@ -42098,19 +42098,19 @@ msgstr "%qD は %qD 内では宣言されていません"
 msgid "%qs cannot be used for compiling a shared library"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr "%qE 属性は局所変数用には指定できません"
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for register variables"
 msgstr "%qE 属性は局所変数用には指定できません"
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, fuzzy, gcc-internal-format
 msgid "multiple %qE attribute"
 msgstr "定義の後で `%s' 属性をセットすることはできません"
@@ -42216,12 +42216,12 @@ msgstr "複数の割り込み属性は許可されていません"
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr "interrupt_thread は fido 上でのみ使用出来ます"
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "スタック制限式はサポートされていません"
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, fuzzy, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not supported on this target"
 msgstr "-fstack-protector はこのターゲットではサポートされていません"
@@ -42262,7 +42262,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr "-mxl-multiply-high は -mno-xl-soft-mul が必要です"
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "%qE 属性は文字列定数引数を必要とします"
@@ -42303,133 +42303,133 @@ msgstr ""
 msgid "argument to %qE attribute is not intstack"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, gcc-internal-format
 msgid "cannot handle inconsistent calls to %qs"
 msgstr "一貫していない %qs への呼び出しを取り扱えません"
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, fuzzy, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr "%<interrupt%> 属性は MIPS32r2 プロセッサが必要です"
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr "割り込みハンドラが MIPS16 関数ではいけません"
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr ""
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, gcc-internal-format
 msgid "built-in function %qE not supported for MIPS16"
 msgstr "組み込み関数 %qE は MIPS16 用にはサポートされていません"
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, gcc-internal-format
 msgid "%qs does not support MIPS16 code"
 msgstr "%qs は MIPS16 コードをサポートしません"
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr ""
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, gcc-internal-format
 msgid "MIPS16 %<-mxgot%> code"
 msgstr ""
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, gcc-internal-format
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr ""
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, fuzzy, gcc-internal-format
 msgid "MSA MIPS16 code"
 msgstr "MIPS16 コードを生成する"
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr "%<-mno-gpopt%> は %<-mexplicit-relocs%> が必要です"
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported combination: %s"
 msgstr "サポートされていない組み合わせです: %s"
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, gcc-internal-format
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr ""
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, gcc-internal-format
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr "%<-march=%s%> は選択した ABI とは互換性がありません"
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr "%<-mgp64%> が 32 ビットプロセッサで使用されています"
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, gcc-internal-format
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr "%<-mgp32%> が 64 ビット ABI で使用されています"
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr "%<-mgp64%> が 32 ビット ABI で使用されています"
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "%qs アーキテクチャは synci 命令をサポートしていません"
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr "%<-mgp32%> と %<-mfp64%> はターゲットが mfhc1 と mthc1 命令をサポートしている時のみ組み合わせることができます"
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr "%<-mgp32%> と %<-mfp64%> は o32 ABI を使用している時のみ組み合わせることができます"
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, fuzzy, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr "%<-mgp32%> と %<-mfp64%> は o32 ABI を使用している時のみ組み合わせることができます"
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr "%<-mips3d%> は %<-mpaired-single%> が必要です"
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, fuzzy, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr "%<-mips3d%> は %<-mpaired-single%> が必要です"
@@ -42439,117 +42439,117 @@ msgstr "%<-mips3d%> は %<-mpaired-single%> が必要です"
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, gcc-internal-format
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, gcc-internal-format
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr "%qs アーキテクチャは branch-likely 命令をサポートしていません"
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr "%qs アーキテクチャは synci 命令をサポートしていません"
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr "%qs アーキテクチャは paired-single 命令をサポートしていません"
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, fuzzy, gcc-internal-format
 msgid "unsupported combination: %qs%s %s"
 msgstr "サポートされていない組み合わせです: %s"
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, fuzzy, gcc-internal-format
 msgid "unsupported combination: %qs %s"
 msgstr "サポートされていない組み合わせです: %s"
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, fuzzy, gcc-internal-format
 msgid "cannot generate position-independent code for %qs"
 msgstr "可能であれば位置非依存コードを生成する (large モード)"
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, fuzzy, gcc-internal-format
 msgid "position-independent code requires %qs"
 msgstr "OS カーネルコード内で使用するために位置非依存コード (PIC) を無効にする"
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr "%<-mno-gpopt%> は %<-mexplicit-relocs%> が必要です"
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr "%qs アーキテクチャは paired-single 命令をサポートしていません"
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr "%qs アーキテクチャは synci 命令をサポートしていません"
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, gcc-internal-format
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr "%<-mips3d%> は %<-mpaired-single%> が必要です"
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, gcc-internal-format
 msgid "%qs must be used with %qs"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, gcc-internal-format
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr ""
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, gcc-internal-format
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr "%qs アーキテクチャは paired-single 命令をサポートしていません"
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr "%qs はターゲットが %qs 命令を提供していることが必要となります"
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support DSP instructions"
 msgstr "%qs アーキテクチャは synci 命令をサポートしていません"
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, gcc-internal-format
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr ""
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, gcc-internal-format
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr ""
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, gcc-internal-format
 msgid "%qs requires branch-likely instructions"
 msgstr "%qs は branch-likely 命令が必要となります"
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, gcc-internal-format
 msgid "the %qs architecture does not support the synci instruction"
 msgstr "%qs アーキテクチャは synci 命令をサポートしていません"
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr "mips16 関数プロファイル"
@@ -43425,58 +43425,58 @@ msgstr "%<#pragma GCC optimize%> が文字列または番号ではありませ
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "不明な #pragma GCC coprocessor %E です"
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, gcc-internal-format
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, gcc-internal-format
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute is not supported on this machine"
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr "target 属性はこのマシン上ではサポートされていません"
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> attribute"
 msgstr "間違った形式の %<#pragma init%> です"
 
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%qE 属性は文字列定数引数を必要とします"
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, fuzzy, gcc-internal-format
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr "attribute(target(\"%s\")) が不明です"
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> attribute"
 msgstr "間違った形式の %<#pragma init%> です"
@@ -43537,175 +43537,195 @@ msgstr ""
 msgid "capture by copy of RVV type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, fuzzy, gcc-internal-format
 msgid "no matching function call to %qE with empty arguments"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, fuzzy, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "-mfpu 用の不明な値 %s です"
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, fuzzy, gcc-internal-format
 msgid "this operation requires the RVV ISA extension"
 msgstr "ビットフィールド命令を使用しない"
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, fuzzy, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, fuzzy, gcc-internal-format
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました"
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the V ISA extension"
 msgstr "ビットフィールド命令を使用しない"
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr "ビットフィールド命令を使用しない"
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr "ビットフィールド命令を使用しない"
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr "ビットフィールド命令を使用しない"
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr "ビットフィールド命令を使用しない"
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr ""
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, fuzzy, gcc-internal-format
 msgid "function attribute %qs requires the V ISA extension"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr ""
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, fuzzy, gcc-internal-format
 msgid "%qs applied to non-RVV type %qT"
 msgstr "%qE 属性は非クラス型に関しては無視されます"
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires an integer constant argument"
 msgid "%qs requires an integer constant"
 msgstr "%qE 属性には整数定数引数が必要です"
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support ARM mode"
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr "ターゲット CPU は ARM モードをサポートしていません"
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs with %qs"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, gcc-internal-format
 msgid "rv64e requires lp64e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr ""
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s が %d と %d の間ではありません"
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "割り込み関数は引数無しでなければいけません"
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr ""
@@ -43957,32 +43977,32 @@ msgstr "%s は 2 この引数のみ受け付けます"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s は 2 この引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr "passing argument %d 番目の %qE の引数を渡すときにポインタからキャスト無しに整数を作成しています"
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, gcc-internal-format
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%s はこの設定ではサポートされていません"
@@ -44022,29 +44042,22 @@ msgstr "二項演算子 %s が不適切です"
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, fuzzy, gcc-internal-format
-msgid "%qs requires the ELFv2 ABI"
-msgstr "EABI を使用する"
-
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "スタックフレームが大きすぎます"
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported number of nops before function entry (%u)"
 msgstr "関数 %qE へ十分な引数がありません"
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, fuzzy, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "レジスタ r2 と r5 を使用する"
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, fuzzy, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "#pragma GCC target はこのマシン用にはサポートされていません"
@@ -44169,108 +44182,118 @@ msgstr "%qs を呼び出しで使用されるレジスタとして使用でき
 msgid "unknown option for %<%s=%s%>"
 msgstr "-mrecip=%s 用の不明なオプションです"
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4837
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4855
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "`this' は右辺値式であり、そのアドレスを取ることはできません"
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "AltiVec 型内での %<long double%> の使用は無効です"
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "AltiVec 型内での真偽型 (boolean) の使用は無効です"
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "AltiVec 型内での %<complex%> の使用は無効です"
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, fuzzy, gcc-internal-format
 #| msgid "use of decimal floating point types in AltiVec types is invalid"
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "AltiVec 型内での十進浮動小数点の使用は無効です"
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "-mvsx 無しで 64 ビットコード用の AltiVec 型内での %<long%> の使用は無効です"
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "AltiVec 型内での %<long%> の使用は廃止されました。%<int%> を使用してください"
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "-mvsx 無しで AltiVec 型内での %<long long%> の使用は無効です"
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, fuzzy, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "-mvsx 無しで AltiVec 型内での %<double%> の使用は無効です"
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "CPU \"%s\" は %s\"%s\"%s 用には無効です"
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s は許可されていません"
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s は無効です"
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "静的リンクはサポートされていません"
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
@@ -44315,7 +44338,7 @@ msgstr "RX FPU 命令は NaNs と無限大をサポートしません"
 msgid "builtin %qs can only be used on vector types"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -44385,228 +44408,228 @@ msgstr "%qE は廃止されました"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "%qs 用の定数引数が範囲外です"
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr "%qs 用の定数引数が範囲外です"
 
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr "%qs 用の定数引数が範囲外です"
 
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr "%qs 用の定数引数が範囲外です"
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, fuzzy, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr "%qE は %qs (%qs 用) として前もって決められています"
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, fuzzy, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher"
 msgstr "%qE は %qs (%qs 用) として前もって決められています"
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, fuzzy, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher"
 msgstr "%qE は %qs (%qs 用) として前もって決められています"
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, fuzzy, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "<未解決オーバーロードされた関数型>"
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, fuzzy, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "間違った組み込みコードです"
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "組み込み関数への無効な引数です"
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "局所変数の合計サイズがアーキテクチャの制限を超過しています"
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr ""
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr ""
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "%qs のフレームサイズ: "
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs は動的スタック割り当てを使用します"
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, fuzzy, gcc-internal-format
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, fuzzy, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64 ビット ABI は ESA/390 モード内ではサポートされていません"
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "ハードウェア十進浮動小数点命令は %s 上では使用出来ません"
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, fuzzy, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "ハードウェア十進浮動小数点命令は %s 上では使用出来ません"
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr "ハードウェア十進浮動小数点命令は %s 上では使用出来ません"
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, fuzzy, gcc-internal-format
 #| msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr "ハードウェア十進浮動小数点命令は ESA/390 モードでは使用出来ません"
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, fuzzy, gcc-internal-format
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr "-mhard-dfp は -msoft-float と併用できません"
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, fuzzy, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float の組み合わせはサポートされていません"
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "スタックサイズは 64k より大きくてはいけません"
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, fuzzy, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard は -mstack-size を暗黙的に使用します"
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%qE 属性は SH2A 用にのみサポートされています"
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "%qs への引数は非負整数であるべきです"
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%qE 属性への引数が %d より大きいです"
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr "attribute(target(\"%s\")) が不明です"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "このターゲットでは %<__int128%> はサポートされていません"
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, fuzzy, gcc-internal-format
 #| msgid "invalid fp constant"
 msgid "invalid cc output constraint: %qs"
 msgstr "無効な浮動小数点定数です"
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, fuzzy, gcc-internal-format
 msgid "multiple cc output constraints not supported"
 msgstr "-mhard-float はサポートされていません"
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, gcc-internal-format
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr ""
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, fuzzy, gcc-internal-format
 msgid "invalid type for cc output constraint"
 msgstr "コンストラクタの静的メンバ初期化子は無効です"
@@ -45048,8 +45071,8 @@ msgstr "%qE 属性は効果がありません"
 msgid "attribute %qs applies to array types only"
 msgstr "%qs 属性は配列型のみに適用できます"
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void の値が本来の意味通りに無視されませんでした"
@@ -45125,7 +45148,7 @@ msgstr ""
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr ""
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "元々はここで定義されました"
@@ -45358,7 +45381,7 @@ msgstr "%q+D の宣言は前の非変数を隠します"
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "`%s' の宣言はグローバル宣言を覆い隠します"
@@ -45368,7 +45391,7 @@ msgstr "`%s' の宣言はグローバル宣言を覆い隠します"
 msgid "declaration of %qD shadows a previous local"
 msgstr "`%s' の宣言は前方のローカルシンボルを覆い隠します"
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "隠された宣言はここです"
@@ -45433,7 +45456,7 @@ msgstr "%qE が宣言されていません (この関数内での最初の使用
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "未宣言の識別子は出現した各関数内で一回のみ報告されます"
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "ラベル %qE があらゆる関数の外側から参照されました"
@@ -45468,7 +45491,7 @@ msgstr ""
 msgid "duplicate label declaration %qE"
 msgstr "重複したラベルの宣言 %qE です"
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "重複したラベル %qD です"
@@ -45503,7 +45526,7 @@ msgstr ""
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE が誤った種類のタグとして宣言されました"
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "%qE 属性は関数型にのみ適用できます"
@@ -45650,12 +45673,12 @@ msgstr "ISO C90 は %<[*]%> 配列宣言をサポートしません"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> は関数プロトタイプスコープ以外では許可されていません"
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, fuzzy, gcc-internal-format
 msgid "%<omp::%s%> not allowed to be specified in this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
@@ -45665,7 +45688,7 @@ msgstr "マクロ引数内でディレクトリを使うことはできません
 msgid "%q+D is usually a function"
 msgstr "%q+D は通常は関数です"
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "前に %qD 用の定義がありません"
@@ -45741,7 +45764,7 @@ msgstr "volatile フィールドがあるオブジェクトをレジスタに配
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "初期化されていない定数 %qD は C++ 内では無効です"
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -45928,7 +45951,7 @@ msgstr "仮引数 %qE 用に記憶域クラスが指定されました"
 msgid "storage class specified for unnamed parameter"
 msgstr "無名仮引数用に記憶域クラスが指定されました"
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "型名用に記憶域クラスが指定されました"
@@ -45991,7 +46014,7 @@ msgstr "関数の配列としての %qE の宣言です"
 msgid "declaration of type name as array of functions"
 msgstr "関数の配列としての型名の宣言です"
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr ""
@@ -46097,7 +46120,7 @@ msgstr "型名は配列を返す関数として定義されています"
 msgid "function definition has qualified void return type"
 msgstr "関数定義が void 戻り型の修飾子を持っています"
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "関数戻り値の型修飾子は無視されました"
@@ -46224,7 +46247,7 @@ msgstr "ISO C は const や volatile の関数型を禁止しています"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "構造体または共用体のメンバは可変型を持つことは出来ません"
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "変数またはフィールド %qE が void と宣言されています"
@@ -46331,7 +46354,7 @@ msgstr "可変型の入れ子になっていない関数です"
 msgid "object with variably modified type must have no linkage"
 msgstr "可変型のオブジェクトはリンクされてはいけません"
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "関数宣言がプロトタイプではありません"
@@ -46421,18 +46444,18 @@ msgstr "%<union %E%> の入れ子になった再定義です"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "%<struct %E%> の入れ子になった再定義です"
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "%qs 式内での型定義は C++ では無効です"
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids specifying subobject to initialize"
 msgid "%qT defined in underspecified object initializer"
 msgstr "ISO C90 は初期化用に副オブジェクトを指定することを禁止してます"
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "宣言が何も宣言していません"
@@ -46462,604 +46485,604 @@ msgstr ""
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "共用体に名前付きメンバがありません"
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "共用体にメンバがありません"
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "構造体に名前付きメンバがありません"
 
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "構造体にメンバがありません"
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "共用体に可変配列メンバがあります"
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "構造体の最後ではない所に可変配列メンバがあります"
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "共用体に可変配列メンバがあります"
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr "構造体の最後ではない所に可変配列メンバがあります"
 
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "配列 %qE のサイズが大きすぎます"
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, fuzzy, gcc-internal-format
 msgid "type punning toggles scalar storage order"
 msgstr "認識できないレジスタ名 %qs です"
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "共用体を透過的にできません"
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, fuzzy, gcc-internal-format
 #| msgid "a member of a structure or union cannot have a variably modified type"
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr "構造体または共用体のメンバは可変型を持つことは出来ません"
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %<struct %E%>"
 msgid "redefinition of struct or union %qT"
 msgstr "%<struct %E%> の再定義です"
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "%<enum %E%> の入れ子になった再定義です"
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%> の再定義です"
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, fuzzy, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "指定したモードは列挙値用には小さすぎます"
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "列挙値が整数の範囲の最大値を超えました"
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration values exceed range of largest integer"
 msgid "enumeration values exceed range of %qs"
 msgstr "列挙値が整数の範囲の最大値を超えました"
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of %<enum %E%>"
 msgid "conflicting redefinition of enum %qT"
 msgstr "%<enum %E%> の入れ子になった再定義です"
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "%qE 用の列挙値が整数定数ではありません"
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "%qE の列挙値が整数定数式ではありません"
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "列挙値がオーバーフローしました"
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, fuzzy, gcc-internal-format
 msgid "enumerator value outside the range of underlying type"
 msgstr "%qE 用の列挙値が整数定数ではありません"
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, fuzzy, gcc-internal-format
 msgid "enumerator value outside the range of %qs"
 msgstr "%qE 用の列挙値が整数定数ではありません"
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr "ISO C は列挙値を %<int%> の範囲に制限しています"
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "非インライン (noinline) 属性が与えられたインライン関数 %qD です"
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "戻り値の型が不完全型です"
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "戻り値の型をデフォルトの %<int%> にします"
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, fuzzy, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "プロトタイプ無しの大域関数に関して警告する"
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "前に %qD 用のプロトタイプがありません"
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD がプロトタイプ無しで、定義される前に使用されました"
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD はその定義の前で宣言しないで使用されました"
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "%qD の戻り型が %<int%> ではありません"
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD は通常は非静的関数です。"
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "プロトタイプ関数宣言内で古いスタイルの仮引数宣言です"
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "伝統的な C では ISO C スタイルの関数定義は拒否されます"
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr "ISO C は十進浮動小数点をサポートしません"
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "古いスタイルの関数定義です"
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "仮引数リストに仮引数名がありません"
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD は非仮引数として宣言されています"
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "複数の仮引数が %qD という名前です"
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "仮引数 %qD が void 型で宣言されています"
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "%qD の型をデフォルトの %<int%> にします"
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "仮引数 %qD が不完全型を持っています"
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "仮引数 %qD 用の宣言がありますが、そのような仮引数はありません"
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "引数の数が組み込みプロトタイプと一致しません"
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "引数の数がプロトタイプと一致しません"
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "プロトタイプ宣言です"
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "引数 %qD が組み込みプロトタイプと一致しません"
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "引数 %qD がプロトタイプと一致しません"
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "非 void を戻す関数内に return 文がありません"
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "仮引数 %qD が設定されましたが使用されません"
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> ループ初期化宣言は C99 モード内でのみ許可されています"
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, fuzzy, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "オプション -std=c99 または -std=gnu99 をコードコンパイル時に使用してください"
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 は %<[*]%> 配列宣言をサポートしません"
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "静的変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> が %<for%> ループ初期化宣言内で宣言されています"
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> が %<for%> ループ初期化宣言内で宣言されています"
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> が %<for%> ループ初期化宣言内で宣言されています"
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "非変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "互換性のないアドレス空間修飾子 %qs と %qs です"
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "宣言指定が予期されます"
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "宣言指定内に複数の記憶域クラスがあります"
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %<auto%>"
 msgstr "%<__thread%> が %<auto%> と併せて使用されています"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> used with %<constexpr%>"
 msgstr "%<__thread%> が %<register%> と併せて使用されています"
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "宣言指定内に二個またはそれ以上の型があります"
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> は GCC にとって長すぎます"
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 は %<long long%> をサポートしません"
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 は複素数型をサポートしません"
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr ""
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE が重複しています"
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C は %<__int128%> 型をサポートしません"
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 は複素数型をサポートしません"
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr "ISO C は %<__int128%> 型をサポートしません"
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr "ISO C は十進浮動小数点をサポートしません"
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "固定小数点型はこのターゲットではサポートされていません"
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C は固定小数点型をサポートしません"
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, fuzzy, gcc-internal-format
 #| msgid "case label is not an integer constant expression"
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr "case ラベルは整数定数式に出来ません"
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant expression"
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr "%qE の列挙値が整数定数式ではありません"
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr ""
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE は宣言の開始ではありません"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> が %<auto%> と併せて使用されています"
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> が %<register%> と併せて使用されています"
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> が %<typedef%> と併せて使用されています"
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<constexpr%>"
 msgstr "%<__thread%> が %<register%> と併せて使用されています"
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "%s は %s をサポートしません"
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 は %<long long%> をサポートしません"
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> が %<extern%> の前にあります"
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> が %<static%> の前にあります"
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> used with %<auto%>"
 msgstr "%<__thread%> が %<auto%> と併せて使用されています"
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<extern%>"
 msgstr "%<__thread%> が %<register%> と併せて使用されています"
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %qs"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> used with %qE"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> が %<_Fract%> または %<_Accum%> 無しで使用されています"
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C は単なる %<complex%> を %<double complex%> を意味するものとしてはサポートしません"
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr "ISO C90 は %<[*]%> 配列宣言をサポートしません"
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C は複素整数型をサポートしません"
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, fuzzy, gcc-internal-format
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr "%q+D 用の整列は最低 %d でなければいけません"
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr "ISO C++ は %<__int128%> を %qs に対してはサポートしていません"
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, fuzzy, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "左シフト回数が負です"
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "左シフト回数が負です"
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "右シフト回数が負です"
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "左シフト回数 >= 型の幅となっています"
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "右シフト回数 >= 型の幅となっています"
@@ -47089,7 +47112,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "行末 (EOL) が予期されます"
@@ -47099,8 +47122,8 @@ msgstr "行末 (EOL) が予期されます"
 msgid "ISO C forbids an empty translation unit"
 msgstr ""
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr ""
@@ -47140,9 +47163,9 @@ msgstr "不明な型名 %qE です"
 msgid "unknown type name %qE"
 msgstr "不明な型名 %qE です"
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "宣言指定が予期されます"
@@ -47172,7 +47195,7 @@ msgstr "getter/setter 属性は後に %<=%> が無ければいけません"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>、識別子または %<(%> が予期されます"
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -47192,7 +47215,7 @@ msgstr "packed 属性は必要ありません"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "getter/setter 属性は後に %<=%> が無ければいけません"
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, fuzzy, gcc-internal-format
 msgid "%<assume%> attribute not followed by %<;%>"
 msgstr "getter/setter 属性は後に %<=%> が無ければいけません"
@@ -47283,7 +47306,7 @@ msgstr "静的アサーション内の式が定数ではありません"
 msgid "static assertion failed: %E"
 msgstr "静的アサーションに失敗しました: %E"
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, fuzzy, gcc-internal-format
 msgid "static assertion failed"
 msgstr "静的アサーションに失敗しました: %E"
@@ -47354,10 +47377,10 @@ msgstr "マクロ引数 \"%s\" は文字列化されます"
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "識別子が予期されます"
@@ -47511,7 +47534,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr ""
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr ""
@@ -47521,8 +47544,8 @@ msgstr ""
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, fuzzy, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs attribute argument"
 msgstr "認識できないアドレス"
@@ -47696,12 +47719,12 @@ msgstr "ISO C は中間項が省略された ?: 式を禁じます"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, fuzzy, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "フィールドの型はここで宣言されました"
@@ -47851,7 +47874,7 @@ msgstr "ISO C は %<__int128%> 型をサポートしません"
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, gcc-internal-format
 msgid "expected expression"
 msgstr "式が予期されます"
@@ -48173,12 +48196,12 @@ msgstr "objective-c メソッド定義が予期されます"
 msgid "no type or storage class may be specified here,"
 msgstr "型または記憶域クラスがここで指定されていません、"
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, fuzzy, gcc-internal-format
 msgid "empty property attribute list"
 msgstr "不明な property 属性です"
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, fuzzy, gcc-internal-format
 msgid "missing property attribute"
 msgstr "不明な property 属性です"
@@ -48188,57 +48211,57 @@ msgstr "不明な property 属性です"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "不明な property 属性です"
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不明な property 属性です"
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "Objective-C 文字列の前に連続した %<@%> があります"
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, fuzzy, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr "クラス名が予期されます"
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, fuzzy, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr "setter 名は %<:%> で終端されなければいけません"
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr ""
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> は複合文内でのみ使用できます"
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma GCC pch_preprocess%> は最初に無ければいけません"
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp taskwait%> は複合文内でのみ使用できます"
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -48248,25 +48271,25 @@ msgstr ""
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr "%<#pragma GCC pch_preprocess%> は最初に無ければいけません"
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for 文が予期されます"
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> は最初に無ければいけません"
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "%qs 句が多すぎます"
@@ -48281,63 +48304,63 @@ msgstr "添え字は整数でなければいけません"
 msgid "expected %<)%> or %<,%>"
 msgstr "%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD は変数ではありません"
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD は変数ではありません"
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> または %<shared%> が予期されます"
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr "%<#pragma omp section%> または %<}%> が予期されます"
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, fuzzy, gcc-internal-format
 msgid "expected constant logical expression"
 msgstr "式が予期されます"
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<catch%> が予期されます"
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -48360,22 +48383,22 @@ msgstr "%<num_threads%> 値は正でなければいけません"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, fuzzy, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "整数式が予期されます"
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, fuzzy, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
@@ -48385,95 +48408,95 @@ msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, fuzzy, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, fuzzy, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "引数が多すぎます"
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "packed 属性は必要ありません"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, fuzzy, gcc-internal-format
 msgid "too many %<self%> clauses"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr "%<none%> または %<shared%> が予期されます"
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, fuzzy, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "%<using%> が予期されます"
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, fuzzy, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "整数 0 とポインタとの順序比較です"
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>、%<*%>、%<-%>、%<&%>、%<^%>、%<|%>、%<&&%> または %<||%> が予期されます"
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "スケジュール %<runtime%> は %<chunk_size%> 仮引数をとりません"
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "スケジュール %<auto%> は %<chunk_size%> 仮引数をとりません"
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "`無効なスケジュールの種類です"
@@ -48483,22 +48506,22 @@ msgstr "`無効なスケジュールの種類です"
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr ""
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, fuzzy, gcc-internal-format
 msgid "expected %<allocator%> or %<align%>"
 msgstr "%<operator%> が予期されます"
@@ -48508,22 +48531,22 @@ msgstr "%<operator%> が予期されます"
 msgid "duplicate %qs modifier"
 msgstr "`%s' が重複しています"
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, fuzzy, gcc-internal-format
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr "整数 0 とポインタとの順序比較です"
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, fuzzy, gcc-internal-format
 msgid "multiple linear modifiers"
 msgstr "重複する `virtual' 指定子"
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, fuzzy, gcc-internal-format
 msgid "multiple %<step%> modifiers"
 msgstr "重複する `virtual' 指定子"
@@ -48543,62 +48566,62 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, fuzzy, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "RTP PIC は Thumb では使用できません"
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "`無効なスケジュールの種類です"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, fuzzy, gcc-internal-format
 msgid "invalid doacross kind"
 msgstr "無効なマスクです"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, fuzzy, gcc-internal-format
 msgid "too many %<always%> modifiers"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, fuzzy, gcc-internal-format
 msgid "too many %<close%> modifiers"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, fuzzy, gcc-internal-format
 msgid "too many %<present%> modifiers"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "無効なマスクです"
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr ""
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, fuzzy, gcc-internal-format
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr "%<none%> または %<shared%> が予期されます"
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, gcc-internal-format
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr ""
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "`無効なスケジュールの種類です"
@@ -48613,88 +48636,88 @@ msgstr "`無効なスケジュールの種類です"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, fuzzy, gcc-internal-format
 msgid "expected an OpenACC clause"
 msgstr "ポインタが予期されます"
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, fuzzy, gcc-internal-format
 msgid "expected an OpenMP clause"
 msgstr "ポインタが予期されます"
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "セクション属性は `%s' には使えません"
 
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "ファイルスコープの可変フィールドです"
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<#pragma message%> の後に文字列が予期されます"
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr ""
@@ -48709,7 +48732,7 @@ msgstr ""
 msgid "expected function name"
 msgstr "関数が予期されます"
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "メンバ関数の名前を欠いています"
@@ -48719,22 +48742,22 @@ msgstr "メンバ関数の名前を欠いています"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
@@ -48759,7 +48782,7 @@ msgstr ""
 msgid "modified here"
 msgstr "共用体がここで定義されています"
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, fuzzy, gcc-internal-format
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
 msgstr "整数 0 とポインタとの順序比較です"
@@ -48799,112 +48822,112 @@ msgstr ""
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr "--driver は最早サポートされません"
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, fuzzy, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "%<+%>、%<*%>、%<-%>、%<&%>、%<^%>、%<|%>、%<&&%> または %<||%> が予期されます"
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, fuzzy, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, fuzzy, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, fuzzy, gcc-internal-format
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr "RTP PIC は Thumb では使用できません"
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, fuzzy, gcc-internal-format
 msgid "%qs clause requires %qs clause"
 msgstr "%qE は %qs (%qs 用) として前もって決められています"
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after union definition"
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr "共用体定義の後には %<;%> が予期されます"
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, gcc-internal-format
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr ""
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr "%<#pragma omp atomic%> 用の無効な演算子です"
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<delete%>"
 msgid "unexpected %<else%>"
 msgstr "%<delete%> が予期されます"
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr "%<#pragma omp atomic%> 用の無効な演算子です"
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%> 用の無効な演算子です"
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%> 用の無効な演算子です"
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr ""
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "初期化子の要素が定数式ではありません"
@@ -48914,27 +48937,27 @@ msgstr "初期化子の要素が定数式ではありません"
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr ""
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, fuzzy, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, fuzzy, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, fuzzy, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -48944,164 +48967,164 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> またはファイル終端 (EOF) が予期されます"
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr "%<#pragma omp flush%> は複合文内でのみ使用できます"
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, fuzzy, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "%<none%> または %<shared%> が予期されます"
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<#pragma omp%> 句が予期されます"
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr "%<#pragma omp flush%> は複合文内でのみ使用できます"
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, fuzzy, gcc-internal-format
 #| msgid "not enough perfectly nested loops"
 msgid "not enough nested loops"
 msgstr "ループが完全な入れ子になっていません"
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "for 文が予期されます"
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> は複合文内でのみ使用できます"
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<operator%> が予期されます"
 
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<using%> が予期されます"
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, fuzzy, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "クラス名が予期されます"
 
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, fuzzy, gcc-internal-format
 msgid "unknown selector %qs for context selector set %qs"
 msgstr "不明な演算子 %qs が %%:version-compare 内にあります"
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, fuzzy, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "%s は 2 この引数のみ受け付けます"
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, gcc-internal-format
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr ""
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, fuzzy, gcc-internal-format
 msgid "%<score%> argument must be constant integer expression"
 msgstr "整数 0 とポインタとの順序比較です"
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, fuzzy, gcc-internal-format
 msgid "%<score%> argument must be non-negative"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, fuzzy, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "文字列リテラルが予期されます"
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
@@ -49109,292 +49132,292 @@ msgstr ""
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> selector is not supported yet"
 msgstr "%qs スイッチは既にサポートされていません"
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, fuzzy, gcc-internal-format
 msgid "expected context selector set name"
 msgstr "クラス名が予期されます"
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, fuzzy, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "%<catch%> が予期されます"
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, fuzzy, gcc-internal-format
 msgid "variant %qD is not a function"
 msgstr "呼び出されたオブジェクトは関数ではありません"
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "-f%s と -msdata=%s は併用できません"
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, fuzzy, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, gcc-internal-format
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<try%> が予期されます"
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr "%<#pragma GCC pop_options%> に対応した %<#pragma GCC push_options%> がありません"
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr ""
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, gcc-internal-format
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr ""
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%> or %<assumes%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, gcc-internal-format
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, fuzzy, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "前方での `%s' の宣言"
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, fuzzy, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr "%<(%> またはファイル終端 (EOF) が予期されます"
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, fuzzy, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "関数が予期されます"
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%<#pragma omp section%> または %<}%> が予期されます"
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, fuzzy, gcc-internal-format
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, fuzzy, gcc-internal-format
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr "可変長配列が使用されています"
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, fuzzy, gcc-internal-format
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "可変長配列が使用されています"
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, fuzzy, gcc-internal-format
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %qs or %qs"
 msgstr "%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> は複合文内でのみ使用できます"
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, fuzzy, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr "--driver は最早サポートされません"
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, fuzzy, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr "--driver は最早サポートされません"
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, fuzzy, gcc-internal-format
 msgid "expected at least one assumption clause"
 msgstr "代入として無効な左辺値です"
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, fuzzy, gcc-internal-format
 msgid "expected directive name"
 msgstr "関数が予期されます"
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr ""
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, fuzzy, gcc-internal-format
 #| msgid "unknown spec function %qs"
 msgid "unknown assumption clause %qs"
 msgstr "不明な spec 関数 %qs です"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, fuzzy, gcc-internal-format
 msgid "expected assumption clause"
 msgstr "ポインタが予期されます"
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE は最初に使用した後に %<threadprivate%> と宣言されています"
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自動変数 %qE は %<threadprivate%> になることは出来ません"
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE は不完全型を持っています"
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, gcc-internal-format
 msgid "no closing brace"
 msgstr ""
@@ -49535,7 +49558,7 @@ msgstr "%<void *%> ポインタの参照を解除しています"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "添字が付けられた値が、配列、ポインタまたはベクトルではありません"
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "配列の添字が整数型ではありません"
@@ -49565,7 +49588,7 @@ msgstr "%qE は初期化されていません"
 msgid "enum constant defined here"
 msgstr "列挙型定数がここで定義されています"
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -49678,17 +49701,17 @@ msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "関数 %qE へ渡す引数が少なすぎます"
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "文字列リテラルの比較結果は不定です"
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, fuzzy, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "ポインタと整数との比較を行なっています"
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr ""
@@ -49713,7 +49736,7 @@ msgstr "関数ポインタの差を求めようとしています"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "不完全型へのポインタに関する計算です"
 
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "不完全型へのポインタに関する計算です"
@@ -50008,7 +50031,7 @@ msgstr "ポインタから異なるサイズの整数へのキャストです"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "型 %qT の関数呼び出しから一致しない型 %qT へのキャストです"
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "異なるサイズの整数からポインタへのキャストです"
@@ -50180,7 +50203,7 @@ msgstr "左辺への代入は format 属性の候補のようです"
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "左辺の初期化は format 属性の候補のようです"
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "戻り型は format 属性の候補のようです"
@@ -50382,12 +50405,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "可変配列メンバを初期化しています"
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, fuzzy, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "互換性のないポインタ型からの初期化です"
@@ -50397,7 +50420,7 @@ msgstr "互換性のないポインタ型からの初期化です"
 msgid "array of inappropriate type initialized from string constant"
 msgstr "適切でない型の配列が文字列定数で初期化されています"
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "非左辺値配列の無効な使用です"
@@ -50428,7 +50451,7 @@ msgstr "初期化子の要素が定数式ではありません"
 msgid "initializer element is not computable at load time"
 msgstr "初期化子の要素がロード時に計算出来ません"
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
@@ -50443,7 +50466,7 @@ msgstr "初期化子の終わりに余分なブレースのグループ"
 msgid "braces around scalar initializer"
 msgstr "スカラー初期化子が中括弧で囲まれています"
 
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "入れ子になったコンテキスト内で可変配列メンバを初期化しています"
@@ -50534,7 +50557,7 @@ msgstr "構造体初期化子内の要素が多すぎます"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
@@ -50574,7 +50597,7 @@ msgstr "ISO C は %<goto *expr;%> を禁止しています"
 msgid "computed goto must be pointer type"
 msgstr "%d 番目の %qE の引数はアドレスでなければいけません"
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%> と宣言されている関数が %<return%> 文を持っています"
@@ -50629,7 +50652,7 @@ msgstr "switch 文の外にある %<default%> ラベルです"
 msgid "break statement not within loop or switch"
 msgstr "ループまたは switch 文の外にある break 文です"
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -50675,27 +50698,27 @@ msgstr ""
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr ""
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "異なる列挙型の比較に関して警告する"
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "結果の数が異なります"
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "型 %qT と %qT の間での比較です"
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, fuzzy, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "浮動小数点の比較で == や != を使うのは安全ではありません"
@@ -50767,29 +50790,29 @@ msgstr "スカラーが必要な場所で共用体型の値が使用されてい
 msgid "used vector type where scalar is required"
 msgstr "スカラーが必要な場所で構造体型の値が使用されています"
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, fuzzy, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
@@ -50800,85 +50823,85 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%qs 句が多すぎます"
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, fuzzy, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, fuzzy, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "代入として無効な左辺値です"
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "セクション属性は `%s' には使えません"
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, fuzzy, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "可変長配列が使用されています"
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, fuzzy, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
@@ -50888,17 +50911,17 @@ msgstr "ベクトル型の delete ですが、ポインタでも配列型でも
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "ISO C は関数型の修飾子を禁止しています"
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr "仮引数 %qD が不完全型を持っています"
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, fuzzy, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "非整数型のビットフィールド %qD です"
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
@@ -50908,32 +50931,32 @@ msgstr ""
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, fuzzy, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr "読み取り専用変数 %qD の増分です"
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, fuzzy, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr "読み取り専用変数 %qD の増分です"
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, fuzzy, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr "初期化子は `%s' のサイズの特定に失敗しました"
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, fuzzy, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr "ポインタが予期されます"
 
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr ""
@@ -50963,7 +50986,7 @@ msgstr "可変長配列 %qE が使用されています"
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE は %<reduction(%s)%> 用の無効な型を持っています"
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -50973,17 +50996,17 @@ msgstr ""
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "可変長配列が使用されています"
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE は %<threadprivate%> (%<copyin%> 用として) でなければいけません"
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
 msgstr ""
@@ -50998,24 +51021,24 @@ msgstr ""
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
@@ -51027,32 +51050,32 @@ msgstr "%qE がデータ句内で二回以上出現しています"
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, fuzzy, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE は %<firstprivate%> 句内では変数ではありません"
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE は %<lastprivate%> 句内では変数ではありません"
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
@@ -51072,7 +51095,7 @@ msgstr ""
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
@@ -51082,7 +51105,7 @@ msgstr "%qE は句 %qs 内では変数ではありません"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
@@ -51092,76 +51115,76 @@ msgstr "%qE は句 %qs 内では変数ではありません"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr ""
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, fuzzy, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, fuzzy, gcc-internal-format
 msgid "unsupported map expression %qE"
 msgstr "固定小数変換内で無効な型です"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
@@ -51176,22 +51199,22 @@ msgstr "ソースはポインタではありません"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE は %qs (%qs 用) として前もって決められています"
@@ -51201,38 +51224,38 @@ msgstr "%qE は %qs (%qs 用) として前もって決められています"
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
@@ -51501,13 +51524,13 @@ msgstr "第 %d 引数を %qT から %qT へ変換する方法が不明です"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "第 %d 引数を %qT から %qT へ変換する方法が不明です"
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  候補では %d 個の引数が予期されますが、%d 個の引数が与えられています"
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -51819,568 +51842,568 @@ msgstr "型が全く異なるポインタの比較でキャストを欠いてい
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "条件式内でポインタ型と整数型が適合しません"
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "%qD の戻り型が %<int%> ではありません"
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "%q#T と %q#T の間での比較です"
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to %<(%T) (%A)%>"
 msgid "no match for call to %<%T::operator[] (%A)%>"
 msgstr "%<(%T) (%A)%> への呼び出しが適合しません"
 
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, fuzzy, gcc-internal-format
 #| msgid "call of %<(%T) (%A)%> is ambiguous"
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr "%<(%T) (%A)%> の呼び出しが曖昧です"
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD は通常は非静的関数です。"
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD は通常は非静的関数です。"
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr ""
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "%<operator %s%> は %qT 用としては適切ではありません"
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, fuzzy, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "ここで宣言されています"
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "ここで宣言されています"
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, fuzzy, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D はアクセス出来ません"
 
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, fuzzy, gcc-internal-format
 msgid "  declared here"
 msgstr "ここで宣言されています"
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "NULL から非ポインタ型 %qT へ変換しています"
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "NULL から非ポインタ型へ変換しています"
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr ""
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, fuzzy, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "%qT 用の初期化子の周りに中括弧が多すぎます"
 
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 #, fuzzy
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr ""
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "%qT から %qT への無効な変換です"
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 #, fuzzy
 msgid "invalid conversion from %qH to %qI"
 msgstr "%qT から %qT への無効な変換です"
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, fuzzy, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "`explicit' にできるのは、コンストラクタだけです"
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "参照を参照として宣言できません"
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr "参照を参照として宣言できません"
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "参照を参照として宣言できません"
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 #, fuzzy
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "参照を参照として宣言できません"
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 #, fuzzy
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "参照を参照として宣言できません"
 
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "ビットフィールド %qD を関数型として宣言できません"
 
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "参照を参照として宣言できません"
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "関数呼び出しの引数が format 属性の候補であるようです"
 
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr ""
 
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, fuzzy, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, fuzzy, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "代わりに #include を使用してください"
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "可変配列メンバを初期化しています"
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, fuzzy, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, fuzzy, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr "代わりに #include を使用してください"
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, fuzzy, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "可変配列メンバを初期化しています"
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, fuzzy, gcc-internal-format
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr "不完全型への変換です"
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "定数が自身を参照しています"
 
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 #, fuzzy
 msgid "cannot convert %qH to %qI"
 msgstr "型 %qT から型 %qT へ変換できません"
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "非関数 %qD の呼び出しです"
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "コンストラクタ %<%T::%D%> を直接呼び出すことは出来ません"
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "オーバーロードされた %<%s(%A)%> の呼び出しは曖昧です"
 
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "コンストラクタから値を返そうとしています"
 
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "デストラクタから値を返そうとしています"
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "オブジェクト以外がメンバ関数 %qD を呼び出すことは出来ません"
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, gcc-internal-format
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr ""
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, fuzzy, gcc-internal-format
 msgid "try making the operator a %<const%> member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 #, fuzzy
 msgid "  for conversion from %qH to %qI"
 msgstr "%q#T から %q#T への変換です"
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " 候補 1: %q+#F"
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " 候補 2: %q+#F"
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "無効なバージョン番号形式"
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "possibly dangling reference to a temporary"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr ""
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, gcc-internal-format
 msgid "explicit conversion function was not considered"
 msgstr ""
@@ -52426,7 +52449,7 @@ msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D はオーバーロードすることが出来ません"
 
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "前方での `%s' の宣言"
@@ -52848,7 +52871,7 @@ msgstr "構造体に可変配列メンバ以外のメンバがありません"
 msgid "next member %q#D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T が再定義されています"
@@ -52980,7 +53003,7 @@ msgstr "関数 `%s' に対して不適切な保存クラス"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
@@ -53021,7 +53044,7 @@ msgstr ""
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr ""
@@ -53039,7 +53062,7 @@ msgstr ""
 msgid "%q+E is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -53060,7 +53083,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
@@ -53107,7 +53130,7 @@ msgstr "%s に `%s' という名前のメンバはありません"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -53236,18 +53259,18 @@ msgstr "配列の添字が配列境界の外にあります"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "初期化子を欠いています"
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> ポインタの参照を解除しています"
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -53255,470 +53278,470 @@ msgstr "%<void *%> ポインタの参照を解除しています"
 msgid "%qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD は定数式で初期化されませんでした"
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "初期化子を欠いています"
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, fuzzy, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "初期化子を欠いています"
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, fuzzy, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, fuzzy, gcc-internal-format
 msgid "allocated here"
 msgstr "ここで宣言されています"
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
 msgstr ""
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "%qD は定数式で初期化されませんでした"
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qE は初期化されていません"
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D は const ではありません"
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D は volatile です"
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD は定数式で初期化されませんでした"
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, fuzzy, gcc-internal-format
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, fuzzy, gcc-internal-format
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr ""
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr ""
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, fuzzy, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "use of %qD"
 msgstr "無効な %qD の使用です"
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr ""
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr ""
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr ""
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr ""
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, fuzzy, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr "%q+D が再定義されました"
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, fuzzy, gcc-internal-format
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "%q+D が再定義されました"
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, fuzzy, gcc-internal-format
 msgid "pointed-to object declared here"
 msgstr "フィールドの型はここで宣言されました"
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, fuzzy, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "%<template%> が予期されます"
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "組み込み関数 %qD は単一の引数をとります"
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, fuzzy, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "`%s' はその定義の前にプロトタイプなしで使われました"
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, fuzzy, gcc-internal-format
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%qE の列挙値が整数定数式ではありません"
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, fuzzy, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, fuzzy, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "仮想関数は friend にできません"
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "%qE は最初に使用した後に %<threadprivate%> と宣言されています"
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "%q+F が %<static%> と宣言されましたが定義されていません"
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, fuzzy, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "初期化子内に非定数の配列インデックスがあります"
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, fuzzy, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "ファイル \"%s\" に戻るはずでした"
@@ -54449,7 +54472,7 @@ msgstr "%<__builtin_prefetch%> への第三引数は定数でなければいけ
 msgid "no suspend point info for %qD"
 msgstr "前に %qD 用のプロトタイプがありません"
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -54471,23 +54494,23 @@ msgstr "case の値としてポインタは許可されていません"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, fuzzy, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr "参照を参照として宣言できません"
@@ -54508,69 +54531,69 @@ msgstr ""
 msgid "%qD was promoted to an immediate function"
 msgstr "%qD はテンプレート関数ではありません"
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, fuzzy, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, fuzzy, gcc-internal-format
 msgid "call to consteval function %qE is not a constant expression"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, fuzzy, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, fuzzy, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qE attribute"
 msgid "pack expansion of %qE attribute"
 msgstr "%qE 属性の無効な引数です"
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, fuzzy, gcc-internal-format
 msgid "use fold expression in the attribute argument instead"
 msgstr "マクロ引数リストにあり得ないトークン"
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%s は型 %s ではありません (引数 %d)"
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
@@ -54615,7 +54638,7 @@ msgstr ""
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "%qT から %qT への変換が曖昧です"
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -55002,7 +55025,7 @@ msgstr "前方での `%s' の宣言"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "使用している宣言 %q+D は前に使用している宣言と競合しています"
 
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "前方での `%s' の宣言"
@@ -55143,8 +55166,8 @@ msgstr "前方での `%s' の暗黙的な宣言"
 msgid "%q#D previously defined here"
 msgstr "前はここで定義されました"
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, fuzzy, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "前はここで宣言されました"
@@ -55220,53 +55243,38 @@ msgstr ""
 msgid "previous specification in %q#D here"
 msgstr "前の %q+D の宣言はここです"
 
-#: cp/decl.cc:2285
-#, fuzzy, gcc-internal-format
-msgid "declaration %qD conflicts with builtin"
-msgstr "%q+D のセクションが前の宣言と競合しています"
-
-#: cp/decl.cc:2288
-#, fuzzy, gcc-internal-format
-msgid "declaration %qD conflicts with import"
-msgstr "%q+D のセクションが前の宣言と競合しています"
-
-#: cp/decl.cc:2289
-#, fuzzy, gcc-internal-format
-msgid "import declared %q#D here"
-msgstr "%qD はここで宣言されています"
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, fuzzy, gcc-internal-format
 msgid "conflicting exporting for declaration %qD"
 msgstr "無効な宣言です"
 
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared here without exporting"
 msgstr "前はここで宣言されました"
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "前の %q+D の宣言はここです"
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "前の %q+D の宣言はここです"
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr ""
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, fuzzy, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr "%q+D が再定義されました"
@@ -55279,44 +55287,44 @@ msgstr "%q+D が再定義されました"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr ""
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%q+D のデータ領域が前の宣言と競合しています"
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr ""
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr ""
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr ""
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -55324,2503 +55332,2503 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr ""
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "%q+D の冗長な再宣言です"
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, fuzzy, gcc-internal-format
 msgid "previous label"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, gcc-internal-format
 msgid "jump to label %qD"
 msgstr ""
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr "case ラベルにジャンプしています"
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr ""
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  ここから"
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, fuzzy, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr "  try ブロックに入ります"
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, fuzzy, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "  catch ブロックに入ります"
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, fuzzy, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  try ブロックに入ります"
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, fuzzy, gcc-internal-format
 #| msgid "missing increment expression"
 msgid "  enters statement expression"
 msgstr "増分式がありません"
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, fuzzy, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "文が予期されます"
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, fuzzy, gcc-internal-format
 msgid "  enters %<consteval if%> statement"
 msgstr "文が予期されます"
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, fuzzy, gcc-internal-format
 msgid "  does not destroy %qD"
 msgstr "%s は %s をサポートしません"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, gcc-internal-format
 msgid "  does not clean up handled exception"
 msgstr ""
 
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "非テンプレート %qD がテンプレートとして使用されています"
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is a function, not a type"
 msgstr "%qD は関数テンプレートではありません"
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr ""
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "不明な型名 %qE です"
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr ""
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "仮引数 `%s' の型が宣言されていません"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, fuzzy, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "要求された整列が 2 の累乗ではありません"
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D は無効です。無名共用体は非静的データメンバのみ持つことが出来ます"
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous struct not inside named type"
 msgid "anonymous struct with base classes"
 msgstr "無名構造体が名前つき型の中にありません"
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "一つの宣言に複数の型があります"
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "`enum %s' の再宣言"
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, fuzzy, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typdef 宣言で型名を欠いています"
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ は無名構造体を禁止しています"
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr ""
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, fuzzy, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, fuzzy, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%s に対する記憶クラス指定子 `%s'"
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "`%s' の宣言で型がデフォルトの `int' とされました"
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef `%s' が初期化されました"
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "`%s' の宣言に `extern' がついており、初期化もされています"
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "初期化された変数 `%s' は dllimport マークされています"
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D のテンプレート宣言です"
 
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "ポインタ宣言子に不適切な型修飾子"
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "重複した初期化子"
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr ""
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "変数 `%s' には初期化子がありますが、不完全型です"
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "配列 `%s' の要素に不完全型があります"
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, fuzzy, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "仮引数 `%s' は不完全型です"
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr ""
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "自明でないラベルのついた初期化子です"
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "初期化子は `%s' のサイズの特定に失敗しました"
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "`%s' での配列サイズを欠いています"
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, fuzzy, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "未初期化定数を ROM に置かない"
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "初期化された変数 %q+D は dllimport とマークされています"
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "無効なビット列初期化子です"
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, fuzzy, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "無名基底クラスの初期設定子が曖昧です"
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "要求されたメンバ `%s' は多重継承グラフの中で曖昧です"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "無効な初期化子です"
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "入力ファイルが多すぎます"
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "スカラー初期化子がブレースで囲まれています"
 
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, fuzzy, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "スカラー初期化子がブレースで囲まれています"
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "初期化子のまわりのブレースを欠いています"
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "ソースは不完全型へのポインタです"
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "配列 `%s' の要素に不完全型があります"
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ISO C89 は複合リテラルを禁じます"
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "`%s' は不完全型です"
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, fuzzy, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "共用体初期化子内の要素が多すぎます"
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, fuzzy, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "_Pramga が括弧で囲まれた文字列リテラルを受け取りました"
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "コンストラクタの静的メンバ初期化子は無効です"
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(クラス外での初期化を必要とします)"
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "仮引数 %qD が初期化されます"
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "宣言内にない %<[*]%> です"
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, fuzzy, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "%qs に対して記憶域クラスが指定されています"
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "`%s' の宣言に `extern' がついており、初期化もされています"
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, fuzzy, gcc-internal-format
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "戻り値の型が不完全型です"
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, fuzzy, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "可変長オブジェクトが初期化されないようです"
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qE 属性は変数および関数へのみ適用できます"
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, fuzzy, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "関数 `%s' が変数であるかのように初期化されました"
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "ソースは不完全型へのポインタです"
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 は可変長の配列 %qE を禁止しています"
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs が構造体フィールド用に指定されています"
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "定数式が欠けているか無効です"
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "ソースは不完全型へのポインタです"
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "%<offsetof%> を静的データメンバ %qD へ適用できません"
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初期化子は `%s' のサイズの特定に失敗しました"
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "`%s' での配列サイズを欠いています"
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, fuzzy, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "他のクラス `%s' のデストラクタを、メンバにはできません"
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, fuzzy, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "他のクラス `%s' のデストラクタを、メンバにはできません"
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD は非仮引数として宣言されています"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "仮引数 %qD が void 型で宣言されています"
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java メソッド %qD が非 Java 戻り型 %qT を持ちます"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "共用体定義の後には %<;%> が予期されます"
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, fuzzy, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "共用体を透過的にできません"
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "%qD はテンプレート関数ではありません"
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "constrained non-template friend declaration must be a definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, fuzzy, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "`::main' を template としては宣言できません"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "`::main' を inline としては宣言できません"
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, fuzzy, gcc-internal-format
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr "静的メンバ %qD はビットフィールドに出来ません"
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "静的メンバ %qD はビットフィールドに出来ません"
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, fuzzy, gcc-internal-format
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr "静的メンバ %qD はビットフィールドに出来ません"
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, fuzzy, gcc-internal-format
 msgid "explicit object parameter declared here"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qs は -mcpu= への引数としては無効です"
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, fuzzy, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "`main' は `int' を返さなければなりません"
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "typedef %q+D が再定義されました"
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "メンバ関数へのポインタが呼ばれましたが、クラススコープ内ではありません"
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "`::main' を template としては宣言できません"
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "自動変数 %qE は %<threadprivate%> になることは出来ません"
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, fuzzy, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr "%s=%s は数値ではありません"
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, fuzzy, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "可変長オブジェクトが初期化されないようです"
 
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, fuzzy, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "定数式が欠けているか無効です"
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C89 は可変長サイズの配列 `%s' を禁じます"
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C89 は可変長サイズの配列 `%s' を禁じます"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "可変長配列が使用されています"
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "配列の次元がオーバーフローしました"
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, fuzzy, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "`%s' の宣言は void の配列"
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "`%s' の宣言は void の配列"
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "配列参照での添字を欠いています"
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable-length array of %<auto%>"
 msgstr "可変長配列が使用されています"
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, fuzzy, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, fuzzy, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, fuzzy, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD の宣言内でテンプレート仮引数リストが多すぎます"
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "無名変数やフィールドが void と宣言されました"
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "変数またはフィールドが void と宣言されました"
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, fuzzy, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%s=%s は数値ではありません"
 
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, fuzzy, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "関数の定義が `register' と宣言されました"
 
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "宣言内にない %<[*]%> です"
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C は単なる %<complex%> を %<double complex%> を意味するものとしてはサポートしません"
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ では型の無い %qs の宣言を禁止しています"
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "このターゲットでは %<__int128%> はサポートされていません"
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ は %<__int128%> を %qs に対してはサポートしていません"
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> と %<unsigned%> が %qs に対して両方指定されています"
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> および %<short%> が %qs に対して両方指定されています"
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with typedef-name %qD"
 msgstr "%<__thread%> が %<typedef%> と併せて使用されています"
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%<__thread%> が %<typedef%> と併せて使用されています"
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> が %<typedef%> と併せて使用されています"
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex は %qs に対しては無効です"
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, fuzzy, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "仮引数宣言の中の typedef 宣言は無効です"
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "仮引数 `%s' で指定された記憶クラス"
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "仮引数 %qs に対して記憶域クラスタ指定されています"
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "仮引数は %<constexpr%> として宣言してはいけません"
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> がクラス宣言外で使用されています"
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "無効な宣言です"
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs の宣言内に複数の記憶域クラスがあります"
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "%qs に対して記憶域クラスが指定されています"
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, fuzzy, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "ネストした関数 `%s' は `extern' に宣言されました"
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, fuzzy, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "`%s' のトップレベルの宣言が `auto' を指定します"
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "friend 関数宣言内の記憶クラス指定子は無効です"
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored"
 msgstr "%qE 属性は無視されました"
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs の宣言内に複数の記憶域クラスがあります"
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr ""
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, fuzzy, gcc-internal-format
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, fuzzy, gcc-internal-format
 msgid "a function type cannot have an explicit object parameter"
 msgstr "関数を inline にできません"
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, gcc-internal-format
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, fuzzy, gcc-internal-format
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr "静的メンバ %qD はビットフィールドに出来ません"
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr ""
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, fuzzy, gcc-internal-format
 msgid "the type of an explicit object member function is a regular function type"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, fuzzy, gcc-internal-format
 msgid "valid explicit object parameter declared here"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "仮想関数は friend にできません"
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "%<restrict%> の誤った使用法です"
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, fuzzy, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "関数戻り値の型修飾子は無視されました"
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "`%s' は関数を返す関数として宣言されています"
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "`%s' は配列を返す関数として宣言されています"
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "仮想関数は friend にできません"
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, fuzzy, gcc-internal-format
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, fuzzy, gcc-internal-format
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr "静的メンバ %qD はビットフィールドに出来ません"
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be an explicit object member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, fuzzy, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "デストラクタは仮引数を取りません"
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "参照を参照として宣言できません"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "メンバ関数は暗黙的にそのクラスの friend です"
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "オブジェクト以外がメンバ関数 %qD を呼び出すことは出来ません"
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> がクラス宣言外で使用されています"
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "空の宣言内に %<inline%> があります"
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, fuzzy, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "`explicit' にできるのは、コンストラクタだけです"
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, fuzzy, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非オブジェクトメンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "static `%s' を mutable として宣言できません"
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "const `%s' を `mutable' として宣言できません"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "宣言内にない %<[*]%> です"
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "クラス宣言の外側で virtual 指定しています"
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "複雑なパラメタをもつ関数は inline にできません"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, fuzzy, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "クラス `%s' を大域スコープの friend にしようとしています"
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, fuzzy, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "`%s' の宣言はグローバル宣言を覆い隠します"
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "`enum %s' の再宣言"
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "仮引数宣言の中で `::' を使えません"
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, fuzzy, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr "%qD は関数テンプレートではありません"
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "無効なデフォルトテンプレート引数"
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "無効な用法の of %%d, %%x, 又は %%X"
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "%s: 関数 `%s' の宣言が変換されていません\n"
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%s を開けません"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "変数 %qD が関数として再宣言されました"
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "元の型はここで宣言されました"
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "領域 `%s' は不完全な型です"
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "仮引数が不完全型です"
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "`%s' は関数でもメンバ関数でもありません -- friend とは宣言できません"
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, fuzzy, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "`%s' は関数でもメンバ関数でもありません -- friend とは宣言できません"
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "仮引数 %q+D が %<inline%> と宣言されています"
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "関数を inline にできません"
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "非オブジェクトメンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `register' は無効です"
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr "関数 %qD への代入です"
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "初期化子リストは非メンバ関数では使えません"
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, fuzzy, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtual な非クラス関数 `%s'"
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "他の関数内で static 関数を宣言できません"
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "仮引数は %<constexpr%> として宣言してはいけません"
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, fuzzy, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "`%s' が初期化されるところで、`extern' 宣言されました"
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, fuzzy, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "関数がローカル変数のアドレスを返しています"
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "関数がローカル変数のアドレスを返しています"
 
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "仮引数宣言の中で `::' を使えません"
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "仮引数 `%s' は無効です"
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "パラメタはメソッドの型を不正に宣言しました"
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, fuzzy, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ は無名構造体を禁止しています"
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "%qD の無効なテンプレート宣言です"
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -57832,116 +57840,101 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, fuzzy, gcc-internal-format
 #| msgid "function template %qD redeclared as a class template"
 msgid "class template %qD redeclared as non-template"
 msgstr "関数テンプレート %qD がクラステンプレートとして再定義されました"
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "事前の宣言なしの大域関数に関して警告する"
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, fuzzy, gcc-internal-format
-msgid "cannot declare %qD in a different module"
-msgstr "%qD をビットフィールド型として宣言できません"
-
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, gcc-internal-format
-msgid "previously declared here"
-msgstr "前はここで宣言されました"
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "型修飾子 `%s' は struct や class の後には使えません"
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重複した case の値"
 
-#: cp/decl.cc:16984
-#, fuzzy, gcc-internal-format
-msgid "cannot declare %qD in different module"
-msgstr "%qD をビットフィールド型として宣言できません"
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "`%s' は前にここで定義されました"
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "述語は識別子でなければなりません"
@@ -57950,82 +57943,82 @@ msgstr "述語は識別子でなければなりません"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "`%s' の列挙値が整数定数ではありません"
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "`%s' の列挙値が整数定数ではありません"
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "整数定数が %<unsigned long%> 型に対して大きすぎます"
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C は列挙値を %<int%> の範囲に制限しています"
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "列挙値がオーバーフロー"
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "%qE 用の列挙値が整数定数ではありません"
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T が複数定義されています"
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "戻り値の型が不完全型です"
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "非 void を戻す関数内に return 文がありません"
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "関数の戻り型は %<volatile%> と互換性がありません"
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, fuzzy, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "非 void を戻す関数内に return 文がありません"
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, fuzzy, gcc-internal-format
 msgid "using %qs"
 msgstr "%s を閉じているときにエラーが発生しました: %m"
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "%qD の型をデフォルトの %<int%> にします"
@@ -58080,7 +58073,7 @@ msgstr "関数を削除 (delete) できません。%<delete%> の有効な引数
 msgid "deleting %qT is undefined"
 msgstr "%qT の削除は定義されていません"
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D のテンプレート宣言です"
@@ -58090,7 +58083,7 @@ msgstr "%q#D のテンプレート宣言です"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr ""
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "デストラクタ %qD がメンバテンプレートとして宣言されています"
@@ -58274,64 +58267,64 @@ msgstr ""
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "`operator delete' は第一引数として `void *' 型をとります"
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, fuzzy, gcc-internal-format
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, gcc-internal-format
 msgid "%qT has a base %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, gcc-internal-format
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, gcc-internal-format
 msgid "%qT has a base %qT which has internal linkage"
 msgstr ""
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, gcc-internal-format
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr "`%s' が `static' と宣言されましたが未定義です"
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but not defined"
 msgstr "`%s' が `static' と宣言されましたが未定義です"
@@ -58340,104 +58333,104 @@ msgstr "`%s' が `static' と宣言されましたが未定義です"
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "`%s' が `static' と宣言されましたが未定義です"
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr "`%s' が `static' と宣言されましたが未定義です"
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q+D のセクションが前の宣言と競合しています"
 
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, fuzzy, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, gcc-internal-format
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "`%s' が使われましたが未定義です"
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q#D"
 msgstr "仮引数リストからの仮引数名を欠いています"
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, fuzzy, gcc-internal-format
 msgid "...following parameter %P which has a default argument"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, fuzzy, gcc-internal-format
 msgid "implicitly-declared %qD is deprecated"
 msgstr "%qE は廃止されました"
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, fuzzy, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -58542,7 +58535,7 @@ msgstr ""
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
@@ -58552,7 +58545,7 @@ msgstr "%s に `%s' という名前のメンバはありません"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%s に `%s' という名前のメンバはありません"
@@ -58577,47 +58570,47 @@ msgstr "例外処理を無効にしました. 有効にするには -fexceptions
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr ""
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, gcc-internal-format
 msgid "  in thrown expression"
 msgstr "  throw された式の中"
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, gcc-internal-format
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr ""
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, gcc-internal-format
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr ""
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, gcc-internal-format
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr ""
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, fuzzy, gcc-internal-format
 msgid "for type %qT"
 msgstr "%q+D と型が競合しています"
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, gcc-internal-format
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr ""
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr ""
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
 msgstr ""
@@ -58884,12 +58877,12 @@ msgstr ""
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "クラスタイプ項を欠いています"
@@ -58904,12 +58897,12 @@ msgstr ""
 msgid "invalid pointer to bit-field %qD"
 msgstr "二項演算子 %s が不適切です"
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
@@ -59104,52 +59097,52 @@ msgstr ""
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, fuzzy, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr "複合リテラルが可変サイズを持っています"
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, fuzzy, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "%s を参照として宣言できません"
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr ""
@@ -59521,228 +59514,273 @@ msgstr "式が予期されます"
 msgid "encapsulation is malformed"
 msgstr ""
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, fuzzy, gcc-internal-format
 msgid "conflicting global module declaration %#qD"
 msgstr "無効な宣言です"
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, fuzzy, gcc-internal-format
 msgid "existing declaration %#qD"
 msgstr "無効な宣言です"
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match"
 msgstr "初期化された変数 `%s' は dllimport マークされています"
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, fuzzy, gcc-internal-format
 #| msgid "missing definition"
 msgid "existing definition %qD"
 msgstr "定義がありません"
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "... this enumerator %qD"
 msgstr "列挙型 %q+D の再宣言です"
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, fuzzy, gcc-internal-format
 msgid "enumerator %qD does not match ..."
 msgstr "型 %qT の引数が %qT と一致しません"
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr ""
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr ""
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr ""
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, gcc-internal-format
 msgid "recursive lazy load"
 msgstr ""
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr ""
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, fuzzy, gcc-internal-format
 msgid "module %qs declared here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, fuzzy, gcc-internal-format
 msgid "indirect import %qs is not already loaded"
 msgstr "%s\"%s\"%s は許可されていません"
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr ""
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr ""
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, fuzzy, gcc-internal-format
 msgid "macro definitions of %qE corrupted"
 msgstr "前の %q+D の宣言はここです"
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, fuzzy, gcc-internal-format
 #| msgid "inconsistent instance variable specification"
 msgid "inconsistent imported macro definition %qE"
 msgstr "インスタンス変数の仕様が一貫していません"
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr ""
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr ""
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, fuzzy, gcc-internal-format
 msgid "compiled module file is %qs"
 msgstr "%s: ファイル `%s' を削除できません: %s\n"
 
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "compiled module is %sversion %s"
 msgstr "`コンパイラのバージョンを表示する"
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collect2 version %s\n"
 msgid "compiler is %sversion %s%s%s"
 msgstr "collect2 バージョン %s\n"
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, gcc-internal-format
 msgid "module %qs found"
 msgstr ""
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr ""
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr ""
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr ""
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr ""
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, fuzzy, gcc-internal-format
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr "例外処理を無効にしました. 有効にするには -fexceptions を使ってください"
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, fuzzy, gcc-internal-format
 msgid "fixed tree mismatch"
 msgstr "<戻り値> "
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "interface partition is not exported"
 msgstr "スタック制限式はサポートされていません"
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module cluster %u: %s"
 msgstr "%s を開くのに失敗しました"
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module: %s"
 msgstr "%s を開くのに失敗しました"
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr ""
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr ""
 
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr ""
 
-#: cp/module.cc:19283
+#: cp/module.cc:19117
+#, fuzzy, gcc-internal-format
+msgid "declaration %qD conflicts with builtin"
+msgstr "%q+D のセクションが前の宣言と競合しています"
+
+#: cp/module.cc:19122
+#, fuzzy, gcc-internal-format
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr "%q+D のセクションが前の宣言と競合しています"
+
+#: cp/module.cc:19125
+#, fuzzy, gcc-internal-format
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr "%q+D のセクションが前の宣言と競合しています"
+
+#: cp/module.cc:19130
+#, fuzzy, gcc-internal-format
+msgid "import declared attached to module %qs"
+msgstr "%qD はここで宣言されています"
+
+#: cp/module.cc:19134
+#, fuzzy, gcc-internal-format
+msgid "import declared in global module"
+msgstr "メソッド定義がクラスコンテキスト内ではありません"
+
+#: cp/module.cc:19140
+#, fuzzy, gcc-internal-format
+msgid "conflicting declaration of %qD in module %qs"
+msgstr "インラインテンプレートの明示的な実体化のみを生成する"
+
+#: cp/module.cc:19143
+#, fuzzy, gcc-internal-format
+msgid "conflicting declaration of %qD in global module"
+msgstr "リンク無し %q+D の再定義です"
+
+#: cp/module.cc:19148
+#, fuzzy, gcc-internal-format
+msgid "previously declared in module %qs"
+msgstr "前はここで宣言されました"
+
+#: cp/module.cc:19152
+#, fuzzy, gcc-internal-format
+msgid "previously declared in global module"
+msgstr "前はここで宣言されました"
+
+#: cp/module.cc:19404
 #, fuzzy, gcc-internal-format
 msgid "reading CMI %qs"
 msgstr "%s を閉じているときにエラーが発生しました: %m"
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, gcc-internal-format
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, fuzzy, gcc-internal-format
 msgid "during load of pendings for %<%E%s%E%>"
 msgstr "-mrecip=%s 用の不明なオプションです"
@@ -59754,390 +59792,390 @@ msgstr "-mrecip=%s 用の不明なオプションです"
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr ""
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, fuzzy, gcc-internal-format
 msgid "module already declared"
 msgstr "シンボルの頭にアンダースコアをつける"
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, fuzzy, gcc-internal-format
 msgid "module already imported"
 msgstr "シンボルの頭にアンダースコアをつける"
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, fuzzy, gcc-internal-format
 msgid "module %qs imported here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown Compiled Module Interface: %s"
 msgstr "<不明な演算子>"
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr ""
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr ""
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr ""
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, gcc-internal-format
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr ""
 
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, fuzzy, gcc-internal-format
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr "伝統的な前処理を有効にする"
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr ""
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr ""
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, fuzzy, gcc-internal-format
 msgid "you should use the %<-%s%> option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, fuzzy, gcc-internal-format
 msgid "invalid header name %qs"
 msgstr "%%R への無効な被演算子です"
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, fuzzy, gcc-internal-format
 msgid "invalid module name %qs"
 msgstr "無効な %qD の使用です"
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr ""
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, fuzzy, gcc-internal-format
 #| msgid "error writing %qs"
 msgid "writing CMI %qs"
 msgstr "%qs へ書き込み中にエラーが発生しました"
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, fuzzy, gcc-internal-format
 msgid "not writing module %qs due to errors"
 msgstr "%s への書き込みエラーです"
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to write compiled module: %s"
 msgstr "%s を開くのに失敗しました"
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, fuzzy, gcc-internal-format
 msgid "unknown header kind %qs"
 msgstr "不明な TLS モデル %qs です"
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, fuzzy, gcc-internal-format
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "`%s' のセクションは前方でに宣言されたものと衝突します"
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, fuzzy, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%d 個のコンストラクタが見つかりました\n"
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, fuzzy, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, fuzzy, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "パラメタはメソッドの型を不正に宣言しました"
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, fuzzy, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s: %s: "
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, fuzzy, gcc-internal-format
 msgid "exporting %q#D that does not have external linkage"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here with no linkage"
 msgstr "%qD はここで宣言されています"
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here with internal linkage"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here with module linkage"
 msgstr "%qD はここで宣言されています"
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr ""
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, fuzzy, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%s=%s は数値ではありません"
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, fuzzy, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "%q#D のテンプレート宣言です"
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, fuzzy, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a direct base of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "%qD は %qD 内では宣言されていません"
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "%q#D が宣言されています"
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr ""
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD は %qD 内では宣言されていません"
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, fuzzy, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "非インライン (noinline) 属性が与えられたインライン関数 %qD です"
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "`%s' 属性の疑似命令が無視されました"
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr ""
 
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, fuzzy, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "`this' は静的メンバ関数から使用できません"
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "弱い %q+D は %qE として定義できません"
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, fuzzy, gcc-internal-format
 msgid "it was later defined here"
 msgstr "構造体がここで定義されています"
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "初期化された変数 `%s' は dllimport マークされています"
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, fuzzy, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "%qs スイッチは既にサポートされていません"
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, fuzzy, gcc-internal-format
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "メソッド属性を指定するのは最後のみでなければいけません"
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "ラベル %qD はここで定義されています"
 
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, fuzzy, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%q+D  のアドレス領域は前の宣言と競合しています"
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "`%s' は前にここで定義されました"
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -60162,7 +60200,7 @@ msgstr "識別子 %qE は C++ 予約語と競合しています"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
@@ -60408,7 +60446,7 @@ msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
@@ -60588,7 +60626,7 @@ msgstr ""
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr ""
@@ -60643,7 +60681,7 @@ msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定
 msgid "template-id not allowed for destructor in C++20"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, gcc-internal-format
 msgid "remove the %qs"
 msgstr ""
@@ -60663,7 +60701,7 @@ msgstr ""
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr ""
@@ -60713,7 +60751,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
@@ -60748,7 +60786,7 @@ msgstr "一つの空の宣言中に、二つの型が指定されています"
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr ""
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "無効な %qD の使用です"
@@ -60773,7 +60811,7 @@ msgstr "ISO C++ は名前つき戻り値を許可しません"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
@@ -60923,8 +60961,8 @@ msgstr ""
 msgid "capture of non-variable %qE"
 msgstr "読み取り専用変数 %qD の増分です"
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%qD はここで宣言されています"
@@ -60964,7 +61002,7 @@ msgstr "仮引数 `%s' で指定された記憶クラス"
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr ""
@@ -61090,7 +61128,7 @@ msgstr ""
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
@@ -61152,7 +61190,7 @@ msgstr "式の中の文に不完全型があります"
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
@@ -61178,7 +61216,7 @@ msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ は計算型 goto を禁じます"
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
@@ -61459,12 +61497,12 @@ msgstr ""
 msgid "cannot expand initializer for member %qD"
 msgstr "メンバ `%s' に対する無効な初期値"
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D は静的宣言の後に非静的宣言が続いています"
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -62102,7 +62140,7 @@ msgstr "`%s' の引数として無効な型"
 msgid "%qT not permitted in template argument"
 msgstr "合っていない引数です"
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
@@ -62282,12 +62320,12 @@ msgstr "%q+#T の前の定義"
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, gcc-internal-format
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr ""
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
@@ -62489,37 +62527,37 @@ msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定
 msgid "expression must be enclosed in parentheses"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr ""
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, fuzzy, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr "要求された整列が定数ではありません"
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, fuzzy, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "要求された整列が定数ではありません"
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "無効な宣言です"
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -62528,437 +62566,437 @@ msgstr ""
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, fuzzy, gcc-internal-format
 msgid "template-id not allowed for constructor in C++20"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "--driver は最早サポートされません"
 
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, fuzzy, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "宣言が何も宣言していません"
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "`>>' はテンプレートクラス名は `> >' とすべきです"
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, fuzzy, gcc-internal-format
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr "`>>' はテンプレートクラス名は `> >' とすべきです"
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "テンプレート型統一中 `%s' が使用されました"
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD specifier"
 msgstr "型指定子が予期されます"
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, fuzzy, gcc-internal-format
 msgid "%qD specifier conflicts with %qs"
 msgstr "%+D によりセクション型が競合します"
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> が %qD の前にあります"
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, fuzzy, gcc-internal-format
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr "%<__thread%> が %<typedef%> と併せて使用されています"
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ は `long long' を受け入れません"
 
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "%qE が重複しています"
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "`%s' が重複しています"
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> が予期されます"
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> が予期されます"
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> が予期されます"
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> が予期されます"
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> が予期されます"
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> が予期されます"
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> が予期されます"
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> が予期されます"
 
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> が予期されます"
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> が予期されます"
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> が予期されます"
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> が予期されます"
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> が予期されます"
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "%<catch%> が予期されます"
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> が予期されます"
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> が予期されます"
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> が予期されます"
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> が予期されます"
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, fuzzy, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "%<@end%> が予期されます"
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> が予期されます"
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> が予期されます"
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> が予期されます"
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> が予期されます"
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> または %<::%> が予期されます"
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "前はここで宣言されました"
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, fuzzy, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "参照を参照として宣言できません"
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "名前無しテンプレートクラスです"
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, fuzzy, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "ラベル %qD はここで定義されています"
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, fuzzy, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "デフォルト引数内でファイルが終了しています"
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c メソッド定義が予期されます"
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "識別子が必要です"
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr "不明な property 属性です"
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "整数式が予期されます"
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "無効な初期化子です"
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
@@ -62967,12 +63005,12 @@ msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "--driver は最早サポートされません"
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
@@ -62982,133 +63020,133 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "唯一の仮引数となる %<void%> には修飾子がつきません"
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma GCC pop_options%> に対応した %<#pragma GCC push_options%> がありません"
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr ""
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "無効な初期化子です"
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "式が予期されます"
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "参照型に対して new を適用できません"
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "メンバ関数の名前を欠いています"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, fuzzy, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "#pragma GCC java_exceptions の末尾にゴミ"
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp taskwait%> は複合文内でのみ使用できます"
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp taskwait%> は複合文内でのみ使用できます"
 
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr "#pragma GCC optimize は関数内では許可されていません"
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, fuzzy, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr "ret 命令は実装されていません"
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, fuzzy, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "#if 式の中では文字列定数が使えません"
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -63138,7 +63176,7 @@ msgstr ""
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
@@ -63153,170 +63191,170 @@ msgstr "`%s' が再定義されました"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr ""
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, fuzzy, gcc-internal-format
 msgid "from definition of %q#D"
 msgstr "`%s' が再定義されました"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr ""
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, fuzzy, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD は関数テンプレートではありません"
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD は変数ではありません"
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, fuzzy, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr ""
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "Code 属性を欠いています"
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "Code 属性を欠いています"
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, fuzzy, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr "`operator delete' の宣言内に多すぎる引数"
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, fuzzy, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "#define 中の仮引数リストが終端されていません"
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "%qD の宣言内でテンプレート仮引数リストが多すぎます"
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "%qD の宣言内でテンプレート仮引数リストが少なすぎます"
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, fuzzy, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD はテンプレート関数ではありません"
@@ -63329,153 +63367,153 @@ msgstr "%qD はテンプレート関数ではありません"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "メンバ関数 %qD は %qT 内では宣言されていません"
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "隠された宣言はここです"
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, fuzzy, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "%K %D の最後の引数が 0 から 3 の間の整数定数ではありません"
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr "          %s"
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "#define 中の仮引数リストが終端されていません"
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "前はここで宣言されました"
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, fuzzy, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "関数 %qE への引数が多すぎます"
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "重複したラベル %qD です"
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] ""
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD 用のデフォルト引数がありません"
@@ -63484,47 +63522,47 @@ msgstr "%qD 用のデフォルト引数がありません"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "仮引数リスト中の `void' はリスト全体を占めなければなりません"
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "名前無しテンプレートクラスです"
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -63534,505 +63572,505 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD の無効なテンプレート宣言です"
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "非テンプレート %q#D のテンプレート定義です"
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr ""
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD with different constraints"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT はテンプレート型ではありません"
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] ""
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "テンプレート仮引数 %q+#D です"
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "ここで %q#D として再宣言されています"
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "redeclared here"
 msgstr "ここで宣言されています"
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "元の定義はここに出現しています"
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D with different constraints"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "テンプレート仮引数 %q+#D です"
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, fuzzy, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "型 %qT と %qT の間での比較です"
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "型 %qT から型 %qT へ変換できません"
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "型 %qT の引数が %qT と一致しません"
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "`restrict' の用法が不適切です"
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, fuzzy, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "%qE から %qT へ変換できません"
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "関数 %<va_start%> への引数の数が間違っています"
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%qD は関数テンプレートではありません"
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "空の宣言です"
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "内部一貫性がありません"
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "テンプレート内で `%s' を使用しています"
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, fuzzy, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "整数 0 とポインタとの順序比較です"
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, fuzzy, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "共用体に可変配列メンバがあります"
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, fuzzy, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE は宣言の開始ではありません"
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "%q#D 用のデフォルト引数の再定義です"
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "メンバ関数へのポインタが呼ばれましたが、クラススコープ内ではありません"
 
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, gcc-internal-format, gfc-internal-format
 msgid "mismatched argument pack lengths (%d vs %d)"
 msgstr ""
@@ -64050,303 +64088,303 @@ msgstr ""
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "sizeof が関数型に適用されました"
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "仮引数 `%s' は無効です"
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "無効な宣言です"
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, fuzzy, gcc-internal-format
 msgid "function returning an array"
 msgstr "関数が集合体を返しています"
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "`%s' は関数を返す関数として宣言されています"
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, fuzzy, gcc-internal-format
 msgid "forming reference to void"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "大きさゼロの配列を作ろうとしています"
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "テンプレート内で `%s' を使用しています"
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "void 式の不適切な使用"
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qE attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "%qE 属性用に間違った数の引数が指定されました"
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr ""
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr ""
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "static フィールド `%s' を欠いています"
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT はテンプレート型ではありません"
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "初期化子の要素が定数ではありません"
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "不正な文字列定数です"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 #, fuzzy
 msgid "%s %#qS"
 msgstr "%s: %s"
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "%s: `%s' の初期化:\n"
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ は減算にメソッドへのポインタを使うことを禁じます"
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -64358,163 +64396,163 @@ msgstr ""
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "'#' にマクロ仮引数名が続いていません"
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "'#' にマクロ仮引数名が続いていません"
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "%s=%s は数値ではありません"
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, fuzzy, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr "`%s' の宣言は仮引数リストのシンボルを覆い隠します"
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "非テンプレート %qD がテンプレートとして使用されています"
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, fuzzy, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr "spec %qs が無効です"
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "inline に出来ると見なされていない関数です"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "間接関数 %q+D は弱い参照として宣言できません"
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, fuzzy, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "無効なメソッド宣言です。メソッド名が必要です"
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, fuzzy, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, fuzzy, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, fuzzy, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "不完全な typedef `%s' の使用は不適切です"
@@ -64720,632 +64758,632 @@ msgstr ""
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "%<for%> ループ初期化宣言は C99 モード内でのみ許可されています"
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, fuzzy, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr "合っていない引数です"
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, fuzzy, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "引数が構造体です"
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, fuzzy, gcc-internal-format
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr "`this' は静的メンバ関数から使用できません"
 
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, gcc-internal-format
 msgid "use explicit object parameter %qs instead"
 msgstr ""
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, fuzzy, gcc-internal-format
 msgid "name the explicit object parameter"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, fuzzy, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "`this' は静的メンバ関数から使用できません"
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> before it is valid"
 msgstr "トップレベルでの `this' の使用は無効です"
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> after it is valid"
 msgstr "トップレベルでの `this' の使用は無効です"
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "トップレベルでの `this' の使用は無効です"
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, fuzzy, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%s は型 %s ではありません (引数 %d)"
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, fuzzy, gcc-internal-format
 msgid "%<auto{x}%> cannot be constrained"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, fuzzy, gcc-internal-format
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, fuzzy, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "テンプレート型仮引数には `class' や `typename' 予約語を使わねばなりません"
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "無効なデフォルトテンプレート引数"
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "`%s' の宣言は仮引数リストのシンボルを覆い隠します"
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "インスタンス化されない型に対する無効な操作です"
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "無効な宣言です"
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, fuzzy, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "無名共用体内に保護されたメンバ %q+#D があります"
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, fuzzy, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "alloc_size パラメータが範囲外です"
 
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "合っていない引数です"
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "要求されたメンバ `%s' は多重継承グラフの中で曖昧です"
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, fuzzy, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "レジスタ '%c' が不明です"
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT はテンプレート型ではありません"
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, fuzzy, gcc-internal-format
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr "要求された整列が定数ではありません"
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr ""
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, fuzzy, gcc-internal-format
 msgid "%<__type_pack_element%> index is out of range"
 msgstr "被演算子の数字が範囲外です"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "仮引数宣言の中の記憶域クラス指定は無効です"
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "ISO C++ はメンバ関数への `sizeof' の適用を禁じます"
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "ISO C++ はメンバ関数への `sizeof' の適用を禁じます"
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "ISO C++ はメンバ関数への `sizeof' の適用を禁じます"
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, fuzzy, gcc-internal-format
 #| msgid "constructor priorities are not supported"
 msgid "pointer-to-member mapping %qE not supported"
 msgstr "コンストラクタのプロパティはサポートされません"
 
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, fuzzy, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE は %<reduction%> 用の無効な型を持っています"
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, gcc-internal-format
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr ""
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, fuzzy, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "インスタンス変数 `%s' は private と宣言されています"
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "インスタンス変数 `%s' は private と宣言されています"
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, fuzzy, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, fuzzy, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, fuzzy, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "%qs 句が多すぎます"
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, fuzzy, gcc-internal-format
 msgid "%<filter%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> がポインタ型として定義されていません"
 
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr ""
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr ""
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr ""
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr ""
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, fuzzy, gcc-internal-format
 msgid "static assertion failed: %.*s"
 msgstr "静的アサーションに失敗しました: %E"
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, fuzzy, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "%<__builtin_prefetch%> への第三引数は定数でなければいけません"
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, fuzzy, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "<未解決オーバーロードされた関数型>"
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr ""
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr ""
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr "%<__builtin_next_arg%> が引数無しで呼び出されました"
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "カンマ演算子の左側の式に効力がありません"
 
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "%<__builtin_return_address%> へのサポートされていない引数です"
@@ -65353,1170 +65391,1170 @@ msgstr "%<__builtin_return_address%> へのサポートされていない引数
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr ""
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, fuzzy, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, fuzzy, gcc-internal-format
 msgid " declared here"
 msgstr "ここで宣言されています"
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, fuzzy, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, fuzzy, gcc-internal-format
 msgid "%qD is not public"
 msgstr "%s は型 %s ではありません (引数 %d)"
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, fuzzy, gcc-internal-format
 msgid "%qD is mutable"
 msgstr "%qD は変数ではありません"
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, fuzzy, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr "%s は型 %s ではありません (引数 %d)"
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "`java_interface' 属性は Java クラス定義に対してのみ用いる事ができます"
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "%qE 属性は変数および関数へのみ適用できます"
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "%qE 属性は型に適用できません"
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, fuzzy, gcc-internal-format
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "要求された init_priority は整数型の定数ではありません"
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, fuzzy, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "init_priority 属性はクラス型オブジェクトのファイルスコープ定義でのみ使えます"
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, fuzzy, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "要求された init_priority が範囲外です"
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, fuzzy, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "要求された init_priority は内部で使用するために予約されています"
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> は有効な宣言子ではありません"
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> は有効な宣言子ではありません"
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE 属性は非クラス型に関しては無視されます"
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE 属性は関数へのみ適用出来ます。%s へは適用できません"
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "`%s' 属性は関数に対してのみ適用されます"
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "配列の添字が整数型ではありません"
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, fuzzy, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "Tree 検査: %s があるべき所に %s があります(%s 内, %s:%d)"
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, fuzzy, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, fuzzy, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ は `void *' 型ポインタと関数ポインタとの %s を禁じます"
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ は `void *' 型ポインタと関数ポインタとの %s を禁じます"
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ は `void *' 型ポインタと関数ポインタとの %s を禁じます"
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, fuzzy, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, fuzzy, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, fuzzy, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "?: への被演算子が異なる型 %qT と %qT を持っています"
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, fuzzy, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "?: への被演算子が異なる型 %qT と %qT を持っています"
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ビットフィールドに `__alignof' が適用されました"
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ は関数型の式への `sizeof' の適用を禁じます"
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ は関数型の式への `sizeof' の適用を禁じます"
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "文字列定数中の \\r エスケープ"
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, fuzzy, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "文字列定数中の \\r エスケープ"
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr ""
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr ""
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "メンバ関数の名前を欠いています"
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr ""
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "配列参照での添字を欠いています"
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, fuzzy, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "`register' と宣言された配列に添字をつけようとしています"
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "添字をつけられた値が配列でもポインタでもありません"
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, fuzzy, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "メンバへのポインタ構築の使用でオブジェクトを欠いています"
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ はプログラムの中から `::main' を呼び出すことを禁じます"
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "\"%s\" はマクロ名としては使えません"
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr ""
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr ""
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr ""
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr ""
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "関数に対する引数が多すぎます"
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "関数への引数が少なすぎます"
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "仮引数が不完全型です"
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "仮引数が不完全型です"
 
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, gcc-internal-format
 msgid "the address %qE will never be NULL"
 msgstr ""
 
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr ""
 
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr ""
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, fuzzy, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, fuzzy, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, fuzzy, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, fuzzy, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, fuzzy, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, fuzzy, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, fuzzy, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, fuzzy, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, fuzzy, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "関数ポインタが計算で使われました"
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ はポインタと整数との比較を禁じます"
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "%qT と %qT の比較です"
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, fuzzy, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "整数 0 とポインタとの順序比較です"
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, fuzzy, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr "非浮動小数点引数での順序付けられない比較です"
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "二項演算子 %s が不適切です"
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ は減算に `void *' 型のポインタを使うことを禁じます"
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ は減算にメソッドへのポインタを使うことを禁じます"
 
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ポインタ演算で不完全型へのポインタを使うことは無効です"
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr "ISO C++ は非左辺値式へのキャストのアドレスを取ることを禁じます"
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ は非左辺値式へのキャストのアドレスを取ることを禁じます"
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr "ISO C++ は非左辺値式へのキャストのアドレスを取ることを禁じます"
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, gcc-internal-format
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, fuzzy, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ は `::main' 関数のアドレスを取ることを禁じます"
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "ビットフィールド %qD のアドレスを取得できません"
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, fuzzy, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<void%> 型の式のアドレスを取得しています"
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ は enum の %s を禁じます"
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ は enum の %s を禁じます"
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "不完全型へのポインタに対する演算"
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ は減算に `void *' 型のポインタを使うことを禁じます"
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ は減算に `void *' 型のポインタを使うことを禁じます"
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, fuzzy, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "`this' は右辺値式であり、そのアドレスを取ることはできません"
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, fuzzy, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "register 変数 `%s' のアドレスが要求されました"
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "無名基底クラスの初期設定子が曖昧です"
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "初期化子リストは複合式として取り扱われました"
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, fuzzy, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, fuzzy, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "関数戻り値の型修飾子は無視されました"
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, fuzzy, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "戻り値の型が不完全型です"
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 #, fuzzy
 msgid "converting from %qH to %qI"
 msgstr "NaN から整数への変換です"
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, fuzzy, gcc-internal-format
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 #, fuzzy
 msgid "cast from %qH to %qI loses precision"
 msgstr "%s: 全体的な精度の低下"
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 #, fuzzy
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 #, fuzzy
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "キャストによってポインタが示す型の要求アラインメントが増加します"
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, fuzzy, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ は関数ポインタとオブジェクトポインタの間でのキャストを禁じます"
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C は共用体型へのキャストを禁じます"
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qE from type %qT to type %qT"
 msgid "moving %qE of type %qT to itself"
 msgstr "%qE を型 %qT から型 %qT へ変換できません"
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, fuzzy, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "%d 番目の引数が `%s' の型と互換性がありません"
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "配列の不正な初期化"
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "代入として無効な左辺値です"
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   ポインタからメンバ関数への変換で"
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, fuzzy, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "無効なバージョン番号形式"
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 #, fuzzy
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 #, fuzzy
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 #, fuzzy
 msgid "cannot convert %qH to %qI in return"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 #, fuzzy
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "ポインタ型へ変換できません"
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "format 属性をの候補となりそうな関数について警告する"
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "引数 %d 個の `%s' を渡します"
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "returning pointer to temporary"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, fuzzy, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "非左辺値への参照が返されました"
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, fuzzy, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "要求された大域レジスタ変数 `%s' のアドレス"
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, fuzzy, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "要求された大域レジスタ変数 `%s' のアドレス"
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, fuzzy, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "return 文に十分な値がありません"
 
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, fuzzy, gcc-internal-format
 msgid "redundant move in initialization"
 msgstr "return 文に十分な値がありません"
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "デストラクタから値を返そうとしています"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "コンストラクタの関数 try ブロックのハンドラからは return できません"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "コンストラクタから値を返そうとしています"
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "戻り型が関数で、`return' に値がありません"
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "初期化子がありません"
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "戻り型が関数で、`return' に値がありません"
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, fuzzy, gcc-internal-format
 msgid "not eliding copy on return from %qD"
 msgstr "無効なメソッド宣言です。メソッド名が必要です"
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr ""
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, fuzzy, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "無効な %%s 値"
@@ -66737,157 +66775,157 @@ msgstr ""
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "関数を inline にできません"
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "%qE の %qT から %qT への変換は曖昧です"
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "%qE の %qT から %qT への変換は曖昧です"
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, fuzzy, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, fuzzy, gcc-internal-format
 msgid "initializer-string for %qT is too long"
 msgstr "char の配列にとって初期化子文字列が長すぎます"
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, fuzzy, gcc-internal-format
 msgid "remove %<{ }%> around initializer"
 msgstr "スカラー初期化子が中括弧で囲まれています"
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "初期化子を欠いています"
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "仮引数 `%s' が初期化されました"
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "仮引数 `%s' が初期化されました"
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "%qD の型は元の宣言と一致しません"
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, fuzzy, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "レコードや共用体にフィールド名がない初期化子です"
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "union 初期化子がフィールド名ではなくインデックス値になっています"
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "循環ポインタの代表を検出しました"
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "`->' のベースオペランドがポインタではありません"
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, fuzzy, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "`operator->()'の結果が非ポインタの結果をもたらします"
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "`->' のベースオペランドがポインタではありません"
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "\"%s\" は C++ の演算子であり、マクロ名として使用することはできません"
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, fuzzy, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, fuzzy, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "不完全型への変換です"
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "不完全型への変換です"
@@ -67879,7 +67917,7 @@ msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "無効なビット列初期化子です"
@@ -69202,7 +69240,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr "引数の型が異なります"
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -69417,7 +69455,7 @@ msgstr ""
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "シンボルの頭にアンダースコアをつける"
@@ -70218,7 +70256,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
@@ -71025,12 +71063,12 @@ msgstr ""
 msgid "are_identical_variables: Bad type"
 msgstr ""
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr ""
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr ""
@@ -71278,273 +71316,273 @@ msgstr ""
 msgid "check_init_expr(): Unknown expression type"
 msgstr ""
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, fuzzy, gcc-internal-format
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr "コンストラクタを静的メンバ関数とすることはできません"
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, fuzzy, gcc-internal-format
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, fuzzy, gcc-internal-format
 msgid "Specification function %qs at %L must be PURE"
 msgstr "コンストラクタを静的メンバ関数とすることはできません"
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, fuzzy, gcc-internal-format
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr "コンストラクタを静的メンバ関数とすることはできません"
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr "二重にクォートされた文字列は #if 式内では使えません"
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr ""
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr ""
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr "定数式がオーバーフローしました"
 
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, gcc-internal-format
 msgid "check_restricted(): Unknown expression type"
 msgstr ""
 
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, gcc-internal-format
 msgid "Function %qs at %L must be PURE"
 msgstr ""
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr ""
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr ""
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr ""
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr ""
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr "呼び出されたオブジェクトは関数ではありません"
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Illegal assignment to external procedure at %L"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr ""
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "キャストは関数型を指定しています"
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, fuzzy, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, fuzzy, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, fuzzy, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr ""
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
@@ -71552,192 +71590,192 @@ msgstr ""
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr ""
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr ""
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "`asm' の引数が定数文字列ではありません "
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, fuzzy, gcc-internal-format
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr "`asm' の引数が定数文字列ではありません "
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "定数式がオーバーフローしました"
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "定数式がオーバーフローしました"
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "`asm' の引数が定数文字列ではありません "
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, gcc-internal-format
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "`asm' の引数が定数文字列ではありません "
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -71758,8 +71796,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "一時オブジェクトへの参照を返そうとしています"
@@ -71839,7 +71877,7 @@ msgstr ""
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -71974,12 +72012,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -72849,7 +72887,7 @@ msgstr "NaN から整数への変換です"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "値をベクトルには変換できません"
@@ -73400,7 +73438,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -73566,6 +73604,11 @@ msgstr "式の整数がオーバーフローしました"
 msgid "check_charlen_present(): length not set"
 msgstr ""
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr ""
+
 #: fortran/match.cc:118
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
@@ -73967,7 +74010,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr ""
@@ -74490,82 +74533,82 @@ msgstr "'%s' トークンの所で文法エラー"
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr "式内"
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr "文が予期されます"
 
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr ""
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -75986,8 +76029,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -78355,12 +78398,12 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "ラベル %s があらゆる関数の外側で参照されました"
@@ -78480,7 +78523,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -78879,278 +78922,283 @@ msgstr ""
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, fuzzy, gcc-internal-format
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr "`%s' の宣言は関数の配列"
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, fuzzy, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%qE は廃止されました"
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "Invalid array reference at %L"
+msgstr "無効な参照型です"
+
+#: fortran/resolve.cc:6433
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "添え字は整数でなければいけません"
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, fuzzy, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "式文が無効です"
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -79159,284 +79207,284 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "\"%s\" は C++ の演算子であり、マクロ名として使用することはできません"
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "仮引数 %u が void 型を持っています"
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "数値型が予期されます"
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "無効なオプション %s"
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -79444,212 +79492,212 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "コンストラクタ %qs 内"
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, gcc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, fuzzy, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "フォーマット引数がポインタではありません (引数 %d)"
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "引数は定数でなければいけません"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "無効なオプション %s"
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -79657,999 +79705,999 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "配列 `%s' の大きさが大きすぎます"
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s 内、位置 %s:%d"
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, fuzzy, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr "コンストラクタを静的メンバ関数とすることはできません"
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr ""
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%qD は既に定義されています"
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%s に互換性のない型"
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "関数 `%s' への引数が少なすぎます"
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "式文が無効です"
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-constant character length at %L in DATA statement"
 msgstr "初期化子内に非定数の配列インデックスがあります"
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "`%s' の第二引数は `char **' とすべきです"
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "ラベル `%s' が定義されましたが使われていません"
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "ラベル `%s' が定義されましたが使われていません"
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, fuzzy, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -81193,330 +81241,330 @@ msgstr ""
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr ""
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, fuzzy, gcc-internal-format
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr "データ領域 '%s' は前の宣言と矛盾します"
+
+#: fortran/symbol.cc:508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr ""
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr ""
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, gcc-internal-format
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr ""
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "`%s' 属性は関数に対してのみ適用されます"
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, gcc-internal-format, gfc-internal-format
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr ""
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, fuzzy, gcc-internal-format
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr "データ領域 '%s' は前の宣言と矛盾します"
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr ""
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr ""
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "フィールド '%s' の ConstantValue 属性が重複しています"
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr "フィールド '%s' の ConstantValue 属性が重複しています"
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr ""
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "section 属性はローカル変数に対しては指定できません"
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "フィールド '%s' の ConstantValue 属性が重複しています"
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr "section 属性はローカル変数に対しては指定できません"
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr ""
 
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr ""
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr "式内"
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -81546,24 +81594,24 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -81749,37 +81797,37 @@ msgstr "FPU レジスタ内の機能の値を返す"
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr "ISO C90 は可変長の配列 %qE を禁止しています"
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr ""
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "関数 `%s' への引数が少なすぎます"
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -81790,17 +81838,17 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "言語 %s は認識できません"
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, fuzzy, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "環境変数 %qs が定義されていません"
@@ -81941,7 +81989,7 @@ msgstr ""
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr ""
@@ -82315,6 +82363,11 @@ msgstr "変数 %qD が関数として再宣言されました"
 msgid "function %qD redeclared as variable"
 msgstr "関数 %qD が変数として再宣言されました"
 
+#: lto/lto-symtab.cc:865
+#, gcc-internal-format
+msgid "previously declared here"
+msgstr "前はここで宣言されました"
+
 #: lto/lto.cc:174
 #, gcc-internal-format
 msgid "%<lto_obj_file_open()%> failed"
@@ -83570,7 +83623,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr ""
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, fuzzy, gcc-internal-format
 msgid "non-objective-c type %qT cannot be caught"
 msgstr "非オブジェクトメンバ `%s' を `mutable' とは宣言できません"
@@ -83580,7 +83633,7 @@ msgstr "非オブジェクトメンバ `%s' を `mutable' とは宣言できま
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr ""
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, gcc-internal-format
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
 msgstr ""
@@ -84267,6 +84320,10 @@ msgstr ""
 #~ msgid "class template placeholder %qE not permitted in this context"
 #~ msgstr "マクロ引数内でディレクトリを使うことはできません"
 
+#, fuzzy, gcc-internal-format
+#~ msgid "cannot declare %qD in a different module"
+#~ msgstr "%qD をビットフィールド型として宣言できません"
+
 #, fuzzy, gcc-internal-format
 #~ msgid "cannot define %qD in different module"
 #~ msgstr "作成時と使用時でエンディアンが異なります"
diff --git a/gcc/po/nl.po b/gcc/po/nl.po
index 1d14c1e3e25..5bf417fe393 100644
--- a/gcc/po/nl.po
+++ b/gcc/po/nl.po
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 4.9-b20140202\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
 "PO-Revision-Date: 2014-02-05 12:25+0100\n"
 "Last-Translator: Benno Schulenberg <benno@vertaalt.nl>\n"
 "Language-Team: Dutch <vertaling@vrijschrift.org>\n"
@@ -417,7 +417,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr "-march=... en -mcpu=... gaan niet samen"
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 msgid "shared and mdll are not compatible"
 msgstr "-shared en -mdll zijn niet compatibel"
 
@@ -19288,20 +19288,20 @@ msgstr "onherkenbare insn:"
 msgid "insn does not satisfy its constraints:"
 msgstr ""
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr ""
 
 # Vertaling voor "endianness"? Of niet nodig?
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 #, fuzzy
 #| msgid "created and used with different endianness"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "aangemaakt en gebruikt met verschillende \"endianness\""
 
 # Vertaling voor "endianness"? Of niet nodig?
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 #, fuzzy
 #| msgid "created and used with different endianness"
 msgid "created and used with different settings of %<-fpie%>"
@@ -19631,7 +19631,7 @@ msgstr "lengte-modifier in strfmon-formaat"
 msgid "<command-line>"
 msgstr "<opdrachtregel>"
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "ongeldige operand voor code '%c'"
@@ -19650,9 +19650,9 @@ msgstr "ongeldige operand voor '%%%c'"
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector constant"
@@ -19675,7 +19675,7 @@ msgstr "ongeldige operand voor '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "ongeldige operand voor '%%%c'"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, c-format
 msgid "missing operand"
 msgstr "operand ontbreekt"
@@ -19707,94 +19707,94 @@ msgstr "ongeldige adresseringsmodus"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "ongeldige operanden in binaire bewerking"
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, c-format
 msgid "invalid %%J value"
 msgstr "ongeldige waarde voor %%J"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, c-format
 msgid "invalid %%r value"
 msgstr "ongeldige waarde voor %%r"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, c-format
 msgid "invalid %%R value"
 msgstr "ongeldige waarde voor %%R"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, c-format
 msgid "invalid %%N value"
 msgstr "ongeldige waarde voor %%N"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, c-format
 msgid "invalid %%P value"
 msgstr "ongeldige waarde voor %%P"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, c-format
 msgid "invalid %%h value"
 msgstr "ongeldige waarde voor %%h"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, c-format
 msgid "invalid %%L value"
 msgstr "ongeldige waarde voor %%L"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, c-format
 msgid "invalid %%m value"
 msgstr "ongeldige waarde voor %%m"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, c-format
 msgid "invalid %%M value"
 msgstr "ongeldige waarde voor %%M"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, c-format
 msgid "invalid %%U value"
 msgstr "ongeldige waarde voor %%U"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, c-format
 msgid "invalid %%s value"
 msgstr "ongeldige waarde voor %%s"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, c-format
 msgid "invalid %%C value"
 msgstr "ongeldige waarde voor %%C"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, c-format
 msgid "invalid %%E value"
 msgstr "ongeldige waarde voor %%E"
 
 # mja, is nogal technisch - ikke nie snap nie
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "onbekende 'unspec' relocatie"
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ongeldige code voor %%xn"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, fuzzy, c-format
 msgid "invalid operand address"
 msgstr "Ongeldige modus voor gen_tst_reg"
@@ -19892,36 +19892,36 @@ msgstr "ongeldige UNSPEC als operand: %d"
 msgid "unrecognized supposed constant"
 msgstr "vermoedelijke constante niet herkend"
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, c-format
 msgid "invalid shift operand"
 msgstr "ongeldige shift-operand"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "Thumb-instructie met predicaat"
 
 # mja. snappen wie snappen kan ^^
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instructie met predicaat in voorwaardelijke sequentie"
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -19929,122 +19929,122 @@ msgstr "ongeldige operand voor code '%c'"
 msgid "invalid operand for code '%c'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, c-format
 msgid "instruction never executed"
 msgstr "instructie wordt nooit uitgevoerd"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "ongeldige conversie van %<__fpreg%>"
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 #, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "ongeldige registernaam voor %qs"
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr ""
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 #, fuzzy
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "operand %<%d%> is geen register"
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 msgid "bad address, not an I/O address:"
 msgstr ""
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 #, fuzzy
 msgid "bad address, not a constant:"
 msgstr "adres-offset is geen constante"
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 msgid "bad address, not (reg+disp):"
 msgstr ""
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 msgid "bad address, not post_inc or pre_dec:"
 msgstr ""
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr "interne compilerfout.  Slecht adres:"
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 msgid "internal compiler error.  Unknown mode:"
 msgstr "interne compilerfout.  Onbekende modus:"
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 msgid "invalid insn:"
 msgstr "ongeldige insn:"
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 msgid "incorrect insn:"
 msgstr ""
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 msgid "unknown move insn:"
 msgstr "onbekende move-insn:"
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 msgid "bad shift insn:"
 msgstr ""
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "interne compilerfout.  Verkeerde shift:"
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 msgid "unsupported fixed-point conversion"
 msgstr ""
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 #, fuzzy
 msgid "variable"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 #, fuzzy
 msgid "function parameter"
 msgstr "%Jherdefinitie van parameter %qD"
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 #, fuzzy
 msgid "structure field"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 #, fuzzy
 msgid "return type of function"
 msgstr "doorgeven van argument %d van %qs"
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 #, fuzzy
 msgid "pointer"
 msgstr "ongeldige lvalue in toewijzing"
@@ -20083,7 +20083,7 @@ msgstr "onverwachte operand"
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -20407,54 +20407,54 @@ msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige opera
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ongeldige operand voor '%c'"
 
 # "constraints" hier te vertalen ("beperkingen"/"restricties") of niet?
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ongeldige constraints voor operand"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "Ongeldig token in expressie"
 
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 msgid "unknown insn mode"
 msgstr "onbekende insn-modus"
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr "ongeldige conversie van %<__fpreg%>"
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr "ongeldige conversie van %<__fpreg%>"
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr "ongeldige conversie naar %<__fpreg%>"
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 #, fuzzy
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr "ongeldige registernaam voor %qs"
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
 msgstr ""
 
@@ -20485,7 +20485,7 @@ msgstr "ongeldige bewerking met %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "ongeldige operand voor %%P"
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, c-format
 msgid "invalid %%p value"
 msgstr "ongeldige waarde voor %%p"
@@ -20513,29 +20513,29 @@ msgstr ""
 msgid "invalid addressing mode"
 msgstr "ongeldige adresseringsmodus"
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, c-format
 msgid "'%%%c' is not a valid operand prefix"
 msgstr "'%%%c' is geen geldige operand-prefix"
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "ongeldig gebruik van '%%%c'"
@@ -20570,7 +20570,7 @@ msgid "post-increment address is not a register"
 msgstr "post-increment adres is geen register"
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 msgid "bad address"
 msgstr "slecht adres"
 
@@ -20734,7 +20734,7 @@ msgstr "niet-ondersteunde versie"
 msgid "unsupported memory expression:"
 msgstr "ongeldige waarheidsexpressie"
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, fuzzy, c-format
 msgid "invalid vector operand"
 msgstr "ongeldige operand voor %%P"
@@ -20787,263 +20787,263 @@ msgstr ""
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "case-label niet in een switch-statement"
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 #, fuzzy
 msgid "bad move"
 msgstr "slechte test"
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%A value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%D value"
 msgstr "ongeldige waarde voor %%D"
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, c-format
 msgid "invalid %%K value"
 msgstr "ongeldige waarde voor %%K"
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, c-format
 msgid "invalid %%O value"
 msgstr "ongeldige waarde voor %%O"
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, c-format
 msgid "invalid %%q value"
 msgstr "ongeldige waarde voor %%q"
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, c-format
 msgid "invalid %%x value"
 msgstr "ongeldige waarde voor %%x"
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "twee %<u%>s in integerconstante"
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec argument doorgegeven aan functie zonder prototype"
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "ongeldige conversie van %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "ongeldige conversie naar %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "ongeldige conversie van %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "ongeldige conversie naar %<__fpreg%>"
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
 # Betere vertaling voor 'decompose'?
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, c-format
 msgid "cannot decompose address"
 msgstr "kan adres niet ontleden"
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "ongeldige operand voor 'b' modifier"
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "ongeldige operand voor 'b' modifier"
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "ongeldige operand voor 'O' modifier"
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "ongeldige operand voor 'b' modifier"
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "ongeldige operand voor 'b' modifier"
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "ongeldige operand voor 'o' modifier"
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "ongeldige code voor operanduitvoer"
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "ongeldige operand voor 'o' modifier"
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "ongeldige expressie als operand"
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "ongeldige operand voor 'o' modifier"
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "AltiVec argument doorgegeven aan functie zonder prototype"
 
 # 'signedness' = 'signed-heid'?
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 #, fuzzy
 msgid "types differ in signedness"
 msgstr "doelen van pointer in %s verschillen in signedness"
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -21247,12 +21247,12 @@ msgstr "{{anoniem}}"
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "ongeldige operand van %s"
@@ -21265,7 +21265,7 @@ msgstr "ongeldige operand van %s"
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -21274,7 +21274,7 @@ msgstr "ongeldige operand van %s"
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "ongeldige operand van %s"
@@ -21282,7 +21282,7 @@ msgstr "ongeldige operand van %s"
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "ongeldige operand van %s"
@@ -21294,29 +21294,29 @@ msgstr "ongeldige operand van %s"
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "ongeldige operand van %s"
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "ongeldige operand van %s"
@@ -21326,17 +21326,17 @@ msgstr "ongeldige operand van %s"
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "ongeldige operand van %s"
@@ -21345,8 +21345,8 @@ msgstr "ongeldige operand van %s"
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "ongeldige operand van %s"
@@ -21357,17 +21357,17 @@ msgid "expected %<.%>"
 msgstr "ongeldige operand van %s"
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "ongeldige operand van %s"
@@ -21375,32 +21375,32 @@ msgstr "ongeldige operand van %s"
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "ongeldige operand van %s"
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, fuzzy, gcc-internal-format
 msgid "expected %<else%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr ""
 
@@ -21408,7 +21408,7 @@ msgstr ""
 msgid "(anonymous)"
 msgstr "(anoniem)"
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "ongeldige operand van %s"
@@ -21425,23 +21425,23 @@ msgstr "ongeldige operand van %s"
 msgid "candidate:"
 msgstr "kandidaat 1:"
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 #, fuzzy
 msgid "  after user-defined conversion:"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "kandidaat 1:"
 msgstr[1] "kandidaat 1:"
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr "kandidaat 1:"
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr "kandidaat 2:"
 
@@ -21702,7 +21702,7 @@ msgstr ""
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 msgid "candidates are:"
 msgstr "kandidaten zijn:"
 
@@ -21753,54 +21753,54 @@ msgstr "conversie gooit constantheid weg"
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "argument van verkeerd type voor unaire min"
 
 # 'unary' = 'unair'?
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "argument van verkeerd type voor unaire plus"
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "argument van verkeerd type voor bit-complement"
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "argument van verkeerd type voor abs"
 
 # OK, ik geef het op: wat is hier een goede vertaling voor 'conjugation'?
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "argument van verkeerd type voor vervoeging"
 
 # 'unary' = 'unair'?
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "argument van verkeerd type voor unaire plus"
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 #, fuzzy
 msgid "no pre-increment operator for type"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 #, fuzzy
 msgid "no pre-decrement operator for type"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -21879,7 +21879,7 @@ msgstr ""
 msgid "Deleted feature:"
 msgstr ""
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 #, fuzzy
 msgid "array assignment"
 msgstr "beginwaarde ontbreekt"
@@ -22082,12 +22082,12 @@ msgstr ""
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 #, fuzzy
 msgid "assignment"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 #, fuzzy
 msgid "pointer assignment"
 msgstr "ongeldige lvalue in toewijzing"
@@ -22260,49 +22260,49 @@ msgstr ""
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 #, fuzzy
 msgid "iterator variable"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -22311,11 +22311,11 @@ msgstr ""
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr ""
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
@@ -22330,12 +22330,12 @@ msgstr ""
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -22344,81 +22344,81 @@ msgstr ""
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, fuzzy, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, fuzzy, c-format
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, fuzzy, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, c-format
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, c-format
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
@@ -22442,15 +22442,15 @@ msgstr ""
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 msgid "Loop variable has been modified"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 msgid "DO step value is zero"
 msgstr ""
 
@@ -22531,7 +22531,7 @@ msgid "expected boolean type"
 msgstr "ongeldige operand van %s"
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "ongeldige operand van %s"
@@ -22602,7 +22602,7 @@ msgstr "geen argumenten"
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, fuzzy, gcc-internal-format
 msgid "too many arguments"
 msgstr "te veel argumenten voor formaat"
@@ -23270,7 +23270,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s voor %qs"
@@ -23721,8 +23721,8 @@ msgstr "attribuut %qE botst met attribuut %s"
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "eerdere declaratie van %qs"
@@ -23739,7 +23739,7 @@ msgstr "attribuut-commando %qE wordt genegeerd"
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr "attribuut-commando %qs wordt genegeerd"
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, gcc-internal-format
 msgid "wrong number of arguments specified for %qE attribute"
 msgstr "verkeerd aantal argumenten opgegeven voor attribuut %qE"
@@ -23749,7 +23749,7 @@ msgstr "verkeerd aantal argumenten opgegeven voor attribuut %qE"
 msgid "expected %i or more, found %i"
 msgstr "ongeldige operand van %s"
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "expected %i, found %i"
 msgstr "ongeldige operand van %s"
@@ -23816,12 +23816,12 @@ msgstr ""
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -23830,7 +23830,7 @@ msgstr ""
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -23852,8 +23852,8 @@ msgstr "attribuut %qE wordt genegeerd"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "eerdere declaratie van %qs"
@@ -23964,7 +23964,7 @@ msgstr "kan %s niet vinden"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "offset buiten de grenzen van een constante string"
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, fuzzy, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -24071,7 +24071,7 @@ msgstr "ontbrekend argument bij %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "ongeldig argument voor %<__builtin_frame_address%>"
@@ -24093,43 +24093,43 @@ msgstr "tweede argument van %<__builtin_longjmp%> moet 1 zijn"
 msgid "target format does not support infinity"
 msgstr "doelformaat ondersteunt geen oneindige waarde"
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, fuzzy, gcc-internal-format
 #| msgid "%<va_start%> used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> gebruikt in functie met vaste argumenten"
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> opgeroepen zonder argument"
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "de tweede parameter van %<va_start%> is niet het laatste benoemde argument"
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, fuzzy, gcc-internal-format
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, fuzzy, gcc-internal-format
 msgid "last argument of %qD is not integer constant between 0 and 3"
 msgstr "herhalings-aantal is geen integerconstante"
@@ -25182,12 +25182,12 @@ msgstr ""
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, fuzzy, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, fuzzy, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
@@ -25747,7 +25747,7 @@ msgstr ""
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr ""
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, fuzzy, gcc-internal-format
 msgid "%qs failed"
 msgstr "kan bestand '%s' niet openen"
@@ -25777,19 +25777,19 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "call to %qs declared with attribute error: %s"
 msgstr "functie %q+D is geherdeclareerd met attribuut 'noinline'"
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "call to %qs declared with attribute warning: %s"
 msgstr "functie %q+D is geherdeclareerd met attribuut 'noinline'"
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
 msgstr ""
@@ -25824,7 +25824,7 @@ msgstr "grote integer impliciet afgekapt naar 'unsigned' type"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "vergelijking is altijd %d vanwege breedte van bit-veld"
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -25990,7 +25990,7 @@ msgstr "kon procestijden niet ophalen"
 msgid "%s signal terminated program %s"
 msgstr ""
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option %qs"
 msgid "unrecognized command-line option %qs"
@@ -26257,7 +26257,7 @@ msgstr "multilib spec '%s' is ongeldig"
 msgid "multilib exclusions %qs is invalid"
 msgstr "multilib exclusions '%s' is ongeldig"
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, fuzzy, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "multilib select '%s' in ongeldig"
@@ -26558,22 +26558,22 @@ msgstr ""
 msgid "%qD specified bound %E equals source length"
 msgstr ""
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr "%Jflexibel array-lid niet aan het eind van de struct"
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr ""
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s not supported for variable length aggregates"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
@@ -26615,16 +26615,16 @@ msgid "function returns address of local variable"
 msgstr "functie geeft adres van lokale variabele terug"
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, fuzzy, gcc-internal-format
@@ -26636,366 +26636,366 @@ msgstr "%qs tevoren hier gedeclareerd"
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, fuzzy, gcc-internal-format
 msgid "referenced argument declared here"
 msgstr "ongeldige beginwaarde"
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, fuzzy, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgid_plural "%qE output %wu bytes into a destination of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 msgid "%qE argument %Z overlaps destination object %qE"
 msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 msgid "%qE argument %Z may overlap destination object %qE"
 msgid_plural "%qE arguments %Z may overlap destination object %qE"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, gcc-internal-format
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, fuzzy, gcc-internal-format
 msgid "null destination pointer"
 msgstr "lege declaratie"
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, fuzzy, gcc-internal-format
 #| msgid "unterminated format string"
 msgid "null format string"
@@ -27739,12 +27739,12 @@ msgstr "%qs is geen geldige pointer-modus"
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -28516,7 +28516,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "ongeldig gebruik van %<restrict%>"
@@ -28860,17 +28860,17 @@ msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 msgid "mismatching definition"
 msgstr "beginwaarde ontbreekt"
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr ""
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, gcc-internal-format
 msgid "IPA modref summary is missing in input file"
 msgstr ""
@@ -29948,77 +29948,77 @@ msgstr "kan bestand '%s' niet openen"
 msgid "error closing optimization records %qs"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, fuzzy, gcc-internal-format
 #| msgid "command line option %qs is not supported by this configuration"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "opdrachtregeloptie %qs wordt niet ondersteund door deze configuratie"
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "ontbrekend argument bij %qs"
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs should be a non-negative integer"
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr "argument van %qs moet een niet-negatieve integer zijn"
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer"
 msgstr "argument van %qs moet een niet-negatieve integer zijn"
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is not between %d and %d"
 msgstr "-malign-loops=%d ligt niet tussen 0 en %d"
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument in option %qs"
 msgid "invalid argument in option %qs"
 msgstr "niet-herkend argument bij optie %qs"
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr ""
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, gcc-internal-format
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr ""
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, gcc-internal-format
 msgid "unrecognized argument in option %qs"
 msgstr "niet-herkend argument bij optie %qs"
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, fuzzy, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute larger than %d"
 msgid "argument to %qs is bigger than %d"
 msgstr "argument van attribuut %qE is groter dan %d"
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, gcc-internal-format
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
 msgstr ""
@@ -30096,8 +30096,8 @@ msgstr "argument voor \"%s\" moet een niet-negatieve integer zijn"
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with %qs"
 msgstr "case-selector niet compatibel met label"
@@ -30819,7 +30819,7 @@ msgstr "globale registervariabele volgt op een functiedefinitie"
 msgid "register of %qD used for multiple global register variables"
 msgstr "registernaam opgegeven voor niet-registervariabele %qs"
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "conflicterende types voor %qs"
@@ -31272,42 +31272,42 @@ msgstr ""
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "__builtin_saveregs wordt niet ondersteund door dit doelsysteem"
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, fuzzy, gcc-internal-format
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, fuzzy, gcc-internal-format
 msgid "nested functions not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, fuzzy, gcc-internal-format
 msgid "nested function trampolines not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, fuzzy, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, fuzzy, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, fuzzy, gcc-internal-format
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, fuzzy, gcc-internal-format
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC target%> is not supported for this machine"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
@@ -32439,83 +32439,83 @@ msgstr ""
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr ""
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr ""
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr ""
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr ""
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr ""
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr ""
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr ""
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr ""
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr ""
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr ""
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr ""
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr ""
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, fuzzy, gcc-internal-format
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr "inline maken mislukt in oproep van %qs"
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr "van hieruit opgeroepen"
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "called from this function"
 msgstr "van hieruit opgeroepen"
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, fuzzy, gcc-internal-format
 msgid "inlining failed in call to %q+F: %s"
 msgstr "inline maken mislukt in oproep van %qs"
@@ -32573,27 +32573,27 @@ msgstr "ongeldig element-type voor attribuut %qs"
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr "ongeldig element-type voor attribuut %qs"
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, fuzzy, gcc-internal-format
 msgid "in a call to non-static member function %qD"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, fuzzy, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, fuzzy, gcc-internal-format
 msgid "in a call to function %qD declared %qs"
 msgstr "%Jgeneste functie %qD gedeclareerd maar niet gedefinieerd"
@@ -32799,7 +32799,7 @@ msgstr "parameter %qD krijgt beginwaarde"
 msgid "%qs may be used uninitialized"
 msgstr "%qs is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, fuzzy, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -33031,7 +33031,7 @@ msgstr ""
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -33046,122 +33046,122 @@ msgstr ""
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "arrays van functies zijn niet betekenisvol"
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, gcc-internal-format
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, gcc-internal-format
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr ""
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, fuzzy, gcc-internal-format
 msgid "%qD is unavailable: %s"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, fuzzy, gcc-internal-format
 msgid "%qD is unavailable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, fuzzy, gcc-internal-format
 msgid "%qE is unavailable: %s"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, fuzzy, gcc-internal-format
 msgid "%qE is unavailable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type is unavailable: %s"
 msgstr "kan bestand '%s' niet openen"
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, fuzzy, gcc-internal-format
 msgid "type is unavailable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
@@ -33186,262 +33186,262 @@ msgstr "functie-oproep heeft geaggregeerde waarde"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, fuzzy, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, fuzzy, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type %s is not an opaque type"
 msgstr "%qs is geen iterator"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type %s is not with opaque mode"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr ""
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr ""
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, fuzzy, gcc-internal-format
 msgid "main variant is not defined"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, fuzzy, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "%qs heeft een onvolledig type"
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -33659,7 +33659,7 @@ msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr ""
@@ -33876,7 +33876,7 @@ msgstr "attribuut %qE wordt genegeerd omdat %qT reeds gedefinieerd is"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "attribuut %qE wordt genegeerd omdat %qT reeds gedefinieerd is"
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr ""
@@ -34069,7 +34069,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr "attribuut %qE kan niet opgegeven worden voor lokale variabelen"
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for local variables"
 msgstr "attribuut %qE kan niet opgegeven worden voor lokale variabelen"
@@ -34407,7 +34407,7 @@ msgstr "%<%.*s%> is niet gedefinieerd"
 msgid "%qE argument is not a function"
 msgstr "het argument van %<cleanup%> is geen functie"
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
@@ -34936,7 +34936,7 @@ msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr "ISO C staat geen extra %<;%> buiten een functie toe"
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, gcc-internal-format
 msgid "invalid application of %qs to a void type"
 msgstr "ongeldige toepasing van %qs op een void-type"
@@ -35069,17 +35069,17 @@ msgstr ""
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, fuzzy, gcc-internal-format
@@ -35204,167 +35204,167 @@ msgstr "poging om het adres te nemen van lid %qs van een bitveld-structure"
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, fuzzy, gcc-internal-format
 msgid "size of array is too large"
 msgstr "omvang van array %qs is te groot"
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "incompatibel type voor argument %d van %qE"
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, fuzzy, gcc-internal-format
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "%s maakt pointer van integer zonder een cast"
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, fuzzy, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr "%<defined%> zonder een naam"
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr ""
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr ""
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, fuzzy, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "doorgeven van argument %d van %qs"
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "ongeldig type-argument %qs"
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "indexwaarde valt buiten bereik"
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, fuzzy, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr "grootte van array %qs is negatief"
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array is negative"
 msgstr "grootte van array %qs is negatief"
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "grootte van array %qs is negatief"
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -36001,7 +36001,7 @@ msgstr "integerconstante is zo groot dat hij unsigned is"
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr "integerconstante is zo groot dat hij unsigned is"
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, fuzzy, gcc-internal-format
 msgid "%<_BitInt(%d)%> is not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
@@ -36081,7 +36081,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr "traditionele C verwerpt het aaneenplakken van stringconstantes"
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -36136,7 +36136,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ongeldig type voor iteratie-variabele %qE"
@@ -36152,17 +36152,17 @@ msgstr "ongeldig type voor iteratie-variabele %qE"
 msgid "%qE is not initialized"
 msgstr "parameter %qD krijgt beginwaarde"
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Ongeldig token in expressie"
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Ongeldig token in expressie"
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "toewijzingsonderdrukking"
@@ -36172,7 +36172,7 @@ msgstr "toewijzingsonderdrukking"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Ongeldig token in expressie"
@@ -36260,7 +36260,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -36270,7 +36270,7 @@ msgstr ""
 msgid "%qD is not a function argument"
 msgstr "%qs is geen iterator"
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "bitveld %qs heeft een ongeldig type"
@@ -36875,7 +36875,7 @@ msgid "wrong type argument to %s"
 msgstr "argument van verkeerd type voor abs"
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -37816,35 +37816,35 @@ msgstr "vergelijking tussen %qT en %qT"
 
 #: c-family/c-warn.cc:3832
 #, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3836
+#: c-family/c-warn.cc:3839
 #, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr ""
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr ""
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr ""
@@ -38065,117 +38065,117 @@ msgstr "-mregparm=%d ligt niet tussen 0 en %d"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, gcc-internal-format
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, gcc-internal-format
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, gcc-internal-format
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr "optie -mcpu=%s geeft conflicten met optie -mtune="
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr "optie -mcpu=%s geeft conflicten met optie -mtune="
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, gcc-internal-format
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, fuzzy, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr ""
@@ -38580,13 +38580,13 @@ msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC optimize%> is not a string or number"
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC optimize%> is geen string of getal"
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, fuzzy, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "misvormde #pragma pack"
@@ -39157,7 +39157,7 @@ msgstr ""
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
@@ -39235,12 +39235,12 @@ msgid "unknown tuning option (%s)"
 msgstr "onbekende spec-functie '%s'"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
@@ -39251,7 +39251,7 @@ msgid "specify a system register with a small string length"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
@@ -39433,9 +39433,9 @@ msgstr ""
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "het argument van %<alias%> is geen string"
@@ -39487,18 +39487,18 @@ msgid "virtual function multiversioning not supported"
 msgstr "-pipe wordt niet ondersteund"
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
@@ -39511,8 +39511,8 @@ msgstr ""
 msgid "lane %wd out of range %wd - %wd"
 msgstr "operandnummer buiten bereik"
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, fuzzy, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "niet-ondersteunde versie"
@@ -39522,7 +39522,7 @@ msgstr "niet-ondersteunde versie"
 msgid "GCC does not currently support return type %qT for simd"
 msgstr "ongebruikte argumenten in $-stijl formaat"
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "ongebruikte argumenten in $-stijl formaat"
@@ -39532,7 +39532,7 @@ msgstr "ongebruikte argumenten in $-stijl formaat"
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr "ongebruikte argumenten in $-stijl formaat"
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "ongebruikte argumenten in $-stijl formaat"
@@ -39624,8 +39624,8 @@ msgstr "L%d cache-latency niet gekend voor %s"
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "slechte waarde %qs voor -mmeroy-latency"
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr ""
@@ -39746,18 +39746,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "het argument van %<asm%> is geen constante string"
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -39875,7 +39875,7 @@ msgid "argument of %qE attribute is missing"
 msgstr "argument van attribuut %qE is geen string-constante"
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "herhalings-aantal is geen integerconstante"
@@ -39898,23 +39898,23 @@ msgstr "attribuut %qE is enkel van toepassing op functie-types"
 msgid "argument of %qE attribute ignored"
 msgstr "attribuut %qE wordt genegeerd"
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "attribuut %qE is enkel van toepassing op variabelen"
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, fuzzy, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, fuzzy, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "ongeldig gebruik van %<restrict%>"
@@ -40158,7 +40158,7 @@ msgstr "doel-CPU ondersteunt geen interworking"
 msgid "target CPU does not support unaligned accesses"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, fuzzy, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr "doel-CPU ondersteunt geen interworking"
@@ -40210,7 +40210,7 @@ msgstr "Grens voor structure-grootte kan enkel op 8 of 32 insgesteld worden"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "case-selector niet compatibel met label"
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
@@ -40317,7 +40317,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -40362,42 +40362,42 @@ msgstr "attribuut %qE is enkel van toepassing op geïnitialiseerde variabelen di
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "attribuut %qE is enkel van toepassing op functie-types"
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "ongeldige operand van %s"
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "ongeldig type-argument %qs"
@@ -40405,24 +40405,24 @@ msgstr "ongeldig type-argument %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qs"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "ongeldig vector-type voor attribuut %qs"
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of #pragma %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "rommel aan einde van #pragma %s"
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
@@ -40476,162 +40476,162 @@ msgstr ""
 msgid "unknown core architecture %qs specified with %qs"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, fuzzy, gcc-internal-format
 msgid "%<-fpic%> is not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, fuzzy, gcc-internal-format
 msgid "%<-fPIC%> is not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, fuzzy, gcc-internal-format
 msgid "%<-fpie%> is not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, fuzzy, gcc-internal-format
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-G en -static sluiten elkaar uit"
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "functie %qs kan geen waarde teruggeven"
 
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, gcc-internal-format
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr ""
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, gcc-internal-format
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, fuzzy, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "de zwakke declaratie van %qs moet publiek zijn"
 
 # goede vertaling van variadic?
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables and functions"
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "attribuut %qE is enkel van toepassing op variabelen en functies"
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "%Jsectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute does not apply to types"
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr "attribuut %qE heeft geen betekenis voor types"
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables"
 msgid "%qE attribute on non-volatile variable"
 msgstr "attribuut %qE is enkel van toepassing op variabelen"
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, fuzzy, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, fuzzy, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, gcc-internal-format
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr ""
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, gcc-internal-format
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, fuzzy, gcc-internal-format
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr "Enkel variabelen met beginwaarde kunnen in het 8-bit gebied geplaatst worden."
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr "Enkel variabelen met beginwaarde kunnen in het 8-bit gebied geplaatst worden."
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "Enkel variabelen met beginwaarde kunnen in het 8-bit gebied geplaatst worden."
@@ -40640,43 +40640,43 @@ msgstr "Enkel variabelen met beginwaarde kunnen in het 8-bit gebied geplaatst wo
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, fuzzy, gcc-internal-format
 #| msgid "%qE incompatible attribute ignored"
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "incompatibel attribuut %qE wordt genegeerd"
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, fuzzy, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, fuzzy, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "ongeldige registernaam voor %qs"
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "ongeldige registernaam voor %qs"
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -40819,7 +40819,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr ""
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, fuzzy, gcc-internal-format
@@ -41458,8 +41458,8 @@ msgstr "%<defined%> zonder een naam"
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
@@ -41525,263 +41525,263 @@ msgstr "Bestandsnaam voor uitvoer twee keer opgegeven"
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, fuzzy, gcc-internal-format
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, fuzzy, gcc-internal-format
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, fuzzy, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, fuzzy, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, fuzzy, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d ligt niet tussen 0 en %d"
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, fuzzy, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "case-selector niet compatibel met label"
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, fuzzy, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr ""
@@ -41789,295 +41789,295 @@ msgstr ""
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr ""
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, fuzzy, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "case-selector niet compatibel met label"
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, fuzzy, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, fuzzy, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "onbekende machine-modus %qs"
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr ""
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, fuzzy, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "case-selector niet compatibel met label"
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, fuzzy, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s en -mcall-%s zijn incompatibel"
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s en -mcall-%s zijn incompatibel"
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, fuzzy, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "argument van attribuut %qE is groter dan %d"
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, fuzzy, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, fuzzy, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, fuzzy, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, fuzzy, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
 # XXX FIXME, ERROR:  s/none /non-/
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "attribuut %qE is gebruikt voor non-class-methode"
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "incompatibel attribuut %qE wordt genegeerd"
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "attribuut %qE is alleen beschikbaar voor 32-bits"
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "attribuut %qE vereist een string-constante als argument"
 
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "de '-%c' moet een argument hebben"
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
@@ -42268,46 +42268,46 @@ msgstr ""
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "herdefinitie van %<union %s%>"
 
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, gcc-internal-format
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr ""
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr ""
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr ""
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "onbekende machine-modus %qs"
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr ""
@@ -42327,8 +42327,8 @@ msgstr "%qs is geen static veld"
 msgid "malformed %<#pragma builtin%>"
 msgstr "misvormde #pragma weak"
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, fuzzy, gcc-internal-format
 msgid "invalid argument of %qE attribute"
 msgstr "ongeldig type-argument %qs"
@@ -42383,12 +42383,12 @@ msgstr "onbekende spec-functie '%s'"
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr ""
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "Alignment moet een kleine macht van twee zijn, en niet %d, in #pragma pack"
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, fuzzy, gcc-internal-format
 msgid "failed to expand built-in function"
 msgstr "veld %qs als een functie gedeclareerd"
@@ -42514,19 +42514,19 @@ msgstr "%<%.*s%> is niet gedefinieerd"
 msgid "%qs cannot be used for compiling a shared library"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr "attribuut %qE kan niet opgegeven worden voor lokale variabelen"
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for register variables"
 msgstr "attribuut %qE kan niet opgegeven worden voor lokale variabelen"
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, fuzzy, gcc-internal-format
 msgid "multiple %qE attribute"
 msgstr "herhaalde label-declaratie %qs"
@@ -42631,12 +42631,12 @@ msgstr "meerdere interrupt-attributen zijn niet toegestaan"
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, fuzzy, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, fuzzy, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
@@ -42677,7 +42677,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr ""
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires a string constant argument"
 msgid "%qE attribute requires a string argument"
@@ -42720,132 +42720,132 @@ msgstr ""
 msgid "argument to %qE attribute is not intstack"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, fuzzy, gcc-internal-format
 msgid "cannot handle inconsistent calls to %qs"
 msgstr "kan oproep van %qs niet inline maken"
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr ""
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr ""
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr ""
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE not supported for MIPS16"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, fuzzy, gcc-internal-format
 msgid "%qs does not support MIPS16 code"
 msgstr "%s ondersteunt %s niet"
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr ""
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, gcc-internal-format
 msgid "MIPS16 %<-mxgot%> code"
 msgstr ""
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, gcc-internal-format
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr ""
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, gcc-internal-format
 msgid "MSA MIPS16 code"
 msgstr ""
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, gcc-internal-format
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr ""
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported combination: %s"
 msgstr "niet-ondersteunde versie"
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, gcc-internal-format
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr ""
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr "case-selector niet compatibel met label"
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr ""
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, gcc-internal-format
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, fuzzy, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr "macro %qs gebruikt zonder argumenten"
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr ""
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr ""
@@ -42855,117 +42855,117 @@ msgstr ""
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, fuzzy, gcc-internal-format
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr "case-selector niet compatibel met label"
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, fuzzy, gcc-internal-format
 msgid "unsupported combination: %qs%s %s"
 msgstr "niet-ondersteunde versie"
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, fuzzy, gcc-internal-format
 msgid "unsupported combination: %qs %s"
 msgstr "niet-ondersteunde versie"
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, fuzzy, gcc-internal-format
 msgid "cannot generate position-independent code for %qs"
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, fuzzy, gcc-internal-format
 msgid "position-independent code requires %qs"
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr ""
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, gcc-internal-format
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr ""
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, fuzzy, gcc-internal-format
 msgid "%qs must be used with %qs"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, gcc-internal-format
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr ""
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr ""
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support DSP instructions"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, gcc-internal-format
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr ""
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, gcc-internal-format
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr ""
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, fuzzy, gcc-internal-format
 msgid "%qs requires branch-likely instructions"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support the synci instruction"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr ""
@@ -43864,57 +43864,57 @@ msgstr "%<#pragma GCC optimize%> is geen string of getal"
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "rommel aan einde van %<#pragma reset_options%>"
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, gcc-internal-format
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, gcc-internal-format
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, fuzzy, gcc-internal-format
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> attribute"
 msgstr "ongeldig type-argument %qs"
 
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "het argument van %<alias%> is geen string"
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, gcc-internal-format
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> attribute"
 msgstr "misvormde #pragma pack"
@@ -43976,173 +43976,193 @@ msgstr "kon 0x%l.8x niet naar een regio omzetten"
 msgid "capture by copy of RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, fuzzy, gcc-internal-format
 msgid "no matching function call to %qE with empty arguments"
 msgstr "ongeldig type-argument %qs"
 
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, fuzzy, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, gcc-internal-format
 msgid "this operation requires the RVV ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr "AltiVec argument doorgegeven aan functie zonder prototype"
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the V ISA extension"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, gcc-internal-format
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, gcc-internal-format
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, gcc-internal-format
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, gcc-internal-format
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr ""
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, fuzzy, gcc-internal-format
 msgid "function attribute %qs requires the V ISA extension"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "het argument van %<asm%> is geen constante string"
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr ""
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, fuzzy, gcc-internal-format
 msgid "%qs applied to non-RVV type %qT"
 msgstr "%<%c%> optie gebruikt bij type %<%c%>"
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, fuzzy, gcc-internal-format
 msgid "%qs requires an integer constant"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, fuzzy, gcc-internal-format
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, fuzzy, gcc-internal-format
 msgid "code model %qs with %qs"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, gcc-internal-format
 msgid "rv64e requires lp64e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr ""
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr ""
@@ -44396,32 +44416,32 @@ msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, gcc-internal-format
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
@@ -44461,29 +44481,22 @@ msgstr "ongeldige operanden voor binaire %s-operator"
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, gcc-internal-format
-msgid "%qs requires the ELFv2 ABI"
-msgstr ""
-
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, fuzzy, gcc-internal-format
 msgid "stack frame too large"
 msgstr "bestand %qs is te groot"
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported number of nops before function entry (%u)"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, fuzzy, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%<__thread%> samen met %<register%> gebruikt"
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
@@ -44610,107 +44623,117 @@ msgstr "-fPIC is niet geldig met -mcoff"
 msgid "unknown option for %<%s=%s%>"
 msgstr "onbekende machine-modus %qs"
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4837
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4855
 #, fuzzy, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, fuzzy, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "ongeldig gebruik van '%%%c'"
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "spec '%s' is ongeldig"
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "spec '%s' is ongeldig"
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
@@ -44756,7 +44779,7 @@ msgstr ""
 msgid "builtin %qs can only be used on vector types"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -44826,229 +44849,229 @@ msgstr "%<%.*s%> is niet gedefinieerd"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "te veel argumenten voor procedure `%s'"
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr "argument %d is alleen-lezen"
 
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr "te veel argumenten voor procedure `%s'"
 
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr "te veel argumenten voor procedure `%s'"
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher"
 msgstr ""
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher"
 msgstr ""
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, fuzzy, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, fuzzy, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "slechte conditiecode"
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, fuzzy, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "gevraagde positie is geen integerconstante"
 
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr ""
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr ""
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr ""
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, fuzzy, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, fuzzy, gcc-internal-format
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "argument van %qs moet een niet-negatieve integer zijn"
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "argument van %qs is te groot (max. %d)"
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr "het argument van %<alias%> is geen string"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, fuzzy, gcc-internal-format
 msgid "invalid cc output constraint: %qs"
 msgstr "twee %<u%>s in integerconstante"
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, fuzzy, gcc-internal-format
 #| msgid "multiple interrupt attributes not allowed"
 msgid "multiple cc output constraints not supported"
 msgstr "meerdere interrupt-attributen zijn niet toegestaan"
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr "type-qualifiers voor %qs geven een conflict met een eerdere declaratie"
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, fuzzy, gcc-internal-format
 msgid "invalid type for cc output constraint"
 msgstr "ongeldig gebruik van %<restrict%>"
@@ -45488,8 +45511,8 @@ msgstr "attribuut %qE heeft geen effect"
 msgid "attribute %qs applies to array types only"
 msgstr "attribuut %qs is enkel van toepassing op array-types"
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void-waarde niet genegeerd zoals het hoort"
@@ -45565,7 +45588,7 @@ msgstr ""
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, fuzzy, gcc-internal-format
 msgid "originally defined here"
 msgstr "functie-definitie als %<typdef%> gedeclareerd"
@@ -45803,7 +45826,7 @@ msgstr "%Jdeclaratie van %qD verbergt een eerdere niet-variabele"
 msgid "declaration of %qD shadows a parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "de declaratie van %qs verbergt een parameter"
@@ -45813,7 +45836,7 @@ msgstr "de declaratie van %qs verbergt een parameter"
 msgid "declaration of %qD shadows a previous local"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, fuzzy, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "%Jde verborgen declaratie is hier"
@@ -45879,7 +45902,7 @@ msgstr "%qE is hier niet gedeclareerd (eerste gebruik in deze functie)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "(Elke niet-gedeclareerde naam wordt slechts één"
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, fuzzy, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "naar label %s gerefereerd buiten enige functie"
@@ -45914,7 +45937,7 @@ msgstr "overflow in constante expressie"
 msgid "duplicate label declaration %qE"
 msgstr "herhaalde label-declaratie %qs"
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, fuzzy, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "herhaald label %qs"
@@ -45949,7 +45972,7 @@ msgstr "overflow in constante expressie"
 msgid "%qE defined as wrong kind of tag"
 msgstr ""
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute applied to %qD with void return type"
@@ -46101,12 +46124,12 @@ msgstr "ISO C90 ondersteunt geen %<[*]%> declaratoren van arrays"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, fuzzy, gcc-internal-format
 msgid "%<omp::%s%> not allowed to be specified in this context"
 msgstr "%<%.*s%> is niet gedefinieerd"
@@ -46116,7 +46139,7 @@ msgstr "%<%.*s%> is niet gedefinieerd"
 msgid "%q+D is usually a function"
 msgstr "%J%qD is meestal een functie"
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%Jgeen eerdere declaratie voor %qD"
@@ -46194,7 +46217,7 @@ msgstr "een object met een volatile veld kan niet in een register geplaatst word
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "ongeïnitialiseerde const %qD is ongeldig in C++"
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -46380,7 +46403,7 @@ msgstr "opslagklasse opgegeven voor parameter %qs"
 msgid "storage class specified for unnamed parameter"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "opslagklasse opgegeven voor typenaam"
@@ -46443,7 +46466,7 @@ msgstr "%qs wordt gedeclareerd als een array van functies"
 msgid "declaration of type name as array of functions"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "ongeldig gebruik van strcture met flexibel array-lid"
@@ -46550,7 +46573,7 @@ msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 msgid "function definition has qualified void return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typekwalificaties op teruggeeftypes van functies worden genegeerd"
@@ -46678,7 +46701,7 @@ msgstr "ISO C verbiedt %<const%> of %<volatile%> functie-types"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, fuzzy, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variabele of veld %qs als void gedeclareerd"
@@ -46784,7 +46807,7 @@ msgstr "argument %d is alleen-lezen"
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "functie-declaratie is geen prototype"
@@ -46874,17 +46897,17 @@ msgstr "geneste herdefinitie van %<union %s%>"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "geneste herdefinitie van %<struct %s%>"
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, fuzzy, gcc-internal-format
 msgid "%qT defined in underspecified object initializer"
 msgstr "onbekend veld %qs opgegeven in beginwaarde"
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "declaratie declareert niets"
@@ -46914,605 +46937,605 @@ msgstr ""
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union heeft geen benoemde leden"
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union heeft geen leden"
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "struct heeft geen benoemde leden"
 
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct heeft geen leden"
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "%Jflexibel array-lid in union"
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, fuzzy, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "%Jflexibel array-lid niet aan het eind van de struct"
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "%Jflexibel array-lid in union"
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, fuzzy, gcc-internal-format
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr "%Jflexibel array-lid niet aan het eind van de struct"
 
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "omvang van array %qs is te groot"
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, gcc-internal-format
 msgid "type punning toggles scalar storage order"
 msgstr ""
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union kan niet transparant gemaakt worden"
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, fuzzy, gcc-internal-format
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, fuzzy, gcc-internal-format
 msgid "redefinition of struct or union %qT"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "geneste herdefinitie van %<enum %qs%>"
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "herdeclaratie van %<enum %qs%>"
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
 msgstr "opgegeven modus is te klein voor enumeratiewaarden"
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "enumeratiewaarden overschrijden het bereik van de grootste integer"
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration values exceed range of largest integer"
 msgid "enumeration values exceed range of %qs"
 msgstr "enumeratiewaarden overschrijden het bereik van de grootste integer"
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, fuzzy, gcc-internal-format
 msgid "conflicting redefinition of enum %qT"
 msgstr "geneste herdefinitie van %<enum %qs%>"
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "overflow in enumeratiewaarden"
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration values exceed range of largest integer"
 msgid "enumerator value outside the range of underlying type"
 msgstr "enumeratiewaarden overschrijden het bereik van de grootste integer"
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "enumerator value outside the range of %qs"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "%J%<noinline%> attribuut gegeven aan ingebouwde functie %qD"
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "teruggeeftype is onvolledig"
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "teruggeeftype krijgt standaardwaarde %<int%>"
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, fuzzy, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, fuzzy, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "%Jgeen eerder prototype voor %qD"
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%J%qD werd voor haar definitie gebruikt zonder protoype"
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%J%qD werd voor haar definitie gebruikt zonder declaratie"
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "%Jteruggeeftype van %qD is niet %<int%>"
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "ISO C verbiedt gekwalificeerde functie-types"
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, fuzzy, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%J%qD is gewoonlijk een niet-static funtie"
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, fuzzy, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "%Jparameterdeclaraties in oude stijl gebruikt in de definitie van een functie die een prototype heeft"
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, fuzzy, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "%Jtraditionele C verwerpt functiedefinities in de stijl van ISO C"
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr ""
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, fuzzy, gcc-internal-format
 msgid "old-style function definition"
 msgstr "%Jfunctiedefinitie in oude stijl"
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, fuzzy, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "%Jparameternaam ontbreekt in parameterlijst"
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%J%qD als niet-parameter gedeclareerd"
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "%Jmeerdere parameters hebben de naam %qD"
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "%Jparameter %qD als void gedeclareerd"
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, fuzzy, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "%Jtype van %qD krijgt standaardtype %<int%>"
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "%Jparameter %qD heeft een onvolledig type"
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, fuzzy, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "%Jdeclaratie voor parameter %qD maar er is zo geen parameter"
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, fuzzy, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "aantal argumenten kom niet overeen met prototype"
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "aantal argumenten kom niet overeen met prototype"
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, fuzzy, gcc-internal-format
 msgid "prototype declaration"
 msgstr "%Hdeclaratie van prototype"
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, fuzzy, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "gepromoveerd argument %qD komt niet overeen met prototype"
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "gepromoveerd argument %qD komt niet overeen met prototype"
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, fuzzy, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parameter %qD krijgt beginwaarde"
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "initiële declaratie voor %<for%> lus gebruikt buiten C99 modus"
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 ondersteunt geen %<[*]%> declaratoren van arrays"
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, fuzzy, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%qs als 'inline' gedeclareerd na de definitie"
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, fuzzy, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%qs als 'inline' gedeclareerd na de definitie"
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, fuzzy, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%qs als 'inline' gedeclareerd na de definitie"
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, fuzzy, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, fuzzy, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %<auto%>"
 msgstr "%<__thread%> samen met %<auto%> gebruikt"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> used with %<constexpr%>"
 msgstr "%<__thread%> samen met %<register%> gebruikt"
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "twee of meer data types opgegeven bij declaratie"
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> is te lang voor GCC"
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 ondersteunt geen complexe types"
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "herhaalde %qs"
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 ondersteunt geen complexe types"
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, fuzzy, gcc-internal-format
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, fuzzy, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr ""
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
 # is letterlijke vertaling maar klinkt zo vreemd...
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, fuzzy, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qs slaagt er niet in een typedef of ingebouwd type te zijn"
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, fuzzy, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> samen met %<auto%> gebruikt"
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> samen met %<register%> gebruikt"
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> samen met %<typedef%> gebruikt"
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<constexpr%>"
 msgstr "%<__thread%> samen met %<register%> gebruikt"
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "%s ondersteunt %s niet"
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> vóór %<extern%> gebruikt"
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> vóór %<static%> gebruikt"
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> used with %<auto%>"
 msgstr "%<__thread%> samen met %<auto%> gebruikt"
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<extern%>"
 msgstr "%<__thread%> samen met %<register%> gebruikt"
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %qs"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> used with %qE"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, fuzzy, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<__thread%> samen met %<auto%> gebruikt"
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ondersteunt gewone %<complex%> niet in de betekenis van %<double complex%>"
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, fuzzy, gcc-internal-format
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr "%<defined%> zonder een naam"
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr "ISO C++ ondersteunt %<long long%> niet"
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "teller van links shift is negatief"
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "teller van links shift is negatief"
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "teller van rechtse shift is negatief"
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "teller van links shift is >= breedte van het type"
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "teller van rechtse shift is >= breedte van het type"
@@ -47544,7 +47567,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "ongeldige operand van %s"
@@ -47554,8 +47577,8 @@ msgstr "ongeldige operand van %s"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C verbiedt een leeg bronbestand"
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr ""
@@ -47596,9 +47619,9 @@ msgstr "onbekende machine-modus %qs"
 msgid "unknown type name %qE"
 msgstr "onbekende machine-modus %qs"
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "meerdere opslagklassen in declaratie van %qs"
@@ -47628,7 +47651,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -47649,7 +47672,7 @@ msgstr "ongeldige operand van %s"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "sectie-attribuut is niet toegestaan voor %q+D"
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<assume%> attribute not followed by %<;%>"
@@ -47743,7 +47766,7 @@ msgstr "beginwaarde-element is niet constant"
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, fuzzy, gcc-internal-format
 msgid "static assertion failed"
 msgstr "pex_init mislukt"
@@ -47814,10 +47837,10 @@ msgstr "argument %d is alleen-lezen"
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "ongeldige operand van %s"
@@ -47971,7 +47994,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr ""
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr ""
@@ -47981,8 +48004,8 @@ msgstr ""
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs attribute argument"
 msgstr ""
@@ -48157,12 +48180,12 @@ msgstr "ISO C verbiedt het weglaten van de middelste term van een ?: expresie"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, fuzzy, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -48313,7 +48336,7 @@ msgstr "ISO C90 ondersteunt %<long long%> niet"
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, fuzzy, gcc-internal-format
 msgid "expected expression"
 msgstr "ongeldige waarheidsexpressie"
@@ -48639,12 +48662,12 @@ msgstr "meerdere opslagklassen in declaratie van %qs"
 msgid "no type or storage class may be specified here,"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr ""
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, fuzzy, gcc-internal-format
 msgid "missing property attribute"
 msgstr "beginwaarde ontbreekt"
@@ -48654,57 +48677,57 @@ msgstr "beginwaarde ontbreekt"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "onbekende operator '%s' in %%:version-compare"
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, fuzzy, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr "herdeclaratie van %qs"
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr ""
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "misvormde #pragma pack(pop[,id])"
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -48714,25 +48737,25 @@ msgstr ""
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "overflow in constante expressie"
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "misvormde #pragma pack(pop[,id])"
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "te veel invoerbestanden"
@@ -48747,63 +48770,63 @@ msgstr "%<defined%> zonder een naam"
 msgid "expected %<)%> or %<,%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, fuzzy, gcc-internal-format
 msgid "expected constant logical expression"
 msgstr "ongeldige waarheidsexpressie"
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -48826,22 +48849,22 @@ msgstr ""
 msgid "%<num_tasks%> value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, fuzzy, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "ongeldige waarheidsexpressie"
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr ""
@@ -48851,95 +48874,95 @@ msgstr ""
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "te veel argumenten voor formaat"
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, fuzzy, gcc-internal-format
 msgid "too many %<self%> clauses"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, fuzzy, gcc-internal-format
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, fuzzy, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, fuzzy, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "zowel %<long%> als %<void%> opgegeven bij declaratie"
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ongeldige const_double operand"
@@ -48949,22 +48972,22 @@ msgstr "ongeldige const_double operand"
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr ""
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, fuzzy, gcc-internal-format
 msgid "expected %<allocator%> or %<align%>"
 msgstr "ongeldige operand van %s"
@@ -48975,22 +48998,22 @@ msgstr "ongeldige operand van %s"
 msgid "duplicate %qs modifier"
 msgstr "herhaalde %qs"
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, fuzzy, gcc-internal-format
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, fuzzy, gcc-internal-format
 msgid "multiple linear modifiers"
 msgstr "herhaalde case-waarde"
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, fuzzy, gcc-internal-format
 msgid "multiple %<step%> modifiers"
 msgstr "herhaalde case-waarde"
@@ -49010,63 +49033,63 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, fuzzy, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "case-selector niet compatibel met label"
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ongeldige const_double operand"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, fuzzy, gcc-internal-format
 msgid "invalid doacross kind"
 msgstr "ongeldige const_double operand"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, fuzzy, gcc-internal-format
 msgid "too many %<always%> modifiers"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, fuzzy, gcc-internal-format
 msgid "too many %<close%> modifiers"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<present%> modifiers"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr ""
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr ""
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, fuzzy, gcc-internal-format
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, gcc-internal-format
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr ""
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ongeldige const_double operand"
@@ -49081,88 +49104,88 @@ msgstr "ongeldige const_double operand"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, fuzzy, gcc-internal-format
 msgid "expected an OpenACC clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, fuzzy, gcc-internal-format
 msgid "expected an OpenMP clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "lege declaratie"
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "ongeldige linker operand van %s"
 
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr ""
@@ -49177,7 +49200,7 @@ msgstr "%<%.*s%> is niet gedefinieerd"
 msgid "expected function name"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qs is meestal een functie"
@@ -49187,22 +49210,22 @@ msgstr "%qs is meestal een functie"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
@@ -49227,7 +49250,7 @@ msgstr ""
 msgid "modified here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, fuzzy, gcc-internal-format
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
 msgstr "expressie-statement heeft onvolledig type"
@@ -49267,110 +49290,110 @@ msgstr ""
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr ""
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, fuzzy, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, fuzzy, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, fuzzy, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, fuzzy, gcc-internal-format
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr "case-selector niet compatibel met label"
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, fuzzy, gcc-internal-format
 msgid "%qs clause requires %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, fuzzy, gcc-internal-format
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr "conflicterende declaraties van %qs"
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, gcc-internal-format
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr ""
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, fuzzy, gcc-internal-format
 msgid "unexpected %<else%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr ""
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "beginwaarde-element is niet constant"
@@ -49380,27 +49403,27 @@ msgstr "beginwaarde-element is niet constant"
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr ""
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr ""
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, fuzzy, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, fuzzy, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -49410,163 +49433,163 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr ""
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, fuzzy, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr ""
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "herdeclaratie van %qs"
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, fuzzy, gcc-internal-format
 msgid "not enough nested loops"
 msgstr "geen argumenten"
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "overflow in constante expressie"
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr ""
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, fuzzy, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "herdeclaratie van %qs"
 
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, fuzzy, gcc-internal-format
 msgid "unknown selector %qs for context selector set %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, fuzzy, gcc-internal-format
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, fuzzy, gcc-internal-format
 msgid "%<score%> argument must be constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, fuzzy, gcc-internal-format
 msgid "%<score%> argument must be non-negative"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, fuzzy, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
@@ -49574,290 +49597,290 @@ msgstr ""
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> selector is not supported yet"
 msgstr "__builtin_saveregs wordt niet ondersteund door dit doelsysteem"
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, fuzzy, gcc-internal-format
 msgid "expected context selector set name"
 msgstr "herdeclaratie van %qs"
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, fuzzy, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, fuzzy, gcc-internal-format
 msgid "variant %qD is not a function"
 msgstr "%qs is meestal een functie"
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, fuzzy, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "%Jparameter %qD heeft een onvolledig type"
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, gcc-internal-format
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr ""
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr ""
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, gcc-internal-format
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr ""
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%> or %<assumes%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, fuzzy, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, fuzzy, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr ""
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, gcc-internal-format
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, fuzzy, gcc-internal-format
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, fuzzy, gcc-internal-format
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, fuzzy, gcc-internal-format
 msgid "expected %qs or %qs"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, gcc-internal-format
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr ""
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr ""
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, gcc-internal-format
 msgid "expected at least one assumption clause"
 msgstr ""
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, fuzzy, gcc-internal-format
 msgid "expected directive name"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr ""
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, fuzzy, gcc-internal-format
 msgid "unknown assumption clause %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, fuzzy, gcc-internal-format
 msgid "expected assumption clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, fuzzy, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, fuzzy, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%Jparameter %u heeft een onvolledig type"
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, gcc-internal-format
 msgid "no closing brace"
 msgstr ""
@@ -49999,7 +50022,7 @@ msgstr "%<void *%> pointer wordt gederefereerd"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "waarde met subscript is noch een array, noch een pointer"
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "array subscript is geen integer"
@@ -50029,7 +50052,7 @@ msgstr "%qs als ander soort symbool geherdeclareerd"
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -50143,18 +50166,18 @@ msgstr "ongeldige registernaam voor %qs"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "vergelijking tussen pointer en integer"
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, fuzzy, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "kan niet derefereren, is geen pointer."
@@ -50181,7 +50204,7 @@ msgid "arithmetic on pointer to an incomplete type"
 msgstr "rekensom met pointer naar onvolledig type"
 
 # 'Arithmetic'?? 'rekensom' is wel correct, maar het klinkt zo stom.
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "rekensom met pointer naar onvolledig type"
@@ -50480,7 +50503,7 @@ msgstr "cast van pointer naar integer met andere grootte"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "cast naar pointer van integer met andere grootte"
@@ -50661,7 +50684,7 @@ msgstr ""
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -50868,12 +50891,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "initialisatie van flexibel array-lid"
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -50883,7 +50906,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr "array van ongeschikt type heeft stringconstante als beginwaarde"
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ongeldig gebruik van array die geen lvalue is"
@@ -50914,7 +50937,7 @@ msgstr "beginwaarde-element is niet constant"
 msgid "initializer element is not computable at load time"
 msgstr "beginwaarde-element kan niet berekend worden tijdens het laden"
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
@@ -50929,7 +50952,7 @@ msgstr "extra accolade-groep aan einde van beginwaarde"
 msgid "braces around scalar initializer"
 msgstr "accolades rond scalaire beginwaarde"
 
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "initialisatie van flexibel array-lid in een geneste context"
@@ -51021,7 +51044,7 @@ msgstr "overtollige elementen in beginwaarde van struct"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "niet-statische initialisatie van flexibel array-lid"
@@ -51061,7 +51084,7 @@ msgstr "ISO C verbiedt %<goto *expr;%>"
 msgid "computed goto must be pointer type"
 msgstr "het argument van %<cleanup%> is geen naam"
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, fuzzy, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "als %<noreturn%> gedeclareerde functie bevat een %<return%> statement"
@@ -51117,7 +51140,7 @@ msgstr "default-label niet in een switch-statement"
 msgid "break statement not within loop or switch"
 msgstr "break-statement niet in een lus of switch"
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -51164,27 +51187,27 @@ msgstr ""
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr ""
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "vergelijking tussen types %qT en %qT"
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr ""
@@ -51257,29 +51280,29 @@ msgstr "waarde van union-type gebruikt waar een scalair nodig is"
 msgid "used vector type where scalar is required"
 msgstr "waarde van struct-type gebruikt waar een scalair nodig is"
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, fuzzy, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "ongeldige operand van %s"
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -51290,85 +51313,85 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "te veel invoerbestanden"
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, fuzzy, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "ongeldige operand van %s"
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "%qs is smaller dan waarden van zijn type"
@@ -51378,17 +51401,17 @@ msgstr "%qs is smaller dan waarden van zijn type"
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "ISO C verbiedt gekwalificeerde functie-types"
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr "%Jparameter %qD heeft een onvolledig type"
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, fuzzy, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
@@ -51398,32 +51421,32 @@ msgstr ""
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, fuzzy, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr "ongeldige operand voor 'o' modifier"
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, fuzzy, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr ""
@@ -51453,7 +51476,7 @@ msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "grootte van %qs is %u bytes"
@@ -51463,17 +51486,17 @@ msgstr "grootte van %qs is %u bytes"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
 msgstr ""
@@ -51488,23 +51511,23 @@ msgstr ""
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, gcc-internal-format
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -51516,32 +51539,32 @@ msgstr ""
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -51561,7 +51584,7 @@ msgstr "%qs is geen bestand, pipe of tty"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -51571,7 +51594,7 @@ msgstr "%qs is geen bestand, pipe of tty"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -51581,76 +51604,76 @@ msgstr "%qs is geen bestand, pipe of tty"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr ""
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, fuzzy, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, fuzzy, gcc-internal-format
 msgid "unsupported map expression %qE"
 msgstr "niet-ondersteunde versie"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qs is geen static veld"
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -51665,22 +51688,22 @@ msgstr "grootte van array %qs is van een niet-integraal type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "waarde met subscript is noch een array, noch een pointer"
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr "te veel invoerbestanden"
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
@@ -51690,38 +51713,38 @@ msgstr ""
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
@@ -52001,14 +52024,14 @@ msgstr "ongeldige registernaam voor %qs"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -52322,568 +52345,568 @@ msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "%Jteruggeeftype van %qD is niet %<int%>"
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "vergelijking tussen %q#T en %q#T"
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, fuzzy, gcc-internal-format
 msgid "no match for call to %<%T::operator[] (%A)%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, fuzzy, gcc-internal-format
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "impliciete declaratie van functie %qE"
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr ""
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, fuzzy, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, fuzzy, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, fuzzy, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%s is niet addresseerbaar"
 
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, fuzzy, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, fuzzy, gcc-internal-format
 msgid "  declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "accolades ontbreken rond beginwaarde"
 
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 #, fuzzy
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 #, fuzzy
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr ""
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 #, fuzzy
 msgid "invalid conversion from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "ongeldige registernaam voor %qs"
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 #, fuzzy
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, fuzzy, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr ""
 
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, fuzzy, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "kan oproep van %qs niet inline maken"
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "herhaald lid %qs"
 
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is too large"
 msgid "; use assignment instead"
 msgstr "gevraagd alignment is te groot"
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "dubbele beginwaarde"
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, fuzzy, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "herhaald lid %qs"
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, fuzzy, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "dubbele beginwaarde"
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, gcc-internal-format
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr ""
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 #, fuzzy
 msgid "cannot convert %qH to %qI"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, fuzzy, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, fuzzy, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, gcc-internal-format
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr ""
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, fuzzy, gcc-internal-format
 msgid "try making the operator a %<const%> member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 #, fuzzy
 msgid "  for conversion from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "parameternaam ontbreekt uit parameterlijst"
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr "kandidaat is: %+#D"
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr "kandidaat is: %+#D"
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 #, fuzzy
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 #, fuzzy
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, gcc-internal-format
 msgid "possibly dangling reference to a temporary"
 msgstr ""
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr ""
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, fuzzy, gcc-internal-format
 #| msgid "%s: declaration of function '%s' not converted\n"
 msgid "explicit conversion function was not considered"
@@ -52930,7 +52953,7 @@ msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "eerdere declaratie van %qs"
@@ -53352,7 +53375,7 @@ msgstr "%Jflexibel array-lid in overigens lege struct"
 msgid "next member %q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "herdefinitie van %qs"
@@ -53483,7 +53506,7 @@ msgstr "ongeldige opslagklasse voor functie %qs"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
@@ -53524,7 +53547,7 @@ msgstr ""
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%J%qD is gewoonlijk een niet-static funtie"
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr ""
@@ -53542,7 +53565,7 @@ msgstr "%<register%> in lege declaratie op bestandsniveau"
 msgid "%q+E is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -53563,7 +53586,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
@@ -53610,7 +53633,7 @@ msgstr "%qs is geen bestand, pipe of tty"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -53739,18 +53762,18 @@ msgstr "array subscript is geen integer"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> pointer wordt gederefereerd"
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -53758,469 +53781,469 @@ msgstr "%<void *%> pointer wordt gederefereerd"
 msgid "%qE is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr ""
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr ""
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, fuzzy, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, fuzzy, gcc-internal-format
 msgid "allocated here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
 msgstr ""
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "array-index in beginwaarde van niet-array"
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%qs is geen iterator"
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, fuzzy, gcc-internal-format
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, fuzzy, gcc-internal-format
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr ""
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr ""
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr ""
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, fuzzy, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, fuzzy, gcc-internal-format
 msgid "use of %qD"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr ""
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr ""
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr ""
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr ""
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, gcc-internal-format
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, fuzzy, gcc-internal-format
 msgid "pointed-to object declared here"
 msgstr "%Jeerder hier gebruikt"
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr ""
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, fuzzy, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "ongeldige beginwaarde"
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "functie kan niet inline gemaakt worden"
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, fuzzy, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, fuzzy, gcc-internal-format
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, fuzzy, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, fuzzy, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, fuzzy, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, fuzzy, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "niet-constante array-index in beginwaarde"
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "onverwachte operand"
@@ -54940,7 +54963,7 @@ msgstr "derde argument voor %<__builtin_prefetch%> moet een constante zijn"
 msgid "no suspend point info for %qD"
 msgstr "%Jgeen eerder prototype voor %qD"
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -54961,23 +54984,23 @@ msgstr "pointers zijn niet toegestaan als case-waarden"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, fuzzy, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr "ongeldige registernaam voor %qs"
@@ -54997,69 +55020,69 @@ msgstr ""
 msgid "%qD was promoted to an immediate function"
 msgstr "%qs is meestal een functie"
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, fuzzy, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, fuzzy, gcc-internal-format
 msgid "call to consteval function %qE is not a constant expression"
 msgstr "overflow in constante expressie"
 
 # is de "," deel van de special format spec of niet?  en moet "true" hier vertaald worden of niet?
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, fuzzy, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, fuzzy, gcc-internal-format
 msgid "pack expansion of %qE attribute"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, fuzzy, gcc-internal-format
 msgid "use fold expression in the attribute argument instead"
 msgstr "%qs is geen iterator"
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qs is geen iterator"
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qs is geen iterator"
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
@@ -55104,7 +55127,7 @@ msgstr "ongeldige registernaam voor %qs"
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, fuzzy, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "kan niet derefereren, is geen pointer."
@@ -55489,7 +55512,7 @@ msgstr "eerdere declaratie van %qs"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "eerdere declaratie van %qs"
@@ -55630,8 +55653,8 @@ msgstr "eerdere declaratie van %qs"
 msgid "%q#D previously defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, fuzzy, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%qs tevoren hier gedefinieerd"
@@ -55706,52 +55729,37 @@ msgstr "argumenten aan macro %qs gegeven"
 msgid "previous specification in %q#D here"
 msgstr "eerdere definitie van %qs"
 
-#: cp/decl.cc:2285
-#, fuzzy, gcc-internal-format
-msgid "declaration %qD conflicts with builtin"
-msgstr "conflicterende declaraties van %qs"
-
-#: cp/decl.cc:2288
-#, fuzzy, gcc-internal-format
-msgid "declaration %qD conflicts with import"
-msgstr "conflicterende declaraties van %qs"
-
-#: cp/decl.cc:2289
-#, fuzzy, gcc-internal-format
-msgid "import declared %q#D here"
-msgstr "%qs tevoren hier gedeclareerd"
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, fuzzy, gcc-internal-format
 msgid "conflicting exporting for declaration %qD"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, fuzzy, gcc-internal-format
 msgid "previously declared here without exporting"
 msgstr "%Jeerder hier gebruikt"
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "%Jeerdere definitie van %qD was hier"
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "%Jeerdere declaratie van %qD was hier"
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "als %<noreturn%> gedeclareerde functie bevat een %<return%> statement"
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "overbodige herdeclaratie van %qs in zelfde bereik"
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, fuzzy, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr "%Jherdefinitie van %qD"
@@ -55764,44 +55772,44 @@ msgstr "%Jherdefinitie van %qD"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "herdefinitie van %q#D"
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD botst met gebruikte functie"
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D is niet gedeclareerd in class"
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -55809,2512 +55817,2512 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "%Jdeclaratie van %qD als thread-local volgt declaratie als niet-thread-local"
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "%Jdeclaratie van %qD als niet-thread-local volgt declaratie als thread-local"
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "overbodige herdeclaratie van %qs in zelfde bereik"
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, fuzzy, gcc-internal-format
 msgid "previous label"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, fuzzy, gcc-internal-format
 msgid "jump to label %qD"
 msgstr "herhaald label %qs"
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr ""
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr ""
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, fuzzy, gcc-internal-format
 msgid "  from here"
 msgstr "van hieruit opgeroepen"
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, fuzzy, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr ""
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, fuzzy, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "ongeldige operand van %s"
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, fuzzy, gcc-internal-format
 msgid "  enters statement expression"
 msgstr "overflow in constante expressie"
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, gcc-internal-format
 msgid "  enters %<consteval if%> statement"
 msgstr ""
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, fuzzy, gcc-internal-format
 msgid "  does not destroy %qD"
 msgstr "%s ondersteunt %s niet"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, gcc-internal-format
 msgid "  does not clean up handled exception"
 msgstr ""
 
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, fuzzy, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "macro %qs gebruikt zonder argumenten"
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, fuzzy, gcc-internal-format
 msgid "%qD is a function, not a type"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, fuzzy, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, fuzzy, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr "anonieme %s gedeclareerd binnen parameterlijst"
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, fuzzy, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "nutteloos sleutelwoord of typenaam in lege declaratie"
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, fuzzy, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, fuzzy, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, fuzzy, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "type krijgt standaardwaarde %<int%> in de declaratie van %qs"
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%<register%> in lege declaratie op bestandsniveau"
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD krijgt beginwaarde (gebruik beter __typeof__)"
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%qs is geen static veld"
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, fuzzy, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "dubbele beginwaarde"
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr ""
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, fuzzy, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variabele %qs heeft beginwaarde, maar een onvolledig type"
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementen van array %qs hebben een onvolledig type"
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, fuzzy, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "parameter %qs heeft een onvolledig type"
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qs als ander soort symbool geherdeclareerd"
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, fuzzy, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "array %qs heeft grootte die negatief of 0 is"
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "opslaggrootte van %qs is niet constant"
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "ongeïnitialiseerde const %qD"
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, fuzzy, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "ongeldige beginwaarde"
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "ongeldige beginwaarde voor veld %qs"
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, fuzzy, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "accolades rond scalaire beginwaarde"
 
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, fuzzy, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "accolades rond scalaire beginwaarde"
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, fuzzy, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "accolades ontbreken rond beginwaarde"
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "elementen van array %qs hebben een onvolledig type"
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "ISO C90 verbiedt het gebruik van samengestelde expressies als lvalues"
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%qs heeft een onvolledig type"
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, fuzzy, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qs is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "te weinig argumenten voor functie %qs"
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "%Jherdeclaratie van enum %qD"
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, fuzzy, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, fuzzy, gcc-internal-format
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "type van teruggeefwaarde is onvolledig"
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, fuzzy, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, fuzzy, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "typedef %qs krijgt beginwaarde alsof het een variabele is"
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "dereferentie van pointer naar onvolledig type"
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "opslagklasse opgegeven voor structure-veld %qs"
 msgstr[1] "opslagklasse opgegeven voor structure-veld %qs"
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "dubbele beginwaarde"
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "herhaald lid %qs"
 
 # Betere vertaling voor 'decompose'?
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "kan adres niet ontleden"
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "teruggeeftype is onvolledig"
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "array %qs heeft grootte die negatief of 0 is"
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, fuzzy, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "%J%qD als niet-parameter gedeclareerd"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "%Jparameter %qD als void gedeclareerd"
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "%Jfunctiedefinitie in oude stijl"
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, fuzzy, gcc-internal-format
 #| msgid "function return type cannot be function"
 msgid "a function concept cannot be constrained"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "%qs is meestal een functie"
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, gcc-internal-format
 msgid "constrained non-template friend declaration must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, fuzzy, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, fuzzy, gcc-internal-format
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, fuzzy, gcc-internal-format
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, fuzzy, gcc-internal-format
 msgid "explicit object parameter declared here"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr ""
 
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "Ongeldige optie %qs"
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr ""
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, fuzzy, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, fuzzy, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, fuzzy, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, fuzzy, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ verbiedt array %qs van variabele lengte"
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ verbiedt array %qs van variabele lengte"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr ""
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, fuzzy, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "%qs wordt gedeclareerd als een array van voids"
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, fuzzy, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, fuzzy, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "registernaam niet opgegeven voor %qs"
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "registernaam niet opgegeven voor %qs"
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, fuzzy, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ongeldig gebruik van het niet gedefinieerde type %<%s %s%>"
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ongeldig gebruik van het niet gedefinieerde type %<%s %s%>"
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, fuzzy, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "functie-definitie als %<register%> gedeclareerd"
 
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ondersteunt gewone %<complex%> niet in de betekenis van %<double complex%>"
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ verbiedt lid-declaraties zonder leden"
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs wordt niet ondersteund door dit doelsysteem"
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ ondersteunt %<long long%> niet"
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "zowel 'signed' als 'unsigned' opgegeven voor %qs"
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "zowel 'long' als 'short' opgegeven voor %qs"
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with typedef-name %qD"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%<__thread%> samen met %<typedef%> gebruikt"
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> samen met %<typedef%> gebruikt"
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, fuzzy, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, fuzzy, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr ""
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, fuzzy, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, fuzzy, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attribuut wordt genegeerd"
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr ""
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, gcc-internal-format
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, fuzzy, gcc-internal-format
 msgid "a function type cannot have an explicit object parameter"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, gcc-internal-format
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, fuzzy, gcc-internal-format
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr ""
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, gcc-internal-format
 msgid "the type of an explicit object member function is a regular function type"
 msgstr ""
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "valid explicit object parameter declared here"
 msgstr ""
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "typekwalificaties op teruggeeftypes van functies worden genegeerd"
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<noreturn%> functie geeft niet-void waarde terug"
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, fuzzy, gcc-internal-format
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, fuzzy, gcc-internal-format
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be an explicit object member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, fuzzy, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, fuzzy, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> bij lege declaratie"
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, fuzzy, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "%Jtypedef %qD als %<inline%> gedeclareerd"
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, fuzzy, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "dubbele beginwaarde"
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "cast geeft functie-type op"
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "%Jparameter %qD als %<inline%> gedeclareerd"
 
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 ondersteunt geen flexibele array-leden"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "In functie %qs"
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "open %s"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "variabele of veld %qs als void gedeclareerd"
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "parameter %qs heeft een onvolledig type"
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qs mag niet als alleen-lezen gedeclareerd worden"
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, fuzzy, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qs mag niet als alleen-lezen gedeclareerd worden"
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "%qs is geen static veld"
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, fuzzy, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs krijgt beginwaarde en is als %<extern%> gedeclareerd"
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs heeft zowel %<extern%> als een beginwaarde"
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "ongeldig type-argument %qs"
 
 # Of is 'verbiedt parameterdeclaraties op voorhand' beter?
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ISO C verbiedt voorwaartse declaraties van parameters"
 
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, fuzzy, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, fuzzy, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "beginwaarde ontbreekt"
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -58326,115 +58334,100 @@ msgstr ""
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, fuzzy, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, fuzzy, gcc-internal-format
-msgid "cannot declare %qD in a different module"
-msgstr "cast geeft functie-type op"
-
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, fuzzy, gcc-internal-format
-msgid "previously declared here"
-msgstr "%Jeerder hier gebruikt"
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, fuzzy, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "%qs is geen typedef of ingebouwd type"
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "herhaalde case-waarde"
 
-#: cp/decl.cc:16984
-#, fuzzy, gcc-internal-format
-msgid "cannot declare %qD in different module"
-msgstr "kan niet derefereren, is geen pointer."
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "eerdere definitie van %qs"
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "grootte van array %qs is van een niet-integer type"
@@ -58443,83 +58436,83 @@ msgstr "grootte van array %qs is van een niet-integer type"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "overflow in enumeratiewaarden"
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "herdefinitie van %qs"
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "type van teruggeefwaarde is onvolledig"
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, fuzzy, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "kan klasse '%s' niet vinden"
 
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, fuzzy, gcc-internal-format
 msgid "using %qs"
 msgstr "%J%s %<%c%s%>"
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -58574,7 +58567,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "herdeclaratie van %qs"
@@ -58584,7 +58577,7 @@ msgstr "herdeclaratie van %qs"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, fuzzy, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "%<%s %s%> binnen parameterlijst gedeclareerd"
@@ -58769,64 +58762,64 @@ msgstr ""
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr ""
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, gcc-internal-format
 msgid "%qT has a base %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, gcc-internal-format
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, gcc-internal-format
 msgid "%qT has a base %qT which has internal linkage"
 msgstr ""
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, gcc-internal-format
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but not defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
@@ -58835,104 +58828,104 @@ msgstr "label %qs gebruikt maar niet gedefinieerd"
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, fuzzy, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, gcc-internal-format
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q#D"
 msgstr "parameternaam ontbreekt uit parameterlijst"
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, fuzzy, gcc-internal-format
 msgid "...following parameter %P which has a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, fuzzy, gcc-internal-format
 msgid "implicitly-declared %qD is deprecated"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, fuzzy, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -59038,7 +59031,7 @@ msgstr "grootte van %qs is %u bytes"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -59048,7 +59041,7 @@ msgstr "%qs is geen bestand, pipe of tty"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -59073,47 +59066,47 @@ msgstr ""
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr ""
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, gcc-internal-format
 msgid "  in thrown expression"
 msgstr ""
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr "cast geeft functie-type op"
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, gcc-internal-format
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr ""
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, gcc-internal-format
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr ""
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, gcc-internal-format
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr ""
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, fuzzy, gcc-internal-format
 msgid "for type %qT"
 msgstr "%s voor %qs"
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, gcc-internal-format
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr ""
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr ""
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
 msgstr ""
@@ -59380,12 +59373,12 @@ msgstr "%qs is geen bestand, pipe of tty"
 msgid "type %qT is not a direct base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qs is geen iterator"
@@ -59400,12 +59393,12 @@ msgstr ""
 msgid "invalid pointer to bit-field %qD"
 msgstr "bitveld %qs heeft een negatieve breedte"
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
@@ -59600,52 +59593,52 @@ msgstr ""
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, fuzzy, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, fuzzy, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
@@ -60021,229 +60014,274 @@ msgstr "herdeclaratie van %qs"
 msgid "encapsulation is malformed"
 msgstr ""
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, fuzzy, gcc-internal-format
 msgid "conflicting global module declaration %#qD"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, fuzzy, gcc-internal-format
 msgid "existing declaration %#qD"
 msgstr "herdeclaratie van %qs"
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match"
 msgstr "externe declaratie van %qs komt niet overeen met de globale declaratie"
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, fuzzy, gcc-internal-format
 msgid "existing definition %qD"
 msgstr "beginwaarde ontbreekt"
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, fuzzy, gcc-internal-format
 msgid "... this enumerator %qD"
 msgstr "%Jherdeclaratie van enum %qD"
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, fuzzy, gcc-internal-format
 msgid "enumerator %qD does not match ..."
 msgstr "externe declaratie van %qs komt niet overeen met de globale declaratie"
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr ""
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr ""
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr ""
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, gcc-internal-format
 msgid "recursive lazy load"
 msgstr ""
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr ""
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, fuzzy, gcc-internal-format
 msgid "module %qs declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, gcc-internal-format
 msgid "indirect import %qs is not already loaded"
 msgstr ""
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr ""
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr ""
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, fuzzy, gcc-internal-format
 msgid "macro definitions of %qE corrupted"
 msgstr "herdefinitie van %qs"
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, gcc-internal-format
 msgid "inconsistent imported macro definition %qE"
 msgstr ""
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr ""
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr ""
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, fuzzy, gcc-internal-format
 msgid "compiled module file is %qs"
 msgstr "kan bestand '%s' niet openen"
 
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collect2 version %s\n"
 msgid "compiled module is %sversion %s"
 msgstr "collect2 versie %s\n"
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collect2 version %s\n"
 msgid "compiler is %sversion %s%s%s"
 msgstr "collect2 versie %s\n"
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, fuzzy, gcc-internal-format
 msgid "module %qs found"
 msgstr "veld %qs niet gevonden"
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr ""
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr ""
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr ""
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr ""
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, gcc-internal-format
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr ""
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, gcc-internal-format
 msgid "fixed tree mismatch"
 msgstr ""
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, fuzzy, gcc-internal-format
 msgid "interface partition is not exported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module cluster %u: %s"
 msgstr ""
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to open %s"
 msgid "failed to read compiled module: %s"
 msgstr "kan %s niet openen"
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr ""
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr ""
 
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr ""
 
-#: cp/module.cc:19283
+#: cp/module.cc:19117
+#, fuzzy, gcc-internal-format
+msgid "declaration %qD conflicts with builtin"
+msgstr "conflicterende declaraties van %qs"
+
+#: cp/module.cc:19122
+#, fuzzy, gcc-internal-format
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
+
+#: cp/module.cc:19125
+#, fuzzy, gcc-internal-format
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr "%Jsectie van %qD geeft een conflict met een eerdere declaratie"
+
+#: cp/module.cc:19130
+#, gcc-internal-format
+msgid "import declared attached to module %qs"
+msgstr ""
+
+#: cp/module.cc:19134
+#, gcc-internal-format
+msgid "import declared in global module"
+msgstr ""
+
+#: cp/module.cc:19140
+#, fuzzy, gcc-internal-format
+msgid "conflicting declaration of %qD in module %qs"
+msgstr "conflicterende declaraties van %qs"
+
+#: cp/module.cc:19143
+#, fuzzy, gcc-internal-format
+msgid "conflicting declaration of %qD in global module"
+msgstr "conflicterende declaraties van %qs"
+
+#: cp/module.cc:19148
+#, fuzzy, gcc-internal-format
+msgid "previously declared in module %qs"
+msgstr "%Jeerder hier gebruikt"
+
+#: cp/module.cc:19152
+#, fuzzy, gcc-internal-format
+msgid "previously declared in global module"
+msgstr "%Jeerder hier gebruikt"
+
+#: cp/module.cc:19404
 #, fuzzy, gcc-internal-format
 #| msgid "Creating '%s'\n"
 msgid "reading CMI %qs"
 msgstr "Aanmaken van '%s'\n"
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, fuzzy, gcc-internal-format
 #| msgid "failed to open %s"
 msgid "failed to load binding %<%E%s%E%>"
 msgstr "kan %s niet openen"
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, fuzzy, gcc-internal-format
 #| msgid "failed to open %s"
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr "kan %s niet openen"
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, gcc-internal-format
 msgid "during load of pendings for %<%E%s%E%>"
 msgstr ""
@@ -60255,396 +60293,396 @@ msgstr ""
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr ""
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, fuzzy, gcc-internal-format
 msgid "module already declared"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, fuzzy, gcc-internal-format
 msgid "module already imported"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, fuzzy, gcc-internal-format
 msgid "module %qs imported here"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown Compiled Module Interface: %s"
 msgstr ""
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr ""
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr ""
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr ""
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, gcc-internal-format
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr ""
 
 # of "preprocessing" behouden?
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, fuzzy, gcc-internal-format
 #| msgid "Enable traditional preprocessing"
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr "Schakel traditionele voorverwerking in"
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr ""
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr ""
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, gcc-internal-format
 msgid "you should use the %<-%s%> option"
 msgstr ""
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, fuzzy, gcc-internal-format
 msgid "invalid header name %qs"
 msgstr "ongeldige macronaam %<%.*s%>"
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid module name %qs"
 msgstr "%qs is geen geldige pointer-modus"
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr ""
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, fuzzy, gcc-internal-format
 msgid "writing CMI %qs"
 msgstr "#error %s"
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, fuzzy, gcc-internal-format
 msgid "not writing module %qs due to errors"
 msgstr "%s:fout bij schrijven van uitvoerbestand '%s'\n"
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to write compiled module: %s"
 msgstr "kon exit-status niet ophalen"
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, fuzzy, gcc-internal-format
 msgid "unknown header kind %qs"
 msgstr "onbekende 'unspec' relocatie"
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, gcc-internal-format
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr ""
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "macro %qs gebruikt zonder argumenten"
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, fuzzy, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%d constructor(s) gevonden\n"
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, fuzzy, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, fuzzy, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "%Jsectie van %qD geeft een conflict met een eerdere declaratie"
 
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%J%s %<%c%s%>"
 
 # XXX FIXME:  useless gettextization
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s%s\n"
 msgid "%s %s %p %d"
 msgstr "%s %s%s\n"
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, gcc-internal-format
 msgid "exporting %q#D that does not have external linkage"
 msgstr ""
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here with no linkage"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here with internal linkage"
 msgstr "%qs als ander soort symbool geherdeclareerd"
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here with module linkage"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, fuzzy, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr "%qs is geen iterator"
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qs is geen iterator"
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr ""
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, fuzzy, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a direct base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%d constructor(s) gevonden\n"
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, fuzzy, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "attribuut-commando %qD wordt genegeerd"
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, fuzzy, gcc-internal-format
 msgid "  %qE"
 msgstr "%s voor %qs"
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr ""
 
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, fuzzy, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, fuzzy, gcc-internal-format
 msgid "it was later defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, fuzzy, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, fuzzy, gcc-internal-format
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, fuzzy, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, fuzzy, gcc-internal-format
 #| msgid "%qD conflicts with used function"
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%qD botst met gebruikte functie"
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "eerdere definitie van %qs"
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr ""
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr ""
@@ -60669,7 +60707,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
@@ -60915,7 +60953,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
@@ -61097,7 +61135,7 @@ msgstr "accolade-groep in expressie enkel toegestaan binnen een functie"
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, fuzzy, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "ongeldige waarheidsexpressie"
@@ -61152,7 +61190,7 @@ msgstr ""
 msgid "template-id not allowed for destructor in C++20"
 msgstr ""
 
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, gcc-internal-format
 msgid "remove the %qs"
 msgstr ""
@@ -61172,7 +61210,7 @@ msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 msgid "expected unqualified-id"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qs is geen iterator"
@@ -61222,7 +61260,7 @@ msgstr "types in voorwaardelijke expressie komen niet overeen"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
@@ -61257,7 +61295,7 @@ msgstr "types in voorwaardelijke expressie komen niet overeen"
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr ""
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "ongeldig gebruik van %<restrict%>"
@@ -61282,7 +61320,7 @@ msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
@@ -61432,8 +61470,8 @@ msgstr ""
 msgid "capture of non-variable %qE"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -61473,7 +61511,7 @@ msgstr "argumenten aan macro %qs gegeven"
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr ""
@@ -61598,7 +61636,7 @@ msgstr "ongeldige lvalue in asm-statement"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "herdeclaratie van %qs"
@@ -61661,7 +61699,7 @@ msgstr "expressie-statement heeft onvolledig type"
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "herdeclaratie van %qs"
@@ -61687,7 +61725,7 @@ msgstr ""
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ verbiedt geneste functies"
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "ongeldige beginwaarde"
@@ -61971,12 +62009,12 @@ msgstr ""
 msgid "cannot expand initializer for member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%Jdeclaratie van %qD als static volgt declaratie als niet-static"
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -62620,7 +62658,7 @@ msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 msgid "%qT not permitted in template argument"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
@@ -62799,12 +62837,12 @@ msgstr "eerdere definitie van %qs"
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, gcc-internal-format
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr ""
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "ongeldige operand van %s"
@@ -63007,38 +63045,38 @@ msgstr ""
 msgid "expression must be enclosed in parentheses"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr ""
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "gevraagde positie is geen integerconstante"
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, fuzzy, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "gevraagd alignment is geen constante"
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "twee of meer data types in de declaratie van %qs"
@@ -63047,438 +63085,438 @@ msgstr "twee of meer data types in de declaratie van %qs"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, fuzzy, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, gcc-internal-format
 msgid "template-id not allowed for constructor in C++20"
 msgstr ""
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "declaratie declareert niets"
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, fuzzy, gcc-internal-format
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD specifier"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, fuzzy, gcc-internal-format
 msgid "%qD specifier conflicts with %qs"
 msgstr "conflicterende types voor %qs"
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> vóór %<extern%> gebruikt"
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, fuzzy, gcc-internal-format
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr "%<__thread%> samen met %<typedef%> gebruikt"
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ ondersteunt %<long long%> niet"
 
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "zowel %<short%> als %<char%> opgegeven bij declaratie"
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "herhaalde %qs"
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "herhaalde %qs"
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, fuzzy, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, fuzzy, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, fuzzy, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Ongeldige optie %qs"
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, fuzzy, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, fuzzy, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, fuzzy, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qs als ander soort symbool geherdeclareerd"
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "prefix-attributen worden genegeerd vóór %<@%D%>"
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ongeldige operand voor 'p' modifier"
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr "onbekende machine-modus %qs"
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "%qs is geen iterator"
@@ -63487,12 +63525,12 @@ msgstr "%qs is geen iterator"
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
@@ -63502,134 +63540,134 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr ""
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr ""
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qs is meestal een functie"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, fuzzy, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "misvormde #pragma weak"
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr ""
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, gcc-internal-format
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr ""
 
 # 'braced-group'? Wie schrijft verdorie die foutmeldingen?
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr "accolade-groep in expressie enkel toegestaan binnen een functie"
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr ""
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, fuzzy, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -63659,7 +63697,7 @@ msgstr ""
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
@@ -63674,172 +63712,172 @@ msgstr "herdefinitie van %qs"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, fuzzy, gcc-internal-format
 msgid "from definition of %q#D"
 msgstr "herdefinitie van %qs"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, fuzzy, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, fuzzy, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
 # XXX FIXME:  useless gettextization
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, fuzzy, gcc-internal-format
 #| msgid "%s %qs"
 msgid "%s %#qD"
 msgstr "%s %qs"
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr ""
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr ""
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "impliciete declaratie van functie %qs"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "misvormde #pragma pack"
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, fuzzy, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, fuzzy, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, fuzzy, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, fuzzy, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qs is meestal een functie"
@@ -63852,154 +63890,154 @@ msgstr "%qs is meestal een functie"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, fuzzy, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "%qs impliciet als functie gedeclareerd"
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "%Jsectie van %qD geeft een conflict met een eerdere declaratie"
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, fuzzy, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, fuzzy, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr "<anoniem>"
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, fuzzy, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "te veel argumenten voor functie %qE"
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "herhaald label %qs"
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "argument %d is alleen-lezen"
 msgstr[1] "argument %d is alleen-lezen"
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "ongeldig type-argument %qs"
@@ -64008,47 +64046,47 @@ msgstr "ongeldig type-argument %qs"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "macro %qs gebruikt zonder argumenten"
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
@@ -64058,509 +64096,509 @@ msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, fuzzy, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "herdefinitie van %<union %s%>"
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, fuzzy, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, fuzzy, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD with different constraints"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "macro %qs gebruikt zonder argumenten"
 msgstr[1] "macro %qs gebruikt zonder argumenten"
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "eerdere declaratie van %qs"
 msgstr[1] "eerdere declaratie van %qs"
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, fuzzy, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "ongeldige naam %qs"
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, fuzzy, gcc-internal-format
 msgid "redeclared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "%Jherdefinitie van typedef %qD"
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "functie-definitie als %<typdef%> gedeclareerd"
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D with different constraints"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "iterator %qs is van een afgeleid type"
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, fuzzy, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, fuzzy, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d or more)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "verkeerd aantal sjabloonargumenten (%d, moet %d of meer zijn)"
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "gegeven voor %q+D"
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D is geen functiesjabloon"
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, fuzzy, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "lege declaratie"
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "herdeclaratie van %qs"
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, fuzzy, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, fuzzy, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "%Jflexibel array-lid in union"
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, fuzzy, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
 # Betere term voor "mismatched"?
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "mismatched arguments"
 msgid "mismatched argument pack lengths (%d vs %d)"
@@ -64579,305 +64617,305 @@ msgstr "slechte combinatie van argumenten"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ongeldige operand voor %p-code"
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "herdeclaratie van %qs"
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, fuzzy, gcc-internal-format
 msgid "function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qE attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "verkeerd aantal argumenten opgegeven voor attribuut %qE"
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "herhaalde definitie %qs"
 
 # XXX FIXME:  useless gettextization
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 #, fuzzy
 #| msgid "%s %qs"
 msgid "%s %#qS"
 msgstr "%s %qs"
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qs is geen static veld"
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, fuzzy, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "impliciete declaratie van functie %qs"
@@ -64889,165 +64927,165 @@ msgstr "impliciete declaratie van functie %qs"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, fuzzy, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr "de declaratie van %qs verbergt een symbool uit de parameterlijst"
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, fuzzy, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "macro %qs gebruikt zonder argumenten"
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, fuzzy, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "functie wordt niet als kandidaat voor inlining beschouwd"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "%Jeerder hier gebruikt"
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "kan %qs niet nabootsen"
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "ongeldig type-argument %qs"
@@ -65253,636 +65291,636 @@ msgstr "type van parameter %qs is niet gedeclareerd"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "initiële declaratie voor %<for%> lus gebruikt buiten C99 modus"
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
 # Betere term voor "mismatched"?
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "%qE missing template arguments"
 msgstr "slechte combinatie van argumenten"
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, fuzzy, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr ""
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, fuzzy, gcc-internal-format
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, gcc-internal-format
 msgid "use explicit object parameter %qs instead"
 msgstr ""
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, gcc-internal-format
 msgid "name the explicit object parameter"
 msgstr ""
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, fuzzy, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> before it is valid"
 msgstr "ongeldig gebruik van %<this%> op hoogste niveau"
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> after it is valid"
 msgstr "ongeldig gebruik van %<this%> op hoogste niveau"
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "ongeldig gebruik van %<this%> op hoogste niveau"
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, fuzzy, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%<%c%> optie gebruikt bij type %<%c%>"
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, gcc-internal-format
 msgid "%<auto{x}%> cannot be constrained"
 msgstr ""
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, gcc-internal-format
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr ""
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "de declaratie van %qs verbergt een symbool uit de parameterlijst"
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "ongeldig gebruik van het niet gedefinieerde type %<%s %s%>"
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, fuzzy, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qs is geen iterator"
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, fuzzy, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "kan functie %<main%> niet inline maken"
 
 # Betere term voor "mismatched"?
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing template arguments"
 msgstr "slechte combinatie van argumenten"
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, fuzzy, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "modi in %s expressie komen niet overeen"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, fuzzy, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qs is geen iterator"
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, fuzzy, gcc-internal-format
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr "gevraagd alignment is geen constante"
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr ""
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, fuzzy, gcc-internal-format
 msgid "%<__type_pack_element%> index is out of range"
 msgstr "operandnummer buiten bereik"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "nutteloze type-kwalificatie in lege declaratie"
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member mapping %qE not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, fuzzy, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, gcc-internal-format
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr ""
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, fuzzy, gcc-internal-format
 #| msgid "vectorlength must be an integer constant"
 msgid "%<vector%> length expression must be integral"
 msgstr "vectorlengte moet een integerconstante zijn"
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<defined%> zonder een naam"
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, fuzzy, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, fuzzy, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "te veel invoerbestanden"
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "%<defined%> zonder een naam"
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "%<defined%> zonder een naam"
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, fuzzy, gcc-internal-format
 msgid "%<filter%> expression must be integral"
 msgstr "%<defined%> zonder een naam"
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "rekensom met pointer naar onvolledig type"
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%qs is geen iterator"
 
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%Jparameter %u heeft een onvolledig type"
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr ""
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr ""
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr ""
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr ""
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, gcc-internal-format
 msgid "static assertion failed: %.*s"
 msgstr ""
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "%Jdeclaratie van %qD als niet-static volgt declaratie als static"
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, fuzzy, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "modi in %s expressie komen niet overeen"
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, fuzzy, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr ""
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr ""
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr "%<__builtin_next_arg%> opgeroepen zonder argument"
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "%qs is geen iterator"
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, fuzzy, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -65891,1194 +65929,1194 @@ msgstr "niet-ondersteund argument voor %<__builtin_return_address%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr ""
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, fuzzy, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, fuzzy, gcc-internal-format
 msgid " declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, fuzzy, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, fuzzy, gcc-internal-format
 msgid "%qD is not public"
 msgstr "%qs is geen iterator"
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, fuzzy, gcc-internal-format
 msgid "%qD is mutable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, fuzzy, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr "%qs heeft een onvolledig type"
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr "attribuut %qE is enkel van toepassing op functie-types"
 
 # XXX FIXME:  duplicate
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "het argument van attribuut %qE is geen string-constante"
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "attribuut %qE is enkel van toepassing op class-definities"
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "attribuut %qE is enkel van toepassing op class-definities"
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "attribuut %qE is enkel van toepassing op class-definities"
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute has no effect"
 msgid "%qE attribute takes no arguments"
 msgstr "attribuut %qE heeft geen effect"
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute does not apply to types"
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "attribuut %qE heeft geen betekenis voor types"
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "gevraagde positie is geen integerconstante"
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr ""
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr ""
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "herdeclaratie van %qs"
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, fuzzy, gcc-internal-format
 #| msgid "'%%%c' is not a valid operand prefix"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "'%%%c' is geen geldige operand-prefix"
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr ""
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "herhaalde definitie %qs"
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "attribuut %qE is enkel van toepassing op functies, niet %s"
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute applies only to functions"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "attribuut %qE is enkel van toepassing op functies"
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "array subscript is geen integer"
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr ""
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, fuzzy, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, fuzzy, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "pointer van type %<void *%> gebruikt in aftrekking"
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "pointer van type %<void *%> gebruikt in aftrekking"
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "pointer van type %<void *%> gebruikt in aftrekking"
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, fuzzy, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, fuzzy, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "vergelijking tussen types %qT en %qT"
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ongeldige toepasing van %qs op een void-type"
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "ongeldige toepasing van %qs op een void-type"
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, fuzzy, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ verbiedt casts naar een union-type"
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr ""
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, fuzzy, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qs is meestal een functie"
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qs is geen iterator"
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, fuzzy, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "waarde met subscript is noch een array, noch een pointer"
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, fuzzy, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ verbiedt accolade-groepen in expressies"
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "te weinig argumenten voor functie %qs"
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "te veel argumenten voor functie %qE"
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "te veel argumenten voor functie %qE"
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "te weinig argumenten voor functie %qs"
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "te veel argumenten voor functie"
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "te weinig argumenten voor functie"
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, fuzzy, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameter heeft een onvolledig type"
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, fuzzy, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parameter heeft een onvolledig type"
 
 # is de "," deel van de special format spec of niet?  en moet "true" hier vertaald worden of niet?
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, fuzzy, gcc-internal-format
 msgid "the address %qE will never be NULL"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
 # is de "," deel van de special format spec of niet?  en moet "true" hier vertaald worden of niet?
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
 # is de "," deel van de special format spec of niet?  en moet "true" hier vertaald worden of niet?
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr ""
 
 # is de "," deel van de special format spec of niet?  en moet "true" hier vertaald worden of niet?
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr "vergelijking tussen types %qT en %qT"
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, fuzzy, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr "vergelijking tussen types %qT en %qT"
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, fuzzy, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, fuzzy, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr ""
 
 # 'Arithmetic'?? 'rekensom' is wel correct, maar het klinkt zo stom.
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr "rekensom met pointer naar onvolledig type"
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, fuzzy, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, fuzzy, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ verbiedt een vergelijking tussen pointer en integer"
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "operand-types zijn %qT en %qT"
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "geordende vergelijking van pointer met integer nul"
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with null pointer"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "geordende vergelijking van pointer met null-pointer"
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, fuzzy, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "pointer van type %<void *%> gebruikt in aftrekking"
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
 # 'Arithmetic'?? 'rekensom' is wel correct, maar het klinkt zo stom.
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, fuzzy, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "rekensom met pointer naar onvolledig type"
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr ""
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, fuzzy, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, gcc-internal-format
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, fuzzy, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ verbiedt het adres van een gecaste expressie"
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, fuzzy, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ verbiedt het %sen van een enum"
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ verbiedt het %sen van een enum"
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ verbiedt het %sen van een pointer van type %qT"
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ verbiedt het %sen van een pointer van type %qT"
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, fuzzy, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, fuzzy, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "adres van registervariabele %qs gevraagd"
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, fuzzy, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "typekwalificaties op teruggeeftypes van functies worden genegeerd"
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, fuzzy, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "type van teruggeefwaarde is onvolledig"
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 #, fuzzy
 msgid "converting from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, fuzzy, gcc-internal-format
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 #, fuzzy
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 #, fuzzy
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "cast verhoogt het benodigde alignment van het doeltype"
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, fuzzy, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ verbiedt voorwaardelijke expressies tussen 0 en een functiepointer"
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, fuzzy, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, fuzzy, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ verbiedt casts naar een union-type"
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, fuzzy, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, gcc-internal-format
 msgid "moving %qE of type %qT to itself"
 msgstr ""
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr ""
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr ""
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr ""
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "array-index in beginwaarde van niet-array"
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, fuzzy, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, fuzzy, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 #, fuzzy
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 #, fuzzy
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 #, fuzzy
 msgid "cannot convert %qH to %qI in return"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 #, fuzzy
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, fuzzy, gcc-internal-format
 msgid "returning pointer to temporary"
 msgstr "herhaald lid %qs"
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, fuzzy, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, fuzzy, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, fuzzy, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, fuzzy, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "ongeldige lvalue in asm-statement"
 
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, fuzzy, gcc-internal-format
 msgid "redundant move in initialization"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "beginwaarde ontbreekt"
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, fuzzy, gcc-internal-format
 msgid "not eliding copy on return from %qD"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr ""
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -67300,159 +67338,159 @@ msgstr ""
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "%qs is geen static veld"
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, fuzzy, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, fuzzy, gcc-internal-format
 #| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "beginwaarde-string voor array van chars is te lang"
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "accolades rond scalaire beginwaarde"
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, fuzzy, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "onbekend veld %qs opgegeven in beginwaarde"
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr ""
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "dubbele beginwaarde"
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
@@ -68440,7 +68478,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr ""
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "%s voor %qs"
@@ -69851,7 +69889,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -70068,7 +70106,7 @@ msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "gevraagd alignment is geen macht van 2"
@@ -70872,7 +70910,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
@@ -71680,12 +71718,12 @@ msgstr ""
 msgid "are_identical_variables: Bad type"
 msgstr ""
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr ""
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr ""
@@ -71933,274 +71971,274 @@ msgstr ""
 msgid "check_init_expr(): Unknown expression type"
 msgstr ""
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, fuzzy, gcc-internal-format
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, fuzzy, gcc-internal-format
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, fuzzy, gcc-internal-format
 msgid "Specification function %qs at %L must be PURE"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr ""
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, gcc-internal-format
 msgid "check_restricted(): Unknown expression type"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L must be PURE"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr ""
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr ""
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr ""
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr ""
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr "%qs is meestal een functie"
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal assignment to external procedure at %L"
 msgstr ""
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr ""
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, fuzzy, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, fuzzy, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, fuzzy, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
@@ -72208,194 +72246,194 @@ msgstr ""
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr ""
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr ""
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "ongeldige waarheidsexpressie"
 
 # dit klinkt niet al te best
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
 # dit klinkt niet al te best
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, fuzzy, gcc-internal-format
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -72416,8 +72454,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "doorgeven van argument %d van %qs"
@@ -72497,7 +72535,7 @@ msgstr ""
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -72633,12 +72671,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -73508,7 +73546,7 @@ msgstr "ongeldige registernaam voor %qs"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
@@ -74063,7 +74101,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -74231,6 +74269,11 @@ msgstr "integer overflow in expressie"
 msgid "check_charlen_present(): length not set"
 msgstr ""
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr ""
+
 #: fortran/match.cc:118
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
@@ -74632,7 +74675,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
@@ -75157,82 +75200,82 @@ msgstr "%s voor %qs"
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr ""
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -76655,8 +76698,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -79023,12 +79066,12 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "naar label %s gerefereerd buiten enige functie"
@@ -79148,7 +79191,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
@@ -79553,278 +79596,283 @@ msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, fuzzy, gcc-internal-format
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, fuzzy, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "Invalid array reference at %L"
+msgstr "kan niet derefereren, is geen pointer."
+
+#: fortran/resolve.cc:6433
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, fuzzy, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -79833,287 +79881,287 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "expressie-statement heeft onvolledig type"
 
 # vertaling voor 'statement'?
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "%Jparameter %u heeft %<void%> als type"
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%<defined%> zonder een naam"
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -80121,214 +80169,214 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "In functie %qs"
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, gcc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, fuzzy, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, fuzzy, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
 # Ongeldig soort wat?
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -80336,1005 +80384,1005 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "String-lengte bij %L is te groot"
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, fuzzy, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr ""
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, fuzzy, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Lege array-constructor op %C is niet toegestaan"
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, fuzzy, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-constant character length at %L in DATA statement"
 msgstr "niet-constante array in DATA statement %L."
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Substring bij %L heeft lengte nul"
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, fuzzy, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -81881,333 +81929,333 @@ msgstr "Te veel argumenten voor %s op %L"
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr ""
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, fuzzy, gcc-internal-format
+#| msgid "%qE attribute conflicts with attribute %s"
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr "attribuut %qE botst met attribuut %s"
+
+#: fortran/symbol.cc:508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr ""
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr ""
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, fuzzy, gcc-internal-format
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, gcc-internal-format, gfc-internal-format
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr ""
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr "attribuut %qE botst met attribuut %s"
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr ""
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr ""
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr ""
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr ""
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qE attribute cannot be specified for local variables"
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr "attribuut %qE kan niet opgegeven worden voor lokale variabelen"
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "herhaalde case-waarde"
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -82237,24 +82285,24 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -82441,37 +82489,37 @@ msgstr "%s: definitie van functie '%s' niet omgezet\n"
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, fuzzy, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "onbekende machine-modus %qs"
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -82483,17 +82531,17 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "Intrinsieke functie %s(%d) wordt niet herkend"
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, fuzzy, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "ongeldig type-argument %qs"
@@ -82635,7 +82683,7 @@ msgstr ""
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr ""
@@ -83008,6 +83056,11 @@ msgstr "veld %qs als een functie gedeclareerd"
 msgid "function %qD redeclared as variable"
 msgstr "functie %qs geherdeclareerd als inline"
 
+#: lto/lto-symtab.cc:865
+#, fuzzy, gcc-internal-format
+msgid "previously declared here"
+msgstr "%Jeerder hier gebruikt"
+
 #: lto/lto.cc:174
 #, gcc-internal-format
 msgid "%<lto_obj_file_open()%> failed"
@@ -84257,7 +84310,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr ""
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, fuzzy, gcc-internal-format
 msgid "non-objective-c type %qT cannot be caught"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
@@ -84267,7 +84320,7 @@ msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr ""
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, gcc-internal-format
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
 msgstr ""
@@ -85120,18 +85173,10 @@ msgstr ""
 #~ msgid "argument 1 of __builtin_spe_predicate must be a constant"
 #~ msgstr "argument voor %<__builtin_args_info%> moet een constante zijn"
 
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#~ msgid "Builtin function %s requires the -mhtm option"
-#~ msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
-
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #~ msgid "Builtin function %s requires the -maltivec option"
 #~ msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#~ msgid "Builtin function %s requires the -mpaired option"
-#~ msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
-
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #~ msgid "Builtin function %s requires the -mspe option"
 #~ msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
diff --git a/gcc/po/ru.po b/gcc/po/ru.po
index dd5d4749b89..a51bfd459db 100644
--- a/gcc/po/ru.po
+++ b/gcc/po/ru.po
@@ -12,7 +12,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 9.1-b20190414\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
 "PO-Revision-Date: 2019-05-04 12:10+0300\n"
 "Last-Translator: Pavel Maryanov <acid@jack.kiev.ua>\n"
 "Language-Team: Russian <gnu@d07.ru>\n"
@@ -408,7 +408,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr "не задавайте одновременно -march=... и -mcpu=..."
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 msgid "shared and mdll are not compatible"
 msgstr "shared и mdll несовместимы"
 
@@ -19833,18 +19833,18 @@ msgstr "некорректная RTL-инструкция"
 msgid "insn does not satisfy its constraints:"
 msgstr "RTL-инструкция не удовлетворяет своим ограничениям:"
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "создан с одним значением '%s', а используется с другим"
 
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "создан с одним значением -fpic, а используется с другим"
 
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 #, fuzzy
 #| msgid "created and used with different settings of -fpie"
 msgid "created and used with different settings of %<-fpie%>"
@@ -20169,7 +20169,7 @@ msgstr "модификатор размера в формате strfmon"
 msgid "<command-line>"
 msgstr "<command-line>"
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr ""
@@ -20188,9 +20188,9 @@ msgstr "недопустимый операнд для кода '%%%c'"
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, c-format
 msgid "invalid vector constant"
 msgstr ""
@@ -20212,7 +20212,7 @@ msgstr "недопустимый операнд для кода '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "недопустимый операнд - плавающий или векторный регистр для кода '%%%c'"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, c-format
 msgid "missing operand"
 msgstr "отсутствует операнд"
@@ -20243,93 +20243,93 @@ msgstr ""
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "неверные операнды в бинарной операции"
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "'%%&' использовано без локальной динамической TLS ссылки"
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, c-format
 msgid "invalid %%J value"
 msgstr "некорректное %%J значение"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, c-format
 msgid "invalid %%r value"
 msgstr "некорректное значение %%r"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, c-format
 msgid "invalid %%R value"
 msgstr "некорректное значение %%R"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, c-format
 msgid "invalid %%N value"
 msgstr "некорректное значение %%N"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, c-format
 msgid "invalid %%P value"
 msgstr "некорректное значение %%P"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, c-format
 msgid "invalid %%h value"
 msgstr "некорректное значение %%h"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, c-format
 msgid "invalid %%L value"
 msgstr "некорректное значение %%L"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, c-format
 msgid "invalid %%m value"
 msgstr "некорректное значение %%M"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, c-format
 msgid "invalid %%M value"
 msgstr "некорректное значение %%M"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, c-format
 msgid "invalid %%U value"
 msgstr "некорректное значение %%U"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, c-format
 msgid "invalid %%s value"
 msgstr "некорректное значение %%s"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, c-format
 msgid "invalid %%C value"
 msgstr "некорректное значение %%C"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, c-format
 msgid "invalid %%E value"
 msgstr "некорректное значение %%E"
 
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "некорректное unspec-перемещение"
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, c-format
 msgid "invalid %%xn code"
 msgstr "некорректный код %%xn"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, c-format
 msgid "invalid operand address"
 msgstr "некорректный адрес операнда"
@@ -20425,35 +20425,35 @@ msgstr "некорректный операнд UNSPEC: %d"
 msgid "unrecognized supposed constant"
 msgstr "неопознанная константа"
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, c-format
 msgid "invalid shift operand"
 msgstr "некорректный оператор сдвига"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "предикативная инструкция для архитектуры Thumb"
 
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "предикативная инструкция в условной последовательности"
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Неподдерживаемый операнд для кода '%c'"
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -20461,117 +20461,117 @@ msgstr "Неподдерживаемый операнд для кода '%c'"
 msgid "invalid operand for code '%c'"
 msgstr "недопустимый операнд для кода '%c'"
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, c-format
 msgid "instruction never executed"
 msgstr "инструкция никогда не выполняется"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "устаревший код формата Maverick '%c'"
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "некорректное преобразование из %<__fpreg%>"
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "некорректное преобразование к типу %qT от типа %qT"
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "для операнда адреса требуются ограничения одного из регистров X, Y или Z"
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "операнды для %T/%t должны быть reg + const_int:"
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 msgid "bad address, not an I/O address:"
 msgstr "некорректный адрес, не I/O адрес:"
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 msgid "bad address, not a constant:"
 msgstr "некорректный адрес, не константа:"
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 msgid "bad address, not (reg+disp):"
 msgstr "некорректный адрес, не (reg+disp)"
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "некорректный адрес, не post_inc или pre_dec:"
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr "внутренняя ошибка компилятора.  Некорректный адрес:"
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "Неподдерживаемый код '%c' для значения с фикс. точкой:"
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 msgid "internal compiler error.  Unknown mode:"
 msgstr "внутренняя ошибка компилятора.  Неизвестный режим:"
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 msgid "invalid insn:"
 msgstr "недопустимая инструкция:"
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 msgid "incorrect insn:"
 msgstr "некорректная инструкция:"
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 msgid "unknown move insn:"
 msgstr "некорректная инструкция перемещения:"
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 msgid "bad shift insn:"
 msgstr "некорректная инструкция сдвига:"
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "внутренняя ошибка компилятора.  Некорректное смещение:"
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 msgid "unsupported fixed-point conversion"
 msgstr "неподдерживаемое преобразование с фиксированной точкой"
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 msgid "variable"
 msgstr "переменная"
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 msgid "function parameter"
 msgstr "параметр функции"
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 msgid "structure field"
 msgstr "поле структуры"
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 msgid "return type of function"
 msgstr "тип результата функции"
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 msgid "pointer"
 msgstr "указатель"
 
@@ -20612,7 +20612,7 @@ msgstr "некорректный операнд"
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -20937,54 +20937,54 @@ msgstr "операнд не является целым, неверный код
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "операнд не является специфическим целым, неверный код операнда 'R'"
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "некорректный код операнда '%c'"
 
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "некорректные ограничения для операнда"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, c-format
 msgid "invalid vector immediate"
 msgstr ""
 
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 msgid "unknown insn mode"
 msgstr "некорректный режим инструкции"
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr "некорректное преобразование из %<__fpreg%>"
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr "некорректное преобразование из %<__fpreg%>"
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr "некорректное преобразование к %<__fpreg%>"
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr "некорректное преобразование к типу %qT от типа %qT"
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
 msgstr ""
 
@@ -21015,7 +21015,7 @@ msgstr "некорректный операнд для %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "неверный операнд для кода %%P"
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, c-format
 msgid "invalid %%p value"
 msgstr "неверное значение для кода %%p"
@@ -21042,29 +21042,29 @@ msgstr "невозможно использовать абсолютный ад
 msgid "invalid addressing mode"
 msgstr "некорректный режим адресации"
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, c-format
 msgid "'%%%c' is not a valid operand prefix"
 msgstr "'%%%c' не является корректным префиксом операнда"
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "недопустимое использование '%%%c'"
@@ -21096,7 +21096,7 @@ msgid "post-increment address is not a register"
 msgstr "постинкрементный адрес - не регистр"
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 msgid "bad address"
 msgstr "некорректный адрес"
 
@@ -21265,7 +21265,7 @@ msgstr "неподдерживаемая комбинация: %s"
 msgid "unsupported memory expression:"
 msgstr "неподдерживаемое преобразование с фиксированной точкой"
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, fuzzy, c-format
 #| msgid "invalid %%r operand"
 msgid "invalid vector operand"
@@ -21328,256 +21328,256 @@ msgstr "ключ -mquad-memory-atomic требует 64-битного режи
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "ключ -mquad-memory не поддерживается для обратного (little endian) порядка байт"
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 msgid "bad move"
 msgstr "некорректная пересылка"
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 msgid "Bad 128-bit move"
 msgstr "некорректная 128-битная пересылка"
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%A value"
 msgstr "некорректное %%J значение"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%D value"
 msgstr "неверное значение для кода %%D"
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, c-format
 msgid "invalid %%e value"
 msgstr "некорректное %%e значение"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, c-format
 msgid "invalid %%f value"
 msgstr "недопустимое значение для кода %%f"
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, c-format
 msgid "invalid %%F value"
 msgstr "недопустимое значение для кода %%F"
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, c-format
 msgid "invalid %%G value"
 msgstr "недопустимое значение для кода %%G"
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, c-format
 msgid "invalid %%j code"
 msgstr "недопустимое значение для кода %%j"
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, c-format
 msgid "invalid %%J code"
 msgstr "недопустимое значение для кода %%J"
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, c-format
 msgid "invalid %%k value"
 msgstr "недопустимое значение для кода %%k"
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, c-format
 msgid "invalid %%K value"
 msgstr "недопустимое значение для кода %%K"
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, c-format
 msgid "invalid %%O value"
 msgstr "недопустимое значение для кода %%O"
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, c-format
 msgid "invalid %%q value"
 msgstr "недопустимое значение для кода %%q"
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%t value"
 msgstr "некорректное %%J значение"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, c-format
 msgid "invalid %%T value"
 msgstr "недопустимое значение для кода %%T"
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, c-format
 msgid "invalid %%u value"
 msgstr "недопустимое значение для кода %%u"
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, c-format
 msgid "invalid %%v value"
 msgstr "недопустимое значение для кода %%v"
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%V value"
 msgstr "некорректное %%J значение"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, c-format
 msgid "invalid %%x value"
 msgstr "неверное значение для кода %%x"
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%z value"
 msgstr "некорректное %%J значение"
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "некорректное значение %%y, попробуйте использовать ограничитель 'Z'"
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 #, fuzzy
 #| msgid "Enable using IEEE 128-bit floating point instructions."
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Включить использование инструкций IEEE 128-битной плавающей точки."
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Аргумент AltiVec передан в функцию без прототипа"
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 msgid "Could not generate addis value for fusion"
 msgstr "Не удалось сгенерировать дополнительное значение для синтеза"
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Не удалось сгенерировать смещение загрузки/сохранения для синтеза"
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 msgid "Bad GPR fusion"
 msgstr "Некорректный GPR синтез"
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "некорректное преобразование из %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "некорректное преобразование к %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "некорректное преобразование из %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "некорректное преобразование к %<__fpreg%>"
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "символьные ссылки на память поддерживаются только для z10 или более поздних версий"
 
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, c-format
 msgid "cannot decompose address"
 msgstr "ошибка при декомпозиции адреса"
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "некорректный оператор сравнения для 'E' модификатора вывода"
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "некорректная ссылка для 'J' модификатора вывода"
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "некорректный адрес для 'O' модификатора вывода"
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "некорректный адрес для 'R' модификатора вывода"
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "ожидалась ссылка на память для 'S' модификатора вывода"
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "некорректный адрес для 'S' модификатора вывода"
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "ожидалось выражении из регистров и памяти для 'N' модификатора вывода"
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "ожидался регистр или выражение памяти для модификатора вывода 'M'"
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "некорректная константа для модификатора вывода '%c'"
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "некорректная константа - попытайтесь использовать модификатор вывода"
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "некорректная константный вектор для модификатора вывода '%c'"
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "некорректное выражение - попытайтесь использовать модификатор вывода"
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "некорректное выражение для модификатора вывода '%c'"
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 msgid "vector argument passed to unprototyped function"
 msgstr "векторный аргумент передан в функцию без прототипа"
 
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 msgid "types differ in signedness"
 msgstr "типы различаются знаковостью"
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 msgid "binary operator does not support two vector bool operands"
 msgstr "бинарный оператор не поддерживает два операнда-вектора с булевыми компонентами"
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 msgid "binary operator does not support vector bool operand"
 msgstr "бинарный оператор не поддерживает операнд - вектор с булевыми компонентами"
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "бинарный оператор не поддерживает сочетание операндов вектор с булевыми компонентами и вектор с плавающими компонентами"
 
@@ -21773,12 +21773,12 @@ msgstr "({anonymous})"
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "ожидалось %<;%>"
@@ -21791,7 +21791,7 @@ msgstr "ожидалось %<;%>"
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -21800,7 +21800,7 @@ msgstr "ожидалось %<;%>"
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "ожидалась %<)%>"
@@ -21808,7 +21808,7 @@ msgstr "ожидалась %<)%>"
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "ожидалась %<]%>"
@@ -21819,29 +21819,29 @@ msgstr "ожидалось %<;%>, %<,%> или %<)%>"
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "ожидалась %<(%>"
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "ожидалось %<[%>"
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "ожидалась %<{%>"
@@ -21851,17 +21851,17 @@ msgstr "ожидалась %<{%>"
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "ожидалось %<:%>"
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "ожидалось %<while%>"
@@ -21870,8 +21870,8 @@ msgstr "ожидалось %<while%>"
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "ожидалась %<,%>"
@@ -21881,17 +21881,17 @@ msgid "expected %<.%>"
 msgstr "ожидалась %<.%>"
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "ожидалось %<@end%>"
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "ожидалось %<>%>"
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "ожидалась %<,%> или %<)%>"
@@ -21899,33 +21899,33 @@ msgstr "ожидалась %<,%> или %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "ожидалось %<=%>"
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "ожидалась %<}%>"
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<delete%>"
 msgid "expected %<else%>"
 msgstr "ожидалось %<delete%>"
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "ожидалось %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr ""
 
@@ -21933,7 +21933,7 @@ msgstr ""
 msgid "(anonymous)"
 msgstr "(anonymous)"
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "ожидалось %<<%>"
@@ -21950,24 +21950,24 @@ msgstr "ожидалась метка"
 msgid "candidate:"
 msgstr "кандидат 1:"
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 #, fuzzy
 #| msgid "Enable user-defined instructions."
 msgid "  after user-defined conversion:"
 msgstr "Включить определяемые пользователем инструкции."
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "кандидат"
 msgstr[1] "претенденты:"
 msgstr[2] "претенденты:"
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr "кандидат 1:"
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr "кандидат 2:"
 
@@ -22219,7 +22219,7 @@ msgstr ""
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 msgid "candidates are:"
 msgstr "претенденты:"
 
@@ -22263,48 +22263,48 @@ msgstr "преобразование типа отбрасывает конст
 msgid "source type is not polymorphic"
 msgstr "тип источника не является полиморфным"
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "неверный тип аргумента для унарного минуса"
 
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "неверный тип аргумента для унарного плюса"
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "неверный тип аргумента для побитового дополнения"
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "неверный тип аргумента для abs"
 
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "неверный тип аргумента для сопряжения"
 
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 msgid "in argument to unary !"
 msgstr "в аргументе унарного !"
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 msgid "no pre-increment operator for type"
 msgstr "нет преинкрементного оператора для типа"
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 msgid "no post-increment operator for type"
 msgstr "нет постинкрементного оператора для типа"
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 msgid "no pre-decrement operator for type"
 msgstr "нет предекрементного оператора для типа"
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 msgid "no post-decrement operator for type"
 msgstr "нет постдекрементного оператора для типа"
 
@@ -22384,7 +22384,7 @@ msgstr "Устаревшая возможность:"
 msgid "Deleted feature:"
 msgstr "Отмененная возможность:"
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 msgid "array assignment"
 msgstr "присваивание массивов"
 
@@ -22591,11 +22591,11 @@ msgstr "блочный IF"
 msgid "implied END DO"
 msgstr "предписанный END DO"
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 msgid "assignment"
 msgstr "присваивание"
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 msgid "pointer assignment"
 msgstr "присваивание указателя"
 
@@ -22756,47 +22756,47 @@ msgstr "Операнд пользовательского оператора %%<
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнды пользовательского оператора %%<%s%%> в %%L есть %s/%s"
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 msgid "Loop variable"
 msgstr "Переменная цикла"
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 msgid "iterator variable"
 msgstr "Переменная итератора"
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 msgid "Start expression in DO loop"
 msgstr "Начальное выражение в DO цикле"
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 msgid "End expression in DO loop"
 msgstr "Конечное выражение в DO цикле"
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 msgid "Step expression in DO loop"
 msgstr "Шаговое выражение в DO цикле"
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE объект"
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 msgid "ALLOCATE object"
 msgstr "ALLOCATE объект"
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 msgid "STAT variable"
 msgstr "STAT переменная"
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 msgid "ERRMSG variable"
 msgstr "ERRMSG переменная"
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 msgid "item in READ"
 msgstr "элемент в READ"
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK переменная"
 
@@ -22805,11 +22805,11 @@ msgstr "ACQUIRED_LOCK переменная"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "Разные CHARACTER длины (%ld/%ld) в конструкторе массива"
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Целочисленное переполнение при вычислении объема памяти для размещения"
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
@@ -22824,12 +22824,12 @@ msgstr "Фактическая длина строки не соответств
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Фактическая длина строки меньше декларированной для формального аргумента '%s' (%ld/%ld)"
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Цель переотображения ранга слишком мала (%ld < %ld)"
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 msgid "Assignment of scalar to unallocated array"
 msgstr "Присваивание скаляра неразмещенному массиву"
 
@@ -22838,83 +22838,83 @@ msgstr "Присваивание скаляра неразмещенному м
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Неравные character длины (%ld/%ld) в %s"
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, fuzzy, c-format
 #| msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "аргументы 'a%d' и 'a%d' для внутренней функции '%s'"
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, fuzzy, c-format
 #| msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "аргументы 'a%d' и 'a%d' для внутренней функции '%s'"
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Аргумент NCOPIES от REPEAT встроенной функции отрицателен (его значение равно %ld)"
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "Аргумент NCOPIES от REPEAT встроенной функции слишком велик"
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, c-format
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, c-format
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
@@ -22936,15 +22936,15 @@ msgstr "Assigned метка не есть целевая метка"
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Некорректный image номер %d в SYNC IMAGES"
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr "Бесконечный цикл"
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 msgid "Loop variable has been modified"
 msgstr "Переменная цикла изменена"
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 msgid "DO step value is zero"
 msgstr "Значение DO шага нулевое"
 
@@ -23023,7 +23023,7 @@ msgid "expected boolean type"
 msgstr "ожидался булевый тип"
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "ожидалось целое"
@@ -23088,7 +23088,7 @@ msgstr "недостаточно аргументов"
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "слишком много аргументов"
@@ -23738,7 +23738,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "-mrelax поддерживается только для RTP PIC"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "синтаксическая ошибка в %s операторе в %C"
@@ -24201,8 +24201,8 @@ msgstr ""
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "предыдущая декларация здесь"
@@ -24219,7 +24219,7 @@ msgstr "директива описания атрибута %qE проигно
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr "%<%E::%E%> scoped attribute директива проигнорирована"
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, gcc-internal-format
 msgid "wrong number of arguments specified for %qE attribute"
 msgstr "для атрибута %qE задано неверное число аргументов"
@@ -24230,7 +24230,7 @@ msgstr "для атрибута %qE задано неверное число а
 msgid "expected %i or more, found %i"
 msgstr "ожидалось %<(%> или конец строки"
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %<,%> before %qE"
 msgid "expected %i, found %i"
@@ -24298,12 +24298,12 @@ msgstr "атрибуты типов игнорируются, если тип у
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -24312,7 +24312,7 @@ msgstr "атрибуты типов игнорируются, если тип у
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -24334,8 +24334,8 @@ msgstr "атрибут %qE проигнорирован"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "предыдущая декларация %qD"
@@ -24449,7 +24449,7 @@ msgstr "ошибка чтения профиля функции из %s"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "смещение %qwi вне границ константной строки"
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qE declared here"
@@ -24563,7 +24563,7 @@ msgstr "отсутствует аргумент для %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, fuzzy, gcc-internal-format
 #| msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
@@ -24587,44 +24587,44 @@ msgstr "второй аргумент %<__builtin_longjmp%> должен быт
 msgid "target format does not support infinity"
 msgstr "целевой формат не поддерживает бесконечные значения"
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, fuzzy, gcc-internal-format
 #| msgid "%<va_start%> used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> в функции с фиксированным числом аргументов"
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "неверное число аргументов в вызове функции %<va_start%>"
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "вызов %<__builtin_next_arg%> без аргумента"
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "неверное число аргументов в вызове функции %<__builtin_next_arg%>"
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "второй аргумент %<va_start%> не является последним явным аргументом"
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "неопределенное поведение, если второй параметр %<va_start%> продекларирован с классом памяти %<register%>"
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr "аргумент 1 для %qE должен быть типом с константным размером"
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, fuzzy, gcc-internal-format
 #| msgid "%Kargument %d must be a constant immediate"
 msgid "last argument of %qD is not integer constant between 0 and 3"
@@ -25704,12 +25704,12 @@ msgstr "атрибут %<weakref%> игнорируется, поскольку
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F используется, но нигде не определена"
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F объявлена %<static%>, но нигде не определена"
@@ -26297,7 +26297,7 @@ msgstr "region_array не соответствует region_tree"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "lp_array не соответствует region_tree"
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, fuzzy, gcc-internal-format
 #| msgid "open %s failed: %s"
 msgid "%qs failed"
@@ -26328,19 +26328,19 @@ msgstr "обратить порядок хранения для %smode"
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr "запись %wu-бит данных вне границ объекта-приемника, данные усечены до %wu-бит"
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, fuzzy, gcc-internal-format
 #| msgid "%Kcall to %qs declared with attribute error: %s"
 msgid "call to %qs declared with attribute error: %s"
 msgstr "%Kвызов %qs, объявленной с атрибутом error: %s"
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, fuzzy, gcc-internal-format
 #| msgid "%Kcall to %qs declared with attribute warning: %s"
 msgid "call to %qs declared with attribute warning: %s"
 msgstr "%Kвызов %qs, объявленной с атрибутом warning: %s"
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, fuzzy, gcc-internal-format
 #| msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
@@ -26377,7 +26377,7 @@ msgstr "большая константа с фиксированной точк
 msgid "comparison is always %d due to width of bit-field"
 msgstr "при данной ширине битового поля результат сравнения - всегда %d"
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "предполагается, что при упрощении проверки диапазона не произошло переполнение"
@@ -26556,7 +26556,7 @@ msgstr "не удалось вычислить время обработки: %m
 msgid "%s signal terminated program %s"
 msgstr ""
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option %qs"
 msgid "unrecognized command-line option %qs"
@@ -26837,7 +26837,7 @@ msgstr "описание мультибиблиотеки %qs некоррект
 msgid "multilib exclusions %qs is invalid"
 msgstr "исключения %qs в мультибиблиотеке некорректны"
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "выбор мультибиблиотеки %qs %qs некорректен"
@@ -27159,24 +27159,24 @@ msgstr "заданная граница %wu превышает максимал
 msgid "%qD specified bound %E equals source length"
 msgstr ""
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member %qD not at end of %q#T"
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr "элемент регулируемого массива %qD не в конце %q#T"
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr ""
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mn is not supported for linux targets"
 msgid "%s not supported for variable length aggregates"
 msgstr "-mn не поддерживается для linux целей"
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SPE not supported in this target"
 msgid "%s not supported on this target"
@@ -27218,16 +27218,16 @@ msgid "function returns address of local variable"
 msgstr "функция возвращает адрес локальной переменной"
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, gcc-internal-format
@@ -27240,27 +27240,27 @@ msgstr "объявлено здесь"
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr "nonnull аргумент %qD сравнивается с NULL"
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr "%qE вывод может быть усечен ранее последнего символа формата"
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr "%qE вывод усечен ранее последнего символа формата"
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr "%qE может писать завершающий nul после конца приемника"
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr "%qE запись завершающего nul после конца приемника"
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -27268,7 +27268,7 @@ msgstr[0] "%<%.*s%> директивная запись %wu байт в обла
 msgstr[1] "%<%.*s%> директивная запись %wu байт в область размера %wu"
 msgstr[2] "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
@@ -27276,7 +27276,7 @@ msgstr[0] "%<%.*s%> директивный вывод может быть усе
 msgstr[1] "%<%.*s%> директивный вывод может быть усечен записью %wu байт в область размера %wu"
 msgstr[2] "%<%.*s%> директивный вывод может быть усечен записью %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
@@ -27284,67 +27284,67 @@ msgstr[0] "%<%.*s%> директивный вывод усечен запись
 msgstr[1] "%<%.*s%> директивный вывод усечен записью %wu байт в область размера %wu"
 msgstr[2] "%<%.*s%> директивный вывод усечен записью %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr "%<%.*s%> директивный вывод может быть усечен записью до %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr "%<%.*s%> директивный вывод усечен записью до %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr "%<%.*s%> директивная запись до %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "%<%.*s%> директивный вывод может быть усечен записью примерно %wu или более байт в область размера %wu"
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "%<%.*s%> директивный вывод усечен записью примерно %wu или более байт в область размера %wu"
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr "%<%.*s%> директивная запись примерно %wu или более байт в область размера %wu"
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "%<%.*s%> директивный вывод может быть усечен записью от %wu до %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "%<%.*s%> директивный вывод усечен записью от %wu до %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr "%<%.*s%> директивная запись от %wu до %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr "%<%.*s%> директивный вывод может быть усечен записью %wu или более байт в область размера %wu"
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr "%<%.*s%> директивный вывод усечен записью %wu или более байт в область размера %wu"
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr "%<%.*s%> директивная запись %wu или более байт в область размера %wu"
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
@@ -27352,7 +27352,7 @@ msgstr[0] "%<%.*s%> директивная запись %wu байт в обла
 msgstr[1] "%<%.*s%> директивная запись %wu байт в область размера от %wu до %wu"
 msgstr[2] "%<%.*s%> директивная запись %wu байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -27360,7 +27360,7 @@ msgstr[0] "%<%.*s%> директивный вывод может быть усе
 msgstr[1] "%<%.*s%> директивный вывод может быть усечен записью %wu байт в область размера от %wu до %wu"
 msgstr[2] "%<%.*s%> директивный вывод может быть усечен записью %wu байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -27368,128 +27368,128 @@ msgstr[0] "%<%.*s%> директивный вывод усечен запись
 msgstr[1] "%<%.*s%> директивный вывод усечен записью %wu байт в область размера от %wu до %wu"
 msgstr[2] "%<%.*s%> директивный вывод усечен записью %wu байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%> директивный вывод может быть усечен записью до %wu байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%> директивный вывод усечен записью до %wu байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%> директивная запись до %wu байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%> директивный вывод может быть усечен записью примерно %wu или более байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%> директивный вывод усечен записью примерно %wu или более байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%> директивная запись примерно %wu или более байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%> директивный вывод может быть усечен записью от %wu до %wu байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%> директивный вывод усечен записью от %wu до %wu байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%> директивная запись от %wu до %wu байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%> директивный вывод может быть усечен записью %wu или более байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%> директивный вывод усечен записью %wu или более байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%> директивная запись %wu или более байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, fuzzy, gcc-internal-format
 #| msgid "directive argument %qE"
 msgid "%<%.*s%> directive argument is null"
 msgstr "аргумент директивы %qE"
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr "%<%.*s%> директивный вывод от %wu до %wu байт превышает минимальный требуемый размер 4095"
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr "%<%.*s%> директивный вывод от %wu до %wu байт может превысить минимальный требуемый размер 4095"
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr "%<%.*s%> директивный вывод от %wu до %wu байт вызывает превышение результатом %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr "%<%.*s%> директивный вывод от %wu до %wu байт вызывает превышение результатом %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "%<%.*s%> директивный вывод от %wu до %wu байт вызывает превышение результатом %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr "%<%.*s%> директивный вывод от %wu до %wu байт может вызвать превышение результатом %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, fuzzy, gcc-internal-format
 #| msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 #| msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD declared here"
 msgid "referenced argument declared here"
 msgstr "параметр шаблона %qD декларирован здесь"
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
@@ -27497,22 +27497,22 @@ msgstr[0] "предполагать директивный вывод в %wu б
 msgstr[1] "предполагать директивный вывод в %wu байт"
 msgstr[2] "предполагать директивный вывод в %wu байт"
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "аргумент директивы %qE"
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr "аргумент директивы в диапазоне [%E, %E]"
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr "использование диапазона [%E, %E] для аргумента директивы"
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, fuzzy, gcc-internal-format
 #| msgid "%qE output %wu byte into a destination of size %wu"
 msgid "%qE output %wu byte into a destination of size %wu"
@@ -27521,22 +27521,22 @@ msgstr[0] "%qE вывод %wu байт в приемник размера %wu"
 msgstr[1] "%qE вывод %wu байт в приемник размера %wu"
 msgstr[2] "%qE вывод %wu байт в приемник размера %wu"
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr "%qE вывод от %wu до %wu байт в приемник размера %wu"
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr "%qE вывод %wu или более байт (предполагается %wu) в приемник размера %wu"
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr "%qE вывод %wu или более байт в приемник размера %wu"
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
@@ -27544,46 +27544,46 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, fuzzy, gcc-internal-format
 #| msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgid "%qE output between %wu and %wu bytes"
 msgstr "%qE вывод от %wu до %wu байт в приемник размера %wu"
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, fuzzy, gcc-internal-format
 #| msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr "%qE вывод %wu или более байт (предполагается %wu) в приемник размера %wu"
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, fuzzy, gcc-internal-format
 #| msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgid "%qE output %wu or more bytes"
 msgstr "%qE вывод %wu или более байт в приемник размера %wu"
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 msgid "%qE argument %Z overlaps destination object %qE"
 msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 #, fuzzy
 #| msgid "%qE output %wu byte into a destination of size %wu"
 msgid "%qE argument %Z may overlap destination object %qE"
@@ -27592,38 +27592,38 @@ msgstr[0] "%qE вывод %wu байт в приемник размера %wu"
 msgstr[1] "%qE вывод %wu байт в приемник размера %wu"
 msgstr[2] "%qE вывод %wu байт в приемник размера %wu"
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, gcc-internal-format
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, fuzzy, gcc-internal-format
 #| msgid "null destination pointer"
 msgid "null destination pointer"
 msgstr "нулевой указатель приемника"
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr "заданная граница %wu превышает размер %wu объекта приемника"
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, fuzzy, gcc-internal-format
 #| msgid "null format string"
 msgid "null format string"
@@ -28508,12 +28508,12 @@ msgstr "неизвестная машинный режим %qs для указа
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD объявлено здесь"
@@ -29340,7 +29340,7 @@ msgstr "токен %u имеет x-location == %u"
 msgid "token %u has %<y-location == %u%>"
 msgstr "токен %u имеет y-location == %u"
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "недопустимое использование атрибута %<fallthrough%>"
@@ -29703,18 +29703,18 @@ msgstr "это определено как указатель на другой
 msgid "mismatching definition"
 msgstr "отсутствует определение"
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function in gimple call"
 msgid "invalid fnsummary in LTO stream"
 msgstr "некорректная функция в gimple вызове"
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr "во входном файле отсутствует информация о межпроцедурных inline-подстановках"
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, fuzzy, gcc-internal-format
 #| msgid "ipa inline summary is missing in input file"
 msgid "IPA modref summary is missing in input file"
@@ -30849,77 +30849,77 @@ msgstr "ошибка записи в %s: %m"
 msgid "error closing optimization records %qs"
 msgstr "Выполнить оптимизацию кода вокруг команд передачи управления."
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, fuzzy, gcc-internal-format
 #| msgid "command line option %qs is not supported by this configuration"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "ключ %qs для этой конфигурации не поддерживается"
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "отсутствует аргумент для %qs"
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs should be a non-negative integer"
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr "аргумент %qs должен быть неотрицательным целым числом"
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer"
 msgstr "аргумент %qs должен быть неотрицательным целым числом"
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, gcc-internal-format
 msgid "argument to %qs is not between %d and %d"
 msgstr ""
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %qD"
 msgid "invalid argument in option %qs"
 msgstr "некорректный аргумент для %qD"
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr ""
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, fuzzy, gcc-internal-format
 #| msgid "FPX fast and compact options cannot be specified together"
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr "FPX fast и compact опции не могут задаваться вместе"
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, gcc-internal-format
 msgid "unrecognized argument in option %qs"
 msgstr "некорректный аргумент ключа %qs"
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "допустимые аргументы для %qs: %s; имелось в виду %qs?"
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "допустимые аргументы %qs: %s"
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "ключ %qs больше не поддерживается"
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute larger than %d"
 msgid "argument to %qs is bigger than %d"
 msgstr "аргумент для %qE атрибута больше чем %d"
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, fuzzy, gcc-internal-format
 #| msgid "malformed COLLECT_GCC_OPTIONS"
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
@@ -31002,8 +31002,8 @@ msgstr "аргумент %<-O%> должен быть неотрицательн
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, gcc-internal-format
 msgid "%qs is incompatible with %qs"
 msgstr "%qs несовместим с %qs"
@@ -31790,7 +31790,7 @@ msgstr "глобальная регистровая переменная - за
 msgid "register of %qD used for multiple global register variables"
 msgstr "регистр %qD назначен для нескольких глобальных регистровых переменных"
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "конфликтует с %qD"
@@ -32257,45 +32257,45 @@ msgstr "секция синонима %q+D должна соответствов
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "__builtin_saveregs не поддерживается для этой целевой платформы"
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, fuzzy, gcc-internal-format
 #| msgid "ifunc is not supported on this target"
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "ifunc не поддерживается на этой платформе"
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, gcc-internal-format
 msgid "nested functions not supported on this target"
 msgstr "вложенные функции не поддерживаются для этой платформы"
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, gcc-internal-format
 msgid "nested function trampolines not supported on this target"
 msgstr "трамплины вложенных функций не поддерживается для этой платформы"
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "глобальные конструкторы не поддерживаются для этой платформы"
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "глобальные деструкторы не поддерживаются для этой платформы"
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute is not supported on this machine"
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "атрибут target не поддерживается для данной машины"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute is not supported on this machine"
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "атрибут target не поддерживается для данной машины"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "%<#pragma GCC target%> is not supported for this machine"
@@ -33503,86 +33503,86 @@ msgstr "блок %i содержит некорректную дугу"
 msgid "BB %i has incorrect fallthru edge"
 msgstr "блок %i содержит некорректную сквозную дугу"
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr "функция %q+F не может быть скопирована, поскольку имеют нелокальные переходы в эту функцию"
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr "функция %q+F не может быть скопирована, поскольку она сохраняет адрес локальной метки в статической переменной"
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr "inline-подстановка функции %q+F невозможна, поскольку функция использует alloca (что отменяет атрибут always_inline)"
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr "inline-подстановка функции %q+F невозможна, поскольку функция использует setjmp"
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr "inline-подстановка функции %q+F невозможна, поскольку функция использует списки из переменного числа аргументов"
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr "inline-подстановка функции %q+F невозможна, поскольку функция содержит обработку исключительных ситуаций setjmp-longjmp"
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr "inline-подстановка функции %q+F невозможна, поскольку функция использует не локальный goto"
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses __builtin_return or __builtin_apply_args"
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr "inline-подстановка функции %q+F невозможна, поскольку функция использует __builtin_return или __builtin_apply_args"
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr "inline-подстановка функции %q+F невозможна, поскольку функция использует вычисляемый goto"
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr "inline-подстановка функции %q+F невозможна, поскольку функция использует списки из переменного числа аргументов"
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it is suppressed using -fno-inline"
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr "подстановка функций %q+F невозможна, т.к. задан ключ -fno-inline"
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr "подстановка функции %q+F невозможна, т.к. она имеет атрибуты, препятствующие inline-подстановке"
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, fuzzy, gcc-internal-format
 #| msgid "inlining failed in call to always_inline %q+F: %s"
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr "inline-подстановка для вызова always_inline функции %q+F не выполнена: %s"
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr "которая вызвана здесь"
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, gcc-internal-format
 msgid "called from this function"
 msgstr "вызвано из этой функции"
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, gcc-internal-format
 msgid "inlining failed in call to %q+F: %s"
 msgstr "inline-подстановка при вызове %q+F не выполнена: %s"
@@ -33643,28 +33643,28 @@ msgstr "некорректный тип элемента для атрибута
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr "недопустимое использование атрибута %<fallthrough%>"
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "in a call to non-static member function %qD"
 msgstr "некорректное использование нестатической функции-элемента %qD"
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "в вызове встроенной функции %qD"
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, fuzzy, gcc-internal-format
 #| msgid "in a call to function %qD declared here"
 msgid "in a call to function %qD declared %qs"
@@ -33910,7 +33910,7 @@ msgstr "%qE не инициализирован"
 msgid "%qs may be used uninitialized"
 msgstr "%qD, возможно, используется без инициализации в данной функции"
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD было объявлено здесь"
@@ -34149,7 +34149,7 @@ msgstr "векторное условие будет расширено по ч
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "векторная операция перемешивания будет выполнена по частям"
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr "векторизация не получилась для simd цикла"
@@ -34164,131 +34164,131 @@ msgstr "неконстантный элемент в константном CONS
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr "элемент с побочными эффектами в no-side-effects CONSTRUCTOR"
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "массивы функций не имеют осмысленной интерпретации"
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "результат функции не может иметь тип функции"
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "дерево: %s, имеется %s в %s, на %s:%d"
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "дерево: не ожидалось ничего из %s, обнаружено %s в %s, на %s:%d"
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "дерево: ожидался класс %qs, обнаружен %qs (%s) в %s, на %s:%d"
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "дерево: не ожидался класс %qs, обнаружен %qs (%s) в %s, на %s:%d"
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr "дерево: ожидалось omp_clause %s, обнаружено %s в %s, на %s:%d"
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "дерево: ожидалось дерево, содержащее структуру %qs, обнаружено %qs в %s, на %s:%d"
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr "проверка дерева: доступ к элементу %d tree_int_cst с %d элементами в %s, на %s:%d"
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr "дерево: доступ к элементу %d вектора tree_vec с %d элементами в %s, на %s:%d"
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "дерево: доступ к операнду %d функции %s с %d операндами в %s, в %s:%d"
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "дерево: доступ к операнду %d функции omp_clause %s с %d операндами в %s, в %s:%d"
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD устарело: %s"
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD устарело"
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE устаревшее: %s"
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "имя %qE будет исключено в будущих версиях"
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "поддержка данного типа будет исключена в будущих версиях: %s"
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "поддержка данного типа будет исключена в будущих версиях"
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is unavailable: %s"
 msgstr "%qD не переменная"
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is unavailable"
 msgstr "%qD не переменная"
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qE is unavailable: %s"
 msgstr "%qD не переменная"
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qE is unavailable"
 msgstr "%qD не переменная"
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "open %s failed: %s"
 msgid "type is unavailable: %s"
 msgstr "ошибка открытия %s: %s"
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "type is unavailable"
@@ -34314,307 +34314,307 @@ msgstr "%qD не переменная"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_SIZE_UNIT"
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr "вариант типа имеет другой TYPE_SIZE_UNIT"
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TYPE_SIZE_UNIT"
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr "TYPE_SIZE_UNIT варианта типа"
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, fuzzy, gcc-internal-format
 #| msgid "type's TYPE_SIZE_UNIT"
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr "TYPE_SIZE_UNIT типа"
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, fuzzy, gcc-internal-format
 #| msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr "вариант типа с TYPE_ALIAS_SET_KNOWN_P"
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_VFIELD"
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr "вариант типа имеет другой TYPE_VFIELD"
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_BINFO"
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr "вариант типа имеет другой TYPE_BINFO"
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TYPE_BINFO"
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr "TYPE_BINFO варианта типа"
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, fuzzy, gcc-internal-format
 #| msgid "type's TYPE_BINFO"
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr "TYPE_BINFO типа"
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_FIELDS"
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr "вариант типа имеет другой TYPE_FIELDS"
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "первое несоответствие является полем"
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, gcc-internal-format
 msgid "and field"
 msgstr "и поле"
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TREE_TYPE"
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr "вариант типа имеет другой TREE_TYPE"
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, fuzzy, gcc-internal-format
 #| msgid "type variant's TREE_TYPE"
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr "TREE_TYPE варианта типа"
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, fuzzy, gcc-internal-format
 #| msgid "type's TREE_TYPE"
 msgid "type%'s %<TREE_TYPE%>"
 msgstr "TREE_TYPE типа"
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "тип не совместим со своим вариантом"
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qT is not a template type"
 msgid "type %s is not an opaque type"
 msgstr "%qT не является шаблонным типом"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "type %s is not with opaque mode"
 msgstr "тип %qT не является непосредственной базой %qT"
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr ""
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_SIZE_UNIT"
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr "вариант типа имеет другой TYPE_SIZE_UNIT"
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, fuzzy, gcc-internal-format
 #| msgid "type variant has different TYPE_BINFO"
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr "вариант типа имеет другой TYPE_BINFO"
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, fuzzy, gcc-internal-format
 #| msgid "Main variant is not defined"
 msgid "main variant is not defined"
 msgstr "Главный вариант не определен"
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr "TYPE_MAIN_VARIANT имеет другой TYPE_MAIN_VARIANT"
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr "TYPE_CANONICAL имеет другой TYPE_CANONICAL"
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CANONICAL is not compatible"
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr "TYPE_CANONICAL несовместим"
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr "TYPE_MODE от TYPE_CANONICAL несовместим"
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CANONICAL of main variant is not main variant"
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr "TYPE_CANONICAL от главного варианта не есть главный вариант"
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr "TYPE_VFIELD не есть ни FIELD_DECL ни TREE_LIST"
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr "TYPE_NEXT_PTR_TO не есть POINTER_TYPE"
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr "TYPE_NEXT_REF_TO не есть REFERENCE_TYPE"
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_BINFO is not TREE_BINFO"
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr "TYPE_BINFO не есть TREE_BINFO"
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr "TYPE_BINFO тип не есть TYPE_MAIN_VARIANT"
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr "TYPE_METHOD_BASETYPE не есть ни record ни union"
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr "TYPE_OFFSET_BASETYPE не есть ни record ни union"
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr "TYPE_ARRAY_MAX_SIZE не INTEGER_CST"
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_VALUES_RAW field is non-NULL"
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr "TYPE_VALUES_RAW поле не-NULL"
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr "TYPE_LANG_SLOT_1 (binfo) поле не-NULL"
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, fuzzy, gcc-internal-format
 #| msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr "Enum значение не есть CONST_DECL или INTEGER_CST"
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, fuzzy, gcc-internal-format
 #| msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr "Тип enum значения не есть ни INTEGER_TYPE ни преобразуемый в enum"
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, fuzzy, gcc-internal-format
 #| msgid "Enum value name is not IDENTIFIER_NODE"
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr "Имя enum значения не есть IDENTIFIER_NODE"
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, fuzzy, gcc-internal-format
 #| msgid "Array TYPE_DOMAIN is not integer type"
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "Массивный TYPE_DOMAIN не есть целочисленный тип"
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_FIELDS defined in incomplete type"
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "TYPE_FIELDS определено в неполном типе"
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, fuzzy, gcc-internal-format
 #| msgid "Wrong tree in TYPE_FIELDS list"
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr "Неверное дерево в TYPE_FIELDS списке"
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr "TYPE_CACHED_VALUES_P есть %i, в то время как TYPE_CACHED_VALUES есть %p"
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr "TYPE_CACHED_VALUES не есть TREE_VEC"
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, fuzzy, gcc-internal-format
 #| msgid "wrong TYPE_CACHED_VALUES entry"
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr "неверный TYPE_CACHED_VALUES элемент"
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, fuzzy, gcc-internal-format
 #| msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr "TREE_PURPOSE не-NULL в TYPE_ARG_TYPES списке"
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, fuzzy, gcc-internal-format
 #| msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr "Неверный элемент в TYPE_ARG_TYPES списке"
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_VALUES_RAW field is non-NULL"
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr "TYPE_VALUES_RAW поле не-NULL"
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr "TYPE_CACHED_VALUES_P установлен хотя не должен"
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, fuzzy, gcc-internal-format
 #| msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
@@ -34842,7 +34842,7 @@ msgstr "в данной конфигурации определения алиа
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "атрибут видимости не поддерживается в данной конфигурации; определение игнорируется"
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr ""
@@ -35075,7 +35075,7 @@ msgstr "атрибут %qE игнорируется, поскольку %qT уж
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "атрибут %qE игнорируется, поскольку %qT уже определен"
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE атрибут действует только в public-объектах"
@@ -35267,7 +35267,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr "%qE атрибут для non-volatile переменной"
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for local variables"
 msgstr "%qE атрибут нельзя задавать для локальных переменных"
@@ -35619,7 +35619,7 @@ msgstr "%qD не совместим с %qD"
 msgid "%qE argument is not a function"
 msgstr "аргумент %qE не функция"
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "сообщение для атрибута deprecated не является строковой константой"
@@ -36176,7 +36176,7 @@ msgstr "ISO C++ не разрешает применение %<alignof%> к ти
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr "ISO C++ не разрешает применение %<_Alignof%> к типу функции"
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, gcc-internal-format
 msgid "invalid application of %qs to a void type"
 msgstr "недопустимое применение %qs к типу void"
@@ -36311,17 +36311,17 @@ msgstr "%<fallthrough%> атрибут задан несколько раз"
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "%<fallthrough%> атрибут задан с параметром"
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "слишком мало аргументов в вызове функции %qE"
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, gcc-internal-format
@@ -36453,181 +36453,181 @@ msgstr "взятие адреса от битового поля структу
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "индекс %E обозначает смещение, превышающее размер %qT"
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "размер массива слишком велик"
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "тип операнда %qT несовместим с аргументом %d для %qE"
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "при передаче аргумента %d %qE целое преобразуется в указатель без приведения типа"
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, fuzzy, gcc-internal-format
 #| msgid "left argument must be a slice"
 msgid "both arguments must be compatible"
 msgstr "левый аргумент должен быть вырезкой"
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "неправильное число аргументов в вызове функции %qE"
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "аргумент 1 для %qE должен быть не-void указателем"
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr "аргумент 1 для %qE должен быть типом с константным размером"
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "аргумент 1 для %qE должен быть типом с константным размером"
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "аргумент 1 для %qE должен быть указателем на объект ненулевого размера"
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "аргумент %d для %qE должен быть указателем"
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "аргумент %d для %qE должен быть указателем на тип константного размера"
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "аргумент %d для %qE не должен быть указателем на функцию"
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "несоответствие размера в аргументе %d для %qE"
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be a pointer to a constant size type"
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr "аргумент %d для %qE должен быть указателем на тип константного размера"
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr "передача аргумента %d %qE отменяет квалификатор %qv указуемого типа"
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be a pointer to a constant size type"
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr "аргумент %d для %qE должен быть указателем на тип константного размера"
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr "передача аргумента %d %qE отменяет квалификатор %qv указуемого типа"
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "нецелочисленный аргумент %d модели памяти для %qE"
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "некорректный аргумент %d модели памяти для %qE"
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "значение индекса вне диапазона"
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "преобразование скаляра %qT в вектор %qT включает усечение"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "внутренняя функция %qE должна вызываться напрямую"
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "size of array %qE is not a constant expression"
 msgstr "размер массива %qD не является целочисленным константным выражением"
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array is not a constant expression"
 msgstr "размер массива не является целочисленным константным выражением"
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "размер массива %qE отрицательный"
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "размер массива отрицательный"
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, fuzzy, gcc-internal-format
 #| msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr "%Kаргумент %i значение %qE превышает максимальный размер объекта %E"
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, fuzzy, gcc-internal-format
 #| msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "%Kаргумент %i значение %qE превышает максимальный размер объекта %E"
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, fuzzy, gcc-internal-format
 #| msgid "specified bound %wu exceeds maximum object size %wu"
 msgid "size of array exceeds maximum object size %qE"
 msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
@@ -37286,7 +37286,7 @@ msgstr "целая константа слишком велика для тип
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr "целая константа слишком велика для типа %<unsigned long%>"
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int%d%> is not supported on this target"
 msgid "%<_BitInt(%d)%> is not supported on this target"
@@ -37372,7 +37372,7 @@ msgstr "неподдерживаемая нестандартная конкат
 msgid "traditional C rejects string constant concatenation"
 msgstr "традиционный Си не поддерживает конкатенацию строковых констант"
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -37431,7 +37431,7 @@ msgstr "%<depend(source)%> клаузула задана вместе с %<depen
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "%<ordered%> клаузула с параметром не может быть задана в %qs конструкции"
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "некорректный тип итерационной переменной %qE"
@@ -37446,17 +37446,17 @@ msgstr "%<_Atomic%> итерационная переменная %qE"
 msgid "%qE is not initialized"
 msgstr "%qE не инициализирован"
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "отсутствует управляющий предикат"
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "некорректный управляющий предикат"
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "отсутствует инкрементальное выражение"
@@ -37466,7 +37466,7 @@ msgstr "отсутствует инкрементальное выражение
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "некорректное инкрементальное выражение"
@@ -37557,7 +37557,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -37569,7 +37569,7 @@ msgstr ""
 msgid "%qD is not a function argument"
 msgstr "%qD не является аргументом функции"
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "битовое поле %qE в %qs клаузуле"
@@ -38210,7 +38210,7 @@ msgid "wrong type argument to %s"
 msgstr "неверный аргумент типа для %s"
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -39171,35 +39171,35 @@ msgstr "сравнение между %qT и %qT"
 
 #: c-family/c-warn.cc:3832
 #, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3836
+#: c-family/c-warn.cc:3839
 #, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr ""
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr ""
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr ""
@@ -39430,128 +39430,128 @@ msgstr "-mregparm=%d не между 0 и %d"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr "для опции -mcache-block-size=X допустимый X должен быть: 4, 8, 16, 32, 64, 128, 256 или 512"
 
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> requires %<-mfp32%>"
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr "%<-march=%s%> требует %<-mfp32%>"
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s: ISA string must begin with rv32 or rv64"
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr "-march=%s: ISA цепочка должна начинаться с rv32 или rv64"
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s: invalid ISA string"
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr "-march=%s: некорректная ISA цепочка"
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> requires %<-mfp32%>"
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr "%<-march=%s%> требует %<-mfp32%>"
 
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s: ISA string must begin with rv32 or rv64"
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr "-march=%s: ISA цепочка должна начинаться с rv32 или rv64"
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, gcc-internal-format
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, fuzzy, gcc-internal-format
 #| msgid "-mcpu=%s conflicts with -march=%s"
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr "-mcpu=%s конфликтует с -march=%s"
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, fuzzy, gcc-internal-format
 #| msgid "-mcpu=%s conflicts with -march=%s"
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr "-mcpu=%s конфликтует с -march=%s"
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "ключ %<-march=%s%> несовместим с выбранным ABI"
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr "ключ %<-march=%s%> несовместим с выбранным ABI"
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s: ISA string must begin with rv32 or rv64"
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr "-march=%s: ISA цепочка должна начинаться с rv32 или rv64"
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, fuzzy, gcc-internal-format
 #| msgid "%<%s%> is unknown"
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "%<%s%> неизвестен"
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr ""
@@ -39997,13 +39997,13 @@ msgstr "ожидался тип %qT, но аргумент имеет тип %qT
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "ожидался тип %qT, но аргумент имеет тип %qT"
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC optimize%> is not a string or number"
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC optimize%> не строка и не число"
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, fuzzy, gcc-internal-format
 #| msgid "unknown #pragma GCC coprocessor %E"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
@@ -40647,7 +40647,7 @@ msgstr "передача параметров для аргументов тип
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, fuzzy, gcc-internal-format
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
@@ -40730,12 +40730,12 @@ msgid "unknown tuning option (%s)"
 msgstr "неизвестная опция настройки (%s)"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
@@ -40747,7 +40747,7 @@ msgid "specify a system register with a small string length"
 msgstr "Порядок выделения регистров"
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr ""
@@ -40947,9 +40947,9 @@ msgstr ""
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "аргумент атрибута %<target%> не строка"
@@ -41007,21 +41007,21 @@ msgid "virtual function multiversioning not supported"
 msgstr "мультиверсионность виртуальной функции не поддерживается"
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, fuzzy, gcc-internal-format
 #| msgid "multiversioning needs ifunc which is not supported on this target"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "мультиверсионность требует ifunc, что не поддерживается на этой платформе"
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 #, fuzzy
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr "передача параметров для аргументов типа %qT изменилась в GCC 7.1"
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 #, fuzzy
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
@@ -41038,8 +41038,8 @@ msgstr "передача параметров для аргументов тип
 msgid "lane %wd out of range %wd - %wd"
 msgstr "проход %wd вне диапазона %wd - %wd"
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported simdlen %d"
 msgid "unsupported simdlen %wd"
@@ -41051,7 +41051,7 @@ msgstr "неподдерживаемая simdlen %d"
 msgid "GCC does not currently support return type %qT for simd"
 msgstr "неподдерживаемый тип аргумента для внутренней функции"
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
@@ -41062,7 +41062,7 @@ msgstr ""
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr "неподдерживаемый тип аргумента для внутренней функции"
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr ""
@@ -41164,8 +41164,8 @@ msgstr "L%d латентность кэша для %s неизвестна"
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "некорректное значение %qs для -mmemory-latency"
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr "некорректный встроенный fcode"
@@ -41296,18 +41296,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr ""
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -41425,7 +41425,7 @@ msgid "argument of %qE attribute is missing"
 msgstr ""
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "аргументом атрибута %qE должна быть целая константа"
@@ -41446,25 +41446,25 @@ msgstr ""
 msgid "argument of %qE attribute ignored"
 msgstr ""
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "%qE атрибут применим только к переменным"
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, fuzzy, gcc-internal-format
 #| msgid "alternatives not allowed in asm flag output"
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "альтернативы не допускается в выводе ассемблерного флага"
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, fuzzy, gcc-internal-format
 #| msgid "unknown asm flag output %qs"
 msgid "unknown %<asm%> flag output %qs"
 msgstr "неизвестный вывод ассемблерного флага %qs"
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for asm flag output"
 msgid "invalid type for %<asm%> flag output"
@@ -41730,7 +41730,7 @@ msgstr "целевой процессор не поддерживает кома
 msgid "target CPU does not support unaligned accesses"
 msgstr "целевой процессор не поддерживает невыровненные доступы"
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support branch-likely instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -41785,7 +41785,7 @@ msgstr "граница размера структуры может быть т
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "позиционно-независимый RTP несовместим с -msingle-pic-base"
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
@@ -41902,7 +41902,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "передача параметров для аргументов типа %qT изменилась в GCC 7.1"
@@ -41943,45 +41943,45 @@ msgstr "атрибут %qE не действует на функции со ст
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "атрибут %qE применим только к базовому типу указателя на функцию"
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, fuzzy, gcc-internal-format
 #| msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr "доступ к локальной памяти потока в настоящее время не поддерживается с -mpure-code или -mslow-flash-data"
 
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd вне диапазона %wd - %wd"
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "невозможно вычислить фактическое положение параметра в стеке"
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Неожиданный thumb1 далекий переход"
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "нет свободных low-регистров для выталкивания high-регистров"
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "подпрограммы Service Routines для прерываний не могут использоваться в режиме Thumb"
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-check=specific for Thumb-1"
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "-fstack-check=specific для Thumb-1"
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr ""
@@ -41989,22 +41989,22 @@ msgstr ""
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "auto fpu выбор в настоящее время здесь не допускается"
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32-bit systems"
 msgid "%<asm%> flags not supported in thumb1 mode"
@@ -42059,166 +42059,166 @@ msgstr "поддерживаемые архитектуры ядра:%s"
 msgid "unknown core architecture %qs specified with %qs"
 msgstr "неизвестная архитектура ядра %qs задана с %qs"
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic is not supported"
 msgid "%<-fpic%> is not supported"
 msgstr "ключ -fpic не поддерживается"
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIC is not supported"
 msgid "%<-fPIC%> is not supported"
 msgstr "ключ -fPIC не поддерживается"
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, fuzzy, gcc-internal-format
 #| msgid "-fpie is not supported"
 msgid "%<-fpie%> is not supported"
 msgstr "-fpie не поддерживается"
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIE is not supported"
 msgid "%<-fPIE%> is not supported"
 msgstr "-fPIE не поддерживается"
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr ""
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs функция не может иметь аргументы"
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "%qs функция не может возвращать значение"
 
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, gcc-internal-format
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs похоже искаженный %qs обработчик, отсутствует %<__vector%> префикс"
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, gcc-internal-format
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr "%<builtin_return_address%> содержит только 2 байта адреса"
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr "смещение указателя от символа, возможно, некорректно"
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr "доступ к памяти данных с адресом программной памяти"
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr "доступ к программной памяти с адресом памяти данных"
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr "фиксированный регистр %s использован для передачи параметра функции"
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "запись в адресное пространство %qs не поддерживается"
 
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "атрибут %qE применим только к переменным в статической памяти"
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "атрибут %qE поддерживается только для сокращенных Tiny ядер"
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute address out of range"
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr "адрес атрибута %qE вне диапазона"
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr "и %s и %qE атрибут предоставляют адрес"
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "%qE атрибут для non-volatile переменной"
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "адресные пространства не поддерживаются для сокращенных Tiny устройств"
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "адресное пространство %qs не поддерживается для устройств с флэш-памятью размером до %d KiB"
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr "указатель в адресное пространство %qs должен быть const в %qT"
 
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr "указатель в адресное пространство %qs должен быть const в %s %q+D"
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables in static storage"
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr "атрибут %qE применим только к переменным в статической памяти"
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr "переменная %q+D должна быть const, чтобы ее можно было поместить в доступную только на чтение секцию посредством %qs"
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, fuzzy, gcc-internal-format
 #| msgid "static IO declaration for %q+D needs an address"
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr "декларация статического IO для %q+D требует адрес"
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, fuzzy, gcc-internal-format
 #| msgid "only uninitialized variables can be placed in the .noinit section"
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr "только неинициализированные переменные могут размещаться в секции .noinit"
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, gcc-internal-format
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr "переменная %q+D с динамической инициализацией помещена в область программной памяти"
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "неинициализированная переменная %q+D помещена в область программной памяти"
@@ -42227,43 +42227,43 @@ msgstr "неинициализированная переменная %q+D по
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q#D with %<auto%> type used in its own initializer"
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr "переменная %q#D с %<auto%> типом использована в своем собственном инициализаторе"
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%q+D имеет несовместимые атрибуты %qs и %qs"
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr "архитектура %qs поддерживается только для ассемблера"
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "преобразование из адресного пространства %qs в адресное пространство %qs"
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "%s ожидает целую константу времени компиляции"
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%s ожидает длинную целую константу времени компиляции в качестве первого аргумента"
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr "округление до %d бит не влияет на величину с фиксированной точкой с %d битами в дробной части"
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr "результат округления всегда будет 0"
@@ -42421,7 +42421,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "вызов требует ifunc, которая не поддерживается этой целью"
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, gcc-internal-format
@@ -43110,8 +43110,8 @@ msgstr "следующий за последним аргумент должен
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr "версии функции не могут быть помечены как gnu_inline, должны генерироваться тела"
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "модель кода %s не поддерживает PIC режим"
@@ -43181,273 +43181,273 @@ msgstr "слишком много диапазонов размера задан
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "Intel MCU psABI не поддерживается в %s режиме"
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> устарело; используйте вместо этого соответственно %<-mtune=k8%> или %<-mtune=generic%>"
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> устарело; используйте вместо этого соответственно %<target(\"tune=k8\")%> или %<target(\"tune=generic\")%>"
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte не поддерживается для 32-битного кода"
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32-bit systems"
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "-mcmodel= не поддерживается на 32-битных системах"
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32-bit systems"
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr "-mcmodel= не поддерживается на 32-битных системах"
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte не поддерживается для 32-битного кода"
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32-bit systems"
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "-mcmodel= не поддерживается на 32-битных системах"
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "адресный режим %qs не поддерживается в %s-битном режиме"
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, fuzzy, gcc-internal-format
 #| msgid "%<-Wabi=1%> is not supported, using =2"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-Wabi=1%> не поддерживается, используется =2"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, fuzzy, gcc-internal-format
 #| msgid "transactional memory is not supported with %<-fsanitize=address%>"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "транзакционная память не поддерживается с %<-fsanitize=address%>"
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, fuzzy, gcc-internal-format
 #| msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "транзакционная память не поддерживается с %<-fsanitize=kernel-address%>"
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fcheck-pointer-bounds%> is not supported with %<-fsanitize=bounds%>"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "%<-fcheck-pointer-bounds%> не поддерживается с %<-fsanitize=bounds%>"
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "модель кодирования %s не поддерживается в %s-битном режиме"
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "модель кода %qs не поддерживается в режиме x32"
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, fuzzy, gcc-internal-format
 #| msgid "-masm=intel not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-masm=intel не поддерживается в этой конфигурации"
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-битный режим не компилируется в"
 
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "%<generic%> процессор может использоваться только для %<-mtune=%> ключа"
 
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "%<generic%> процессор может использоваться только для %<target(\"tune=\")%> атрибута"
 
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "%<intel%> процессор может использоваться только для %<-mtune=%> ключа"
 
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "%<intel%> процессор может использоваться только для %<target(\"tune=\")%> атрибута"
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "заданный процессор не поддерживает набор команд x86-64"
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<-march=%> switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "некорректное значение (%qs) для ключа %<-march=%>"
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "некорректное значение (%qs) для %<target(\"arch=\")%> атрибута"
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "допустимые аргументы для %<-march=%> ключа: %s; имелось в виду %qs?"
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "допустимые аргументы для %<target(\"arch=\")%> атрибута: %s; вы имели в виду %qs?"
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "допустимые аргументы для %<-march=%> ключа: %s"
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "допустимые аргументы для %<target(\"arch=\")%> атрибута: %s"
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<-mtune=%> switch"
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "некорректное значение (%qs) для ключа %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "некорректное значение (%qs) для %<target(\"tune=\")%> атрибута"
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "допустимые аргументы для %<-mtune=%> ключа: %s; имелось в виду %qs?"
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "допустимые аргументы для %<target(\"tune=\")%> атрибута: %s; вы имели в виду %qs?"
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "допустимые аргументы для %<-mtune=%> ключа: %s"
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "допустимые аргументы для %<target(\"tune=\")%> атрибута: %s"
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored in 64-bit mode"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "-mregparm игнорируется в 64-битном режиме"
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored for Intel MCU psABI"
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "-mregparm игнорируется для Intel MCU psABI"
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d не между 0 и %d"
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "-mnop-mcount несовместимо с этой целью"
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> игнорируется в 64-битном режиме"
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> игнорируется в 64-битном режиме"
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr ""
@@ -43455,309 +43455,309 @@ msgstr ""
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr ""
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary is not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "-mpreferred-stack-boundary не поддерживается для этой целевой платформы"
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d не между %d и %d"
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, fuzzy, gcc-internal-format
 #| msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d не между %d и 12"
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-mnop-mcount несовместимо с этой целью"
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not implemented for -fPIC"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "-mnop-mcount не реализовано для -fPIC"
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> используется без SSE включения"
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> используется без SSE включения"
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "набор команд SSE отменен, используется арифметика 387"
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "набор команд 387 отменен, используется арифметика SSE"
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "опробование стека требует %<-maccumulate-outgoing-args%> для корректной работы"
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "опробование стека требует %<target(\"accumulate-outgoing-args\")%> для корректной работы"
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "фиксированный ebp регистр требует %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "фиксированный ebp регистр требует %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, fuzzy, gcc-internal-format
 #| msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "-mfentry не поддерживается для 32 бит в комбинации с -fpic"
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry несовместимо с SEH"
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, fuzzy, gcc-internal-format
 #| msgid "unknown option for -mrecip=%s"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "неизвестная опция для -mrecip=%s"
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs не есть допустимое число в -mstack-protector-guard-offset"
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs не есть допустимое смещение в -mstack-protector-guard-offset="
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs не есть допустимый базовый регистр в -mstack-protector-guard-reg"
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr ""
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-mnop-mcount несовместимо с этой целью"
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, fuzzy, gcc-internal-format
 #| msgid "ms_abi and sysv_abi attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "атрибуты ms_abi и sysv_abi несовместимы"
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, fuzzy, gcc-internal-format
 #| msgid "Only DWARF debug format is supported for interrupt service routine."
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr "Только отладочный формат DWARF поддерживается для программы обслуживания прерываний."
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%s инструкции не допускаются в %s сервисной программе"
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in %s service routine"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "%s инструкции не допускаются в %s сервисной программе"
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, fuzzy, gcc-internal-format
 #| msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "%s инструкции не допускаются в функции с no_caller_saved_registers атрибутом"
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "атрибуты fastcall и regparm несовместимы"
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "атрибуты regparam и thiscall несовместимы"
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE атрибут требует целый константный аргумент"
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "аргумент для %qE атрибута больше чем %d"
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "атрибуты fastcall и cdecl несовместимы"
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "атрибуты fastcall и stdcall несовместимы"
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "атрибуты fastcall и thiscall несовместимы"
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "атрибуты stdcall и cdecl несовместимы"
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "атрибуты stdcall и fastcall несовместимы"
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "атрибуты stdcall и thiscall несовместимы"
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "атрибуты cdecl и thiscall несовместимы"
 
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "атрибут %qE используется для неклассового метода"
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "несовместимый атрибут %qE игнорируется"
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "атрибут %qE допустим только для 32 бит"
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент атрибута %qE не ноль и не один"
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "аргументом атрибута %qE должна быть строковая константа"
 
 #
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "программа обслуживания прерываний должна иметь указатель первым аргументом"
 
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "программа обслуживания прерываний должна иметь беззнаковый %sint вторым аргументом"
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "программа обслуживания прерываний может иметь только указательный аргумент и необязательный целочисленный аргумент"
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt service routine can't have non-void return value"
 msgid "interrupt service routine must return %<void%>"
@@ -43967,52 +43967,52 @@ msgstr "некорректный размер операнда для расши
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "нецелый операнд использован с кодом операнда 'z'"
 
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 #, fuzzy
 #| msgid "the mangling of %<va_list%> has changed in GCC 4.4"
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr "разборка %<va_list%> изменилась в GCC 4.4"
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, fuzzy, gcc-internal-format
 #| msgid "no low registers available for popping high registers"
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr "нет свободных low-регистров для выталкивания high-регистров"
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32-bit systems"
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "-mcmodel= не поддерживается на 32-битных системах"
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr ""
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, fuzzy, gcc-internal-format
 #| msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr "HLE_ACQUIRE не использовано с ACQUIRE или более сильной моделью памяти"
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, fuzzy, gcc-internal-format
 #| msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr "HLE_RELEASE не использовано с RELEASE или более сильной моделью памяти"
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, fuzzy, gcc-internal-format
 #| msgid "-fdirectives-only is incompatible with -traditional"
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
@@ -44034,8 +44034,8 @@ msgstr "определение статического элемента дан
 msgid "malformed %<#pragma builtin%>"
 msgstr "Некорректный синтаксис #pragma builtin"
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, gcc-internal-format
 msgid "invalid argument of %qE attribute"
 msgstr "некорректный аргумент атрибута %qE"
@@ -44095,12 +44095,12 @@ msgstr "PRINT_OPERAND: некорректный символ пунктуаци
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr "нулевой указатель в вызове PRINT_OPERAND"
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "аргумент %d для внутренней функции должен быть константой в диапазоне от %d до %d"
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, gcc-internal-format
 msgid "failed to expand built-in function"
 msgstr "ошибка при расширении внутренней функции"
@@ -44235,19 +44235,19 @@ msgstr "%qD не совместим с %qD"
 msgid "%qs cannot be used for compiling a shared library"
 msgstr "%s нельзя использовать в asm в таком контексте"
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr "%qE атрибут нельзя задавать для локальных переменных"
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for register variables"
 msgstr "%qE атрибут нельзя задавать для локальных переменных"
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "multiple %qE attribute"
@@ -44361,12 +44361,12 @@ msgstr "несколько атрибутов прерываний не допу
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr "interrupt_thread доступен только на fido"
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "выражение для границы стека не поддерживается"
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int%d%> is not supported on this target"
 msgid "%<-fexcess-precision=16%> is not supported on this target"
@@ -44414,7 +44414,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr "-mxl-multiply-high требует -mno-xl-soft-mul"
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "%qE атрибут требует строковый аргумент"
@@ -44457,136 +44457,136 @@ msgstr "вектор прерывания для %qE атрибута не ес
 msgid "argument to %qE attribute is not intstack"
 msgstr "аргумент %qE атрибута не есть intstack"
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, gcc-internal-format
 msgid "cannot handle inconsistent calls to %qs"
 msgstr "ошибка при обработке некорректных вызовов %qs"
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr "атрибут %<interrupt%> требует процессор MIPS32r2 или выше"
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr "обработчики прерываний не могут быть функциями MIPS16"
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-check=specific not implemented for MIPS16"
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr "-fstack-check=specific не реализовано для MIPS16"
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, gcc-internal-format
 msgid "built-in function %qE not supported for MIPS16"
 msgstr "встроенная функция %qE не поддерживается для MIPS16"
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, gcc-internal-format
 msgid "%qs does not support MIPS16 code"
 msgstr "%qs не поддерживает код MIPS16"
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr "MIPS16 PIC для ABI, отличного от o32 и o64"
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, fuzzy, gcc-internal-format
 #| msgid "MIPS16 -mxgot code"
 msgid "MIPS16 %<-mxgot%> code"
 msgstr "код MIPS16 -mxgot"
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, fuzzy, gcc-internal-format
 #| msgid "hard-float MIPS16 code for ABIs other than o32 and o64"
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr "аппаратная реализация плавающей арифметики для MIPS16 и ABI, отличного от o32 и o64"
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, gcc-internal-format
 msgid "MSA MIPS16 code"
 msgstr "MSA MIPS16 код"
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr "для %<-mno-gpopt%> требуется %<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported combination: %s"
 msgstr "неподдерживаемая комбинация: %s"
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, gcc-internal-format
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr "%<-%s%> конфликтует с другими ключами, которые задают процессор %s"
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, gcc-internal-format
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr "ключ %<-march=%s%> несовместим с выбранным ABI"
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr "ключ %<-mgp64%> задан для 32-битного процессора"
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, gcc-internal-format
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr "ключ %<-mgp32%> задан для 64-битного процессора"
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr "ключ %<-mgp64%> задан для 32-битного ABI"
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "архитектура %qs не поддерживает %<-mfp32%>"
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr "%<-mgp32%> и %<-mfp64%> могут сочетаться, только если процессор поддерживает команды mfhc1 и mthc1"
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr "%<-mgp32%> и %<-mfp64%> могут сочетаться только при использовании ABI o32"
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr "%<-mfpxx%> использоваться только с o32 ABI"
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr "%<-march=%s%> требует %<-mfp32%>"
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr "%<-mfpxx%> требует %<-mlra%>"
@@ -44596,119 +44596,119 @@ msgstr "%<-mfpxx%> требует %<-mlra%>"
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, gcc-internal-format
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr "сочетание %qs and %qs несовместимо с %qs"
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, gcc-internal-format
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr "архитектура %qs не поддерживает команды branch-likely"
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, gcc-internal-format
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr "архитектура %qs не поддерживает инструкции madd или msub"
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr "архитектура %qs не поддерживает нечетные регистры одинарной точности"
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, gcc-internal-format
 msgid "unsupported combination: %qs%s %s"
 msgstr "неподдерживаемая комбинация: %qs%s %s"
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, gcc-internal-format
 msgid "unsupported combination: %qs %s"
 msgstr "неподдерживаемая комбинация: %qs %s"
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, gcc-internal-format
 msgid "cannot generate position-independent code for %qs"
 msgstr "невозможно генерировать позиционно-независимый код для %qs"
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, gcc-internal-format
 msgid "position-independent code requires %qs"
 msgstr "позиционно-независимый код требует %qs"
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr "для %<-mno-gpopt%> требуется %<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr "невозможно использовать метод доступа к малым объектам данных для %qs"
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr "архитектура %qs не поддерживает %<-m%s=legacy%>"
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr "архитектура %qs не поддерживает %<-m%s=2008%>"
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, gcc-internal-format
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr "для %<-mips3d%> требуется %<-mpaired-single%>"
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, gcc-internal-format
 msgid "%qs must be used with %qs"
 msgstr "%qs следует использовать вместе с %qs"
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, gcc-internal-format
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr "%<-mmsa%> должно использоваться с %<-mfp64%> и %<-mhard-float%>"
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, gcc-internal-format
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr "архитектура %qs не поддерживает команды формата PS"
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr "%qs поддерживается только для процессоров, имеющих команду %qs"
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, gcc-internal-format
 msgid "the %qs architecture does not support DSP instructions"
 msgstr "архитектура %qs не поддерживает DSP инструкции"
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr "%<-mmsa%> должно использоваться с %<-mfp64%> и %<-mhard-float%>"
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr "%<-mmsa%> должно использоваться с %<-mfp64%> и %<-mhard-float%>"
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, gcc-internal-format
 msgid "%qs requires branch-likely instructions"
 msgstr "%qs поддерживается только для процессоров, имеющих команды branch likely"
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, gcc-internal-format
 msgid "the %qs architecture does not support the synci instruction"
 msgstr "архитектура %qs не поддерживает команду synci"
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr "профилирование функций mips16"
@@ -45672,64 +45672,64 @@ msgstr "%<#pragma GCC optimize%> не строка и не число"
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "неизвестная модель '#pragma extern_model' '%s'"
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected attribute before string constant"
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr "неожиданный атрибут перед строковой константой"
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, fuzzy, gcc-internal-format
 #| msgid "variable appears in more than one clause"
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr "%qE встречается более одного раза в конструкции данных"
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, fuzzy, gcc-internal-format
 #| msgid "variable appears in more than one clause"
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr "%qE встречается более одного раза в конструкции данных"
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, fuzzy, gcc-internal-format
 #| msgid "variable appears in more than one clause"
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr "%qE встречается более одного раза в конструкции данных"
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgid "malformed %<target()%> attribute"
 msgstr "некорректное значение (%qs) для %<target(\"arch=\")%> атрибута"
 
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, fuzzy, gcc-internal-format
 #| msgid "%<no-custom-%s%> does not accept arguments"
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%<no-custom-%s%> не принимает аргументы"
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, fuzzy, gcc-internal-format
 #| msgid "unknown property attribute before %qE"
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr "неизвестный атрибут свойства перед %qE"
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgid "malformed %<target(\"%s\")%> attribute"
@@ -45799,190 +45799,214 @@ msgstr "невозможно разместить объект абстракт
 msgid "capture by copy of RVV type %qT"
 msgstr "захват копированием неполного типа %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, fuzzy, gcc-internal-format
+#| msgid "Builtin function %s requires the -mhtm option"
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr "Встроенная функция %s требует опцию -mhtm"
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, fuzzy, gcc-internal-format
+#| msgid "Builtin function %s requires the -mpaired option"
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr "Встроенная функция %s требует опцию --mpaired"
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, fuzzy, gcc-internal-format
+#| msgid "Builtin function %s requires the -mvsx option"
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr "Встроенная функция %s требует опцию -mvsx"
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, fuzzy, gcc-internal-format
+#| msgid "Builtin function %s requires the -mvsx option"
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr "Встроенная функция %s требует опцию -mvsx"
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin function %s requires the -mvsx option"
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr "Встроенная функция %s требует опцию -mvsx"
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%s(%A)%>"
 msgid "no matching function call to %qE with empty arguments"
 msgstr "нет соответствующей функции для вызова %<%s(%A)%>"
 
 #
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, fuzzy, gcc-internal-format
 #| msgid "unknown cpu %qs for -mtune"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "неизвестный процессор %qs для -mtune"
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, gcc-internal-format
 msgid "this operation requires the RVV ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI для передачи структуры с элементом complex float изменен в GCC 4.4"
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr "Аргумент AltiVec передан в функцию без прототипа"
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, fuzzy, gcc-internal-format
 #| msgid "Use the SPE ABI extensions."
 msgid "%s %qT requires the V ISA extension"
 msgstr "Использовать расширения SPE ABI."
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, gcc-internal-format
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, gcc-internal-format
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, gcc-internal-format
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, gcc-internal-format
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr ""
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, fuzzy, gcc-internal-format
 #| msgid "function attributes %qs and %qs have no effect on %qs function"
 msgid "function attribute %qs requires the V ISA extension"
 msgstr "атрибуты функций %qs и %qs не воздействуют на %qs функцию"
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute is neither zero, nor one"
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "аргумент атрибута %qE не ноль и не один"
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr ""
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgid "%qs applied to non-RVV type %qT"
 msgstr "атрибут %qE применен к неклассовому, неперечислимому типу %qT"
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires an integer constant argument"
 msgid "%qs requires an integer constant"
 msgstr "%qE атрибут требует целый константный аргумент"
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, fuzzy, gcc-internal-format
 #| msgid "-mdiv requires -march to subsume the %<M%> extension"
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "-mdiv требует -march, чтобы понять %<M%> расширение"
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support ARM mode"
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr "целевой процессор не поддерживает режим ARM"
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs with -f%s"
 msgid "code model %qs with %qs"
 msgstr "модель кода %qs с -f%s"
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, fuzzy, gcc-internal-format
 #| msgid "requested ABI requires -march to subsume the %qc extension"
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "запрошенный ABI требует -march, чтобы понять %qc расширение"
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, gcc-internal-format
 msgid "rv64e requires lp64e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr ""
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, fuzzy, gcc-internal-format
 #| msgid "ABI requires -march=rv%d"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "ABI требует -march=rv%d"
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d не между %d и %d"
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qs функция не может иметь аргументы"
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr ""
@@ -46254,35 +46278,35 @@ msgstr ""
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, fuzzy, gcc-internal-format
 #| msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl устарело для little endian; используйте присваивание для невыровненных загрузок и сохранений"
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, fuzzy, gcc-internal-format
 #| msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr устарело для little endian; используйте присваивание для невыровненных загрузок и сохранений"
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr "передача аргумента %d %qE отменяет квалификатор %qv указуемого типа"
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, gcc-internal-format
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
@@ -46324,31 +46348,23 @@ msgstr "некорректные операнды типов %qT и %qT для 
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC вектор, переданный по ссылке: нестандартное расширение ABI без гарантий совместимости"
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, fuzzy, gcc-internal-format
-#| msgid "Use the ELFv2 ABI."
-msgid "%qs requires the ELFv2 ABI"
-msgstr "Использовать ELFv2 ABI."
-
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "кадр стека слишком велик"
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incorrect number of arguments to function %qE"
 msgid "unsupported number of nops before function entry (%u)"
 msgstr "неправильное число аргументов в вызове функции %qE"
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr ""
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, fuzzy, gcc-internal-format
 #| msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
@@ -46481,110 +46497,120 @@ msgstr ""
 msgid "unknown option for %<%s=%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4837
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4855
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "отсутствует профилирование 64-битного кода для этого ABI"
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "использование %<long double%> в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "использование типов boolean в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "использование %<complex%> в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, fuzzy, gcc-internal-format
 #| msgid "use of decimal floating point types in AltiVec types is invalid"
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "использование типов decimal floating point в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "использование %<long%> в типах AltiVec не рекомендуется; используйте %<int%>"
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
 #
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "мультиверсионность виртуальной функции не поддерживается"
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin function %s requires the -mvsx option"
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "Встроенная функция %s требует опцию -mvsx"
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin function %s requires the -mvsx option"
 msgid "type %<__vector_pair%> requires the %qs option"
@@ -46636,7 +46662,7 @@ msgstr "инструкции RX FPU не поддерживают NaNs и бес
 msgid "builtin %qs can only be used on vector types"
 msgstr "встроенная функция vec_step может использоваться только для векторных типов"
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "константное значение требуется для встроенной функции %qF (аргумент %d)"
@@ -46712,246 +46738,246 @@ msgstr "%qs соответствующий вариант устарел."
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "константный аргумент %d для внутренней функции %qF вне диапазона для целевого типа"
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument %d for builtin %qF is out of range ("
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr "константный аргумент %d для внутренней функции %qF вне диапазона ("
 
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument %d for builtin %qF is out of range (0.."
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr "константный аргумент %d для внутренней функции %qF вне диапазона (0.."
 
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument %d for builtin %qF is out of range (0.."
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr "константный аргумент %d для внутренней функции %qF вне диапазона (0.."
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr "встроенная функция %qF не поддерживается без -mhtm (по умолчанию с -march=zEC12 и выше)."
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr "встроенная функция %qF требует -mvx (по умолчанию с -march=z13 и выше)."
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin %qF requires z14 or higher."
 msgid "Builtin %qF requires z14 or higher"
 msgstr "Встроенная функция %qF требует z14 или выше."
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, fuzzy, gcc-internal-format
 #| msgid "Builtin %qF requires z14 or higher."
 msgid "Builtin %qF requires z15 or higher"
 msgstr "Встроенная функция %qF требует z14 или выше."
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "неразрешенная перегрузка внутренней функции"
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "некорректный встроенный icode"
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "некорректный аргумент %d для встроенной функции %qF"
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
 #
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr ""
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "суммарный размер локальных переменных превышает архитектурный предел"
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr ""
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr ""
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "размер кадра %qs равен %wd байт"
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs использует динамическое размещение стека"
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, fuzzy, gcc-internal-format
 #| msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr "передача параметров для аргументов типа %qT изменилась в GCC 7.1"
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, fuzzy, gcc-internal-format
 #| msgid "%<__RTL%> function cannot be compiled with %<-flto%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "%<__RTL%> функция не может компилироваться с %<-flto%>"
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-битный ABI в режиме ESA/390 не поддерживается"
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "аппаратная поддержка векторов отсутствует на %s"
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, fuzzy, gcc-internal-format
 #| msgid "hardware vector support not available with -msoft-float"
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "аппаратная поддержка векторов недоступна с -msoft-float"
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr "аппаратные инструкции десятичной плавающей точки отсутствуют на %s"
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, fuzzy, gcc-internal-format
 #| msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr "аппаратные инструкции десятичной плавающей точки отсутствуют в режиме ESA/390"
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, fuzzy, gcc-internal-format
 #| msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr "ключ -mhard-dfp не может быть использован вместе с -msoft-float"
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "сочетание ключей -mbackchain -mpacked-stack -mhard-float не поддерживается"
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "размер стека должен быть больше чем охраняющее значение стека"
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "размер стека должен быть больше чем 64k"
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "ключ -mstack-guard влечет использование ключа -mstack-size"
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is supported only for SH2A"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "атрибут %qE поддерживается только для SH2A"
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "аргументы для %qs должны быть неотрицательными целыми числами"
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %<target%> argument not a string"
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr "аргумент атрибута %<target%> не строка"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "значение %qs не поддерживается атрибутом %<target%>"
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constant"
 msgid "invalid cc output constraint: %qs"
 msgstr "недопустимая константа"
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, fuzzy, gcc-internal-format
 #| msgid "placeholder constraints not satisfied"
 msgid "multiple cc output constraints not supported"
 msgstr "ограничения заполнителя не удовлетворены"
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, fuzzy, gcc-internal-format
 #| msgid "asm-specifier for variable %qE conflicts with asm clobber list"
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr "asm-спецификатор для переменной %qE конфликтует со списком переписываемых регистров"
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for asm flag output"
 msgid "invalid type for cc output constraint"
@@ -47423,8 +47449,8 @@ msgstr "атрибут %qE не действует"
 msgid "attribute %qs applies to array types only"
 msgstr "атрибут %qs применим только к массивным типам"
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "использование пустого (void) значения"
@@ -47501,7 +47527,7 @@ msgstr "тип массива %q+D завершен несовместимым 
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr "в этой области видимости уже есть декларация %qD"
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "исходное определение находится здесь"
@@ -47746,7 +47772,7 @@ msgstr "декларация %q+D перекрывает предшествую
 msgid "declaration of %qD shadows a parameter"
 msgstr "декларация %qD перекрывает параметр"
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "декларация %qD перекрывает глобальную декларацию"
@@ -47756,7 +47782,7 @@ msgstr "декларация %qD перекрывает глобальную д
 msgid "declaration of %qD shadows a previous local"
 msgstr "декларация %qD перекрывает декларированную ранее локальную переменную"
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "перекрытая декларация находится здесь"
@@ -47822,7 +47848,7 @@ msgstr "%qE не описан (первое использование в это
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "сообщение о каждом неописанном идентификаторе выдается один раз в каждой функции, где он встречается"
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "ссылка на метку %qE вне функции"
@@ -47857,7 +47883,7 @@ msgstr "переход в выражение-оператор"
 msgid "duplicate label declaration %qE"
 msgstr "повторная декларация метки %qE"
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "дублирование метки %qD"
@@ -47893,7 +47919,7 @@ msgstr "по переключателю происходит переход в 
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE: определение с некорректным видом тега"
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "%qE атрибут применен к %qD с void типом возврата"
@@ -48046,12 +48072,12 @@ msgstr "ISO C90 не поддерживает конструкцию %<[*]%> в
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> не допускается нигде кроме прототипа функции"
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<omp::%s%> not allowed to be specified in this context"
@@ -48062,7 +48088,7 @@ msgstr "%<this%> недопустим в данном контексте"
 msgid "%q+D is usually a function"
 msgstr "%q+D обычно является функцией"
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "отсутствует предварительная декларация %qD"
@@ -48142,7 +48168,7 @@ msgstr "некорректная попытка разместить в реги
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "неинициализированная константа %qD не допускается в C++"
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D в declare target директиве не имеет отображаемого типа"
@@ -48332,7 +48358,7 @@ msgstr "класс хранения в декларации параметра %
 msgid "storage class specified for unnamed parameter"
 msgstr "класс хранения задан для неименованного параметра"
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "класс хранения задан для имени типа"
@@ -48395,7 +48421,7 @@ msgstr "имя %qE описано как массив функций"
 msgid "declaration of type name as array of functions"
 msgstr "имя типа описано как массив функций"
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "неверное употребление структуры с регулируемым элементом-массивом"
@@ -48501,7 +48527,7 @@ msgstr "имя типа объявлено как функция, возвращ
 msgid "function definition has qualified void return type"
 msgstr "в определении функции задан квалифицированный void-тип возвращаемого значения"
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "квалификаторы в описании типа возвращаемого значения функции "
@@ -48628,7 +48654,7 @@ msgstr "в ISO C функции с квалификаторами const и volat
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "элемент структуры или объединения не может иметь переменно модифицируемый тип"
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "переменная или поле %qE объявлено void"
@@ -48737,7 +48763,7 @@ msgstr "не вложенная функция с переменно модиф
 msgid "object with variably modified type must have no linkage"
 msgstr "объект с переменно модифицируемым типом не должен иметь привязки"
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "декларация функции не является прототипом"
@@ -48827,18 +48853,18 @@ msgstr "вложенное переопределение %<union %E%>"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "вложенное переопределение %<struct %E%>"
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "определение типа в выражении %qs некорректно в C++"
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, fuzzy, gcc-internal-format
 #| msgid "unknown field %qE specified in initializer"
 msgid "%qT defined in underspecified object initializer"
 msgstr "неизвестное поле %qE в инициализаторе"
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "декларация ничего не описывает"
@@ -48868,360 +48894,360 @@ msgstr "пустая структура имеет размер 0 в C, разм
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr "пустое объединение имеет размер 0 в C, размер 1 в C++"
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "объединение не содержит именованных элементов"
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "объединение без элементов"
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "структура не содержит именованных элементов"
 
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "структура не содержит элементов"
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "регулируемый элемент-массив в объединении"
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "регулируемый элемент-массив - не последний элемент структуры"
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "регулируемый элемент-массив в структуре без именованных элементов"
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr "регулируемый элемент-массив - не последний элемент структуры"
 
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "тип %qT слишком велик"
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, fuzzy, gcc-internal-format
 #| msgid "reverse scalar storage order"
 msgid "type punning toggles scalar storage order"
 msgstr "обратить порядок хранения скаляра"
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "трактовка данного объединения как прозрачного невозможна"
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of typedef %q+D with variably modified type"
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr "переопределение typedef %q+D с переменно модифицируемым типом"
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %<struct %E%>"
 msgid "redefinition of struct or union %qT"
 msgstr "повторное определение %<struct %E%>"
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "вложенное переопределение %<enum %E%>"
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "повторная декларация %<enum %E%>"
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
 msgstr "заданный режим слишком мал для значений перечислимого типа"
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "перечислимый тип превышает диапазон максимального целочисленного типа"
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration values exceed range of largest integer"
 msgid "enumeration values exceed range of %qs"
 msgstr "перечислимый тип превышает диапазон максимального целочисленного типа"
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of %<enum %E%>"
 msgid "conflicting redefinition of enum %qT"
 msgstr "вложенное переопределение %<enum %E%>"
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "значение перечислимого типа для %qE не является константой целого типа"
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "значение перечислимого типа для %qE не является целочисленным константным выражением"
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "переполнение значений перечислимого типа"
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgid "enumerator value outside the range of underlying type"
 msgstr "значение перечислимого типа для %qD должно иметь целочисленный или unscoped перечислимый тип"
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "enumerator value outside the range of %qs"
 msgstr "в ISO C значения перечислимого типа ограничены диапазоном типа %<int%>"
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr "в ISO C значения перечислимого типа ограничены диапазоном типа %<int%>"
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %qD given attribute noinline"
 msgid "inline function %qD given attribute %qs"
 msgstr "inline функция %qD с атрибутом noinline"
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "тип возвращаемого значения не полный"
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "по умолчанию возвращаемый тип функции - %<int%>"
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "%q+D определена как variadic функциях без прототипа"
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "прототип для %qD не был предварительно определен"
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD использована без прототипа, до её определению"
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "функция %qD использована до определения без предварительной декларации"
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "возвращаемое значение функции %qD - не %<int%>"
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "%<_Atomic%>-квалифицированный возвращаемый тип в %qD"
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "обычно %qD является нестатической функцией"
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "старый стиль деклараций параметров в определении функции с прототипом"
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "в традиционном С не поддерживаются определения функций в стиле ISO C"
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C99 does not support %<_Static_assert%>"
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr "ISO C99 не поддерживает %<_Static_assert%>"
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "определение функции в старом стиле"
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "в списке параметров пропущено имя параметра"
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD декларирован как не параметр"
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "более одного параметра с именем %qD"
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "параметр %qD объявлен с типом void"
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "по умолчанию для %qD принят тип %<int%>"
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "параметр %qD имеет неполный тип"
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "декларация параметра %q+D, не заданного в списке параметров"
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "число аргументов не соответствует встроенному прототипу"
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "число аргументов не соответствует прототипу"
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "декларация прототипа"
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "аргумент %qD после приведения типа не соответствует встроенному прототипу"
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD после приведения типа не соответствует прототипу"
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "аргумент %qD не соответствует встроенному прототипу"
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD не соответствует прототипу"
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "в функции, которая должна возвращать значение, отсутствует оператор return"
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "параметру %qD присвоено значение, но он не использован"
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "декларации в заголовке %<for%>-цикла допускаются только в C99 или C11 режиме"
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, fuzzy, gcc-internal-format
 #| msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "используйте опцию -std=c99, -std=gnu99,-std=c11 или -std=gnu11 для компиляции вашей программы"
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 не поддерживает конструкцию %<for%> в декларациях циклов"
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "декларация статической переменной %qD в заголовке %<for%>-цикла"
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "декларация %<extern%> переменной %qD в заголовке %<for%>-цикла"
 
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "декларация %<struct %E%> в заголовке %<for%>-цикла"
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "декларация %<union %E%> в заголовке %<for%>-цикла"
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "декларация %<enum %E%> в заголовке %<for%>-цикла"
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "декларация %qD, не являющегося переменной, в заголовке %<for%>-цикла"
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "несовместимые квалификаторы адресного пространства %qs и %qs"
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "повторный %qE  спецификатор декларации"
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "в декларации задано более одного класса хранения"
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<auto%>"
 msgid "%qs used with %<auto%>"
@@ -49229,262 +49255,262 @@ msgstr "%qE использован с %<auto%>"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<register%>"
 msgid "%<auto%> used with %<constexpr%>"
 msgstr "%qE использован с %<register%>"
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "два или более типа в декларации"
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "GCC не поддерживает тип %<long long long%>"
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 не поддерживает тип %<long long%>"
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 не поддерживает комплексные типы"
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C не поддерживает типы с насыщением"
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "дублирование %qE"
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C не поддерживает типы %<__int%d%>"
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> не поддерживается для этой целевой машины"
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 не поддерживает булевы типы"
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support the %<_Float%d%s%> type"
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr "ISO C не поддерживает тип %<_Float%d%s%>"
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<_Float%d%s%> не поддерживается для этой целевой машины"
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr "ISO C не поддерживает десятичный тип с плавающей точкой"
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "типы с фиксированной точкой не поддерживаются для этой целевой платформы"
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C не поддерживает типы с фиксированной точкой"
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, fuzzy, gcc-internal-format
 #| msgid "case label is not an integer constant expression"
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr "case-метка не является целочисленным константным выражением"
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant expression"
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr "значение перечислимого типа для %qE не является целочисленным константным выражением"
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr ""
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "в C++ результатом поиска %qD будет поле, а не тип"
 
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE не является встроенным типом или typedef-типом"
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE - не в начале декларации"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE использован с %<auto%>"
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE использован с %<register%>"
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE использован с %<typedef%>"
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<register%>"
 msgid "%qE used with %<constexpr%>"
 msgstr "%qE использован с %<register%>"
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 не поддерживает %qE"
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 не поддерживает %qE"
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> перед %<extern%>"
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> перед %<static%>"
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<auto%>"
 msgid "%<typedef%> used with %<auto%>"
 msgstr "%qE использован с %<auto%>"
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<register%>"
 msgid "%qE used with %<extern%>"
 msgstr "%qE использован с %<register%>"
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, fuzzy, gcc-internal-format
 #| msgid "%qs used with %qE"
 msgid "%qE used with %qs"
 msgstr "%qs использован с %qE"
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "повторение %<_Thread_local%> или %<__thread%>"
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs использован с %qE"
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%<constexpr%> used with %qE"
 msgstr "спецификатор %<__thread%> использован с %qE"
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> использован без %<_Fract%> или %<_Accum%>"
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не поддерживает %<complex%> как эквивалент %<double complex%>"
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support %<__int%d%> types"
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr "ISO C не поддерживает типы %<__int%d%>"
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C не поддерживает целочисленные комплексные типы"
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, fuzzy, gcc-internal-format
 #| msgid "Fixed line length must be at least seven"
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr "Фиксированная длина строки должна быть по крайней мере семь"
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr "ISO C++ не поддерживает %<__int%d%> для %qs"
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "%<#pragma omp declare reduction%> объединитель ссылается на переменную %qD, которая не %<omp_out%> и не %<omp_in%>"
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "%<#pragma omp declare reduction%> инициализатор ссылается на переменную %qD, которая не %<omp_priv%> и не %<omp_orig%>"
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "сдвиг влево отрицательного значения"
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "сдвиг влево на отрицательное число позиций"
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "сдвиг вправо на отрицательное число позиций"
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "величина сдвига влево больше или равна ширине данного типа"
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "величина сдвига вправо больше или равна ширине данного типа"
@@ -49515,7 +49541,7 @@ msgstr "противоречивый маркер управления верс
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "ожидался конец строки"
@@ -49525,8 +49551,8 @@ msgstr "ожидался конец строки"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C не допускает пустых единиц трансляции"
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr ""
@@ -49567,9 +49593,9 @@ msgstr "неизвестное имя типа %qE; имелось в виду %
 msgid "unknown type name %qE"
 msgstr "неизвестное имя типа %qE"
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "ожидались спецификаторы декларации"
@@ -49603,7 +49629,7 @@ msgstr "за атрибутом %<fallthrough%> не следует %<;%>"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "ожидалось %<;%>, идентификатор или %<(%>"
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "префиксные атрибуты для методов игнорируются"
@@ -49623,7 +49649,7 @@ msgstr "неожиданный атрибут"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "за атрибутом %<fallthrough%> не следует %<;%>"
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, fuzzy, gcc-internal-format
 #| msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgid "%<assume%> attribute not followed by %<;%>"
@@ -49719,7 +49745,7 @@ msgstr "выражение в статическом утверждении не
 msgid "static assertion failed: %E"
 msgstr "не выполнено статическое утверждение: %E"
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "нарушено статическое утверждение"
@@ -49795,10 +49821,10 @@ msgstr "пустое перечисление некорректно"
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "ожидался идентификатор"
@@ -49962,7 +49988,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr ""
@@ -49972,8 +49998,8 @@ msgstr ""
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs attribute argument"
 msgstr ""
@@ -50151,12 +50177,12 @@ msgstr "ISO C не поддерживает выражения ?: с пусты
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr ""
@@ -50308,7 +50334,7 @@ msgstr "ISO C90 не поддерживает %<__func__%> предопреде
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, gcc-internal-format
 msgid "expected expression"
 msgstr "ожидалось выражение"
@@ -50640,13 +50666,13 @@ msgstr "ожидалась декларация метода objective-c"
 msgid "no type or storage class may be specified here,"
 msgstr "в этом месте не может указываться ни тип, ни класс хранения,"
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, fuzzy, gcc-internal-format
 #| msgid "unknown property attribute"
 msgid "empty property attribute list"
 msgstr "неизвестный атрибут свойства"
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, fuzzy, gcc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing property attribute"
@@ -50658,61 +50684,61 @@ msgstr "отсутствует атрибут Code"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "неизвестный атрибут свойства"
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "неизвестный атрибут свойства"
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%> before %qE"
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "ожидалось %<=%> перед %qE"
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected %qE selector name"
 msgstr "ожидался selection-statement"
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, fuzzy, gcc-internal-format
 #| msgid "setter name must terminate with %<:%>"
 msgid "setter method names must terminate with %<:%>"
 msgstr "имя setter должно заканчиваться %<:%>"
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr ""
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> может использоваться только в составных операторах"
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> должна быть в контексте файла"
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp section%> может использоваться только в конструкции %<#pragma omp sections%>"
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> может использоваться только в конструкции %<#pragma omp sections%>"
@@ -50723,25 +50749,25 @@ msgstr "%<#pragma omp section%> может использоваться толь
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr "%<#pragma %s%> может использоваться только в составных операторах"
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for, while или do оператор ожидался"
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> должна быть первой"
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "слишком много конструкций %qs"
@@ -50756,65 +50782,65 @@ msgstr "выражение должно быть целочисленным"
 msgid "expected %<)%> or %<,%>"
 msgstr "ожидалась %<)%> или %<,%>"
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD не переменная"
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD не указательная переменная"
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "collapse аргумент требует положительного константного целого выражения"
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%> before %<#pragma%>"
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr "ожидалось %<none%> или %<shared%> перед %<#pragma%>"
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected constant logical expression"
 msgstr "ожидалось целочисленное выражение"
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "ожидалось %<data%>, %<update%>, %<enter%> или %<exit%>"
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "ожидалось %<data%>"
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "слишком много %<if%> клаузул с %qs модификатором"
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "слишком много %<if%> клаузул"
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "слишком много %<if%> клаузул без модификатора"
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "если какая-либо %<if%> клаузула имеет модификатор, то все %<if%> должны использовать модификатор"
@@ -50837,23 +50863,23 @@ msgstr "значение %<num_threads%> должно быть положите
 msgid "%<num_tasks%> value must be positive"
 msgstr "значение %<num_tasks%> должно быть положительным"
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "значение %<grainsize%> должно быть положительным"
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "значение %<priority%> должен быть неотрицательным"
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "ожидалось целочисленное выражение"
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%> before %<decltype%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
@@ -50865,100 +50891,100 @@ msgstr "ожидалось %<=%>, %<,%>, %<;%>, %<asm%> или %<__attribute__%>
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses with %qs modifier"
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "слишком много %<if%> клаузул с %qs модификатором"
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses with %qs modifier"
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "слишком много %<if%> клаузул с %qs модификатором"
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "%qs выражение должно быть целочисленным"
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "значение %qs должно быть положительным"
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "слишком много %<static%> аргументов"
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "неожиданный аргумент"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%<tile%> аргумент требует положительной целочисленной константы"
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses"
 msgid "too many %<self%> clauses"
 msgstr "слишком много %<if%> клаузул"
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr "ожидалось %<none%> или %<shared%>"
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%>"
 msgid "expected %<concurrent%>"
 msgstr "ожидалось %<new%>"
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "ordered аргумент требует положительного константного целого выражения"
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "ожидалось %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> или идентификатор"
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "заданы оба модификатора %<monotonic%> и %<nonmonotonic%>"
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "расписание %<runtime%> не имеет параметра %<chunk_size%>"
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "расписание %<auto%> не имеет параметра %<chunk_size%>"
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "значение размера чанка должно быть положительным"
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "некорректный тип планирования"
@@ -50968,22 +50994,22 @@ msgstr "некорректный тип планирования"
 msgid "%<num_teams%> value must be positive"
 msgstr "значение %<num_teams%> должно быть положительным"
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr ""
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "значение %<thread_limit%> должно быть положительным"
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%<aligned%> клаузула выражения выравнивания должна быть положительным константным целочисленным выражением"
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<allocator%> or %<align%>"
@@ -50995,24 +51021,24 @@ msgstr "ожидалась %<,%> или %<)%>"
 msgid "duplicate %qs modifier"
 msgstr "дублирование %qs"
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, fuzzy, gcc-internal-format
 #| msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr "%<aligned%> клаузула выражения выравнивания должна быть положительным константным целочисленным выражением"
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, fuzzy, gcc-internal-format
 #| msgid "multiple ref-qualifiers"
 msgid "multiple linear modifiers"
 msgstr "несколько ref-квалификаторов"
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, fuzzy, gcc-internal-format
 #| msgid "multiple ref-qualifiers"
 msgid "multiple %<step%> modifiers"
@@ -51033,69 +51059,69 @@ msgstr "%<safelen%> клаузула выражения должна быть п
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%<simdlen%> клаузула выражения должна быть положительным константным целочисленным выражением"
 
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, fuzzy, gcc-internal-format
 #| msgid "%qs feature modifier is incompatible with %s %s"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "модификатор %qs возможности несовместим с %s %s"
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "некорректный depend вид"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, fuzzy, gcc-internal-format
 #| msgid "invalid map kind"
 msgid "invalid doacross kind"
 msgstr "некорректный map вид"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses with %qs modifier"
 msgid "too many %<always%> modifiers"
 msgstr "слишком много %<if%> клаузул с %qs модификатором"
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses with %qs modifier"
 msgid "too many %<close%> modifiers"
 msgstr "слишком много %<if%> клаузул с %qs модификатором"
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses with %qs modifier"
 msgid "too many %<present%> modifiers"
 msgstr "слишком много %<if%> клаузул с %qs модификатором"
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "некорректный map вид"
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr ""
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%> or %<typename%>"
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr "ожидалось %<class%> или %<typename%>"
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, fuzzy, gcc-internal-format
 #| msgid "%<linear%> clause step expression must be integral"
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr "%<linear%> клаузула выражения шага должна быть целочисленным выражением"
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "некорректный dist_schedule вид"
@@ -51111,94 +51137,94 @@ msgstr "некорректный proc_bind вид"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "ожидалось %<;%>, %<,%> или %<)%>"
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected OpenACC parallelism."
 msgid "expected an OpenACC clause"
 msgstr "Неожиданный OpenACC параллелизм."
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs не является корректным для %qs"
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs должна быть первой клаузулой %qs"
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, fuzzy, gcc-internal-format
 #| msgid "expected label"
 msgid "expected an OpenMP clause"
 msgstr "ожидалась метка"
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "нет допустимых клаузул заданных в %<#pragma acc declare%>"
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "секция массива в %<#pragma acc declare%>"
 
 #
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD должна быть глобальной переменной в %<#pragma acc declare link%>"
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "некорректная OpenACC клаузула в контексте файла"
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "некорректное использование %<extern%> переменной %qD в %<#pragma acc declare%>"
 
 #
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "некорректное использование %<global%> переменной %qD в %<#pragma acc declare%>"
 
 #
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "%qD должна быть глобальной переменной в %<#pragma acc declare link%>"
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "переменная %qD использована более одного раза с %<#pragma acc declare%>"
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "ожидалось %<data%> после %<#pragma acc %s%>"
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> не содержит клаузулу перемещения данных"
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr ""
@@ -51213,7 +51239,7 @@ msgstr "%qE не был декларирован"
 msgid "expected function name"
 msgstr "ожидалось имя функции"
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD не ссылается на функцию"
@@ -51223,22 +51249,22 @@ msgstr "%qD не ссылается на функцию"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "за %<#pragma acc routine%> не следует немедленно декларация или определение функции"
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "за %<#pragma acc routine%> не следует немедленно декларация или определение одиночной функции"
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> должна быть применена до использования"
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> должна быть применена до определения"
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> должна содержать по крайней мере одну %<device%>, %<host%> или %<self%>клаузулу"
@@ -51265,7 +51291,7 @@ msgstr ""
 msgid "modified here"
 msgstr "объединение определено здесь"
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, fuzzy, gcc-internal-format
 #| msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
@@ -51306,126 +51332,126 @@ msgstr ""
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr ""
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "ожидалась клаузула %<depend%>, %<destroy%> или %<update%>"
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "ожидалось %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> или идентификатор"
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "слишком много конструкций %qs"
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "слишком много конструкций %qs"
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr "%<#pragma omp target update%> должна содержать хотя бы одну %<from%> или %<to%> клаузулу"
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in %qs clause"
 msgid "%qs clause requires %qs clause"
 msgstr "%qD не есть переменная в %qs клаузуле"
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr "%<#pragma omp target update%> должна содержать хотя бы одну %<from%> или %<to%> клаузулу"
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr "%<#pragma omp target update%> должна содержать хотя бы одну %<from%> или %<to%> клаузулу"
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr "%<#pragma omp target update%> должна содержать хотя бы одну %<from%> или %<to%> клаузулу"
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr "%<#pragma omp target update%> должна содержать хотя бы одну %<from%> или %<to%> клаузулу"
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after union definition"
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr "ожидалось %<;%> после определения объединения"
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%> before string constant"
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr "ожидалось %<;%>, %<,%> или %<)%> перед строковой константой"
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, fuzzy, gcc-internal-format
 #| msgid "invalid form of %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr "некорректный формат %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<delete%>"
 msgid "unexpected %<else%>"
 msgstr "ожидалось %<delete%>"
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, fuzzy, gcc-internal-format
 #| msgid "invalid form of %<#pragma omp atomic%>"
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr "некорректный формат %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "некорректный формат %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "некорректный оператор для %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr ""
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> использует два различных выражения для памяти"
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant expression"
 msgid "%<depobj%> expression is not lvalue expression"
@@ -51437,29 +51463,29 @@ msgstr "выражение %qE не является константным вы
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr "выражение %qE не является константным выражением"
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr ""
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr "ожидалось %<data%>, %<update%>, %<enter%> или %<exit%>"
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "ожидалась клаузула %<depend%>, %<destroy%> или %<update%>"
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, fuzzy, gcc-internal-format
 #| msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgid "%<flush%> list specified together with memory order clause"
@@ -51470,183 +51496,183 @@ msgstr "%<nonmonotonic%> модификатор планирования зад
 msgid "expected %<(%> or end of line"
 msgstr "ожидалось %<(%> или конец строки"
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr "%<#pragma omp taskyield%> может использоваться только в составных операторах"
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<while%> before %<decltype%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "ожидалось %<while%> перед %<decltype%>"
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "ожидалась конструкция %<#pragma omp%>"
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr "%<#pragma omp taskyield%> может использоваться только в составных операторах"
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "ожидалась декларация итерации или инициализация"
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, fuzzy, gcc-internal-format
 #| msgid "not enough perfectly nested loops"
 msgid "not enough nested loops"
 msgstr "недостаточно аккуратно вложенные циклы"
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "%<ordered%> параметр клаузулы меньше чем %<collapse%>"
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "ожидался оператор for"
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "итерационная переменная %qD не должна быть firstprivate"
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp ordered%> with %<depend> clause may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> может использоваться только в составных операторах"
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "ожидался %<for%> после %qs"
 
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "ожидалось %<point%>"
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> с map-type отличном от %<to%>, %<from%>, %<tofrom%> или %<alloc%> на %<map%> клаузуле"
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp target data%> должна содержать хотя бы одну %<map%> клаузулу"
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> должна содержать хотя бы одну %<from%> или %<to%> клаузулу"
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> с map-type отличном от %<to%> или %<alloc%> на %<map%> клаузуле"
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> должна содержать хотя бы одну %<map%> клаузулу"
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> с map-type отличном от %<from%>, %<release%> или %<delete%> на %<map%> клаузуле"
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> должна содержать хотя бы одну %<map%> клаузулу"
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> с map-type отличном от %<to%>, %<from%>, %<tofrom%> или %<alloc%> на %<map%> клаузуле"
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr "за %<#pragma omp declare simd%> должна следовать декларация функции или определение или другая %<#pragma omp declare simd%>"
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "за %<#pragma omp declare simd%> должна следовать декларация или определение функции"
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected trait selector name"
 msgstr "ожидался selection-statement"
 
 #
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for 'tune' target %s"
 msgid "unknown selector %qs for context selector set %qs"
 msgstr "неизвестное значение %s для ключа -mfpu"
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, fuzzy, gcc-internal-format
 #| msgid "%<no-custom-%s%> does not accept arguments"
 msgid "selector %qs does not accept any properties"
 msgstr "%<no-custom-%s%> не принимает аргументы"
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr "%<friend%> может быть задан только внутри класса"
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, fuzzy, gcc-internal-format
 #| msgid "%qs length expression must be positive constant integer expression"
 msgid "%<score%> argument must be constant integer expression"
 msgstr "%qs выражение длины должно быть положительным константным целочисленным выражением"
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, fuzzy, gcc-internal-format
 #| msgid "%<priority%> value must be non-negative"
 msgid "%<score%> argument must be non-negative"
 msgstr "значение %<priority%> должен быть неотрицательным"
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "ожидался строковый литерал"
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "property must be constant integer expression"
 msgstr "ожидалось целочисленное выражение"
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, fuzzy, gcc-internal-format
 #| msgid "property %qs already specified in %<@synthesize%>"
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
@@ -51656,317 +51682,317 @@ msgstr "свойство %qs уже специфицировано в %<@synthes
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, fuzzy, gcc-internal-format
 #| msgid "using parameters for %<linear%> step is not supported yet"
 msgid "%<requires%> selector is not supported yet"
 msgstr "модель кода %<large%> пока не поддерживается"
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected context selector set name"
 msgstr "ожидался selection-statement"
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<match%>"
 msgstr "ожидалось %<catch%>"
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L is not a function"
 msgid "variant %qD is not a function"
 msgstr "%qs в %L не есть функция"
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, fuzzy, gcc-internal-format
 #| msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "  типы %qT и %qT имеют несовместимые cv-qualifiers"
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare simd%>, за которой не следует немедленно декларация функции или определение"
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare simd%>, за которой не следует немедленно одиночная декларация функции или определение"
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, fuzzy, gcc-internal-format
 #| msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr "%qD задан и в declare target %<link%> и в %<to%> клаузулах"
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, fuzzy, gcc-internal-format
 #| msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr "%qD задан и в declare target %<link%> и в %<to%> клаузулах"
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "ожидалось %<target%>"
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%> or %<typename%>"
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr "ожидалось %<class%> или %<typename%>"
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr "%<#pragma omp end declare target%> без соответствующей %<#pragma omp declare target%>"
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr ""
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute with %s attribute at %L"
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr "%s атрибут конфликтует с %s атрибутом в %L"
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%> or %<typename%>"
 msgid "expected %<declare%> or %<assumes%>"
 msgstr "ожидалось %<class%> или %<typename%>"
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr "%<#pragma omp declare reduction%> не в контексте файла или блока"
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr "предекларированный арифметический тип в %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr "функциональный или массивный тип в %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, gcc-internal-format
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr "%<_Atomic%> квалифицированный тип в %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr "const, volatile или restrict квалифицированный тип в %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr "повторная декларация %qs %<#pragma omp declare reduction%> для типа %qT"
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "предыдущая %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr "ожидалось %<omp_priv%> или имя функции"
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "ожидалось имя функции %<(%>"
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "одним из аргументов вызова инициализатора должен быть %<&omp_priv%>"
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "ожидалось %<simd%> или %<reduction%> или %<target%>"
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr "%<#pragma omp target data%> должна содержать хотя бы одну %<map%> клаузулу"
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr "%<_Atomic%> %qE в %<reduction%> клаузуле"
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, fuzzy, gcc-internal-format
 #| msgid "variable length element type in array %<reduction%> clause"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "тип элемента переменой длины в предложении массива %<reduction%>"
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr "ожидалась клаузула %<depend%>, %<destroy%> или %<update%>"
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> before %qE"
 msgid "expected %qs or %qs"
 msgstr "ожидалась %<(%> перед %qE"
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> с %<depend%> клаузулой может использоваться только в составных операторах"
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr ""
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr ""
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected at least one assumption clause"
 msgstr "ожидалась конструкция %<#pragma omp%>"
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, fuzzy, gcc-internal-format
 #| msgid "expected function name"
 msgid "expected directive name"
 msgstr "ожидалось имя функции"
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr ""
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, fuzzy, gcc-internal-format
 #| msgid "unknown asm flag output %qs"
 msgid "unknown assumption clause %qs"
 msgstr "неизвестный вывод ассемблерного флага %qs"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, fuzzy, gcc-internal-format
 #| msgid "expected function name"
 msgid "expected assumption clause"
 msgstr "ожидалось имя функции"
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE объявлена %<threadprivate%> после первого использования"
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "автоматическая переменная %qE не может быть %<threadprivate%>"
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE имеет неполный тип"
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> без включения транзакционной памяти"
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> внутри %<__transaction_relaxed%>"
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, fuzzy, gcc-internal-format
 #| msgid "%<transaction_may_cancel_outer%> function call not within outer transaction or %<transaction_may_cancel_outer%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "%<transaction_may_cancel_outer%> вызов функции не внутри внешней транзакции или %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> не внутри %<__transaction_atomic%>"
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, gcc-internal-format
 msgid "no closing brace"
 msgstr "нет закрывающей скобки"
@@ -52114,7 +52140,7 @@ msgstr "доступ по указателю %<void *%>"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "индексируемый объект не является ни массивом, ни указателем, ни вектором"
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "индекс массива не является целым значением"
@@ -52145,7 +52171,7 @@ msgstr "переменная %qD декларирована как ссылка,
 msgid "enum constant defined here"
 msgstr "константа перечислимого типа определена здесь"
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> от массивного параметра функции %qE вернет размер от %qT"
@@ -52260,17 +52286,17 @@ msgstr "неявная конверсия из %qT в %qT при передач
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "слишком мало аргументов в вызове функции %qE"
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "сравнение со строковым литералом приводит к неопределенному поведению"
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "сравнение указателя и нулевой символьной константы"
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "вы хотели перейти по указателю?"
@@ -52295,7 +52321,7 @@ msgstr "указатель на функцию в операции вычита
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "арифметическая операция над указателем на неполный тип"
 
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "арифметическая операция над указателем на пустой агрегат"
@@ -52601,7 +52627,7 @@ msgstr "приведение указателя к целому другого 
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "приведение вызова функции типа %qT к несоответствующему типу %qT"
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "приведение к типу указателя от целого другого размера"
@@ -52776,7 +52802,7 @@ msgstr "левой части присваивания, вероятно, мож
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "левой части инициализации, вероятно, можно задать атрибут format"
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "тип результата, вероятно, может быть задан с атрибутом format"
@@ -52986,12 +53012,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "инициализация регулируемого элемента-массива"
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -53001,7 +53027,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr "инициализация массива несоответствующего типа строковой константой"
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "некорректное использование массива, не являющегося левой частью присваивания"
@@ -53032,7 +53058,7 @@ msgstr "элемент инициализатора не является кон
 msgid "initializer element is not computable at load time"
 msgstr "инициализирующий элемент не может быть вычислен во время компоновки"
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "вектор скрытого типа не может быть инициализирован"
@@ -53047,7 +53073,7 @@ msgstr "избыточные фигурные скобки в конце ини
 msgid "braces around scalar initializer"
 msgstr "фигурные скобки вокруг скалярного инициализатора"
 
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "инициализация элемента регулируемого элемента-массива во вложенном контексте"
@@ -53138,7 +53164,7 @@ msgstr "избыточные элементы в инициализаторе с
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "позиционная инициализация поля в %<struct%> декларированной с %<designated_init%> атрибутом"
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "не статическая инициализация регулируемого элемента-массива в структуре"
@@ -53179,7 +53205,7 @@ msgstr "в ISO C операторы вида %<goto *expr;%> запрещены"
 msgid "computed goto must be pointer type"
 msgstr "аргумент %d для %qE должен быть указателем"
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "функция декларированная с атрибутом %<noreturn%> содержит оператор %<return%>"
@@ -53234,7 +53260,7 @@ msgstr "метка %<default%> вне оператора switch"
 msgid "break statement not within loop or switch"
 msgstr "оператор break вне цикла или оператора switch"
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -53284,27 +53310,27 @@ msgstr "результат сравнения всегда %<false%>, поско
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr "результат сравнения всегда %<true%>, поскольку адрес %qD не может быть NULL"
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "сравнение векторов с разными типами элементов"
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "сравнение векторов с разным числом элементов"
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "сравнение между типами %qT и %qT"
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "невозможно найти целый тип того же размера, что и %qT"
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
@@ -53377,30 +53403,30 @@ msgstr "объединение употреблено в контексте, г
 msgid "used vector type where scalar is required"
 msgstr "векторный тип использован в контексте, где допустимо только скалярное значение"
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> должна задавать одну из %<parallel%>, %<for%>, %<sections%> или %<taskgroup%> клаузул"
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<parallel%> or %<target%> %<if%> clause modifier"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "ожидался %<parallel%> или %<target%> модификатор %<if%> клаузулы"
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> должна задавать одну из %<parallel%>, %<for%>, %<sections%> или %<taskgroup%> клаузул"
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD не есть переменная в %qs клаузуле"
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE не есть переменная в %qs клаузуле"
@@ -53411,87 +53437,87 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%> %qD в %qs клаузуле"
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD есть threadprivate переменная в %qs клаузуле"
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "нижняя граница %qE секции массива не имеет целочисленный тип"
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "длина %qE секции массива не имеет целочисленный тип"
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer %qs in %s clause at %L"
 msgid "expected single pointer in %qs clause"
 msgstr "Указатель на процедуру %qs в %s клаузуле в %L"
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "секция массива нулевой длины в %qs клаузуле"
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "для массивного типа с неизвестной границей должно быть задано выражение для длины"
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "отрицательная нижняя граница в секции массива в %qs клаузуле"
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "отрицательная длина в секции массива в %qs клаузуле"
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "нижняя граница %qE выше размера секции массива в %qs клаузуле"
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "длина %qE выше размера секции массива в %qs клаузуле"
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "верхняя граница %qE выше размера секции массива в %qs клаузуле"
 
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, fuzzy, gcc-internal-format
 #| msgid "for unknown bound array type length expression must be specified"
 msgid "for array function parameter length expression must be specified"
 msgstr "для массивного типа с неизвестной границей должно быть задано выражение для длины"
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "для типа указателя должно быть задано выражение длины"
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "секция массив не непрерывна в %qs клаузуле"
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE не имеет тип указателя или массива"
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, fuzzy, gcc-internal-format
 #| msgid "throwing NULL, which has integral, not pointer type"
 msgid "iterator %qD has neither integral nor pointer type"
@@ -53503,19 +53529,19 @@ msgstr "исключительная ситуация NULL имеет целый
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "%<_Atomic%>-квалифицированный массивный тип"
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD has incomplete type"
 msgid "iterator %qD has const qualified type"
 msgstr "параметр %qD имеет неполный тип"
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "iterator step with non-integral type"
 msgstr "битовое поле %qD не целочисленного типа"
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
@@ -53525,39 +53551,39 @@ msgstr ""
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, fuzzy, gcc-internal-format
 #| msgid "condition expression refers to iteration variable %qD"
 msgid "begin expression refers to outer iterator %qD"
 msgstr "выражение условия ссылается на итерационную переменную %qD"
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, fuzzy, gcc-internal-format
 #| msgid "condition expression refers to iteration variable %qD"
 msgid "end expression refers to outer iterator %qD"
 msgstr "выражение условия ссылается на итерационную переменную %qD"
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, fuzzy, gcc-internal-format
 #| msgid "initializer expression refers to iteration variable %qD"
 msgid "step expression refers to outer iterator %qD"
 msgstr "выражение инициализатора ссылается на итерационную переменную %qD"
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected pointer in %qs clause"
 msgstr "ожидался указатель"
 
 #
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, fuzzy, gcc-internal-format
 #| msgid "using parameters for %<linear%> step is not supported yet"
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "модель кода %<large%> пока не поддерживается"
 
 #
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, fuzzy, gcc-internal-format
 #| msgid "using parameters for %<linear%> step is not supported yet"
 msgid "%<inscan%> %<reduction%> clause with array section"
@@ -53590,7 +53616,7 @@ msgstr "битовое поле %qE в %qs клаузуле"
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE имеет недопустимый тип для %<reduction(%s)%>"
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "определенная пользователем редукция не найдена для %qE"
@@ -53600,17 +53626,17 @@ msgstr "определенная пользователем редукция н
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "тип элемента переменой длины в предложении массива %<reduction%>"
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE должно быть %<threadprivate%> для %<copyin%>"
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, fuzzy, gcc-internal-format
 #| msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
@@ -53626,24 +53652,24 @@ msgstr "линейное предложение применено к нецел
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "%<_Atomic%> %qD в предложении %<linear%>"
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "шаг предложения %<linear%> %qE не является ни константой, ни параметром"
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE не является переменной в предложении %qs"
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr "%qD многократно встречается в предложениях данных"
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD многократно встречается в предложениях сокращения"
@@ -53655,32 +53681,32 @@ msgstr "%qE многократно встречается в предложен
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD многократно встречается в предложениях данных"
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD встречается в предложениях данных и сопоставления"
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE не является переменной в предложении %<firstprivate%>"
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE не является переменной в предложении %<lastprivate%>"
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE не является переменной в предложении %<aligned%>"
@@ -53700,7 +53726,7 @@ msgstr "%<_Atomic%> %qD в предложении %<aligned%>"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE многократно встречается в предложении %<aligned%>"
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<depend%> clause"
 msgid "%qE is not a variable in %<nontemporal%> clause"
@@ -53712,7 +53738,7 @@ msgstr "%qE не является переменной в предложении
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE многократно встречается в предложении %<aligned%>"
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<aligned%> clause"
 msgid "%qE is not a variable in %<allocate%> clause"
@@ -53724,78 +53750,78 @@ msgstr "%qE не является переменной в предложении
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE многократно встречается в предложении %<aligned%>"
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr ""
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<depend%> clause"
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr "%qE не является переменной в предложении %<depend%>"
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "секция массива не имеет отображаемый тип в предложении %qs"
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %qD"
 msgid "unsupported map expression %qE"
 msgstr "неподдерживаемый аргумент для %qD"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD многократно встречается в предложениях движения"
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD многократно встречается в предложениях сопоставления"
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD не имеет отображаемый тип в предложении %qs"
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE не является ни переменной, ни именем функции в предложении %qs"
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE многократно встречается в одной директиве %<declare target%><)%>"
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD не является аргументом в %<uniform%> предложении"
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE не является аргументом в %<uniform%> предложении"
@@ -53811,24 +53837,24 @@ msgstr "источник не есть указатель"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "%qs переменная не является ни указателем, ни массивом"
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %qs clauses on a task construct"
 msgstr "слишком много конструкций %qs"
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "предложение %<inbranch%> несовместимо с %<notinbranch%>"
 
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE является предопределённым %qs для %qs"
@@ -53838,41 +53864,41 @@ msgstr "%qE является предопределённым %qs для %qs"
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "значение предложения %<simdlen%> больше значения %<safelen%> предложения"
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "%<nonmonotonic%> модификатор планирования задан вместе с %<ordered%> предложением"
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "шаг %<linear%> предложения является параметром %qD, который не указан в %<uniform%> предложении"
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, fuzzy, gcc-internal-format
 #| msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
@@ -54167,7 +54193,7 @@ msgstr ""
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr ""
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -54175,7 +54201,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -54497,575 +54523,575 @@ msgstr "условное выражение между различными ук
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "перечислимый и неперечислимый тип в условном выражении"
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "нет %<%D(int)%> декларированного для постфиксного %qs, пробуем применить префиксный оператор"
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "нет %<%D(int)%> декларированного для постфиксного %qs"
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %qD is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "возвращаемое значение функции %qD - не %<int%>"
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "сравнение между %q#T и %q#T"
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to %<(%T) (%A)%>"
 msgid "no match for call to %<%T::operator[] (%A)%>"
 msgstr "не найден метод для преобразования в %<(%T) (%A)%>"
 
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, fuzzy, gcc-internal-format
 #| msgid "call of %<(%T) (%A)%> is ambiguous"
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr "вызов %<(%T) (%A)%> неоднозначен"
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, fuzzy, gcc-internal-format
 #| msgid "exception cleanup for this placement new selects non-placement operator delete"
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr "очистка исключений для этого размещения new выбирает неразмещенный оператор delete"
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD есть обычная (неразмещенная) функция освобождения в C++14 (или с -fsized-deallocation)"
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD есть обычная (неразмещенная) функция освобождения"
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "нет соответствующей функции освобождения для %qD"
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr ""
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "нет подходящего %<operator %s%> для %qT"
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "%q#D private в данном контексте"
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "декларировано private здесь"
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%q#D protected в данном контексте"
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "декларировано protected здесь"
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D недоступно в данном контексте"
 
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "передача NULL в неуказательный аргумент %P в %qD"
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, fuzzy, gcc-internal-format
 #| msgid " declared here"
 msgid "  declared here"
 msgstr " объявлено здесь"
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "преобразование в неуказательный тип %qT из NULL"
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "преобразование %<false%> в указательный тип для аргумента %P в %qD"
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "преобразование %<false%> в указательный тип %qT"
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  при инициализации %P -го аргумента %qD"
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, fuzzy, gcc-internal-format
 #| msgid "explicit conversion operators only available with -std=c++11 or -std=gnu++11"
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "явные операции преобразования доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "слишком много фигурных скобок вокруг инициализатора для %qT"
 
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 #, fuzzy
 #| msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr "ISO C++ не допускает %<alignof%> с не-типом"
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr ""
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 msgid "invalid conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "преобразование в %qT из списка инициализации будет использовать явный конструктор %qD"
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "в C++11 и выше подразумеваемый конструктор может быть явным"
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr ""
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 #, fuzzy
 #| msgid "conversion to non-const reference type %q#T from rvalue of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr "преобразование к неконстантной ссылки типа %qT из rvalue типа %qT"
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 #, fuzzy
 #| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "преобразование к volatile ссылке типа %qT из rvalue типа %qT"
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "недопустимое связывание битового поля %qE с %qT"
 
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "недопустимое связывание упакованного  поля %qE с %qT"
 
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "недопустимое связывание rvalue %qE с %qT"
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, fuzzy, gcc-internal-format
 #| msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr "scoped enum %qT передан дальше ... как %qT перед fabi-version=6, %qT после"
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "передача объектов нетривиально копируемого типа %q#T через %<...%> условно поддерживается"
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "невозможно принять ссылочный тип %q#T через %<...%>"
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "прием объектов нетривиально копируемого типа %q#T через %<...%> условно поддерживается"
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "рекурсивное вычисление подразумеваемого аргумента для %q#D"
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "вызов %qD использует подразумеваемый аргумент для параметра %P, который еще не определен"
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "аргумент вызова функции мог быть кандидатом для атрибута формата"
 
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "использование мультиверсионной функции без подразумеваемой"
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr ""
 
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "передача %qT как аргумент %<this%> отбрасывает квалификаторы"
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  в вызове %qD"
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT не является базовым для %qT"
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "передача аргументов в многоточие унаследованного конструктора %qD"
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr ""
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr ""
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr ""
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr "аргумент 3 в вызове функции %qE имеет тип указателя на boolean"
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "конструктор делегирует к себе"
 
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 msgid "cannot convert %qH to %qI"
 msgstr ""
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "нет подходящей функции для вызова %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr ""
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "вызов не функции %qD"
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "невозможно вызвать конструктор %<%T::%D%> непосредственно"
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "для приведения типов в функциональном стиле удалите избыточные %<::%D%>"
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "нет соответствующей функции для вызова %<%s(%A)%>"
 
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "вызов перегруженной %<%s(%A)%> имеет неоднозначную трактовку"
 
 #
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "чисто виртуальная %q#D вызвана из инициализатора нестатического элемента данных"
 
 #
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "чисто виртуальная %q#D вызвана из конструктора"
 
 #
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "чисто виртуальная %q#D вызвана из деструктора"
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "некорректный вызов элемента-функции %qD без объекта"
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "при передаче %qT предпочтение отдается %qT, а не %qT"
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr "ISO C++ говорит здесь о неоднозначности, хотя худшее преобразование для первого лучше, чем худшее преобразование для второго:"
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "try making the operator a %<const%> member function"
 msgstr "деструктор не может быть статической элементом-функцией"
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "предпочтение отдается %qD (а не %qD)"
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 msgid "  for conversion from %qH to %qI"
 msgstr ""
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  поскольку это дает лучшую последовательность преобразований аргумента"
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "несоответствие подразумеваемого аргумента при разрешении перегрузки"
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr ""
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr ""
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ говорит здесь о неоднозначности, хотя худшее преобразование для первого лучше, чем худшее преобразование для второго:"
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "временная граница %qD сохраняется, пока существует конструктор"
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr ""
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "possibly dangling reference to a temporary"
 msgstr "возврат ссылки на временную переменную"
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr ""
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, fuzzy, gcc-internal-format
 #| msgid "%s: definition of function '%s' not converted\n"
 msgid "explicit conversion function was not considered"
@@ -55113,7 +55139,7 @@ msgid "%q#D cannot be overloaded with %q#D"
 msgstr ""
 
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "предыдущая декларация %q#D"
@@ -55550,7 +55576,7 @@ msgstr "элемент регулируемого массива %qD в друг
 msgid "next member %q#D declared here"
 msgstr "следующий элемент %q#D объявлен здесь"
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "повторное определение %q#T"
@@ -55685,7 +55711,7 @@ msgstr ""
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
@@ -55727,7 +55753,7 @@ msgstr ""
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr ""
@@ -55745,7 +55771,7 @@ msgstr ""
 msgid "%q+E is not a constant expression"
 msgstr "%q+E не есть константное выражение"
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -55768,7 +55794,7 @@ msgstr "самосравнение всегда дает false"
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, gcc-internal-format
 msgid "call to internal function %qE"
@@ -55820,7 +55846,7 @@ msgstr "  %qT является неоднозначным базовым кла
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -55960,18 +55986,18 @@ msgstr "значение индекс массива %qE вне границ т
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "значение индекса массива %qE вне границ массива %qD типа %qT"
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "доступ к неинициализированному элементу массива"
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "доступ по пустому указателю в %qE"
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -55979,517 +56005,517 @@ msgstr "доступ по пустому указателю в %qE"
 msgid "%qE is not a constant expression"
 msgstr "%qE не есть константное выражение"
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "mutable %qD не может использоваться в константном выражении"
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "доступ к неинициализированному элементу %qD"
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "обращение к элементу %qD вместо инициализированного элемента %qD в константном выражении"
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на mutable подобъекты %qT"
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "вложенные функции не поддерживаются для этой платформы"
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, fuzzy, gcc-internal-format
 #| msgid "accessing uninitialized member %qD"
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "доступ к неинициализированному элементу %qD"
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "обращение к значению %qE через %qT glvalue в константном выражении"
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, fuzzy, gcc-internal-format
 #| msgid "use of the value of the object being constructed in a constant expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "использование значения конструируемого объекта в константном выражении"
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "allocated here"
 msgstr "объявлено здесь"
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
 msgstr ""
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, fuzzy, gcc-internal-format
 #| msgid "the value of %qD is not usable in a constant expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "значение %qD не может использоваться в константном выражении"
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "значение %qD не может использоваться в константном выражении"
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD использована в своем собственном инициализаторе"
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D не есть const"
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D переменная"
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD не была инициализирована константным выражением"
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD не была декларирована %<constexpr%>"
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD не имеет целый или перечислимый тип"
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, fuzzy, gcc-internal-format
 #| msgid "modification of %qE is not a constant expression"
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr "модификация %qE не есть константное выражение"
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, fuzzy, gcc-internal-format
 #| msgid "modification of %qE is not a constant expression"
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr "модификация %qE не есть константное выражение"
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, fuzzy, gcc-internal-format
 #| msgid "a reinterpret_cast is not a constant expression"
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr "reinterpret_cast не является константным выражением"
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, fuzzy, gcc-internal-format
 #| msgid "modification of %qE is not a constant expression"
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr "модификация %qE не есть константное выражение"
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, fuzzy, gcc-internal-format
 #| msgid "Change of value in conversion from %qs to %qs at %L"
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr "Изменение значения в преобразовании из %qs в %qs в %L"
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr ""
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr ""
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, fuzzy, gcc-internal-format
 #| msgid "Change of value in conversion from %qs to %qs at %L"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "Изменение значения в преобразовании из %qs в %qs в %L"
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "оператор не является константным выражением"
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "глубина конкретизации шаблона превышает максимум %d (используйте -ftemplate-depth=, чтобы увеличить максимум)"
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "inline assembly is not a constant expression"
 msgstr "элемент инициализатора не является константным выражением"
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "use of %qD"
 msgstr "некорректное использование %qD"
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr ""
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr ""
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr ""
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr ""
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "значение %qE типа %qT не есть константное выражение"
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "глубина конкретизации шаблона превышает максимум %d (используйте -ftemplate-depth=, чтобы увеличить максимум)"
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, fuzzy, gcc-internal-format
 #| msgid "capture of variable %qD with non-automatic storage duration"
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "capture переменной  %qD с неавтоматическим сроком хранения"
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "временная нелитерального типа %qT в константном выражении"
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, fuzzy, gcc-internal-format
 #| msgid "a reinterpret_cast is not a constant expression"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "reinterpret_cast не является константным выражением"
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "преобразование из указательного типа %qT в арифметический тип %qT в константном выражении"
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на mutable подобъекты %qT"
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, fuzzy, gcc-internal-format
 #| msgid "routine %qD declared here"
 msgid "pointed-to object declared here"
 msgstr "программа %qD декларирована здесь"
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr "параметр шаблона %qD типа %qT не допускается в целочисленном константном выражении, поскольку он не целого или перечислимого типа"
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, fuzzy, gcc-internal-format
 #| msgid "the value of %qD is not usable in a constant expression"
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr "значение %qD не может использоваться в константном выражении"
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на не полностью инициализированную переменную"
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> не является константным выражением"
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "выражение %qE не является константным выражением"
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> не есть константное выражение"
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, fuzzy, gcc-internal-format
 #| msgid "a reinterpret_cast is not a constant expression"
 msgid "contract predicate is false in constant expression"
 msgstr "reinterpret_cast не является константным выражением"
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-id"
 msgid "unexpected template-id %qE"
 msgstr "ожидался template-id"
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qE must be directly called"
 msgid "function concept must be called"
 msgstr "внутренняя функция %qE должна вызываться напрямую"
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "размер массива %qD не является целочисленным константным выражением"
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "неожиданное выражение %qE вида %s"
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на mutable подобъекты %qT"
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на не полностью инициализированную переменную"
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на mutable подобъекты %qT"
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qE не есть константное выражение, поскольку оно ссылается на mutable подобъекты %qT"
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, fuzzy, gcc-internal-format
 #| msgid "statement cannot resolve address of overloaded function"
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr "оператор не может разрешить адрес перегруженной функции"
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "некорректное приведение rvalue выражения из типа %qT к типу %qT"
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from integer to pointer"
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "reinterpret_cast из целого в указатель"
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of объекта %qE с поточно-локальным или автоматическим хранением не есть константное выражение"
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "использование %<this%> в константном выражении"
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr ""
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant expression"
 msgid "new-expression is not a constant expression before C++20"
 msgstr "выражение %qE не является константным выражением"
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "виртуальные функции не могут быть friend-функциями"
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, fuzzy, gcc-internal-format
 #| msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "приведение к нецелочисленному типу %qT в константном выражении"
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "%qD декларирована %<thread_local%> я %<constexpr%> функции"
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared %<static%> in %<constexpr%> function"
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "%qD декларирована %<static%> я %<constexpr%> функции"
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "деление на ноль не есть константное выражение"
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> не есть константное выражение"
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<this%> in a constant expression"
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "использование %<this%> в константном выражении"
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "неконстантная инициализация массива"
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "неожиданное AST вида %s"
@@ -57301,7 +57327,7 @@ msgstr "третий аргумент %<__builtin_prefetch%> должен быт
 msgid "no suspend point info for %qD"
 msgstr "прототип для %qD не был предварительно определен"
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -57324,23 +57350,23 @@ msgstr "в конструкции case нельзя употреблять ук
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "граница массив переменной длины неизвестна"
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, fuzzy, gcc-internal-format
 #| msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
@@ -57362,79 +57388,79 @@ msgstr ""
 msgid "%qD was promoted to an immediate function"
 msgstr "%qD не является функцией шаблоном"
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to member function %q#D"
 msgid "taking address of an immediate function %qD"
 msgstr "слишком много аргументов для элемента-функции %q#D"
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, fuzzy, gcc-internal-format
 #| msgid "modification of %qE is not a constant expression"
 msgid "call to consteval function %qE is not a constant expression"
 msgstr "модификация %qE не есть константное выражение"
 
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, fuzzy, gcc-internal-format
 #| msgid "throw will always call terminate()"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "throw будет всегда вызывать terminate()"
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, fuzzy, gcc-internal-format
 #| msgid "in C++11 destructors default to noexcept"
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "в C++11 деструкторы подразумевают noexcept"
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, fuzzy, gcc-internal-format
 #| msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr "в C++11 это throw терминируется, поскольку деструкторы подразумевают noexcept"
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes in template argument %qE"
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "игнорирование атрибутов аргумента шаблона %qE"
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qE attribute"
 msgid "pack expansion of %qE attribute"
 msgstr "некорректный аргумент атрибута %qE"
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in template-argument"
 msgid "use fold expression in the attribute argument instead"
 msgstr "lambda-выражение в аргументе шаблона"
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD не является типом"
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qD is not a class type"
 msgstr "%qT не является классовым типом"
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have pointer or array type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE не имеет тип указателя или массива"
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qD does not have integral type"
 msgstr "%qD не имеет целый или перечислимый тип"
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
@@ -57477,7 +57503,7 @@ msgstr "преобразование к неконстантной ссылки
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "преобразование %qT в %qT не снимает указатель"
@@ -57870,7 +57896,7 @@ msgstr "из предыдущей декларации %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "редекларация %qD отличается в %<constexpr%> от предыдущей декларации"
 
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "предыдущая декларация %qD"
@@ -58021,8 +58047,8 @@ msgstr "предыдущая декларация %<pragma omp declare reduction
 msgid "%q#D previously defined here"
 msgstr "%q#D ранее определено здесь"
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q#D ранее декларировано здесь"
@@ -58102,60 +58128,42 @@ msgstr "подразумеваемый аргумент задан для пар
 msgid "previous specification in %q#D here"
 msgstr "предыдущая спецификации в %q#D здесь"
 
-#: cp/decl.cc:2285
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
-msgid "declaration %qD conflicts with builtin"
-msgstr "декларация %q+#D конфликтует с внутренней декларацией %q#D"
-
-#: cp/decl.cc:2288
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of namespace %qD conflicts with"
-msgid "declaration %qD conflicts with import"
-msgstr "декларация namespace %qD противоречит"
-
-#: cp/decl.cc:2289
-#, fuzzy, gcc-internal-format
-#| msgid " declared here"
-msgid "import declared %q#D here"
-msgstr " объявлено здесь"
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q+#D"
 msgid "conflicting exporting for declaration %qD"
 msgstr "конфликтующая декларация %q+#D"
 
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared here without exporting"
 msgstr "предыдущая декларация здесь"
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %qD was here"
 msgid "previous definition of %qD here"
 msgstr "предыдущее определение %qD было здесь"
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %qD was here"
 msgid "previous declaration of %qD here"
 msgstr "предыдущая декларация %qD была здесь"
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared %<virtual%> inside a union"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "функция %qD декларирована %<virtual%> внутри объединения"
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "избыточная повторная декларация %qD в той же области видимости"
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, fuzzy, gcc-internal-format
 #| msgid "deleted definition of %q+D"
 msgid "deleted definition of %qD is not first declaration"
@@ -58169,44 +58177,44 @@ msgstr "удаленное определение %q+D"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "явная специализация %qD после первого использования"
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%qD: атрибут видимости проигнорирован, так как он конфликтует с предыдущей декларацией"
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "переопределение %q#D"
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD противоречит использованной функции"
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D не декларировано в классе"
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D переопределен inline с %<gnu_inline%> атрибутом"
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D переопределен inline без %<gnu_inline%> атрибута"
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -58214,766 +58222,766 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "редекларация friend %q#D не может иметь подразумеваемые аргументы шаблона"
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "локальная для потока декларация %q#D следует за не локальной для потока декларацией"
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "не локальная для потока декларация %q#D следует за локальной для потока декларацией"
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "редекларация %q#D"
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "избыточное переопределение %<constexpr%> элемента статических данных %qD"
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "локальная метка %qE конфликтует с существующей меткой"
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, gcc-internal-format
 msgid "previous label"
 msgstr "предыдущая метка"
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, gcc-internal-format
 msgid "jump to label %qD"
 msgstr "переход по метке %qD"
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr "переход по case-метке"
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr ""
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  отсюда"
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  покидает OpenMP структурный блок"
 
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  пересекает инициализацию %q#D"
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  входит в try-блок"
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  входит в catch-блок"
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  входит в OpenMP структурный блок"
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "  входит в синхронизируемый или атомарный оператор"
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, fuzzy, gcc-internal-format
 #| msgid "jump into statement expression"
 msgid "  enters statement expression"
 msgstr "переход в выражение-оператор"
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, fuzzy, gcc-internal-format
 #| msgid "  enters %<constexpr%> if statement"
 msgid "  enters %<constexpr if%> statement"
 msgstr "  входит в %<constexpr%> оператор if"
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, fuzzy, gcc-internal-format
 #| msgid "  enters %<constexpr%> if statement"
 msgid "  enters %<consteval if%> statement"
 msgstr "  входит в %<constexpr%> оператор if"
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C99 does not support %qE"
 msgid "  does not destroy %qD"
 msgstr "ISO C99 не поддерживает %qE"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, gcc-internal-format
 msgid "  does not clean up handled exception"
 msgstr ""
 
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  пропускает инициализацию %q#D"
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "использование %qD без параметров шаблона"
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is a function, not a type"
 msgstr "%qD не является шаблоном функции"
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T не является классом"
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "шаблон класса с именем %q#T' отсутствует в %q#T"
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "нет имени типа %q#T в %q#T"
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "просмотр %qT в %qT неоднозначен"
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> именует %q#T, который не является шаблоном класса"
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, fuzzy, gcc-internal-format
 #| msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> именует %q#T, который не является типом"
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "параметры шаблона не соответствуют шаблону %qD"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, fuzzy, gcc-internal-format
 #| msgid "-faligned-new=%d is not a power of two"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "-faligned-new=%d не есть степень двойки"
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous struct not inside named type"
 msgid "anonymous struct with base classes"
 msgstr "анонимная структура не внутри именованного типа"
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "элемент %q+#D с конструктором недопустим в анонимном агрегатном типе"
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "элемент %q+#D с деструктором недопустим в анонимном агрегатном типе"
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "элемент %q+#D с операцией присваивания-копирования недопустим в анонимном агрегатном типе"
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "атрибуты проигнорированы в декларации %q#T"
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "атрибут для %q#T должен следовать за %qs ключевым словом"
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "несколько типов в одной декларации"
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "повторная декларация внутреннего типа C++ %qT"
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> можно задавать только для переменных или деклараций функций"
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "отсутствует имя типа в typedef-декларации"
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "в ISO C++ анонимные структуры запрещены"
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> может задаваться только для функций"
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> может задаваться только для функций"
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> может быть задан только внутри класса"
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> может быть задан только для конструкторов"
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "класс хранения может быть задан только для объектов и функций"
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> может задаваться только для объектов и функций"
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> может задаваться только для объектов и функций"
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> может задаваться только для объектов и функций"
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> может задаваться только для объектов и функций"
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> в этой декларации отброшен"
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%> не может использоваться для деклараций типов"
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "атрибут игнорируется в явной конкретизации %q#T"
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "никакой атрибут не может применяться к явной конкретизации"
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "игнорирование атрибутов примененных к классу %qT вне определения"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "игнорирование атрибутов примененных к зависимому типу %qT без ассоциированной декларации"
 
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use decltype instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD инициализирован (используйте decltype взамен)"
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "декларация %q#D содержит %<extern%> и инициализирована"
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "определение функции %q#D помечено %<dllimport%>"
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D не есть статический элемент данных %q#T"
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "non-member-template декларация %qD"
 
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "не соответствует декларации элемента шаблона здесь"
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ не разрешает определять %<%T::%D%> как %<%T::%D%>"
 
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "повторная инициализация %qD"
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "декларация %q#D вне класса не является определением"
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr ""
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "переменная %q#D инициализирована, хотя имеет неполный тип"
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "элементы массива %q#D имеют неполный тип"
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "агрегатный тип %q#D неполон и не может быть определён"
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "переменная %qD декларирована как ссылка, но не инициализирована"
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "имя использовано в определенном в GNU-стиле инициализаторе массива"
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "имя %qD использовано в определенном в GNU-стиле инициализаторе массива"
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "нетривиально определенные инициализаторы не поддерживаются"
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "C99 обозначение %qE не является целочисленным константным выражением"
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "при инициализации не удалось определить размер %qD"
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "не задан размер массива для %qD"
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "массив %qD имеет нулевой размер"
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "размер памяти %qD неизвестен"
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "размер памяти %qD не константа"
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "простите: семантики inline переменной %q#D являются неверными (запутаетесь с несколькими копиями)"
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "простите: семантики статических данных inline функции %q#D являются неверными (запутаетесь с несколькими копиями)"
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "это можно обойти, удалив инициализатор"
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "неинициализированная константа %qD"
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "неинициализированная переменная %qD в %<constexpr%> функции"
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T не имеет предоставленный пользователем подразумеваемый конструктор"
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "конструктор не является предоставленным пользователем, поскольку он явно подразумевался в теле класса"
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "и неявно определенный конструктор не инициализирует %q#D"
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "некорректный тип %qT является инициализатором для вектора типа %qT"
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "инициализатор для %qT должен быт заключен в фигурные скобки"
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> использовано в определенном в GNU-стиле инициализаторе для класса %qT"
 
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "запрос элемента %qD неоднозначен"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT не имеет нестатического элемента данных с именем %qD"
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD не является элементом %qT"
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "некорректный инициализатор для %q#D"
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 обозначение %qE вне инициализатора агрегата"
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "избыточные элементы в инициализаторе для %qT"
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "фигурные скобки вокруг скалярного инициализатора для типа %qT"
 
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "фигурные скобки вокруг скалярного инициализатора для типа %qT"
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "отсутствуют фигурные скобки вокруг инициализатора %qT"
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type %qT"
 msgid "structured binding has incomplete type %qT"
 msgstr "поле %qD имеет неполный тип %qT"
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "элементы массива %q#T имеют неполный тип"
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "составной литерал переменного размера"
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D имеет неполный тип"
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "в инициализаторе скалярного объекта %qD должен быть только один элемент"
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "в C++98 %qD следует инициализировать при помощи конструктора, а не %<{...}%>"
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "массив %qD инициализируется строковой константой %qE, заключённой в скобки"
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "инициализатор недопустим для статического элемента с конструктором"
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "неконстантная инициализация внутри класса некорректна для статического элемента %qD"
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "неконстантная инициализация внутри класса некорректна для non-inline статического элемента %qD"
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(запрошена инициализация вне класса)"
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "ссылка %qD инициализируется собой"
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%> не является декларацией"
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to constructor %q#D"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "слишком мало аргументов для конструктора %q#D"
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "повторная декларация перечислимого типа %q+D"
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "присваивание (а не инициализация) в декларации"
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "использован %<register%> спецификатор класса хранения"
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "декларация %q#D не имеет инициализатора"
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "инициализатор для %<decltype(auto) %D%> имеет тип функции (вы забыли %<()%> ?)"
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "тип результата %q#T неполный"
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "переменная concept не имеет инициализатора"
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "перекрытие предыдущей декларации %q#D"
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables in static storage"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "атрибут %qE применим только к переменным в статической памяти"
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "функция %q#D инициализирована как переменная"
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "невозможна декомпозиция типа класса %qT, так как он содержит анонимный элемент структуры"
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "невозможна декомпозиция типа класса %qT, так как он имеет анонимный элемент объединения"
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "невозможна декомпозиция типа класса %qT: и он и его базовый класс %qT имеют нестатические элементы данных"
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "невозможна декомпозиция типа класса %qT: его базовые классы %qT и %qT имеют нестатические элементы данных"
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr ""
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "невозможна декомпозиция массива переменной длины %qT"
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -58981,7 +58989,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -58989,7 +58997,7 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -58997,1822 +59005,1822 @@ msgstr[0] ""
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> не является целочисленным константным выражением"
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "невозможна декомпозиция типа объединения %qT"
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "невозможна декомпозиция non-array non-class типа %qT"
 
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "невозможна декомпозиция типа lambda замыкания %qT"
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr ""
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "невозможна декомпозиция типа класса %qT без нестатических элементов данных"
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "нелокальная переменная %qD декларированная %<__thread%> требует динамической инициализации"
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "нелокальная переменная %qD декларированная %<__thread%> имеет нетривиальный деструктор"
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "C++11 %<thread_local%> допускает динамическую инициализацию и уничтожение"
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "при инициализации не удалось определить размер %qT"
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "не задан размер массива в %qT"
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "нулевой размер массива %qT"
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "деструктор чужого класса %qT не может быть элементом"
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "конструктор чужого класса %qT не может быть элементом"
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD декларирована как %<virtual%> переменная"
 
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации переменной"
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD декларирован как %<virtual%> параметр"
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD декларирован как %<inline%> параметр"
 
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации параметра"
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD декларирован как %<virtual%> тип"
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD декларирован как %<inline%> тип"
 
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации типа"
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD декларирован как %<virtual%> поле"
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD декларирован как %<inline%> поле"
 
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации поля"
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D декларировано как friend"
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D декларировано со спецификацией исключений"
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "определение %qD вне пространства имён, объемлющего %qT"
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "статическая функция-член %q#D объявлена с квалификаторами типа"
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "concept %q#D декларирован с параметрами функциями"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "concept %q#D декларирован с выведенным типом возврата"
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "concept %q#D с non-%<bool%> типом возврата %qT"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "concept %qD не имеет определения"
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be instrumented"
 msgid "a function concept cannot be constrained"
 msgstr "функция не может быть инструментирована"
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD не является функцией шаблоном"
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "constrained non-template friend declaration must be a definition"
 msgstr "friend-декларация вне определения класса"
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "определение явной специализации %qD в friend-декларации"
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "некорректное использование идентификатора шаблона %qD в декларации первичного шаблона"
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "аргументы по умолчанию не допускаются в декларации специализации friend-шаблона %qD"
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "не допускается использовать %<inline%> в декларации специализации friend-шаблона %qD"
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "декларация %q#D вне класса не является определением"
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "недопустимая декларация %<::main%> как шаблона"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "недопустимая декларация %<::main%> как inline-функции"
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "недопустимая декларация %<::main%> как статической функции"
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "недопустимая декларация %<::main%> как статической функции"
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "не-элемент-функция %qD не может иметь cv-квалификатор"
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "статическая элемент-функция %qD не может иметь cv-квалификатор"
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr "статическая элемент-функция %qD не может иметь cv-квалификатор"
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "non-member функция %qD не может иметь ref-квалификатор"
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "статическая элемент-функция %qD не может иметь ref-квалификатор"
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have ref-qualifier"
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr "статическая элемент-функция %qD не может иметь ref-квалификатор"
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD declared here"
 msgid "explicit object parameter declared here"
 msgstr "параметр шаблона %qD декларирован здесь"
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, fuzzy, gcc-internal-format
 #| msgid "deduction guide %qD must be declared at namespace scope"
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "руководство вывода %qD должно декларироваться в контексте пространства имен"
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, fuzzy, gcc-internal-format
 #| msgid "deduction guide %qD must be declared at namespace scope"
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "руководство вывода %qD должно декларироваться в контексте пространства имен"
 
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "руководство вывода %qD не должно иметь тело функции"
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "литеральный оператор с C-привязкой"
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD имеет некорректный список аргументов"
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "целый суффикс %qs перекрыт реализацией"
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, fuzzy, gcc-internal-format
 #| msgid "floating point suffix %qs shadowed by implementation"
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "суффикс плавающей точки %qs перекрыт реализацией"
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "суффиксы литеральных операторов без предшествующего %<_%> зарезервированы для будущей стандартизации"
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD должен быть не-элемент-функцией"
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> должна возвращать %<int%>"
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "определение неявно декларированного %qD"
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "определение явно подразумеваемого %q+D"
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D явно подразумевается здесь"
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "нет элемента-функции %q#D в классе %qT"
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "невозможно декларировать %<::main%> как глобальную переменную"
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "non-template переменная не может быть %<concept%>"
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, fuzzy, gcc-internal-format
 #| msgid "deduction guide %qD must be declared at namespace scope"
 msgid "concept must be defined at namespace scope"
 msgstr "руководство вывода %qD должно декларироваться в контексте пространства имен"
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "concept должен иметь тип %<bool%>"
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, fuzzy, gcc-internal-format
 #| msgid "variable concept has no initializer"
 msgid "a variable concept cannot be constrained"
 msgstr "переменная concept не имеет инициализатора"
 
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "инициализация внутри класса статического элемента данных %q#D неполного типа"
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> требуется для инициализации внутри класса статического элемента данных %q#D нецелого типа"
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "инициализация внутри класса статического элемента данных %q#D нелитерального типа"
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "некорректная инициализация внутри класса статического элемента данных нецелочисленного типа %qT"
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ запрещает инициализацию внутри класса неконстантного статического элемента %qD"
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ запрещает инициализацию элемента-константы %qD нецелочисленного типа %qT"
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "размер массива %qD имеет нецелочисленный тип %qT"
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "размер массива имеет нецелочисленный тип %qT"
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "размер массива %qD не является целочисленным константным выражением"
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "размер массива не является целочисленным константным выражением"
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ запрещает массив нулевого размера %qD"
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ запрещает массивы нулевого размера"
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ запрещает массив переменного размера %qD"
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ запрещает массивы переменного размера"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "используется массив переменного размера %qD"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "используется массив переменного размера"
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "переполнение в размерности массива"
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as array of %qT"
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%qD декларировано как массив %qT"
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "creating array of template placeholder type %qT"
 msgstr "создание указателя на элемент ссылочного типа %qT"
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "декларация %qD как массива void"
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "создание массива void"
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "декларация %qD как массива функций"
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "создание массива функций"
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "декларация %qD как массива ссылок"
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "создание массива ссылок"
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "декларация %qD как массива элементов-функций"
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "создание массива элементов-функций"
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "декларация многомерного массива %qD должна определять границы для всех размерностей, кроме первой"
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "в многомерном массиве должны быть определены границы для всех размерностей, кроме первой"
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable-length array of %<auto%>"
 msgstr "используется массив переменного размера"
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "некорректная спецификация возвращаемого типа в конструкторе"
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "квалификаторы не допускаются в декларации конструктора"
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "некорректная спецификация возвращаемого типа в деструкторе"
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "квалификаторы не допускаются в декларации деструктора"
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "тип результата задан для %<operator %T%>"
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "квалификаторы не допускаются в декларации %<operator %T%>"
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "возвращаемый тип задан для руководства вывода"
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "квалификаторы не допускаются в декларации руководства вывода"
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, fuzzy, gcc-internal-format
 #| msgid "decl-specifier in declaration of deduction guide"
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "decl-спецификатор в декларации руководства вывода"
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "декларация безымянной переменной или поля с типом void"
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "декларация переменной или поля с типом void"
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "%<inline%> спецификатор некорректен для переменной %qD декларированной в контексте блока"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT как тип а не плоский %<decltype(auto)%>"
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "деструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "недопустимое использование квалифицированного имени %<::%D%>"
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "недопустимое использование квалифицированного имени %<%T::%D%>"
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "недопустимое использование квалифицированного имени %<%D::%D%>"
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT не является классом или пространством имён"
 
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "декларация %qD как не-функции"
 
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "декларация %qD как не-элемента"
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "декларатор отсутствует; используется зарезервированное слово %qD"
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "определение функции не объявляет параметры"
 
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "декларация %qD как не-функции"
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "декларация %qD как %<typedef%>"
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "декларация %qD как параметра"
 
 #
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, fuzzy, gcc-internal-format
 #| msgid "no classes specified"
 msgid "both %qs and %qs specified"
 msgstr "нет специфицированных классов"
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%<constexpr%> не может встречаться в typedef декларации"
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "два или более типа в декларации имени %qs"
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C++ не поддерживает плоские %<complex%> означающие %<double complex%>"
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ запрещает декларации %qs без типа"
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> не поддерживается этой целевой платформой"
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ не поддерживает %<__int%d%> для %qs"
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, fuzzy, gcc-internal-format
 #| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> и %<unsigned%> одновременно заданы для %qs"
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> и %<short%> одновременно заданы для %qs"
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, fuzzy, gcc-internal-format
 #| msgid "%qs used with %qE"
 msgid "%qs specified with %qT"
 msgstr "%qs использован с %qE"
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, fuzzy, gcc-internal-format
 #| msgid "%qs specified with %<typeof%>"
 msgid "%qs specified with typedef-name %qD"
 msgstr "%qs указан с %<typeof%>"
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs указан с %<decltype%>"
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qs указан с %<typeof%>"
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "спецификатор complex для %qs недопустим"
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, fuzzy, gcc-internal-format
 #| msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr "за типом заполнителя шаблона %qT должен следовать простой declarator-id"
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "элемент %qD не может быть декларирован и как %<virtual%> и как %<static%>"
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "элемент %qD не может быть декларирован и как %<virtual%> и как %<constexpr%>"
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef-декларация не допускается в декларации параметров"
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "класс хранения задан для параметра шаблона %qs"
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "класс хранения в декларации параметра %qs"
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %qs"
 msgstr "параметр не может быть декларирован %<constexpr%>"
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> вне декларации класса"
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr ""
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "unrestricted объединения допустимы только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for structured binding declaration"
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "некорректный инициализатор для структурированной связывающей декларации"
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr ""
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "тип должен быть cv-qualified %<auto%> или ссылкой на cv-qualified %<auto%>"
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr ""
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "в декларации %qs задано более одного класса хранения"
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "для %qs задан класс хранения"
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "вложенная функция %qs объявлена %<extern%>"
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "имя %qs описано на верхнем уровне с классом хранения %<auto%>"
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "имя %qs на уровне функции неявно имеет класс auto и объявлено %<__thread%>"
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "класс хранения не допускается в декларации friend-функции"
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "атрибут проигнорирован"
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "атрибут, относящийся к спецификатору типа, игнорируется"
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr ""
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "Ожидалась открывающая скобка"
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, fuzzy, gcc-internal-format
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "%<~auto%> доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, fuzzy, gcc-internal-format
 #| msgid "Function %qs at %L cannot have an initializer"
 msgid "a function type cannot have an explicit object parameter"
 msgstr "Функция %qs в %L не может иметь инициализатор"
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, fuzzy, gcc-internal-format
 #| msgid "a conversion function cannot have a trailing return type"
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr "функция преобразования не может иметь завершающий тип возврата"
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, fuzzy, gcc-internal-format
 #| msgid "  member function type %qT is not a valid template argument"
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr "  тип элемента-функции %qT не есть корректный аргумент шаблона"
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr ""
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, gcc-internal-format
 msgid "the type of an explicit object member function is a regular function type"
 msgstr ""
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD declared here"
 msgid "valid explicit object parameter declared here"
 msgstr "параметр шаблона %qD декларирован здесь"
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "requires-клаузула для типа возврата"
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs функция использует %<auto%> спецификатор типа без завершающего типа возврата"
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, fuzzy, gcc-internal-format
 #| msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "выведенный тип возврата доступен только с -std=c++14 или -std=gnu++14"
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "виртуальная функция не может иметь выведенный тип возврата"
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs функция с завершающим типом возврата имеет %qT в качестве своего типа а не обычный %<auto%>"
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "%qs функция с завершающим типом возврата имеет %qT в качестве своего типа а не обычный %<auto%>"
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "неверное употребление спецификатора %<restrict%>"
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "руководство вывода для %qT должно иметь завершающий тип возврата"
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "хвостовой тип возврата %qT руководства вывода не есть специализация %qT"
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "завершающий тип возврата доступен только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs функция с завершающим типом возврата не декларирована с %<auto%> спецификатором типа"
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "функция преобразования не может иметь завершающий тип возврата"
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%>-qualified return type of %qD"
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "%<_Atomic%>-квалифицированный возвращаемый тип в %qD"
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs объявлена как функция, возвращающая функцию"
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs объявлена как функция, возвращающая массив"
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "функция с атрибутом noreturn возвращает не-void значение"
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "деструктор не может быть статической элементом-функцией"
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "конструктор не может быть статической элементом-функцией"
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "деструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "конструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "деструкторы не могут быть ref-квалифицированы"
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "конструкторы не могут быть ref-квалифицированы"
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "конструкторы не могут быть декларированы %<virtual%>"
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "виртуальные функции не могут быть friend-функциями"
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-декларация вне определения класса"
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "невозможно определить friend-функцию %qs в определении локального класса"
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr "не-элемент-функция %qD не может иметь cv-квалификатор"
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, fuzzy, gcc-internal-format
 #| msgid "implicit templates may not be %<virtual%>"
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr "неявные шаблоны не могут быть %<virtual%>"
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD cannot be an explicit object member function"
 msgstr "%qD должен быть нестатической элементом-функцией"
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "деструкторы не могут иметь параметров"
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "недопустимая декларация указателя на %q#T"
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "недопустимая декларация ссылки на %q#T"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "недопустимая декларация указателя на элемент %q#T"
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "невозможно декларировать ссылку на квалифицированный тип функции %qT"
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "невозможно декларировать указатель на квалифицированный тип функции %qT"
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "Недопустимо определять ссылку на %q#T, которая не будет определением типа или аргументом шаблона"
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "идентификатор шаблона %qD использован как декларатор"
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "элементы-функции неявно считаются friend-функциями своего класса"
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "избыточная квалификация %<%T::%> элемента %qs"
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "недопустимая декларация элемента %<%T::%s%> внутри %qT"
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "не параметрический %qs не может содержать параметры"
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "элемент данных не может иметь тип %qT модифицируемого размера"
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "параметр не может иметь модифицированный тип `%T"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> вне декларации класса"
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> в friend декларации"
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "только декларации конструкторов и операторов преобразования могут быть %<explicit%>"
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация не-элемента %qs как %<mutable%>"
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация не объектного элемента %qs как %<mutable%>"
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация функции %qs как %<mutable%>"
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация статического %qs как %<mutable%>"
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация константного %qs как %<mutable%>"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "ссылка %qs не может быть декларирована %<mutable%>"
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a function definition"
 msgstr "типы нельзя определять в условиях"
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a member function definition"
 msgstr "типы нельзя определять в условиях"
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> не является декларацией"
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef декларирован %<auto%>"
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "requires-клаузула для typedef"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef имя не может быть вложенным спецификатором имени"
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ запрещает определять вложенный тип %qD с тем же именем, что и объемлющий класс"
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "в декларации friend-класса использован квалификатор %<inline%>"
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "параметры шаблона не могут быть friend"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "в friend-декларации требуется указание класса: %<friend class %T::%D%>"
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "в friend-декларации требуется указание класса: %<friend %#T%>"
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "попытка сделать класс %qT \"другом\" глобальной области видимости"
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "некорректные квалификаторы для типа функции, не являющейся элементом"
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "requires-клаузула для идентификатора типа"
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "абстрактный декларатор %qT использован в качестве декларатора"
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "requires-клаузула в декларации нефункционального типа %qT"
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "недопустимое использование %<::%> в декларации параметра"
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "невозможно декларировать параметр с абстрактным типом %qT"
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<auto%> параметр недопустим в данном контексте"
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "параметр декларирован %<auto%>"
 
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "некорректное использование имени шаблона %qE без списка аргументов"
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "нестатический элемент данных декларирован с заполнителем %qT"
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ запрещает элемент регулируемый массив %qs"
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C++ запрещает элементы регулируемые массивы"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "недопустимое использование %<::%>"
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "декларация функции %qD в неверном контексте"
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "функция %qD декларирована %<virtual%> внутри объединения"
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD не может быть декларирована %<virtual%>, поскольку она всегда статическая"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "ожидалось квалифицированное имя в friend декларации для деструктора %qD"
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "декларация %qD как элемента %qT"
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %qs"
 msgstr "деструктор не может быть %<constexpr%>"
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "ожидалось квалифицированное имя в friend декларации для конструктора %qD"
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "конструктор не может быть %<concept%>"
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "concept не может быть элементом-функцией"
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "ошибка открытия %s"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "специализация переменного шаблона %qD декларирована как функция"
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "переменный шаблон декларирован здесь"
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "поле %qD имеет неполный тип %qT"
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "имя %qT имеет неполный тип"
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE не является ни функцией, ни элементом-функцией; не может быть декларировано как friend"
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE не является ни функцией, ни элементом-функцией; не может быть декларировано как friend"
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, fuzzy, gcc-internal-format
 #| msgid "an attribute that appertains to a type-specifier is ignored"
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr "атрибут, относящийся к спецификатору типа, игнорируется"
 
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, fuzzy, gcc-internal-format
 #| msgid "static data member %qE declared %<concept%>"
 msgid "static data member %qE declared %qs"
 msgstr "статический элемент данных %qE декларирован %<concept%>"
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "нестатический элемент данных %qE объявлен как %<constexpr%>"
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "некорректный класс хранения %<auto%> для функции %qs"
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "некорректный класс хранения %<register%> для функции %qs"
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "некорректный класс хранения %<__thread%> для функции %qs"
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "класс хранения %<thread_local%> недопустим для функции %qs"
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, fuzzy, gcc-internal-format
 #| msgid "alignment specified for function %qE"
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr "выравнивание задано для функции %qE"
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-спецификаторы в %qs не допускаются вне определения класса"
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> спецификатор некорректен для функции %qs декларированной вне глобального контекста"
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "некорректно указано %<inline%> для функции %qs, объявленной вне глобальной области видимости"
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "виртуальная функция %qs не является элементом класса"
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs определен не в контексте класса"
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs декларирован не в контексте класса"
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "недопустимая декларация статического элемента-функции %qD"
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "недопустимая декларация статической функции внутри другой функции"
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "слово %<static%> недопустимо при определении (в отличие от объявления) статического элемента данных в классе"
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "статический элемент %qD объявлен как %<register%>"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "недопустимая явная extern-декларация элемента %q#D"
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "параметр не может быть декларирован %<constexpr%>"
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%<extern%> декларация %qs с инициализацией"
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "для %qs задан спецификатор %<extern%> и инициализатор"
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "аргумент по умолчанию %qE использует %qD"
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "аргумент по умолчанию %qE использует локальную переменную %qD"
 
 #
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "некорректное использование cv-квалифицированного типа %qT в декларации параметра"
 
 #
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "некорректное использование типа %<void%> в декларации параметра"
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "%<_Atomic%>-квалифицированный параметр типа %qT для %q+D"
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "некорректная декларация параметра %qD с типом метода"
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "параметр %qD включает указатель на массив с неизвестной границей %qT"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "параметр %qD включает ссылку на массив с неизвестной границей %qT"
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "некорректный конструктор; возможно, вы имели в виду %<%T (const %T&)%>"
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "декларация %qD может не действовать в пространстве имён"
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD можно не определять статической"
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD должен быть нестатической элементом-функцией"
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a non-member function"
 msgid "%qD must be a member function"
 msgstr "%qD должен быть не-элемент-функцией"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD должен быть либо нестатическим элементом-функцией или функцией-не-элементом"
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD должен иметь аргумент типа класс или перечислимого типа"
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ не поддерживает перегрузку операции ?:"
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD не может иметь переменное число аргументов"
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr ""
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD не может иметь аргументов по умолчанию"
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "преобразование к void никогда не использует операцию преобразования типа"
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "преобразование к ссылке на тот же тип никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to the same type will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "преобразование к тому же типу никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "преобразование к ссылке на базовый класс никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a base class will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "преобразование к базовому классу никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "пользовательский оператор %qD всегда вычисляет оба аргумента"
 
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "префиксный %qD должен возвращать %qT"
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "постфиксный %qD должен возвращать %qT"
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD должен возвращать результат по значению"
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "использование параметра шаблона %qT после %qs"
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "использование синонима специализации шаблона %qT после %qs"
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "использование typedef-имени %qD после %qs"
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD ранее декларирован здесь"
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "ссылка на %qT как на %qs"
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT ранее декларирован здесь"
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "ссылка на %qT как на enum"
@@ -60824,118 +60832,101 @@ msgstr "ссылка на %qT как на enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "для %<%s %T%> нужен аргумент-шаблон"
 
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "ссылка на %qD противоречива"
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, fuzzy, gcc-internal-format
 #| msgid "function template %qD redeclared as a class template"
 msgid "class template %qD redeclared as non-template"
 msgstr "шаблон функции %qD редекларирован как шаблон класса"
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD имеет то же имя, что и класс, в котором он(а) декларируется"
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT не является шаблоном"
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "возможно вы хотите явно добавить %<%T::%>"
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "использование перечисления %q#D без предыдущей декларации"
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "повторная декларация %qT как не-шаблона"
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare %qD to be a bit-field type"
-msgid "cannot declare %qD in a different module"
-msgstr "недопустимая декларация %qD как битового поля"
-
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, gcc-internal-format
-msgid "previously declared here"
-msgstr "предыдущая декларация здесь"
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "некорректный производный тип union %qT"
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT определен с многими непосредственными базами"
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT определен с непосредственной виртуальной базой"
 
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "базовый тип %qT не является ни структурой, ни классом"
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "рекурсивный тип %qT не определён"
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "некорректное дублирование базового типа %qT"
 
-#: cp/decl.cc:16984
-#, fuzzy, gcc-internal-format
-#| msgid "cannot capture %qE by reference"
-msgid "cannot declare %qD in different module"
-msgstr "невозможно захватить %qE по ссылке"
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "scoped/unscoped рассогласование в enum %q#T"
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "предыдущее определение здесь"
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "рассогласование основного типа в enum %q#T"
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "отличающийся основной тип в enum %q#T"
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -60944,84 +60935,84 @@ msgstr ""
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ни один целочисленный тип не годится для представления всех значений перечислимого типа %qT"
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "значение перечислимого типа для %qD должно иметь целочисленный или unscoped перечислимый тип"
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "значение перечислимого типа для %qD не является константой целого типа"
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "увеличенное значение перечисления слишком велико для %<unsigned long%>"
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "увеличенное значение перечисления слишком велико для %<long%>"
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "переполнение в перечисляемых значениях для %qD"
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "повторное определение %q#T"
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "тип результата %q#T неполный"
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> должен возвращать ссылку на %<*this%>"
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "нет операторов возврата в функции возвращающей %qT"
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "только плоский %<auto%> тип возврата может быть приведен к %<void%>"
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "в функции, которая должна возвращать значение, отсутствует оператор return"
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD уже определена в классе %qT"
 
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing %qs"
 msgid "using %qs"
 msgstr "объемлющая %qs"
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "использование %qD до приведения %<auto%>"
@@ -61076,7 +61067,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr "удаление %qT не определено"
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "шаблонная декларация %q#D"
@@ -61086,7 +61077,7 @@ msgstr "шаблонная декларация %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "предоставленные списки параметров шаблона не соответствуют параметрам шаблона %qD"
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "деструктор %qD объявлен как шаблон элемента"
@@ -61274,72 +61265,72 @@ msgstr "деструктор не может быть статической э
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> имеет первый параметр типа %qT"
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type has no linkage"
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr "%qT имеет поле %qD, тип которого не имеет привязки"
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT имеет поле %qD, тип которого зависит от типа %qT, который не имеет привязки"
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type has no linkage"
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr "%qT имеет поле %qD, тип которого не имеет привязки"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr "%qT имеет поле %qD, использующее анонимное пространство имён"
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT объявлен с большей областью видимости, чем тип его поля %qD"
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type has no linkage"
 msgid "%qT has a base %qT which has no linkage"
 msgstr "%qT имеет базу %qT чей тип не имеет привязки"
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr "%qT имеет базу %qT чей тип зависит от типа %qT, который не имеет привязки"
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type has no linkage"
 msgid "%qT has a base %qT which has internal linkage"
 msgstr "%qT имеет базу %qT чей тип не имеет привязки"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr "%qT наследован от %qT, использующего анонимное пространство имён"
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT объявлен с большей областью видимости, чем родитель %qT"
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D, declared using unnamed type, is used but never defined"
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr "%q#D, декларированное с использованием неименованного типа, используется, но не определяется"
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D, declared using unnamed type, is used but never defined"
 msgid "%q#D, declared using an unnamed type, is used but not defined"
@@ -61349,110 +61340,110 @@ msgstr "%q#D, декларированное с использованием н
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "неименованный тип без привязки использован для декларации переменной %q#D с привязкой"
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "неименованный тип без привязки использован для декларации функции %q#D с привязкой"
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q#D не ссылается на неквалифицированный тип, поэтому не используется для привязки"
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q#D, декларированное с использованием локального типа %qT, используется, но не определяется"
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D, declared using local type %qT, is used but never defined"
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr "%q#D, декларированное с использованием локального типа %qT, используется, но не определяется"
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "тип %qT без привязки использован для декларации переменной %q#D с привязкой"
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "тип %qT без привязки использован для декларации функции %q#D с привязкой"
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr ""
 
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr ""
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, fuzzy, gcc-internal-format
 #| msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr "более поздняя -fabi-version= (или =0) избегает этой ошибки изменением в разборке"
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr "программа должна также определять %qD"
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "inline функция %qD использована, но нигде не определена"
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, fuzzy, gcc-internal-format
 #| msgid "default argument missing for parameter %P of %q+#D"
 msgid "default argument missing for parameter %P of %q#D"
 msgstr "отсутствует аргумент по умолчанию для параметра %P функции %q+#D"
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, fuzzy, gcc-internal-format
 #| msgid "parameter pack cannot have a default argument"
 msgid "...following parameter %P which has a default argument"
 msgstr "parameter pack не может иметь подразумеваемый аргумент"
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, fuzzy, gcc-internal-format
 #| msgid "class %qE is deprecated"
 msgid "implicitly-declared %qD is deprecated"
 msgstr "класс %qE устарел"
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "использование удаленной функции %qD"
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %q#D with different constraints"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "редекларация %q#D с другими ограничениями"
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -61573,7 +61564,7 @@ msgstr "ссылка на %<%T::%D%> неоднозначна"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qT не содержит элемент с именем %qE; имелось в виду %qE?"
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD не является элементом %qT"
@@ -61584,7 +61575,7 @@ msgstr "%qD не является элементом %qT"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qT не содержит элемент с именем %qE; имелось в виду %qE?"
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD не является элементом %qD"
@@ -61611,50 +61602,50 @@ msgstr "обработка прерываний отключена, задайт
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr "исключительная ситуация NULL имеет целый тип, а не тип указателя"
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, gcc-internal-format
 msgid "  in thrown expression"
 msgstr "  в throw-выражении"
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare catch parameter to be of rvalue reference type %qT"
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr "невозможно декларировать catch параметр как rvalue тип ссылки %qT"
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, gcc-internal-format
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr "невозможно throw выражение типа %qT, поскольку он включает типы переменного размера"
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, gcc-internal-format
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr "невозможно catch тип %qT, поскольку он включает типы переменного размера"
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, fuzzy, gcc-internal-format
 #| msgid "exception of type %qT will be caught"
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr "исключительная ситуация типа %qT будет обработана"
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, fuzzy, gcc-internal-format
 #| msgid "for %qD"
 msgid "for type %qT"
 msgstr "для %qD"
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, gcc-internal-format
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr "обработчик %<...%> должен быть последним в своем try-блоке"
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr "noexcept-expression приводится к %<false%> из-за вызова %qD"
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
 msgstr "но %qD не делает throw; возможно его следует декларировать %<noexcept%>"
@@ -61925,12 +61916,12 @@ msgstr "тип %qT не является непосредственной или
 msgid "type %qT is not a direct base of %qT"
 msgstr "тип %qT не является непосредственной базой %qT"
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "массив должен быть инициализирован инициализатором в фигурных скобках"
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT не является классовым типом"
@@ -61945,12 +61936,12 @@ msgstr "неполный тип %qT не имеет элемента %qD"
 msgid "invalid pointer to bit-field %qD"
 msgstr "некорректный указатель на битовое поле %qD"
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "некорректное использование нестатической функции-элемента %qD"
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "некорректное использование нестатического элемента %qD"
@@ -62156,52 +62147,52 @@ msgstr "удаление объекта абстрактного типа кла
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "удаление объекта полиморфного типа класса %qT, имеющего невиртуальный деструктор, может вызвать неопределенное поведение"
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "тип, заданный в векторном delete, не является ни массивом, ни указателем"
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr "массив с границей времени выполнения не может захватываться копированием, только по ссылке"
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr "так как тип элементов массива %qT имеет переменный размер"
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "невозможно захватить %qE по ссылке"
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "захват копированием неполного типа %qT"
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> не было захвачено для этой lambda функции"
@@ -62600,242 +62591,293 @@ msgstr "ожидался template-id для типа"
 msgid "encapsulation is malformed"
 msgstr ""
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q+#D"
 msgid "conflicting global module declaration %#qD"
 msgstr "конфликтующая декларация %q+#D"
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration %q+D"
 msgid "existing declaration %#qD"
 msgstr "в декларации %q+D"
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, fuzzy, gcc-internal-format
 #| msgid "extern declaration of %q#D doesn%'t match"
 msgid "definition of %qD does not match"
 msgstr "extern декларация %q#D не соответствует"
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, fuzzy, gcc-internal-format
 #| msgid "missing definition"
 msgid "existing definition %qD"
 msgstr "отсутствует определение"
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "... this enumerator %qD"
 msgstr "повторная декларация перечислимого типа %q+D"
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "enumerator %qD does not match ..."
 msgstr "аргумент типа %qT не соответствует типу %qT"
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr ""
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr ""
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr ""
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, gcc-internal-format
 msgid "recursive lazy load"
 msgstr ""
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr ""
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, fuzzy, gcc-internal-format
 #| msgid "routine %qD declared here"
 msgid "module %qs declared here"
 msgstr "программа %qD декларирована здесь"
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, gcc-internal-format
 msgid "indirect import %qs is not already loaded"
 msgstr ""
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr ""
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr ""
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %qD was here"
 msgid "macro definitions of %qE corrupted"
 msgstr "предыдущее определение %qD было здесь"
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, fuzzy, gcc-internal-format
 #| msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgid "inconsistent imported macro definition %qE"
 msgstr "  противоречивый вывод parameter pack с %qT и %qT"
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr ""
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr ""
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete module file %qs: %s"
 msgid "compiled module file is %qs"
 msgstr "Не удалось удалить файл модуля %qs: %s"
 
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Display the compiler's version."
 msgid "compiled module is %sversion %s"
 msgstr "Показать версию компилятора."
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collect2 version %s\n"
 msgid "compiler is %sversion %s%s%s"
 msgstr "collect2 версия %s\n"
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, fuzzy, gcc-internal-format
 #| msgid "no %qs getter found"
 msgid "module %qs found"
 msgstr "не найден %qs getter"
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr ""
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr ""
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr ""
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr ""
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, fuzzy, gcc-internal-format
 #| msgid "exception handling disabled, use -fexceptions to enable"
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr "обработка прерываний отключена, задайте -fexceptions"
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, fuzzy, gcc-internal-format
 #| msgid "function attribute mismatch"
 msgid "fixed tree mismatch"
 msgstr "несовпадение атрибутов функции"
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "interface partition is not exported"
 msgstr "выражение для границы стека не поддерживается"
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to rename %s to state file %s [%s]"
 msgid "failed to read compiled module cluster %u: %s"
 msgstr "не удалось переименовать %s в файл состояния %s [%s]"
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to create map component '%s'"
 msgid "failed to read compiled module: %s"
 msgstr "не удалось создать map компонент '%s'"
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr ""
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr ""
 
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr ""
 
-#: cp/module.cc:19283
+#: cp/module.cc:19117
+#, fuzzy, gcc-internal-format
+#| msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
+msgid "declaration %qD conflicts with builtin"
+msgstr "декларация %q+#D конфликтует с внутренней декларацией %q#D"
+
+#: cp/module.cc:19122
+#, fuzzy, gcc-internal-format
+#| msgid "declaration of namespace %qD conflicts with"
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr "декларация namespace %qD противоречит"
+
+#: cp/module.cc:19125
+#, gcc-internal-format
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr ""
+
+#: cp/module.cc:19130
+#, gcc-internal-format
+msgid "import declared attached to module %qs"
+msgstr ""
+
+#: cp/module.cc:19134
+#, gcc-internal-format
+msgid "import declared in global module"
+msgstr ""
+
+#: cp/module.cc:19140
+#, fuzzy, gcc-internal-format
+#| msgid "conflicting declaration of template %q+#D"
+msgid "conflicting declaration of %qD in module %qs"
+msgstr "конфликтующая декларация шаблона %q+#D"
+
+#: cp/module.cc:19143
+#, fuzzy, gcc-internal-format
+#| msgid "conflicting declaration of %q+#D with %qL linkage"
+msgid "conflicting declaration of %qD in global module"
+msgstr "конфликтующая декларация %q+#D с %qL привязкой"
+
+#: cp/module.cc:19148
+#, fuzzy, gcc-internal-format
+#| msgid "previously declared here"
+msgid "previously declared in module %qs"
+msgstr "предыдущая декларация здесь"
+
+#: cp/module.cc:19152
+#, fuzzy, gcc-internal-format
+#| msgid "previously declared here"
+msgid "previously declared in global module"
+msgstr "предыдущая декларация здесь"
+
+#: cp/module.cc:19404
 #, fuzzy, gcc-internal-format
 #| msgid "creating %s"
 msgid "reading CMI %qs"
 msgstr "создание %s"
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, gcc-internal-format
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, gcc-internal-format
 msgid "during load of pendings for %<%E%s%E%>"
 msgstr ""
@@ -62847,326 +62889,326 @@ msgstr ""
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr ""
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol %qs already declared"
 msgid "module already declared"
 msgstr "Символ %qs уже декларирован"
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, fuzzy, gcc-internal-format
 #| msgid "module procedure"
 msgid "module already imported"
 msgstr "процедура модуля"
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, fuzzy, gcc-internal-format
 #| msgid "module procedure"
 msgid "module %qs imported here"
 msgstr "процедура модуля"
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown punctuation '%c'"
 msgid "unknown Compiled Module Interface: %s"
 msgstr "неизвестный знак пунктуации '%c'"
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr ""
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr ""
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr ""
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, fuzzy, gcc-internal-format
 #| msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr "\"%s\" отладочный формат не может быть использован с прекомпилированными заголовками"
 
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, fuzzy, gcc-internal-format
 #| msgid "Enable traditional preprocessing."
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr "Традиционное препроцессирование."
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr ""
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr ""
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, gcc-internal-format
 msgid "you should use the %<-%s%> option"
 msgstr ""
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param name %qs"
 msgid "invalid header name %qs"
 msgstr "некорректное --param имя %qs"
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param name %qs"
 msgid "invalid module name %qs"
 msgstr "некорректное --param имя %qs"
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr ""
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, fuzzy, gcc-internal-format
 #| msgid "error writing %qs"
 msgid "writing CMI %qs"
 msgstr "ошибка записи %qs"
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing modules file: %s"
 msgid "not writing module %qs due to errors"
 msgstr "Ошибка записи в файл модулей: %s"
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to create map component '%s'"
 msgid "failed to write compiled module: %s"
 msgstr "не удалось создать map компонент '%s'"
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, fuzzy, gcc-internal-format
 #| msgid "unknown spec function %qs"
 msgid "unknown header kind %qs"
 msgstr "неизвестная функция %qs в спецификации"
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+#D shadows template parameter"
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "декларация %q+#D перекрывает параметр шаблона"
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D конфликтует с предыдущей декларацией"
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr ""
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr ""
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "из-за различных спецификаций исключений"
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "некорректная декларация параметра %qD с типом метода"
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "декларация %q#D перекрывает параметр"
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "декларация %qD перекрывает элемент %qT"
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr ""
 
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, gcc-internal-format
 msgid "exporting %q#D that does not have external linkage"
 msgstr ""
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D declared here"
 msgid "%q#D declared here with no linkage"
 msgstr "%q#D декларировано здесь"
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here, later in the translation unit"
 msgid "%q#D declared here with internal linkage"
 msgstr "%qD декларировано здесь, позднее в единице трансляции"
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D declared here"
 msgid "%q#D declared here with module linkage"
 msgstr "%q#D декларировано здесь"
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names destructor"
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T::%D%> обозначает деструктор"
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "using-декларация для не-элемента внутри класса"
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a class, namespace, or enumeration"
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qE не класс, пространство имен или перечисление"
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, fuzzy, gcc-internal-format
 #| msgid "non-member-template declaration of %qD"
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "non-member-template декларация %qD"
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "using-декларация для не-элемента внутри класса"
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "%qT is not a direct base of %qT"
 msgstr "тип %qT не является непосредственной базой %qT"
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, fuzzy, gcc-internal-format
 #| msgid "did you mean to use logical not (%<!%>)?"
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr "имелось в виду использовать логическое отрицание (%<!%>)?"
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared in %qD"
 msgstr "%qE не был декларирован"
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration of namespace %q+D"
 msgid "using-declaration may not name namespace %qD"
 msgstr "противоречивая декларация %q#D"
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> обозначает конструктор в %qT"
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "декларация %qD вне пространства имён, объемлющего %qD"
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "явные квалификаторы в декларации %qD"
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD следовало объявить внутри %qD"
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr ""
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD атрибут требует единственный NTBS аргумент"
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD атрибут не имеет смысла, поскольку элементы анонимного пространства имен получают локальные символы"
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "игнорирование %qD атрибута в анонимном пространстве имен"
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "игнорирование %qD атрибута в non-inline пространстве имен"
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "атрибут %qD игнорируется"
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "максимальное число %d пространств имен просмотрено для %qE"
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -63174,100 +63216,100 @@ msgstr[0] "предлагаемый вариант:"
 msgstr[1] "предлагаемые варианты:"
 msgstr[2] "предлагаемые варианты:"
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr ""
 
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr ""
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr ""
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr ""
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "определение %qD не соответствует %<#include <initializer_list>%>"
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fabi-version=1%> is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "%<-fabi-version=1%> больше не поддерживается"
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr "%<this%> недопустим в данном контексте"
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%qs в %L неоднозначно"
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "использование пространства имён %qD здесь недопустимо; предполагается %qD"
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr ""
 
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, fuzzy, gcc-internal-format
 #| msgid "%qD conflicts with used function"
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%qD противоречит использованной функции"
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous definition here"
 msgid "reachable %s definition here"
 msgstr "предыдущее определение здесь"
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX вход в pop_everything ()\n"
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -63295,7 +63337,7 @@ msgstr "идентификатор %qE является ключевым сло
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr "LEXER_DEBUGGING_ENABLED_P не установлено в true"
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
@@ -63551,7 +63593,7 @@ msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<concept%> доступно только с -fconcepts"
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, fuzzy, gcc-internal-format
 #| msgid "%<requires%> only available with -fconcepts"
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
@@ -63735,7 +63777,7 @@ msgstr "операторы-выражения не допустимы вне ф
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "lambda-выражения доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "ожидалось primary-expression"
@@ -63795,7 +63837,7 @@ msgstr "%<~auto%> доступно только с -std=c++14 или -std=gnu++1
 msgid "template-id not allowed for destructor in C++20"
 msgstr "квалификаторы не допускаются в декларации деструктора"
 
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, gcc-internal-format
 msgid "remove the %qs"
 msgstr ""
@@ -63815,7 +63857,7 @@ msgstr "typedef-имя %qD использовано как декларатор
 msgid "expected unqualified-id"
 msgstr "ожидался unqualified-id"
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD не является шаблоном"
@@ -63867,7 +63909,7 @@ msgstr "типы нельзя определять в %<typeid%> выражен
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "неверное число аргументов для %<__builtin_addressof%>"
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "неверное число аргументов для %<__builtin_launder%>"
@@ -63905,7 +63947,7 @@ msgstr "типы нельзя определять в условиях"
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr ""
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "некорректное использование %qD"
@@ -63930,7 +63972,7 @@ msgstr "ISO C++ не допускает %<alignof%> с не-типом"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "типы не могут быть определены в %<noexcept%> выражениях"
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in a new-expression"
 msgid "types may not be defined in %qs expressions"
@@ -64093,8 +64135,8 @@ msgstr "пустой инициализатор для lambda init-capture"
 msgid "capture of non-variable %qE"
 msgstr ""
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D декларировано здесь"
@@ -64137,7 +64179,7 @@ msgstr "задан аргумент по умолчанию для lambda-пар
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr ""
@@ -64276,7 +64318,7 @@ msgstr "в операторе asm требуется lvalue-выражение"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "наследуемые конструкторы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "ожидался selection-statement"
@@ -64342,7 +64384,7 @@ msgstr "range-based %<for%> выражение типа %qT имеет непо
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "противоречивые begin/end типы в range-based %<for%> операторе: %qT и %qT"
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "ожидался iteration-statement"
@@ -64371,7 +64413,7 @@ msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ не поддерживает вычисляемые goto"
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "ожидался оператор перехода"
@@ -64673,12 +64715,12 @@ msgstr "только конструкторы берут инициализат
 msgid "cannot expand initializer for member %qD"
 msgstr ""
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "mem-initializer для %qD следует за constructor delegation"
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "constructor delegation следует за mem-initializer для %qD"
@@ -65357,7 +65399,7 @@ msgstr "отсутствуют аргументы шаблона после %qT"
 msgid "%qT not permitted in template argument"
 msgstr "отсутствуют аргументы шаблона"
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, gcc-internal-format
 msgid "invalid use of %qT"
@@ -65542,13 +65584,13 @@ msgstr "предыдущее определение %q#T"
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, fuzzy, gcc-internal-format
 #| msgid "no unexpanded parameter packs in binary fold"
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr "нет нерасширенных пакетов параметров в бинарной свертке"
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "ожидалось class-key"
@@ -65763,39 +65805,39 @@ msgstr "C++11 атрибуты доступны только с -std=c++11 ил
 msgid "expression must be enclosed in parentheses"
 msgstr "выражение должно быть целочисленным"
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr ""
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "заданная позиция не является целой константой"
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not an integer constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "запрошенное выравнивание не является целочисленной константой"
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "специализация элемента %<%T::%E%> требует %<template<>%> синтаксис"
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "некорректная декларация %<%T::%E%>"
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "недостаточно списков параметров шаблонов"
@@ -65804,453 +65846,453 @@ msgstr "недостаточно списков параметров шабло
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "слишком много списков параметров шаблонов"
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on constructor declaration"
 msgid "template-id not allowed for constructor in C++20"
 msgstr "квалификаторы не допускаются в декларации конструктора"
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "именованные возвращаемые значения больше не поддерживаются"
 
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "нет подходящего concept для template-introduction"
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "некорректная декларация шаблона элемента в локальном классе"
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "шаблон с привязкой C"
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "некорректная явная специализация"
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "шаблонная декларация %<typedef%>"
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "декларация шаблона класса не должна декларирован ничего иного"
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "явная специализация шаблона не может иметь класс хранения"
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> должно быть %<> >%> внутри списка аргументов вложенного шаблона"
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "ошибочное использование %<>>%>, используйте %<>%> для завершения списка аргументов шаблона"
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, fuzzy, gcc-internal-format
 #| msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr "ошибочное использование %<>>%>, используйте %<>%> для завершения списка аргументов шаблона"
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "аргумент %<sizeof...%> должен быть окружен скобками"
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "некорректное использование %qD в спецификации привязки"
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate virt-specifier"
 msgid "duplicate %qD specifier"
 msgstr "повторный virt-specifier"
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, fuzzy, gcc-internal-format
 #| msgid "%qs used with %qE"
 msgid "%qD specifier conflicts with %qs"
 msgstr "%qs использован с %qE"
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> перед %qD"
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, fuzzy, gcc-internal-format
 #| msgid "%qs specified with %<typeof%>"
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr "%qs указан с %<typeof%>"
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 не поддерживает %<long long%>"
 
 #
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "заданы и %<__thread%> и %<thread_local%>"
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "дублирование %qD"
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "дублирование %qs"
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "ожидалось %<new%>"
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "ожидалось %<delete%>"
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "ожидалось %<return%>"
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "ожидалось %<extern%>"
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "ожидалось %<static_assert%>"
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "ожидалось %<decltype%>"
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "ожидалось %<operator%>"
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "ожидалось %<class%>"
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "ожидалось %<template%>"
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "ожидалось %<namespace%>"
 
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "ожидалось %<using%>"
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "ожидалось %<asm%>"
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "ожидалось %<try%>"
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "ожидалось %<catch%>"
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "ожидалось %<throw%>"
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>"
 msgid "expected %<auto%>"
 msgstr "ожидалось %<data%>"
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "ожидалось %<__label__%>"
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "ожидалось %<@try%>"
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "ожидалось %<@synchronized%>"
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "ожидалось %<@throw%>"
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "ожидалось %<__transaction_atomic%>"
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "ожидалось %<__transaction_relaxed%>"
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "ожидалось %<@end%>"
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "ожидалось %<::%>"
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "ожидалось %<...%>"
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "ожидалось %<*%>"
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "ожидалось %<~%>"
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "ожидалось %<:%> или %<::%>"
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs tag использован в именовании %q#T"
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T был ранее декларирован здесь"
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "недопустимая декларация ссылки на %q#T"
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared with greater visibility than its base %qT"
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT объявлен с большей областью видимости, чем родитель %qT"
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, fuzzy, gcc-internal-format
 #| msgid "expected class-key"
 msgid "replace the class-key with %qs"
 msgstr "ожидалось class-key"
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qT defined as %qs here"
 msgstr "метка %qD определена здесь"
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared here"
 msgid "%qT first declared as %qs here"
 msgstr "%qT декларировано здесь"
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD редекларирован с другим доступом"
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "в C++98 %<template%> (для снятия неоднозначности) допускается только внутри шаблонов"
 
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "конец файла в аргументе по умолчанию"
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "неверное положение %<@%D%> конструкции Objective-C++"
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c++ получатель сообщения ожидался"
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "ожидались objective-c++ аргумент(ы) сообщения"
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "в конструкции %<@encode%> в качестве аргумента должен быть задан тип"
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "некорректное Objective-C++ имя селектора"
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "ожидалась objective-c++ декларация метода"
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "атрибуты метода должны задаваться в конце"
 
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "случайное %qs между Objective-C++ методами"
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "некорректный тип для instance переменной"
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "ожидался идентификатор после %<@protocol%>"
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "атрибуты нельзя задавать до %<@%D%> Objective-C++ ключевого слова"
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "префиксные атрибуты игнорируются до %<@%D%>"
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "некорректный тип для property"
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, fuzzy, gcc-internal-format
 #| msgid "unknown property attribute"
 msgid "unknown property attribute %qE"
 msgstr "неизвестный атрибут свойства"
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "ожидалось целочисленное выражение"
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%<wait%> выражение должно быть целочисленным"
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "некорректный reduction-инициализатор"
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in parameter types"
 msgid "types may not be defined in iterator type"
@@ -66260,13 +66302,13 @@ msgstr "типы нельзя определять в типах парамет
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma vtable no longer supported"
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "#pragma vtable больше не поддерживается"
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "скобочная инициализация не допускается в OpenMP %<for%> цикле"
@@ -66277,142 +66319,142 @@ msgstr "скобочная инициализация не допускаетс
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "%<ordered%> клаузула с параметром не может быть задана в %qs конструкции"
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "итерационная переменная %qD не должна быть reduction"
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp end declare target%> без соответствующей %<#pragma omp declare target%>"
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr ""
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "некорректная клаузула инициализатора"
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "ожидалось id-выражение (аргументы)"
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "один из аргументов вызова инициализатора должен быть %<omp_priv%> или %<&omp_priv%>"
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "типы не могут определяться в declare reduction списке типов"
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "предекларированный арифметический тип %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "функциональный или массивный тип %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "тип ссылки %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, fuzzy, gcc-internal-format
 #| msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "const, volatile или __restrict квалифицированный тип %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> именует множество перегрузок"
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD не ссылается на функцию в контексте пространства имен"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, fuzzy, gcc-internal-format
 #| msgid "atomic_cancel"
 msgid "%<atomic_cancel%>"
 msgstr "atomic_cancel"
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> без включения поддержки транзакционной памяти"
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> без включения поддержки транзакционной памяти"
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "внешний %<__transaction_cancel%> не внутри внешнего %<__transaction_atomic%>"
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  либо %<transaction_may_cancel_outer%> функция"
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma GCC coprocessor"
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "некорректный синтаксис #pragma GCC coprocessor"
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%> может использоваться только в составных операторах"
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp taskyield%> может использоваться только в составных операторах"
 
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> должна быть внутри функций"
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "multi-source compilation not implemented for C++"
 msgstr "межмодульные оптимизации не реализованы для C++"
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "стандартные преобразования в данном контексте недопустимы"
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "неявные шаблоны не могут быть %<virtual%>"
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -66442,7 +66484,7 @@ msgstr "объемлющие шаблоны классов не были явн
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "специализация %qD должна появляться в пределах пространства имен"
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "специализация %qD в другой namespace-области"
@@ -66457,27 +66499,27 @@ msgstr ""
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "явная конкретизация %qD в пространстве имен %qD (которое не включает пространство имен %qD)"
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "имя класса затеняет шаблон параметра шаблона %qD"
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "специализация алиасного шаблона %qD"
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "явная специализация не-шаблона %qT"
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "специализация %qT после конкретизации"
 
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#D"
 msgid "from definition of %q#D"
@@ -66485,147 +66527,147 @@ msgstr "переопределение %q#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "специализация %qT после конкретизации %qT"
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "специализация шаблона %qD не допускается ISO C++"
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "специализация %qD после конкретизации"
 
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr ""
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD не является шаблоном функции"
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD не есть переменный шаблон"
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "идентификатор шаблона %qD для %q+D не соответствует никакой декларации шаблона"
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "разбор %d %<template<>%>, требуется %d для специализации шаблона элемента-функции"
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "неоднозначная конкретизация шаблона %qD для %q+D"
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, fuzzy, gcc-internal-format
 #| msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "переменные шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr ""
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr "элементы явно специализированного класса определяются без заголовка шаблона"
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "явная специализация %qD вне своего пространства имен должна использовать nested-name-specifier"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "явная конкретизация %qD вне своего пространства имен должна использовать nested-name-specifier"
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr ""
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr ""
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr ""
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD in declaration of primary template"
 msgid "template-id %qE in declaration of primary template"
 msgstr "template-id %qD в декларации первичного шаблона"
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "список параметров шаблона использован в явной конкретизации"
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "определение представленное для явной конкретизации"
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "слишком много списков параметров шаблона в декларации %qD"
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "слишком мало списков параметров шаблона в декларации %qD"
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "перед явной специализацией %qD должно быть %<template <>%>"
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "явная специализация декларированного %<concept%>"
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, fuzzy, gcc-internal-format
 #| msgid "non-type partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "нетиповая частичная специализация %qD не допускается"
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, fuzzy, gcc-internal-format
 #| msgid "non-class, non-variable partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "неклассовая, непеременная частичная специализация %qD не допускается"
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "задан подразумеваемый аргумент в явной специализации"
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD не является функцией шаблоном"
@@ -66638,142 +66680,142 @@ msgstr "%qD не является функцией шаблоном"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "специализация неявно декларированного специального элемента-функции"
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "никакая элемент-функция %qD не декларирована в %qT"
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "friend декларация %qD не видна для явной специализации"
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, gcc-internal-format
 msgid "friend declaration here"
 msgstr "friend декларация здесь"
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "явная специализация function concept %qD"
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "Аргумент ACOS в %L должен быть между -1 и 1"
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, fuzzy, gcc-internal-format
 #| msgid "non-parameter %qs cannot be a parameter pack"
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "не параметрический %qs не может содержать параметры"
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, fuzzy, gcc-internal-format
 #| msgid "non-parameter %qs cannot be a parameter pack"
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "не параметрический %qs не может содержать параметры"
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "packs параметров не расширены с %<...%>:"
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "          %s"
 msgid "        %s"
 msgstr "          %s"
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "декларация параметра шаблона %q+D перекрывает параметр шаблона"
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "декларация %q+#D перекрывает параметр шаблона"
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "параметр шаблона %qD декларирован здесь"
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "специализация variable concept %q#D"
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "параметры шаблона не выводимы в частичной специализации:"
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "первичный шаблон здесь"
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "частичная специализация не более специальна чем первичный шаблон, так как она замещает несколько параметров пакетным расширением"
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "слишком много аргументов в вызове функции %qE"
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "частичная специализация %qD не более специальна чем"
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "первичный шаблон %qD"
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "parameter pack аргумент %qE должен быть в конце списка аргументов шаблона"
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "parameter pack аргумент %qT должен быть в конце списка аргументов шаблона"
 
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -66781,17 +66823,17 @@ msgstr[0] "тип %qT аргумента шаблона %qE зависит от
 msgstr[1] "тип %qT аргумента шаблона %qE зависит от параметров шаблона"
 msgstr[2] "тип %qT аргумента шаблона %qE зависит от параметров шаблона"
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "декларация %qD делает неоднозначной более раннюю конкретизацию шаблона для %qD"
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "частичная специализация %qD после конкретизации %qD"
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "нет подразумеваемого аргумента для %qD"
@@ -66800,48 +66842,48 @@ msgstr "нет подразумеваемого аргумента для %qD"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "parameter pack %q+D должен быть в конце списка параметров шаблона"
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "подразумеваемые аргументы шаблона не могут использоваться в редекларации friend шаблона функции"
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, fuzzy, gcc-internal-format
 #| msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "подразумеваемые аргументы шаблона не могут использоваться в шаблонах функций без -std=c++11 или -std=gnu++11"
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "подразумеваемые аргументы шаблона не могут использоваться в частичных специализациях"
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "подразумеваемый аргумент для параметра шаблона для класса включающего %qD"
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "шаблон %qD декларирован"
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "шаблон класса без имени"
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "элемент-шаблон %qD не может иметь virt-спецификаторы"
@@ -66851,63 +66893,63 @@ msgstr "элемент-шаблон %qD не может иметь virt-спец
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "некорректная template-декларация %qD"
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "определение шаблона для не-шаблона %q#D"
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "ожидалось %d уровней параметров шаблона для %q#D, дано %d"
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "дано %d параметров шаблона для %q#D"
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "дано %d параметров шаблона для %q#T"
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  вместо требуемых %d"
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "аргументы шаблона для %qD не соответствуют первоначальному шаблону %qD"
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "используйте %<template<>%> для явной специализации"
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %q#D with different constraints"
 msgid "redeclaration of %qD with different constraints"
 msgstr "редекларация %q#D с другими ограничениями"
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT не является шаблонным типом"
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "спецификаторы шаблона не заданы в декларации %qD"
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -66915,7 +66957,7 @@ msgstr[0] "редекларировано с %d параметром шабло
 msgstr[1] "редекларировано с %d параметрами шаблона"
 msgstr[2] "редекларировано с %d параметрами шаблона"
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -66923,453 +66965,453 @@ msgstr[0] "предыдущая декларация %qD использовал
 msgstr[1] "предыдущая декларация %qD использовала %d параметра шаблона"
 msgstr[2] "предыдущая декларация %qD использовала %d параметра шаблона"
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "параметр шаблона %q+#D"
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "редекларирован здесь как %q#D"
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "redeclared here"
 msgstr "объявлено здесь"
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %q#D with different constraints"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "редекларация %q#D с другими ограничениями"
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "исходная декларация находится здесь"
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %q#D with different constraints"
 msgid "redeclaration of %q#D with different constraints"
 msgstr "редекларация %q#D с другими ограничениями"
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%E не является корректным аргументом шаблона для типа %qT"
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "это должно быть адресом функции с внешней привязкой"
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "это должно быть именем функции с внешней привязкой"
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%E не является корректным аргументом шаблона для типа %qT, поскольку %qD не имеет привязки"
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%E не является корректным аргументом шаблона для типа %qT, поскольку %qD не имеет внешней привязки"
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "это должно быть указателем на элемент вида %<&X::Y%>"
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr ""
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, fuzzy, gcc-internal-format
 #| msgid "  couldn't deduce template parameter %qD"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  невозможно вывести параметр шаблона %qD"
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  типы %qT и %qT имеют несовместимые cv-qualifiers"
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  несоответствие типов %qT и %qT"
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  параметр шаблона %qD не есть parameter pack, но аргумент %qD таковым является"
 
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  аргумент шаблона %qE не соответствует указателю на элемент константе %qE"
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE не эквивалентно %qE"
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  противоречивый вывод parameter pack с %qT и %qT"
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  выведены конфликтующие типы для параметра %qT (%qT и %qT)"
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  выведены конфликтующие значения для нетипового параметра %qE (%qE и %qE)"
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  тип массива переменного размера %qT не есть корректный аргумент шаблона"
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  тип элемента-функции %qT не есть корректный аргумент шаблона"
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  невозможно преобразовать %qE (типа %qT) к типу %qT"
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT является неоднозначным базовым классом %qT"
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT не является производным от %qT"
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  параметры шаблона для шаблона аргумента шаблона несовместимы с другими выведенными аргументами шаблона"
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, fuzzy, gcc-internal-format
 #| msgid "  can't deduce a template for %qT from non-template type %qT"
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  невозможно вывести шаблон для %qT из нешаблонного типа %qT"
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr ""
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr "%qE не есть корректный аргумент шаблона типа %qT, поскольку %qE не переменная"
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE не есть корректный аргумент шаблона типа %qT, поскольку %qD не имеет внешней привязки"
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE не есть корректный аргумент шаблона типа %qT, поскольку %qD не имеет привязки"
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "адрес %qD не есть корректный аргумент шаблона"
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "адрес %qT подобъекта %qD не есть корректный аргумент шаблона"
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "адрес %qD не есть корректный аргумент шаблона, так как он не имеет статический срок хранения"
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD не есть корректный аргумент шаблона, поскольку %qD переменная, а не адрес переменной"
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE не есть корректный аргумент шаблона для %qT, поскольку не является адресом переменной"
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT, поскольку строковые литералы не могут быть использованы в этом контексте"
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr ""
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "  аргумент шаблона %qE не соответствует указателю на элемент константе %qE"
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT из-за конфликтов в cv-qualification"
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT, поскольку он не есть lvalue"
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D не есть корректный аргумент шаблона для типа %qT, поскольку ссылочная переменная не имеет постоянного адреса"
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT, поскольку он является указателем"
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "попробуйте задать %qE"
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT, поскольку он имеет тип %qT"
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "игнорирование атрибутов аргумента шаблона %qT"
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "игнорирование атрибутов аргумента шаблона %qE"
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "injected-class-name %qD использовано как шаблон аргумента шаблона"
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "некорректное использование деструктора %qE в качестве типа"
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "для того чтобы сослаться на тип параметра шаблона, используйте конструкцию %<typename %E%>"
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "несоответствия типа/значения в аргументе %d в списке параметров шаблона для %qD"
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  ожидалась константа типа %qT, а обнаружено %qT"
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "подразумеваемый аргумент для параметра шаблона для класса включающего %qD"
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  ожидался шаблон класса, а обнаружено %qE"
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  ожидался тип, обнаружено %qE"
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  ожидался тип, обнаружено %qT"
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  ожидался шаблон класса, обнаружено %qT"
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  ожидался шаблон типа %qD, обнаружено %qT"
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "несоответствие ограничений в аргументе %d в списке параметров шаблона для %qD"
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr ""
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "ошибка при преобразовании аргумента шаблона %qE из %qT в %qT"
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "некорректный аргумент шаблона %d"
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "неправильное число аргументов шаблона (%d, а должно быть %d)"
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "неправильное число аргументов шаблона (%d, а должно быть по крайней мере %d)"
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "предоставлено для %qD"
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "pack expansion аргумент для non-pack параметра %qD алиасного шаблона %qD"
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "pack expansion аргумент для non-pack параметра %qD concept %qD"
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "так что любая конкретизация с непустым пакетом параметров была бы синтаксически некорректной"
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D не является шаблоном функции"
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "не-шаблонный тип %qT использован как шаблон"
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "для декларации шаблона %q+D"
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, fuzzy, gcc-internal-format
 #| msgid "template constraint failure"
 msgid "template constraint failure for %qD"
 msgstr "нарушение ограничения шаблона"
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "использование некорректного переменного шаблона %qE"
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "глубина конкретизации шаблона превышает максимум %d (используйте -ftemplate-depth=, чтобы увеличить максимум)"
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, fuzzy, gcc-internal-format
 #| msgid "ordered argument needs positive constant integer expression"
 msgid "score argument must be constant integer expression"
 msgstr "ordered аргумент требует положительного константного целого выражения"
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L must be nonnegative"
 msgid "score argument must be non-negative"
 msgstr "%qs в %L должен быть неотрицательным"
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, fuzzy, gcc-internal-format
 #| msgid "%qs length expression must be positive constant integer expression"
 msgid "property must be constant integer expression or string literal"
 msgstr "%qs выражение длины должно быть положительным константным целочисленным выражением"
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr ""
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "свертка пустого расширения над %O"
 
 #
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a potential constant expression"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE не есть потенциальное константное выражение"
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr ""
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "создание указателя на элемент-функцию не классового типа %qT"
 
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "mismatched arguments"
 msgid "mismatched argument pack lengths (%d vs %d)"
@@ -67388,307 +67430,307 @@ msgstr "несовпадающие аргументы"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "переменная %qD имеет тип функции"
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "некорректный тип параметра %qT"
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "в декларации %q+D"
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "функция возвращает массив"
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "функция возвращает функцию"
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "создание ссылки на void"
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "формирование указателя на ссылочный тип %qT"
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "формирование ссылки на ссылочный тип %qT"
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "формирование указателя на квалифицированный тип функции %qT"
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "формирование ссылки на квалифицированный тип функции %qT"
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "создание указателя на элемент не классового типа %qT"
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "создание указателя на элемент ссылочного типа %qT"
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "создание указателя на элемент типа void"
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "создание массива элементов типа %qT"
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT не является типом class, struct или union"
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT разрешается в %qT, который не является перечислимым типом"
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT разрешается в %qT, который не является классовым типом"
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "использование %qs в шаблоне"
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "квалифицированный тип %qT не соответствует имени деструктора ~%qT"
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "зависимое имя %qE разбирается как не тип, но конкретизация дает тип"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "задайте %<typename %E%>, если подразумевается тип"
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "элемент инициализатора не является константным выражением"
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "некорректное использование pack expansion expression"
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "используйте %<...%> для расширения argument pack"
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "пустой инициализатор в lambda init-capture"
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD не декларирован в этом контексте, и не было найдено деклараций при зависимом от аргументов поиске в точке конкретизации"
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "декларации в зависимой базе %qT не найдены при неквалифицированном поиске"
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "используйте %<this->%D%>"
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "используйте %<%T::%D%>"
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD декларировано здесь, позднее в единице трансляции"
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_choose_expr%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "неверное число аргументов в вызове %<__builtin_choose_expr%>"
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qE attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "для атрибута %qE задано неверное число аргументов"
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT не является классом или пространством имён"
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD не является классом или пространством имён"
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "использование некорректного поля %qD"
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT есть/использует неименованный тип"
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "аргумент шаблона для %qD использует локальный тип %qT"
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT есть переменно модифицированный тип"
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "целочисленное выражение %qE не является константой"
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  при конкретизации %qD"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "неоднозначная конкретизация шаблона для %q#T"
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "неоднозначная конкретизация шаблона класса для %q#D"
 
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 msgid "%s %#qS"
 msgstr ""
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "явная конкретизация нешаблона %q#D"
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of variable concept %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "специализация variable concept %q#D"
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of function concept %qD"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "явная специализация function concept %qD"
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD не является статическим элементом данных шаблона класса"
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "нет подходящего шаблона для %qD"
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "тип %qT для явной конкретизации %qD не соответствует декларированному типу %qT"
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "явная конкретизация %q#D"
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "повторная явная конкретизация %q#D"
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 запрещает использование %<extern%> в явной конкретизации"
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "класс хранения %qD в конкретизации шаблона"
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "явная конкретизация неклассового шаблона %qD"
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "явная конкретизация типа %qT, не являющегося шаблоном"
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "явная конкретизация %q#T до определения шаблона"
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ запрещает использование %qE в явных конкретизациях"
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "повторная явная конкретизация %q#T"
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -67700,175 +67742,175 @@ msgstr ""
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "явная конкретизация %qD без определения"
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "глубина конкретизации шаблона превышает максимум %d при конкретизации %q+D, возможно при генерации виртуальной таблицы (задайте -ftemplate-depth=, чтобы увеличить максимум)"
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template non-type parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T не является корректным типом для нетипового параметра шаблона"
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "некорректный нетиповый параметр шаблона"
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T не является корректным типом для нетипового параметра шаблона"
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, fuzzy, gcc-internal-format
 #| msgid "a concept cannot be a member function"
 msgid "a concept cannot be constrained"
 msgstr "concept не может быть элементом-функцией"
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace or unscoped enum"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT не является пространством имен или unscoped enum"
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#T inside template parameter list"
 msgid "concept %qE has multiple template parameter lists"
 msgstr "определение %q#T внутри списка параметров шаблона"
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, fuzzy, gcc-internal-format
 #| msgid "non-class template %qT used without template arguments"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "неклассовый шаблон %qT использован без аргументов шаблона"
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, fuzzy, gcc-internal-format
 #| msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "use %qD directly instead"
 msgstr "используйте директиву #include"
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "невозможно вывести аргументы шаблона для инициализации копированием %qT, поскольку он имеет неявное руководство вывода или декларированные пользователем конструкторы"
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "вывод аргумента шаблона класса потерпел неудачу:"
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "явные руководства вывода не рассматриваются для copy-инициализации"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, fuzzy, gcc-internal-format
 #| msgid "in a call to function %qD declared here"
 msgid "explicit deduction guide declared here"
 msgstr "в вызове функции %qD определенной здесь"
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, fuzzy, gcc-internal-format
 #| msgid "class template argument deduction failed:"
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "вывод аргумента шаблона класса потерпел неудачу:"
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direct-list-initialization %<auto%> требует ровно один элемент"
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "для вывода к %<std::initializer_list%> используйте copy-list-initialization (то есть добавьте %<=%> перед %<{%>)"
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "не удается вывести возвращаемый тип lambda из %qE"
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "невозможно вывести %qT из %qE"
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "ограничения заполнителя не удовлетворены"
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "выведенный инициализатор не удовлетворяет ограничениям заполнителя"
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "выведенный тип возврата не удовлетворяет ограничениям заполнителя"
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "выведенный тип выражения не удовлетворяет ограничениям заполнителя"
 
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr ""
@@ -68084,665 +68126,665 @@ msgstr "невозможно определить тип операнда %qE д
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "__label__ декларации допускаются только в контекстах функций"
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "некорректное использование элемента %qD в статическом элементе-функции"
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %qD in static member function"
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr "некорректное использование элемента %qD в статическом элементе-функции"
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %qD in static member function"
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr "некорректное использование элемента %qD в статическом элементе-функции"
 
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, fuzzy, gcc-internal-format
 #| msgid "missing template arguments"
 msgid "%qE missing template arguments"
 msgstr "отсутствуют аргументы шаблона"
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "cannot call a concept as a function"
 msgstr "%qE нельзя использовать как функцию"
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "аргументы к деструктору не допускаются"
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr "имя %<this%> недоступно для статических элементов-функций"
 
 #
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, fuzzy, gcc-internal-format
 #| msgid "used %d template parameter(s) instead of %d"
 msgid "use explicit object parameter %qs instead"
 msgstr "использовано %d параметр(ов) шаблона вместо %d"
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template non-type parameter"
 msgid "name the explicit object parameter"
 msgstr "некорректный нетиповый параметр шаблона"
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "имя %<this%> недоступно для статических элементов-функций"
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<this%> before it is valid"
 msgstr "некорректное использование %<this%> на внешнем уровне"
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<this%> after it is valid"
 msgstr "некорректное использование %<this%> на внешнем уровне"
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "некорректное использование %<this%> в функции, не являющейся элементом"
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "некорректное использование %<this%> на внешнем уровне"
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "некорректный квалифицированный контекст в имени псевдодеструктора"
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "квалифицированный тип %qT не соответствует имени деструктора ~%qT"
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE не имеет тип %qT"
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "составной литерал необъектного типа %qT"
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be instrumented"
 msgid "%<auto{x}%> cannot be constrained"
 msgstr "функция не может быть инструментирована"
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, fuzzy, gcc-internal-format
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<~auto%> доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "параметры шаблона, являющиеся типами, должны задаваться при помощи ключевых слов %<class%> или %<typename%>"
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "некорректное использование типа %qT как подразумеваемого значения для шаблона параметра шаблона"
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "некорректный подразумеваемый аргумент для шаблона параметра шаблона"
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "определение %q#T внутри списка параметров шаблона"
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "некорректное определение квалифицированного типа %qT"
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "некорректная спецификация базового класса"
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "невозможно захватить элемент %qD анонимного объединения"
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD не захватывается"
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "lambda не имеет подразумеваемого захвата"
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr "lambda в локальном классе %q+T не может захватывать переменные из объемлющего контекста"
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "использование локальной переменной с автоматическим хранением из объемлющей функции"
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "использование параметра из внутренней функции"
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "использование параметра вне тела функции"
 
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr "отсутствуют аргументы шаблона"
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "параметр шаблона %qD типа %qT не допускается в целочисленном константном выражении, поскольку он не целого или перечислимого типа"
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "использование шаблона класса %qT в качестве выражения"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "запрос элемента %qD неоднозначен в сетке множественного наследования"
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD не может появляться в константном выражении"
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "тип %qE неизвестен"
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT не имеет перечислимый тип"
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not an integer constant"
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr "запрошенное выравнивание не является целочисленной константой"
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr ""
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, fuzzy, gcc-internal-format
 #| msgid "Reference statement index out of range"
 msgid "%<__type_pack_element%> index is out of range"
 msgstr "Индекс оператора ссылки вне диапазона"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter pack __bases only valid in template declaration"
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "Parameter pack __bases допустим только в декларации шаблона"
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "невозможно применить %<offsetof%> к деструктору %<~%T%>"
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "невозможно применить %<offsetof%> к элементу-функции %qD"
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr ""
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, fuzzy, gcc-internal-format
 #| msgid "constructor priorities are not supported"
 msgid "pointer-to-member mapping %qE not supported"
 msgstr "приоритеты конструкторов не поддерживаются"
 
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "определенный пользователем reduction поиск неоднозначен"
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "%qE в %<reduction%> клаузуле есть массив нулевого размера"
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE имеет const тип для %<reduction%>"
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "определенная пользователем редукция в конструкторским инициализатором для базового класса %qT"
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, fuzzy, gcc-internal-format
 #| msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr "модификатор не должен задаваться в предложении %<linear%> для конструкций %<simd%> или %<for%>"
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr "linear клаузула с %qs модификатором применена к нессылочной переменной с %qT типом"
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "linear клаузула применена к нецелой, неуказательной переменной с %qT типом"
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "выражение линейного шага должно быть целочисленным"
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> допускается в OpenMP только в %<declare simd%> клаузулах"
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD не есть переменная в клаузуле %qs"
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD не есть переменная в клаузуле %<firstprivate%>"
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD не есть переменная в клаузуле %<lastprivate%>"
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "%<gang%> статическое выражение должно быть целочисленным"
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<gang%> статическое значение должно быть положительным"
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "%<gang%> числовое выражение должно быть целочисленным"
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "%<vector%> выражение длины должно быть целочисленным"
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "%<worker%> числовое выражение должно быть целочисленным"
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<gang%> числовое значение должно быть положительным"
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<vector%> значение длины должно быть положительным"
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<worker%> числовое значение должно быть положительным"
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "schedule chunk size выражение должно быть целочисленным"
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "%qs выражение длины должно быть целочисленным"
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%qs выражение длины должно быть положительным константным целочисленным выражением"
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%> выражение должно быть целочисленным"
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%> выражение должно быть целочисленным"
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "%<device%> идентификатор должен быть целочисленным"
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "%<dist_schedule%> выражение размера чанка должно быть целочисленным"
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD не есть переменная в %<aligned%> клаузуле"
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE в %<aligned%> клаузуле не указатель, не массив и не ссылка на указатель или массив"
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD появляется более одного раза в %<aligned%> клаузулах"
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "%<aligned%> клаузула выражения выравнивания должна быть целочисленной"
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in %<depend%> clause"
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD не есть переменная в %<depend%> клаузуле"
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in %<aligned%> clauses"
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD появляется более одного раза в %<aligned%> клаузулах"
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<aligned%> clause"
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%qE не является переменной в предложении %<aligned%>"
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in %<aligned%> clause"
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD не есть переменная в %<aligned%> клаузуле"
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in %<aligned%> clauses"
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD появляется более одного раза в %<aligned%> клаузулах"
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in %<depend%> clause"
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr "%qD не есть переменная в %<depend%> клаузуле"
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "шаблон %qE в клаузуле %qs"
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "перегрузка имени функции %qE в клаузуле %qs"
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "%<grainsize%> выражение должно быть целочисленным"
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "%<priority%> выражение должно быть целочисленным"
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, fuzzy, gcc-internal-format
 #| msgid "%<wait%> expression must be integral"
 msgid "%<hint%> expression must be integral"
 msgstr "%<wait%> выражение должно быть целочисленным"
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, fuzzy, gcc-internal-format
 #| msgid "%qs length expression must be positive constant integer expression"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%qs выражение длины должно быть положительным константным целочисленным выражением"
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, fuzzy, gcc-internal-format
 #| msgid "%<wait%> expression must be integral"
 msgid "%<filter%> expression must be integral"
 msgstr "%<wait%> выражение должно быть целочисленным"
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, fuzzy, gcc-internal-format
 #| msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "%qs переменная не является ни указателем, ни массивом, ни ссылкой на указатель или массив"
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "%qs переменная не является ни указателем, ни массивом, ни ссылкой на указатель или массив"
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tile%> аргумент требует целочисленный тип"
 
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD не есть переменная файла, пространства имен или контекста блока"
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE директива не в %qT определении"
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "разность между %qE и %qD не имеет целый тип"
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> использована с итерационной переменной класса %qE"
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> использует два различных выражения для памяти"
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr ""
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr ""
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr ""
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, fuzzy, gcc-internal-format
 #| msgid "%qs length expression must be positive constant integer expression"
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr "%qs выражение длины должно быть положительным константным целочисленным выражением"
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr ""
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, fuzzy, gcc-internal-format
 #| msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> не является константным выражением"
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, fuzzy, gcc-internal-format
 #| msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> не является константным выражением"
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %s"
 msgid "static assertion failed: %.*s"
 msgstr "неудача static assertion: %s"
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "неконстантное условие для static assertion"
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "аргумент decltype должен быть выражением"
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, fuzzy, gcc-internal-format
 #| msgid "decltype cannot resolve address of overloaded function"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "decltype не может разрешить адрес перегруженной функции"
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr ""
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr ""
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr "вызов %<__builtin_next_arg%> без аргумента"
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a class template"
 msgid "%qD is not a class or alias template"
 msgstr "%qE не является шаблоном класса"
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "операнд выражения свертки не имеет нерасширенных пакетов параметров"
 
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "оба аргумента в бинарной свертке имеют нерасширенные пакеты параметров"
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "нет нерасширенных пакетов параметров в бинарной свертке"
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "неуказательный аргумент для %<__builtin_launder%>"
@@ -68750,1210 +68792,1210 @@ msgstr "неуказательный аргумент для %<__builtin_launder
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "квалификаторы %qV не могут быть применены к %qT"
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr ""
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, gcc-internal-format
 msgid " declared here"
 msgstr " объявлено здесь"
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr "выравнивание %qD увеличено в -fabi-version=9 (GCC 5.2)"
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, fuzzy, gcc-internal-format
 #| msgid "base class %qT has cv qualifiers"
 msgid "base class %qT is not public"
 msgstr "базовый класс %qT имеет квалификаторы cv"
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not captured"
 msgid "%qD is not public"
 msgstr "%qD не захватывается"
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is mutable"
 msgstr "%qD не переменная"
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD has a non-structural type"
 msgstr "%qD не является типом"
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr "%qE атрибут может применяться только к функциям или к классовым или перечислимым типам"
 
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "аргумент атрибута %qE не строковая константа"
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "%qE атрибут может применяться только к функциям или к классовым или перечислимым типам"
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to Java class definitions"
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "%qE атрибут может применяться только к определениям Java классов"
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to Java class definitions"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "%qE атрибут может применяться только к определениям Java классов"
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, fuzzy, gcc-internal-format
 #| msgid "the %qE attribute requires arguments"
 msgid "%qE attribute takes no arguments"
 msgstr "%qE атрибуту требуются аргументы"
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute doesn't apply to functions"
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "%qE атрибут не применим к функциям"
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "заданный init_priority не является целой константой"
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "%qE атрибут может использоваться только для определений объектов типа class на уровне файла"
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is out of range"
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "заданный init_priority вне диапазона"
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is reserved for internal use"
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "заданный init_priority зарезервировано для внутреннего использования"
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr ""
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%qE атрибуту требуются аргументы"
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "аргументы для %qE атрибута должны быть узкими строковыми литералами"
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "аргументы для %qE атрибута должны содержать корректные идентификаторы"
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%c%> не является корректным символом для идентификатора"
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%c%> не является корректным символом в идентификаторе"
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "атрибут %qE применен к неклассовому, неперечислимому типу %qT"
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "атрибут %qE применен к %qT после его определения"
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "игнорирование %qE атрибута, примененного к конкретизации шаблона %qT"
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "игнорирование %qE атрибута, примененного к специализации шаблона %qT"
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "атрибут %qE применен к нефункции, непеременной %qD"
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "атрибут %qE применен к extern \"C\" декларации %qD"
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, fuzzy, gcc-internal-format
 #| msgid "Warn if a comparison always evaluates to true or false."
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr "Предупреждать, если результат сравнения всегда истина или всегда ложь."
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "ноль как константа пустой указатель"
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, fuzzy, gcc-internal-format
 #| msgid "lang_* check: failed in %s, at %s:%d"
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "lang_* check: ошибка в %s, в %s:%d"
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "сравнение между различными указательными типами %qT и %qT без приведения типов"
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "преобразование между различными указательными типами %qT и %qT без приведения типов"
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "условное выражение между различными указательными типами %qT и %qT без приведения типов"
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ запрещает сравнение между указателем типа %<void *%> и указателем не функцию"
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ запрещает преобразование между указателем типа %<void *%> и указателем не функцию"
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ запрещает условное выражение между указателем типа %<void *%> и указателем не функцию"
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "сравнение между различными pointer-to-member типами %qT и %qT без приведения типов"
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "преобразование между различными pointer-to-member типами %qT и %qT без приведения типов"
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "условное выражение между различными pointer-to-member типами %qT и %qT без приведения типов"
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr ""
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "некорректное применение %qs к элементу-функции"
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "недопустимое применение %<sizeof%> к битовому полю"
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ запрещает применение %<sizeof%> к выражению функционального типа"
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "недопустимое применение %<__alignof%> к битовому полю"
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ запрещает применение %<__alignof%> к выражению функционального типа"
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "%<alignas%> аргумент имеет нецелочисленный тип %qT"
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "некорректное использование нестатической функции-элемента типа %qT"
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ запрещает преобразование строковой константы в %qT"
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "устаревшее преобразование из строковой константы в %qT"
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "запрос на элемент %qD в %qE, который имеет указательный тип %qT (возможно вы хотели использовать %<->%> ?)"
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "запрос элемента %qD в %qE, имеющего не классовый тип %qT"
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of nonstatic data member %qE"
 msgid "invalid use of non-static data member %qE"
 msgstr "некорректное использование нестатического элемента данных %qE"
 
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "недопустимый доступ к нестатическому элементу данных в %qD в виртуальной базе NULL объекта"
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "объектный тип %qT не соответствует имени деструктора ~%qT"
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "разрушаемый тип %qT, а деструктор относится к %qT"
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "поле %q#D доступно через %q#D"
 
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T не содержит элемента с именем %qE"
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has no member named %qE; did you mean %qE?"
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%q#T не содержит элемента с именем %qE; имелось в виду %qE?"
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has no member named %qE; did you mean %qE?"
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%q#T не содержит элемента с именем %qE; имелось в виду %qE?"
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T не содержит элемента с именем %qE; имелось в виду %qE?"
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> не является элементом %qT"
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT не является базовым для %qT"
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD не является шаблонным элементом-функцией"
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT не является типом указателя на объект"
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "некорректное использование индексирования массива к указателю на элемент"
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "некорректное использование унарной %<*%> к указателю на элемент"
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "некорректное использование неявного преобразования к указателю на элемент"
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr "левый операнд %<->*%> должен быть указателем на класс, но является указателем на элемент типа %qT"
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "отсутствует индекс массива"
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "индексируемый массив объявлен как %<register%>"
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "индексируемый объект не является ни массивом, ни указателем"
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "не задан объект при использовании %qE"
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ запрещает использование %<::main%> из программы"
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "необходимо использовать %<.*%> или %<->*%> для вызова pointer-to-member функции в %<%E (...)%>, например %<(... ->* %E) (...)%>"
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE нельзя использовать как функцию"
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD нельзя использовать как функцию"
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "выражение нельзя использовать как функцию"
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "слишком много аргументов для конструктора %q#D"
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "слишком мало аргументов для конструктора %q#D"
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "слишком много аргументов для элемента-функции %q#D"
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "слишком мало аргументов для элемента-функции %q#D"
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "слишком много аргументов для функции %q#D"
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "слишком мало аргументов для функции %q#D"
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "слишком много аргументов для метода %q#D"
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "слишком мало аргументов для метода %q#D"
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "для функции задано слишком много аргументов"
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "слишком мало аргументов функции"
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "параметр %P %qD имеет неполный тип %qT"
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "параметр %P имеет неполный тип %qT"
 
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will never be NULL"
 msgid "the address %qE will never be NULL"
 msgstr "адрес %qD никогда не будет NULL"
 
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "адрес %qD никогда не будет NULL"
 
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, fuzzy, gcc-internal-format
 #| msgid "the compiler can assume that the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr "компилятор может предположить, что адрес %qD не может быть NULL"
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr ""
 
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "компилятор может предположить, что адрес %qD не может быть NULL"
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr "операнды для ?: имеют разные типы %qT и %qT"
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, fuzzy, gcc-internal-format
 #| msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "преобразование между различными указательными типами %qT и %qT без приведения типов"
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr "сравнение между типами %qT и %qT"
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "сравнение между различными указательными типами %qT и %qT без приведения типов"
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, fuzzy, gcc-internal-format
 #| msgid "complex arguments must have floating-point type"
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr "complex аргументы должны иметь плавающие типы"
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, fuzzy, gcc-internal-format
 #| msgid "cast from function call of type %qT to non-matching type %qT"
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr "приведение вызова функции типа %qT к несоответствующему типу %qT"
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "преобразование из указательного типа %qT в арифметический тип %qT в константном выражении"
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types when assigning to type %qT from type %qT"
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr "несовместимые типы в присваивании типу %qT значения типа %qT"
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "предполагается приведение к типу %qT из перегруженной функции"
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL в арифметическом выражении"
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ не поддерживает сравнение между указателем и целым"
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "типы операндов %qT и %qT"
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "упорядоченное сравнение указателя с целочисленным нулем"
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "аргумент неупорядоченного сравнения - не плавающее значение"
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "некорректные операнды типов %qT и %qT для бинарной операции %qO"
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ не поддерживает использование указателя %<void *%> в вычитании"
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ не поддерживает использование указателя на функцию в вычитании"
 
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ не поддерживает использование указателя на метод в вычитании"
 
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "некорректное использование указателя на неполный тип в вычислениях с указателями"
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr ""
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr ""
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "некорректное использование %qE для образования указателя на элемент-функцию"
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  qualified-id требуется"
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "нельзя использовать скобки вокруг %qE для образования указателя на элемент-функцию"
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr ""
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of a cast to a non-lvalue expression"
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr "ISO C++ не поддерживает взятие адреса от приведения к не-lvalue-выражению"
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr "(указатель на элемент можно получить только при помощи %<&%E%>)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "адрес от временной переменной"
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ не поддерживает взятие адреса от функции %<::main%>"
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "нельзя создать указатель на элемент-ссылку %qD"
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "попытка взять адрес битового поля"
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, fuzzy, gcc-internal-format
 #| msgid "%<~%> on an expression of type bool"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<~%> от выражения типа bool"
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "имелось в виду использовать логическое отрицание (%<!%>)?"
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ запрещает инкрементирование enum"
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ запрещает декрементирование enum"
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "невозможно инкрементировать указатель на неполный тип %qT"
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "невозможно декрементировать указатель на неполный тип %qT"
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ запрещает инкрементирование указателя типа %qT"
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ запрещает декрементирование указателя типа %qT"
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr "использование операнда типа %qT в %<operator--%> запрещено"
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr "использование операнда типа %qT в %<operator++%> устарело"
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "нельзя взять адрес от %<this%>, поскольку это rvalue-выражение"
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "запрошен адрес явной регистровой переменной %qD"
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "запрошен адрес для %qD, которая декларирована как %<register%>"
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "list-initializer для неклассового типа не должен быть заключен в скобки"
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "список выражений рассматривается как составное выражение в инициализаторе"
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "список выражений рассматривается как составное выражение в mem-initializer"
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "список выражений рассматривается как составное выражение в функциональном приведении типов"
 
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s - список выражений рассматривается как составное выражение"
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "нет контекста для разрешения типа %qE"
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "приведение от типа %qT к типу %qT отбрасывает квалификаторы"
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, fuzzy, gcc-internal-format
 #| msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "static_cast от типа %qT к типу %qT отбрасывает квалификаторы"
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpret_cast от типа %qT к типу %qT отбрасывает квалификаторы"
 
 #
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr ""
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr ""
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "некорректное применение static_cast от типа %qT к типу %qT"
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "тип класса %qT неполный"
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 msgid "converting from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "некорректное приведение rvalue выражения из типа %qT к типу %qT"
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 msgid "cast from %qH to %qI loses precision"
 msgstr ""
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr ""
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "приведение указателя на функцию к указателю на объект условно поддерживается"
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "некорректное приведение из типа %qT к типу %qT"
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "некорректное применение const_cast с типом %qT, не являющимся ни указателем, ни ссылкой, ни  указателем на элемент данных"
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "некорректное применение const_cast с типом %qT, являющимся указателем или ссылкой на функцию"
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "некорректное применение const_cast от rvalue-выражения типа %qT к типу %qT"
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "некорректное применение const_cast от типа %qT к типу %qT"
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ не поддерживает приведение к типу массива %qT"
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "некорректное приведение к типу функции %qT"
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qE from type %qT to type %qT"
 msgid "moving %qE of type %qT to itself"
 msgstr "ошибка преобразования %qE из типа %qT в тип %qT"
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  в вычислении %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "присваивание массиву из списка инициализатора"
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "несовместимые типы в присваивании %qT -> %qT"
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "массив использован как инициализатор"
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "некорректное присваивание массива"
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   в преобразовании указателя на элемент-функцию"
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "преобразование указателя к элементу через виртуальную базу %qT"
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   в преобразовании указателя на элемент"
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "некорректное преобразование к типу %qT от типа %qT"
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 msgid "cannot convert %qH to %qI in default argument"
 msgstr ""
 
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr ""
 
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 msgid "cannot convert %qH to %qI in initialization"
 msgstr ""
 
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 msgid "cannot convert %qH to %qI in return"
 msgstr ""
 
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 msgid "cannot convert %qH to %qI in assignment"
 msgstr ""
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "параметр %qP %qD мог быть кандидатом для атрибута формата"
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "параметр мог быть кандидатом для атрибута формата"
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "цель преобразования могла быть кандидатом для атрибута формата"
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "цель инициализации могла быть кандидатом для атрибута формата"
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "левая часть присваивания могла быть кандидатом для атрибута формата"
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "при передаче аргумента %P от %qD"
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "возврат ссылки на временную переменную"
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "returning pointer to temporary"
 msgstr "возврат ссылки на временную переменную"
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "возвращена ссылка на локальную переменную %qD"
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "возвращен адрес метки %qD"
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "возвращен адрес локальной переменной %qD"
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
 #
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, fuzzy, gcc-internal-format
 #| msgid "not enough values in return statement"
 msgid "redundant move in return statement"
 msgstr "недостаточно значений в операторе возврата"
 
 #
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, fuzzy, gcc-internal-format
 #| msgid "not enough values in return statement"
 msgid "redundant move in initialization"
 msgstr "недостаточно значений в операторе возврата"
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "возвращен результат деструктора"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "возврат в обработчике try-блока конструктора"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "возврат результата конструктора"
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return без значения в функции, возвращающей %qT"
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "возврат списка инициализатора"
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "противоречивые типы %qT и %qT выведены для возвращаемого типа lambda"
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "противоречивый вывод для auto return type: %qT и затем %qT"
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> не должен возвращать NULL, если только он не декларирован %<throw()%> (или задан ключ -fcheck-new)"
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q#D"
 msgid "not eliding copy on return from %qD"
 msgstr "некорректный ковариантный тип результата для %q#D"
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr ""
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, fuzzy, gcc-internal-format
 #| msgid "using temporary as lvalue"
 msgid "using rvalue as lvalue"
@@ -70178,165 +70220,165 @@ msgstr "перегруженная функция без контекстной
 msgid "insufficient contextual information to determine type"
 msgstr "недостаточно контекстной информации для определения типа"
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "использован синтаксис конструктора для типа %qT, который не имеет конструкторов"
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, fuzzy, gcc-internal-format
 #| msgid "interface %qE does not have valid constant string layout"
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "интерфейс %qE не имеет корректной структуры константной строки"
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 #, fuzzy
 #| msgid "Warn about narrowing conversions within { } that are ill-formed in C++11."
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "Предупреждать о сужающих преобразованиях в { }, являющихся дефектными в C++11."
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 #, fuzzy
 #| msgid "conversion from %q#T to %q#T"
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "преобразование из %q#T в %q#T"
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, fuzzy, gcc-internal-format
 #| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "слишком длинная строка инициализации для символьного массива"
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "фигурные скобки вокруг скалярного инициализатора"
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "невозможно инициализировать агрегат типа %qT составным литералом"
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "отсутствует инициализатор для элемента %qD"
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "элемент %qD - неинициализированная ссылка"
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "элемент %qD с неинициализированными ссылочными полями"
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "поле %qD не найдено в инициализируемом объединении"
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "значение индекса вместо имени поля в инициализаторе объединения"
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "обнаружено циклическое делегирование указателей"
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "базовый операнд %<->%> имеет неуказательный тип %qT"
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "результат %<operator->()%> не является указателем"
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "базовый операнд %<->%> не является указателем"
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE не может использоваться как элемент, поскольку имеет тип %qT"
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "невозможно применить элементный указатель %qE к %qE, который имеет неклассовый тип %qT"
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "указатель на элементный тип %qT несовместим с объектным типом %qT"
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "тип указатель на элемент-функцию %qT требует rvalue"
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "тип указатель на элемент-функцию %qT требует lvalue"
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, fuzzy, gcc-internal-format
 #| msgid "pointer-to-member-function type %qT requires an lvalue"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "тип указатель на элемент-функцию %qT требует lvalue"
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "функциональное приведение к массивному типу %qT"
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be instrumented"
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "функция не может быть инструментирована"
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, fuzzy, gcc-internal-format
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<~auto%> доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "некорректная инициализация значения ссылочного типа"
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "вызов функции %qD, которая вызывает исключение неполного типа %q#T"
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "вызов функции, которая вызывает исключение неполного типа %q#T"
@@ -71386,7 +71428,7 @@ msgstr "Список имен %qs не может быть аргументом
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "%<I%> в %L и %<J%> в %L не могут обе быть BOZ литеральными константами"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid exponent-letter %<q%> in real-literal-constant at %C"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -72754,7 +72796,7 @@ msgstr "Некорректная INTENT спецификация в %C"
 msgid "deferred type parameter at %C"
 msgstr "отложенный параметр типа в %C"
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Скалярное INTEGER выражение ожидалось в %L"
@@ -72981,7 +73023,7 @@ msgstr "Компонент %qs с CLASS в %C должен быть размещ
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Компонент-массив структуры в %C должен иметь явную или отложенную форму"
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "Компонент %qs в %C уже декларирован в %L"
@@ -73800,7 +73842,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr "Ожидался список формальный аргументов в определении функции в %C"
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "BIND(C) атрибут в %L может использоваться только для переменных или common блоков"
@@ -74618,12 +74660,12 @@ msgstr "identical_array_ref(): противоречивые размерност
 msgid "are_identical_variables: Bad type"
 msgstr "are_identical_variables: Некорректный тип"
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr "INTENT(%s) фактические аргументы в %L могут противоречить фактическим аргументам в %L."
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr "gfc_check_dependency: ожидается EXPR_VARIABLE"
@@ -74879,276 +74921,276 @@ msgstr "Parameter %qs at %L не был декларирован или явля
 msgid "check_init_expr(): Unknown expression type"
 msgstr "check_init_expr(): Неизвестный тип выражения"
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr "Спецификационная функция %qs в %L не может быть оператор-функцией"
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr "Спецификационная функция %qs в %L не может быть внутренней функцией"
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, gcc-internal-format
 msgid "Specification function %qs at %L must be PURE"
 msgstr "Спецификационная функция %qs в %L должна быть PURE"
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr "Спецификационная функция %qs в %L не может быть RECURSIVE"
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, gcc-internal-format
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr "Формальный аргумент %qs не допускается в выражении в %L"
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr "Формальный аргумент %qs в %L не может быть OPTIONAL"
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr "Формальный аргумент %qs в %L не может быть INTENT(OUT)"
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr "Переменная %qs не может появляться в выражении в %L"
 
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, gcc-internal-format
 msgid "check_restricted(): Unknown expression type"
 msgstr "check_restricted(): Неизвестный тип выражения"
 
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr "Выражение в %L должно быть INTEGER типа, найдено %s"
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, gcc-internal-format
 msgid "Function %qs at %L must be PURE"
 msgstr "Функция %qs в %L должна быть PURE"
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr "Выражение в %L должно быть скалярным"
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr ""
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr "Несовместимые ранги в %s (%d и %d) в %L"
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "Иная форма для %s в %L по измерению %d (%d и %d)"
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr "Присваивание полиморфному комассиву в %L не допускается"
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr "%qs в %L не есть VALUE"
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal stride of zero at %L"
 msgid "Illegal assignment to external procedure at %L"
 msgstr "Некорректный нулевой шаг в %L"
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "Несовместимые ранги %d и %d в присваивании в %L"
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "Тип переменной UNKNOWN в присваивании в %L"
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "NULL появляется в правой части присваивания в %L"
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "Функция с POINTER-значением появляется в правой части присваивания в %L"
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr ""
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Несовместимые типы в DATA операторе в %L; попытка преобразования %s в %s"
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "Цель указательного присваивания не есть POINTER в %L"
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "%qs в указательном присваивании в %L не может быть l-value, поскольку это процедура"
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Ожидалась спецификация границ для %qs в %L"
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Спецификация границ для %qs в указательном присваивании в %L"
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "Шаг не может присутствовать в %L"
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "Указательный объект в %L не должен иметь коиндекс"
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Некорректное присваивание указателя на процедуру в %L"
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Результат функции %qs некорректен как процедурная цель в присваивании указателя на процедуру в %L"
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Абстрактный интерфейс %qs некорректен в присваивании указателя на процедуру в %L"
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Оператор-функция %qs некорректна в присваивании указателя на процедуру в %L"
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Внутренняя процедура %qs некорректна в присваивании указателя на процедуру в %L"
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Встроенная функция %qs в %L некорректна в присваивании указателя на процедуру"
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Невстроенная элементная процедура %qs некорректна в присваивании указателя на процедуру в %L"
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "Несоответствие в присваивании указателя на процедуру в %L: несоответствие в соглашении о вызове"
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "Несоответствие интерфейсов в присваивании указателя на процедуру в %L: %qs не есть подпрограмма"
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Явный интерфейс требуются для компонента %qs в %L: %s"
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Явный интерфейс требуются для %qs в %L: %s"
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Несоответствие интерфейсов в присваивании указателя на процедуру в %L: %s"
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr "Цель указателя на процедуру %qs в %L должна быть встроенной функцией, host или use ассоциированной, на нее должна быть ссылка или она должна иметь EXTERNAL атрибут"
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr "Цель указательного присваивания не есть POINTER в %L"
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr "Data-pointer-object в %L должен быть неограниченно полиморфным или иметь тип с BIND или SEQUENCE атрибутами, чтобы быть совместимым с неограниченно полиморфной целью"
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Разные типа в присваивании указателя в %L; попытка присвоить %s в %s"
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Разные виды типовых параметров в присваивании указателя в %L"
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Разные ранги в присваивании указателя в %L"
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "Цель переотображения ранга меньше чем размер указателя (%ld < %ld) в %L"
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "Цель переотображения ранга должна быть ранга 1 или просто непрерывна в %L"
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "Цель, переотображающая ранг, не ранга 1 в %L"
@@ -75156,204 +75198,204 @@ msgstr "Цель, переотображающая ранг, не ранга 1 
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "Целевые данные в %L не должны иметь коиндекс"
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Целевое выражение в присваивании указателя в %L должна выдавать указательный результат"
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr ""
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "Цель инициализации указателя в %L должна иметь TARGET атрибут"
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NAME= specifier at %C should be a constant expression"
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr "NAME= спецификатор в %C должен быть константным выражением"
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr ""
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Цель присваивания указателя не TARGET и не POINTER в %L"
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Некорректная цель в присваивании указателя в PURE процедуре в %L"
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Присваивание указателя с индексом вектора в правой части в %L"
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Цель присваивания указателя имеет PROTECTED атрибут в %L"
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "Указатель в %L в присваивании указателя может пережить цель указателя"
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Цель инициализации указателя в %L не должна быть ALLOCATABLE"
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Цель инициализации указателя в %L должна иметь TARGET атрибут"
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Цель инициализации указателя в %L должна иметь SAVE атрибут"
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "Цель инициализации указателя на процедуру в %L не может быть указателем на процедуру"
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Внутренняя процедура %qs некорректна в присваивании указателя на процедуру в %L"
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Внутренняя процедура %qs некорректна в присваивании указателя на процедуру в %L"
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Указательные функции в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Non-variable выражение в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Именованная константа %qs в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qs в контексте определения переменных (%s) в %L не есть переменная"
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Non-POINTER в контексте ассоциации указателей (%s) в %L"
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Тип недоступен в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_EVENT в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant %qs in variable definition context (%s) at %L"
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr "Именованная константа %qs в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Формальный аргумент %qs с INTENT(IN) в контексте ассоциации указателей (%s) в %L"
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Формальный аргумент %qs с INTENT(IN) в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "Переменная %qs является PROTECTED и не может появляться в контексте ассоциации указателей (%s) в %L"
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "Переменная %qs является PROTECTED и не может появляться в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Переменная %qs не может появляться в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr "%qs в %L ассоциированное с векторно индексированной целью не может использоваться в контексте определения переменных (%s)"
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "%qs в %L ассоциированное с выражением не может использоваться в контексте определения переменных (%s)"
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr "%qs в %L ассоциированное с выражением не может использоваться в контексте определения переменных (%s)"
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "Имя ассоциации %qs не может появляться в контексте определения переменных (%s) в %L, поскольку его цель в %L также не может"
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "Элементы с одинаковым значением в %L и %L в векторном индексе в контексте определения переменной (%s)"
@@ -75376,8 +75418,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Некорректный идентификатор в copy_walk_reduction_arg"
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "Создание временного массива в %L"
@@ -75462,7 +75504,7 @@ msgstr "Переменная %qs в %L установлена в неопред
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Переменная %qs в %L не определяется внутри цикла, начинающегося в %L, как INTENT(OUT) аргумент для функции %qs"
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr "Код для переразмещения размещаемого массива в %L будет добавлен"
@@ -75599,12 +75641,12 @@ msgstr "Первый аргумент определенного присваи
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Второй аргумент определенного присваивания в %L должен быть INTENT(IN)"
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Первый аргумент интерфейса оператора в %L должен быть INTENT(IN)"
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Второй аргумент интерфейса оператора в %L должен быть INTENT(IN)"
@@ -76500,7 +76542,7 @@ msgstr "Преобразование из %s в %s в %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
@@ -77089,7 +77131,7 @@ msgstr "NAMELIST %qs в READ операторе в %L содержит симв
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST объект %qs в списке имен %qs в %L является полиморфным и требует определенную процедуру ввода/вывода"
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "NAMELIST объект %qs в списке имен %qs в %L с ALLOCATABLE или POINTER компонентами"
@@ -77265,6 +77307,11 @@ msgstr "Переполнение при вычислении целочисле
 msgid "check_charlen_present(): length not set"
 msgstr ""
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr ""
+
 #: fortran/match.cc:118
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
@@ -77683,7 +77730,7 @@ msgstr "STOP код в %L должен быть default character KIND=%d"
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "STOP код в %L должен быть default integer KIND=%d"
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
@@ -78218,87 +78265,87 @@ msgstr "ошибка разбора в SELECT TYPE операторе в %C"
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "Селектор в SELECT TYPE в %C не есть именованная переменная; используйте associate-name=>"
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "LOCK statement at %C"
 msgid "SELECT RANK statement at %C"
 msgstr "LOCK оператор в %C"
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in SELECT TYPE statement at %C"
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "ошибка разбора в SELECT TYPE операторе в %C"
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Неожиданный CASE оператор в %C"
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Синтаксическая ошибка в CASE спецификации в %C"
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Неожиданный TYPE IS оператор в %C"
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr "Спецификация типа не должна специфицировать sequence производный тип или тип с BIND атрибутом в SELECT TYPE в %C [F2003:C815]"
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Синтаксическая ошибка в TYPE IS спецификации в %C"
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Синтаксическая ошибка в CLASS IS спецификации в %C"
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected RANK statement at %C"
 msgstr "Неожиданный END оператор в %C"
 
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL stride expression at %L must be a scalar %s"
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "FORALL шаговое выражение в %L должно быть скаляром %s"
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE specification at %C"
 msgid "Syntax error in RANK specification at %C"
 msgstr "Синтаксическая ошибка в CASE спецификации в %C"
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "ELSEWHERE оператор в %C не заключен в WHERE блок"
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "Метка %qs в %C не соответствует WHERE метке %qs"
@@ -79813,8 +79860,8 @@ msgstr "параметр ORDERED клаузулы меньше чем COLLAPSE 
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF клаузула в %L требует скалярное LOGICAL выражение"
@@ -82285,12 +82332,12 @@ msgstr "Встроенная %qs декларированная INTRINSIC в %L
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Не-RECURSIVE процедура %qs в %L возможно вызывает себя рекурсивно.  Объявите её RECURSIVE или используйте %<-frecursive%>"
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Не-RECURSIVE процедура %qs в %L возможно вызывает себя рекурсивно.  Объявите её RECURSIVE или используйте %<-frecursive%>"
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Метка %d используемая в %L нигде не определяется"
@@ -82412,7 +82459,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Функция %qs в %L не имеет IMPLICIT тип. Может имелось в виду %qs?"
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Функция %qs в %L не имеет IMPLICIT тип"
@@ -82821,282 +82868,288 @@ msgstr "Переменная предполагаемого типа %s в %L н
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Переменная предполагаемого ранга %s в %L не должна иметь ссылку на подобъект"
 
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_variable_attr(): Bad array reference"
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr "gfc_variable_attr(): Некорректная ссылка на массив"
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Переменная %qs, использованная в спецификационном выражении, фигурирует в %L до ENTRY оператора, в котором она является параметром"
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Переменная %qs используется в %L до оператора ENTRY, в котором она является параметром"
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Полиморфный подобъект коиндексированного объекта в %L"
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Коиндексированный объект с полиморфным размещаемым подкомпонентом в %L"
 
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, fuzzy, gcc-internal-format
 #| msgid "%qs matching variant is deprecated."
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%qs соответствующий вариант устарел."
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Bad array reference at %L"
+msgid "Invalid array reference at %L"
+msgstr "Некорректная ссылка на массив в %L"
+
+#: fortran/resolve.cc:6433
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Error in type-spec at %L"
 msgid "Error in typebound call at %L"
 msgstr "Ошибка в спецификации типа в %L"
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Передаваемый объект в %L должен быть скаляром"
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Базовый объект для вызова компонента указателя на процедуру в %L имеет ABSTRACT тип %qs'"
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Базовый объект для вызова type-bound процедуры в %L имеет ABSTRACT тип %qs"
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Базовый объект для вызова NOPASS type-bound процедуры в %L должен быть скаляром"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Не найдено подходящего конкретного связывания для вызова GENERIC %qs в %L"
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs в %L должна быть SUBROUTINE"
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs в %L должна быть FUNCTION"
 
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Некорректный тип выражения"
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "'%s' в %L должна быть скаляром"
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s в %L должен быть integer"
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s в %L должна быть INTEGER"
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Шаговое выражение в DO цикле в %L не может быть нулевым"
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO цикл в %L будет выполнен ноль раз"
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "DO цикл в %L является неопределенным, так как он переполняется"
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "DO цикл в %L является неопределенным, так как он теряет значимость"
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL индекс-имя в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL стартовое выражение в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL конечное выражение в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL шаговое выражение в %L должно быть скаляром %s"
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL шаговое выражение в %L не может быть нулевым"
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL индекс %qs не может появляться в спецификации триплета в %L"
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allocate-object в %L должен быть ALLOCATABLE или POINTER"
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Коиндексированный размещаемый объект в %L"
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Source-expr в %L должно быть скалярным или иметь тот же ранг, что и allocate-object в %L"
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Source-expr в %L и allocate-object в %L должны иметь одинаковую форму"
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Тип сущности в %L есть тип несовместимый с source-expr в %L"
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Allocate-object в %L и source-expr в %L должны иметь одинаковый вид параметра типа"
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Source-expr в %L не должно быть типа LOCK_TYPE и не должно иметь LOCK_TYPE компонент, если allocate-object в %L является комассивом"
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "Source-expr в %L не должно быть типа EVENT_TYPE и не должно иметь EVENT_TYPE компонент, если allocate-object в %L является комассивом"
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Размещение %s ABSTRACT базового типа в %L требует type-spec или source-expr"
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Размещение %s в %L с type-spec требует того же character-length параметра, что и в декларации"
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Спецификация массива требуется в ALLOCATE операторе в %L"
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Спецификация массива или SOURCE= выражение со значением массивом требуется в ALLOCATE операторе в %L"
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Спецификация комассива требуется в ALLOCATE операторе в %L"
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Некорректная спецификация комассива в ALLOCATE операторе в %L"
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Некорректная спецификация массива в ALLOCATE операторе в %L"
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs не должно появляться в спецификации массива в %L в том же ALLOCATE операторе где оно само размещается"
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "Ожидалась '*' в спецификации коиндекса в ALLOCATE операторе в %L"
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-variable в %L должна быть скалярной INTEGER переменной"
 
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-variable в %L не должна быть %sd в том же %s операторе"
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG в %L бесполезно без STAT тега"
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "ERRMSG переменная в %L должна быть стандартной скалярной CHARACTER переменной"
 
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Переменная Errmsg в %L не должна быть %sd в том же операторе %s"
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allocate-object в %L также появляется в %L"
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allocate-object в %L есть подобъект объекта в %L"
@@ -83105,287 +83158,287 @@ msgstr "Allocate-object в %L есть подобъект объекта в %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE метка в %L перекрывается с CASE меткой в %L"
 
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Выражение в CASE операторе в %L должно быть типа %s"
 
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Выражение в CASE операторе в %L должно быть вида %d"
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Выражение в CASE операторе в %L должно быть скаляром"
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Выражение выбора в вычисляемом GOTO операторе в %L должно быть скалярным integer выражением"
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Аргумент SELECT оператора в %L не может быть %s"
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Аргумент SELECT оператора в %L не может быть скалярным выражением"
 
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Выражение в CASE операторе в %L не находится в диапазоне %s"
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "За DEFAULT CASE в %L не может следовать второй DEFAULT CASE в %L"
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Логический диапазон в CASE операторе в %L не допускается"
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Константное логическое значение в CASE операторе повторяется в %L"
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Спецификации диапазона в %L невозможно найти соответствие"
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Логический SELECT CASE блок в %L имеет более двух случаев"
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Встроенная функция %qs в %L некорректна в присваивании указателя на процедуру"
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type %qs cannot be used as a variable at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Производный тип %qs не может быть использован как переменная в %C"
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name %qs at %L is used as array"
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Имя ассоциации %qs в %L используется как массив"
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Селектор в %L не может быть NULL()"
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Селектор в %L не имеет типа"
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Имя ассоциации %qs в %L используется как массив"
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "CLASS селектор в %L требует временной переменной, которая пока не реализована"
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Селектор должен быть полиморфным в SELECT TYPE операторе в %L"
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Селектор в %L не должен быть коиндексирован"
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS в %L перекрывается с TYPE IS в %L"
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Производный тип %qs в %L должен быть расширяемым"
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Производный тип %qs в %L должен быть расширением %qs"
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Неожиданный встроенный тип %qs в %L"
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Спецификация типа в %L должна специфицировать, что каждый параметр длины типа является предполагаемым"
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Двойной CLASS IS блок в SELECT TYPE операторе в %L"
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Некорректный контекст для NULL () встроенной в %L"
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "DTIO %s процедура в %L должна быть рекурсивной"
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может быть полиморфным, если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может иметь POINTER компоненты, если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Элемент передачи данных в %L не может иметь компоненты указатели на процедуру"
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может иметь ALLOCATABLE компоненты если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Элемент передачи данных в %L не может иметь PRIVATE компоненты"
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может иметь PRIVATE компоненты, если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Элемент передачи данных в %L не может быть полной ссылкой на массив предполагаемого размера"
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Lock переменная в %L должна быть скаляром типа LOCK_TYPE"
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "Event переменная в %L должна быть скаляром типа EVENT_TYPE"
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Аргумент event переменная в %L должен быть комассивом или коиндексированным"
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Аргумент event переменная в %L должен быть комассивом, но не коиндексированным"
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT= аргумент в %L должна быть скалярной INTEGER переменной"
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG= аргумент в %L должна быть скалярной CHARACTER переменной"
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK= аргумент в %L должна быть скалярной LOGICAL переменной"
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "UNTIL_COUNT= аргумент в %L должен быть скалярным INTEGER выражением"
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Imageset аргумент в %L должен быть скалярным или ранга 1 INTEGER выражением"
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Imageset аргумент в %L должен быть между 1 и num_images()"
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Оператор в %L не есть корректный оператор цели перехода для оператора перехода в %L"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Переход в %L может вызвать зацикливание"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO оператор в %L покидает CRITICAL конструкцию для метки в %L"
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO оператор в %L покидает DO CONCURRENT конструкцию для метки в %L"
@@ -83393,221 +83446,221 @@ msgstr "GOTO оператор в %L покидает DO CONCURRENT констр
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Метка в %L не находится в том же блоке, что GOTO оператор в %L"
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE маска в %L имеет противоречивую форму"
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE цель присваивания в %L имеет противоречивую форму"
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Non-ELEMENTAL определенное пользователем присваивание в WHERE в %L"
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Неподдерживаемый оператор внутри WHERE в %L"
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Присваивание FORALL индексной переменной в %L"
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL с индексом %qs не используется в левой части присваивания в %L и поэтому может вызвать множественное присваивание этому объекту"
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BLOCK construct at %C"
 msgid "FORALL construct at %L"
 msgstr "BLOCK конструкция в %C"
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL имя индекса в %L должно быть скалярной переменной типа integer"
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Внешняя FORALL конструкция уже имеет индекс с этим именем %L"
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE клаузула в %L требует LOGICAL массив"
 
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Некорректный тип блока"
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have procedure pointer components"
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr "Элемент передачи данных в %L не может иметь компоненты указатели на процедуру"
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr "CHARACTER выражение будет усечено в присваивании (%ld/%ld) в %L"
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Коиндексированное выражение в %L присваивается переменной производного типа с POINTER компонентом в PURE процедуре"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Присваивание коиндексированной переменной в %L в PURE процедуре"
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Присваивание полиморфному комассиву в %L не допускается"
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Присваивание размещаемой полиморфной переменной в %L"
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Присваивание размещаемой полиморфной переменной в %L требует %<-frealloc-lhs%>"
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, fuzzy, gcc-internal-format
 #| msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr "Неразмещаемая переменная не должна быть полиморфной во встроенном присваивании в %L - проверьте, что имеется соответствующая конкретная подпрограмма для '=' оператора"
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Коиндексированная переменная не должна иметь размещаемых окончательных компонентов в присваивании в %L"
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "TODO: type-bound определенные присваивания в %L не выполнены, так как несколько ссылок на части массива появятся в промежуточных выражениях."
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Присваивание указателя на процедуру в %L"
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Результат функции в левой части присваивания в %L должен иметь pointer атрибут."
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "Аргумент SELECT оператора в %L не может быть скалярным выражением"
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "STAT= аргумент в %L должна быть скалярной INTEGER переменной"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "ASSIGNED GOTO оператор в %L требует INTEGER переменной"
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Переменной %qs не присвоили целевую метку в %L"
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternate RETURN оператор в %L требует SCALAR-INTEGER спецификатор возврата"
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected initialization expression in CASE at %C"
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "Ожидалось инициализационное выражение в CASE в %C"
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN оператор в %L требует скалярную подразумеваемого INTEGER переменную"
 
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "Некорректный NULL в %L"
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Оператор арифметического IF в %L требует скалярное REAL или INTEGER выражение"
 
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Нет выражения в DO WHILE"
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Условие выхода из DO WHILE цикла в %L должно быть скалярным LOGICAL выражением"
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL клаузула маски в %L требует скалярное LOGICAL выражение"
 
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Некорректный код оператора"
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter %qs declared at %L"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Неиспользуемый параметр %qs декларирован в %L"
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Переменная %qs со связывающей меткой %qs в %L использует тот же глобальный идентификатор, что и сущность в %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "Переменная %qs из модуля %qs со связывающей меткой %qs в %L использует тот же глобальный идентификатор, что и сущность в %L из модуля %qs"
@@ -83615,1013 +83668,1013 @@ msgstr "Переменная %qs из модуля %qs со связывающе
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Процедура %qs со связывающей меткой %qs в %L использует тот же глобальный идентификатор, что и сущность в %L"
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Длина строки в %L слишком велика"
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Размещаемый массив %qs в %L должен иметь отложенную форму или предполагаемый ранг"
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Скалярный объект %qs в %L не может быть ALLOCATABLE"
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Указатель на массив %qs at %L должен иметь отложенную форму или предполагаемый ранг"
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Массив %qs at %L не может иметь отложенную форму"
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Тип %qs CLASS переменной %qs at %L не является расширяемым"
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS переменная %qs в %L должна быть формальным параметром, размещаемой или указателем"
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Тип %qs не может быть host ассоциированным в %L, поскольку он блокирован несовместимым объектом с тем же именем декларированным в %L"
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Выведенный SAVE для переменной модуля %qs в %L необходим из-за подразумеваемой инициализации"
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Сущность %qs в %L имеет параметр отложенного типа и требует либо POINTER либо ALLOCATABLE атрибут"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Массив из модуля или главной программы %qs в %L должен иметь константную форму"
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Сущность с предполагаемой character длиной в %L должна быть формальным аргументом или PARAMETER"
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs в %L должна иметь константную character длину в этом контексте"
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON переменная %qs в %L должна иметь константную character длину"
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Размещаемая %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Внешняя %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Формальный параметр %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Встроенная %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Результат функции %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Автоматический массив %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s в %L"
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Оператор функция с character значением %qs в %L должна иметь константную длину"
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs имеет PRIVATE тип и не может быть формальным аргументом %qs, который PUBLIC в %L"
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Процедура %qs в PUBLIC интерфейсе %qs в %L берет формальные аргументы %qs, который PRIVATE"
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Функция %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Внешний объект %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL функция %qs в %L должна иметь скалярный результат"
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Оператор функция %qs в %L не может иметь pointer или allocatable атрибут"
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) функция %qs в %L не может иметь значение массив"
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) функция %qs в %L не может иметь значение указатель"
 
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) функция %qs в %L не может быть pure"
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) функция %qs в %L не может быть рекурсивной"
 
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) функция %qs в %L"
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Указатель на процедуру %qs в %L не должен быть элементным"
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Формальная процедура %qs в %L не должна быть элементной"
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Переменная результата функции %s в %L элементной функции %qs не должна иметь атрибут ALLOCATABLE или POINTER"
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с SAVE атрибутом в %qs в %L"
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с INTENT атрибутом в %qs в %L"
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с RESULT атрибутом в %qs в %L"
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL атрибут конфликтует с FUNCTION атрибутом в %qs в %L"
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Результат указатель на процедуру %qs в %L оказался без pointer атрибута"
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Несоответствие в ELEMENTAL атрибуте между MODULE PROCEDURE в %L и ее интерфейсом в %s"
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Несоответствие в PURE атрибуте между MODULE PROCEDURE в %L и ее интерфейсом в %s"
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Несоответствие в RECURSIVE атрибуте между MODULE PROCEDURE в %L и ее интерфейсом в %s"
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s между MODULE PROCEDURE декларацией в MODULE %qs и декларацией в %L в (SUB)MODULE %qs"
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, fuzzy, gcc-internal-format
 #| msgid "Interface %qs at %L must be explicit"
 msgid "Interface of %qs at %L must be explicit"
 msgstr "Интерфейс %qs в %L должен быть явным"
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL процедура %qs в %L не есть SUBROUTINE"
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL процедура в %L должна иметь ровно один аргумент"
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Аргумент FINAL процедуры в %L должен быть типа %qs"
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Аргумент FINAL процедуры в %L не должен быть POINTER"
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Аргумент FINAL процедуры в %L не должен быть ALLOCATABLE"
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Аргумент FINAL процедуры в %L не должен быть OPTIONAL"
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Аргумент FINAL процедуры в %L не должен быть INTENT(OUT)"
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Нескалярная FINAL процедура в %L должна иметь аргумент предполагаемой формы"
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "FINAL процедура %qs декларированная в %L имеет тот же ранг (%d), что и %qs"
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr "Только массивные FINAL процедуры декларированные для производного типа %qs определенного в %L, предлагают также скалярный тип"
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, fuzzy, gcc-internal-format
 #| msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs и %qs не могут быть смешанными FUNCTION/SUBROUTINE для GENERIC %qs в %L"
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs и %qs для GENERIC %qs в %L неоднозначны"
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Неопределенное конкретное связывание %qs как цели GENERIC %qs в %L"
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs в %L должен нацеливаться на конкретное связывание, %qs также GENERIC"
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC %qs в %L не может перебить конкретное связывание с тем же именем"
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-bound operator at %L can't be NOPASS"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Type-bound оператор в %L не может быть NOPASS"
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs должна быть процедурой модуля или внешней процедурой с явным интерфейсом в %L"
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Процедура %qs с PASS(%s) в %L не имеет аргумента %qs"
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Процедура %qs с PASS в %L должна иметь по крайней мере один аргумент"
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Неполиморфный passed-object формальный аргумент %qs в %L"
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L должен быть производного типа %qs"
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, fuzzy, gcc-internal-format
 #| msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L должен быть производного типа %qs"
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr ""
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Passed-object формальный аргумент %qs в %L должен быть скаляром"
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Passed-object формальный аргумент %qs в %L не должен быть ALLOCATABLE"
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Passed-object формальный аргумент %qs в %L не должен быть POINTER"
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Процедура %qs в %L имеет то же имя, что и компонент %qs"
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Процедура %qs в %L имеет то же имя, что и унаследованный компонент %qs"
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Производный тип %qs декларированный в %L должен быть ABSTRACT, поскольку %qs есть DEFERRED и не перебивается"
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Комассивный компонент %qs в %L должен быть размещаемым с отложенной формой"
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Компонент %qs в %L типа TYPE(C_PTR) или TYPE(C_FUNPTR) не должен быть комассивом"
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Компонент %qs в %L с комассивным компонентом должен быть неуказательным, неразмещаемым скаляром"
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Компонент %qs в %L имеет CONTIGUOUS атрибут, но не является указателем на массив"
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Компонент %qs типа BIND(C) в %L должен иметь единичную длину"
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Компонент указателя на процедуру %qs с PASS(%s) в %L не имеет аргумента %qs"
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Компонент указателя на процедуру %qs с PASS в %L должен иметь по крайней мере один аргумент"
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L должен быть производного типа %qs"
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L должен быть скаляром"
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L не может иметь POINTER атрибут"
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Аргумент %qs от %qs с PASS(%s) в %L не может быть ALLOCATABLE"
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Компонент %qs от %qs в %L имеет то же имя, что и унаследованная type-bound процедура"
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Character длина компонента %qs должна быть константным спецификационным выражением в %L"
 
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be of INTEGER type, found %s"
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "Выражение в %L должно быть INTEGER типа, найдено %s"
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Character компонент %qs от %qs в %L с отложенной длиной должен быть POINTER или ALLOCATABLE"
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "компонент %qs имеет PRIVATE тип и не может быть компонентом %qs, который PUBLIC в %L"
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Полиморфный компонент %s в %L в SEQUENCE или BIND(C) типе %s"
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Компонент %s SEQUENCE типа декларированный в %L не имеет SEQUENCE атрибут"
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Конфликтующие инициализаторы в объединении в %L и %L"
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Поскольку расширяющий тип %qs в %L имеет комассивный компонент, родительский тип %qs должен также иметь его"
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Нерасширяемый производный тип %qs в %L не должен быть ABSTRACT"
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Generic имя %qs функции %qs в %L то же, что и имя производного типа в %L"
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type %qs at %L must be extensible"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Производный тип %qs в %L должен быть расширяемым"
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Массив предполагаемого размера %qs в списке имен %qs в %L не допускается"
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST массивный объект %qs с предполагаемой формой в списке имен %qs в %L"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST массивный объект %qs с неконстантной формой в списке имен %qs в %L"
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST объект %qs с неконстантной character длиной в списке имен %qs в %L"
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST объект %qs был декларирован PRIVATE и не может быть членом PUBLIC списка имен %qs в %L"
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST объект %qs имеет use-associated PRIVATE компоненты и не может быть членом списка имен %qs в %L"
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST объект %qs имеет PRIVATE компоненты и не может быть членом PUBLIC списка имен %qs в %L"
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с NAMELIST атрибутом в %qs в %L"
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameter массив %qs at %L не может быть автоматическим или отложенной формы"
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Неявно типизированный PARAMETER %qs в %L не соответствует более позднему IMPLICIT типу"
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Несовместимый производный тип в PARAMETER в %L"
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "CLASS переменная %qs в %L не может иметь PARAMETER атрибут"
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, fuzzy, gcc-internal-format
 #| msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Сущность %qs в %L имеет параметр отложенного типа и требует либо POINTER либо ALLOCATABLE атрибут"
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Простите, размещаемые/указательные компоненты в комассивах полиморфных (CLASS) типов в %L не поддерживаются"
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "PROTECTED атрибут конфликтует с EXTERNAL атрибутом в %L"
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "PROCEDURE атрибут конфликтует с PROTECTED атрибутом в %L"
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs в %L имеет CONTIGUOUS атрибут, но не является указателем на массив или массивом предполагаемой формы или предполагаемого ранга"
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Массив предполагаемого размера в %L должен быть формальным аргументом"
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Массив предполагаемой формы в %L должен быть формальным аргументом"
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Массив предполагаемой формы в %L должен быть формальным аргументом"
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Массив предполагаемого ранга в %L не может иметь VALUE или CODIMENSION атрибут"
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Символ в %L не является DUMMY переменной"
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs в %L не может иметь VALUE атрибут, поскольку он не является формальным аргументом"
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Character формальная переменная %qs в %L с VALUE атрибутом должна иметь константную длину"
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C совместимая character формальная переменная %qs в %L с VALUE атрибутом должна иметь длину один"
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Производный тип %qs в %L имеет тип %qs, который не был определен"
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутов должна быть формальным аргументом"
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом должна быть типа TYPE(*) или числового встроенного типа"
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом не может иметь ALLOCATABLE, CODIMENSION, POINTER или VALUE атрибут"
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом не может иметь INTENT(OUT) атрибут"
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом должна быть или скаляром или массивом предполагаемого размера"
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Предполагаемый тип переменной %s в %L разрешен только для формальных переменных"
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Переменная предполагаемого типа %s в %L не может иметь ALLOCATABLE, CODIMENSION, POINTER или VALUE атрибут"
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Переменная предполагаемого типа %s в %L не может иметь INTENT(OUT) атрибут"
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Переменная предполагаемого типа %s в %L не должна быть массивом явной формы"
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Переменная %qs at %L не может быть BIND(C), поскольку она не COMMON блок и не декларирована на уровне модуля"
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs в %L PRIVATE производного типа %qs"
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Переменная %s в %L типа LOCK_TYPE или с подкомпонентом типа LOCK_TYPE должна быть комассивом"
 
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) формальный аргумент %qs в %L имеет ASSUMED SIZE и поэтому не может иметь подразумеваемый инициализатор"
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Формальный аргумент %qs в %L типа LOCK_TYPE не должен быть INTENT(OUT)"
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Формальный аргумент %qs в %L типа EVENT_TYPE не должен быть INTENT(OUT)"
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Результат функции %qs в %L не должен быть комассивом или иметь комассивный компонент"
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Переменная %qs в %L типа TYPE(C_PTR) или TYPE(C_FUNPTR) не должна быть комассивом"
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Переменная %qs в %L с комассивным компонентом должна быть неуказательным, неразмещаемым скаляром, который не есть комассив"
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Переменная %qs в %L является комассивом и не является ни ALLOCATABLE, ни SAVE, ни формальным аргументом"
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Комассивная переменная %qs в %L не должна иметь коизмерения с отложенной формой"
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Размещаемая комассивная переменная %qs в %L должна иметь отложенную форму"
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Переменная %qs в %L является INTENT(OUT) и может поэтому не быть размещаемым комассивом или иметь комассивные компоненты"
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Комассивная формальная переменная %qs в %L не допускается в BIND(C) процедуре %qs"
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL формальная переменная %qs в %L с не-C_Bool видом в BIND(C) процедуре %qs"
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL результирующая переменная %qs в %L с не-C_Bool видом в BIND(C) процедуре %qs"
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Список имен %qs не может быть аргументом для подпрограммы или функции в %L"
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate в %L не является SAVEd"
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "!$OMP DECLARE TARGET переменная %qs в %L не есть SAVEd"
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting list of named entities at %C"
 msgid "Expecting definable entity near %L"
 msgstr "Ожидается список именованных сущностей в %C"
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA элемент %qs в %L должен быть в COMMON"
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA массив %qs в %L должен быть указан в предыдущей декларации"
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA элемент %qs в %L не может иметь коиндекс"
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA элемент %qs в %L является указателем и поэтому должен быть полным массивом"
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, fuzzy, gcc-internal-format
 #| msgid "Argument %qs of elemental procedure at %L cannot have the ALLOCATABLE attribute"
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Аргумент %qs элементной процедуры в %L не может иметь ALLOCATABLE атрибут"
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Неконстантная секция массива в %L в DATA операторе"
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA оператор в %L имеет больше переменных чем значений"
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Nonconstant array section at %L in DATA statement"
 msgid "Non-constant character length at %L in DATA statement"
 msgstr "Неконстантная секция массива в %L в DATA операторе"
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "начало implied-do цикла в %L не может быть упрощено до константного значения"
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "окончание implied-do цикла в %L не может быть упрощено до константного значения"
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "шаг implied-do цикла в %L не может быть упрощен до константного значения"
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "шаг implied-do цикла в %L не может быть упрощен до константного значения"
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA оператор в %L имеет больше значений чем переменных"
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Метка %d в %L определена, но не используется"
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Метка %d в %L определена, но не может быть использована"
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Переменная производного типа %qs в %L должна иметь SEQUENCE атрибут, чтобы быть EQUIVALENCE объектом"
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Переменная производного типа %qs в %L не может иметь ALLOCATABLE компоненты, чтобы быть EQUIVALENCE объектом"
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Переменная производного типа %qs в %L с подразумеваемой инициализацией не может быть в EQUIVALENCE с переменной в COMMON"
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Переменная производного типа %qs в %L с указательным(и) компонент(ами) не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Синтаксическая ошибка в EQUIVALENCE операторе в %L"
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Все или никакие объекты в EQUIVALENCE установленной в %L должны иметь PROTECTED атрибут"
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Именованная константа %qs at %L не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Массив %qs at %L с неконстантными границами не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Компонент структуры %qs at %L не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Подстрока в %L имеет нулевую длину"
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC функция %qs в %L PRIVATE типа %qs"
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs в %L не имеет IMPLICIT тип"
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Процедура пользовательского оператора %qs в %L должна быть FUNCTION"
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Процедура пользовательского оператора %qs в %L не может быть предполагаемой character длиной"
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Процедура пользовательского оператора %qs в %L должна иметь по крайней мере один аргумент"
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Первый аргумент интерфейса оператора в %L не может быть необязательным"
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Второй аргумент интерфейса оператора в %L не может быть необязательным"
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Интерфейс оператора в %L должен иметь не более двух аргументов"
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Внутренняя процедура %qs в %L PURE процедуры должна также быть PURE"
@@ -85179,127 +85232,127 @@ msgstr "Неявно декларированная переменная %qs в
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr "Результат функции %qs в %L не имеет IMPLICIT тип"
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr "%s атрибут конфликтует с %s атрибутом в %L"
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, gcc-internal-format
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr "%s атрибут конфликтует с %s атрибутом в %qs в %L"
+
+#: fortran/symbol.cc:508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr "%s атрибут не допускается в BLOCK DATA программной единице в %L"
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "Имя NAMELIST группы в %L не может иметь SAVE атрибут"
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, gcc-internal-format
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr "внутренняя процедура %qs в %L конфликтует с DUMMY аргументом"
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "Указатель на процедуру в %C"
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "%s атрибут применен к %s %s в %L"
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) применен к %s %s в %L"
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, gcc-internal-format, gfc-internal-format
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr "%s атрибут конфликтует с %s атрибутом в %L"
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, gcc-internal-format
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr "%s атрибут конфликтует с %s атрибутом в %qs в %L"
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "Невозможно изменить атрибуты USE-associated символа в %L"
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "Невозможно изменить атрибуты USE-associated символа %s в %L"
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "Повторный %s атрибут специфицирован в %L"
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr "ALLOCATABLE специфицирован вне INTERFACE тела в %L"
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr "Повторный AUTOMATIC атрибут специфицирован в %L"
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "CODIMENSION специфицирован для %qs вне своего INTERFACE тела в %L"
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "DIMENSION специфицирован для %qs вне своего INTERFACE тела в %L"
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "Cray указуемое в %L появляется в нескольких pointer() операторах"
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "Повторный PROTECTED атрибут специфицирован в %L"
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "SAVE атрибут в %L не может быть специфицирован в PURE процедуре"
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "Повторный SAVE атрибут специфицирован в %L"
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "Повторный VALUE атрибут специфицирован в %L"
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Повторный VOLATILE атрибут специфицирован в %L"
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr "Атрибут VOLATILE в %L нельзя указать в процедуре PURE"
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Повторный атрибут ASYNCHRONOUS указан в %L"
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "Атрибут %s %qs конфликтует с атрибутом %s в %L"
 
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -85308,204 +85361,204 @@ msgstr ""
 "Процедура %s в %L уже объявлена как процедура %s \n"
 "F2008: присваивание указательной функции неоднозначно, если оно является первым выполняемым оператором блока спецификаций. Добавьте перед ним выполняемый оператор любого другого. ИСПРАВИТЬ"
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "Процедура %s в %L уже объявлена как процедура %s"
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s)  конфликтует с INTENT(%s) в %L"
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "ACCESS спецификация в %L уже была специфицирована"
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Повторный BIND атрибут специфицирован в %L"
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "BIND(C) в %L"
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Повторный EXTENDS атрибут специфицирован в %L"
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "EXTENDS в %L"
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Символ %qs в %L уже имеет явный интерфейс"
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "%qs в %L имеет атрибуты специфицированные вне своего INTERFACE тела"
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "Символ %qs в %L конфликтует с символом из модуля %qs, use-associated в %L"
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Символ %qs в %L уже имеет базовый тип %s"
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Процедура %qs в %L не может иметь базовый тип %s"
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Символ %qs в %L не может иметь тип"
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Компонент %qs в %C уже в родительском типе в %L"
 
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Символ %qs в %C неоднозначен"
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Производный тип %qs в %C используется до своего определения"
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Компонент %qs в %C есть PRIVATE компонент %qs"
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "%qs в %C не является элементом структуры %qs. Может имелось в виду %qs?"
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs в %C не является элементом структуры %qs"
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Повторная метка оператора %d в %L и %L"
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Метка %d в %C уже фигурирует как цель перехода"
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Метка %d в %C уже фигурирует как метка формата"
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr "завершающий оператор DO цикла не END DO или CONTINUE с меткой %d в %C"
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Метка %d в %C ранее использована как FORMAT метка"
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Метка %d в %C ранее использована как цель перехода"
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "Разделяемая DO терминирующая метка %d в %C"
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "LOCK statement at %C"
 msgid "Labeled DO statement at %L"
 msgstr "LOCK оператор в %C"
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Имя %qs в %C является неоднозначной ссылкой на %qs из модуля %qs"
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "Имя %qs в %C является неоднозначной ссылкой на %qs из текущей программной единицы"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Символ %qs в %C уже был host ассоциирован"
 
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr "verify_bind_c_derived_type(): Данный символ неожиданно оказался NULL"
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Производный тип %qs декларированный в %L должен иметь BIND атрибут, чтобы быть C совместимым"
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "Производный тип %qs с BIND(C) атрибутом в %L пуст и может быть недоступен для C парного процессора"
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Компонент %qs в %L не может иметь POINTER атрибут, поскольку он является элементом BIND(C) производного типа %qs в %L"
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "Компонент указатель на процедуру %qs в %L не может быть элементом BIND(C) производного типа %qs в %L"
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Компонент %qs в %L не может иметь ALLOCATABLE атрибут, поскольку он является элементом BIND(C) производного типа %qs в %L"
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "Компонент %qs в производном типе %qs в %L может не быть C совместимым хотя производный тип %qs есть BIND(C)"
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "Компонент %qs в производном типе %qs в %L может не быть C совместимым"
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Производный тип %qs в %L не может иметь SEQUENCE атрибут, поскольку он есть BIND(C)"
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "Символ %qs используется до своего типизирования в %L"
@@ -85535,24 +85588,24 @@ msgstr "Перекрывающиеся неравные инициализато
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "Перекрывающиеся неравные инициализаторы в EQUIVALENCE в %C"
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Создание временного массива в %L для аргумента %qs"
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "Некорректный тип выражения при проходе (%d)"
@@ -85745,38 +85798,38 @@ msgstr "Возвращаемое значение %qs функции %qs дек
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr "Извините, !$ACC DECLARE в %L не допускается в конструкции BLOCK"
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't compute the length of the char array at %L."
 msgid "Cannot compute the length of the char array at %L."
 msgstr "Не могу вычислить длину char массива в %L."
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr "Код для переразмещения размещаемой переменной в %L будет добавлен"
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Простите, коиндексированный доступ к неограниченному полиморфному объекту в %L не поддерживается"
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Простите, коиндексированный доступ к неограниченному полиморфному компоненту в %L не поддерживается"
 
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Неизвестная встроенная операция"
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Неизвестная функция списка аргументов в %L"
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -85787,17 +85840,17 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "Встроенная функция %qs (%d) не опознана"
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "%<dim%> аргумент встроенной функции %s в %L не есть корректный индекс измерения"
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "Простите, event компонент производного типа в %L пока не поддерживается"
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "event переменная в %L не должен быть коиндексирована"
@@ -85950,7 +86003,7 @@ msgstr "Простите, lock компонент производного ти
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr "Извините, поддержка только для integer вида %d реализована для image-set в %L"
 
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr "gfc_trans_select(): Некорректный тип для case выражения."
@@ -86334,6 +86387,11 @@ msgstr "переменная %qD повторно декларирована к
 msgid "function %qD redeclared as variable"
 msgstr "функция %qD повторно декларирована как переменная"
 
+#: lto/lto-symtab.cc:865
+#, gcc-internal-format
+msgid "previously declared here"
+msgstr "предыдущая декларация здесь"
+
 #: lto/lto.cc:174
 #, fuzzy, gcc-internal-format
 #| msgid "lto_obj_file_open() failed"
@@ -87632,7 +87690,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr "%<-fobjc-sjlj-exceptions%> игнорируется для %<-fgnu-runtime%>"
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, gcc-internal-format
 msgid "non-objective-c type %qT cannot be caught"
 msgstr ""
@@ -87643,7 +87701,7 @@ msgstr ""
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr "%<-fobjc-sjlj-exceptions%> единственная поддерживаемая система исключений для %<-fnext-runtime%> с %<-fobjc-abi-version%> < 2"
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> >= 2"
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
@@ -90127,15 +90185,9 @@ msgstr ""
 #~ msgid "Builtin function %s is only valid for the cell processor"
 #~ msgstr "Встроенная функция %s допустима только для процессора cell"
 
-#~ msgid "Builtin function %s requires the -mhtm option"
-#~ msgstr "Встроенная функция %s требует опцию -mhtm"
-
 #~ msgid "Builtin function %s requires the -maltivec option"
 #~ msgstr "Встроенная функция %s требует опцию --maltivec"
 
-#~ msgid "Builtin function %s requires the -mpaired option"
-#~ msgstr "Встроенная функция %s требует опцию --mpaired"
-
 #~ msgid "Builtin function %s requires the -mspe option"
 #~ msgstr "Встроенная функция %s требует опцию -mspe"
 
diff --git a/gcc/po/sr.po b/gcc/po/sr.po
index 38ad52fcb58..ad434e5bdaa 100644
--- a/gcc/po/sr.po
+++ b/gcc/po/sr.po
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 4.2.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
 "PO-Revision-Date: 2007-08-19 12:00+0200\n"
 "Last-Translator: Caslav Ilic <caslav.ilic@gmx.net>\n"
 "Language-Team: Serbian <gnu@prevod.org>\n"
@@ -456,7 +456,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr "не могу се задати и -C и -o"
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 msgid "shared and mdll are not compatible"
 msgstr "shared и mdll нису сагласни"
 
@@ -21300,18 +21300,18 @@ msgstr "непрепознатљива ија:"
 msgid "insn does not satisfy its constraints:"
 msgstr "ија не задовољава своја ограничења:"
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "направљено и употребљено са различитим поставкама за ‘%s’"
 
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "направљено и употребљено са различитим поставкама за -fpic"
 
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 #, fuzzy
 #| msgid "created and used with different settings of -fpie"
 msgid "created and used with different settings of %<-fpie%>"
@@ -21651,7 +21651,7 @@ msgstr "модификатор дужине у формату strfmon"
 msgid "<command-line>"
 msgstr "<командна-линија>"
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "unsupported operand for code '%c'"
@@ -21672,9 +21672,9 @@ msgstr "неисправан операнд за кôд ‘%c’"
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid vector constant"
@@ -21697,7 +21697,7 @@ msgstr "неисправан операнд за кôд ‘%c’"
 msgid "incompatible register operand for '%%%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, c-format
 msgid "missing operand"
 msgstr "недостаје операнд"
@@ -21730,93 +21730,93 @@ msgstr "неисправна адреса"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr ""
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, c-format
 msgid "invalid %%J value"
 msgstr "неисправна %%J вредност"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, c-format
 msgid "invalid %%r value"
 msgstr "неисправна %%r вредност"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, c-format
 msgid "invalid %%R value"
 msgstr "неисправна %%R вредност"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, c-format
 msgid "invalid %%N value"
 msgstr "неисправна %%N вредност"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, c-format
 msgid "invalid %%P value"
 msgstr "неисправна %%P вредност"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, c-format
 msgid "invalid %%h value"
 msgstr "неисправна %%h вредност"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, c-format
 msgid "invalid %%L value"
 msgstr "неисправна %%L вредност"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, c-format
 msgid "invalid %%m value"
 msgstr "неисправна %%m вредност"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, c-format
 msgid "invalid %%M value"
 msgstr "неисправна %%M вредност"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, c-format
 msgid "invalid %%U value"
 msgstr "неисправна %%U вредност"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, c-format
 msgid "invalid %%s value"
 msgstr "неисправна %%s вредност"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, c-format
 msgid "invalid %%C value"
 msgstr "неисправна %%C вредност"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, c-format
 msgid "invalid %%E value"
 msgstr "неисправна %%E вредност"
 
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "непознато unspec релокације"
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, c-format
 msgid "invalid %%xn code"
 msgstr "неисправан %%xn кôд"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid operand address"
@@ -21919,36 +21919,36 @@ msgstr "неисправан УНСПЕЦ као операнд"
 msgid "unrecognized supposed constant"
 msgstr "непрепозната претпостављена константа"
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, c-format
 msgid "invalid shift operand"
 msgstr "неисправан операнд помака"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "предикатна инструкција Тамба"
 
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "предикатна инструкција у условном редоследу"
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "Unsupported operand for code '%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -21956,130 +21956,130 @@ msgstr "неисправан операнд за кôд ‘%c’"
 msgid "invalid operand for code '%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, fuzzy, c-format
 #| msgid "instruction never exectued"
 msgid "instruction never executed"
 msgstr "инструкција се никад не извршава"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "неисправно претварање из %<__fpreg%>"
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "неисправно претварање у тип %qT из типа %qT"
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "адресни операнд захтева ограничење за X, Y или Z регистар"
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 #, fuzzy
 #| msgid "output operand %d must use %<&%> constraint"
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "излазни операнд %d мора користити ограничење %<&%>"
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 #, fuzzy
 #| msgid "bad address, not (reg+disp):"
 msgid "bad address, not an I/O address:"
 msgstr "лоша адреса, није (reg+disp):"
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 #, fuzzy
 #| msgid "address offset not a constant"
 msgid "bad address, not a constant:"
 msgstr "помак адресе није константа"
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 msgid "bad address, not (reg+disp):"
 msgstr "лоша адреса, није (reg+disp):"
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "лоша адреса, није post_inc или pre_dec:"
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr "унутрашња грешка компилатора. Лоша адреса:"
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 msgid "internal compiler error.  Unknown mode:"
 msgstr "унутрашња грешка компилатора. Непознат режим:"
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 msgid "invalid insn:"
 msgstr "неисправна ија:"
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 msgid "incorrect insn:"
 msgstr "нетачна ија:"
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 msgid "unknown move insn:"
 msgstr "непозната ија премештања:"
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 msgid "bad shift insn:"
 msgstr "лоша ија помака:"
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "унутрашња грешка компилатора. Нетачан помак:"
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 #, fuzzy
 #| msgid "unsupported combination: %s"
 msgid "unsupported fixed-point conversion"
 msgstr "неподржана комбинација: %s"
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 msgid "variable"
 msgstr ""
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "function parameter"
 msgstr "поновљена дефиниција параметра %q+D"
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 msgid "structure field"
 msgstr ""
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 #, fuzzy
 #| msgid "function return type cannot be function"
 msgid "return type of function"
 msgstr "повратни тип функције не може бити функција"
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 msgid "pointer"
 msgstr ""
 
@@ -22118,7 +22118,7 @@ msgstr "неочекиван операнд"
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -22455,55 +22455,55 @@ msgstr "операнд није ни константа ни условни кô
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "неисправан кôд операнда ‘%c;’"
 
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "неисправна ограничења за операнд"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, fuzzy, c-format
 #| msgid "%Hinvalid controlling predicate"
 msgid "invalid vector immediate"
 msgstr "%Hнеисправан контролишући предикат"
 
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 msgid "unknown insn mode"
 msgstr "непознат режим ије"
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr "неисправно претварање из %<__fpreg%>"
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr "неисправно претварање из %<__fpreg%>"
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr "неисправно претварање у %<__fpreg%>"
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr "неисправно претварање у тип %qT из типа %qT"
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
 msgstr ""
 
@@ -22535,7 +22535,7 @@ msgstr "неисправна операција на %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "неисправан %%P операнд"
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, c-format
 msgid "invalid %%p value"
 msgstr "неисправна %%p вредност"
@@ -22566,30 +22566,30 @@ msgstr ""
 msgid "invalid addressing mode"
 msgstr "неисправна адреса"
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, fuzzy, c-format
 #| msgid "'%s' is not a valid class name"
 msgid "'%%%c' is not a valid operand prefix"
 msgstr "‘%s’ није исправно име класе"
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, fuzzy, c-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of '%%%c'"
@@ -22622,7 +22622,7 @@ msgid "post-increment address is not a register"
 msgstr "адреса постувећања није регистар"
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 msgid "bad address"
 msgstr "лоша адреса"
 
@@ -22795,7 +22795,7 @@ msgstr "неподржана комбинација: %s"
 msgid "unsupported memory expression:"
 msgstr "очекиван је целобројни израз"
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, fuzzy, c-format
 #| msgid "invalid %%c operand"
 msgid "invalid vector operand"
@@ -22850,276 +22850,276 @@ msgstr ""
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "лоша проба"
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%A value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%D value"
 msgstr "неисправна %%D вредност"
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, c-format
 msgid "invalid %%f value"
 msgstr "неисправна %%f вредност"
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, c-format
 msgid "invalid %%F value"
 msgstr "неисправна %%F вредност"
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, c-format
 msgid "invalid %%G value"
 msgstr "неисправна %%G вредност"
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, c-format
 msgid "invalid %%j code"
 msgstr "неисправан %%j кôд"
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, c-format
 msgid "invalid %%J code"
 msgstr "неисправан %%J кôд"
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, c-format
 msgid "invalid %%k value"
 msgstr "неисправна %%k вредност"
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, c-format
 msgid "invalid %%K value"
 msgstr "неисправна %%K вредност"
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, c-format
 msgid "invalid %%O value"
 msgstr "неисправна %%O вредност"
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, c-format
 msgid "invalid %%q value"
 msgstr "неисправна %%q вредност"
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, c-format
 msgid "invalid %%T value"
 msgstr "неисправна %%T вредност"
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, c-format
 msgid "invalid %%u value"
 msgstr "неисправна %%u вредност"
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, c-format
 msgid "invalid %%v value"
 msgstr "неисправна %%v вредност"
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, c-format
 msgid "invalid %%x value"
 msgstr "неисправна %%x вредност"
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "неисправна интерпункција %qc у ограничењу"
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "алтивек аргумент прослеђен непрототипизираној функцији"
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Не стварај јединствену излазну тачку за сваку функцију"
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "не могу да створим поновљена учитавања за:"
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "неисправно претварање из %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "неисправно претварање у %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "неисправно претварање из %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "неисправно претварање у %<__fpreg%>"
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, c-format
 msgid "cannot decompose address"
 msgstr "не могу да разложим адресу"
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "неисправан операнд за модификатор ‘b’"
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid reference for 'J' output modifier"
 msgstr "неисправан операнд за модификатор ‘b’"
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, fuzzy, c-format
 #| msgid "invalid operand for 'O' modifier"
 msgid "invalid address for 'O' output modifier"
 msgstr "неисправан операнд за модификатор ‘O’"
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'R' output modifier"
 msgstr "неисправан операнд за модификатор ‘b’"
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'S' output modifier"
 msgstr "неисправан операнд за модификатор ‘b’"
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant for output modifier '%c'"
 msgstr "неисправан операнд за модификатор ‘o’"
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, fuzzy, c-format
 #| msgid "invalid operand output code"
 msgid "invalid constant - try using an output modifier"
 msgstr "неисправан кôд излаза операнада"
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "неисправан операнд за модификатор ‘o’"
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid expression - try using an output modifier"
 msgstr "неисправан израз као операнд"
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid expression for output modifier '%c'"
 msgstr "неисправан операнд за модификатор ‘o’"
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "алтивек аргумент прослеђен непрототипизираној функцији"
 
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "циљеви показивача у повратку разликују се у означености"
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -23322,12 +23322,12 @@ msgstr "<анонимно>"
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "очекивано је %<;%>"
@@ -23340,7 +23340,7 @@ msgstr "очекивано је %<;%>"
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -23349,7 +23349,7 @@ msgstr "очекивано је %<;%>"
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -23358,7 +23358,7 @@ msgstr "очекивано је %<{%>"
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -23372,30 +23372,30 @@ msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "очекивано је %<(%>"
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
 msgstr "очекивано је %<{%>"
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "очекивано је %<{%>"
@@ -23405,18 +23405,18 @@ msgstr "очекивано је %<{%>"
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
@@ -23426,8 +23426,8 @@ msgstr "очекивано је %<{%>"
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -23440,19 +23440,19 @@ msgid "expected %<.%>"
 msgstr "очекивано је %<{%>"
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -23461,34 +23461,34 @@ msgstr "очекивано је %<,%> или %<;%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "очекивано је %<=%>"
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<else%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "очекивано је %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr ""
 
@@ -23498,7 +23498,7 @@ msgstr ""
 msgid "(anonymous)"
 msgstr "<анонимно>"
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -23517,13 +23517,13 @@ msgstr "Очекивано је име"
 msgid "candidate:"
 msgstr "кандидат 1:"
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 #, fuzzy
 #| msgid "type %qs has a user-defined constructor"
 msgid "  after user-defined conversion:"
 msgstr "тип %qs има кориснички дефинисан конструктор"
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -23533,11 +23533,11 @@ msgstr[1] "кандидат 1:"
 msgstr[2] "кандидат 1:"
 msgstr[3] "кандидат 1:"
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr "кандидат 1:"
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr "кандидат 2:"
 
@@ -23823,7 +23823,7 @@ msgstr ""
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 msgid "candidates are:"
 msgstr "кандидати су:"
 
@@ -23881,50 +23881,50 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "погрешан тип аргумента уз унарно минус"
 
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "погрешан тип аргумента уз унарно плус"
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "погрешан тип аргумента уз битски комплемент"
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "погрешан тип аргумента за abs"
 
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "погрешан тип аргумента за конјугацију"
 
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "погрешан тип аргумента уз унарно плус"
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -24007,7 +24007,7 @@ msgstr ""
 msgid "Deleted feature:"
 msgstr ""
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 #, fuzzy
 #| msgid "Array assignment"
 msgid "array assignment"
@@ -24208,11 +24208,11 @@ msgstr "блоковско IF"
 msgid "implied END DO"
 msgstr "имплицитно END DO"
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 msgid "assignment"
 msgstr "додела"
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 msgid "pointer assignment"
 msgstr "додела показивача"
 
@@ -24411,59 +24411,59 @@ msgstr "Операнд корисничког оператора ‘%s’ код
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнди корисничког оператора ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "iterator variable"
 msgstr "Изврши праћење променљивих"
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "неисправан израз као операнд"
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE "
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "ALLOCATE "
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -24472,11 +24472,11 @@ msgstr ""
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr ""
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
@@ -24491,12 +24491,12 @@ msgstr ""
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 #, fuzzy
 #| msgid "assignment of read-only location"
 msgid "Assignment of scalar to unallocated array"
@@ -24507,84 +24507,84 @@ msgstr "додела само-за-читање локацији"
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, c-format
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, fuzzy, c-format
 #| msgid "Argument NCOPIES of REPEAT intrinsic is negative"
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Аргумент NCOPIES уз сопствено REPEAT негативан је"
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 #, fuzzy
 #| msgid "Argument NCOPIES of REPEAT intrinsic is negative"
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "Аргумент NCOPIES уз сопствено REPEAT негативан је"
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, c-format
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, c-format
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
@@ -24610,15 +24610,15 @@ msgstr "Додељена етикета није етикета циља"
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 msgid "Loop variable has been modified"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 msgid "DO step value is zero"
 msgstr ""
 
@@ -24704,7 +24704,7 @@ msgid "expected boolean type"
 msgstr "Очекиван је тип израза"
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -24786,7 +24786,7 @@ msgstr "без аргумената"
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments for format"
 msgid "too many arguments"
@@ -25530,7 +25530,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Синтаксна грешка у наредби %s код %C"
@@ -26021,8 +26021,8 @@ msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration here"
@@ -26042,7 +26042,7 @@ msgstr "атрибутска директива %qs игнорисана"
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr "атрибутска директива %qs игнорисана"
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments specified for %qE attribute"
@@ -26054,7 +26054,7 @@ msgstr "погрешан број аргумената наведне за ат
 msgid "expected %i or more, found %i"
 msgstr "очекивано је %<(%> или крај линије"
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %i, found %i"
@@ -26124,12 +26124,12 @@ msgstr "атрибути типа игноришу се пошто је тип 
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -26138,7 +26138,7 @@ msgstr "атрибути типа игноришу се пошто је тип 
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -26160,8 +26160,8 @@ msgstr "атрибут %qE се игнорише"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %qD"
@@ -26286,7 +26286,7 @@ msgstr "не могу да нађем датотеку за класу %s"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "померај ван граница константне ниске"
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qE declared here"
@@ -26403,7 +26403,7 @@ msgstr "недостаје аргумент за „%s“"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
@@ -26427,46 +26427,46 @@ msgstr "%<__builtin_longjmp%> други аргумент мора бити 1"
 msgid "target format does not support infinity"
 msgstr "циљни формат не подржава бесконачност"
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, fuzzy, gcc-internal-format
 #| msgid "%<va_start%> used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> употребљено у функцији са фиксним аргументима"
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %<va_start%>"
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "премало аргумената за функцију %<va_start%>"
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> позвано без аргумената"
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %<va_start%>"
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "премало аргумената за функцију %<va_start%>"
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "други параметар за %<va_start%> није последњи именовани аргумент"
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr "%Hпрви аргумент за %D мора бити показивач, а други целобројна константа"
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, fuzzy, gcc-internal-format
 #| msgid "%Hlast argument of %D is not integer constant between 0 and 3"
 msgid "last argument of %qD is not integer constant between 0 and 3"
@@ -27585,12 +27585,12 @@ msgstr "атрибут %qE се игнорише јер је %qT већ дефи
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F употребљено али недефинисано"
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
@@ -28193,7 +28193,7 @@ msgstr "низ не одговара стаблу области"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "низ не одговара стаблу области"
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, gcc-internal-format
 msgid "%qs failed"
 msgstr ""
@@ -28223,19 +28223,19 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "call to %qs declared with attribute error: %s"
 msgstr "функција %q+D поново декларисана са атрибутом неуткане"
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "call to %qs declared with attribute warning: %s"
 msgstr "функција %q+D поново декларисана са атрибутом неуткане"
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, fuzzy, gcc-internal-format
 #| msgid "assuming signed overflow does not occur when simplifying range test"
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
@@ -28276,7 +28276,7 @@ msgstr "велики целобројни имплицитно подсечен
 msgid "comparison is always %d due to width of bit-field"
 msgstr "поређење је увек %d услед ширине битског поља"
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "претпостављам да се означено преливање не дешава при упрошћавању пробе опсега"
@@ -28465,7 +28465,7 @@ msgstr "нисам успео да добавим времена процеса"
 msgid "%s signal terminated program %s"
 msgstr "Користи алтернативна имена регистара"
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized command-line option %qs"
@@ -28757,7 +28757,7 @@ msgstr "вишебиб. навод ‘%s’ није исправан"
 msgid "multilib exclusions %qs is invalid"
 msgstr "вишебиб. искључење ‘%s’ није исправно"
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, fuzzy, gcc-internal-format
 #| msgid "multilib select '%s' is invalid"
 msgid "multilib select %qs %qs is invalid"
@@ -29088,23 +29088,23 @@ msgstr ""
 msgid "%qD specified bound %E equals source length"
 msgstr ""
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, gcc-internal-format
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr ""
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr ""
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "%s not supported for variable length aggregates"
 msgstr "%s није подржано за угњеждене функције"
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%s not supported on this target"
@@ -29148,16 +29148,16 @@ msgid "function returns address of local variable"
 msgstr "функција враћа адресу на локалну променљиву"
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, fuzzy, gcc-internal-format
@@ -29170,27 +29170,27 @@ msgstr "%q+D декларисано овде"
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -29199,7 +29199,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
@@ -29208,7 +29208,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
@@ -29217,67 +29217,67 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
@@ -29286,7 +29286,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -29295,7 +29295,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -29304,122 +29304,122 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, gcc-internal-format
 msgid "referenced argument declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
@@ -29428,23 +29428,23 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "directive argument %qE"
 msgstr "неисправан аргумент опције %qs"
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgid_plural "%qE output %wu bytes into a destination of size %wu"
@@ -29453,22 +29453,22 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
@@ -29477,36 +29477,36 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 msgid "%qE argument %Z overlaps destination object %qE"
 msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] ""
@@ -29514,7 +29514,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 msgid "%qE argument %Z may overlap destination object %qE"
 msgid_plural "%qE arguments %Z may overlap destination object %qE"
 msgstr[0] ""
@@ -29522,38 +29522,38 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, gcc-internal-format
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, fuzzy, gcc-internal-format
 #| msgid "Maintain backchain pointer"
 msgid "null destination pointer"
 msgstr "Одржавај показивач контраланца"
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, fuzzy, gcc-internal-format
 #| msgid "%s in format string at %C"
 msgid "null format string"
@@ -30317,12 +30317,12 @@ msgstr "неисправан режим показивача %qs"
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -31154,7 +31154,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid use of attribute %<fallthrough%>"
@@ -31524,17 +31524,17 @@ msgstr ""
 msgid "mismatching definition"
 msgstr "недостаје дефиниција"
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr ""
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, gcc-internal-format
 msgid "IPA modref summary is missing in input file"
 msgstr ""
@@ -32667,82 +32667,82 @@ msgstr "грешка при упису у %s: %m"
 msgid "error closing optimization records %qs"
 msgstr "Изврши оптимизацију за укрштање скокова"
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, fuzzy, gcc-internal-format
 #| msgid "command line option %qs is not supported by this configuration"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "опција командне линије %qs није подржана овом конфигурацијом"
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"%s\""
 msgid "missing argument to %qs"
 msgstr "недостаје аргумент за „%s“"
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr "аргумент за „%s“ треба да је ненегативан цео број"
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "argument to %qs should be a non-negative integer"
 msgstr "аргумент за „%s“ треба да је ненегативан цео број"
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "argument to %qs is not between %d and %d"
 msgstr "-mregparm=%d није између 0 и %d"
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid argument in option %qs"
 msgstr "неисправан аргумент типа за %qs"
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr ""
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, gcc-internal-format
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr ""
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized argument in option %qs"
 msgstr "непрепозната опција командне линије „%s“"
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "Неисправан тип аргумента %qs за %qs"
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "valid arguments to %qs are: %s"
 msgstr "Неисправан тип аргумента %qs за %qs"
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "прекидач %qs више није подржан"
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qs is bigger than %d"
 msgstr "аргумент за атрибут %qs већи од %d"
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, gcc-internal-format
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
 msgstr ""
@@ -32824,8 +32824,8 @@ msgstr "аргумент за „%s“ треба да је ненегатива
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%qs is incompatible with %qs"
@@ -33599,7 +33599,7 @@ msgstr "глобална регистарска променљива прати
 msgid "register of %qD used for multiple global register variables"
 msgstr "регистар се користи за две глобалне регистарске променљиве"
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, fuzzy, gcc-internal-format
 #| msgid "  conflict with %q+D"
 msgid "conflicts with %qD"
@@ -34076,47 +34076,47 @@ msgstr ""
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "__builtin_saveregs није подржано овим циљем"
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "-fdata-sections није подржано за овај циљ"
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, fuzzy, gcc-internal-format
 #| msgid "global destructors not supported on this target"
 msgid "nested functions not supported on this target"
 msgstr "глобални деструктори нису подржани на овом циљу"
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, fuzzy, gcc-internal-format
 #| msgid "-ffunction-sections not supported for this target"
 msgid "nested function trampolines not supported on this target"
 msgstr "-ffunction-sections није подржано за овај циљ"
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "глобални конструктори нису подржани на овом циљу"
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "глобални деструктори нису подржани на овом циљу"
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "атрибут %qE није подржан на овој платформи"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attributes are not supported for this target"
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "%Jатрибути одељка нису подржани за овај циљ"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma extern_prefix not supported on this target"
 msgid "%<#pragma GCC target%> is not supported for this machine"
@@ -35359,89 +35359,89 @@ msgstr "Последња наредба у об. %i има неисправно
 msgid "BB %i has incorrect fallthru edge"
 msgstr "погрешна ија у пропадном потегу"
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it receives a non-local goto"
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr "функција %q+F се не може уткати јер прима нелокално goto"
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses variable sized variables"
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr "функција %q+F се не може уткати јер користи променљиве променљиве величине"
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr "функција %q+F се не може уткати јер користи alloca (потисните атрибутом always_inline)"
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr "функција %q+F се не може уткати јер користи setjmp"
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr "функција %q+F се не може уткати јер користи променљиву листу аргумената"
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr "функција %q+F се не може уткати јер користи јер користи руковање изузецима типа setjmp-longjmp"
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr "функција %q+F се не може уткати јер користи нелокално goto"
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses __builtin_return or __builtin_apply_args"
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr "функција %q+F се не може уткати јер користи __builtin_return или __builtin_apply_args"
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr "функција %q+F се не може уткати јер користи рачунско goto"
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr "функција %q+F се не може уткати јер користи променљиву листу аргумената"
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it is suppressed using -fno-inline"
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr "функција %q+F не може никако бити уткана јер је то сузбијено помоћу -fno-inline"
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr "функција %q+F не може никако бити уткана јер користи атрибуте сукобљене са уткивањем"
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, fuzzy, gcc-internal-format
 #| msgid "inlining failed in call to %q+F: %s"
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr "уткивање није успело у позиву %q+F: %s"
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr "позвано одавде"
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, fuzzy, gcc-internal-format
 #| msgid "from this location"
 msgid "called from this function"
 msgstr "на овој локацији"
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, gcc-internal-format
 msgid "inlining failed in call to %q+F: %s"
 msgstr "уткивање није успело у позиву %q+F: %s"
@@ -35501,29 +35501,29 @@ msgstr "неисправан тип вектора за атрибут %qE"
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr "неисправан тип вектора за атрибут %qE"
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "in a call to non-static member function %qD"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "in a call to built-in function %qD"
 msgstr "позив не-функције %qD"
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, fuzzy, gcc-internal-format
 #| msgid "no member function %qD declared in %qT"
 msgid "in a call to function %qD declared %qs"
@@ -35753,7 +35753,7 @@ msgstr "%H%qE није успостављено"
 msgid "%qs may be used uninitialized"
 msgstr "%H%qD у овој функцији може бити бити употребљено неуспостављено"
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "%qD was declared here"
@@ -35994,7 +35994,7 @@ msgstr ""
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -36009,136 +36009,136 @@ msgstr ""
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "низови функција немају смисла"
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "повратни тип функције не може бити функција"
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "провера стабла: %s, имам %s у %s, код %s:%d"
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "провера стабла: не очекивах ниједно од %s, имам %s у %s, код %s:%d"
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "провера стабла: очекивах класу %qs, имам %qs (%s) у %s, код %s:%d"
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "провера стабла: нисам очекивао класу %qs, имам %qs (%s) у %s, код %s:%d"
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr "провера стабла: очекивах omp_clause %s, имам %s у %s, код %s:%d"
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: expected tree that contains %qs structure, have %qs  in %s, at %s:%d"
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "провера стабла: очекивах стабло које садржи структуру %qs, имам %qs у %s, код %s:%d"
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr "провера стабла: приступих елту %d у tree_vec са %d елтова у %s, код %s:%d"
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr "провера стабла: приступих елту %d у tree_vec са %d елтова у %s, код %s:%d"
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "провера стабла: приступих операнду %d од %s са %d операнада у %s, код %s:%d"
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "провера стабла: приступих операнду %d од omp_clause %s са %d операнада у %s, код %s:%d"
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated: %s"
 msgstr "%qs је превазиђено"
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated"
 msgstr "%qs је превазиђено"
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated: %s"
 msgstr "%qs је превазиђено"
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated"
 msgstr "%qs је превазиђено"
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type is deprecated"
 msgid "type is deprecated: %s"
 msgstr "тип је превазиђен"
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "тип је превазиђен"
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is unavailable: %s"
 msgstr "%qD није променљива у одредби %qs"
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%qD is unavailable"
 msgstr "%q+#D није приступно"
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is unavailable: %s"
 msgstr "%qE није променљива у одредби %qs"
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a template"
 msgid "%qE is unavailable"
 msgstr "%qE није шаблон"
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, gcc-internal-format, gfc-internal-format
 msgid "type is unavailable: %s"
 msgstr ""
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, gcc-internal-format
 msgid "type is unavailable"
 msgstr ""
@@ -36163,268 +36163,268 @@ msgstr ""
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "type is not compatible with its variant"
 msgstr "тврдња: %s је доделом сагласно са %s"
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qT is not a template type"
 msgid "type %s is not an opaque type"
 msgstr "%qT није шаблонски тип"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "type %s is not with opaque mode"
 msgstr "тип %qT није непосредна основа од %qT"
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr ""
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr ""
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "main variant is not defined"
 msgstr "променљива окружења DJGPP није дефинисана"
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "величина низа %qs има нецелобројни тип"
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has an incomplete type"
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "%qD има непотпун тип"
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -36662,7 +36662,7 @@ msgstr "%Jдефиниције алијаса нису подржане у ов
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "атрибут видљивости није подржан у овој конфигурацији, игноришем"
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr ""
@@ -36891,7 +36891,7 @@ msgstr "атрибут %qE се игнорише јер је %qT већ дефи
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "атрибут %qE се игнорише јер је %qT већ дефинисан"
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "атрибут %qE има утицаја само у јавним објектима"
@@ -37096,7 +37096,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr "атрибут %qs примењује се само на променљиве"
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for local variables"
@@ -37458,7 +37458,7 @@ msgstr "%qD није декларисано у %qD"
 msgid "%qE argument is not a function"
 msgstr "чистачки аргумент није функција"
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "deprecated message is not a string"
@@ -38007,7 +38007,7 @@ msgstr "ИСО Ц++ забрањује примену %<__alignof%> на изр
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr "new се не може применити на функцијиски тип"
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, gcc-internal-format
 msgid "invalid application of %qs to a void type"
 msgstr "неисправна примена %qs на празан тип"
@@ -38148,17 +38148,17 @@ msgstr ""
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "премало аргумената за функцију %qE"
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, gcc-internal-format
@@ -38298,133 +38298,133 @@ msgstr "покушај узимања адресе битског поља %qD 
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of array is too large"
 msgstr "величина низа %qs је превелика"
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "несагласни тип за аргумент %d у %qE"
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "прослеђивање аргумента %d од %qE прави показивач од целобројног без претапања"
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, fuzzy, gcc-internal-format
 #| msgid "types are not quite compatible"
 msgid "both arguments must be compatible"
 msgstr "типови нису сасвим сагласни"
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "incorrect number of arguments to function %qE"
 msgstr "премало аргумената за функцију %qE"
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "аргумент за %qs мора бити двобитна неозначена константа"
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr "аритметика са показивачем на непотпун тип"
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "%Hпрви аргумент за %D мора бити показивач, а други целобројна константа"
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "%Hпрви аргумент за %D мора бити показивач, а други целобројна константа"
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE from incompatible pointer type"
 msgid "argument %d of %qE must be a pointer type"
 msgstr "прослеђивање аргумента %d од %qE из несагласног показивачког типа"
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "аргумент %d од %qE може бити кандидат за форматски атрибут"
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "прослеђивање аргумента %d од %qE прави целобројни од показивача без претапања"
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "size mismatch in argument %d of %qE"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr "прослеђивање аргумента %d од %qE прави целобројни од показивача без претапања"
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr "прослеђивање аргумента %d од %qE одбацује одредбе са циљног типа показивача"
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr "аргумент %d од %qE може бити кандидат за форматски атрибут"
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr "прослеђивање аргумента %d од %qE одбацује одредбе са циљног типа показивача"
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "non-integer memory model argument %d of %qE"
 msgstr "несагласни тип за аргумент %d у %qE"
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid memory model argument %d of %qE"
 msgstr "неисправан аргумент типа за %qs"
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, fuzzy, gcc-internal-format
 #| msgid "index in dimension %d is out of bounds at %L"
 msgid "index value is out of bound"
 msgstr "Индекс у димензији %d је ван граница код %L"
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qT to vector %qT involves truncation"
@@ -38432,59 +38432,59 @@ msgstr "двосмислено претварање из %qT у %qT"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "built-in function %qE must be directly called"
 msgstr "уткана функција %q+D употребљена али недефинисана"
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "size of array %qE is not a constant expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array is not a constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "величина низа %qs је негативна"
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "негативна величина низа"
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "величина низа %qs је негативна"
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -39152,7 +39152,7 @@ msgstr "целобројна константа превелика за тип %
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr "целобројна константа превелика за тип %qs"
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<_BitInt(%d)%> is not supported on this target"
@@ -39238,7 +39238,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr "традиционални Ц одбија надовезивање константних ниски"
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -39294,7 +39294,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "invalid type for iteration variable %qE"
@@ -39312,19 +39312,19 @@ msgstr "%Hнеисправан тип променљиве итерације %q
 msgid "%qE is not initialized"
 msgstr "%H%qE није успостављено"
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmissing controlling predicate"
 msgid "missing controlling predicate"
 msgstr "%Hнедостаје контролишући предикат"
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid controlling predicate"
 msgid "invalid controlling predicate"
 msgstr "%Hнеисправан контролишући предикат"
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmissing increment expression"
 msgid "missing increment expression"
@@ -39335,7 +39335,7 @@ msgstr "%Hнедостаје израз увећања"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid increment expression"
 msgid "invalid increment expression"
@@ -39428,7 +39428,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -39439,7 +39439,7 @@ msgstr ""
 msgid "%qD is not a function argument"
 msgstr "%qD није шаблон функције"
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
@@ -40093,7 +40093,7 @@ msgid "wrong type argument to %s"
 msgstr "погрешан тип аргумента за abs"
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -41130,35 +41130,35 @@ msgstr "поређење између %q#T и %q#T"
 
 #: c-family/c-warn.cc:3832
 #, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3836
+#: c-family/c-warn.cc:3839
 #, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr ""
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr ""
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr ""
@@ -41389,117 +41389,117 @@ msgstr "-mregparm=%d није између 0 и %d"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, gcc-internal-format
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, gcc-internal-format
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, gcc-internal-format
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, gcc-internal-format
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr ""
@@ -41935,12 +41935,12 @@ msgstr ""
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr ""
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr ""
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of #pragma GCC java_exceptions"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
@@ -42569,7 +42569,7 @@ msgstr ""
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
@@ -42650,12 +42650,12 @@ msgid "unknown tuning option (%s)"
 msgstr "непозната функција навода ‘%s’"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
@@ -42667,7 +42667,7 @@ msgid "specify a system register with a small string length"
 msgstr "Одредите редослед резервисања регистара"
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
@@ -42858,9 +42858,9 @@ msgstr ""
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
@@ -42916,19 +42916,19 @@ msgid "virtual function multiversioning not supported"
 msgstr "израз ограничења стека није подржан"
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "__builtin_eh_return није подржан на овом циљу"
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
@@ -42941,8 +42941,8 @@ msgstr ""
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %wd"
@@ -42954,7 +42954,7 @@ msgstr "неподржана комбинација: %s"
 msgid "GCC does not currently support return type %qT for simd"
 msgstr "-fPIC тренутно није подржано на 68000 и 68010"
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
@@ -42965,7 +42965,7 @@ msgstr ""
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr "-fPIC тренутно није подржано на 68000 и 68010"
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "unsupported argument type %qT for simd"
@@ -43067,8 +43067,8 @@ msgstr "Кашњење L%d оставе непознато за %s"
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "лоша вредност %qs за -mmemory-latency"
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr "лош уграђени fcode"
@@ -43199,18 +43199,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "аргумент атрибута %qs није „ilink1“ или „ilink2“"
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -43334,7 +43334,7 @@ msgid "argument of %qE attribute is missing"
 msgstr "аргумент атрибута %qs није константна ниска"
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute allows only an integer constant argument"
@@ -43358,24 +43358,24 @@ msgstr "атрибут %qs је примењив само на функцијс
 msgid "argument of %qE attribute ignored"
 msgstr "атрибут %qE се игнорише"
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only applies to variables"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr ""
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid type for %<asm%> flag output"
@@ -43637,7 +43637,7 @@ msgstr "циљни ЦПУ не подржава инструкције Тамб
 msgid "target CPU does not support unaligned accesses"
 msgstr "циљни ЦПУ не подржава интерворкинг"
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -43694,7 +43694,7 @@ msgstr "граница величине структура може бити п
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "%<-G%> није сагласно са %<-mabicalls%>"
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
@@ -43809,7 +43809,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -43853,44 +43853,44 @@ msgstr "атрибут %qE има утицаја само у јавним обј
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "атрибут %qs је примењив само на функцијске типове"
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "не могу да срачунам стварну локацију параметра на стеку"
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Неочекиван крај модула"
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "нема доступних ниских регистара за подизање високих регистара"
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "сервисне рутине прекида не могу бити кодиране у режиму Тамба"
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -43899,24 +43899,24 @@ msgstr "неисправан тип вектора за атрибут %qE"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "неисправан тип вектора за атрибут %qE"
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "непознато име регистра: %s"
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "%<asm%> flags not supported in thumb1 mode"
@@ -43978,173 +43978,173 @@ msgstr ""
 msgid "unknown core architecture %qs specified with %qs"
 msgstr "нема имена класе наведеног помоћу %qs"
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "%<-fpic%> is not supported"
 msgstr "-pipe није подржано"
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "%<-fPIC%> is not supported"
 msgstr "-pipe није подржано"
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "%<-fpie%> is not supported"
 msgstr "-pipe није подржано"
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe није подржано"
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, fuzzy, gcc-internal-format
 #| msgid "-G and -static are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-G и -static су међусобно искључиви"
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have arguments"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, fuzzy, gcc-internal-format
 #| msgid "Function does not return a value"
 msgid "%qs function cannot return a value"
 msgstr "Функција не враћа вредност"
 
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, fuzzy, gcc-internal-format
 #| msgid "%qs appears to be a misspelled signal handler"
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs изгледа као погрешно написан руковалац сигналима"
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, gcc-internal-format
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Number of registers used to pass integer arguments"
 msgid "fixed register %s used to pass parameter to function"
 msgstr "Број регистара који се користи за прослеђивање целобројних аргумената"
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D not supported"
 msgid "writing to address space %qs not supported"
 msgstr "слаба декларација %q+D није подржана"
 
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variadic functions"
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "атрибут %qE је примењив само на варијадичке функције"
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, gcc-internal-format
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr ""
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute on non-volatile variable"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr ""
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr ""
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, gcc-internal-format
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr ""
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, gcc-internal-format
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, fuzzy, gcc-internal-format
 #| msgid "only uninitialized variables can be placed in the .noinit section"
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr "само неуспостављене променљиве могу се сместити у одељак .noint"
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, fuzzy, gcc-internal-format
 #| msgid "only initialized variables can be placed into program memory area"
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr "само успостављене променљиве могу се сместити у меморијску област програма"
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, fuzzy, gcc-internal-format
 #| msgid "only initialized variables can be placed into program memory area"
 msgid "uninitialized variable %q+D put into program memory area"
@@ -44154,48 +44154,48 @@ msgstr "само успостављене променљиве могу се с
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD may not have been initialized"
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr "променљива %qD можда није успостављена"
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%qs несагласан атрибут игнорисан"
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, fuzzy, gcc-internal-format
 #| msgid "MCU %qs supported for assembler only"
 msgid "architecture %qs supported for assembler only"
 msgstr "МЦУ %qs подржан само за асемблер"
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "conversion from address space %qs to address space %qs"
 msgstr "Претварање из %s у %s код %L"
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of module in string constant"
 msgid "%s expects a compile time integer constant"
 msgstr "Неочекиван крај модула у константној ниски"
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -44351,7 +44351,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "Уткане функције Ц-а 99 нису подржане; користим Гну 89"
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, fuzzy, gcc-internal-format
@@ -45049,8 +45049,8 @@ msgstr "аргумент за %qs мора бити двобитна неозн
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %s does not support PIC mode"
@@ -45124,278 +45124,278 @@ msgstr "нема имена класе наведеног помоћу %qs"
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-битни АБИ није подржан у режиму ЕСЕ/390"
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, fuzzy, gcc-internal-format
 #| msgid "-mtune=x86-64 is deprecated.  Use -mtune=k8 or -mtune=generic instead as appropriate."
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "-mtune=x86-64 је превазиђено. Користите -mtune=k8 или -mtune=generic уместо тога."
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, fuzzy, gcc-internal-format
 #| msgid "-mtune=x86-64 is deprecated.  Use -mtune=k8 or -mtune=generic instead as appropriate."
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "-mtune=x86-64 је превазиђено. Користите -mtune=k8 или -mtune=generic уместо тога."
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "-mcmodel= није подржано на 32-битним системима"
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr "-fdata-sections није подржано за овај циљ"
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mcmodel= није подржано на 32-битним системима"
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "модела кôда %qs није подржан у %s-битном режиму"
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "модела кôда %qs није подржан у %s-битном режиму"
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "модела кôда %s није подржан у ПИЦ режиму"
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-m%s није подржано у овој конфигурацији"
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-битни режим није укомпилован"
 
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "ЦПУ који сте изабрали не подржава скуп инструкција икс86-64"
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "лоша вредност (%s) за прекидач -march="
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "лоша вредност (%s) за прекидач -march="
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "лоша вредност (%s) за прекидач -march="
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "лоша вредност (%s) за прекидач -mtune="
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "лоша вредност (%s) за прекидач -mtune="
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument %qs for %<instanceof%>"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "Неисправан аргумент %qs за %<instanceof%>"
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d није између 0 и %d"
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, fuzzy, gcc-internal-format
 #| msgid "-mrtd calling convention not supported in the 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "конвенција позивања -mrtd није подржана у 64-битном режиму"
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr ""
@@ -45403,318 +45403,318 @@ msgstr ""
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr ""
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "-fprefetch-loop-arrays није подржано за овај циљ"
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d није између %d и 12"
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d није између %d и 12"
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-march=%s није сагласно са изабраним АБИјем"
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "унутармодулске оптимизације нису имплеметиране за Ц++"
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "-msseregparm употребљено без укључених ССЕ инструкција"
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "-msseregparm употребљено без укључених ССЕ инструкција"
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "скуп ССЕ инструкција искључен, користим 387 аритметику"
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "скуп 387 инструкција искључен, користим ССЕ аритметику"
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "табеле одмотавања тренутно захтевају или показивач оквира или -maccumulate-outgoing-args за исправност"
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "табеле одмотавања тренутно захтевају или показивач оквира или -maccumulate-outgoing-args за исправност"
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring unknown option %q.*s in %<-fdump-%s%>"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "игноришем непознату опцију %q.*s у %<-fdump-%s%>"
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr ""
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-protector not supported for this target"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-fstack-protector није подржано за овај циљ"
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "атрибути stdcall и cdecl нису сагласни"
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "атрибути stdcall и cdecl нису сагласни"
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s и -mcall-%s нису сагласни"
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s и -mcall-%s нису сагласни"
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "атрибути fastcall и regparm нису сагласни"
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "аргумент за атрибут %qs већи од %d"
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "атрибути fastcall и cdecl нису сагласни"
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "атрибути stdcall и cdecl нису сагласни"
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "атрибут %qE се игнорише на не-класним типовима"
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "%qs несагласан атрибут игнорисан"
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires a string constant argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "сервисне рутине прекида не могу бити кодиране у режиму Тамба"
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
@@ -45922,48 +45922,48 @@ msgstr "неподржана величина операнда за прошир
 msgid "non-integer operand used with operand code %<z%>"
 msgstr ""
 
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, fuzzy, gcc-internal-format
 #| msgid "no low registers available for popping high registers"
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr "нема доступних ниских регистара за подизање високих регистара"
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "модела кôда %<large%> још увек није подржан"
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr ""
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, fuzzy, gcc-internal-format
 #| msgid "%<-G%> is incompatible with %<-mabicalls%>"
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
@@ -45987,8 +45987,8 @@ msgstr "дефиниција статичког чланског податка
 msgid "malformed %<#pragma builtin%>"
 msgstr "лоше формирано уграђено #pragma"
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid argument of %qE attribute"
@@ -46052,13 +46052,13 @@ msgstr "PRINT_OPERAND: Непозната интерпункција „%c“"
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr "PRINT_OPERAND нулти показивач"
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "аргумент 1 за __builtin_spe_predicate мора бити константа"
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, fuzzy, gcc-internal-format
 #| msgid "failed to reclaim unneeded function"
 msgid "failed to expand built-in function"
@@ -46190,19 +46190,19 @@ msgstr "тврдња: %s је доделом сагласно са %s"
 msgid "%qs cannot be used for compiling a shared library"
 msgstr "%s се не може користити овде у асемблеру"
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr "%Jатрибут одељка се не може навести за локалне променљиве"
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for register variables"
 msgstr "%Jатрибут одељка се не може навести за локалне променљиве"
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "multiple %qE attribute"
@@ -46320,12 +46320,12 @@ msgstr "наведени вишеструки атрибути типа функ
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "израз ограничења стека није подржан"
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-fexcess-precision=16%> is not supported on this target"
@@ -46368,7 +46368,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr ""
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires a single NTBS argument"
 msgid "%qE attribute requires a string argument"
@@ -46413,140 +46413,140 @@ msgstr ""
 msgid "argument to %qE attribute is not intstack"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, gcc-internal-format
 msgid "cannot handle inconsistent calls to %qs"
 msgstr "не могу да обрадим неусаглашене позиве за %qs"
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr ""
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr ""
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr ""
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, fuzzy, gcc-internal-format
 #| msgid "C99 inline functions are not supported; using GNU89"
 msgid "built-in function %qE not supported for MIPS16"
 msgstr "Уткане функције Ц-а 99 нису подржане; користим Гну 89"
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs does not support MIPS16 code"
 msgstr "%s не подржава %s"
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr ""
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, gcc-internal-format
 msgid "MIPS16 %<-mxgot%> code"
 msgstr ""
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, gcc-internal-format
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr ""
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, gcc-internal-format
 msgid "MSA MIPS16 code"
 msgstr ""
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, gcc-internal-format
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr ""
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported combination: %s"
 msgstr "неподржана комбинација: %s"
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, fuzzy, gcc-internal-format
 #| msgid "-%s conflicts with the other architecture options, which specify a %s processor"
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr "-%s се коси са осталим опцијама архитектуре, које наводе процесор %s"
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr "-march=%s није сагласно са изабраним АБИјем"
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, fuzzy, gcc-internal-format
 #| msgid "-mgp64 used with a 32-bit processor"
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr "-mgp64 употребљено са 32-битним процесором"
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, fuzzy, gcc-internal-format
 #| msgid "-mgp32 used with a 64-bit ABI"
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr "-mgp32 употребљено са 64-битним АБИјем"
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, fuzzy, gcc-internal-format
 #| msgid "-mgp64 used with a 32-bit ABI"
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr "-mgp64 употребљено са 32-битним АБИјем"
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, fuzzy, gcc-internal-format
 #| msgid "this target does not support %qs"
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "овај циљ не подржава %qs"
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr ""
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr ""
@@ -46556,134 +46556,134 @@ msgstr ""
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr "тврдња: %s је доделом сагласно са %s"
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr "циљни ЦПУ не подржава инструкције Тамба"
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr "циљни ЦПУ не подржава инструкције Тамба"
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr ""
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported combination: %qs%s %s"
 msgstr "неподржана комбинација: %s"
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported combination: %qs %s"
 msgstr "неподржана комбинација: %s"
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, fuzzy, gcc-internal-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "cannot generate position-independent code for %qs"
 msgstr "Стварај положајно-независни кôд ако је могуће (велики режим)"
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, fuzzy, gcc-internal-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "position-independent code requires %qs"
 msgstr "Стварај положајно-независни кôд ако је могуће (велики режим)"
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr ""
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, fuzzy, gcc-internal-format
 #| msgid "this target does not support %qs"
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr "овај циљ не подржава %qs"
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, fuzzy, gcc-internal-format
 #| msgid "this target does not support %qs"
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr "овај циљ не подржава %qs"
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, fuzzy, gcc-internal-format
 #| msgid "-mips3d requires -mpaired-single"
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr "-mips3d захтева -mpaired-single"
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, fuzzy, gcc-internal-format
 #| msgid "-frepo must be used with -c"
 msgid "%qs must be used with %qs"
 msgstr "-frepo мора бити коришћено уз -c"
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, fuzzy, gcc-internal-format
 #| msgid "-mips3d/-mpaired-single must be used with -mfp64 -mhard-float"
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr "-mips3d и -mpaired-single морају бити употребљени са -mfp64 -mhard-float"
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr "циљни ЦПУ не подржава инструкције Тамба"
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr ""
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "the %qs architecture does not support DSP instructions"
 msgstr "циљни ЦПУ не подржава инструкције Тамба"
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, fuzzy, gcc-internal-format
 #| msgid "-mips3d/-mpaired-single must be used with -mfp64 -mhard-float"
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr "-mips3d и -mpaired-single морају бити употребљени са -mfp64 -mhard-float"
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, gcc-internal-format
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr ""
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, fuzzy, gcc-internal-format
 #| msgid "Use the bit-field instructions"
 msgid "%qs requires branch-likely instructions"
 msgstr "Користи инструкције битског нивоа"
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "the %qs architecture does not support the synci instruction"
 msgstr "циљни ЦПУ не подржава инструкције Тамба"
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr "профилисање функција мипса16"
@@ -47627,58 +47627,58 @@ msgstr ""
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, gcc-internal-format
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, gcc-internal-format
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, gcc-internal-format
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "malformed %<target()%> attribute"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, gcc-internal-format
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, gcc-internal-format
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "malformed %<target(\"%s\")%> attribute"
@@ -47746,183 +47746,203 @@ msgstr "не може се претворити из типа %qT у %qT"
 msgid "capture by copy of RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, gcc-internal-format
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function call to %qE with empty arguments"
 msgstr "нема одговарајуће функције за позив %<%D(%A)%>"
 
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, gcc-internal-format
 msgid "this operation requires the RVV ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr "алтивек аргумент прослеђен непрототипизираној функцији"
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, gcc-internal-format
 msgid "%s %qT requires the V ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, gcc-internal-format
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, gcc-internal-format
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, gcc-internal-format
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, gcc-internal-format
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr ""
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, gcc-internal-format
 msgid "function attribute %qs requires the V ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "аргумент атрибута %qs није „ilink1“ или „ilink2“"
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr ""
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not of type %qT"
 msgid "%qs applied to non-RVV type %qT"
 msgstr "%qE није типа %qT"
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qs requires an integer constant"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr ""
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs with %qs"
 msgstr "модела кôда %qs није подржан у %s-битном режиму"
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, gcc-internal-format
 msgid "rv64e requires lp64e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr ""
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d није између %d и 12"
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs није исправно за %qs"
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs није исправно за %qs"
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "%qs function cannot have different interrupt type"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr ""
@@ -48193,34 +48213,34 @@ msgstr ""
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr "прослеђивање аргумента %d од %qE одбацује одредбе са циљног типа показивача"
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "неисправна комбинација параметара за алтивек сопствену"
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, gcc-internal-format
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
@@ -48264,30 +48284,23 @@ msgstr "неисправни операнди типова %qT и %qT за би
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "ГЦЦ вектор прослеђен упућивачем: нестандарно проширење АБИја, без јемства сагласности"
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, gcc-internal-format
-msgid "%qs requires the ELFv2 ABI"
-msgstr ""
-
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "оквир стека превелик"
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported number of nops before function entry (%u)"
 msgstr ""
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, fuzzy, gcc-internal-format
 #| msgid "Use registers r2 and r5"
 msgid "%qs uses register r29"
 msgstr "Користи регистре r2 и r5"
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
@@ -48425,116 +48438,126 @@ msgstr "Потребан је позивом продрман циљни рег
 msgid "unknown option for %<%s=%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4837
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4855
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "нема профилисања 64-битног кôда за овај АБИ"
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "не може се узети адреса од %<this%>, јер је д-вредносни израз"
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "употреба %<long double%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "употреба логичких типова у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "употреба %<complex%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, fuzzy, gcc-internal-format
 #| msgid "use of decimal floating point types in AltiVec types is invalid"
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "употреба децималних реалних типова у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "употреба %<long%> у алтивек типовима није исправна у 64-битном кôду"
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "превазиђена употреба %<long%> у алтивек; користите %<int%>"
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "употреба %<long long%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "употреба %<double%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type %qT for %qE"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "неисправан апстрактни тип %qT за %qE"
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE is not initialized"
 msgid "%s%qs%s is not allowed"
 msgstr "%H%qE није успостављено"
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "навод ‘%s’ није исправан"
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "израз ограничења стека није подржан"
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr ""
@@ -48582,7 +48605,7 @@ msgstr ""
 msgid "builtin %qs can only be used on vector types"
 msgstr "%qs може бити наведено само за функције"
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -48657,244 +48680,244 @@ msgstr "%qs је превазиђено"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "константан аргумент ван опсега за %qs"
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr "неисправан шаблонски аргумент %d"
 
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr "константан аргумент ван опсега за %qs"
 
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr "константан аргумент ван опсега за %qs"
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher"
 msgstr ""
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher"
 msgstr ""
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, fuzzy, gcc-internal-format
 #| msgid "unresolved overload for Altivec builtin %qF"
 msgid "unresolved overloaded builtin"
 msgstr "неразрешено препуњавање за алтивек уграђено %qF"
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, fuzzy, gcc-internal-format
 #| msgid "bad builtin fcode"
 msgid "bad builtin icode"
 msgstr "лош уграђени fcode"
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "invalid argument %d for builtin %qF"
 msgstr "неисправан аргумент за уграђену функцију"
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "укупна величина локалних променљивих премашује ограничење архитектуре"
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr ""
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr ""
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "величина оквира за %qs је "
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs користи динамичко резервисање стека"
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr ""
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "угњеждена функција %qs декларисана као %<extern%>"
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-битни АБИ није подржан у режиму ЕСЕ/390"
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr "Ограничи употребу хардверских инструкција покретног зареза на 32-битне операције"
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, fuzzy, gcc-internal-format
 #| msgid "Allow hardware floating-point instructions to cover both 32-bit and 64-bit operations"
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr "Дозволи хардверским ФП инструкцијама да покрију и 32-битне и 64-битне операције"
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float нису подржани у комбинацији"
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "величина стека мора бити већа од вредности браника стека"
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "величина стека не сме бити већа од 64k"
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard имплицира коришћење -mstack-size"
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "аргумент за „%s“ треба да је ненегативан цео број"
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "аргумент за атрибут %qs већи од %d"
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, gcc-internal-format
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "ограничења стека нису подржана на овом циљу"
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "invalid cc output constraint: %qs"
 msgstr "неисправан аргумент опције %qs"
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, fuzzy, gcc-internal-format
 #| msgid "mudflap: this language is not supported"
 msgid "multiple cc output constraints not supported"
 msgstr "блатобран: овај језик није подржан"
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, fuzzy, gcc-internal-format
 #| msgid "asm-specifier for variable %qs conflicts with asm clobber list"
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr "наводилац asm за променљиву %qs коси се са asm листом продрмавања"
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand output code"
 msgid "invalid type for cc output constraint"
@@ -49375,8 +49398,8 @@ msgstr "атрибут %qE се игнорише"
 msgid "attribute %qs applies to array types only"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "празна вредност није игнорисана а требало би"
@@ -49455,7 +49478,7 @@ msgstr "тип низа %q+D довршен несагласно са импли
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr "%qD је већ декларисано у овом досегу"
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, fuzzy, gcc-internal-format
 #| msgid "original label is here"
 msgid "originally defined here"
@@ -49707,7 +49730,7 @@ msgstr "декларација %q+D заклања претходну не-пр
 msgid "declaration of %qD shadows a parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "декларација %qD заклања глобалну декларацију"
@@ -49717,7 +49740,7 @@ msgstr "декларација %qD заклања глобалну деклар
 msgid "declaration of %qD shadows a previous local"
 msgstr "декларација %qD заклања претходну локалну"
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
 msgid "shadowed declaration is here"
@@ -49791,7 +49814,7 @@ msgstr "%H%qE недекларисано (прва употреба у овој
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "%H(Сваки недекларисани идентификатор пријављен је само једном"
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "на етикету %qE упућено ван било које функције"
@@ -49828,7 +49851,7 @@ msgstr "скок у наредбени израз"
 msgid "duplicate label declaration %qE"
 msgstr "Удвостручена декларација етикете %qE"
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "удвостручена етикета %qD"
@@ -49867,7 +49890,7 @@ msgstr "скок у наредбени израз"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%H%qE дефинисан као погрешна врста ознаке"
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute applied to %qD with void return type"
@@ -50023,12 +50046,12 @@ msgstr "ИСО Ц 90 не подржава деклараторе низова %
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> није дозвољено другде осим у досегу прототипа функције"
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<omp::%s%> not allowed to be specified in this context"
@@ -50039,7 +50062,7 @@ msgstr "%<this%> се не може употребити у овом конте
 msgid "%q+D is usually a function"
 msgstr "%q+D је обично функција"
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
@@ -50122,7 +50145,7 @@ msgstr "не могу да ставим објекат са непостојан
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "неуспостављена константа %qD"
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -50327,7 +50350,7 @@ msgstr "складишна класа наведена за параметар %
 msgid "storage class specified for unnamed parameter"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "складишна класа наведена за име типа"
@@ -50400,7 +50423,7 @@ msgstr "декларација %qs као низа функција"
 msgid "declaration of type name as array of functions"
 msgstr "декларација %qs као низа функција"
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "неисправна употреба структуре са флексибилним чланским низом"
@@ -50524,7 +50547,7 @@ msgstr "%qs декларисано као функција која враћа 
 msgid "function definition has qualified void return type"
 msgstr "дефиниција функције има одређен празан повратни тип"
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "одредбе типова се игноришу на повратном типу функције"
@@ -50668,7 +50691,7 @@ msgstr "ИСО Ц забрањује константне или непосто
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "члан структуре или уније не може имати променљиво измењив тип"
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "променљива или поље %qE декларисано празним"
@@ -50787,7 +50810,7 @@ msgstr "скок у досег идентификатора са променљ
 msgid "object with variably modified type must have no linkage"
 msgstr "објекат променљиво измењивог типа не може имати повезивост"
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "декларација функције није прототип"
@@ -50882,18 +50905,18 @@ msgstr "угњеждена поновна дефиниција %<union %E%>"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "угњеждена поновна дефиниција %<struct %E%>"
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, fuzzy, gcc-internal-format
 #| msgid "unknown field %qE specified in initializer"
 msgid "%qT defined in underspecified object initializer"
 msgstr "непознато поље %qE наведено у успостављачу"
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "декларација ништа не декларише"
@@ -50925,386 +50948,386 @@ msgstr ""
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "унија нема именованих чланова"
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "унија нема чланова"
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "структура нема именованих чланова"
 
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "структура нема чланова"
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
 msgstr "%Jфлексибилан члански низ у унији"
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member not at end of struct"
 msgstr "%Jфлексибилан члански низ није на крају структуре"
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in a struct with no named members"
 msgstr "%Jфлексибилан члански низ у унији"
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr "%Jфлексибилан члански низ није на крају структуре"
 
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "type %qT is too large"
 msgstr "величина низа %qs је превелика"
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, gcc-internal-format
 msgid "type punning toggles scalar storage order"
 msgstr ""
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "унија не може бити учињена провидном"
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, fuzzy, gcc-internal-format
 #| msgid "a member of a structure or union cannot have a variably modified type"
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr "члан структуре или уније не може имати променљиво измењив тип"
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %<struct %E%>"
 msgid "redefinition of struct or union %qT"
 msgstr "поновна дефиниција %<struct %E%>"
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "угњеждена поновна дефиниција %<enum %E%>"
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "поновљена декларација %<enum %E%>"
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
 msgstr "наведени режим је премали за набројиве вредности"
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "вредности у набрајању премашују опсег највећег целог броја"
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration values exceed range of largest integer"
 msgid "enumeration values exceed range of %qs"
 msgstr "вредности у набрајању премашују опсег највећег целог броја"
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of %<enum %E%>"
 msgid "conflicting redefinition of enum %qT"
 msgstr "угњеждена поновна дефиниција %<enum %E%>"
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "преливање у вредностима набрајача"
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration values exceed range of largest integer"
 msgid "enumerator value outside the range of underlying type"
 msgstr "вредности у набрајању премашују опсег највећег целог броја"
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "enumerator value outside the range of %qs"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute %qs"
 msgstr "утканој функцији %q+D дат је атрибут noinline"
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "повратни тип је непотпун тип"
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "повратни тип спада на %<int%>"
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about global functions without prototypes"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "Упозори на глобалне функције без прототипа"
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, fuzzy, gcc-internal-format
 #| msgid "no previous prototype for %q+D"
 msgid "no previous prototype for %qD"
 msgstr "нема претходног прототипа за %q+D"
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D је употребљено без прототипа пре дефиниције"
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no declaration before its definition"
 msgid "%qD was used with no declaration before its definition"
 msgstr "%q+D је употребљено без декларације пре дефиниције"
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %<int%>"
 msgstr "повратни тип за %q+D није %<int%>"
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is normally a non-static function"
 msgstr "%q+D је обично нестатичка функција"
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style parameter declarations in prototyped function definition"
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "%Jстаровремска декларација параметара у дефиницији функције са прототипом"
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtraditional C rejects ISO C style function definitions"
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "%Jтрадиционални Ц одбија дефиниције функција у стилу ИСО Ц-а"
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr ""
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "old-style function definition"
 msgstr "%Jстаровремска дефиниција функције"
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name missing from parameter list"
 msgid "parameter name missing from parameter list"
 msgstr "%Jнедостаје име параметра у листи параметара"
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "%qD declared as a non-parameter"
 msgstr "%q+D декларисано као не-параметарско"
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, fuzzy, gcc-internal-format
 #| msgid "multiple parameters named %q+D"
 msgid "multiple parameters named %qD"
 msgstr "више параметара по имену %q+D"
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "parameter %qD declared with void type"
 msgstr "параметар %q+D декларисан са празним типом"
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, fuzzy, gcc-internal-format
 #| msgid "type of %q+D defaults to %<int%>"
 msgid "type of %qD defaults to %<int%>"
 msgstr "тип за %q+D спада на %<int%>"
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "parameter %qD has incomplete type"
 msgstr "параметар %q+D има непотпун тип"
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, fuzzy, gcc-internal-format
 #| msgid "declaration for parameter %q+D but no such parameter"
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "декларација за параметар %q+D, али нема таквог"
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "број аргумената не одговора уграђеном прототипу"
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "број аргумената не одговара прототипу"
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, fuzzy, gcc-internal-format
 #| msgid "%Hprototype declaration"
 msgid "prototype declaration"
 msgstr "%Hдекларација прототипа"
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "унапређени аргумент %qD не одговара уграђеном прототипу"
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "унапређени аргумент %qD не одговара прототипу"
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "аргумент %qD не одговара уграђеном прототипу"
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD не одговара прототипу"
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
 msgstr "параметар %qD је успостављен"
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declaration used outside C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "Почетна декларација у %<for%> петљи употребљена ван режима Ц-а 99"
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ИСО Ц 90 не подржава деклараторе низова %<[*]%>"
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of static variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "декларација статичке променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "декларација спољашње променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> декларисана у почетној декларацији %<for%> петље"
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> декларисана у почетној декларацији %<for%> петље"
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> декларисан у почетној декларацији %<for%> петље"
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of non-variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "декларација не-променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "очекивани су наводиоци декларације"
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "вишеструке складишне класе у наводиоцима декларације"
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qs used with %<auto%>"
@@ -51312,277 +51335,277 @@ msgstr "%<__thread%> употребљено уз %<auto%>"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%<auto%> used with %<constexpr%>"
 msgstr "%<__thread%> употребљено уз %<register%>"
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "два или више типова података у наводиоцима декларације"
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> је предуго за ГЦЦ"
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ИСО Ц 90 не подржава комплексне типове"
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "удвостручено %qE"
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "ограничења стека нису подржана на овом циљу"
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ИСО Ц 90 не подржава комплексне типове"
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support the %<%%%s%c%> %s format"
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr "%s не подржава %<%%%s%c%> формат за %s"
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "ограничења стека нису подржана на овом циљу"
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr "ИСО Ц не подржава децимални покретни зарез"
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "fixed-point types not supported for this target"
 msgstr "-fdata-sections није подржано за овај циљ"
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr ""
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE није ни по дефиницији типа ни уграђени тип"
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE није на почетку декларације"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> употребљено уз %<auto%>"
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> употребљено уз %<register%>"
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> употребљено уз %<typedef%>"
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<constexpr%>"
 msgstr "%<__thread%> употребљено уз %<register%>"
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s не подржава %s"
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> пре %<extern%>"
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> пре %<static%>"
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%<typedef%> used with %<auto%>"
 msgstr "%<__thread%> употребљено уз %<auto%>"
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<extern%>"
 msgstr "%<__thread%> употребљено уз %<register%>"
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%qE used with %qs"
 msgstr "%<__thread%> употребљено уз %qE"
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%qs used with %qE"
 msgstr "%<__thread%> употребљено уз %qE"
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%<constexpr%> used with %qE"
 msgstr "%<__thread%> употребљено уз %qE"
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, fuzzy, gcc-internal-format
 #| msgid "%<@try%> without %<@catch%> or %<@finally%>"
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<@try%> без %<@catch%> или %<@finally%>"
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ИСО Ц не подржава да обичан %<complex%> значи %<double complex%>"
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr "ИСО Ц 90 не подржава деклараторе низова %<[*]%>"
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, fuzzy, gcc-internal-format
 #| msgid "Fixed line length must be at least seven."
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr "Фиксна дужина линије мора бити барем седам."
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support %<~%> for complex conjugation"
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr "ИСО Ц не подржава %<~%> за комплексну конјугацију"
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "негативан леви помак"
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "негативан леви помак"
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "негативан десни помак"
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "леви помак >= од ширине типа"
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "десни помак >= од ширине типа"
@@ -51614,7 +51637,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -51626,8 +51649,8 @@ msgstr "Неочекиван крај модула"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ИСО Ц забрањује празну изворну датотеку"
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr ""
@@ -51669,9 +51692,9 @@ msgstr "нема типа по имену %q#T у %q#T"
 msgid "unknown type name %qE"
 msgstr "непознато име регистра: %s"
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "очекивани су наводиоци декларације"
@@ -51705,7 +51728,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "очекиван је идентификатор или %<(%>"
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -51729,7 +51752,7 @@ msgstr "Очекивано је име атрибутског бита"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "атрибут одељка није допуштен за %q+D"
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<assume%> attribute not followed by %<;%>"
@@ -51830,7 +51853,7 @@ msgstr "интегрални израз %qE није константа"
 msgid "static assertion failed: %E"
 msgstr "Тврдња КРИС-порта није прошла: "
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, fuzzy, gcc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed"
@@ -51909,10 +51932,10 @@ msgstr "неисправан шаблонски аргумент %d"
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "очекиван је идентификатор"
@@ -52072,7 +52095,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr ""
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr ""
@@ -52082,8 +52105,8 @@ msgstr ""
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs attribute argument"
 msgstr ""
@@ -52270,12 +52293,12 @@ msgstr "ИСО Ц забрањује изостављање средњег чл
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -52445,7 +52468,7 @@ msgstr "ИСО Ц 90 не подржава деклараторе низова %
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, gcc-internal-format
 msgid "expected expression"
 msgstr "очекиван је израз"
@@ -52791,12 +52814,12 @@ msgstr "Очекивана је декларација класе или суч
 msgid "no type or storage class may be specified here,"
 msgstr "складишна класа наведена за %qs"
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr ""
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, fuzzy, gcc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing property attribute"
@@ -52807,61 +52830,61 @@ msgstr "недостаје атрибут Code"
 msgid "unknown property attribute %<%s%s%>"
 msgstr ""
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr ""
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected %qE selector name"
 msgstr "очекивано је име класе"
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr ""
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, fuzzy, gcc-internal-format
 #| msgid "%<continue%> must be in loop"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<continue%> мора бити у оквиру петље"
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp section%> може бити употребљено само у конструкцији %<#pragma omp sections%>"
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> може бити употребљено само у конструкцији %<#pragma omp sections%>"
@@ -52872,26 +52895,26 @@ msgstr "%<#pragma omp section%> може бити употребљено сам
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr "%<#pragma omp flush%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "очекивана је наредба for"
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> мора бити прво"
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "превише %qs одредби"
@@ -52908,73 +52931,73 @@ msgstr "израз за num_threads мора бити интегрални"
 msgid "expected %<)%> or %<,%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a pointer variable"
 msgstr "%qD није шаблон"
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "поређење означених и неозначених целобројних израза"
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr "очекивано је %<=%>, %<,%>, %<;%>, %<asm%> или %<__attribute__%>"
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected constant logical expression"
 msgstr "очекиван је целобројни израз"
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<data%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -52998,25 +53021,25 @@ msgstr "вредност %<num_threads%> мора бити позитивна"
 msgid "%<num_tasks%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "очекиван је целобројни израз"
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
@@ -53028,108 +53051,108 @@ msgstr "очекивано је %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<static%> arguments"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected element"
 msgid "unexpected argument"
 msgstr "Неочекивани елемент"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "аргумент атрибута %qs није целобројна константа"
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<self%> clauses"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<concurrent%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "поређење уређености показивача са целобројном нулом"
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "очекивано је %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%> или %<||%>"
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "и %<long%> и %<void%> у наводиоцима декларације"
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "распоред %<runtime%> не узима параметар %<chunk_size%>"
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, fuzzy, gcc-internal-format
 #| msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "распоред %<runtime%> не узима параметар %<chunk_size%>"
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "неисправна врста распореда"
@@ -53140,23 +53163,23 @@ msgstr "неисправна врста распореда"
 msgid "%<num_teams%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr ""
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<allocator%> or %<align%>"
@@ -53168,23 +53191,23 @@ msgstr "очекивано је %<,%> или %<;%>"
 msgid "duplicate %qs modifier"
 msgstr "удвостручено %qs"
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, gcc-internal-format
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr ""
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, fuzzy, gcc-internal-format
 #| msgid "multiple inline callers"
 msgid "multiple linear modifiers"
 msgstr "вишеструки уткани позивачи"
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, gcc-internal-format
 msgid "multiple %<step%> modifiers"
 msgstr ""
@@ -53205,70 +53228,70 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "тврдња: %s је доделом сагласно са %s"
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "неисправна врста распореда"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid doacross kind"
 msgstr "неисправна врста распореда"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<always%> modifiers"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<close%> modifiers"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<present%> modifiers"
 msgstr "превише улазних датотека"
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "неисправна маска"
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr ""
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, gcc-internal-format
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr ""
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -53286,95 +53309,95 @@ msgstr "неисправна врста распореда"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected an OpenACC clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs није исправно за %qs"
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a nested class of %qT"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qT није угњеждена класа у %qT"
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected an OpenMP clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "декларација спољашње променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "неисправна употреба %<--%> на логичкој променљивој %qD"
 
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs is used more than once in the argument list of method %qs"
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "Променљива %qs употребљена више од једном у листи аргумената метода %qs"
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr ""
@@ -53391,7 +53414,7 @@ msgstr "%qD није декларисано"
 msgid "expected function name"
 msgstr "очекивано је име класе"
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qD does not refer to a function"
@@ -53402,23 +53425,23 @@ msgstr "%q+D није функција,"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> мора да се јави пре декларације %D, игноришем"
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
@@ -53445,7 +53468,7 @@ msgstr ""
 msgid "modified here"
 msgstr "модификатор ‘E’"
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, gcc-internal-format
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
 msgstr ""
@@ -53485,119 +53508,119 @@ msgstr ""
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr ""
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>, %<,%>, %<;%>, %<}%> or %<__attribute__%>"
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "очекивано је %<:%>, %<,%>, %<;%>, %<}%> или %<__attribute__%>"
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, gcc-internal-format
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, gcc-internal-format
 msgid "%qs clause requires %qs clause"
 msgstr ""
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr "очекивано је %<(%> или крај линије"
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, gcc-internal-format
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr ""
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "unexpected %<else%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr ""
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%<depobj%> expression is not lvalue expression"
@@ -53609,30 +53632,30 @@ msgstr "листа израза %s узима се као сложени изр
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr ""
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr "очекивано је %<=%>, %<,%>, %<;%>, %<asm%> или %<__attribute__%>"
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "очекивано је %<=%>, %<,%>, %<;%>, %<asm%> или %<__attribute__%>"
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -53642,178 +53665,178 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "очекивано је %<(%> или крај линије"
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr "%<#pragma omp flush%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr "%<#pragma omp flush%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "очекивано је успостављање или декларација итерације"
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, fuzzy, gcc-internal-format
 #| msgid "not enough type information"
 msgid "not enough nested loops"
 msgstr "нема довољно података о типу"
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "очекивана је наредба for"
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be firstprivate"
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "не би требало да променљива итерације %qs буде firstprivate"
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr ""
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> мора да се јави пре декларације %D, игноришем"
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, fuzzy, gcc-internal-format
 #| msgid "Expected attribute bit name"
 msgid "expected trait selector name"
 msgstr "Очекивано је име атрибутског бита"
 
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, gcc-internal-format
 msgid "unknown selector %qs for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr "%<friend%> може бити наведено само унутар класе"
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, gcc-internal-format
 msgid "%<score%> argument must be constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<score%> argument must be non-negative"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "очекивана је дословна ниска"
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "property must be constant integer expression"
 msgstr "очекиван је целобројни израз"
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
@@ -53821,311 +53844,311 @@ msgstr ""
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%<requires%> selector is not supported yet"
 msgstr "модела кôда %<large%> још увек није подржан"
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected context selector set name"
 msgstr "очекивано је име класе"
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<match%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "variant %qD is not a function"
 msgstr "%q+D није функција,"
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "елементи низа %q#D имају непотпун тип"
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, gcc-internal-format
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr ""
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr ""
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, gcc-internal-format
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr ""
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<declare%> or %<assumes%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, gcc-internal-format
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "очекивано је %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<omp_priv%> or function-name"
 msgstr "очекивано је %<(%> или крај линије"
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected function-name %<(%>"
 msgstr "очекиван је идентификатор или %<(%>"
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "очекивано је %<=%>, %<,%>, %<;%>, %<asm%> или %<__attribute__%>"
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr "очекивано је %<=%>, %<,%>, %<;%>, %<asm%> или %<__attribute__%>"
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, gcc-internal-format
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "%qE има неисправан тип за %<reduction%>"
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %qs or %qs"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr ""
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr ""
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected at least one assumption clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected directive name"
 msgstr "очекивано је име класе"
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr ""
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown assumption clause %qs"
 msgstr "непознат машински режим %qs"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected assumption clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE декларисано као нитно-локално после прве употребе"
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "аутоматска променљива %qE не може бити нитно-локална"
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "нитно-локално %qE има непотпун тип"
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "no closing brace"
@@ -54277,7 +54300,7 @@ msgstr "разрешавање %<void *%> показивача"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "индексирана вредност није ни низ ни показивач"
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "индекс низа није целобројан"
@@ -54308,7 +54331,7 @@ msgstr "%qD декларисано као упућивач али није ус
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -54429,19 +54452,19 @@ msgstr "захтев за имплицтно претварање из %qT у %q
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "премало аргумената за функцију %qE"
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, fuzzy, gcc-internal-format
 #| msgid "comparison with string literal results in unspecified behaviour"
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "поређење са дословном ниском резултује неодређеним понашањем"
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "поређење између показивача и целобројног"
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -54468,7 +54491,7 @@ msgstr "показивач на функцију употребљен у оду
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "аритметика са показивачем на непотпун тип"
 
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -54789,7 +54812,7 @@ msgstr "претапање из показивача у целобројни р
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "претапање из функцијског позива типа %qT у непоклапајући тип %qT"
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "претапање из целобројног у показивач различите величине"
@@ -54990,7 +55013,7 @@ msgstr "лева страна доделе може бити кандидат з
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "лева страна успостављања може бити кандидат за форматски атрибут"
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "повратни тип може бити кандидат за форматски атрибут"
@@ -55212,12 +55235,12 @@ msgstr "успостављач за целобројну вредност је 
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "успостављање флексибилног чланског низа"
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -55227,7 +55250,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr "низ неподесног типа успостављен константном ниском"
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "неисправна употреба не-л-вредносног низа"
@@ -55259,7 +55282,7 @@ msgstr "елемент успостављача није константан"
 msgid "initializer element is not computable at load time"
 msgstr "елемент успостављача се не може израчунати при учитавању"
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "непрозирни векторски типови не могу бити успостављени"
@@ -55274,7 +55297,7 @@ msgstr "сувишна група витичастих заграда на кр
 msgid "braces around scalar initializer"
 msgstr "витичасте заграде око скаларног успостављача"
 
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "успостављање флексибилног чланског низа у угњежденом контексту"
@@ -55367,7 +55390,7 @@ msgstr "сувишни елементи у успостављачу структ
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "нестатичко успостављање флексибилног чланског низа"
@@ -55408,7 +55431,7 @@ msgstr "ИСО Ц забрањује %<goto *expr;%>"
 msgid "computed goto must be pointer type"
 msgstr "не могу да претворим у показивачки тип"
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "функција декларисана са %<noreturn%> има наредбу %<return%>"
@@ -55466,7 +55489,7 @@ msgstr "етикета %<default%> није у оквиру наредбе пр
 msgid "break statement not within loop or switch"
 msgstr "наредба искакања није у оквиру петље или прекидача"
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -55512,28 +55535,28 @@ msgstr ""
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr ""
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "comparison between types %qT and %qT"
 msgstr "поређење између типова %q#T и %q#T"
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
@@ -55610,31 +55633,31 @@ msgstr "употребљена вредност унијског типа где
 msgid "used vector type where scalar is required"
 msgstr "употребљена вредност структурног типа где се захтева скалар"
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
@@ -55647,91 +55670,91 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "превише %qs одредби"
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "величина у низовном new мора бити интегралног типа"
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "величина у низовном new мора бити интегралног типа"
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected single pointer in %qs clause"
 msgstr "очекивана је дословна ниска"
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Копирај одељке низа у непрекидан блок при улазу у процедуру"
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qE does not have pointer or array type"
 msgstr "%qE нема класни тип"
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, fuzzy, gcc-internal-format
 #| msgid "throwing NULL, which has integral, not pointer type"
 msgid "iterator %qD has neither integral nor pointer type"
@@ -55742,19 +55765,19 @@ msgstr "баца се NULL, које има интегрални, а не пок
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr ""
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "iterator %qD has const qualified type"
 msgstr "битско поље %qs има неисправан тип"
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "iterator step with non-integral type"
 msgstr "битско поље %qD неинтегралног типа"
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
@@ -55764,36 +55787,36 @@ msgstr ""
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, fuzzy, gcc-internal-format
 #| msgid "expression reference type error at %L"
 msgid "begin expression refers to outer iterator %qD"
 msgstr "грешка типа упућивача израза код %L"
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, fuzzy, gcc-internal-format
 #| msgid "expression reference type error at %L"
 msgid "end expression refers to outer iterator %qD"
 msgstr "грешка типа упућивача израза код %L"
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, fuzzy, gcc-internal-format
 #| msgid "expression reference type error at %L"
 msgid "step expression refers to outer iterator %qD"
 msgstr "грешка типа упућивача израза код %L"
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected pointer in %qs clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr ""
@@ -55825,7 +55848,7 @@ msgstr "Променљива %qs није дефинисана у типу %qs"
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE има неисправан тип за %<reduction(%s)%>"
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, fuzzy, gcc-internal-format
 #| msgid "No label definition found for %qs"
 msgid "user defined reduction not found for %qE"
@@ -55836,17 +55859,17 @@ msgstr "Није нађена дефиниција етикете за %qs"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE мора бити нитно-локално за %<copyin%>"
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
 msgstr ""
@@ -55861,24 +55884,24 @@ msgstr ""
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in reduction clauses"
@@ -55891,33 +55914,33 @@ msgstr "%qE се појављује више од једном у одредба
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE није променљива у одредби %<firstprivate%>"
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE није променљива у одредби %<lastprivate%>"
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -55940,7 +55963,7 @@ msgstr ""
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<nontemporal%> clause"
@@ -55952,7 +55975,7 @@ msgstr "%qE није променљива у одредби %qs"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<allocate%> clause"
@@ -55964,84 +55987,84 @@ msgstr "%qE није променљива у одредби %qs"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr ""
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression in array specification at %C"
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr "Очекиван је израз у одредници низа код %C"
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported map expression %qE"
 msgstr "неподржана комбинација: %s"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
@@ -56059,24 +56082,24 @@ msgstr "%s променљива %qs је приватна у спољашњем
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "тип уз векторско delete није ни показивачки ни низовни"
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %qs clauses on a task construct"
 msgstr "превише %qs одредби"
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, fuzzy, gcc-internal-format
 #| msgid "%<-G%> is incompatible with %<-mabicalls%>"
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "%<-G%> није сагласно са %<-mabicalls%>"
 
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE је предодређено као %qs за %qs"
@@ -56086,38 +56109,38 @@ msgstr "%qE је предодређено као %qs за %qs"
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
@@ -56426,7 +56449,7 @@ msgstr "  за претварање из %qT у %qT"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  за претварање из %qT у %qT"
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -56435,7 +56458,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -56782,621 +56805,621 @@ msgstr ""
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "набројиви и ненабројиви тип у условном изразу"
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "%<%D(int)%> није декларисано за постфиксно %qs, покушавам смену префиксним оператором"
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, fuzzy, gcc-internal-format
 #| msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "%<%D(int)%> није декларисано за постфиксно %qs, покушавам смену префиксним оператором"
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "повратни тип за %q+D није %<int%>"
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "поређење између %q#T и %q#T"
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to %<(%T) (%A)%>"
 msgid "no match for call to %<%T::operator[] (%A)%>"
 msgstr "нема поклапања за позив %<(%T) (%A)%>"
 
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, fuzzy, gcc-internal-format
 #| msgid "call of %<(%T) (%A)%> is ambiguous"
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr "двосмислен позив %<(%T) (%A)%>"
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%q+D је обично нестатичка функција"
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, fuzzy, gcc-internal-format
 #| msgid "no corresponding deallocation function for `%D'"
 msgid "no corresponding deallocation function for %qD"
 msgstr "нема одговарајуће функције за ослобађање меморије за ‘%D’"
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr ""
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "нема погодног %<operator %s%> за %qT"
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "у овом контексту"
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared private here"
 msgstr "%q+D декларисано овде"
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "у овом контексту"
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared protected here"
 msgstr "%q+D декларисано овде"
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D није приступно"
 
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "прослеђивање NULL непоказивачком аргументу %P од %qD"
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "  declared here"
 msgstr "%q+D декларисано овде"
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "претварање у непоказивачки тип %qT из NULL"
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "не може се претворити %qT у %qT као аргумент %qP за %qD"
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "претварање NULL у непоказивачки тип"
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  успостављање аргумента %P од %qD"
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, fuzzy, gcc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "too many braces around initializer for %qT"
 msgstr "недостају витичасте заграде око успостављача за %qT"
 
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr ""
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr ""
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "неисправно претварање из %qT у %qT"
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "неисправно претварање из %qT у %qT"
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "само декларације конструктора могу имати %<explicit%>"
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 #, fuzzy
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "неисправно претапање д-вредносног израза типа %qT у тип %qT"
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr "неисправно успостављање неконстантног упућивача типа %qT привременим типа %qT"
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "неисправно успостављање неконстантног упућивача типа %qT привременим типа %qT"
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "неисправно успостављање упућивача типа %qT изразом типа %qT"
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 #, fuzzy
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "не може се повезати битско поље %qE са %qT"
 
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "не може се повезати паковано поље %qE са %qT"
 
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "не може се повезати д-вредност %qE са %qT"
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "не могу се проследити објекти не-ПОД типа %q#T кроз %<...%>; позив ће искочити при извршавању"
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "не могу се примати објекти не-ПОД типа %q#T кроз %<...%>; позив ће искочити при извршавању"
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "поновљена дефиниција подразумеваног аргумента за %q#D"
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, fuzzy, gcc-internal-format
 #| msgid "the default argument for parameter %d of %qD has not yet been parsed"
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "подразумевани аргумент за параметер %d у %qD још увек није рашчлањен"
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "аргумент позива функције може бити кандидат за форматски атрибут"
 
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr ""
 
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "прослеђивање %qT као аргумента %<this%> у %q#D одбацује одредбе"
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  у позиву %qD"
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT није приступна основа од %qT"
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "Недостају аргументи за сопствено %s код %L"
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "додела (не успостављање) у декларацији"
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "користите #include уместо тога"
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "додела (не успостављање) у декларацији"
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "користите #include уместо тога"
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%#qT declared here"
 msgstr "%q+D декларисано овде"
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, gcc-internal-format
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr ""
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "конструктор не може бити виртуелан"
 
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "нема одговарајуће функције за позив %<%T::%s(%A)%#V%>"
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "нема одговарајуће функције за позив %<%T::%s(%A)%#V%>"
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "позив не-функције %qD"
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "нема одговарајуће функције за позив %<%D(%A)%>"
 
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "двосмислен позив препуњене %<%s(%A)%>"
 
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT нема нестатички члански податак по имену %qD"
 
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "враћање вредности из конструктора"
 
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "враћање вредности из деструктора"
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "чланска функција %qD не може се позвати без објекта"
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "прослеђивање %qT бира %qT пре него %qT"
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr "ИСО Ц++ каже да је ово двосмислено, чак иако је најгоре претварање првог боље од најгорег претварања другог:"
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "try making the operator a %<const%> member function"
 msgstr "%qD мора бити нестатичка чланска функција"
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "бирам %qD пре него %qD"
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  за претварање из %qT у %qT"
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  зато што је редослед претварања за аргумент бољи"
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "наведен подразумевани аргумент у експлицитној специјализацији"
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, fuzzy, gcc-internal-format
 #| msgid "candidate 1:"
 msgid " candidate 1: %q#F"
 msgstr "кандидат 1:"
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, fuzzy, gcc-internal-format
 #| msgid "candidate 2:"
 msgid " candidate 2: %q#F"
 msgstr "кандидат 2:"
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ИСО Ц++ каже да је ово двосмислено, чак иако је најгоре претварање првог боље од најгорег претварања другог:"
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "неисправно успостављање неконстантног упућивача типа %qT привременим типа %qT"
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "неисправно успостављање упућивача типа %qT изразом типа %qT"
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "possibly dangling reference to a temporary"
 msgstr "враћање упућивача на привремени"
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr ""
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, fuzzy, gcc-internal-format
 #| msgid "%s: definition of function '%s' not converted\n"
 msgid "explicit conversion function was not considered"
@@ -57450,7 +57473,7 @@ msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D не може бити препуњено"
 
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %q#D"
@@ -57919,7 +57942,7 @@ msgstr "%Jфлексибилан члански низ у иначе празн
 msgid "next member %q#D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "поновна дефиниција %q#T"
@@ -58061,7 +58084,7 @@ msgstr "неисправан апстрактни повратни тип за 
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
@@ -58105,7 +58128,7 @@ msgstr ""
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr ""
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr ""
@@ -58124,7 +58147,7 @@ msgstr ""
 msgid "%q+E is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
@@ -58146,7 +58169,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
@@ -58198,7 +58221,7 @@ msgstr "%qT је двосмислена основа за %qT"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
@@ -58341,20 +58364,20 @@ msgstr ""
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "разрешавање %<void *%> показивача"
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -58363,513 +58386,513 @@ msgstr "разрешавање %<void *%> показивача"
 msgid "%qE is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr ""
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr ""
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је показивач"
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr ""
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr ""
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr ""
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "шаблонски параметар %qD типа %qT није дозвољен у интегралном константном изразу јер није интегралног или набројивог типа"
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr ""
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr ""
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot be used in asm here"
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "%s се не може користити овде у асемблеру"
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr ""
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "allocated here"
 msgstr "позвано одавде"
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
 msgstr ""
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, fuzzy, gcc-internal-format
 #| msgid "array used as initializer"
 msgid "%qD used in its own initializer"
 msgstr "низ употребљен као успостављач"
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q#D is not const"
 msgstr "%q#T није класа"
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is private"
 msgid "%q#D is volatile"
 msgstr "%q+#D је приватно"
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD није декларисано у овом досегу"
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "израз у декларатору new мора имати интегрални или набројиви тип"
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, gcc-internal-format
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr "декларација %q#D изван класе није дефиниција"
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, gcc-internal-format
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, gcc-internal-format
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr ""
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr ""
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr ""
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "inline assembly is not a constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "use of %qD"
 msgstr "неисправна употреба %qD"
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr ""
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr ""
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr ""
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr ""
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, gcc-internal-format
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "набројиви и ненабројиви тип у условном изразу"
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr "шаблонски параметар %qD типа %qT није дозвољен у интегралном константном изразу јер није интегралног или набројивог типа"
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, gcc-internal-format
 msgid "pointed-to object declared here"
 msgstr ""
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr "шаблонски параметар %qD типа %qT није дозвољен у интегралном константном изразу јер није интегралног или набројивог типа"
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr ""
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant expression"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "преливање у константном изразу"
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "contract predicate is false in constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a class template, got %qE"
 msgid "unexpected template-id %qE"
 msgstr "  очекивах шаблон класе, добих %qE"
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "очекиван је израз"
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, gcc-internal-format
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "неисправно претапање д-вредносног израза типа %qT у тип %qT"
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "new-expression is not a constant expression before C++20"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "division by zero is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "преливање у константном изразу"
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "неконстантан индекс низа у успостављачу"
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
@@ -59674,7 +59697,7 @@ msgstr "трећи аргумент за %<__builtin_prefetch%> мора бит
 msgid "no suspend point info for %qD"
 msgstr "нема претходног прототипа за %q+D"
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -59696,23 +59719,23 @@ msgstr "показивачи нису дозвољени као вредност
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, fuzzy, gcc-internal-format
 #| msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
@@ -59734,76 +59757,76 @@ msgstr ""
 msgid "%qD was promoted to an immediate function"
 msgstr "%qD није шаблонска функција"
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "taking address of an immediate function %qD"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "call to consteval function %qE is not a constant expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "адреса за %qD ће увек бити израчуната као %<true%>"
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "pack expansion of %qE attribute"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in template argument list"
 msgid "use fold expression in the attribute argument instead"
 msgstr "грешка у рашчлањивању листе шаблонских аргумената"
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD није тип"
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not a class type"
 msgstr "%qD није тип"
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE нема класни тип"
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qD does not have integral type"
 msgstr "%qE нема класни тип"
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
@@ -59856,7 +59879,7 @@ msgstr "неисправно успостављање неконстантног
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "претапање %qT у %qT не разрешава показивач"
@@ -60288,7 +60311,7 @@ msgstr "од претходне декларације %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "Декларација %qs заклања претходну декларацију етикете"
 
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -60453,8 +60476,8 @@ msgstr "претходна нефункцијска декларација %q+#D
 msgid "%q#D previously defined here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#D previously declared here"
@@ -60537,60 +60560,42 @@ msgstr "подразумевани аргумент дат за парамета
 msgid "previous specification in %q#D here"
 msgstr "после претходног навода у %q+#D"
 
-#: cp/decl.cc:2285
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of namespace %qD conflicts with"
-msgid "declaration %qD conflicts with builtin"
-msgstr "декларација именског простора %qD коси се са"
-
-#: cp/decl.cc:2288
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of namespace %qD conflicts with"
-msgid "declaration %qD conflicts with import"
-msgstr "декларација именског простора %qD коси се са"
-
-#: cp/decl.cc:2289
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration %q+#D here"
-msgid "import declared %q#D here"
-msgstr "претходном декларацијом %q+#D овде"
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting exporting for declaration %qD"
 msgstr "сукобљена декларација %q#D"
 
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "previously declared here without exporting"
 msgstr "%q+#D претходно декларисано овде"
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD here"
 msgstr "претходна дефиниција %q+D беше овде"
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD here"
 msgstr "претходна декларација %q+D беше овде"
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, fuzzy, gcc-internal-format
 #| msgid "function declared %<noreturn%> has a %<return%> statement"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "функција декларисана са %<noreturn%> има наредбу %<return%>"
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "сувишна поновна декларација %qD у истом досегу"
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %qD is not in namespace enclosing %qT"
 msgid "deleted definition of %qD is not first declaration"
@@ -60604,50 +60609,50 @@ msgstr "дефиниција %qD није у именском простору 
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "експлицитна специјализација %qD после прве употребе"
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D: visibility attribute ignored because it"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%q+D: атрибут видљивости игнорисан зато што"
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "redefinition of %q#D"
 msgstr "поновна дефиниција %q#T"
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%qD conflicts with used function"
 msgstr "%q#D се коси са претходном декларацијом употребе %q#D"
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%q#D not declared in class"
 msgstr "%qD није декларисано у %qD"
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -60655,816 +60660,816 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, fuzzy, gcc-internal-format
 #| msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "нитно-локална декларација %q+D прати не-нитно-локалну декларацију"
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, fuzzy, gcc-internal-format
 #| msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "не-нитно-локална декларација %q+D прати нитно-локалну декларацију"
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D"
 msgid "redeclaration of %q#D"
 msgstr "декларација %q#D"
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "сувишна поновна декларација %qD у истом досегу"
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, gcc-internal-format
 msgid "previous label"
 msgstr ""
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, gcc-internal-format
 msgid "jump to label %qD"
 msgstr "скок на етикету %qD"
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr "скок на етикету случаја"
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr ""
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  одавде"
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  излази из структуираног блока ОпенМПа"
 
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  пресеца успостављање %q+#D"
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  улази у блок покушаја"
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  улази у блок хватања"
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  улази структуирани блок ОпенМПа"
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, fuzzy, gcc-internal-format
 #| msgid "jump into statement expression"
 msgid "  enters statement expression"
 msgstr "скок у наредбени израз"
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, gcc-internal-format
 msgid "  enters %<consteval if%> statement"
 msgstr ""
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "  does not destroy %qD"
 msgstr "%s не подржава %s"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, gcc-internal-format
 msgid "  does not clean up handled exception"
 msgstr ""
 
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  прескаче успостављање %q+#D"
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "%qD употребљено без параметара шаблона"
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is a function, not a type"
 msgstr "%qD није шаблон функције"
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T није класа"
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "нема шаблона класе по имену %q#T у %q#T"
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "нема типа по имену %q#T у %q#T"
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "двосмислено претварање из %qT у %qT"
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> именује %q#T, што није шаблон класе"
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, fuzzy, gcc-internal-format
 #| msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> именује %q#T, што није тип"
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "параметри шаблона се не поклапају са шаблоном"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "захтевано равнање није степен двојке"
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D није исправно; анонимна унија може имати само нестатичке чланске податке"
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous struct not inside named type"
 msgid "anonymous struct with base classes"
 msgstr "анонимна структура није унутар именованог типа"
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "члан %q+#D са конструктором није дозвољен у анонимној скупини"
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "члан %q+#D са деструктором није дозвољен у анонимној скупини"
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "члан %q+#D са оператором копирања-доделе није дозвољен у анонимној скупини"
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "атрибут игнорисан у декларацији %q+#T"
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, fuzzy, gcc-internal-format
 #| msgid "attribute for %q+#T must follow the %qs keyword"
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "атрибут за %q+#T мора пратити кључну реч %qs"
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "вишеструки типови у једној декларацији"
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "поновљена декларација Ц++ уграђеног типа %qT"
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs може бити наведено само за функције"
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "недостаје име типа у наредби typedef"
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ИСО Ц++ забрањује анонимне структуре"
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs може бити наведено само за функције"
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs може бити наведено само за функције"
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> може бити наведено само унутар класе"
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> може бити наведено само за конструкторе"
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "складишна класа може бити наведена само за објекте и функције"
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "одредбе могу бити наведене само за објекте и функције"
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "одредбе могу бити наведене само за објекте и функције"
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "одредбе могу бити наведене само за објекте и функције"
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "складишна класа може бити наведена само за објекте и функције"
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, fuzzy, gcc-internal-format
 #| msgid "typedef declaration invalid in parameter declaration"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "декларација typedef није исправна у декларацији параметра"
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, fuzzy, gcc-internal-format
 #| msgid "Class %qs not found in type declaration"
 msgid "%qs cannot be used for type declarations"
 msgstr "Класа %qs не налази се у декларацији типа"
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "дефиниција типа %qD је успостављена (употребите __typeof__)"
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "декларација %q#D има %<extern%> и ипак је успостављена"
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "дефиниција %q+D означена као %<dllimport%>"
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D је нестатички члански податак у %qT"
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "неисправна декларација чланског шаблона %qD"
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ИСО Ц++ не дозвољава да %<%T::%D%> буде дефинисано као %<%T::%D%>"
 
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "удвостручено успостављање %qD"
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "декларација %q#D изван класе није дефиниција"
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr ""
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "променљива %q#D има успостављач али је непотпуног типа"
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "елементи низа %q#D имају непотпун тип"
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "скупина %q#D има непотпун тип и не може се дефинисати"
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD декларисано као упућивач али није успостављено"
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "име %qD употребљено у успостављачу низа утврђеном као Гну-стил"
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "име %qD употребљено у успостављачу низа утврђеном као Гну-стил"
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "нетривијални утврђени успостављачи нису подржани"
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "успостављач не одређује величину %qD"
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "недостаје величина низа у %qD"
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "низ %qD нулте величине"
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t known"
 msgid "storage size of %qD isn%'t known"
 msgstr "величина складишта за %q+D није позната"
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "величина складишта за %q+D није константна"
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "извините: семантика статичких података уткане функције %q+#D је погрешна (доћи ће до вишеструких копија)"
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "извините: семантика статичких података уткане функције %q+#D је погрешна (доћи ће до вишеструких копија)"
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "%J  можете ово заобићи уклањањем успостављача"
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "неуспостављена константа %qD"
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "регистарска променљива %qD употребљена у угњежденој функцији"
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized member %qD with %<const%> type %qT"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "%Jнеуспостављени члан %qD са %<const%> типом %qT"
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "тип %qs има кориснички дефинисан конструктор"
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "неисправан тип %qT као успостављач за вектор типа %qT"
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "успостављач за %qT мора бити у витичастим заградама"
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "име %qD употребљено у успостављачу низа утврђеном као Гну-стил"
 
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "двосмислен захтев за чланом %qD"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT нема нестатички члански податак по имену %qD"
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD није члан у %qT"
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "неисправан успостављач"
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "превише успостављача за %qT"
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "витичасте заграде око скаларног успостављача за тип %qT"
 
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "витичасте заграде око скаларног успостављача за тип %qT"
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "недостају витичасте заграде око успостављача за %qT"
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %P has incomplete type %qT"
 msgid "structured binding has incomplete type %qT"
 msgstr "параметар %P непотпуног је типа %qT"
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "elements of array %q#T have incomplete type"
 msgstr "елементи низа %q#D имају непотпун тип"
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ИСО Ц 90 забрањује сложене дословне ниске"
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "%qD има непотпун тип"
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "скаларни објекат %qD захтева један елемент у успостављачу"
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be initialized by constructor, not by %<{...}%>"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "%qD мора бити успостављен конструктором, не помоћу %<{...}%>"
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "низ %qD успостављен заграђеном константном ниском %qE"
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "успостављач неисправан за статички члан са конструктором"
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ИСО Ц++ забрањује успостављање унутар класе неконстантног статичког члана %qD"
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ИСО Ц++ забрањује успостављање унутар класе неконстантног статичког члана %qD"
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(потребно је успостављање изван класе)"
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "параметар %qD је успостављен"
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, fuzzy, gcc-internal-format
 #| msgid "Class %qs not found in type declaration"
 msgid "could not find variant declaration"
 msgstr "Класа %qs не налази се у декларацији типа"
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, fuzzy, gcc-internal-format
 #| msgid "%s: recursive invocation of constructor %qs"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%s: рекурзивно позивање конструктора %qs"
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "поновљена декларација набрајача %q+D"
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "%<declare variant%> on deleted %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "додела (не успостављање) у декларацији"
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "складишна класа наведена за %qs"
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D has %<extern%> and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "декларација %q#D има %<extern%> и ипак је успостављена"
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "повратни тип %q#T није потпун"
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "објекат променљиве величине не може се успостављати"
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "заклањање претходне декларације типа за %q#D"
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr ""
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "функција %q#D успостављена као променљива"
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  не може се користити застарело везивање код %q+D јер има деструктор"
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT је неприступачна основа за %qT"
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare variable %q+D to be of abstract type %qT"
 msgid "cannot decompose variable length array %qT"
 msgstr "не може се декларисати променљива %q+D апстрактног типа %qT"
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializer provided for function"
 msgid "%u name provided for structured binding"
@@ -61474,7 +61479,7 @@ msgstr[1] "успостављач дат за функцију"
 msgstr[2] "успостављач дат за функцију"
 msgstr[3] "успостављач дат за функцију"
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -61483,7 +61488,7 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -61492,1923 +61497,1923 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "не може се декларисати показивач на %q#T"
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, fuzzy, gcc-internal-format
 #| msgid "initialization string truncated to match variable at %L"
 msgid "in initialization of structured binding variable %qD"
 msgstr "успостављачка ниска подсечена да одговара променљивој код %L"
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "не може се претворити из типа %qT у %qT"
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "не могу да разложим адресу"
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "не могу применити %<offsetof%> на статички члански податак %qD"
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "успостављач не одређује величину %qD"
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "недостаје величина низа у %qD"
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "низ %qD нулте величине"
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "деструктор за туђинску класу %qT не може бити члан"
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "конструктор за туђинску класу %qT не може бити члан"
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D декларисано као пријатељ"
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D декларисано са одредницом изузетака"
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "дефиниција %qD није у именском простору који обухвата %qT"
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "статичка чланска функција %q#D декларисана са одредбама типа"
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%q+D декларисано као не-параметарско"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "параметар %q+D декларисан са празним типом"
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "јавански метод %qD има не-јавански повратни тип %qT"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "concept %qD has no definition"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a function concept cannot be constrained"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD није шаблонска функција"
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "constrained non-template friend declaration must be a definition"
 msgstr "декларација пријатеља није у дефиницији класе"
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "дефиниција експлицитне специјализације %qD у декларацији пријатеља"
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "неисправна употреба ид. шаблона %qD у декларацији примарног шаблона"
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "подразумевани аргументи нису дозвољени у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> није дозвољено у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "декларација %q#D изван класе није дефиниција"
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "%<::main%> се не може декларисати као шаблон"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "%<::main%> се не може декларисати као уткано"
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "%<::main%> се не може декларисати као статичко"
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "%<::main%> се не може декларисати као статичко"
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "explicit object parameter declared here"
 msgstr "шаблонски параметарски тип %qT декларисан пријатељским"
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr ""
 
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "шаблон са Ц повезивошћу"
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "%qD has invalid argument list"
 msgstr "неисправан аргумент опције %qs"
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "%qD мора бити нестатичка чланска функција"
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> мора враћати %<int%>"
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "дефиниција имплицитно декларисаног %qD"
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "дефиниција имплицитно декларисаног %qD"
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "чланска функција %q#D није декларисана у класи %qT"
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%<::main%> се не може декларисати као шаблон"
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "аутоматска променљива %qE не може бити нитно-локална"
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, fuzzy, gcc-internal-format
 #| msgid "strong using only meaningful at namespace scope"
 msgid "concept must be defined at namespace scope"
 msgstr "јако using има смисла само у досегу именског простора"
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "објекат променљиве величине не може се успостављати"
 
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ИСО Ц++ забрањује успостављање унутар класе неконстантног статичког члана %qD"
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ИСО Ц++ забрањује успостављање чланске константе %qD неинтегралног типа %qT"
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "величина низа %qD има неинтегрални тип %qT"
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "величина низа има неинтегрални тип %qT"
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ИСО Ц++ забрањује низ нулте величине %qD"
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ИСО Ц++ забрањује низ нулте величине"
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array %qD"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ИСО Ц++ забрањује низ променљиве величине %qD"
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ИСО Ц++ забрањује низ променљиве величине"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "преливање у димензији низа"
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not declare a template type"
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%qD не декларише шаблонски тип"
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "creating array of template placeholder type %qT"
 msgstr "стварање показивача на члан упућивачког типа %qT"
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "декларација %qs као низа празних"
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of void"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of functions"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of references"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "creating array of function members"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "декларација %qD као вишедимензионог низа мора имати границе за све димензије осим прве"
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "вишедимензиони низ мора имати границе за све димензије осим прве"
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "навод повратног типа за конструктор није исправан"
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "навод повратног типа за деструктор није исправан"
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "наведен повратни тип за %<operator %T%>"
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "навод повратног типа за деструктор није исправан"
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "превише листа шаблонских параметара у декларацији %qD"
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "сукобљени наводиоци у декларацији %qs"
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "неименована променљива или поље декларисано празним"
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "променљива или поље декларисано празним"
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "наводилац %<inline%> није исправан за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "деструктори не могу бити кн-одређени"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "неисправна употреба одређеног имена %<::%D%>"
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "неисправна употреба одређеног имена %<%T::%D%>"
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "неисправна употреба одређеног имена %<%D::%D%>"
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT није ни класа ни именски простор"
 
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "декларација %qD као не-члана"
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "недостаје ид. декларатора; користи се резервисана реч %qD"
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "дефиниција функције не декларише параметре"
 
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "декларација %qD као %s"
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, fuzzy, gcc-internal-format
 #| msgid "no classes specified"
 msgid "both %qs and %qs specified"
 msgstr "није наведена ниједна класа"
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, fuzzy, gcc-internal-format
 #| msgid "Class %qs not found in type declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "Класа %qs не налази се у декларацији типа"
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "два или више типова података у декларацији %qs"
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ИСО Ц не подржава да обичан %<complex%> значи %<double complex%>"
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ИСО Ц++ забрањује декларацију %qs без типа"
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs није подржано овим циљем"
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ИСО Ц++ не подржава %<long long%>"
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, fuzzy, gcc-internal-format
 #| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> и %<unsigned%> наведени заједно за %qs"
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> и %<short%> наведени заједно за %qs"
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "%qs specified with %qT"
 msgstr "нема имена класе наведеног помоћу %qs"
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, gcc-internal-format
 msgid "%qs specified with typedef-name %qD"
 msgstr ""
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs није наведено у обухватајућем паралелном"
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> употребљено уз %<typedef%>"
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex неисправно за %qs"
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "члан %qD не може бити декларисан и као виртуелни и као статички"
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "члан %qD не може бити декларисан и као виртуелни и као статички"
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "декларација typedef није исправна у декларацији параметра"
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for template parameter %qs"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a parameter cannot be declared %qs"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "virtual изван декларације класе"
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "атрибут игнорисан у декларацији %q+#T"
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "атрибут игнорисан у декларацији %q+#T"
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr ""
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "вишеструке складишне класе у декларацији %qs"
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "складишна класа наведена за %qs"
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "угњеждена функција %qs декларисана као %<extern%>"
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "декларација %qs на највишем нивоу наводи %<auto%>"
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs досега функције имплицитно аутоматска и декларасина као %<__thread%>"
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "наводиоци складишне класе нису исправни у декларацијама пријатељских функција"
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "атрибут %qE се игнорише"
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "вишеструке складишне класе у декларацији %qs"
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "Очекивана је лева заграда"
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, gcc-internal-format
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, gcc-internal-format
 msgid "a function type cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, gcc-internal-format
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr "показивач на чланску функцију употребљен у аритметици"
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr ""
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, gcc-internal-format
 msgid "the type of an explicit object member function is a regular function type"
 msgstr ""
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "valid explicit object parameter declared here"
 msgstr ""
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "неисправна употреба %<restrict%>"
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "одредбе типова се игноришу на повратном типу функције"
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs декларисано као функција која враћа функцију"
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs декларисано као функција која враћа низ"
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "функција са %<noreturn%> враћа непразну вредност"
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "деструктор не може бити статичка чланска функција"
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "конструктор не може бити статичка чланска функција"
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "деструктори не могу бити кн-одређени"
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "конструктори не могу бити кн-одређени"
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "деструктори не могу бити кн-одређени"
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "конструктори не могу бити кн-одређени"
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "конструктор не може бити виртуелан"
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "декларација пријатеља није у дефиницији класе"
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "не може се дефинисати пријатељска функција %qs у дефиницији локалне класе"
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, fuzzy, gcc-internal-format
 #| msgid "non-object member %qs cannot be declared %<mutable%>"
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr "не-објектни члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD cannot be an explicit object member function"
 msgstr "%qD мора бити нестатичка чланска функција"
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "деструктори не могу имати параметре"
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "не може се декларисати показивач на %q#T"
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "не може се декларисати показивач на члан %q#T"
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "не може се декларисати битско поље %qD са функцијским типом"
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "ид. шаблона %qD употребљен као декларатор"
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "чланске функције су имплицитно пријатељи својих класа"
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "сувишна одредба %<%T::%> на члану %qs"
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "не може се дефинисати чланска функција %<%T::%s%> унутар %<%T%>"
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "не може се декларисати функција %<%T::%s%> унутар %<%T%>"
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "не може се декларисати члан %<%T::%s%> унутар %qT"
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "члански податак %qD не може бити члански шаблон"
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "члански податак не може имати променљиво измењив тип %qT"
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "параметар не може имати променљиво измењив тип %qT"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "virtual изван декларације класе"
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> у празној декларацији"
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "само декларације конструктора могу имати %<explicit%>"
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "не-члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "не-објектни члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "функција %qs не може бити декларисана %<mutable%>"
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "статичко %qs не може бити декларисано %<mutable%>"
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "константно %qs не може бити декларисано %<mutable%>"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "функција %qs не може бити декларисана %<mutable%>"
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "typedef may not be a function definition"
 msgstr "атрибути нису дозвољени на дефиницији функције"
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "typedef may not be a member function definition"
 msgstr "атрибути нису дозвољени на дефиницији функције"
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not allowed in other than a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> није дозвољено другде осим у декларацији"
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef declared %<auto%>"
 msgstr "дефиниција типа %q+D декларисана као %<inline%>"
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%Jиме за дефиницију типа не може бити угњеждени-именски-наводилац"
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ИСО Ц++ забрањује угњеждени тип %qD истог имена као и обухватајућа класа"
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> наведено уз декларацију пријатељске класе"
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "декларација пријатеља захтева реч class, тј. %<friend class %T::%D%>"
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "декларација пријатеља захтева реч class, тј. %<friend %#T%>"
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "покушај да се класа %qT учини пријатељем глобалног досега"
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "неисправне одредбе уз тип не-чланске функције"
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "апстрактни декларатор %qT употребљен као декларација"
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "поновљена декларација Ц++ уграђеног типа %qT"
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "не може се декларисати параметар %q+D апстрактног типа %qT"
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<this%> се не може употребити у овом контексту"
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter declared %<auto%>"
 msgstr "параметар %q+D декларисан као %<inline%>"
 
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "неисправна употреба шаблонског имена %qE без листе аргумената"
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ИСО Ц++ забрањује низ нулте величине %qD"
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ИСО Ц 90 не подржава флексибилне чланске низове"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "неисправна употреба %<::%>"
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "декларација Ц функције %q#D коси се са"
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "функција %qD декларисана виртуелном унутар уније"
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD не може бити декларисана виртуелном, јер је увек статичка"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "очекивано одређено име у декларацији пријатеља за деструктор %qD"
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "декларација %qD као члана %qT"
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a destructor cannot be %qs"
 msgstr "Конструктор не може бити %s"
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, fuzzy, gcc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "очекивано одређено име у декларацији пријатеља за деструктор %qD"
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a constructor cannot be %<concept%>"
 msgstr "Конструктор не може бити %s"
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "конструктор не може бити статичка чланска функција"
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "не могу да отворим %s"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "специјализација имплицитно декларисане посебне чланске функције"
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "променљива или поље декларисано празним"
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "поље %qD има непотпун тип"
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "име %qT има непотпун тип"
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE није ни функција ни чланска функција; не може се декларисати пријатељем"
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE није ни функција ни чланска функција; не може се декларисати пријатељем"
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "static data member %qE declared %qs"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "Сопствено ‘%s’ код %L не може имати успостављач"
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "складишна класа %<auto%> неисправна за функцију %qs"
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "складишна класа %<register%> неисправна за функцију %qs"
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "складишна класа %<__thread%> неисправна за функцију %qs"
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "складишна класа %<__thread%> неисправна за функцију %qs"
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr "наводилац %<inline%> није исправан за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "навод asm није дозвољен на дефиницији функције"
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> неисправно наведено за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "наводилац %<inline%> није исправан за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "виртуелна не-класна функција %qs"
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, fuzzy, gcc-internal-format
 #| msgid "No variable %qs defined in class %qs"
 msgid "%qs defined in a non-class scope"
 msgstr "Променљива %qs није дефинисана у класи %qs"
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qD није декларисано у овом досегу"
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "не може се декларисати статичка повезивост за чланску функцију %qD"
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "не може се декларисати статичка функција унутар друге функције"
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> не може бити употребљено при дефинисању (насупрот декларисања) статичког чланског податка"
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "не може се експлицитно декларисати спољашња повезивост за члан %q#D"
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "декларација спољашње променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "статичко %qs не може бити декларисано %<mutable%>"
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs успостављено и декларисано као %<extern%>"
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs има и %<extern%> и успостављач"
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "подразумевани аргумент %qE користи локалну променљиву %qD"
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "подразумевани аргумент %qE користи локалну променљиву %qD"
 
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "наводиоци складишне класе нису исправни у декларацијама параметара"
 
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "параметар %qD неисправно декларише тип метода"
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "параметар %qD укључује %s у низ непознатих граница %qT"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "параметар %qD укључује %s у низ непознатих граница %qT"
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "неисправан конструктор; вероватно сте мислили %<%T (const %T&)%>"
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD не може бити декларисано унутар именског простора"
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD не може бити декларисано статичко"
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD мора бити нестатичка чланска функција"
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a member function"
 msgstr "%qD мора бити нестатичка чланска функција"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD мора бити или нестатичка чланска функција или не-чланска функција"
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD мора имати аргумент класног или набројивог типа"
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ИСО Ц++ забрањује препуњавање оператора ?:"
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD не може имати променљив број аргумената"
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD мора узимати ниједан или један аргумент"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD мора узимати један или два аргумента"
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "постфиксно %qD мора узимати %<int%> као аргумент"
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "постфиксно %qD мора узимати %<int%> као други аргумент"
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD мора узимати тачно два аргумента"
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD мора узимати тачно један аргумент"
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD мора узимати тачно два аргумента"
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "кориснички дефинисано %qD увек израчунава оба аргумента"
 
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "префиксно %qD треба да враћа %qT"
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "постфиксно %qD треба да враћа %qT"
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD треба да враћа по вредност"
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization %qD for %q+D"
 msgid "using alias template specialization %qT after %qs"
 msgstr "двосмислена специјализација шаблона %qD за %q+D"
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "употреба typedef-имена %qD после %qs"
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D има претходну декларацију овде"
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT се помиње као %qs"
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T има претходну декларацију овде"
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT се помиње као набрајање"
@@ -63420,121 +63425,103 @@ msgstr "%qT се помиње као набрајање"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "потребан шаблонски аргумент за %<%s %T%>"
 
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "двосмислено упућивање на %qD"
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "class template %qD redeclared as non-template"
 msgstr "%qD употребљено као шаблон, а није"
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD има исто име као и класа у којој је декларисано"
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT није шаблон"
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "употреба набрајања %q#D без претходне декларације"
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "поновљена декларација %qT као не-шаблона"
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare %qD to be a bit-field type"
-msgid "cannot declare %qD in a different module"
-msgstr "%qD се не може декларисати као тип битског поља"
-
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D previously declared here"
-msgid "previously declared here"
-msgstr "%q+#D претходно декларисано овде"
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "неисправна изведена унија %qT"
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "тип %qT није непосредна или виртуелна основа од %qT"
 
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "тип основе %qT није класа или структура"
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "недефинисан рекурзивни тип %qT"
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "неисправан удвостручен тип основе %qT"
 
-#: cp/decl.cc:16984
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare %qD to be a bit-field type"
-msgid "cannot declare %qD in different module"
-msgstr "%qD се не може декларисати као тип битског поља"
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%Jпретходна дефиниција је овде"
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "underlying type %qT of %qT must be an integral type"
@@ -63544,91 +63531,91 @@ msgstr "Крејов показивач код %C мора бити целобр
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ниједан интегрални тип не може представљати све вредности набрајача за %qT"
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD not integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "вредност набрајача за %qD није целобројна константа"
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "преливање у вредностима набрајача код %qD"
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "вишеструке дефиниције %q#T"
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "повратни тип %q#T није потпун"
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> треба да враћа упућивач на %<*this%>"
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "повратни типови функција нису сагласни услед %<volatile%>"
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD је већ дефинисано у класи %qT"
 
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, fuzzy, gcc-internal-format
 #| msgid "Processing %s\n"
 msgid "using %qs"
 msgstr "Обрађујем %s\n"
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -63684,7 +63671,7 @@ msgstr "не може се обрисати функција. Само пока
 msgid "deleting %qT is undefined"
 msgstr "брисање %qT није дефинисано"
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "декларација шаблона %q#D"
@@ -63695,7 +63682,7 @@ msgstr "декларација шаблона %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "параметри шаблона се не поклапају са шаблоном"
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "деструктор %qD декларисан као члански шаблон"
@@ -63895,73 +63882,73 @@ msgstr ""
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> узима тип %<size_t%> (%qT) као први параметар"
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr "%qT има поље %qD чији тип користи анонимни именски простор"
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT има поље %qD чији тип користи анонимни именски простор"
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr "%qT има поље %qD чији тип користи анонимни именски простор"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr "%qT има поље %qD чији тип користи анонимни именски простор"
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT декларисано са већом видљивошћу од типа његовог поља %qD"
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT which has no linkage"
 msgstr "%qT има основу %qT чији тип користи анонимни именски простор"
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr "%qT има основу %qT чији тип користи анонимни именски простор"
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT which has internal linkage"
 msgstr "%qT има основу %qT чији тип користи анонимни именски простор"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr "%qT има основу %qT чији тип користи анонимни именски простор"
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT декларисано са већом видљивошћу од своје основе %qT"
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but not defined"
 msgstr ""
@@ -63970,114 +63957,114 @@ msgstr ""
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D не упућује на неодређени тип, тако да се не користи за повезивост"
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr ""
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "претходна декларација %q+#D са повезивошћу %qL"
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, fuzzy, gcc-internal-format
 #| msgid "section of %q+D conflicts with previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "одељак за %q+D коси се са претходном декларацијом"
 
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous mangling %q#D"
 msgstr "претходна декларација %q+D"
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, gcc-internal-format
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "уткана функција %q+D употребљена али недефинисана"
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, fuzzy, gcc-internal-format
 #| msgid "default argument missing for parameter %P of %q+#D"
 msgid "default argument missing for parameter %P of %q#D"
 msgstr "недостаје подразумевани аргумент за параметар %P од %q+#D"
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, gcc-internal-format
 msgid "...following parameter %P which has a default argument"
 msgstr ""
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "implicitly-declared %qD is deprecated"
 msgstr "дефиниција имплицитно декларисаног %qD"
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "use of deleted function %qD"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -64185,7 +64172,7 @@ msgstr "двосмислено упућивање на %<%T::%D%>"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD није члан у %qT"
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD није члан у %qT"
@@ -64196,7 +64183,7 @@ msgstr "%qD није члан у %qT"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD није члан у %qD"
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD није члан у %qD"
@@ -64223,52 +64210,52 @@ msgstr "руковање изузецима је искључено, укључ
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr "баца се NULL, које има интегрални, а не показивачки тип"
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, gcc-internal-format
 msgid "  in thrown expression"
 msgstr "  у баченом изразу"
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr "не може се декларисати параметар %q+D апстрактног типа %qT"
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create type information for type %qT because it involves types of variable size"
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr "не могу се створити подаци о типу за %qT, јер укључује типове променљиве величине"
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create type information for type %qT because it involves types of variable size"
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr "не могу се створити подаци о типу за %qT, јер укључује типове променљиве величине"
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexception of type %qT will be caught"
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr "%Hбиће ухваћен изузетак типа %qT"
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, gcc-internal-format
 msgid "for type %qT"
 msgstr ""
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<...%> handler must be the last handler for its try block"
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr "%Hруковалац %<...%> мора бити последњи у свом блоку покушаја"
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr ""
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
 msgstr ""
@@ -64559,12 +64546,12 @@ msgstr "тип %qT није непосредна или виртуелна ос
 msgid "type %qT is not a direct base of %qT"
 msgstr "тип %qT није непосредна основа од %qT"
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "успостављач низа мора бити нешто у витичастим заградама"
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%qT is not a class type"
@@ -64580,12 +64567,12 @@ msgstr "непотпун тип %qT нема члан %qD"
 msgid "invalid pointer to bit-field %qD"
 msgstr "неисправан показивач на битско поље %qD"
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "неисправна употреба нестатичког чланског податка %qD"
@@ -64794,55 +64781,55 @@ msgstr ""
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "тип уз векторско delete није ни показивачки ни низовни"
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, fuzzy, gcc-internal-format
 #| msgid "compound literal has variable size"
 msgid "because the array element type %qT has variable size"
 msgstr "сложена дословна ниска има променљиву величину"
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot capture %qE by reference"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "capture by copy of incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<this%> was not captured for this lambda function"
@@ -65242,239 +65229,290 @@ msgstr "очекивана је декларација или наредба"
 msgid "encapsulation is malformed"
 msgstr ""
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting global module declaration %#qD"
 msgstr "сукобљена декларација %q#D"
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration %q+D"
 msgid "existing declaration %#qD"
 msgstr "у декларацији %q+D"
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, fuzzy, gcc-internal-format
 #| msgid "extern declaration of %q#D doesn't match"
 msgid "definition of %qD does not match"
 msgstr "спољашња декларација %q#D не слаже се"
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, fuzzy, gcc-internal-format
 #| msgid "missing definition"
 msgid "existing definition %qD"
 msgstr "недостаје дефиниција"
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "... this enumerator %qD"
 msgstr "поновљена декларација набрајача %q+D"
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "enumerator %qD does not match ..."
 msgstr "аргумент типа %qT не поклапа се са %qT"
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr ""
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr ""
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr ""
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, gcc-internal-format
 msgid "recursive lazy load"
 msgstr ""
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr ""
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "module %qs declared here"
 msgstr "%q+D декларисано овде"
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, gcc-internal-format
 msgid "indirect import %qs is not already loaded"
 msgstr ""
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr ""
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr ""
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "macro definitions of %qE corrupted"
 msgstr "  из дефиниције %q+#D"
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, fuzzy, gcc-internal-format
 #| msgid "inconsistent instance variable specification"
 msgid "inconsistent imported macro definition %qE"
 msgstr "неусаглашена одредница променљиве примерка"
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr ""
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr ""
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "compiled module file is %qs"
 msgstr "нисам могао да отворим датотеку пописа %qs: %s"
 
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collect2 version %s"
 msgid "compiled module is %sversion %s"
 msgstr "collect2 верзија %s"
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collect2 version %s"
 msgid "compiler is %sversion %s%s%s"
 msgstr "collect2 верзија %s"
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs not found"
 msgid "module %qs found"
 msgstr "поље %qs није нађено"
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr ""
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr ""
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr ""
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr ""
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, gcc-internal-format
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr ""
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, fuzzy, gcc-internal-format
 #| msgid "field initializer type mismatch"
 msgid "fixed tree mismatch"
 msgstr "неслагање типа успостављача поља"
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "interface partition is not exported"
 msgstr "израз ограничења стека није подржан"
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module cluster %u: %s"
 msgstr ""
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module: %s"
 msgstr ""
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr ""
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr ""
 
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr ""
 
-#: cp/module.cc:19283
+#: cp/module.cc:19117
+#, fuzzy, gcc-internal-format
+#| msgid "declaration of namespace %qD conflicts with"
+msgid "declaration %qD conflicts with builtin"
+msgstr "декларација именског простора %qD коси се са"
+
+#: cp/module.cc:19122
+#, fuzzy, gcc-internal-format
+#| msgid "declaration of namespace %qD conflicts with"
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr "декларација именског простора %qD коси се са"
+
+#: cp/module.cc:19125
+#, gcc-internal-format
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr ""
+
+#: cp/module.cc:19130
+#, gcc-internal-format
+msgid "import declared attached to module %qs"
+msgstr ""
+
+#: cp/module.cc:19134
+#, gcc-internal-format
+msgid "import declared in global module"
+msgstr ""
+
+#: cp/module.cc:19140
+#, fuzzy, gcc-internal-format
+#| msgid "conflicting declaration %q#D"
+msgid "conflicting declaration of %qD in module %qs"
+msgstr "сукобљена декларација %q#D"
+
+#: cp/module.cc:19143
+#, fuzzy, gcc-internal-format
+#| msgid "conflicting declaration %q#D"
+msgid "conflicting declaration of %qD in global module"
+msgstr "сукобљена декларација %q#D"
+
+#: cp/module.cc:19148
+#, fuzzy, gcc-internal-format
+#| msgid "previous declaration of %qs"
+msgid "previously declared in module %qs"
+msgstr "претходна декларација %qs"
+
+#: cp/module.cc:19152
+#, fuzzy, gcc-internal-format
+#| msgid "%q+#D previously declared here"
+msgid "previously declared in global module"
+msgstr "%q+#D претходно декларисано овде"
+
+#: cp/module.cc:19404
 #, fuzzy, gcc-internal-format
 #| msgid "creating %s"
 msgid "reading CMI %qs"
 msgstr "прави %s"
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, gcc-internal-format
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, gcc-internal-format
 msgid "during load of pendings for %<%E%s%E%>"
 msgstr ""
@@ -65486,326 +65524,326 @@ msgstr ""
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr ""
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "module already declared"
 msgstr "Компонента ‘%s’ код %C већ је декларисана код %L"
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, gcc-internal-format
 msgid "module already imported"
 msgstr ""
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, gcc-internal-format
 msgid "module %qs imported here"
 msgstr ""
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown Compiled Module Interface: %s"
 msgstr ""
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr ""
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr ""
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr ""
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, gcc-internal-format
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr ""
 
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, fuzzy, gcc-internal-format
 #| msgid "Enable traditional preprocessing"
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr "Укључи традиционалну предобраду"
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr ""
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr ""
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, gcc-internal-format
 msgid "you should use the %<-%s%> option"
 msgstr ""
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter %qs"
 msgid "invalid header name %qs"
 msgstr "неисправан параметар %qs"
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, fuzzy, gcc-internal-format
 #| msgid "%s: invalid file name: %s\n"
 msgid "invalid module name %qs"
 msgstr "%s: неисправно име датотеке: %s\n"
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr ""
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, fuzzy, gcc-internal-format
 #| msgid "error writing %qs"
 msgid "writing CMI %qs"
 msgstr "грешка при писању %qs"
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing modules file: %s"
 msgid "not writing module %qs due to errors"
 msgstr "Грешка при писању датотеке модула: %s"
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to write compiled module: %s"
 msgstr ""
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown header kind %qs"
 msgstr "непознат машински режим %qs"
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, gcc-internal-format
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr ""
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D shadows a parameter"
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "декларација %q#D заклања параметар"
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D се коси са претходном декларацијом употребе %q#D"
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D скрива конструктор за %q#T"
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "сукобљена декларација %q#D"
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, fuzzy, gcc-internal-format
 #| msgid "Generate code to check exception specifications"
 msgid "due to different exception specifications"
 msgstr "Створи кôд за проверу одредница изузетака"
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "параметар %qD неисправно декларише тип метода"
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "декларација %q#D заклања параметар"
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "декларација %qD као члана %qT"
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, fuzzy, gcc-internal-format
 #| msgid "using declaration %q+D conflicts with a previous using declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "декларација коришћења %q+D коси се са претходном декларацијом коришћења"
 
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, gcc-internal-format
 msgid "exporting %q#D that does not have external linkage"
 msgstr ""
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as reference but not initialized"
 msgid "%q#D declared here with no linkage"
 msgstr "%qD декларисано као упућивач али није успостављено"
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, fuzzy, gcc-internal-format
 #| msgid "%qD redeclared with different access"
 msgid "%q#D declared here with internal linkage"
 msgstr "%qD поново декларисано са другачијим приступом"
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, fuzzy, gcc-internal-format
 #| msgid "%qD redeclared with different access"
 msgid "%q#D declared here with module linkage"
 msgstr "%qD поново декларисано са другачијим приступом"
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names destructor"
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T::%D%> именује деструктор"
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "декларација употребе за не-члан у досегу класе"
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qT није ни класа ни именски простор"
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr ""
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "декларација употребе за не-члан у досегу класе"
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "%qT is not a direct base of %qT"
 msgstr "тип %qT није непосредна основа од %qT"
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has not been declared"
 msgid "%qD has not been declared in %qD"
 msgstr "%qD није декларисано"
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD not in a namespace surrounding %qD"
 msgid "using-declaration may not name namespace %qD"
 msgstr "декларација %qD није у именском простору који окружује %qD"
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> именује конструктор у %qT"
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "декларација %qD није у именском простору који окружује %qD"
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "експлицитна одредба у декларацији %qD"
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD треба да је декларисано унутар %qD"
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has not been declared"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD није декларисано"
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D декларисано као пријатељ"
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires a single NTBS argument"
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "атрибут %qs захтева тачно један НТБС аргумент"
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "атрибутска директива %qD игнорисана"
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -65814,105 +65852,105 @@ msgstr[1] ""
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %qE"
 msgstr "  %q+#D"
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr ""
 
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<this%> није доступно за статичке чланске функције"
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has not been declared"
 msgid "the macro %qs had not yet been defined"
 msgstr "%qD није декларисано"
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "it was later defined here"
 msgstr "%J%qD декларисано овде"
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "прекидач %qs више није подржан"
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr "%<this%> се не може употребити у овом контексту"
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD не може бити декларисано унутар именског простора"
 
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "Двосмислено име типа ‘%s’ код %C"
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "алијас именског простора %qD није дозвољен овде, претпостављам %qD"
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD defined here"
 msgstr "%q+D декларисано овде"
 
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, fuzzy, gcc-internal-format
 #| msgid "address area of %q+D conflicts with previous declaration"
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "адресна област за %q+D коси се са претходном декларацијом"
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "reachable %s definition here"
 msgstr "%Jпретходна дефиниција је овде"
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX entering pop_everything ()\n"
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -65939,7 +65977,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -66215,7 +66253,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
@@ -66414,7 +66452,7 @@ msgstr "наредбени изрази дозвољени су само уну
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected primary-expression"
@@ -66473,7 +66511,7 @@ msgstr ""
 msgid "template-id not allowed for destructor in C++20"
 msgstr ""
 
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, gcc-internal-format
 msgid "remove the %qs"
 msgstr ""
@@ -66494,7 +66532,7 @@ msgstr "typedef-име %qD употребљено као декларатор д
 msgid "expected unqualified-id"
 msgstr "очекивана је листа наводилаца-одредби"
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD није шаблон"
@@ -66552,7 +66590,7 @@ msgstr "не могу се дефинисати нови типови у пов
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "неподржан аргумент за %<__builtin_frame_address%>"
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -66591,7 +66629,7 @@ msgstr "не могу се дефинисати нови типови у пов
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr ""
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "неисправна употреба %qD"
@@ -66619,7 +66657,7 @@ msgstr "ИСО Ц++ не дозвољава утврђене успостављ
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %qs expressions"
@@ -66781,8 +66819,8 @@ msgstr ""
 msgid "capture of non-variable %qE"
 msgstr "увећање само-за-читање променљиве %qD"
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here"
@@ -66824,7 +66862,7 @@ msgstr "подразумевани аргумент дат за парамета
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr ""
@@ -66955,7 +66993,7 @@ msgstr "неопходна л-вредност у asm наредби"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
@@ -67024,7 +67062,7 @@ msgstr "наредба израза има непотпун тип"
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
@@ -67051,7 +67089,7 @@ msgstr ""
 msgid "ISO C++ forbids computed gotos"
 msgstr "ИСО Ц++ забрањује рачунско goto"
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
@@ -67355,13 +67393,13 @@ msgstr "само конструктори узимају успостављач
 msgid "cannot expand initializer for member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "статичка декларација %q+D прати нестатичку декларацију"
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -68067,7 +68105,7 @@ msgstr "недостаје справљачки циљ после %qs"
 msgid "%qT not permitted in template argument"
 msgstr "грешка у рашчлањивању листе шаблонских аргумената"
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
@@ -68270,12 +68308,12 @@ msgstr "претходна дефиниција %q+#T"
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, gcc-internal-format
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr ""
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
@@ -68496,40 +68534,40 @@ msgstr ""
 msgid "expression must be enclosed in parentheses"
 msgstr "наредба израза има непотпун тип"
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr ""
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "захтевани положај није целобројна константа"
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "захтевано равнање није константа"
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "неисправна поновљена декларација %q+D"
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "премало листа параметара шаблона"
@@ -68538,493 +68576,493 @@ msgstr "премало листа параметара шаблона"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "превише листа шаблонских параметера"
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, gcc-internal-format
 msgid "template-id not allowed for constructor in C++20"
 msgstr ""
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "именоване повратне вредности нису више подржане"
 
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "поклапајући шаблон за %qD није нађен"
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "неисправна декларација чланског шаблона у локалној класи"
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "шаблон са Ц повезивошћу"
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "неисправан навод основне класе"
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %qs"
 msgid "template declaration of %<typedef%>"
 msgstr "декларација шаблона %qs"
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "декларација ништа не декларише"
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization in non-namespace scope %qD"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "експлицитна специјализација у не-именскопросторном досегу %qD"
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> треба да је %<> >%> унутар угњеждене листе шаблонских аргумената"
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "сувишно %<>>%>, користите %<>%> за затварање листе шаблонских аргумената"
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, fuzzy, gcc-internal-format
 #| msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr "сувишно %<>>%>, користите %<>%> за затварање листе шаблонских аргумената"
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "неисправна употреба %qD у одредници повезивости"
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qs"
 msgid "duplicate %qD specifier"
 msgstr "удвостручено %qs"
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, fuzzy, gcc-internal-format
 #| msgid "  conflict with %q+D"
 msgid "%qD specifier conflicts with %qs"
 msgstr "  коси се са %q+D"
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> пре %qD"
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, gcc-internal-format
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr ""
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ИСО Ц++ не подржава %<long long%>"
 
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, fuzzy, gcc-internal-format
 #| msgid "both %<short%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "и %<short%> и %<char%> у наводиоцима декларације"
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "удвостручено %qE"
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "удвостручено %qs"
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "очекивана је наредба"
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<auto%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<co_yield%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "ознака %qs употребљена при именовању %q#T"
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "%q+#D претходно декларисано овде"
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared with greater visibility than its base %qT"
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT декларисано са већом видљивошћу од своје основе %qT"
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, fuzzy, gcc-internal-format
 #| msgid "template class without a name"
 msgid "replace the class-key with %qs"
 msgstr "шаблонска класа без имена"
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qT defined as %qs here"
 msgstr "%qT се помиње као %qs"
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "%qT first declared as %qs here"
 msgstr "%J%qD декларисано овде"
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD поново декларисано са другачијим приступом"
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (као разјашњење двосмислености) дозвољено је само унутар шаблона"
 
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "датотека се завршава подразумеваним аргументом"
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "конструкција %<@%D%> објективног Ц++а на погрешном месту"
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> мора навести тип као аргумент"
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "неисправно име селектора објективног Ц++а"
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, fuzzy, gcc-internal-format
 #| msgid "Class or interface declaration expected"
 msgid "objective-c++ method declaration is expected"
 msgstr "Очекивана је декларација класе или сучеља"
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%Jатрибут одељка се не може навести за локалне променљиве"
 
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "invalid type for instance variable"
 msgstr "%Hнеисправан тип променљиве итерације %qE"
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "очекиван је идентификатор после %<@protocol%>"
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "атрибут %qE се игнорише за %qE"
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr ""
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "очекиван је целобројни израз"
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "неисправан успостављач"
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in iterator type"
@@ -69034,13 +69072,13 @@ msgstr "не могу се дефинисати нови типови у пов
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma vtable no longer supported"
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "#pragma vtable више није подржано"
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
@@ -69050,146 +69088,146 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qD should not be reduction"
 msgstr "не би требало да променљива итерације %qs буде свођена"
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp section%> може бити употребљено само у конструкцији %<#pragma omp sections%>"
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr ""
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "неисправан успостављач"
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "очекиван је израз"
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD није чланска шаблонска функција"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "смеће на крају %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp flush%> може бити употребљено само у сложеним наредбама"
 
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC diagnostic not allowed inside functions"
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "multi-source compilation not implemented for C++"
 msgstr "унутармодулске оптимизације нису имплеметиране за Ц++"
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "стандардна претварања нису дозвољена у овом контексту"
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "шаблони не могу бити виртуелни"
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -69220,7 +69258,7 @@ msgstr "обухватајући шаблони класа не бивају е
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "специјализација %qD у различитом именском простору"
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "специјализација %qD у различитом именском простору"
@@ -69236,28 +69274,28 @@ msgstr "  из дефиниције %q+#D"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "експлицитно извођење %qD у именском простору %qD (који не обухвата простор %qD)"
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "име класе заклања шаблонски шаблонски параметар %qD"
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "specialization of alias template %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "експлицитна специјализација не-шаблонског %qT"
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "специјализација %qT после извођења"
 
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "from definition of %q#D"
@@ -69265,156 +69303,156 @@ msgstr "  из дефиниције %q+#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "специјализација %qT после извођења %qT"
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "делимична специјализација шаблона функције %qD није дозвољена"
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "специјализација %qD после извођења"
 
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD није шаблон функције"
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a variable template"
 msgstr "%qD није шаблон"
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "ид. шаблона %qD за %q+D не одговара ниједној декларацији шаблона"
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "двосмислена специјализација шаблона %qD за %q+D"
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "поклапајући шаблон за %qD није нађен"
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "експлицитна специјализација %qD после прве употребе"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "експлицитно извођење %qD у именском простору %qD (који не обухвата простор %qD)"
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "експлицитна специјализација %qD после прве употребе"
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attributes %s"
 msgstr "недостаје атрибут Code"
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attribute %s"
 msgstr "недостаје атрибут Code"
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD in declaration of primary template"
 msgid "template-id %qE in declaration of primary template"
 msgstr "ид. шаблона %qD у декларацији примарног шаблона"
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "листа шаблонских параметара употребљена у експлицитном извођењу"
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "дефиниција дата за експлицитно извођење"
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "превише листа шаблонских параметара у декларацији %qD"
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "премало листа шаблонских параметара у декларацији %qD"
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "експлицитна специјализација %qD мора бити уведена помоћу %<template <>%>"
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "експлицитна специјализација не-шаблонског %qT"
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "делимична специјализација шаблона функције %qD није дозвољена"
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "делимична специјализација шаблона функције %qD није дозвољена"
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "наведен подразумевани аргумент у експлицитној специјализацији"
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD није шаблонска функција"
@@ -69427,151 +69465,151 @@ msgstr "%qD није шаблонска функција"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "специјализација имплицитно декларисане посебне чланске функције"
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "нема чланске функције %qD декларисане у %qT"
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "декларација пријатеља није у дефиницији класе"
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
 msgid "friend declaration here"
 msgstr "%Jзаклоњена декларација је овде"
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "експлицитна специјализација не-шаблонског %qT"
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "Аргумент у ACOS код %L мора бити између -1 и 1"
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "        %qD"
 msgid "        %s"
 msgstr "        %qD"
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "шаблонски параметарски тип %qT декларисан пријатељским"
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "specialization of variable concept %q#D"
 msgstr "експлицитна специјализација не-шаблонског %qT"
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "шаблонски параметри неискоришћени у делимичној специјализацији:"
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "делимична специјализација %qT не специјализује ниједан шаблонски аргумент"
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments for partial specialization %qT"
 msgstr "превише аргумената за функцију %qs"
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "делимична специјализација %qT не специјализује ниједан шаблонски аргумент"
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "primary template %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT of template argument %qE depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -69581,19 +69619,19 @@ msgstr[1] "тип %qT шаблонског аргумента %qE зависи 
 msgstr[2] "тип %qT шаблонског аргумента %qE зависи од шаблонских параметара"
 msgstr[3] "тип %qT шаблонског аргумента %qE зависи од шаблонских параметара"
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "специјализација %qD после извођења"
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "нема подразумеваног аргумента за %qD"
@@ -69602,53 +69640,53 @@ msgstr "нема подразумеваног аргумента за %qD"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%qD употребљено без параметара шаблона"
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "подразумевани аргументи нису дозвољени у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "шаблонски параметри неискоришћени у делимичној специјализацији:"
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "шаблонски параметри неискоришћени у делимичној специјализацији:"
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "подразумевани аргумент за параметар типа %qT има тип %qT"
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "параметар %qD декларисан празним"
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "шаблонска класа без имена"
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -69659,65 +69697,65 @@ msgstr "%sчланска функција %qD не може имати кн-од
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "неисправна декларација шаблона %qD"
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "шаблонска дефиниција нешаблонског %q#D"
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "очекивах %d нивоа шаблонских параметара за %q#D, добих %d"
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "добих %d шаблонских параметара за %q#D"
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "добих %d шаблонских параметара за %q#T"
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  а потребно је %d"
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "параметри шаблона се не поклапају са шаблоном"
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "обухватајући шаблони класа не бивају експлицитно специјализовани"
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "redeclaration of %qD with different constraints"
 msgstr "декларација %qF баца различите изузетке"
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT није шаблонски тип"
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "наводиоци шаблона нису задати у декларацији %qD"
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -69727,7 +69765,7 @@ msgstr[1] "%qD употребљено без параметара шаблона
 msgstr[2] "%qD употребљено без параметара шаблона"
 msgstr[3] "%qD употребљено без параметара шаблона"
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration %qD used %d template parameter"
@@ -69737,486 +69775,486 @@ msgstr[1] "претходном декларацијом %q+#D овде"
 msgstr[2] "претходном декларацијом %q+#D овде"
 msgstr[3] "претходном декларацијом %q+#D овде"
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "шаблонски параметар %q+#D"
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "поново декларисано овде као %q#D"
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as %q#D"
 msgid "redeclared here"
 msgstr "поново декларисано овде као %q#D"
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "декларација %qF баца различите изузетке"
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "%J  првобитна дефиниција налази се овде"
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "redeclaration of %q#D with different constraints"
 msgstr "декларација %qF баца различите изузетке"
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је показивач"
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер објекат %qD нема спољашњу повезивост"
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(показивач на члан може бити формиран само помоћу %<&%E%>)"
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qT није члан из %qT"
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "добих %d шаблонских параметара за %q#D"
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "  mismatched types %qT and %qT"
 msgstr "поређење између типова %q#T и %q#T"
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "шаблонски аргумент %qE уплиће шаблонске параметре"
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs није исправно за %qs"
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "Неусаглашени рангови за оператор код %L и %L"
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "делимична специјализација %qT не специјализује ниједан шаблонски аргумент"
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "Наредбена функција ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "не може се претворити из типа %qT у %qT"
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT је двосмислена основа за %qT"
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "  %qT is not derived from %qT"
 msgstr "тип %qT није изведен из типа %qT"
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "аргумент типа %qT не поклапа се са %qT"
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qE није променљива"
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qE није променљива"
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "the address of %qD is not a valid template argument"
 msgstr "адреса за %qD ће увек бити израчуната као %<true%>"
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD није исправан шаблонски аргумент јер је %qD променљива, а не адреса неке променљиве"
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD није исправан шаблонски аргумент јер је %qD променљива, а не адреса неке променљиве"
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер се константне ниске не могу користити у овом контексту"
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, fuzzy, gcc-internal-format
 #| msgid "template argument for %qD uses local type %qT"
 msgid "in template argument for type %qT"
 msgstr "шаблонски аргумент за %qD користи локални тип %qT"
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер се коси са кн-одредбом"
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер није л-вредност"
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a non-constant expression"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер није константан израз"
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је показивач"
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "покушајте са %qE уместо тога"
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је типа %qT"
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes on template argument %qT"
 msgstr "примењивање атрибута на шаблонске параметре није имплементирано"
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, fuzzy, gcc-internal-format
 #| msgid "Ignoring statement label in empty statement at %C"
 msgid "ignoring attributes in template argument %qE"
 msgstr "Игноришем етикету наредбе у празној наредби код %C"
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, fuzzy, gcc-internal-format
 #| msgid "name of class shadows template template parameter %qD"
 msgid "injected-class-name %qD used as template template argument"
 msgstr "име класе заклања шаблонски шаблонски параметар %qD"
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of destructor %qD as a type"
 msgid "invalid use of destructor %qE as a type"
 msgstr "неисправна употреба деструктора %qD као типа"
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "да упутите на тип шаблонског параметра, употребите %<typename %E%>"
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "неслагање типа/вредности код аргумента %d у листи шаблонских параметара за %qD"
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  очекивах константу типа %qT, добих %qT"
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  очекивах шаблон класе, добих %qE"
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  очекивах тип, добих %qE"
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr " очекивах тип, добих %qT"
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  очекивах шаблон класе, добих %qT"
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  очекивах шаблон типа %qD, добих %qD"
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "неслагање типа/вредности код аргумента %d у листи шаблонских параметара за %qD"
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  очекивах тип, добих %qE"
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "нисам могао да претворим шаблонски аргумент %qE у %qT"
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "неисправан шаблонски аргумент %d"
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "погрешан број шаблонских аргумената ((%d, а треба %d)"
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "погрешан број шаблонских аргумената ((%d, а треба %d)"
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "дат за %q+D"
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "подразумевани аргумент дат за параметар %d у %q#D"
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD није шаблон функције"
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "нешаблонски тип %qT употребљен као шаблон"
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "за декларацију шаблона %q+D"
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "template constraint failure for %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "употреба %qs у шаблону"
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d (употребите -ftemplate-depth-NN да повећате дубину) извођења %qD"
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr ""
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "score argument must be non-negative"
 msgstr "аргумент за „%s“ треба да је ненегативан цео број"
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr ""
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "%Jфлексибилан члански низ у унији"
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE није на почетку декларације"
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "поновљена дефиниција подразумеваног аргумента за %q#D"
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "стварање показивача на чланску функцију некласног типа %qT"
 
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, gcc-internal-format, gfc-internal-format
 msgid "mismatched argument pack lengths (%d vs %d)"
 msgstr ""
@@ -70234,324 +70272,324 @@ msgstr ""
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "променљива %qD има функцијски тип"
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "неисправан тип параметра %qT"
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "у декларацији %q+D"
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "функција враћа низ"
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "функција враћа функцију"
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "обликовање упућивача на празно"
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "обликовање %s на тип упућивача %qT"
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "обликовање %s на тип упућивача %qT"
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring %qV qualifiers added to function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "игнорисање %qV одредбе додате функцијском типу %qT"
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring %qV qualifiers added to function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "игнорисање %qV одредбе додате функцијском типу %qT"
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "стварање показивача на члан упућивачког типа %qT"
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "стварање показивача на члан празног типа"
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "стварање низа типа %qT"
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT није тип класе, структуре, нити уније"
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT се разрешава до %qT, што није набројиви тип"
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT се разрешава до %qT, што није класни тип"
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "употреба %qs у шаблону"
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "одређени тип %qT не поклапа се са именом деструктора ~%qT"
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "зависно име %qE рашчлањује се као не-тип, али извођење производи тип"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "ставите %<typename %E%> ако мислите на тип"
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr ""
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "неисправна употреба израза празног типа"
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, fuzzy, gcc-internal-format
 #| msgid "%<...%> as arguments.)"
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> за аргументе.)"
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "use %<%T::%D%> instead"
 msgstr "%<%T::%D%> није тип"
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%H%qE недекларисано овде (не у функцији)"
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "неподржан аргумент за %<__builtin_return_address%>"
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "погрешан број аргумената наведне за атрибут %qs"
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT није ни класа ни именски простор"
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD није ни класа ни именски простор"
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "употреба неисправног поља %qD"
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT јесте/користи анонимни тип"
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "шаблонски аргумент за %qD користи локални тип %qT"
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT је променљиво измењив тип"
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  покушај извођења %qD"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%qD is not a static data member of a class template"
 msgstr "%q#D је нестатички члански податак у %qT"
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "поклапајући шаблон за %qD није нађен"
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "експлицитно извођење %q#D"
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "удвостручено експлицитно извођење %q#D"
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of %<extern%> on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ИСО Ц++ забрањује употребу %<extern%> на експлицитним извођењима"
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "складишна класа %qD примењена на извођење шаблона"
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "експлицитно извођење %q#T пре дефиниције шаблона"
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ИСО Ц++ забрањује употребу %qE на експлицитним извођењима"
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "удвостручено експлицитно извођење %q#T"
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -70564,181 +70602,181 @@ msgstr "експлицитна специјализација %qD после п
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "експлицитно извођење %qD али дефиниција није доступна"
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d извођења %q+D, могуће услед стварања виртуелних табела (употребите -ftemplate-depth-NN да повећате максимум)"
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T није исправан тип за шаблонски константан параметар"
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter %qT after %qs"
 msgid "invalid template non-type parameter"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T није исправан тип за шаблонски константан параметар"
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "кључна реч %<typename%> није дозвољена изван шаблона"
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, fuzzy, gcc-internal-format
 #| msgid "opaque vector types cannot be initialized"
 msgid "a concept cannot be constrained"
 msgstr "непрозирни векторски типови не могу бити успостављени"
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT није именски простор"
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#T inside template parameter list"
 msgid "concept %qE has multiple template parameter lists"
 msgstr "дефиниција %q#T унутар листе шаблонских параметара"
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "%qD употребљено без параметара шаблона"
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "use %qD directly instead"
 msgstr "користите #include уместо тога"
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "неисправан шаблонски аргумент %d"
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "функција се не разматра за уткивање"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, fuzzy, gcc-internal-format
 #| msgid "explicit qualification in declaration of %qD"
 msgid "explicit deduction guide declared here"
 msgstr "експлицитна одредба у декларацији %qD"
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Неисправна декларација метода, неопходан је повратни тип"
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, fuzzy, gcc-internal-format
 #| msgid "unable to emulate %qs"
 msgid "unable to deduce %qT from %qE"
 msgstr "не могу да емулирам %qs"
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "invalid use of %qT in template argument"
@@ -70966,695 +71004,695 @@ msgstr "тип asm-операнда %qE не може бити одређен"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "декларације објективног Ц-а могу се јављати само у глобалном досегу"
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "неисправна употреба члана %q+D у статичкој чланској функцији"
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr "неисправна употреба члана %q+D у статичкој чланској функцији"
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr "неисправна употреба члана %q+D у статичкој чланској функцији"
 
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in template argument list"
 msgid "%qE missing template arguments"
 msgstr "грешка у рашчлањивању листе шаблонских аргумената"
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "cannot call a concept as a function"
 msgstr "%qE не може бити употребљено као функција"
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "аргументи нису дозвољени у деструктору"
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr "%<this%> није доступно за статичке чланске функције"
 
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, fuzzy, gcc-internal-format
 #| msgid "used %d template parameter(s) instead of %d"
 msgid "use explicit object parameter %qs instead"
 msgstr "употребљено је %d шаблонских параметара уместо %d"
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, gcc-internal-format
 msgid "name the explicit object parameter"
 msgstr ""
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> није доступно за статичке чланске функције"
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<this%> before it is valid"
 msgstr "неисправна употреба %<this%> на највишем нивоу"
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<this%> after it is valid"
 msgstr "неисправна употреба %<this%> на највишем нивоу"
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "неисправна употреба %<this%> у нечланској функцији"
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "неисправна употреба %<this%> на највишем нивоу"
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "неисправан одредбени досег у имену псеудодеструктора"
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "одређени тип %qT не поклапа се са именом деструктора ~%qT"
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE није типа %qT"
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "сложени дословни необјектног типа %qT"
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, gcc-internal-format
 msgid "%<auto{x}%> cannot be constrained"
 msgstr ""
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, gcc-internal-format
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "типски параметри шаблона морају користити кључну реч %<class%> или %<typename%>"
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "неисправна употреба типа %qT као подразумеване вредности за шаблонски шаблонски параметар"
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "неисправан подразумевани аргумент за шаблонски шаблонски параметар"
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "дефиниција %q#T унутар листе шаблонских параметара"
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "неисправна дефиниција одређеног типа %qT"
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "неисправан навод основне класе"
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "заштићени члан %q+#D у анонимној унији"
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not captured"
 msgstr "%qD није тип"
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "употреба %<auto%> променљиве из обухватајуће функције"
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "употреба параметра из обухватајуће вункције"
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, fuzzy, gcc-internal-format
 #| msgid "use of parameter from containing function"
 msgid "use of parameter outside function body"
 msgstr "употреба параметра из обухватајуће вункције"
 
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in template argument list"
 msgid "missing template arguments"
 msgstr "грешка у рашчлањивању листе шаблонских аргумената"
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "шаблонски параметар %qD типа %qT није дозвољен у интегралном константном изразу јер није интегралног или набројивог типа"
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "употреба шаблона класе %qT као израза"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "захтев за члан %qD двосмислен је у вишеструком снопу наслеђивања"
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "тип за %qE није познат"
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
 msgstr "%qT није шаблонски тип"
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr "граница низа није целобројна константа"
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr ""
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is out of range"
 msgstr ""
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "наводиоци складишне класе нису исправни у декларацијама параметара"
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "не може се применити %<offsetof%> на деструктор %<~%T%>"
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "не може се применити %<offsetof%> на чланску функцију %qD"
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "не може се применити %<offsetof%> на чланску функцију %qD"
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "не може се применити %<offsetof%> на чланску функцију %qD"
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, gcc-internal-format
 msgid "pointer-to-member mapping %qE not supported"
 msgstr ""
 
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "двосмислено упућивање на %qD"
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE има неисправан тип за %<reduction%>"
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, gcc-internal-format
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr ""
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %<firstprivate%>"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qE није променљива у одредби %<firstprivate%>"
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %<lastprivate%>"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qE није променљива у одредби %<lastprivate%>"
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> static expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> num expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<vector%> length expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<worker%> num expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, fuzzy, gcc-internal-format
 #| msgid "%<continue%> must be in loop"
 msgid "%<device%> id must be integral"
 msgstr "%<continue%> мора бити у оквиру петље"
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not allowed in other than a declaration"
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%<[*]%> није дозвољено другде осим у декларацији"
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr ""
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, fuzzy, gcc-internal-format
 #| msgid "reimplementation of class %qs"
 msgid "template %qE in clause %qs"
 msgstr "поновљена имплементација класе %qs"
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<hint%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<filter%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, fuzzy, gcc-internal-format
 #| msgid "subscripted value is neither array nor pointer"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "индексирана вредност није ни низ ни показивач"
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> није дефинисано као показивачки тип"
 
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, fuzzy, gcc-internal-format
 #| msgid "%<threadprivate%> %qE is not file, namespace or block scope variable"
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qE није датотека, именски простор нити променљива блоковског досега"
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, fuzzy, gcc-internal-format
 #| msgid "%<threadprivate%> %qE has incomplete type"
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "нитно-локално %qE има непотпун тип"
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%Hнеисправан тип променљиве итерације %qE"
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr ""
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr ""
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr ""
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr ""
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, fuzzy, gcc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed: %.*s"
 msgstr "Тврдња КРИС-порта није прошла: "
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, fuzzy, gcc-internal-format
 #| msgid "non-static declaration of %q+D follows static declaration"
 msgid "non-constant condition for static assertion"
 msgstr "нестатичка декларација %q+D прати статичку декларацију"
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, fuzzy, gcc-internal-format
 #| msgid "second argument to %<__builtin_expect%> must be a constant"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "други аргумент за %<__builtin_expect%> мора бити константа"
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr ""
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr ""
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr "%<__builtin_next_arg%> позвано без аргумената"
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a class or namespace"
 msgid "%qD is not a class or alias template"
 msgstr "%qD није ни класа ни именски простор"
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "шаблонски аргумент %qE уплиће шаблонске параметре"
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -71663,1303 +71701,1303 @@ msgstr "неподржан аргумент за %<__builtin_return_address%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV одредбе не могу се применити на %qT"
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement-expression in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid " declared here"
 msgstr "%q+D декларисано овде"
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, fuzzy, gcc-internal-format
 #| msgid "base class %qT has cv qualifiers"
 msgid "base class %qT is not public"
 msgstr "основна класа %qT има кн-одредбе"
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not public"
 msgstr "%qD није тип"
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is mutable"
 msgstr "%qD није тип"
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has an incomplete type"
 msgid "%qD has a non-structural type"
 msgstr "%qD има непотпун тип"
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute takes no arguments"
 msgstr "%Jатрибут %qE примењује се само на функције"
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr ""
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "захтевано init_priority није целобројна константа"
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "атрибут %qE може се користити само уз дефиниције објеката класног типа у датотечном досегу"
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is out of range"
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "захтевано init_priority је ван опсега"
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is reserved for internal use"
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "захтевано init_priority резервисано је за унутрашњу употребу"
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "декларација %qD као %s"
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires a single NTBS argument"
 msgid "the %qE attribute requires arguments"
 msgstr "атрибут %qs захтева тачно један НТБС аргумент"
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> није исправан декларатор"
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> није исправан декларатор"
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "атрибут %qE се игнорише на не-класним типовима"
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%Jатрибут %qE примењује се само на функције"
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%Jатрибут %qE примењује се само на функције"
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, gcc-internal-format
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr ""
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "zero as null pointer constant"
 msgstr "граница низа није целобројна константа"
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, fuzzy, gcc-internal-format
 #| msgid "lang_* check: failed in %s, at %s:%d"
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "провера lang_*: крах у %s, код %s:%d"
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "недостаје претапање за %s између различитих типова показивача %qT и %qT"
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "недостаје претапање за %s између различитих типова показивача %qT и %qT"
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "недостаје претапање за %s између различитих типова показивача %qT и %qT"
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type %<void *%> and pointer-to-function"
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ИСО Ц++ забрањује %s између показивача типа %<void *%> и показивача-на-функцију"
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type %<void *%> and pointer-to-function"
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ИСО Ц++ забрањује %s између показивача типа %<void *%> и показивача-на-функцију"
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type %<void *%> and pointer-to-function"
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ИСО Ц++ забрањује %s између показивача типа %<void *%> и показивача-на-функцију"
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "недостаје претапање за %s између различитих типова показивача-на-члан %qT и %qT"
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "недостаје претапање за %s између различитих типова показивача-на-члан %qT и %qT"
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "недостаје претапање за %s између различитих типова показивача-на-члан %qT и %qT"
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "операнди у ?: различитих су типова %qT и %qT"
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "операнди у ?: различитих су типова %qT и %qT"
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "неисправна примена %qs на чланску функцију"
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "неисправна примена %<sizeof%> на битско поље"
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ИСО Ц++ забрањује примену %<sizeof%> на израз функцијског типа"
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "неисправна примена %<__alignof%> на битско поље"
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ИСО Ц++ забрањује примену %<__alignof%> на израз функцијског типа"
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "величина низа има неинтегрални тип %qT"
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to %qT"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "превазиђено претварање из константне ниске у %qT"
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "превазиђено претварање из константне ниске у %qT"
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, fuzzy, gcc-internal-format
 #| msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "захтев за члан %qD у %qE, које је не-класног типа %qT"
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "захтев за члан %qD у %qE, које је не-класног типа %qT"
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of nonstatic data member %qE"
 msgid "invalid use of non-static data member %qE"
 msgstr "неисправна употреба нестатичког чланског податка %qE"
 
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "неисправан приступ нестатичком чланском податку %qD нултог објекта"
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "одређени тип %qT не поклапа се са именом деструктора ~%qT"
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "тип који се уништава је %qT, али деструктор упућује на %qT"
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT нема члан по имену %qE"
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT нема члан по имену %qE"
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> није члан у %qT"
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT није основа за %qT"
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD није чланска шаблонска функција"
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT није типа показивач-на-објекат"
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of array indexing on pointer to member"
 msgstr "неисправна употреба %qs на показивачу-на-члан"
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "неисправна употреба %qs на показивачу-на-члан"
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "неисправна употреба %qs на показивачу-на-члан"
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "недостаје индекс у упућивачу низа"
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "индексирање низа декларисаног као %<register%>"
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "индексирана вредност није ни низ ни показивач"
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "недостаје објекат у употреби %qE"
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ИСО Ц++ забрањује звање %<::main%> унутар програма"
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, fuzzy, gcc-internal-format
 #| msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>"
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "мора се употребити или %<.*%> или %<->*%> за позив показивача на чланску функцију у %<%E (...)%>"
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE не може бити употребљено као функција"
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "%qE не може бити употребљено као функција"
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "%qE не може бити употребљено као функција"
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to constructor %q#D"
 msgstr "превише аргумената за %s %q+#D"
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to constructor %q#D"
 msgstr "премало аргумената за %s %q+#D"
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to member function %q#D"
 msgstr "превише аргумената за функцију %qs"
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to member function %q#D"
 msgstr "премало аргумената за функцију %qs"
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to function %q#D"
 msgstr "превише аргумената за функцију %qs"
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to function %q#D"
 msgstr "премало аргумената за функцију %qs"
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to method %q#D"
 msgstr "превише аргумената за %s %q+#D"
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to method %q#D"
 msgstr "премало аргумената за %s %q+#D"
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "превише аргумената за функцију"
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "превише аргумената за функцију"
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "параметар %P за %qD непотпуног је типа %qT"
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "параметар %P непотпуног је типа %qT"
 
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will never be NULL"
 msgid "the address %qE will never be NULL"
 msgstr "адреса за %qD никако не може бити NULL"
 
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "адреса за %qD никако не може бити NULL"
 
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr "адреса за %qD никако не може бити NULL"
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr ""
 
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "адреса за %qD никако не може бити NULL"
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr "операнди у ?: различитих су типова %qT и %qT"
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "недостаје претапање за %s између различитих типова показивача %qT и %qT"
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr "операнди у ?: различитих су типова %qT и %qT"
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "недостаје претапање за %s између различитих типова показивача %qT и %qT"
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, fuzzy, gcc-internal-format
 #| msgid "cast from function call of type %qT to non-matching type %qT"
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr "претапање из функцијског позива типа %qT у непоклапајући тип %qT"
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, fuzzy, gcc-internal-format
 #| msgid "cast from function call of type %qT to non-matching type %qT"
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr "претапање из функцијског позива типа %qT у непоклапајући тип %qT"
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr "аритметика са показивачем на непотпун тип"
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "претпоставља се претапање у тип %qT из препуњене функције"
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL употребљено аритметички"
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ИСО Ц++ забрањује поређење показивача и целобројног"
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, fuzzy, gcc-internal-format
 #| msgid "no type named %q#T in %q#T"
 msgid "operand types are %qT and %qT"
 msgstr "нема типа по имену %q#T у %q#T"
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "поређење уређености показивача са целобројном нулом"
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "неуређено поређење са не-реалним аргументом"
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "неисправни операнди типова %qT и %qT за бинарно %qO"
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ИСО Ц++ забрањује употребу показивача типа %<void *%> у одузимању"
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ИСО Ц++ забрањује употребу показивача на функцију у одузимању"
 
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ИСО Ц++ забрањује употребу показивача на метод у одузимању"
 
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "неисправна употреба показивача на непотпун тип у аритметици са показивачима"
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of constructor %qD"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of destructor %qD"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "неисправна употреба %qE за добијање показивача-на-чланску-функцију"
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  неопходан је одређен ид."
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "заграде око %qE не могу бити коришћене за добијање показивача-на-чланску-функцију"
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ИСО Ц++ забрањује узимање адресе неодређене или заграћене нестатичке чланске функције, за добијање показивача на чланску функцију. Употребите %<&%T::%D%>"
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr "ИСО Ц++ забрањује узимање адресе неодређене или заграћене нестатичке чланске функције, за добијање показивача на чланску функцију. Употребите %<&%T::%D%>"
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ИСО Ц++ забрањује узимање адресе везане чланске функције за добијање показивача на чланску функцију. Употребите %<&%T::%D%>"
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr "ИСО Ц++ забрањује узимање адресе везане чланске функције за добијање показивача на чланску функцију. Употребите %<&%T::%D%>"
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr "(показивач на члан може бити формиран само помоћу %<&%E%>)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "узимање адресе привременог"
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ИСО Ц++ забрањује узимање адресе функције %<::main%>"
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "не може се створити показивач на упућивачки члан %qD"
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "не може се узети адреса битског поља %qD"
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr ""
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ИСО Ц++ забрањује %s-вање набрајања"
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ИСО Ц++ забрањује %s-вање набрајања"
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ИСО Ц++ забрањује %s-вање показивача типа %qT"
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ИСО Ц++ забрањује %s-вање показивача типа %qT"
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "не може се узети адреса од %<this%>, јер је д-вредносни израз"
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "затражена је адреса експлицитне регистарске променљиве %qD"
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "затражена је адреса од %qD, а декларисано је као %<register%>"
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "успостављач за %qT мора бити у витичастим заградама"
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in initializer"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in functional cast"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "неисправно статичко претапање из типа %qT у тип %qT"
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "неисправно статичко претапање из типа %qT у тип %qT"
 
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "useless cast to type %q#T"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "одредбе типова се игноришу на повратном типу функције"
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "неисправно статичко претапање из типа %qT у тип %qT"
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "повратни тип %q#T није потпун"
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "претварање из %qT у %qT"
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "неисправно претапање д-вредносног израза типа %qT у тип %qT"
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "претапање из %qT у %qT губи на тачности"
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 #, fuzzy
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "недостаје претапање за %s између различитих типова показивача-на-члан %qT и %qT"
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "претапање из %qT у %qT повећава неопходно равнање циљног типа"
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ИСО Ц++ забрањује претапање између показивача на функцију и показивача на објекат"
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "неисправно претапање из типа %qT у тип %qT"
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "неисправна употреба константног претапања са типом %qT, који није показивач, нити показивач на члански податак"
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "неисправна употреба константног претапања са типом %qT, који је показивач или упућивач на функцијски тип"
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "неисправно константно претапање д-вредности типа %qT у тип %qT"
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "неисправно константно претапање из типа %qT у тип %qT"
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ИСО Ц++ забрањује претапање у низовни тип %qT"
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qE from type %qT to type %qT"
 msgid "moving %qE of type %qT to itself"
 msgstr "не може се претворити %qE из типа %qT у тип %qT"
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  у израчунавању %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "неконстантан индекс низа у успостављачу"
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "несагласни типови у додели %qT у %qT"
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "низ употребљен као успостављач"
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "неисправна додела низа"
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   у претварању показивача на чланску функцију"
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "претварање показивача на члан преко виртуелне основе %qT"
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   у претварању показивача на члан"
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "неисправно претварање у тип %qT из типа %qT"
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 #, fuzzy
 #| msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "не може се претворити %qT у %qT као аргумент %qP за %qD"
 
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in return"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "аргумент %d од %qE може бити кандидат за форматски атрибут"
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, fuzzy, gcc-internal-format
 #| msgid "return type might be a candidate for a format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "повратни тип може бити кандидат за форматски атрибут"
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "аргумент позива функције може бити кандидат за форматски атрибут"
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "аргумент позива функције може бити кандидат за форматски атрибут"
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, fuzzy, gcc-internal-format
 #| msgid "assignment left-hand side might be a candidate for a format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "лева страна доделе може бити кандидат за форматски атрибут"
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "у прослеђивању аргумента %P за %q+D"
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "враћање упућивача на привремени"
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "returning pointer to temporary"
 msgstr "враћање упућивача на привремени"
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "враћање упућивача на локалну променљиву %q+D"
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "враћање адресе локалне променљиве %q+D"
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "враћање адресе локалне променљиве %q+D"
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, fuzzy, gcc-internal-format
 #| msgid "Missing return statement"
 msgid "redundant move in return statement"
 msgstr "Недостаје наредба повратка"
 
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in initialization"
 msgid "redundant move in initialization"
 msgstr "несагласни типови у успостављању"
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "враћање вредности из деструктора"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "не може се враћати из руковаоца у блоку покушаја у конструктору"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "враћање вредности из конструктора"
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "наредба враћања без вредности, у функцији која враћа %qT"
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "недостаје успостављач"
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "Неусаглашени рангови за оператор код %L и %L"
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "наредба враћања без вредности, у функцији која враћа %qT"
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> не сме вратити NULL, осим ако је декларисан уз %<throw()%> (или је задато -fcheck-new)"
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, gcc-internal-format
 msgid "not eliding copy on return from %qD"
 msgstr ""
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr ""
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -73210,168 +73248,168 @@ msgstr ""
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "употребљена синтакса конструктора, али конструктор није декларисан за тип %qT"
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD may not have been initialized"
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "променљива %qD можда није успостављена"
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 #, fuzzy
 #| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "двосмислено претварање %qE из %qT у %qT"
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "неисправно претварање из %qT у %qT"
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, fuzzy, gcc-internal-format
 #| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "предугачка ниска успостављача за низ знакова"
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "витичасте заграде око скаларног успостављача"
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "скупина типа %qT не може се успостављати сложеном константном"
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "члан %qD је неуспостављен упућивач"
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "члан %qD је неуспостављен упућивач"
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q#D does not match any in class %qT"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "прототип за %q#D не одговара ниједном у класи %qT"
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "поље %qD није нађено у унији која се успоставља"
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "индексна вредност уместо имена поља у успостављачу уније"
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "откривено кружно прослеђивање показивача"
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "основни операнд за %<->%> непоказивачког је типа %qT"
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%> производи непоказивачки резултат"
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "основни операнд за %<->%> није показивач"
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE се не може користити као члански показивач, пошто је типа %qT"
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "члански показивач %qE не може се применити на %qE, које је некласног типа %qT"
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "тип показивача на члан %qT није сагласан са типом објекта %qT"
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "показивач на чланску функцију употребљен у аритметици"
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "показивач на чланску функцију употребљен у аритметици"
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr ""
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdefault-initialization of %q#D, which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "%Jподразумевано успостављање %q#D, које је упућивачког типа"
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "позив функције %qD која баца непотпун тип %q#T"
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "позив функције која баца непотпун тип %q#T"
@@ -74438,7 +74476,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad kind for logical constant at %C"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -75924,7 +75962,7 @@ msgstr "Лоша одредница намере код %C"
 msgid "deferred type parameter at %C"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -76158,7 +76196,7 @@ msgstr ""
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Низовна компонента структуре код %C мора имати експлицитан или одложени облик"
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already declared at %L"
@@ -77035,7 +77073,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr "Очекивана је формална листа аргумената у дефиницији функције код %C"
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
@@ -77927,12 +77965,12 @@ msgstr ""
 msgid "are_identical_variables: Bad type"
 msgstr ""
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr ""
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr ""
@@ -78201,306 +78239,306 @@ msgstr "Параметар ‘%s’ код %L није декларисан ил
 msgid "check_init_expr(): Unknown expression type"
 msgstr "Очекиван је тип израза"
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be a statement function"
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr "Одредничка функција ‘%s’ код %L не може бити наредбена функција"
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be an internal function"
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr "Одредничка функција ‘%s’ код %L не може бити унутрашња функција"
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L must be PURE"
 msgid "Specification function %qs at %L must be PURE"
 msgstr "Одредничка функција ‘%s’ код %L мора бити чиста"
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be RECURSIVE"
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr "Одредничка функција ‘%s’ код %L не може бити рекурзивна"
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr "Променљива ‘%s’ се не може јавити у изразу код %L"
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be OPTIONAL"
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити опцион"
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr "Променљива ‘%s’ се не може јавити у изразу код %L"
 
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "check_restricted(): Unknown expression type"
 msgstr "Очекиван је тип израза"
 
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression at %L must be of INTEGER type"
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr "Израз код %L мора бити целобројног типа"
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L must be PURE"
 msgid "Function %qs at %L must be PURE"
 msgstr "Одредничка функција ‘%s’ код %L мора бити чиста"
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr "Израз код %L мора бити скалар"
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr ""
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible ranks in %s at %L"
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr "Несагласни рангови у %s код %L"
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "different shape for %s at %L on dimension %d (%d/%d)"
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "%s код %L има различит облик за димензију %d (%d/%d)"
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a VALUE"
 msgid "%qs at %L is not a VALUE"
 msgstr "‘%s’ код %L није вредност"
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal stride of zero at %L"
 msgid "Illegal assignment to external procedure at %L"
 msgstr "Недозвољен нулти корак код %L"
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "Несагласни рангови %d и %d у додели код %L"
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "Тип променљиве је UNKNOWN у додели код %L"
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "Појављује се NULL на десној страни у додели код %L"
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "POINTER valued function appears on right-hand side of assignment at %L"
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "Функција са показивачком вредношћу појављује се на десној страни доделе код %L"
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr ""
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible types in assignment at %L, %s to %s"
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Несагласни типови у додели код %L, %s у %s"
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "Циљ доделе показивача није показивач код %L"
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "‘%s’ у додели показивача код %L не може бити л-вредност јер је процедура"
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Удвостручена одредница %s код %C"
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, fuzzy, gcc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Различити типови у додели показивача код %L"
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "stack size must not be greater than 64k"
 msgid "Stride must not be present at %L"
 msgstr "величина стека не сме бити већа од 64k"
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "Спољашњи објекат ‘%s’ код %L не може имати успостављач"
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Различити типови у додели показивача код %L"
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Различите врсте типова параметара у додели показивача код %L"
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Различите врсте типова параметара у додели показивача код %L"
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' requires argument list at %C"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Наредбена функција ‘%s’ захтева листу аргумената код %C"
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Унутрашња процедура ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not allowed as an actual argument"
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Сопствено ‘%s’ код %L није дозвољено као стварни аргумент"
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr ""
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "удвостручена декларација сучеља за класу %qs"
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Различите знаковне дужине у додели показивача код %L"
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr "Циљ доделе показивача није показивач код %L"
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Различити типови у додели показивача код %L"
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Различите врсте типова параметара у додели показивача код %L"
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Различити рангови у додели показивача код %L"
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Rank remapping target is not rank 1 at %L"
@@ -78509,203 +78547,203 @@ msgstr "Циљ доделе показивача није показивач к
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data target at %L shall not have a coindex"
 msgstr "Елемент преноса података код %L не може имати показивачке компоненте"
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Изборни израз у рачунском GOTO код %L мора бити скаларни целобројан израз"
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr ""
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "Циљ доделе показивача није ни циљ ни показивач код %L"
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr ""
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Циљ доделе показивача није ни циљ ни показивач код %L"
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Лош циљ у додели показивача у чистој процедури код %L"
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Додела показивача са векторским индексом на десној страни код %L"
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Циљ доделе показивача није показивач код %L"
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Успостављање показивача код %C захтева ‘=>’, не ‘=’"
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Компонента код %C мора имати атрибут показивача"
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Објекат ‘%s’ код %L мора имати атрибут %s за SAVE"
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Унутрашња процедура ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr ""
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qE није променљива"
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, gcc-internal-format
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "Променљива ‘%s’ се не може јавити у изразу код %L"
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, gcc-internal-format
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr ""
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -78728,8 +78766,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "creating array of %qT"
 msgid "Creating array temporary at %L"
@@ -78819,7 +78857,7 @@ msgstr "Променљива ‘%s’ код %C не може се редефи
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Променљива ‘%s’ код %C не може се редефинисати унутар петље која почиње код %L"
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -78965,12 +79003,12 @@ msgstr "Први аргумент дефинисане доделе код %L м
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Други аргумент дефинисане доделе код %L мора бити намере-у"
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Први аргумент сучеља оператора код %L мора бити намере-у"
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Други аргумент сучеља оператора код %L мора бити намере-у"
@@ -79919,7 +79957,7 @@ msgstr "Претварање из %s у %s код %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
@@ -80543,7 +80581,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' at %L cannot have ALLOCATABLE components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -80725,6 +80763,11 @@ msgstr "Целобројно преливање"
 msgid "check_charlen_present(): length not set"
 msgstr ""
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr ""
+
 #: fortran/match.cc:118
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
@@ -81178,7 +81221,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "Крејов показивач код %C мора бити целобројни."
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
@@ -81748,92 +81791,92 @@ msgstr "Синтаксна грешка у наредби SAVE код %C"
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "SELECT RANK statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr "Статусни израз код %C мора бити променљива"
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Неочекивана наредба CASE код %C"
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CASE specification at %C"
 msgstr "Синтаксна грешка у одредници CASE код %C"
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Неочекивана наредба END код %C"
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Синтаксна грешка у одредници CASE код %C"
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Синтаксна грешка у одредници CASE код %C"
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected RANK statement at %C"
 msgstr "Неочекивана наредба END код %C"
 
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "Статусни израз код %C мора бити променљива"
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in RANK specification at %C"
 msgstr "Синтаксна грешка у одредници CASE код %C"
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "Наредба ELSEWHERE код %C није обухваћена блоком WHERE"
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -83369,8 +83412,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "Одредба IF код %L захтева скаларни логички израз"
@@ -85949,12 +85992,12 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Етикета %d поменута код %L није дефинисана"
@@ -86090,7 +86133,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Функција ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -86533,298 +86576,304 @@ msgstr ""
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr "Лош упућивач низа код %L"
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s',used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Променљива ‘%s’, употребљена у одредничком изразу, користи се код %L пре наредбе ENTRY у којој је параметар"
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Променљива ‘%s’ употребљена је код %L пре наредбе ENTRY у којој је параметар"
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared %s"
 msgid "Using variable %qs at %L is deprecated"
 msgstr "променљива примерка %qs декларисана је %s"
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Bad array reference at %L"
+msgid "Invalid array reference at %L"
+msgstr "Лош упућивач низа код %L"
+
+#: fortran/resolve.cc:6433
 #, fuzzy, gcc-internal-format
 #| msgid "The type %s cannot be host associated at %L because it is blocked by an incompatible object of the same name at %L"
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr "Тип %s не може бити придружен домаћину код %L зато што га блокира несагласан објекат истог имена код %L"
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be scalar"
 msgid "Passed-object at %L must be scalar"
 msgstr "Ознака %s код %L мора бити скалар"
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L мора бити скалар"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s код %L мора бити целобројно"
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Очекиван је тип израза"
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s код %L мора бити скалар"
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%s at %L must be integer"
 msgstr "%s код %L мора бити скалар"
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s код %L мора бити целобројно"
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "Израз за почетак у FORALL код %L мора бити скаларни целобројан"
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "Израз за крај у FORALL код %L мора бити скаларни целобројан"
 
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "Израз за корак у FORALL код %L мора бити скаларни %s"
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "Израз за корак у FORALL код %L не може бити нула"
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "Променљива ‘%s’ се не може јавити у изразу код %L"
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Израз у наредби ALLOCATE код %L мора бити резервљив или показивач"
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear an the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "‘%s’ не може да се јави у одредници низа код %L у истој наредби резервисања где се и само резервише"
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Етикета код %L није у истом блоку као наредба GOTO код %L"
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -86833,298 +86882,298 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "Етикета CASE код %L преклапа етикету CASE код %L"
 
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be kind %d"
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Израз у наредби CASE код %L мора бити врста %d"
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Израз у наредби CASE код %L мора бити скалар"
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Изборни израз у рачунском GOTO код %L мора бити скаларни целобројан израз"
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Аргумент наредбе SELECT код %L не може бити %s"
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "DEFAULT CASE код %L не може бити праћен другим DEFAULT CASE код %L"
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Логички опсег у наредби CASE код %L није дозвољен"
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "constant logical value in CASE statement is repeated at %L"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "константна логичка вредност у наредби CASE поновљена је код %L"
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Одредница опсега код %L не може никако бити поклопљена"
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Блок логичког SELECT CASE код %L има више од два случаја"
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Име ‘%s’ се не може употребити као дефинисани оператор код %C"
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Selector at %L cannot be NULL()"
 msgstr "Корак итератора код %L не може бити нула"
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Selector at %L has no type"
 msgstr "Функција ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Синтаксна грешка у наредби EQUIVALENCE код %L"
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "Етикета CASE код %L преклапа етикету CASE код %L"
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Изведени тип ‘%s’ код %C користи се пре него што је дефинисан"
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Неочекивана наредба %s код %C"
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L мора бити скалар"
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати показивачке компоненте"
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Елемент преноса података код %L не може имати показивачке компоненте"
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have ALLOCATABLE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати резервљиве компоненте"
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Елемент преноса података код %L не може имати приватне компоненте"
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати приватне компоненте"
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Елемент преноса података код %L не може бити пун упућивач на низ претпостављене величине"
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Одредба NUM_THREADS код %L захтева скаларни целобројни израз"
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Аргумент у ACOS код %L мора бити између -1 и 1"
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Наредба код %L није исправна наредба циља гранања за наредбу гранања код %L"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Branch at %L causes an infinite loop"
 msgid "Branch at %L may result in an infinite loop"
@@ -87132,12 +87181,12 @@ msgstr "Гранање код %L води у бесконачну петљу"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -87145,229 +87194,229 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Етикета код %L није у истом блоку као наредба GOTO код %L"
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "Маска у WHERE код %L има неусаглашен облик"
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "Циљ доделе у WHERE код %L има неусаглашен облик"
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Неподржана наредба унутар WHERE код %L"
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' cause more than one assignment to this object at %L"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL са индексом ‘%s’ изазива више од једне доделе овом објекту код %L"
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Спољашња конструкција FORALL већ има индекс са овим именом %L"
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "Одредба WHERE/ELSEWHERE код %L захтева логички низ"
 
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER expression at %L is being truncated (%d/%d)"
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr "Знаковни израз код %L бива подсечен (%d/%d)"
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Десна страна доделе код %L је изведени тип који садржи показивач у чистој процедури"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Различити типови у додели показивача код %L"
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "Израз за почетак у FORALL код %L мора бити скаларни целобројан"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "Наредба ASSIGNED GOTO код %L захтева целобројну променљиву"
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Променљивој ‘%s’ није додељена циљна етикета код %L"
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Алтернативна наредба повратка код %L захтева скаларни целобројни наводилац повратка"
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected initialization expression in CASE at %C"
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "Очекиван је успостављачки израз у CASE код %C"
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Аритметичко IF код %L захтева бројевни израз"
 
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Излазни услов из петље DO WHILE код %L мора бити скаларни логички израз"
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "Одредба маске у FORALL код %L захтева логички израз"
 
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): лош кôд наредбе"
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter %s declared at %L"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Неупотребљен параметар %s декларисан код %L"
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -87375,1108 +87424,1108 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "величина низа %qs је превелика"
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Резервљиви низ ‘%s’ код %L мора имати одложени облик"
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Скаларни објекат ‘%s’ код %L не може бити резервљив"
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Низовни показивач ‘%s’ код %L мора имати одложен облик"
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Низ ‘%s’ код %L не може имати одложен облик"
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, fuzzy, gcc-internal-format
 #| msgid "The type %s cannot be host associated at %L because it is blocked by an incompatible object of the same name at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Тип %s не може бити придружен домаћину код %L зато што га блокира несагласан објекат истог имена код %L"
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Низ модула или главног програма ‘%s’ код %L мора имати константан облик"
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Ентитет са претпостављеном знаковном дужином код %L мора бити лажни аргумент или параметар"
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "‘%s’ код %L мора имати константну знаковну дужину у овом контексту"
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "‘%s’ код %L мора имати константну знаковну дужину у овом контексту"
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Резервљиво ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Спољашње ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Лажно ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Сопствено ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Резултат функцији ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Аутоматски низ ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "у %s, код %s:%d"
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Наредбена функција знаковне вредности ‘%s’ код %L мора имати константну дужину"
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "‘%s’ је приватног типа и не може бити лажни аргумент у ‘%s’, који је јаван код %L"
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Резултат функцији ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Спољашњи објекат ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Елементална функција ‘%s’ код %L мора имати скаларни резултат"
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Наредбена функција ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати низовну вредност"
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати показивачку вредност"
 
 # no-c-format
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити чиста"
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити рекурзивна"
 
 # no-c-format
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити чиста"
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Лажна процедура ‘%s’ код %C не може имати генеричко сучеље"
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "Атрибут %s коси се са атрибутом %s у ‘%s’ код %L"
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Interface of %qs at %L must be explicit"
 msgstr "Аргумент за %s код %L мора бити дужине један"
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Аргумент у ICHAR код %L мора бити дужине један"
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити показивач"
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be OPTIONAL"
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L не сме бити опциони"
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Први аргумент сучеља оператора код %L мора бити намере-у"
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Корак итератора код %L не може бити нула"
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити неизведени тип"
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити неизведени тип"
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr ""
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити скалар"
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити показивач"
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Низовни показивач ‘%s’ код %L мора имати одложен облик"
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Аргумент у ICHAR код %L мора бити дужине један"
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити неизведени тип"
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, fuzzy, gcc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L не може имати атрибут показивача"
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L."
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Знаковна дужина компоненте ‘%s’ мора бити константан одреднички израз код %L."
 
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be of INTEGER type"
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "Израз код %L мора бити целобројног типа"
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, fuzzy, gcc-internal-format
 #| msgid "The component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Компонента ‘%s’ је приватни тип и не може бити компонента у ‘%s’, која је јавна код %L"
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Компонента %s типа SEQUENCE декларисаног код %L нема атрибут SEQUENCE"
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has not been declared"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%qD није декларисано"
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Низ претпостављене величине ‘%s’ у листи имена ‘%s’ код %C није дозвољен."
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "Приватни симбол ‘%s’ не може бити члан јавне листе имена код %L"
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "Приватни симбол ‘%s’ не може бити члан јавне листе имена код %L"
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or assumed shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Параметарски низ ‘%s’ код %L не може бити аутоматског или претпостављеног облика"
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Имплицитно типски параметар ‘%s’ код %L не одговара каснијем имплицитном типу"
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Несагласан изведени тип у параметру код %L"
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, fuzzy, gcc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Објекат ‘%s’ код %L мора имати атрибут %s за SAVE"
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Лоша одредница за низ претпостављене величине код %C"
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Низ претпостављене величине код %L мора бити лажни аргумент"
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Симбол код %L није лажна променљива"
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Наредбена функција знаковне вредности ‘%s’ код %L мора имати константну дужину"
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined."
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Изведени тип ‘%s’ код %L је типа ‘%s’, који није дефинисан."
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type variable in COMMON at %C does not have the SEQUENCE attribute"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Променљива изведеног типа у заједничком код %C нема атрибут SEQUENCE"
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Аргумент за %s код %L мора бити дужине један"
 
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Јавна функција ‘%s’ код %L не може бити приватног типа ‘%s’"
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "Лажни аргумент намере-из ‘%s’ код %L је претпостављене величине и зато не може имати подразумевани успостављач"
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Низ ‘%s’ код %L не може имати одложен облик"
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Резервљиви низ ‘%s’ код %L мора имати одложени облик"
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Лажна процедура код %L није дозвољена у елементалној процедури"
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s."
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Листа имена %s не може се преименовати у %s придружењем USE."
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Нитно-приватно код %L не снима се"
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting definable entity near %L"
 msgstr "Очекивана је наредба %s код %C"
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA елемент ‘%s’ код %L мора бити у заједничком"
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Лажно ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L не може имати атрибут показивача"
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Неконстантан одељак низа код %L у наредби DATA"
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "Наредба DATA код %L има више променљивих него вредности"
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Nonconstant array section at %L in DATA statement"
 msgid "Non-constant character length at %L in DATA statement"
 msgstr "Неконстантан одељак низа код %L у наредби DATA"
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "Наредба DATA код %L има више вредности него променљивих"
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Ознака %d код %L дефинисана али неупотребљена"
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Ознака %d код %L дефинисана али не може бити употребљена"
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L мора имати атрибут SEQUENCE да би била објекат еквиваленције"
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L не може имати резервљиве компоненте како би била објекат еквиваленције"
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initializer cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Променљива изведеног типа ‘%s’ код %L са подразумеваним успостављачем не може бити објекат еквиваленције"
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L са показивачким компонентама не може бити објекат еквиваленције"
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Синтаксна грешка у наредби EQUIVALENCE код %L"
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Члан заједничког блока ‘%s’ код %L не може бити објекат еквиваленције у чистој процедури ‘%s’"
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Именована константа ‘%s’ код %L не може бити објекат еквиваленције"
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Низ ‘%s’ код %L са неконстантним границама не може бити објекат еквиваленције"
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Компонената структуре ‘%s’ код %L не може бити објекат еквиваленције"
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Подниска код %L има нулту дужину"
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, fuzzy, gcc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Различите знаковне дужине у додели показивача код %L"
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Јавна функција ‘%s’ код %L не може бити приватног типа ‘%s’"
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "Унос ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора бити функција"
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Процедура корисничког оператора ‘%s’ код %L не може бити претпостављене знаковне дужине"
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Први аргумент сучеља оператора код %L не може бити опциони"
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Други аргумент сучеља оператора код %L не може бити опциони"
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Сучеље оператора код %L мора имати, највише, два аргумента"
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -89064,362 +89113,362 @@ msgstr ""
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr "Функција ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr "Атрибут %s коси се са атрибутом %s код %L"
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, fuzzy, gcc-internal-format
+#| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr "Атрибут %s коси се са атрибутом %s у ‘%s’ код %L"
+
+#: fortran/symbol.cc:508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr "Атрибут %s није дозвољен у јединици програма BLOCK DATA код %L"
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "Објекат ‘%s’ код %L мора имати атрибут %s за SAVE"
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, gcc-internal-format
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr ""
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "Procedure pointer at %C"
 msgstr "име процедуре = %s"
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%s attribute applied to %s %s at %L"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, gcc-internal-format, gfc-internal-format
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr "Атрибут %s коси се са атрибутом %s код %L"
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, fuzzy, gcc-internal-format
-#| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr "Атрибут %s коси се са атрибутом %s у ‘%s’ код %L"
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "Не могу се променити атрибути USE-придруженог симбола код %L"
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "Не могу се променити атрибути USE-придруженог симбола %s код %L"
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute specified at %L"
 msgid "Duplicate %s attribute specified at %L"
 msgstr "Удвостручени атрибут %S наведен код %L"
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr "Удвостручени атрибут SAVE наведен код %L"
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray Pointee at %L appears in multiple pointer() statements."
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "Крејов показивани код %L појављује се у више наредби pointer()"
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "Удвостручени атрибут SAVE наведен код %L"
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "Атрибут SAVE код %L не може бити наведен у чистој процедури"
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "Удвостручени атрибут SAVE наведен код %L"
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "Удвостручени атрибут SAVE наведен код %L"
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Удвостручени атрибут SAVE наведен код %L"
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr "Атрибут SAVE код %L не може бити наведен у чистој процедури"
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Удвостручени атрибут SAVE наведен код %L"
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "Процедура %s код %L је већ декларисана као процедура %s"
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "Намера-%s коси се са намером-%s код %L"
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "Одредница ACCESS код %L је већ наведена "
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute specified at %L"
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Удвостручени атрибут %S наведен код %L"
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Удвостручени атрибут SAVE наведен код %L"
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Симбол ‘%s’ код %L већ има експлицитно сучеље"
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %C already has a type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Функција ‘%s’ код %C већ има тип %s"
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Симбол ‘%s’ код %L не може имати тип"
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Компонента ‘%s’ код %C већ је декларисана код %L"
 
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Двосмислен симбол ‘%s’ код %C"
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Изведени тип ‘%s’ код %C користи се пре него што је дефинисан"
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Компонента ‘%s’ код %C је приватна компонента у ‘%s’"
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "‘%s’ код %C није члан структуре ‘%s’"
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "‘%s’ код %C није члан структуре ‘%s’"
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Удвостручена етикета наредбе %d код %L и %L"
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Етикета %d код %C је већ поменута као циљ гранања"
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Етикета %d код %C је већ поменута код етикета формата"
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Етикета %d код %C је претходно употребљена као етикета формата"
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Етикета %d код %C је претходно употребљена као циљ гранања"
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Shared DO termination label %d at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Labeled DO statement at %L"
 msgstr "Неочекивана наредба END код %C"
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Име ‘%s’ код %C је двосмислен упућивач на ‘%s’ из модула ‘%s’"
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from current program unit"
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "Име ‘%s’ код %C је двосмислен упућивач на ‘%s’ из текуће програмске јединице"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Симбол ‘%s’ код %C је већ придружен домаћину"
 
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Променљива изведеног типа ‘%s’ код %L мора имати атрибут SEQUENCE да би била објекат еквиваленције"
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Променљива изведеног типа ‘%s’ код %L мора имати атрибут SEQUENCE да би била објекат еквиваленције"
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -89452,24 +89501,24 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "лош тип израза током хода (%d)"
@@ -89680,37 +89729,37 @@ msgstr "Враћај вредности функција у регистрима
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Непознат сопствени оператор"
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Непозната функције листе аргумената код %L"
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -89722,18 +89771,18 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "Сопствена функција %s(%d) није препозната"
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "Аргумент ‘dim’ за сопствено ‘%s’ код %L није исправан димензиони индекс"
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "The event variable at %L shall not be coindexed"
@@ -89884,7 +89933,7 @@ msgstr ""
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_trans_select(): Bad type for case expr."
@@ -90299,6 +90348,12 @@ msgstr "поље %qs декларисано као функција"
 msgid "function %qD redeclared as variable"
 msgstr "функција %q+D поново декларисана као уткана"
 
+#: lto/lto-symtab.cc:865
+#, fuzzy, gcc-internal-format
+#| msgid "%q+#D previously declared here"
+msgid "previously declared here"
+msgstr "%q+#D претходно декларисано овде"
+
 #: lto/lto.cc:174
 #, gcc-internal-format
 msgid "%<lto_obj_file_open()%> failed"
@@ -91672,7 +91727,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr ""
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, fuzzy, gcc-internal-format
 #| msgid "non-object member %qs cannot be declared %<mutable%>"
 msgid "non-objective-c type %qT cannot be caught"
@@ -91683,7 +91738,7 @@ msgstr "не-објектни члан %qs не може бити деклари
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr ""
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, gcc-internal-format
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
 msgstr ""
diff --git a/gcc/po/sv.po b/gcc/po/sv.po
index 9151df652e0..cfaef7d1230 100644
--- a/gcc/po/sv.po
+++ b/gcc/po/sv.po
@@ -29,10 +29,10 @@
 # thunk			snutt
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 14.1.0\n"
+"Project-Id-Version: gcc 14.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
-"PO-Revision-Date: 2024-05-16 22:03+0200\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
+"PO-Revision-Date: 2024-08-01 21:36+0200\n"
 "Last-Translator: Göran Uddeborg <goeran@uddeborg.se>\n"
 "Language-Team: Swedish <tp-sv@listor.tp-sv.se>\n"
 "Language: sv\n"
@@ -406,7 +406,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr "ange inte både -march=... och -mcpu=..."
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 msgid "shared and mdll are not compatible"
 msgstr "shared och mdll är inkompatibla"
 
@@ -19191,16 +19191,16 @@ msgstr "okänd instruktion:"
 msgid "insn does not satisfy its constraints:"
 msgstr "instruktionen håller inte sina begränsningar:"
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "skapad och använd med olika inställningar av ”%s”"
 
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "skapad och använd med olika inställningar av %<-fpic%>"
 
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 msgid "created and used with different settings of %<-fpie%>"
 msgstr "skapad och använd med olika inställningar av %<-fpie%>"
 
@@ -19522,7 +19522,7 @@ msgstr "längdmodifierare i strfmon-format"
 msgid "<command-line>"
 msgstr "<kommandorad>"
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "ej stödd operand för kod ”%c”"
@@ -19541,9 +19541,9 @@ msgstr "ogiltig operand för ”%%%c”"
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, c-format
 msgid "invalid vector constant"
 msgstr "ogiltig vektorkonstant"
@@ -19563,7 +19563,7 @@ msgstr "inkompatibel operand för ”%%%c”"
 msgid "incompatible register operand for '%%%c'"
 msgstr "inkompatibla registeroperander för ”%%%c”"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, c-format
 msgid "missing operand"
 msgstr "operand saknas"
@@ -19592,93 +19592,93 @@ msgstr "ogiltigt adressläge"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "det går inte att kombinera GNU- och SVE-vektorer i en binär operation"
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "”%%&” använt utan någon lokal dynamisk TLS-referens"
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, c-format
 msgid "invalid %%J value"
 msgstr "ogiltigt %%J-värde"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, c-format
 msgid "invalid %%r value"
 msgstr "ogiltigt %%r-värde"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, c-format
 msgid "invalid %%R value"
 msgstr "ogiltigt %%R-värde"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, c-format
 msgid "invalid %%N value"
 msgstr "ogiltigt %%N-värde"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, c-format
 msgid "invalid %%P value"
 msgstr "ogiltigt %%P-värde"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, c-format
 msgid "invalid %%h value"
 msgstr "ogiltigt %%h-värde"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, c-format
 msgid "invalid %%L value"
 msgstr "ogiltigt %%L-värde"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, c-format
 msgid "invalid %%m value"
 msgstr "ogiltigt %%m-värde"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, c-format
 msgid "invalid %%M value"
 msgstr "ogiltigt %%M-värde"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, c-format
 msgid "invalid %%U value"
 msgstr "ogiltigt %%U-värde"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, c-format
 msgid "invalid %%s value"
 msgstr "ogiltigt %%s-värde"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, c-format
 msgid "invalid %%C value"
 msgstr "ogiltigt %%C-värde"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, c-format
 msgid "invalid %%E value"
 msgstr "ogiltigt %%E-värde"
 
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "okänd avspecifikation av omlokalisering"
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ogiltig %%xn-kod"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, c-format
 msgid "invalid operand address"
 msgstr "ogiltig operandadress"
@@ -19771,35 +19771,35 @@ msgstr "ogiltig UNSPEC som operand: %d"
 msgid "unrecognized supposed constant"
 msgstr "okänd förmodad konstant"
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, c-format
 msgid "invalid shift operand"
 msgstr "ogiltig skiftoperand"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "förutsade Thumb-instruktion"
 
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "förutsade instruktion i villkorlig sekvens"
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Ej stödd operand för kod ”%c”"
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -19807,113 +19807,113 @@ msgstr "Ej stödd operand för kod ”%c”"
 msgid "invalid operand for code '%c'"
 msgstr "ogiltig operand för kod ”%c”"
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, c-format
 msgid "instruction never executed"
 msgstr "instruktionen aldrig utförd"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "föråldrad Maverick-formatkod ”%c”"
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "ogiltig konvertering från typen %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "ogiltig konvertering till typen %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "operationen är inte tillåten på typen %<bfloat16_t%>"
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "adressoperander kräver begränsning för X-, Y- eller Z-register"
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "operander till %T/%t måste vara reg + const_int:"
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 msgid "bad address, not an I/O address:"
 msgstr "felaktig adress, inte en I/O-adress:"
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 msgid "bad address, not a constant:"
 msgstr "felaktig adress, inte en konstant:"
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 msgid "bad address, not (reg+disp):"
 msgstr "felaktig adress, inte (reg+avst):"
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "felaktig adress, inte post_inc eller pre_dec:"
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr "internt kompilatorfel.  Felaktig adress:"
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "Ej stödd kod ”%c” för fixdecimal:"
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 msgid "internal compiler error.  Unknown mode:"
 msgstr "internt kompilatorfel.  Okänt läge:"
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 msgid "invalid insn:"
 msgstr "ogiltig instruktion:"
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 msgid "incorrect insn:"
 msgstr "felaktig instruktion:"
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 msgid "unknown move insn:"
 msgstr "okänd move-instruktion:"
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 msgid "bad shift insn:"
 msgstr "felaktig skiftinstruktion:"
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "internt kompilatorfel.  Felaktig skift:"
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 msgid "unsupported fixed-point conversion"
 msgstr "ej stödd fixdecimalskonvertering"
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 msgid "variable"
 msgstr "variabel"
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 msgid "function parameter"
 msgstr "funktionsparameter"
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 msgid "structure field"
 msgstr "postfält"
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 msgid "return type of function"
 msgstr "returtyp för en funktion"
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 msgid "pointer"
 msgstr "pekare"
 
@@ -19949,7 +19949,7 @@ msgstr "ej stödd operand"
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -20268,46 +20268,46 @@ msgstr "operanden är inte ett heltal, ogiltig operandkod ”R”"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operanden är inte ett specifikt heltal, ogiltig operandkod ”R”"
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ogiltig operandkod ”%c”"
 
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ogiltig begränsning för operand"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, c-format
 msgid "invalid vector immediate"
 msgstr "ogiltig vektoromedelbar"
 
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 msgid "unknown insn mode"
 msgstr "okänt instruktionsläge"
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr "ogiltig konvertering från typen %<__bf16%> utan flaggan %<-msse2%>"
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr "ogiltig konvertering från typen %<_Float16%> utan flaggan %<-msse2%>"
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr "ogiltig konvertering till typen %<__bf16%> utan flaggan %<-msse2%>"
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr "ogiltig konvertering till typen %<_Float16%> utan flaggan %<-msse2%>"
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr "operationen är inte tillåten på typen %<bf16%> utan flaggan %<-msse2%>"
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
 msgstr "operationen är inte tillåten på typen %<_Float16%> utan flaggan %<-msse2%>"
 
@@ -20338,7 +20338,7 @@ msgstr "ogiltig operation på %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "ogiltig %%P-operand"
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, c-format
 msgid "invalid %%p value"
 msgstr "ogiltigt %%p-värde"
@@ -20365,29 +20365,29 @@ msgstr "kan inte använda icke-gp-relativa absoluta adresser"
 msgid "invalid addressing mode"
 msgstr "ogiltigt adresseringsläge"
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, c-format
 msgid "'%%%c' is not a valid operand prefix"
 msgstr "%%%c är inte ett giltigt operandprefix"
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "felaktig användning av ”%%%c”"
@@ -20419,7 +20419,7 @@ msgid "post-increment address is not a register"
 msgstr "efterinkrementeringsadress är inte ett register"
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 msgid "bad address"
 msgstr "felaktig adress"
 
@@ -20577,7 +20577,7 @@ msgstr "ej stödd konstant adress:"
 msgid "unsupported memory expression:"
 msgstr "ej stött minnesuttryck:"
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, c-format
 msgid "invalid vector operand"
 msgstr "ogiltig vektoroperand"
@@ -20625,242 +20625,242 @@ msgstr "%<-mquad-memory-atomic%> förutsätter 64-bitarsläge"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "%<-mquad-memory%> är inte tillgängligt i läget med omvänd byteordning"
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 msgid "bad move"
 msgstr "felaktig förflyttning"
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 msgid "Bad 128-bit move"
 msgstr "Felaktig 128-bitsförflyttning"
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, c-format
 msgid "invalid %%A value"
 msgstr "ogiltigt %%A-värde"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%D value"
 msgstr "ogiltigt %%D-värde"
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, c-format
 msgid "invalid %%e value"
 msgstr "ogiltigt %%e-värde"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, c-format
 msgid "invalid %%f value"
 msgstr "ogiltigt %%f-värde"
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, c-format
 msgid "invalid %%F value"
 msgstr "ogiltigt %%F-värde"
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, c-format
 msgid "invalid %%G value"
 msgstr "ogiltigt %%G-värde"
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, c-format
 msgid "invalid %%j code"
 msgstr "ogiltig %%j-kod"
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, c-format
 msgid "invalid %%J code"
 msgstr "ogiltig %%J-kod"
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, c-format
 msgid "invalid %%k value"
 msgstr "ogiltigt %%k-värde"
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, c-format
 msgid "invalid %%K value"
 msgstr "ogiltigt %%K-värde"
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, c-format
 msgid "invalid %%O value"
 msgstr "ogiltigt %%O-värde"
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, c-format
 msgid "invalid %%q value"
 msgstr "ogiltigt %%q-värde"
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, c-format
 msgid "invalid %%t value"
 msgstr "ogiltigt %%t-värde"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, c-format
 msgid "invalid %%T value"
 msgstr "ogiltigt %%T-värde"
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, c-format
 msgid "invalid %%u value"
 msgstr "ogiltigt %%u-värde"
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, c-format
 msgid "invalid %%v value"
 msgstr "ogiltig %%v-kod"
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, c-format
 msgid "invalid %%V value"
 msgstr "ogiltigt %%V-värde"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, c-format
 msgid "invalid %%x value"
 msgstr "ogiltigt %%x-värde"
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, c-format
 msgid "invalid %%z value"
 msgstr "ogiltigt %%z-värde"
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ogiltigt %%y-värde, försök använda ”Z”-begränsningen"
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Felaktig blandning av IEEE 128-bitars och IBM 128-bitars flyttalstyper"
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-argument skickat till funktion utan prototyp"
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 msgid "Could not generate addis value for fusion"
 msgstr "Kunde inte generera addis-värde för sammanslagning"
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Kan inte generera ladda/lagra-avstånd för sammanslagning"
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 msgid "Bad GPR fusion"
 msgstr "Felaktig GPR-sammanslagning"
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "ogiltig konvertering från typen %<__vector_quad%>"
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "ogiltig konvertering till typen %<__vector_quad%>"
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "ogiltig konvertering från typen %<__vector_pair%>"
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "ogiltig konvertering till typen %<__vector_pair%>"
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "symboliska minnesreferenser stödjs endast på z10 eller senare"
 
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, c-format
 msgid "cannot decompose address"
 msgstr "kan inte dekomponera adress"
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "ogiltig jämförelseoperator för utmatningsmodifieraren ”E”"
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "ogiltig referens för utmatningsmodifieraren ”J”"
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "ogiltig adress för utmatningsmodifieraren ”O”"
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "ogiltig adress för utmatningsmodifieraren ”R”"
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "minnesreferens förväntas för utmatningsmodifieraren ”S”"
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "ogiltig adress för ”S”-utmatningsmodifierare"
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "register- eller minnesuttryck förväntas för utmatningsmodifieraren ”N”"
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "register- eller minnesuttryck förväntas för utmatningsmodifieraren ”M”"
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "ogiltig konstant för utmatningsmodifieraren ”%c”"
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "ogiltig konstant - försök med att använda en utmatningsmodifierare"
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "ogiltig konstant vektor för utmatningsmodifieraren ”%c”"
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "ogiltigt uttryck - försök med att använda en utmatningsmodifierare"
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "ogiltigt uttryck för utmatningsmodifieraren ”%c”"
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 msgid "vector argument passed to unprototyped function"
 msgstr "vektorargument skickat till funktion utan prototyp"
 
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 msgid "types differ in signedness"
 msgstr "typer skiljer i teckenhet"
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 msgid "binary operator does not support two vector bool operands"
 msgstr "binäroperator stödjer inte två vektorbooleanoperander"
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 msgid "binary operator does not support vector bool operand"
 msgstr "den binära operatorn stödjer inte vektor-bool-operand"
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "binär operator stödjer inte blandning av operanderna vektorboolean och flyttalsvektor"
 
@@ -21051,12 +21051,12 @@ msgstr "({anonym})"
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> förväntades"
@@ -21069,7 +21069,7 @@ msgstr "%<;%> förväntades"
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -21078,7 +21078,7 @@ msgstr "%<;%> förväntades"
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> förväntades"
@@ -21086,7 +21086,7 @@ msgstr "%<)%> förväntades"
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> förväntades"
@@ -21097,29 +21097,29 @@ msgstr "%<;%>, %<,%> eller %<)%> förväntades"
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> förväntades"
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> förväntades"
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> förväntades"
@@ -21129,17 +21129,17 @@ msgstr "%<{%> förväntades"
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> förväntades"
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> förväntades"
@@ -21148,8 +21148,8 @@ msgstr "%<while%> förväntades"
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> förväntades"
@@ -21159,17 +21159,17 @@ msgid "expected %<.%>"
 msgstr "%<.%> förväntades"
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> förväntades"
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> förväntades"
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> eller %<)%> förväntades"
@@ -21177,32 +21177,32 @@ msgstr "%<,%> eller %<)%> förväntades"
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> förväntades"
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> förväntades"
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, gcc-internal-format
 msgid "expected %<else%>"
 msgstr "%<else%> förväntades"
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> eller %<}%> förväntades"
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr "<meddelandet okänt vid kompileringstillfället>"
 
@@ -21210,7 +21210,7 @@ msgstr "<meddelandet okänt vid kompileringstillfället>"
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> förväntades"
@@ -21225,21 +21225,21 @@ msgstr "etikett förväntades"
 msgid "candidate:"
 msgstr "kandidat:"
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 msgid "  after user-defined conversion:"
 msgstr "  efter användardefinierad konvertering:"
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "kandidat är:"
 msgstr[1] "kandidater är:"
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr "kandidat 1:"
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr "kandidat 2:"
 
@@ -21471,7 +21471,7 @@ msgstr "%r%s:%d:%d:%R   i expansion av %<constexpr%> i %qs"
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%R   i expansion av %<constexpr%> i %qs"
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 msgid "candidates are:"
 msgstr "kandidater är:"
 
@@ -21515,48 +21515,48 @@ msgstr "konvertering konverterar bort konstantskap"
 msgid "source type is not polymorphic"
 msgstr "källtypen är inte polymorfisk"
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "fel typ på argument till unärt minus"
 
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "fel typ på argument till unärt plus"
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "fel typ på argument till bitkomplement"
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "fel typ på argument till abs"
 
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "fel typ på argument till konjunktion"
 
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 msgid "in argument to unary !"
 msgstr "i argument till unärt !"
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 msgid "no pre-increment operator for type"
 msgstr "ingen pre-ökningsoperator för typen"
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 msgid "no post-increment operator for type"
 msgstr "ingen post-ökningsoperator för typen"
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 msgid "no pre-decrement operator for type"
 msgstr "ingen pre-minskningsoperator för typen"
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 msgid "no post-decrement operator for type"
 msgstr "ingen post-minskningsoperator för typen"
 
@@ -21640,7 +21640,7 @@ msgstr "Förlegad funktion:"
 msgid "Deleted feature:"
 msgstr "Borttagen funktion:"
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 msgid "array assignment"
 msgstr "vektortilldelning"
 
@@ -21831,11 +21831,11 @@ msgstr "block-IF"
 msgid "implied END DO"
 msgstr "implicerat END DO"
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 msgid "assignment"
 msgstr "tilldelning"
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 msgid "pointer assignment"
 msgstr "pekartilldelning"
 
@@ -21995,47 +21995,47 @@ msgstr "Operanderna till användaroperatorn %%<%s%%> vid %%L är %s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanderna till användaroperatorn %%<%s%%> vid %%L är %s/%s"
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 msgid "Loop variable"
 msgstr "Slingvariabel"
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 msgid "iterator variable"
 msgstr "iteratorvariabel"
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 msgid "Start expression in DO loop"
 msgstr "Startuttryck i DO-slinga"
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 msgid "End expression in DO loop"
 msgstr "Slututtryck i DO-slinga"
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 msgid "Step expression in DO loop"
 msgstr "Steguttryck i DO-slinga"
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE-objekt"
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 msgid "ALLOCATE object"
 msgstr "ALLOCATE-objekt"
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 msgid "STAT variable"
 msgstr "STAT-variabel"
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 msgid "ERRMSG variable"
 msgstr "ERRMSG-variabel"
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 msgid "item in READ"
 msgstr "objekt i READ"
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK-variabel"
 
@@ -22044,11 +22044,11 @@ msgstr "ACQUIRED_LOCK-variabel"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "Olika CHARACTER-längder (%ld/%ld) i vektorkonstruerare"
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Heltalsspill vid beräkning av mängden minne att allokera"
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "Värdet på PDT LEN-parametern ”%s” stämmer inte överens med det i attrappdeklarationen"
@@ -22063,12 +22063,12 @@ msgstr "Aktuell stränglängd matchar inte den deklarerade för attrappargument
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Aktuell stränglängd är kortare än den deklarerade för attrappargument ”%s” (%ld/%ld)"
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Målet för återavbildning av ordning är för litet (%ld < %ld)"
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 msgid "Assignment of scalar to unallocated array"
 msgstr "Tilldelning av skalär till en oallokerad vektor"
 
@@ -22077,81 +22077,81 @@ msgstr "Tilldelning av skalär till en oallokerad vektor"
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Olika teckenlängder (%ld/%ld) i %s"
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr "POS-argumentet (%ld) är utanför intervallet 0:%ld i inbyggd BTEST"
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "POS-argument (%ld) utanför intervallet 0:%ld i inbyggd %s"
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr "POS-argumentet (%ld) är utanför intervallet 0:%ld i inbyggd IBITS"
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr "LEN-argumentet (%ld) är utanför intervallet 0:%ld i inbyggd IBITS"
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) i inbyggd IBITS"
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, c-format
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "SHIFT-argumentet (%ld) utanför intervallet 0:%ld i inbyggd %s"
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr "SHIFT-argumentet (%ld) är utanför intervallet -%ld:%ld i inbyggd ISHFT"
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr "SIZE-argumentet (%ld) är utanför intervallet 1:%ld i inbyggd ISHFTC"
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr "SHIFT-argumentet (%ld) är utanför intervallet -%ld:%ld i inbyggd ISHFTC"
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Argument NCOPIES till inbyggd REPEAT är negativt (dess värde är %ld)"
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "Argumentet NCOPIES till inbyggd REPEAT är för stort"
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, c-format
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "FROMPOS-argumentet (%ld) är utanför intervallet 0:%d i inbyggd MVBITS"
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "LEN-argumentet (%ld) är utanför intervallet 0:%d i inbyggd MVBITS"
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, c-format
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "TOPOS-argumentet (%ld) är utanför intervallet 0:%d i inbyggd MVBITS"
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) i inbyggd MVBITS"
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) i inbyggd MVBITS"
@@ -22173,15 +22173,15 @@ msgstr "Tilldelad etikett är inte en måletikett"
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Ogiltigt bildnummer %d i SYNC IMAGES"
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr "Slingan itererar oändligt"
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 msgid "Loop variable has been modified"
 msgstr "Slingvariabel har modifierats"
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 msgid "DO step value is zero"
 msgstr "DO-stegvärdet är noll"
 
@@ -22257,7 +22257,7 @@ msgid "expected boolean type"
 msgstr "boolesk typ förväntades"
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "heltal förväntades"
@@ -22320,7 +22320,7 @@ msgstr "för få argument"
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "för många argument"
@@ -22944,7 +22944,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "%<-mrelax%> stödjs endast för RTP PIC"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Syntaxfel i %s-sats vid %C"
@@ -23380,8 +23380,8 @@ msgstr "ignorerar attributet %qE eftersom det står i konflikt med attributet %q
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "tidigare deklaration här"
@@ -23398,7 +23398,7 @@ msgstr "attributdirektivet %qE ignorerat"
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr "attributdirektivet %<%E::%E%> med räckvidd ignorerat"
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, gcc-internal-format
 msgid "wrong number of arguments specified for %qE attribute"
 msgstr "fel antal argument angivet för attributet %qE"
@@ -23408,7 +23408,7 @@ msgstr "fel antal argument angivet för attributet %qE"
 msgid "expected %i or more, found %i"
 msgstr "%i eller fler förväntades, hittade %i"
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "expected %i, found %i"
 msgstr "%i förväntades, %i hittades"
@@ -23475,12 +23475,12 @@ msgstr "typattribut ignoreras efter att typen redan är definierad"
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -23489,7 +23489,7 @@ msgstr "typattribut ignoreras efter att typen redan är definierad"
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -23511,8 +23511,8 @@ msgstr "attributet %qE ignorerat"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "saknat attribut %<target%> för flerversioners %qD"
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "tidigare deklaration av %qD"
@@ -23621,7 +23621,7 @@ msgstr "det går inte att läsa profilen från %s"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "index %qwi till en konstant sträng pekar utanför dess gränser"
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE är deklarerad här"
@@ -23726,7 +23726,7 @@ msgstr "otillåtet argument 0 till %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, gcc-internal-format
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "ogiltig användning av %<__builtin_va_arg_pack ()%>"
@@ -23748,42 +23748,42 @@ msgstr "andra argumentet till %<__builtin_longjmp%> måste vara 1"
 msgid "target format does not support infinity"
 msgstr "målformatet stödjer inte oändligheten"
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> används i en funktion med fixt antal argument"
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "fel antal argument till funktionen %<va_start%>"
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> anropad utan argument"
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "fel antal argument till funktionen %<__builtin_next_arg%>"
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "andra parametern till %<va_start%> är inte det sista namngivna argumentet"
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "odefinierat beteende när andra parametern till %<va_start%> är deklarerad med lagringsklass %<register%>"
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, gcc-internal-format
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr "första argumentet till %qD måste vara en pekare, det andra en heltalskonstant"
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, gcc-internal-format
 msgid "last argument of %qD is not integer constant between 0 and 3"
 msgstr "sista argumentet till %qD är inte en heltalskonstant mellan 0 och 3"
@@ -24828,12 +24828,12 @@ msgstr "attributet %<weakref%> ignorerat för att variabeln är initierad"
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F är använd men inte definierad"
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F är deklarerad %<static%> men definieras aldrig"
@@ -25382,7 +25382,7 @@ msgstr "%<region_array%> stämmer inte med %<region_tree%>"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "%<lp_array%> stämmer inte med %<region_tree%>"
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, gcc-internal-format
 msgid "%qs failed"
 msgstr "%qs misslyckades"
@@ -25412,17 +25412,17 @@ msgstr "omvänd lagringsordning för %s-läget"
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr "skrivning av %wu-bitsdata utanför gränsen för destinationsobjektet, data avhuggen till %wu bitar"
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, gcc-internal-format
 msgid "call to %qs declared with attribute error: %s"
 msgstr "anrop av %qs deklarerat med attributet error: %s"
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, gcc-internal-format
 msgid "call to %qs declared with attribute warning: %s"
 msgstr "anrop av %qs deklarerat med attributet warning: %s"
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
 msgstr "antar att teckenspill inte förekommer vid förenkling av %<X - Y %s 0%> till %<X %s Y%>"
@@ -25457,7 +25457,7 @@ msgstr "stor fixdecimalskonstant implicit trunkerad till fixdecimaltyp"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "jämförelsen är alltid %d på grund av bredd på bitfält"
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "antar att teckenspill inte förekommer vid förenkling av intervalltest"
@@ -25620,7 +25620,7 @@ msgstr "kunde inte ta processtider: %m"
 msgid "%s signal terminated program %s"
 msgstr "%s-signal avslutade programmet %s"
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, gcc-internal-format
 msgid "unrecognized command-line option %qs"
 msgstr "okänd kommandoradsflagga %qs"
@@ -25882,7 +25882,7 @@ msgstr "multilib-specifikation %qs är ogiltig"
 msgid "multilib exclusions %qs is invalid"
 msgstr "multilib-undantag %qs är ogiltiga"
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "multilib-val %qs %qs är ogiltigt"
@@ -26181,22 +26181,22 @@ msgstr "%qD: den angivna gränsen %E överskrider destinationsstorleken %E"
 msgid "%qD specified bound %E equals source length"
 msgstr "%qD angiven gräns %E är lika med källängden"
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, gcc-internal-format
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr "flexibel vektormedlem %qD har inte väldefinierade utfyllnadsbitar för %qs"
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr "PDP11-bitfältshantering stödjs inte i %qs"
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s not supported for variable length aggregates"
 msgstr "%s stödjs inte för aggregat med variabel längd"
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "%s not supported on this target"
 msgstr "%s stödjs inte på denna målarkitektur"
@@ -26237,16 +26237,16 @@ msgid "function returns address of local variable"
 msgstr "funktionen returnerar adress till en lokal variabel"
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, gcc-internal-format
@@ -26258,366 +26258,366 @@ msgstr "deklarerad här"
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr "%<nonnull%>-argument %qD jämfört med NULL"
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr "%qE-utdata kan ha trunkerats före det sista formattecknet"
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr "%qE-utdata trunkerades före det sista formattecknet"
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr "%qE kan skriva en avslutande nolla efter slutet på destinationen"
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr "%qE skriver en avslutande nolla efter slutet på destinationen"
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] "direktivet %<%.*s%> skrev %wu byte till en region av storlek %wu"
 msgstr[1] "direktivet %<%.*s%> skrev %wu byte till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] "utdata från direktivet %<%.*s%> kan ha huggits av när %wu byte skrevs till en region av storlek %wu"
 msgstr[1] "utdata från direktivet %<%.*s%> kan ha huggits av när %wu byte skrevs till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] "utdata från direktivet %<%.*s%> avhugget när %wu byte skrevs till en region av storlek %wu"
 msgstr[1] "utdata från direktivet %<%.*s%> avhugget när %wu byte skrevs till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr "utdata från direktivet %<%.*s%> kan ha huggits av när upp till %wu byte skrevs till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr "utdata från direktivet %<%.*s%> avhugget när upp till %wu byte skrevs till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr "direktivet %<%.*s%> skrev upp till %wu byte till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "utdata från direktivet %<%.*s%> kan ha huggits av när antagligen %wu eller fler byte skrevs till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "utdata från direktivet %<%.*s%> avhugget när antagligen %wu eller fler byte skrevs till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr "direktivet %<%.*s%> skrev antagligen %wu eller fler byte till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "utdata från direktivet %<%.*s%> kan ha huggits av när mellan %wu och %wu byte skrevs till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "utdata från direktivet %<%.*s%> avhugget när mellan %wu och %wu byte skrevs till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr "direktivet %<%.*s%> skrev mellan %wu och %wu byte till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr "utdata från direktivet %<%.*s%> kan ha huggits av när %wu eller fler byte skrevs till en region med storlek %wu"
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr "utdata från direktivet %<%.*s%> avhugget när %wu eller fler byte skrevs till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr "direktivet %<%.*s%> skrev %wu eller fler byte till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] "direktivet %<%.*s%> skrev %wu byte till en region av storlek mellan %wu och %wu"
 msgstr[1] "direktivet %<%.*s%> skrev %wu byte till en region av storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] "utdata från direktivet %<%.*s%> kan ha huggits av när %wu byte skrevs till en region av storlek mellan %wu och %wu"
 msgstr[1] "utdata från direktivet %<%.*s%> kan ha huggits av när %wu byte skrevs till en region av storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] "utdata från direktivet %<%.*s%> avhugget när %wu byte skrevs till en region av storlek mellan %wu och %wu"
 msgstr[1] "utdata från direktivet %<%.*s%> avhugget när %wu byte skrevs till en region av storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "utdata från direktivet %<%.*s%> kan ha huggits av när upp till %wu byte skrevs till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "utdata från direktivet %<%.*s%> avhugget när upp till %wu byte skrevs till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "direktivet %<%.*s%> skrev upp till %wu byte till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "utdata från direktivet %<%.*s%> kan ha huggits av när antagligen %wu eller fler byte skrevs till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "utdata från direktivet %<%.*s%> höggs av när antagligen %wu eller fler byte skrevs till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "direktivet %<%.*s%> skrev antagligen %wu eller fler byte till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "utdata från direktivet %<%.*s%> kan ha huggits av när mellan %wu och %wu byte skrevs till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "utdata från direktivet %<%.*s%> höggs av när mellan %wu och %wu byte skrevs till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "direktivet %<%.*s%> skrev mellan %wu och %wu byte till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "utdata från direktivet %<%.*s%> kan ha huggits av när %wu eller fler byte skrevs till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "utdata från direktivet %<%.*s%> höggs av när %wu eller fler byte skrevs till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "direktivet %<%.*s%> skrev %wu eller fler byte till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr "direktivargumentet %<%.*s%> är null"
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr "utdata från direktivet %<%.*s%> på %wu byte överskrider minsta nödvändiga storlek på 4095"
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr "utdata från direktivet %<%.*s%> mellan %wu och %wu byte överskrider minsta nödvändiga storlek på 4095"
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr "utdata från direktivet %<%.*s%> mellan %wu och %wu byte kan överskrida minsta nödvändiga storlek på 4095"
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr "utdata från direktivet %<%.*s%> på %wu byte överskrider %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr "utdata från direktivet %<%.*s%> mellan %wu och %wu byte överskrider %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "utdata från direktivet %<%.*s%> på %wu byte får resultatet att överskrida %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "utdata från direktivet %<%.*s%> mellan %wu och %wu byte får resultatet att överskrida %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr "utdata från direktivet %<%.*s%> mellan %wu och %wu byte kan få resultatet att överskrida %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr "direktivargumentet %<%.*s%> är inte en nollavslutad sträng"
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, gcc-internal-format
 msgid "referenced argument declared here"
 msgstr "det refererade argumentet deklarerades här"
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] "antar direktivutdata på %wu byte"
 msgstr[1] "antar direktivutdata på %wu byte"
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "direktivargument %qE"
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr "direktivargument i intervallet [%E, %E]"
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr "använder intervallet [%E, %E] som direktivargument"
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgid_plural "%qE output %wu bytes into a destination of size %wu"
 msgstr[0] "%qE-utdata på %wu byte in i en destination med storlek %wu"
 msgstr[1] "%qE-utdata på %wu byte in i en destination med storlek %wu"
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr "%qE-utdata mellan %wu och %wu byte in i en destination med storlek %wu"
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr "%qE-utdata på %wu eller fler byte (antar %wu) in i en destination med storlek %wu"
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr "%qE-utdata på %wu eller fler byte in i en destination med storlek %wu"
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
 msgstr[0] "%qE-utdata %wu byte"
 msgstr[1] "%qE-utdata %wu byte"
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes"
 msgstr "%qE-utdata mellan %wu och %wu byte"
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr "%qE-utdata på %wu eller fler byte (antar %wu)"
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes"
 msgstr "%qE-utdata på %wu eller fler byte"
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr "direktivbredden %<%.*s%> är utanför intervallet"
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr "direktivprecisionen %<%.*s%> är utanför intervallet"
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr "argumentet %qE %Z och kanske %Z överlappar destinationsobjektet %qE"
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 msgid "%qE argument %Z overlaps destination object %qE"
 msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] "%qE:s argument %Z överlappar destinationsobjektet %qE"
 msgstr[1] "%qE:s argument %Z överlappar destinationsobjektet %qE"
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 msgid "%qE argument %Z may overlap destination object %qE"
 msgid_plural "%qE arguments %Z may overlap destination object %qE"
 msgstr[0] "%qE:s argument %Z kan överlappa destinationsobjektet %qE"
 msgstr[1] "%qE:s argument %Z kan överlappa destinationsobjektet %qE"
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr "destinationsobjektet som refereras av det %<restrict%>-kvalificerade argument 1 deklarerades här"
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr "angiven gräns på %wu överskrider maximal objektstorlek %wu"
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr "angiven gräns på %wu överskrider %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, gcc-internal-format
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr "angiven gränsintervall på [%wu, %wu] överskrider %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, gcc-internal-format
 msgid "null destination pointer"
 msgstr "nolldestinationspekare"
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr "angiven gräns på %wu överskrider storleken %wu på destinationsobjektet"
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, gcc-internal-format
 msgid "null format string"
 msgstr "nollformatsträng"
@@ -27354,12 +27354,12 @@ msgstr "använder en hängande pekare till %qD"
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD är deklarerad här"
@@ -28121,7 +28121,7 @@ msgstr "symbol %u har %<x-location == %u%>"
 msgid "token %u has %<y-location == %u%>"
 msgstr "symbol %u har %<y-location == %u%>"
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "ogiltig användning av attributet %<fallthrough%>"
@@ -28465,17 +28465,17 @@ msgstr "namnet %qs är definierat till ett annat värde i en annan översättnin
 msgid "mismatching definition"
 msgstr "definitionen stämmer inte överens"
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr "ogiltig fnsummary i LTO-ström"
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr "ipa-inline-sammanfattning saknas i indatafil"
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, gcc-internal-format
 msgid "IPA modref summary is missing in input file"
 msgstr "IPA modref-sammanfattning saknas i indatafilen"
@@ -29538,72 +29538,72 @@ msgstr "fel vid skrivning av optimeringsposter till %qs: %s"
 msgid "error closing optimization records %qs"
 msgstr "fel när optimeringsposter %qs stängdes"
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, gcc-internal-format
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "kommandoradsflaggan %qs stödjs inte av denna konfiguration"
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "argument saknas till %qs"
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr "argumentet till %qs skall vara ett ickenegativt heltal eventuellt följt av en storleksenhet"
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer"
 msgstr "argumentet till %qs skall vara ett ickenegativt heltal"
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, gcc-internal-format
 msgid "argument to %qs is not between %d and %d"
 msgstr "argument till %qs är inte mellan %d och %d"
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, gcc-internal-format
 msgid "invalid argument in option %qs"
 msgstr "ogiltigt argument i flaggan %qs"
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr "%qs angivet flera gånger i samma flagga"
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, gcc-internal-format
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr "%qs är ömsesidigt uteslutande med %qs och kan inte användas tillsammans"
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, gcc-internal-format
 msgid "unrecognized argument in option %qs"
 msgstr "okänt argument till flaggan %qs"
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "giltiga argument till %qs är: %s; menade du %qs?"
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "giltiga argument till %qs är: %s"
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "flaggan %qs stödjs inte längre"
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, gcc-internal-format
 msgid "argument to %qs is bigger than %d"
 msgstr "argument till %qs är större än %d"
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, gcc-internal-format
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
 msgstr "felformaterad %<COLLECT_GCC_OPTIONS%>"
@@ -29677,8 +29677,8 @@ msgstr "argumentet till %<-O%> skall vara ett ickenegativt heltal, %<g%>, %<s%>,
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, gcc-internal-format
 msgid "%qs is incompatible with %qs"
 msgstr "%qs är inkompatibel med %qs"
@@ -30392,7 +30392,7 @@ msgstr "global registervariabel följer en funktionsdefinition"
 msgid "register of %qD used for multiple global register variables"
 msgstr "register för %qD använt till flera globala registervariabler"
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "står i konflikt med %qD"
@@ -30842,42 +30842,42 @@ msgstr "sektionen för aliaset %q+D måste stämma med sektionen för dess mål"
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "%<__builtin_saveregs%> stödjs inte på denna målarkitektur"
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, gcc-internal-format
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "argument %qs stödjs inte till %qs på detta mål"
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, gcc-internal-format
 msgid "nested functions not supported on this target"
 msgstr "nästade funktioner stödjs inte på denna målarkitektur"
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, gcc-internal-format
 msgid "nested function trampolines not supported on this target"
 msgstr "nästade funktionstrampoliner stödjs inte för denna målarkitektur"
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "globala konstruerare stödjs inte för denna målarkitektur"
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "globala destruerare stödjs inte på denna målarkitektur"
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, gcc-internal-format
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "attributet %<target%> stödjs inte på denna maskin"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, gcc-internal-format
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "attributet %<target_version%> stödjs inte på denna maskin"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, gcc-internal-format
 msgid "%<#pragma GCC target%> is not supported for this machine"
 msgstr "%<#pragma GCC target%> stödjs inte för denna maskin"
@@ -31990,82 +31990,82 @@ msgstr "GB %i har felaktig båge"
 msgid "BB %i has incorrect fallthru edge"
 msgstr "GB %i har felaktig fall-igenom-båge"
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr "funktion %q+F kan aldrig kopieras eftersom den tar emot ett icke-lokalt goto"
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr "funktion %q+F kan aldrig kopieras eftersom den sparar adressen av en lokal etikett i en statisk variabel"
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr "funktion %q+F kan aldrig inline:as för att den använder alloca (åsidosätt genom att använda attributet always_inline)"
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr "funktion %q+F kan aldrig inline:as eftersom den använder setjmp"
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr "funktion %q+F kan aldrig inline:as eftersom den använder variabel argumentlista"
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr "funktion %q+F kan aldrig inline:as eftersom den använder setjmp-longjmp-undantagshantering"
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr "funktion %q+F kan aldrig inline:as eftersom den använder icke-lokala goto"
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr "funktion %q+F kan aldrig inline:as eftersom den använder %<__builtin_return%> eller %<__builtin_apply_args%>"
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr "funktion %q+F kan aldrig inline:as eftersom den innehåller ett beräknat goto"
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr "funktion %q+F kan aldrig inline:as eftersom den har ett VLA-argument"
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr "funktionen %q+F kan aldrig vara inline eftersom det stängs av av %<-fno-inline%>"
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr "funktionen %q+F kan aldrig vara inline eftersom den använder attribut som står i konflikt med inline"
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, gcc-internal-format
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr "inline:ing misslyckades i anrop av %<always_inline%> %q+F: %s"
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr "anropad härifrån"
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, gcc-internal-format
 msgid "called from this function"
 msgstr "anropad från denna funktion"
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, gcc-internal-format
 msgid "inlining failed in call to %q+F: %s"
 msgstr "inline:ing misslyckades i anrop av %q+F: %s"
@@ -32120,27 +32120,27 @@ msgstr "ogiltigt fn-specifikationsattribut ”%s”"
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr "ogiltigt fn-specifikationsattribut ”%s” arg %i"
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr "%qs pekaren är noll"
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, gcc-internal-format
 msgid "in a call to non-static member function %qD"
 msgstr "i ett anrop av en icke-statisk medlemsfunktion %qD"
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr "argument %u är noll där icke-noll förväntades"
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "i ett anrop till den inbyggda funktionen %qD"
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, gcc-internal-format
 msgid "in a call to function %qD declared %qs"
 msgstr "i ett anrop till funktionen %qD deklarerad %qs"
@@ -32344,7 +32344,7 @@ msgstr "%qs används oinitierad"
 msgid "%qs may be used uninitialized"
 msgstr "%qs kan användas oinitierad"
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD deklarerades här"
@@ -32574,7 +32574,7 @@ msgstr "vektorvillkor kommer expanderas bitvis"
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "vektorblandningsoperationen kommer expanderas bitvis"
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr "vektorisering hände inte för en simd-slinga"
@@ -32589,122 +32589,122 @@ msgstr "icke konstant element i konstant CONSTRUCTOR"
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr "sidoeffektselement i icke sidoeffekts-CONSTRUCTOR"
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "vektorer av funktioner är inte meningsfulla"
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "funktionsreturtyp kan inte vara funktion"
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "trädkontroll: %s, har %s i %s, vid %s:%d"
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "trädkontroll: förväntade ingen av %s, har %s i %s, vid %s:%d"
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "trädkontroll: förväntade klass %qs, har %qs (%s) i %s, vid %s:%d"
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "trädkontroll: klass %qs förväntades inte, har %qs (%s) i %s, vid %s:%d"
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, gcc-internal-format
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr "trädkontroll: %<omp_clause %s%> förväntades, har %qs i %s, vid %s:%d"
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "trädkontroll: förväntade träd som innehåller posten %qs, har %qs i %s, vid %s:%d"
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr "trädkontroll: använde element %d av %<tree_int_cst%> med %d element i %s, vid %s:%d"
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr "trädkontroll: använde element %d av %<tree_vec%> med %d element i %s, vid %s:%d"
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "trädkontroll: använde operand %d av %s med %d operander i %s, vid %s:%d"
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, gcc-internal-format
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "trädkontroll: använde operand %d av %<omp_clause %s%> med %d operander i %s, vid %s:%d"
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD bör undvikas: %s"
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD bör undvikas"
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE bör undvikas: %s"
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE bör undvikas"
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "typen bör undvikas: %s"
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "typen bör undvikas"
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, gcc-internal-format
 msgid "%qD is unavailable: %s"
 msgstr "%qD är otillgänglig: %s"
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, gcc-internal-format
 msgid "%qD is unavailable"
 msgstr "%qD är otillgänglig"
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, gcc-internal-format
 msgid "%qE is unavailable: %s"
 msgstr "%qE är otillgänglig: %s"
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, gcc-internal-format
 msgid "%qE is unavailable"
 msgstr "%qE är otillgänglig"
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, gcc-internal-format, gfc-internal-format
 msgid "type is unavailable: %s"
 msgstr "typen är otillgänglig: %s"
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, gcc-internal-format
 msgid "type is unavailable"
 msgstr "typen är otillgänglig"
@@ -32729,262 +32729,262 @@ msgstr "typen är otillgänglig"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr "typvarianter skiljer i %s"
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr "typvariant har en annan %<TYPE_SIZE_UNIT%>"
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr "typvariantens %<TYPE_SIZE_UNIT%>"
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr "typens %<TYPE_SIZE_UNIT%>"
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr "typvariant med %<TYPE_ALIAS_SET_KNOWN_P%>"
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr "typvariant har en annan %<TYPE_VFIELD%>"
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr "typvariant har en annan %<TYPE_BINFO%>"
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr "typvariantens %<TYPE_BINFO%>"
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr "typens %<TYPE_BINFO%>"
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr "typvariant har andra %<TYPE_FIELDS%>"
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "första som inte stämmer är fält"
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, gcc-internal-format
 msgid "and field"
 msgstr "och fält"
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr "typvariant har en annan %<TREE_TYPE%>"
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr "typvariantens %<TREE_TYPE%>"
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr "typens %<TREE_TYPE%>"
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "typen är inte kompatibel med sin variant"
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is not an opaque type"
 msgstr "typen %s är inte en ogenomskinlig typ"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is not with opaque mode"
 msgstr "typen %s har inte ogenomskinligt läge"
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr "typen %s skiljer i %<TYPE_MODE%>"
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr "typen %s skiljer i %<TYPE_SIZE%>"
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr "typen %s skiljer i %<TYPE_ALIGN%>"
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr "typen %s skiljer i %<TYPE_USER_ALIGN%>"
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, gcc-internal-format
 msgid "main variant is not defined"
 msgstr "huvudvarianten är inte definierad"
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr "%<TYPE_MAIN_VARIANT%> har en annan %<TYPE_MAIN_VARIANT%>"
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr "%<TYPE_CANONICAL%> har en annan %<TYPE_CANONICAL%>"
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr "%<TYPE_CANONICAL%> är inte kompatibla"
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr "%<TYPE_MODE%> av %<TYPE_CANONICAL%> är inte kompatibla"
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr "%<TYPE_CANONICAL%> av huvudvarianten är inte en huvudvariant"
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr "%<TYPE_VFIELD%> är varken %<FIELD_DECL%> eller %<TREE_LIST%>"
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr "%<TYPE_NEXT_PTR_TO%> är inte %<POINTER_TYPE%>"
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr "%<TYPE_NEXT_REF_TO%> är inte %<REFERENCE_TYPE%>"
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr "%<TYPE_BINFO%> är inte %<TREE_BINFO%>"
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr "%<TYPE_BINFO%>-typ är inte %<TYPE_MAIN_VARIANT%>"
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr "%<TYPE_METHOD_BASETYPE%> är inte en post eller union"
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr "%<TYPE_OFFSET_BASETYPE%> är inte en post eller union"
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr "%<TYPE_ARRAY_MAX_SIZE%> inte %<INTEGER_CST%>"
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr "%<TYPE_MAX_VALUE_RAW%> icke-NULL"
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr "%<TYPE_LANG_SLOT_1 (binfo)%>-fält är icke-NULL"
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr "enum-värde är inte %<CONST_DECL%> eller %<INTEGER_CST%>"
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr "enum-värdetyp är varken %<INTEGER_TYPE%> eller konvertibel till enum"
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr "enum-värdenamn är inte %<IDENTIFIER_NODE%>"
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "vektorn %<TYPE_DOMAIN%> är inte av heltalstyp"
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "%<TYPE_FIELDS%> definierad i ofullständig typ"
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr "fel träd i %<TYPE_FIELDS%>-lista"
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr "%<TYPE_CACHED_VALUES_P%> är %i medan %<TYPE_CACHED_VALUES%> är %p"
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr "%<TYPE_CACHED_VALUES%> är inte %<TREE_VEC%>"
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr "fel %<TYPE_CACHED_VALUES%>-post"
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr "%<TREE_PURPOSE%> är icke-NULL i %<TYPE_ARG_TYPES%>-lista"
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr "fel post i %<TYPE_ARG_TYPES%>-lista"
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr "%<TYPE_VALUES_RAW%>-fält är icke-NULL"
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr "%<TYPE_CACHED_VALUES_P%> är satt när det inte skulle vara det"
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr "%<TYPE_METHOD_BASETYPE%> är inte en huvudvariant"
@@ -33199,7 +33199,7 @@ msgstr "aliasdefinitioner stödjs inte i denna konfiguration"
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "synlighetsattribut stödjs inte för denna konfiguration, ignoreras"
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr "%+qD utan attributet %<retain%> och %qD med attributet %<retain%> är placerad i en sektion med samma namn"
@@ -33401,7 +33401,7 @@ msgstr "attributet %qE ignorerat eftersom %qD inte är en variabel"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "attributet %qE ignorerat eftersom %qD inte är en lokal variabel"
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "attributet %qE har bara effekt på publika objekt"
@@ -33583,7 +33583,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr "ignorerar attributet %qE som inte är satt på en variabel"
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for local variables"
 msgstr "attributet %qE kan inte anges för lokala variabler"
@@ -33898,7 +33898,7 @@ msgstr "%qD är inte kompatibel med %qD"
 msgid "%qE argument is not a function"
 msgstr "argumentet %qE är inte en funktion"
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "deprecated-meddelande är inte en sträng"
@@ -34403,7 +34403,7 @@ msgstr "ISO C++ tillåter inte %<alignof%> använt på en funktionstyp"
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr "ISO C tillåter inte %<_Alignof%> använt på en funktionstyp"
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, gcc-internal-format
 msgid "invalid application of %qs to a void type"
 msgstr "ogiltig användning av %qs på en void-typ"
@@ -34534,17 +34534,17 @@ msgstr "attributet %<fallthrough%> angivet flera gånger"
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "attributet %<fallthrough%> angivet med en parameter"
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "för få argument till funktionen %qE"
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, gcc-internal-format
@@ -34668,166 +34668,166 @@ msgstr "försök att ta adressen till en medlem %qD i en bitfältspost"
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "index %E anger ett avstånd större än storleken på %qT"
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "storleken på vektorn är för stor"
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "operandtypen %qT är inkompatibel med argument %d till %qE"
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, gcc-internal-format
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "argument av typen pekare eller av typen heltal förväntades som argument 1"
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr "båda argumenten måste vara kompatibla"
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "felaktigt antal argument till funktionen %qE"
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "argument 1 till %qE måste vara pekartyp som inte pekar på void"
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr "argument 1 till %qE måste vara en pekare på en fullständig typ"
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "argument 1 till %qE måste vara en pekare till en typ med konstant storlek"
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "argument 1 till %qE måste vara en pekare till ett objekt av storlek större än noll"
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "argument %d till %qE måste vara en pekartyp"
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "argument %d till %qE måste vara en pekare till en typ med konstant storlek"
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "argument %d till %qE får inte vara en pekare till en funktion"
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "storleken stämmer inte i argument %d till %qE"
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr "argument %d till %qE måste ha typen pekare på en %<const%>"
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, gcc-internal-format
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr "argument %d till %qE kastar %<const%>-kvalificerare"
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr "argument %d till %qE får inte vara en pekare på en %<volatile%> typ"
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, gcc-internal-format
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr "argument %d till %qE kastar %<volatile%>-kvalificerare"
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "minnesmodellsargument %d som inte är heltal till %qE"
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "ogiltig minnesmodellsargument %d till %qE"
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr "detta mål definierar inte en spekulationsbarriär; ditt program kommer fortfarande fungera korrekt, men felaktig spekulation kommer kanske inte vara begränsat"
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "indexvärdet är utanför gränsen"
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "konvertering av skalären %qT till vektorn %qT innebär avhuggning"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "inbyggd funktion %qE måste anropas direkt"
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr "storlek på vektorn %qE är inte ett konstant uttryck"
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr "storlek på vektorn är inte ett konstant uttryck"
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr "storleken %qE på vektorn %qE är negativ"
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, gcc-internal-format
 msgid "size %qE of array is negative"
 msgstr "storleken %qE på vektorn är negativ"
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr "storleken %qE på vektorn %qE överskrider maximal objektstorlek %qE"
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr "storleken %qE på vektorn överskrider maximal objektstorlek %qE"
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "storleken på vektorn %qE överskrider maximal objektstorlek %qE"
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr "storleken på vektorn överskrider maximal objektstorlek %qE"
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr "miljövariabeln %qs måste expandera till ett ickenegativt heltal mindre än eller lika med %wd"
@@ -35450,7 +35450,7 @@ msgstr "heltalskonstant är för stor för typen %<unsigned _BitInt(%d)%>"
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr "heltalskonstant är för stor för typen %<_BitInt(%d)%>"
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, gcc-internal-format
 msgid "%<_BitInt(%d)%> is not supported on this target"
 msgstr "%<_BitInt(%d)%> stödjs inte för denna målarkitektur"
@@ -35530,7 +35530,7 @@ msgstr "ej stödd konkatenering av stränglitteraler som inte följer standard"
 msgid "traditional C rejects string constant concatenation"
 msgstr "traditionell C stödjer inte strängkonstantsammanslagning"
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr "%<#pragma omp critical%> med %<hint%>-klausul kräver ett namn, utom när %<omp_sync_hint_none%> används"
@@ -35585,7 +35585,7 @@ msgstr "%<depobj%>-beroendetyp angiven i %<depend%>-klausul på en %<depobj%>-ko
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "en %<iterator%>-modifierare får inte anges på en %<depobj%>-konstruktion"
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ogiltig typ för iterationsvariabeln %qE"
@@ -35600,17 +35600,17 @@ msgstr "%<_Atomic%>-iterationsvariabel %qE"
 msgid "%qE is not initialized"
 msgstr "%qE är inte initierad"
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "styrpredikat saknas"
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "ogiltigt styrpredikat"
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "utelämnat ökningsuttryck"
@@ -35620,7 +35620,7 @@ msgstr "utelämnat ökningsuttryck"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr "ökningen är inte en konstant 1 eller -1 för villkoret %<!=%>"
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "ogiltigt ökningsuttryck"
@@ -35705,7 +35705,7 @@ msgstr "felaktig reduktionsmodifierare %<task%> på en konstruktion inte kombine
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr "%<inscan%> %<reduction%>-klausul på en annan konstruktion än %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr "%qD angivet i en %<allocate%>-klausul men inte i en explicit privatiseringsklausul"
@@ -35715,7 +35715,7 @@ msgstr "%qD angivet i en %<allocate%>-klausul men inte i en explicit privatiseri
 msgid "%qD is not a function argument"
 msgstr "%qD är inte ett funktionsargument"
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "bitfältet %qE i %qs-klausul"
@@ -36307,7 +36307,7 @@ msgid "wrong type argument to %s"
 msgstr "fel typ på argument till %s"
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -37230,35 +37230,35 @@ msgstr "jämförelse mellan två vektorer"
 
 #: c-family/c-warn.cc:3832
 #, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
-msgstr "använd unärt %<+%> som degenererar operander till pekare eller %<&%D[0] %s &%D[0]%> för att jämföra adresser"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
+msgstr "använd unärt %<+%> som degenererar operander till pekare eller %<&%s%E%s[0] %s &%s%E%s[0]%> för att jämföra adresser"
 
-#: c-family/c-warn.cc:3836
+#: c-family/c-warn.cc:3839
 #, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
-msgstr "använd %<&%D[0] %s &%D[0]%> för att jämföra adresser"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
+msgstr "använd %<&%s%E%s[0] %s &%s%E%s[0]%> för att jämföra adresser"
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr "resultatet av %<%wu^%wu%> är %wu; menade du %<1 << %wu%> (%wu)?"
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr "resultatet av %<%wu^%wu%> är %wu; menade du %<1LL << %wu%>?"
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr "resultatet av %<%wu^%wu%> är %wu; menade du exponentiering?"
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr "resultatet av %<%wu^%wu%> är %wu; menade du %<1e%wu%>?"
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr "man kan tysta denna varning genom att använda en hexadecimal konstant (%wx istället för %wd)"
@@ -37467,117 +37467,117 @@ msgstr "argumentet till %<-misr-secure=%d%> är inte mellan 0 och 3"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr "för flaggan %<-mcache-block-size=X%> måste ett giltigt X vara: 4, 8, 16, 32, 64, 128, 256 eller 512"
 
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr "%<-march=%s%>: utökningen %qs förekommer mer än en gång."
 
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr "%<-march=%s%>: utökningen %qs är en standard enkelbokstavsutökning som inte stödjs"
 
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr "%<-march=%s%>: utökningen %qs börjar med ”z” men är en standardutökning som inte stödjs"
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr "%<-march=%s%>: utvidgningen %qs börjar med ”s” men är en standardövervakarutvidgning som inte stöjds"
 
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr "%<-march=%s%>: utökningen %qs börjar med ”x” men är en icke-standardutökning som inte stödjs"
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, gcc-internal-format
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr "%<-march=%s%>: ett tal förväntades efter %<%dp%>."
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr "%<-march=%s%>: för %<%s%dp%dp?%>, versionsnummer med mer än 2 nivåer stödjs inte"
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr "%<-march=%s%>: ISA-strängen måste börja med rv32 eller rv64"
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr "%<-march%s%>: rv%de är inte en giltig bas-ISA"
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr "versionen av %<g%> kommer utelämnas, ange en version för individuell utökning."
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr "%<-march=%s%>: första ISA-undergrupp måste vara %<e%>, %<i%> eller %<g%>"
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, gcc-internal-format
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr "%<-march=%s%>: Inte en enbokstavsutökning. %<%c%>"
 
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr "%<-march=%s%>: utökningen zcf stödjs bara i rv32"
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr "%<-march=%s%>: z*inx står i konflikt med flyttalsutökningar"
 
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, gcc-internal-format
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr "%<-march=%s%>: utökningen h kräver utökningen i"
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr "%<-mcpu=%s%> zcd står i konflikt med zcmt"
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr "%<-mcpu=%s%> zcd står i konflikt med zcmp"
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr "%<-march=%s%>: xtheadvector står i konflikt med en vektorutökning eller des underutökning"
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "%<-march=%s%>: namnet på %s måste vara mer än 1 bokstav"
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr "%<-march=%s%>: %s måste separeras med %<_%>"
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, gcc-internal-format
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr "%<-march=%s%>: i, e eller g måste vara den första utökningen"
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "%<-mcpu=%s%>: okänd CPU"
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr "Kan inte hitta en lämpligt multilib-mängd för %<-march=%s%>/%<-mabi=%s%>"
@@ -37975,12 +37975,12 @@ msgstr "en 64-bitars adress förväntades men argument 1 är %d-bitars"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "en 64-bitars adress förväntades men argument 2 är %d-bitars"
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC aarch64%> kräver en strängparameter"
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "okänd %<#pragma GCC aarch64%>-flagga %qs"
@@ -38544,7 +38544,7 @@ msgstr "parameterskickandet för argument av typen %qT ändrades i GCC 14.1"
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "parameterskickandet för argument av typen %qT ändrades i GCC 9.1"
@@ -38620,12 +38620,12 @@ msgid "unknown tuning option (%s)"
 msgstr "okänd trimningsflagga (%s)"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr "inkompatibla flaggor %<-mstack-protector-guard=global%> och %<-mstack-protector-guard-offset=%s%>"
 
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr "både %<-mstack-protector-guard-offset%> och %<-mstack-protector-guard-reg%> måste användas med %<-mstack-protector-guard=sysreg%>"
@@ -38636,7 +38636,7 @@ msgid "specify a system register with a small string length"
 msgstr "ange ett systemregister med en liten stränglängd"
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs är inte ett giltigt avstånd i %qs"
@@ -38816,9 +38816,9 @@ msgstr "pragmat eller attributet %<target(\"%s\")%> tillåter inte en negerad fo
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "pragmat eller attributet %<target(\"%s=%s\")%> är inte giltigt"
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "argument till attribut %<target%> är inte en sträng"
@@ -38870,18 +38870,18 @@ msgid "virtual function multiversioning not supported"
 msgstr "multiversionering av virtuell funktion stödjs inte"
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "multiversionering behöver %<ifunc%> som inte stödjs på detta mål"
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr "parameterskickandet för argument av typen %qT med %<[[no_unique_address]]%>-medlemmar ändrades %{i GCC 10.1%}"
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr "parameterskickandet för argument av typen %qT när C++17 är aktiverat ändrades till att matcha C++14 %{i GCC 10.1%}"
 
@@ -38894,8 +38894,8 @@ msgstr "parameterskickandet för argument av typen %qT ändrades %{i GCC 12.1%}"
 msgid "lane %wd out of range %wd - %wd"
 msgstr "bana %wd utanför intervallet %wd - %wd"
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "ej stödd simdlen %wd"
@@ -38905,7 +38905,7 @@ msgstr "ej stödd simdlen %wd"
 msgid "GCC does not currently support return type %qT for simd"
 msgstr "GCC stödjer för närvarande inte returtypen %qT för simd"
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "returtyp %qT stödjs ej för simd"
@@ -38915,7 +38915,7 @@ msgstr "returtyp %qT stödjs ej för simd"
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr "GCC stödjer för närvarande inte argumenttypen %qT för simd"
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "argumenttyp %qT som inte stödjs till simd"
@@ -39005,8 +39005,8 @@ msgstr "L%d-cachelatens okänd för %s"
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "felaktigt värde %qs till %<-mmemory-latency%>"
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr "felaktig inbyggd fcode"
@@ -39126,18 +39126,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "argumentet till attributet %qE är inte ”ilink” eller ”firq”"
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -39251,7 +39251,7 @@ msgid "argument of %qE attribute is missing"
 msgstr "argumentet till attributet %qE saknas"
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "attributet %qE tillåter endast en heltalskonstant som argument"
@@ -39271,23 +39271,23 @@ msgstr "attributet %qE är bara tillämpligt på typer"
 msgid "argument of %qE attribute ignored"
 msgstr "argumentet till attributet %qE ignoreras"
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "attributet %qE är bara tillämpligt på variabler"
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "alternativ är inte tillåtna i %<asm%>-flaggutdata"
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr "okänd %<asm%>-flaggutdata %qs"
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "ogiltig typ för %<asm%>-flaggutdata"
@@ -39529,7 +39529,7 @@ msgstr "målprocessorn stödjer inte THUMB-instruktioner"
 msgid "target CPU does not support unaligned accesses"
 msgstr "målprocessorn stödjer inte ojusterade åtkomster"
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr "Denna arkitektur stödjer inte grenskyddsinstruktioner"
@@ -39579,7 +39579,7 @@ msgstr "storleksgräns för poster kan bara sättas till 8 eller 32"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC är inkompatibelt med %<-msingle-pic-base%>"
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "FDPIC-läget stödjs inte i Thumb-1-läge"
@@ -39685,7 +39685,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr "argument av typen %qT är inte tillåtna med %<-mgeneral-regs-only%>"
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "parameterskickandet för argument av typen %qT ändrades i GCC 7.1"
@@ -39725,42 +39725,42 @@ msgstr "attributet %qE har ingen effekt på funktioner med statisk länkklass"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "attributet %qE är bara tillämpligt på bastypen av en funktionspekare"
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr "att nå trådlokal lagring stödjs inte för närvarande med %<-mpure-code%> eller %<-mslow-flash-data%>"
 
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd utanför intervall %wd - %wd"
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "kan inte beräkna verklig plats för stackparameter"
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Oväntat långt thumb1-hopp"
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "inga låga register tillgängliga för att poppa höga register"
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "Avbrottshanteringsrutiner kan inte kodas i Thumb-1-läge"
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "%<-fstack-check=specific%> för Thumb-1"
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "ogiltig fpu för målattributet eller pragmat %qs"
@@ -39768,22 +39768,22 @@ msgstr "ogiltig fpu för målattributet eller pragmat %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "automatiskt fpu-val är för närvarande inte tillåtet här"
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "ogiltig arkitektur för målattribut eller -pragma %qs"
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "okänt målattribut eller -pragma %qs"
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "%<asm%>-flaggor stödjs inte i thumb1-läge"
@@ -39837,158 +39837,158 @@ msgstr "stödda kärnarkitekturer:%s"
 msgid "unknown core architecture %qs specified with %qs"
 msgstr "okänd kärnarkitektur %qs angiven till %qs"
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, gcc-internal-format
 msgid "%<-fpic%> is not supported"
 msgstr "%<-fpic%> stödjs inte"
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, gcc-internal-format
 msgid "%<-fPIC%> is not supported"
 msgstr "%<-fPIC%> stödjs inte"
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, gcc-internal-format
 msgid "%<-fpie%> is not supported"
 msgstr "%<-fpie%> stödjs inte"
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, gcc-internal-format
 msgid "%<-fPIE%> is not supported"
 msgstr "%<-fPIE%> stödjs inte"
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "funktionsattributen %qs och %qs är ömsesidigt uteslutande"
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "funktionen %qs kan inte ha argument"
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "funktionen %qs kan inte returnera ett värde"
 
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, gcc-internal-format
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs verkar vara en felstavad %qs-hanterare, prefixet %<__vector%> saknas"
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr "%qs är en reserverad identifierare i AVR-LibC.  Överväg %<#include <avr/interrupt.h>%> före makrot %qs används"
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, gcc-internal-format
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr "%qs är en undanbedd identifierare i AVR-LibC. Överväg %<#include <avr/interrupt.h>%> eller %<#include <compat/deprecated.h>%> före makrot %qs används"
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr "%<builtin_return_address%> innehåller bara 2 byte adress"
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr "pekarförskjutning från symbol kan vara oriktig"
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr "åtkomst av dataminne med programminnesadress"
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr "åtkomst av programminne med dataminnesadress"
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr "fast register %s använt för att skicka en parameter till en funktion"
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "skrivning till adressrymden %qs stödjs inte"
 
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "attributet %qE är bara tillämpligt på variabler med statisk lagringsklass"
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "attributet %qE stödjs bara för reducerade Tiny-kärnor"
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, gcc-internal-format
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr "adressen till attributet %qE är utanför giltigt intervall 0x%x%s0x%x"
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr "både attributet %s och %qE anger en adress"
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "attributet %qE på en icke-volatile variabel"
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "adressrymder stödjs inte för reducerade Tiny-enheter"
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "adressrymden %qs stödjs inte för enheter med flash-storlek upp till %d KiB"
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr "pekare med mål i adressrymden %qs måste vara konstanta i %qT"
 
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr "pekare med mål i adressrymden %qs måste vara konstanta i %s %q+D"
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, gcc-internal-format
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr "variabeln %q+D med attributet %qs måste vara placerat i statisk lagring"
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr "variabeln %q+D måste vara const för att kunna läggas i en endast läsbar sektion med hjälp av %qs"
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, gcc-internal-format
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr "deklarationen av det statiska attributet %qs för %q+D behöver en adress"
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr "bara oinitierade variabler kan placeras i sektionen %<.noinit%>"
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, gcc-internal-format
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr "variabeln %q+D med dynamisk initiering placerad i programminnesområdet"
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "den oinitierade variabeln %q+D placerad i programminnesområdet"
@@ -39997,42 +39997,42 @@ msgstr "den oinitierade variabeln %q+D placerad i programminnesområdet"
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, gcc-internal-format
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr "variabeln %q+D med attributet %qs får inte ha en initierare"
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%q+D har inkompatibla attribut %qs och %qs"
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr "arkitekturen %qs stödjs endast i assembler"
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "konvertering från adressrymd %qs till adressrymd %qs"
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "%s förväntar sig ett heltal konstant vid kompileringstillfället"
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%s förväntar sig ett långt heltal konstant vid kompileringstillfället som första argument"
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr "avrundning till %d bitar har ingen effekt för flyttalsvärde med %d decimalbitar"
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr "avrundningsresultatet kommer alltid bli 0"
@@ -40168,7 +40168,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "indirekt anrop i en funktion, vilket inte stödjs av eBPF"
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, gcc-internal-format
@@ -40787,8 +40787,8 @@ msgstr "argumentet till den inbyggda %<xabort%> måste vara en 8-bitars omedelba
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr "funktionsversioner kan inte markeras som %<gnu_inline%>, kropparna måste vara genererade"
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "kodmodellen %s stödjer inte PIC-läge"
@@ -40854,259 +40854,259 @@ msgstr "för många storleksintervall angivna i flaggan %qs"
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "okänd parameter till flaggan %<-mtune-ctrl%>: %s"
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "Intel MCU psABI stödjs inte i %s-läge"
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> bör undvikas.  Använd istället det som passar av %<-mtune=k8%> och %<-mtune=generic%>"
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> bör undvikas.  Använd istället det som passar av %<target(\"tune=k8\")%> och %<target(\"tune=generic\")%>"
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr "stödet för %<-mtune=knl%> kommer tas bort i GCC 15"
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr "stödet för %<target(\"tune=knl\")%> kommer tas bort i GCC 15"
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr "stödet för %<-mtune=knm%> kommer tas bort i GCC 15"
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr "stödet för %<target(\"tune=knm\")%> kommer tas bort i GCC 15"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "%<-mstringop-strategy=rep_8byte%> stödjs inte för 32-bitarskod"
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, gcc-internal-format
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "%<-mapxf%> stödjs inte för 32-bitarskod"
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, gcc-internal-format
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr "flaggan %<-mapx-features=%>- stödjs inte för 32-bitarskod"
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "%<-muintr%> stödjs inte för 32-bitarskod"
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "%<-mlam=%> flaggan: [u48|u57] stödjs inte för 32-bitarskod"
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "adressläget %qs stödjs inte i %s-bitsläge"
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-mabi=ms%> stödjs inte med X32 ABI"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "%<-mabi=%s%> stödjs inte med %<-fsanitize=address%>"
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "%<-mabi=%s%> stödjs inte med %<-fsanitize=kernel-address%>"
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "%<-mabi=%s%> stödjs inte med %<-fsanitize=thread%>"
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr "%<-mlam=u48%> är inte kompatibelt med hårdvaruassisterad AddressSanitizer, åsidosätt till %<-mlam=u57%>"
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "kodmodellen %qs stödjs inte i %s-bitsläge"
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "kodmodellen %qs stödjs inte i x32-läge"
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "%<-masm=intel%> stödjs inte i denna konfiguration"
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-bitsläge inte inkompilerat"
 
 # "generic" är bokstavligt argument till flaggan
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU %<generic%> kan användas endast till flaggan %<-mtune=%>"
 
 # "generic" är bokstavligt argument till flaggan
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU %<generic%> kan användas endast till attributet %<target(\"tune=\")%>"
 
 # "intel" är bokstavligt argument till flaggan
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU %<intel%> kan användas endast till flaggan %<-mtune=%>"
 
 # "intel" är bokstavligt argument till flaggan
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU %<intel%> kan användas endast till attributet %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "CPU:n du valde stödjer inte instruktionsuppsättningen x86-64"
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr "stödet för %<-march=knl%> kommer tas bort i GCC 15"
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr "stödet för %<target(\"arch=knl\")%> kommer tas bort i GCC 15"
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr "stödet för %<-march=knm%> kommer tas bort i GCC 15"
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr "stödet för %<target(\"arch=knm\")%> kommer tas bort i GCC 15"
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, gcc-internal-format
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "felaktigt värde %qs till flaggan %<-march=%>"
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "felaktigt värde %qs till attributet %<target(\"arch=\")%>"
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "giltiga argument till flaggan %<-march=%> är: %s; menade du %qs?"
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "giltiga argument till attributet %<target(\"arch=\")%> är: %s; menade du %qs?"
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "giltiga argument till flaggan %<-march=%> är: %s"
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "giltiga argument till attributet %<target(\"arch=\")%> är: %s"
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "felaktigt värde %qs till flaggan %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "felaktigt värde %qs till attributet %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "giltiga argument till flaggan %<-mtune=%> är: %s; menade du %qs?"
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "giltiga argument till attributet %<target(\"tune=\")%> är: %s; menade du %qs?"
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "giltiga argument till flaggan %<-mtune=%> är: %s"
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "giltiga argument till attributet %<target(\"tune=\")%> är: %s"
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "%<-mregparm%> ignoreras i 64-bitsläge"
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "%<-mregparm%> ignoreras för Intel MCU psABI"
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "%<-mregparm=%d%> är inte mellan 0 och %d"
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "%<-m96bit-long-double%> är inte kompatibelt med denna målarkitektur"
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> ignoreras i 64-bitsläge"
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> ignoreras i 64-bitsläge"
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr "%<-mno-evex512%> eller %<-mno-avx512XXX%> kan inte avaktivera AVX10-instruktioner när AVX10.1-512 är tillgängligt"
@@ -41114,291 +41114,291 @@ msgstr "%<-mno-evex512%> eller %<-mno-avx512XXX%> kan inte avaktivera AVX10-inst
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr "Att använda %<-mevex512%> utan några AVX512-funktioner aktiverade tillsammans med endast AVX10.1 kommer inte aktivera några AVX512- eller AVX10.1-512-funktioner, använder 256 som maximal vektorstorlek"
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr "Vektorstorleken står i konflikt mellan AVX10.1 och AVX512, använder 512 som maximal vektorstorlek"
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr "%<-mno-avx512XXX%> kan inte avaktivera AVX10-instruktioner när AVX10 är tillgängligt"
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> kan inte avaktivera AVX512-instruktioner när %<-mavx512XXX%>"
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "%<-mpreferred-stack-boundary%> stödjs inte för denna målarkitektur"
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> är inte mellan %d och %d"
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "%<-mincoming-stack-boundary=%d%> är inte mellan %d och 12"
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%<-mnop-mcount%> är inte kompatibelt med denna målarkitektur"
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "%<-mnop-mcount%> är inte implementerat för %<-fPIC%>"
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> använd utan SSE aktiverat"
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> använt utan SSE aktiverat"
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "instruktionsuppsättningen SSE avaktiverad, använder 387-aritmetik"
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "instruktionsuppsättningen 387 avaktiverad, använder SSE-aritmetik"
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "stackavkänning kräver %<-maccumulate-outgoing-args%> för att bli korrekt"
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "stackavkänning kräver %<target(\"accumulate-outgoing-args\")%> för att bli korrekt"
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "fasta ebp-register kräver %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "fasta ebp-register kräver %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "%<-mfentry%> stödjs inte för 32 bitar i kombination med %<-fpic%>"
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%<-mno-fentry%> är inte kompatibelt med SEH"
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "%<-mcall-ms2sysv-xlogues%> stödjs inte för närvarande med SEH"
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "okänt alternativ till %<-mrecip=%s%>"
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs är inte ett giltigt tal i %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs är inte ett giltigt avstånd i %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs är inte ett giltigt basregister i %<-mstack-protector-guard-reg=%>"
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr "%<-fcf-protection=full%> är inte aktiverat av %<-fhardened%> eftersom det angavs på kommandoraden"
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%<-fcf-protection%> är inte kompatibelt med denna målarkitektur"
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "attributen interrupt och naked är inte kompatibla"
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "attributen %qs och %qs är inte kompatibla"
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr "endast felsökningsformatet DWARF stödjs för en avbrottshanteringsrutin"
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> och %<-mcmodel=large%> är inte kompatibla"
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mindirect-branch%> och %<-fcf-protection%> är inte kompatibla"
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> och %<-mcmodel=large%> är inte kompatibla"
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mfunction-return%> och %<-fcf-protection%> är inte kompatibla"
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "%s-instruktioner är inte tillåtna i en undantagshanteringsrutin"
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "%s-instruktioner är inte tillåtna i en avbrottshanteringsrutin"
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "%s-instruktioner är inte tillåtna i en funktion med attributet %<no_caller_saved_registers%>"
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "attributen fastcall och regparm är inte kompatibla"
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "attributen regparam och thiscall är inte kompatibla"
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "attributet %qE kräver en heltalskonstant som argument"
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "argument till attributet %qE är större än %d"
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "attributen fastcall och cdecl är inte kompatibla"
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "attributen fastcall och stdcall är inte kompatibla"
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "attributen fastcall och thiscall är inte kompatibla"
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "attributen stdcall och cdecl är inte kompatibla"
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "attributen stdcall och fastcall är inte kompatibla"
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "attributen stdcall och thiscall är inte kompatibla"
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "attributen cdecl och thiscall är inte kompatibla"
 
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "attributet %qE används för annat än klassmetod"
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-inkompatibelt attribut ignorerat"
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "attributet %qE är bara tillgängligt för 32 bitar"
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "argumentet till attributet %qE är varken noll eller ett"
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "attributet %qE kräver en strängkonstant som argument"
 
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "argumentet till attributet %qE är inte (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "avbrottshanteringsrutiner skall ha en pekare som första argument"
 
 # "unsigned %sint" är tänkt att expanderas till C-syntax
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "avbrottshanteringsrutiner skall ha %qs som andra argument"
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "avbrottshanteringrutiner kan endast ha ett pekarargument och ett valfritt heltalsargument"
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "avbrottshanteringsrutiner måste returnera %<void%>"
@@ -41589,46 +41589,46 @@ msgstr "ej stödd operandstorlek för utökat register"
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "operand som inte är heltal använt med operandkod %<z%>"
 
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr "den tomma klassen %qT parameterskickande ABI ändras i %<-fabi-version=12%> (GCC 8)"
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr "justeringen av %<_Atomic %T%>-fält ändrades i %{GCC 11.1%}"
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, gcc-internal-format
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr "inga register tillgängliga för profilering %<-mcmodel=large%s%>"
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "profileringen %<-mcmodel=large%> med PIC stödjs inte"
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr "%<__bfloat16%> är omdefinierat från typedef %<short%> till reell %<__bf16%> sedan GCC 13.1, var vaksam på implicita konverteringar mellan %<__bf16%> och %<short%>; en explicit bittypkonvertering kan behövas här"
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "okänd arkitekturspecifik minnesmodell"
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr "%<HLE_ACQUIRE%> används inte med %<ACQUIRE%> eller starkare minnesmodell"
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr "%<HLE_RELEASE%> används inte med %<RELEASE%> eller starkare minnesmodell"
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr "%<-fexcess-precision=16%> är inte kompatibel med %<-mfpmath=387%>"
@@ -41648,8 +41648,8 @@ msgstr "definition av statisk datamedlem %q+D i dllimport:erad klass"
 msgid "malformed %<#pragma builtin%>"
 msgstr "felformaterat %<#pragma builtin%>"
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, gcc-internal-format
 msgid "invalid argument of %qE attribute"
 msgstr "ogiltigt argument till attributet %qE"
@@ -41704,12 +41704,12 @@ msgstr "%<PRINT_OPERAND%>: Okänd interpunktion %<%c%>"
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr "%<PRINT_OPERAND%> null-pekare"
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "argument %d till den inbyggda måste vara en konstant i intervallet från %d till %d"
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, gcc-internal-format
 msgid "failed to expand built-in function"
 msgstr "misslyckades att expandera inbyggd funktion"
@@ -41835,17 +41835,17 @@ msgstr "kodmodellen %qs är inte kompatibel med %s"
 msgid "%qs cannot be used for compiling a shared library"
 msgstr "%qs kan inte användas till kompilering av ett delat bibliotek"
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr "attributet %qE kan inte anges för trådlokala variabler"
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for register variables"
 msgstr "attributet %qE kan inte anges för registervariabler"
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, gcc-internal-format
 msgid "multiple %qE attribute"
 msgstr "multipla %qE-attribut"
@@ -41946,12 +41946,12 @@ msgstr "flera avbrottsattribut är inte tillåtet"
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr "%<interrupt_thread%> är tillgängligt endast för fido"
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "stackgränsuttryck stödjs inte"
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not supported on this target"
 msgstr "%<-fexcess-precision=16%> stödjs inte för denna målarkitektur"
@@ -41992,7 +41992,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr "%<-mxl-multiply-high%> kräver %<-mno-xl-soft-mul%>"
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "attributet %qE behöver ett strängargument"
@@ -42032,132 +42032,132 @@ msgstr "avbrottsvektor till %qE-attributet är inte %<vector=(sw0|sw1|hw0|hw1|hw
 msgid "argument to %qE attribute is not intstack"
 msgstr "argumentet till attributet %qE är inte intstack"
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr "ABI:et för att skicka ett värde som innehåller fält med nollbredd före ett intilliggande 64-bitars flyttalsfält ändrades i GCC %{12.1%}"
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr "ABI:et för att returnera ett värde som innehåller bitfält med noll bredd men i övrigt ett aggregat med endast ett eller två flyttalsfält ändrades i GCC %{12.1%}"
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr "ABI:et för att returnera ett värde med C++17 tomma baser men i övrigt ett aggregat med endast ett eller två flyttalsfält ändrades i GCC %{12.1%}"
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, gcc-internal-format
 msgid "cannot handle inconsistent calls to %qs"
 msgstr "kan inte hantera inkonsistenta anrop av %qs"
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr "attributet %<interrupt%> kräver en MIPS32r2-processor eller bättre"
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr "avbrottshanterare kan inte vara MIPS16-funktioner"
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr "%<-fstack-check=specific%> är inte implementerat för MIPS16"
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, gcc-internal-format
 msgid "built-in function %qE not supported for MIPS16"
 msgstr "inbyggd funktion %qE stödjs inte för MIPS16"
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, gcc-internal-format
 msgid "%qs does not support MIPS16 code"
 msgstr "%qs stödjer inte MIPS16-kod"
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr "MIPS16 PIC för andra ABI:er än o32 och o64"
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, gcc-internal-format
 msgid "MIPS16 %<-mxgot%> code"
 msgstr "MIPS16 %<-mxgot%>-kod"
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, gcc-internal-format
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr "MIPS16-kod med %<hard-float%> för andra ABI:er än o32 och o64"
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, gcc-internal-format
 msgid "MSA MIPS16 code"
 msgstr "MSA MIPS16-kod"
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, gcc-internal-format
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr "MIPS16 behöver %<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported combination: %s"
 msgstr "ej stödd kombination: %s"
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, gcc-internal-format
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr "%<-%s%> står i konflikt med andra arkitekturflaggor, som anger en %s-processor"
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, gcc-internal-format
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr "%<-march=%s%> är inte kompatibelt med det valda ABI:et"
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr "%<-mgp64%> använt med en 32-bitarsprocessor"
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, gcc-internal-format
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr "%<-mgp32%> använt med ett 64-bitars ABI"
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr "%<-mgp64%> använt med ett 32-bitars ABI"
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "arkitekturen %qs stödjer inte %<-mfp32%>"
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr "%<-mgp32%> och %<-mfp64%> kan bara kombineras om målet stödjer instruktionerna mfhc1 och mthc1"
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr "%<-mgp32%> och %<-mfp64%> kan endast kombineras när ABI:et o32 används"
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr "%<-mfpxx%> kan endast användas med ABI:et o32"
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr "%<-march=%s%> kräver %<-mfp32%>"
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr "%<-mfpxx%> kräver %<-mlra%>"
@@ -42167,117 +42167,117 @@ msgstr "%<-mfpxx%> kräver %<-mlra%>"
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, gcc-internal-format
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr "kombinationen av %qs och %qs är inkompatibel med %qs"
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, gcc-internal-format
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr "arkitekturen %qs stödjer inte trolig gren-instruktioner"
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, gcc-internal-format
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr "arkitekturen %qs stödjer inte instruktionerna madd eller msub"
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr "arkitekturen %qs stödjer inte udda enkelprecisionsregister"
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, gcc-internal-format
 msgid "unsupported combination: %qs%s %s"
 msgstr "ej stödd kombination: %qs%s %s"
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, gcc-internal-format
 msgid "unsupported combination: %qs %s"
 msgstr "ej stödd kombination: %qs %s"
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, gcc-internal-format
 msgid "cannot generate position-independent code for %qs"
 msgstr "kan inte generera positionsoberoende kod för %qs"
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, gcc-internal-format
 msgid "position-independent code requires %qs"
 msgstr "positionsoberoende kod behöver %qs"
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr "%<-mno-gpopt%> behöver %<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr "det går inte att använda smådataåtkomster för %qs"
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr "arkitekturen %qs stödjer inte %<-m%s=legacy%>"
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr "arkitekturen %qs stödjer inte %<-m%s=2008%>"
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, gcc-internal-format
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr "%<-mips3d%> kräver %<-mpaired-single%>"
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, gcc-internal-format
 msgid "%qs must be used with %qs"
 msgstr "%qs måste användas tillsammans med %qs"
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, gcc-internal-format
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr "%<-mmsa%> måste användas med %<-mfp64%> och %<-mhard-float%>"
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, gcc-internal-format
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr "arkitekturen %qs stödjer inte par-enkel-instruktioner"
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr "%qs kräver ett mål som klarar instruktionen %qs"
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, gcc-internal-format
 msgid "the %qs architecture does not support DSP instructions"
 msgstr "arkitekturen %qs stödjer inte DSP-instruktioner"
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, gcc-internal-format
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr "%<-mloongson-mmi%> måste användas med %<-mhard-float%>"
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, gcc-internal-format
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr "%<-mloongson-ext2%> måste användas med %<-mloongson-ext%>"
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, gcc-internal-format
 msgid "%qs requires branch-likely instructions"
 msgstr "%qs kräver trolig gren-instruktioner"
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, gcc-internal-format
 msgid "the %qs architecture does not support the synci instruction"
 msgstr "arkitekturen %qs stödjer inte instruktionen synci"
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr "funktionsprofilering för mips16"
@@ -43148,57 +43148,57 @@ msgstr "%<#pragma riscv intrinsic%> kräver en strängparameter"
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "okänd %<#pragma riscv intrinsic%>-flagga %qs"
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr "oväntad arkitektur till attributet %<target()%>: måste börja med + elller rv"
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr "oväntat arkitektur till attributet %<target()%>: felaktig sträng funnen %<%s%>"
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, gcc-internal-format
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr "attributet %<target()%>: arkitekturen förekommer mer än en gång"
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, gcc-internal-format
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr "attributet %<target()%>: cpu:n förekommer mer än en gång"
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr "attributet %<target()%>: okänd CPU %qs"
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, gcc-internal-format
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr "attributet %<target()%>: trimning förekommer mer än en gång"
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr "attributet %<target()%>: okänd TUNE %qs"
 
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, gcc-internal-format
 msgid "malformed %<target()%> attribute"
 msgstr "felformaterat attribut %<target()%>"
 
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, gcc-internal-format
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "attributet %<target(\"%s\")%> tar inte något argument"
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, gcc-internal-format
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr "Fick ett okänt attribut %<target(\"%s\")%>"
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> attribute"
 msgstr "felformaterat attribut %<target(\"%s\")%>"
@@ -43258,172 +43258,192 @@ msgstr "kan inte kasta eller fånga RVV-typen %qT"
 msgid "capture by copy of RVV type %qT"
 msgstr "fångst av kopia av RVV-typen %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, gcc-internal-format
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr "den inbyggda funktionen %qE behöver ISA-utökningen zvfhmin eller zvfh"
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr "den inbyggda funktionen %qE behöver ISA-utökningen zve32f, zve64f, zve64d eller v"
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr "den inbyggda funktionen %qE behöver ISA-utökningen zve64d eller v"
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr "den inbyggda funktionen %qE behöver ISA-utökningen zve64x, zve64f, zve64d eller v"
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, gcc-internal-format
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr "den inbyggda funktionen %qE kräver ISA-utökningen %qs"
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, gcc-internal-format
 msgid "no matching function call to %qE with empty arguments"
 msgstr "ingen funktion som stämmer för anrop av %qE med tomma argument"
 
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "okänt cpu %qs till %<-mtune%>"
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, gcc-internal-format
 msgid "this operation requires the RVV ISA extension"
 msgstr "denna åtgärd kräver ISA-utökningen RVV"
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr "man kan aktivera RVV genom att använda kommandoradsflaggan %<-march%>, eller genom att använda attributet eller pragmat %<target%>"
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI:et för en tillplattad post med nollängds bitfält ändrades i GCC 10"
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, gcc-internal-format
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr "RVV-typen %qT kan inte skickas till en funktion utan prototyp"
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, gcc-internal-format
 msgid "%s %qT requires the V ISA extension"
 msgstr "%s %qT kräver ISA-utökningen V"
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, gcc-internal-format
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr "%s %qT kräver ISA-utökningen zve64x, zve64f, zve64d eller v"
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, gcc-internal-format
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr "%s %qT kräver ISA-utökningen zvfhmin eller zvfh"
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, gcc-internal-format
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr "%s %qT kräver ISA-utökningen zve32f, zve64f, zve64d eller v"
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, gcc-internal-format
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr "%s %qT kräver ISA-utökningen zve64d eller v"
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr "%s %qT kräver den minimala vektorlängden %qd men %qd ges"
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, gcc-internal-format
 msgid "function attribute %qs requires the V ISA extension"
 msgstr "funktionsattributet %qs kräver ISA-utökningen V"
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "argumentet till attributet %qE är inte %<\"user\"%>, %<\"supervisor\"%> eller %<\"machine\"%>"
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr "%qs stödjs endast när %<-mrvv-vector-bits=zvl%> anges"
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, gcc-internal-format
 msgid "%qs applied to non-RVV type %qT"
 msgstr "%qs använt på %qT som inte är en RVV-typ"
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, gcc-internal-format
 msgid "%qs requires an integer constant"
 msgstr "%qs kräver en heltalskonstant"
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr "felaktig RVV-vektorstorlek %qd, förväntad storlek är %qd baserat på LMUL av typen och %qs"
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "%<-mdiv%> kräver %<-march%> för att innefatta utökningen %<M%>"
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr "Aktuell RISC-V GCC stödjer inte VLEN större än 4096 bitar till utökningen ”V”"
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr "Nuvarande RISC-V GCC stödjer inte RVV i läget rak byteordning"
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, gcc-internal-format
 msgid "code model %qs with %qs"
 msgstr "kodmodell %qs med %qs"
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "begärt ABI kräver %<-march%> för att innefatta utökningen %qc"
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr "rv32e kräver ABI:et ilp32e"
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, gcc-internal-format
 msgid "rv64e requires lp64e ABI"
 msgstr "rv64e kräver ABI:et lp64e"
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr "z*inx kräver ABI:et ilp32, ilp32e, lp64 eller lp64"
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "ABI:et kräver %<-march=rv%d%>"
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> måste vara mellan %d och %d"
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr "%<-mriscv-attribute%> RISC-V ELF-attribut behöver GNU as 2.32 [%<-mriscv-attribute%>]"
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs är inte ett giltigt basregister i %qs"
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs är inte ett giltigt tal i %qs"
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "funktionen %qs kan inte ha olika avbrottstyp"
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr "kan inte allokera vl-register för %qs på detta mål"
@@ -43673,32 +43693,32 @@ msgstr "den inbyggda %qs tar endast 2 argument"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "den inbyggda %qs tar endast 3 argument"
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "%<vec_lvsl%> bör undvikas för omvänd byteordning; använd tilldelning för ojusterade laddningar och lagringar"
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "%<vec_lvsr%> bör undvikas för omvänd byteordning; använd tilldelning för ojusterade laddningar och lagringar"
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, gcc-internal-format
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr "att skicka argument %d till %qE kastar %qs-kvalificerare från pekarmåltyp"
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "ogiltig parameterkombination för inbyggd %qs i AltiVec"
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, gcc-internal-format
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr "den överlagrade inbyggda %qs implementeras av den inbyggda %qs"
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%qs stödjs inte i denna kompilatorkonfiguration"
@@ -43738,29 +43758,22 @@ msgstr "felaktig användning av MMA-operand av typ %qs som en funktionsparameter
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-vektor skickad som referens: icke-standard ABI-utökning utan kompatibilitetsgaranti"
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, gcc-internal-format
-msgid "%qs requires the ELFv2 ABI"
-msgstr "%qs kräver ELFv2 ABI"
-
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "för stor stackram"
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported number of nops before function entry (%u)"
 msgstr "ej stött antal nop:ar före funktionsposten (%u)"
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%qs använder register r29"
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "Stackramar större än 2 G stödjs inte med %<-fsplit-stack%>"
@@ -43885,107 +43898,117 @@ msgstr "%qs behöver ett giltigt basregister"
 msgid "unknown option for %<%s=%s%>"
 msgstr "okänt alternativ till %<%s=%s%>"
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr "%<-mrop-protect%> behöver %<-mcpu=power8%> eller senare"
+
+#: config/rs6000/rs6000.cc:4837
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr "%<-mprop-protect%> behöver ELFv2 ABI:et"
+
+#: config/rs6000/rs6000.cc:4855
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs bör undvikas och rekommenderas inte under några omständigheter"
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr "%qs är en ogenomskinlig typ, och det går inte att sätta den till andra värden"
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "ingen profilering av 64-bitskod för detta ABI"
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "du kan inte ta adressen till en nästad funktion om du använder flaggan %qs"
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "användning av %<long double%> i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "användning av booleaner i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "användning av %<complex%> i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "användning av decimala flyttalstyper i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "användning av %<long%> i AltiVec-typer är ogiltigt för 64-bitskod utan %qs"
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "användning av %<long%> i AltiVec-typer bör undvikas, använd %<int%>"
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "användning av %<long long%> i AltiVec-typer är ogiltigt utan %qs"
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "användning av %<double%> i AltiVec-typer är ogiltigt utan %qs"
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "felaktig cpu %qs för %s%qs%s"
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s är inte tillåtet"
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s är ogiltigt"
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> slår av %<-m%s%>"
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "attributet %<target_clones%> behöver GLIBC (2.23 och nyare) som exporterar bitar om hårdvaruegenskaper"
 
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Multiversionering av virtuell funktion stödjs inte"
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr "resultatet av instruktionen xxspltidp är odefinierat för undernormala indatavärden"
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "typen %<__vector_quad%> behöver flaggan %qs"
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr "typen %<__vector_pair%> behöver flaggan %qs"
@@ -44030,7 +44053,7 @@ msgstr "RX FPU-instruktioner stödjer inte NaN:er och oändligheter"
 msgid "builtin %qs can only be used on vector types"
 msgstr "inbyggd %qs kan endast användas på vektortyper"
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "konstant värde behövs till den inbyggda %qF argument %d"
@@ -44100,225 +44123,225 @@ msgstr "%qs-matchningsvariant bör undvikas"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "det konstanta argumentet %d till den inbyggda %qF är utanför intervallet för måltypen"
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr "det konstanta argumentet %d till den inbyggda %qF är ogiltigt (%s)"
 
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr "det konstanta argumentet %d till den inbyggda %qF ligger utanför intervallet (0-%wu)"
 
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr "det konstanta argumentet %d till den inbyggda %qF ligger utanför intervallet (%wd-%wd)"
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr "inbyggd %qF stödjs inte utan %<-mhtm%> (standard med %<-march=zEC12%> och högre)"
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr "inbyggd %qF behöver %<-mvx%> (standard med %<-march=z13%> och högre)"
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher"
 msgstr "Inbyggd %qF kräver z14 eller högre"
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher"
 msgstr "Inbyggd %qF kräver z15 eller högre"
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "ej upplöst överlagrad inbyggd"
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "felaktig inbyggd icode"
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "ogiltigt argument %d till den inbyggda %qF"
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "begärt attribut %qE är inte ett kommaseparerat par av ickenegativa heltalskonstanter eller för stort (max. %d)"
 
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "argumentet till attributet %qE är inte (keep|thunk|thunk-extern)"
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "totala storleken på lokala variabler överskrider arkitekturens gräns"
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr "ramstorleken för funktionen %qs är %wd byte vilket överskrider användarens valda stackgräns på %d byte; en ovillkorlig fälla läggs till"
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr "ramstorleken för funktionen %qs är %wd byte vilket är mer än hälften av stackstorleken; den dynamiska kontrollen skulle inte vara pålitlig.  Ingen kontroll läggs ut för denna funktion"
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "ramstorlek på %qs är %wd byte"
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs använder dynamisk stackallokering"
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr "parameterskickandet för argument av typen %qT med noll breda bitfältsmedlemmar ändrades i GCC 12"
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "nästade funktioner kan inte profileras med %<-mfentry%> på s390"
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bits ABI stödjs inte i ESA/390-läge"
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr "thunk-inline stödjs endast med %<-mindirect-branch-jump%>"
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "vektorstöd i hårdvara är inte tillgängliga på %s"
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "stöd för hårdvaruvektorer är inte tillgängligt med %<-msoft-float%>"
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr "hårdvaruinstruktioner för decimala flyttal är inte tillgängliga på %s"
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, gcc-internal-format
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr "hårdvaruinstruktioner för decimalflyttal är inte tillgängliga i läget ESA/390"
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr "%<-mhard-dfp%> kan inte användas tillsammans med %<-msoft-float%>"
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> stödjs inte i kombination"
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "stackstorlek måste vara större än stackvaktsvärdet"
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "stackstorlek får inte vara större än 64 k"
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "%<-mstack-guard%> implicerar användning av %<-mstack-size%>"
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr "%<-mtpf-trace-hook-prologue-check%> behöver ett heltal i intervallet 0-4095"
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr "%<-mtpf-trace-hook-prologue-target%> behöver ett heltal i intervallet 0-4095"
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr "%<-mtpf-trace-hook-epilogue-check%> behöver ett heltal i intervallet 0-4095"
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr "%<-mtpf-trace-hook-epilogue-target%> behöver ett heltal i intervallet 0-4095"
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%<-mfentry%> stödjs endast för 64-bitars CPU:er"
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "argumenten till %qs skall vara ickenegativa heltal"
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "argumentet till %qs är för stort (max. %d)"
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr "%<-mno-pic-data-is-text-relative%> kan inte användas utan %<-fpic%>/%<-fPIC%>"
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, gcc-internal-format
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr "argument %qs till attribut %<target%> är okänt"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "värdet %qs stödjs inte av attributet %<target%>"
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, gcc-internal-format
 msgid "invalid cc output constraint: %qs"
 msgstr "ogiltig cc-utmatningsbegränsning: %qs"
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, gcc-internal-format
 msgid "multiple cc output constraints not supported"
 msgstr "flera cc-utmatningsbegränsningar stödjs inte"
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, gcc-internal-format
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr "%<asm%>-specificerare för cc-utmatning står i konflikt med %<asm%>-överskrivningslista"
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, gcc-internal-format
 msgid "invalid type for cc output constraint"
 msgstr "ogiltig typ för cc-utmatningsbegränsning"
@@ -44744,8 +44767,8 @@ msgstr "attributet %qE har ingen effekt"
 msgid "attribute %qs applies to array types only"
 msgstr "attributet %qs är bara tillämpbart på vektortyper"
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "värdet av typen void ignoreras inte vilket bör göras"
@@ -44820,7 +44843,7 @@ msgstr "den kompletterade typen på vektor %q+D är inkompatibel med implicit in
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr "underspecificerad deklaration av %qE, som redan är deklarerad i denna räckvidd"
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "ursprungligen definierad här"
@@ -45052,7 +45075,7 @@ msgstr "deklaration av %q+D skuggar tidigare icke-variabel"
 msgid "declaration of %qD shadows a parameter"
 msgstr "deklaration av %qD skuggar en parameter"
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "deklaration av %qD skuggar en global deklaration"
@@ -45063,7 +45086,7 @@ msgstr "deklaration av %qD skuggar en global deklaration"
 msgid "declaration of %qD shadows a previous local"
 msgstr "deklaration av %qD skuggar en tidigare lokal deklaration"
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "skuggad deklaration är här"
@@ -45128,7 +45151,7 @@ msgstr "%qE är odeklarerad (första förekomsten i denna funktion)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "varje odeklarerad identifierare rapporteras bara en gång för varje funktion den förekommer i"
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "etikett %qE är refererad till utanför någon funktion"
@@ -45163,7 +45186,7 @@ msgstr "hopp in i satsuttryck"
 msgid "duplicate label declaration %qE"
 msgstr "dubbel deklaration av etikett %qE"
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "dubblerad etikett %qD"
@@ -45198,7 +45221,7 @@ msgstr "switch hoppar in i satsuttryck"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE definierad som fel sorts tagg"
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "attributet %qE tillämpat på %qD med returtypen void"
@@ -45340,12 +45363,12 @@ msgstr "ISO C90 stödjer inte %<[*]%>-vektordeklarerare"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> är inte tillåtet annat än inom en funktionsprototyp"
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, gcc-internal-format
 msgid "%<omp::%s%> not allowed to be specified in this context"
 msgstr "%<omp::%s%> är inte tillåtet att anges i detta sammanhang"
@@ -45355,7 +45378,7 @@ msgstr "%<omp::%s%> är inte tillåtet att anges i detta sammanhang"
 msgid "%q+D is usually a function"
 msgstr "%q+D är vanligtvis en funktion"
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "ingen tidigare deklaration av %qD"
@@ -45431,7 +45454,7 @@ msgstr "kan inte lägga objekt med volatile-fält i register"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "oinitierad %<const %D%> är ogiltig i C++"
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D i deklarationsmålsdirektiv har inte en avbildbar typ"
@@ -45616,7 +45639,7 @@ msgstr "lagringsklass angiven för parameter %qE"
 msgid "storage class specified for unnamed parameter"
 msgstr "lagringsklass angiven för namnlös parameter"
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "lagringsklass angiven för typnamn"
@@ -45679,7 +45702,7 @@ msgstr "deklaration av %qE som en vektor av funktioner"
 msgid "declaration of type name as array of functions"
 msgstr "deklaration av typnamn som en vektor av funktioner"
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "ogiltig användning av post med flexibel vektormedlem"
@@ -45785,7 +45808,7 @@ msgstr "typnamn är deklarerat som en funktion som returnerar en vektor"
 msgid "function definition has qualified void return type"
 msgstr "funktionsdefinition som har kvalificerad void-returtyp"
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typkvalificerare ignoreras för funktions returtyp"
@@ -45912,7 +45935,7 @@ msgstr "ISO C förbjuder const- eller volatile-funktionstyper"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "en medlem av an post eller union får inte ha variabel typ"
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variabel eller fält %qE deklarerad void"
@@ -46017,7 +46040,7 @@ msgstr "onästad funktion med variabelt modifierad typ"
 msgid "object with variably modified type must have no linkage"
 msgstr "objekt med variabel typ får inte ha länkklass"
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "funktionsdeklarationen är inte en prototyp"
@@ -46107,17 +46130,17 @@ msgstr "nästad omdefinition av %<union %E%>"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "nästad omdefinition av %<struct %E%>"
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "att definiera en typ i %qs-uttryck är ogiltigt i C++"
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, gcc-internal-format
 msgid "%qT defined in underspecified object initializer"
 msgstr "%qT är definierat i underspecificerad objektinitierare"
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "deklaration som inte deklarerar något"
@@ -46147,596 +46170,596 @@ msgstr "tom post har storlek 0 i C, storlek 1 i C++"
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr "tom union har storlek 0 i C, storlek 1 i C++"
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "unionen har inga namngivna medlemmar"
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "unionen har inga medlemmar"
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "posten har inga namngivna medlemmar"
 
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "posten har inga medlemmar"
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexibel vektormedlem i union"
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "flexibel vektormedlem inte vid slutet av post"
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "flexibel vektormedlem i struct utan namngivna medlemmar"
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, gcc-internal-format
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr "posten som innehåller en flexibel vektormedlem inte vid slutet av annan post"
 
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "typen %qT är för stor"
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, gcc-internal-format
 msgid "type punning toggles scalar storage order"
 msgstr "typstampning byter lagringsordning för skalärer"
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "unionen kan inte göras transparent"
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, gcc-internal-format
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr "omdefinition av posten eller unionen %qT med variabelt modifierad typ"
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, gcc-internal-format
 msgid "redefinition of struct or union %qT"
 msgstr "omdefinition av posten eller unionen %qT"
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "nästad omdefinition av %<enum %E%>"
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "omdeklaration av %<enum %E%>"
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr "%<enum%> deklarerad med men definierad utan en fast underliggande typ"
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "angiven sort för liten för uppräkningsvärden"
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "uppräkningsvärden överskrider gränsen för största heltal"
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, gcc-internal-format
 msgid "enumeration values exceed range of %qs"
 msgstr "uppräkningsvärden överskrider gränsen på %qs"
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, gcc-internal-format
 msgid "conflicting redefinition of enum %qT"
 msgstr "omdefinition av enum %qT som står i konflikt"
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "uppräkningsvärde för %qE är inte en heltalskonstant"
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "uppräkningsvärde för %qE är inte ett konstant heltalsuttryck"
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "överspill i uppräkningsvärden"
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, gcc-internal-format
 msgid "enumerator value outside the range of underlying type"
 msgstr "uppräkningsvärdet är utanför intervallet för den underliggande typen"
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, gcc-internal-format
 msgid "enumerator value outside the range of %qs"
 msgstr "uppräkningsvärdet är utanför intervallet för %qs"
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr "ISO C begränsar uppräkningsvärden till intervallet hos %<int%> före C23"
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "inline-funktionen %qD har fått attributet %qs"
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "returtypen är en ofullständig typ"
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "returtyp sätts skönsmässigt till %<int%>"
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "%q+D deklarerat som en variadisk funktion utan prototyp"
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "ingen tidigare prototyp för %qD"
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD användes utan någon prototyp före sin definition"
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD användes utan någon deklaration före sin definition"
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "returtypen för %qD är inte %<int%>"
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "%<_Atomic%>-kvalificerad returtyp till för %qD"
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD är normalt en icke-statisk funktion"
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "gammaldags parameterdeklarationer i funktionsdefinition med prototyp"
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "traditionell C tillåter inte ISO C:s stil av funktionsdefinitioner"
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr "ISO C stödjer inte att utelämna parameternamn i funktionsdefinitioner före C23"
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "gammaldags funktionsdefinition"
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "parameternamn saknas i parameterlista"
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD deklarerad som en icke-parameter"
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "flera parametrar med namnet %qD"
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "parameter %qD deklarerad med typen void"
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "typen på %qD sätts skönsmässigt till %<int%>"
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "parametern %qD har ofullständig typ"
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "deklaration av parameter %qD med det finns ingen sådan parameter"
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "antalet argument stämmer inte med inbyggd prototyp"
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "antalet argument stämmer inte med prototypen"
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "prototypdeklaration"
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "befordrat argument %qD stämmer inte med inbyggd prototyp"
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "befordrat argument %qD stämmer inte med prototypen"
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "argument %qD stämmer inte med inbyggd prototyp"
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argument %qD stämmer inte med prototypen"
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ingen retursats i funktion som returnerar icke-void"
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parametern %qD sätts men används inte"
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%>-slinga med startdeklaration är endast tillåtet i C99- och C11-läge"
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "använd flaggan %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> eller %<-std=gnu11%> för att kompilera din kod"
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 stödjer inte %<for%>-slingor med initiala deklarationer"
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "deklaration av statisk variabel %qD i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "deklaration av %<extern%>-variabel %qD i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> är deklarerad i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> är deklarerad i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> är deklarerad i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "deklaration av icke-variabel %qD i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "inkompatibla adressrymdskvalificerare %qs och %qs"
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "dubblerade %qE-deklarationsspecificerare"
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "flera lagringsklasser i deklarationsspecificerare"
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, gcc-internal-format
 msgid "%qs used with %<auto%>"
 msgstr "%qs använt med %<auto%>"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, gcc-internal-format
 msgid "%<auto%> used with %<constexpr%>"
 msgstr "%<auto%> använt med %<constexpr%>"
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "två eller fler datatyper i deklaration av specificerare"
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> är för långt för GCC"
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 stödjer inte %<long long%>"
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 stödjer inte komplexa typer"
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C stödjer inte mättning av typer"
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "dubblerad %qE"
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C stödjer inte typen %<__int%d%>"
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> stödjs inte för denna målarkitektur"
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 stödjer inte booleska typer"
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr "ISO C stödjer inte typen %<_Float%d%s%> före C23"
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<_Float%d%s%> stödjs inte för denna målarkitektur"
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr "ISO C stödjer inte decimala flyttal före C23"
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "fixdecimaltyper stödjs inte för denna målarkitektur"
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C stödjer inte fixdecimaltyper"
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, gcc-internal-format
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr "argumentet till %<_BitInt%> är inte ett konstant heltalsuttryck"
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr "argumentet %qE till %<_BitInt%> är inte ett konstant positivt heltalsuttryck"
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr "argumentet %qE till %<_BitInt%> är större än %<BITINT_MAXWIDTH%> %qd"
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "C++-uppslagning av %qD skulle returnera ett fält, inte en typ"
 
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE är varken en typedef eller en inbyggd typ"
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE är inte i början av deklarationen"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE använt med %<auto%>"
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE använt med %<register%>"
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE använt med %<typedef%>"
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, gcc-internal-format
 msgid "%qE used with %<constexpr%>"
 msgstr "%qE använt med %<constexpr%>"
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 stödjer inte %qE"
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 stödjer inte %qE"
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> före %<extern%>"
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> före %<static%>"
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, gcc-internal-format
 msgid "%<typedef%> used with %<auto%>"
 msgstr "%<typedef%> använt med %<auto%>"
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, gcc-internal-format
 msgid "%qE used with %<extern%>"
 msgstr "%qE använt med %<extern%>"
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, gcc-internal-format
 msgid "%qE used with %qs"
 msgstr "%qE använt med %qs"
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "dubblerat %<_Thread_local%> eller %<__thread%>"
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs använt med %qE"
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, gcc-internal-format
 msgid "%<constexpr%> used with %qE"
 msgstr "%<constexpr%> använt med %qE"
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> används utan %<_Fract%> eller %<_Accum%>"
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C stödjer inte bara %<complex%> i meningen %<double complex%>"
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, gcc-internal-format
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr "ISO C stödjer inte %<auto%>-attribut före C23"
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr "%<__auto_type%> följt av %<[[]]%>-attribut"
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C stödjer inte komplexa heltalstyper"
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, gcc-internal-format
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr "argumentet till %<signed _BitInt%> måste vara åtminstone 2"
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, gcc-internal-format
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr "ISO C stödjer inte %<%s_BitInt(%d)%> före C23"
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "%<#pragma omp declare reduction%>-kombinerare refererar variabeln %qD som inte är varken %<omp_out%> eller %<omp_in%>"
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "%<#pragma omp declare reduction%>-initierare refererar till variabeln %qD som inte är varken %<omp_priv%> eller %<omp_orig%>"
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "vänsterskift med negativt värde"
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "vänstershiftoperanden är negativ"
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "högershiftoperanden är negativ"
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "vänstershiftoperanden ≥ storleken på typen"
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "högershiftoperanden ≥ storleken på typen"
@@ -46766,7 +46789,7 @@ msgstr "markör för versionshanteringskonflikt i filen"
 msgid "to match this %qs"
 msgstr "för att matcha denna %qs"
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "oväntat radslut"
@@ -46776,8 +46799,8 @@ msgstr "oväntat radslut"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C förbjuder tomma översättningsenheter"
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr "%qs utan motsvarande %qs"
@@ -46817,9 +46840,9 @@ msgstr "okänt typnamn %qE; menade du %qs?"
 msgid "unknown type name %qE"
 msgstr "okänt typnamn %qE"
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "deklarationsspecificerare förväntades"
@@ -46849,7 +46872,7 @@ msgstr "attributet %<fallthrough%> på toppnivå"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, identifierare eller %<(%> förväntades"
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "prefixattribut ignoreras för metoder"
@@ -46869,7 +46892,7 @@ msgstr "oväntat attribut"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "attributet %<fallthrough%> följs inte av %<;%>"
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, gcc-internal-format
 msgid "%<assume%> attribute not followed by %<;%>"
 msgstr "attributet %<assume%> följs inte av %<;%>"
@@ -46960,7 +46983,7 @@ msgstr "uttryck i statisk försäkran är inte konstant"
 msgid "static assertion failed: %E"
 msgstr "statisk försäkran misslyckades: %E"
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "statisk försäkran misslyckades"
@@ -47031,10 +47054,10 @@ msgstr "tom enum är ogiltig"
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "identifierare förväntades"
@@ -47185,7 +47208,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr "inre slingor måste vara perfekt nästade med en %<reduction%> %<inscan%>-klausul"
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr "OpenMP-direktiv blandas med attribut- och pragma-syntax på samma sats"
@@ -47195,8 +47218,8 @@ msgstr "OpenMP-direktiv blandas med attribut- och pragma-syntax på samma sats"
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr "OpenMP %<omp::decl%>-attribut på en sats"
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs attribute argument"
 msgstr "okänt OpenMP-direktivnamn i klausulargumentet %qs"
@@ -47370,12 +47393,12 @@ msgstr "ISO C förbjuder utelämnande av den mittersta termen i ett %<?:%>-uttry
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr "divisionen %<sizeof (%T) / sizeof (%T)%> beräknar inte antalet vektorelement"
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "första %<sizeof%>-operanden deklarerades här"
@@ -47522,7 +47545,7 @@ msgstr "ISO C90 stödjer inte den fördefinierade identifieraren %<__func__%>"
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, gcc-internal-format
 msgid "expected expression"
 msgstr "uttryck förväntades"
@@ -47842,12 +47865,12 @@ msgstr "objective-c-metoddeklaration förväntas"
 msgid "no type or storage class may be specified here,"
 msgstr "ingen typ eller lagringsklass kan anges här,"
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr "tom egenskapsattributslista"
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, gcc-internal-format
 msgid "missing property attribute"
 msgstr "saknat egenskapsattribut"
@@ -47857,57 +47880,57 @@ msgstr "saknat egenskapsattribut"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "okänt egenskapsattribut %<%s%s%>"
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "okänt egenskapsattribut"
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "%<=%> förväntades efter Objective-C %qE"
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr "%qE-väljarnamn förväntades"
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr "setter-metodnamn måste avslutas med %<:%>"
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> kräver ett tilldelningsuttryck som beräknas till en icke-negativ heltalskonstant mindre än %u"
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr "mellanliggande kod får inte innehålla OpemMP-direktiv"
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> får bara användas i sammansatta satser"
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> måste ha filräckvidd"
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp scan%> får bara användas i en slingkonstruktion med %<inscan%> %<reduction%>-klausul"
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> får bara användas i %<#pragma omp sections%>-konstruktion"
@@ -47917,25 +47940,25 @@ msgstr "%<#pragma omp section%> får bara användas i %<#pragma omp sections%>-k
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr "%<#pragma %s%> får bara användas med filräckvidd"
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for-, while- eller do-sats förväntades"
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> måste komma först"
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "för många %qs-klausuler"
@@ -47950,63 +47973,63 @@ msgstr "uttrycket måste vara ett heltal"
 msgid "expected %<)%> or %<,%>"
 msgstr "%<)%> eller %<,%> förväntades"
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD är inte en variabel"
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD är inte en pekarvariabel"
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "collapse-argument behöver ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> eller %<present%> förväntades"
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, gcc-internal-format
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr "%<none%>, %<shared%>, %<private%> eller %<firstprivate%> förväntades"
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, gcc-internal-format
 msgid "expected constant logical expression"
 msgstr "ett konstant logiskt uttryck förväntades"
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<data%>, %<update%>, %<enter%> eller %<exit%> förväntades"
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<data%> förväntades"
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "för många %<if%>-klausuler med %qs-modifierare"
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "för många %<if%>-klausuler"
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "för många %<if%>-klausuler utan modifierare"
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "om någon %<if%>-klausul har en modifierare måste alla %<if%>-klausuler använda modifierare"
@@ -48029,22 +48052,22 @@ msgstr "%<num_threads%>-värdet måste vara positivt"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_tasks%>-värdet måste vara positivt"
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<grainsize%>-värdet måste vara positivt"
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<priority%>-värdet måste vara positivt"
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "konstant heltalsuttryck med giltigt sync-hint-värde förväntades"
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "%<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> eller %<default%> förväntades"
@@ -48054,94 +48077,94 @@ msgstr "%<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> elle
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr "%<scalar%>, %<aggregate%>, %<pointer%> eller %<all%> förväntades"
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "för många %<defaultmap%>-klausuler med %qs-modifierare"
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "för många %<defaultmap%>-klausuler med ospecificerad kategori"
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "%qs-uttrycket måste vara ett heltal"
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%qs-värdet måste vara positivt"
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "för många %<static%>-argument"
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "oväntat argument"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "argumentet till %<tile%> behöver en positiv heltalskonstant"
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, gcc-internal-format
 msgid "too many %<self%> clauses"
 msgstr "för många %<self%>-klausuler"
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, gcc-internal-format
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr "%<reproducible%> eller %<unconstrained%> förväntades"
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "%<concurrent%> förväntades"
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "%<teams%>, %<parallel%> eller %<thread%> förväntades"
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "ordered-argument behöver ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> eller identifierare förväntades"
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "både %<monotonic%>- och %<nonmonotonic%>-modifierare angivna"
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "%<runtime%>-schemaläggning tar ingen %<chunk_size%>-parameter"
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "%<auto%>-schemaläggning tar ingen %<chunk_size%>-parameter"
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "värdet på styckesstorleken måste vara positivt"
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ogiltig schedule-sort"
@@ -48151,22 +48174,22 @@ msgstr "ogiltig schedule-sort"
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_teams%>-värdet måste vara positivt"
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr "%<num_teams%> undre gräns %qE är större än den övre gränsen %qE"
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<thread_limit%>-värdet måste vara positivt"
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%<aligned%>-klausulens justeringsuttryck måste vara ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, gcc-internal-format
 msgid "expected %<allocator%> or %<align%>"
 msgstr "%<allocator%> eller %<align%> förväntades"
@@ -48176,22 +48199,22 @@ msgstr "%<allocator%> eller %<align%> förväntades"
 msgid "duplicate %qs modifier"
 msgstr "dubblerad %qs-modifierare"
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr "%<allocate%>-klausulens allokeraruttryck har typen %qT istället för %<omp_allocator_handle_t%>"
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, gcc-internal-format
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr "argumentet till modifieraren %<align%> av klausulen %<allocate%> måste vara ett positivt konstant heltalsuttryck som är en exponent av två"
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, gcc-internal-format
 msgid "multiple linear modifiers"
 msgstr "upprepade linear-modifierare"
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, gcc-internal-format
 msgid "multiple %<step%> modifiers"
 msgstr "upprepade %<step%>-modifierare"
@@ -48211,62 +48234,62 @@ msgstr "%<safelen%>-klausulens uttryck måste vara ett positivt konstant heltals
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%<simdlen%>-klausulens uttryck måste vara ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "modifieraren %<iterator%> är inkompatibel med %qs"
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ogiltig depend-sort"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, gcc-internal-format
 msgid "invalid doacross kind"
 msgstr "felaktig doacross-sort"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, gcc-internal-format
 msgid "too many %<always%> modifiers"
 msgstr "för många %<always%>-modifierare"
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, gcc-internal-format
 msgid "too many %<close%> modifiers"
 msgstr "för många %<close%>-modifierare"
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, gcc-internal-format
 msgid "too many %<present%> modifiers"
 msgstr "för många %<present%>-modifierare"
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr "en klausul %<map%> med en annan avbildningstypsmodifierare än %<always%>, %<close%> eller %<present%>"
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "ogiltig map-sort"
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr "%<ancestor%>-enhetsmodifierare som inte föregås av ett %<requires%>-direktiv med en klausul %<reverse_offload%>"
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, gcc-internal-format
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr "%<ancestor%> eller %<device_num%> förväntades"
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, gcc-internal-format
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr "%<device%>-klausulens uttryck måste beräknas till %<1%>"
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ogiltig dist_schedule-sort"
@@ -48281,88 +48304,88 @@ msgstr "ogiltig proc_bind-sort"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<host%>, %<nohost%> eller %<any%> förväntades"
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr "%<detach%>-klausulens händelsehandtag har typen %qT istället för %<omp_event_handle_t%>"
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, gcc-internal-format
 msgid "expected an OpenACC clause"
 msgstr "en OpenACC-klausul förväntades"
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs är inte giltigt för %qs"
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr "klausuler i %<simd%>-egenskap skall separeras av %<,%>"
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs måste vara den första klausulen i %qs"
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, gcc-internal-format
 msgid "expected an OpenMP clause"
 msgstr "en OpenMP-klausul förväntades"
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "inga giltiga klausuler angivna i %<#pragma acc declare%>"
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "vektorsektionen i %<#pragma acc declare%>"
 
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD måste vara en global variabel i %<#pragma acc declare link%>"
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "ogiltig OpenACC-klausul vid filräckvidd"
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "ogiltig användning av %<extern%>-variabel %qD i %<#pragma acc declare%>"
 
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "ogiltig användning av %<global%>-variabeln %qD i %<#pragma acc declare%>"
 
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "%qD måste vara en variabel deklarerad i samma räckvidd som %<#pragma acc declare%>"
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "variabeln %qD använd mer än en gång med %<#pragma acc declare%>"
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<data%> förväntades efter %<#pragma acc %s%>"
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> har ingen dataflyttningsklausul"
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr "konstruktionen %<host_data%> kräver en klausul %<use_device%>"
@@ -48377,7 +48400,7 @@ msgstr "%qE har inte deklarerats"
 msgid "expected function name"
 msgstr "ett funktionsnamn förväntades"
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD refererar inte till en funktion"
@@ -48387,22 +48410,22 @@ msgstr "%qD refererar inte till en funktion"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> följs inte omedelbart av en funktionsdeklaration eller -definition"
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> följs inte omedelbart av en ensam funktionsdeklaration eller -definition"
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> måste vara tillämpad före användning"
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> måste vara tillämpad före definitionen"
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> måste innehålla åtminstone en %<device%>- eller %<host%>- eller %<self%>-klausul"
@@ -48427,7 +48450,7 @@ msgstr "variabeln %qD använd i klausulen %<allocator%> får inte ändras mellan
 msgid "modified here"
 msgstr "modifierad här"
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, gcc-internal-format
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
 msgstr "klausulargumentet %<align%> måste vara ett positivt konstant heltalsuttryck som är en exponent av två"
@@ -48467,110 +48490,110 @@ msgstr "%<allocate%>-klausulen kräver en fördefinierad allokerare eftersom %qD
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr "%<#pragma omp allocate%> för statiska variabler som %qD stödjs inte ännu"
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "%<read%>-, %<write%>-, %<update%>- eller %<capture%>-klausul förväntades"
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr "%<seq_cst%>, %<acquire%> eller %<relaxed%> förväntades"
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "%<read%>-, %<write%>-, %<update%>-, %<capture%>-, %<compare%>-, %<weak%>-, %<fail%>-, %<seq_cst%>-, %<acq_rel%>-, %<release%>-, %<relaxed%>- eller %<hint%>-klausul förväntades"
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "för många atomära klausuler"
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "för många minnesordningsklausuler"
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, gcc-internal-format
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr "en %qs-klausul är inkompatibel med en %<read%>- eller %<write%>-klausul"
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, gcc-internal-format
 msgid "%qs clause requires %qs clause"
 msgstr "en %qs-klausul behöver en %qs-klausul"
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr "%<#pragma omp atomic write%> är inkompatibelt med en %<acquire%>-klausul implicit tillhandahållen av ett %<requires%>-direktiv"
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr "%<#pragma omp atomic read%> är inkompatibelt med en %<release%>-klausul implicit tillhandahållen av ett %<requires%>-direktiv"
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr "%<#pragma omp atomic read%> är inkompatibelt med en %<release%>-klausul"
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr "%<#pragma omp atomic write%> är inkompatibelt en %<acquire%>-klausul"
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, gcc-internal-format
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr "en %<==%>-jämförelse förväntades i ett %<if%>-villkor"
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, gcc-internal-format
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr "jämförelse med %<==%>, %<<%> eller %<>%> förväntades i %<if%>-villkor"
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr "ogiltig form på %<#pragma omp atomic compare%>"
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, gcc-internal-format
 msgid "unexpected %<else%>"
 msgstr "oväntat %<else%>"
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, gcc-internal-format
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr "ogiltig form på %<pragma omp atomic compare%>"
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ogiltig form på %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ogiltig operator för %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr "%<weak%>-klausul kräver atomär likhetsjämförelse"
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> använder två olika uttryck till minne"
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "uttrycket %<depobj%> är inte ett l-värde-uttryck"
@@ -48580,27 +48603,27 @@ msgstr "uttrycket %<depobj%> är inte ett l-värde-uttryck"
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr "uttrycket %<destroy%> är inte ett l-värde-uttryck"
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr "uttrycket %qE till %<destroy%> skall vara detsamma som argumentet %qE till %<depobj%>"
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr "%<in%>, %<out%>, %<inout%>, %<mutexinoutset%> eller %<inoutset%> förväntades"
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "%<depend%>-, %<destroy%>- eller %<update%>-klausul förväntades"
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "%<seq_cst%>, %<acq_rel%>, %<release%> eller %<acquire%> förväntades"
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr "%<flush%>-lista specificerat tillsammans med minnesordningsklausul"
@@ -48610,163 +48633,163 @@ msgstr "%<flush%>-lista specificerat tillsammans med minnesordningsklausul"
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> eller filslut förväntades"
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr "%<[[omp::directive(%s)]]%> måste vara det enda angivna attributet på en sats"
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr "%<#pragma omp scan%> med noll föregående körbara satser"
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "en %<inclusive%>- eller %<exclusive%>-klausul förväntades"
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<#pragma omp scan%> förväntades"
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr "%<#pragma omp scan%> med noll flöljande körbara satser"
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "iterationsdeklaration eller initiering förväntades"
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, gcc-internal-format
 msgid "not enough nested loops"
 msgstr "inte tillräckligt med nästade slingor"
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "%<ordered%>-klausulparameter är mindre än %<collapse%>"
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "for-sats förväntades"
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "iterationsvariabel %qD får inte vara firstprivate"
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> med %qs-klausul får bara användas i sammansatta satser"
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> förväntades efter %qs"
 
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> förväntades"
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> med en annan map-typ än %<to%>, %<from%>, %<tofrom%> eller %<alloc%> på %<map%>-klausul"
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp target data%> måste innehålla åtminstone en %<map%>-, %<use_device_ptr%>- eller %<use_device_addr%>-klausul"
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> måste innehålla åtminstone en %<from%>- eller %<to%>-klausul"
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> med en annan map-typ än %<to%>, %<tofrom%> eller %<alloc%> på %<map%>-klausul"
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> måste innehålla åtminstone en %<map%>-klausul"
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> med en annan map-typ än %<from%>, %<tofrom%>, %<release%> eller %<delete%> på %<map%>-klausul"
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> måste innehålla åtminstone en %<map%>-klausul"
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> med en annan map-typ än %<to%>, %<from%>, %<tofrom%> eller %<alloc%> på %<map%>-klausul"
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp declare %s%> måste följas av funktionsdeklaration eller -definition eller en annan %<#pragma omp declare %s%>"
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> måste följas av en funktionsdeklaration eller -definition"
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "trait-väljarnamn förväntades"
 
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, gcc-internal-format
 msgid "unknown selector %qs for context selector set %qs"
 msgstr "okänd selektor %qs för kontextselektormängden %qs"
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "väljaren %qs tar inte några egenskaper"
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, gcc-internal-format
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr "%<score%> kan inte anges i egenskaper i trait-selector-set %qs"
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, gcc-internal-format
 msgid "%<score%> argument must be constant integer expression"
 msgstr "argumentet till %<score%> måste vara ett konstant heltalsuttryck"
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, gcc-internal-format
 msgid "%<score%> argument must be non-negative"
 msgstr "argumentet till %<score%> måste vara ickenegativt"
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "identifierare eller strängkonstant förväntades"
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "egenskapen måste vara ett konstant heltalsuttryck"
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "egenskaper för %<simd%>-väljare får inte anges i %<metadirective%>"
@@ -48774,290 +48797,290 @@ msgstr "egenskaper för %<simd%>-väljare får inte anges i %<metadirective%>"
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, gcc-internal-format
 msgid "%<requires%> selector is not supported yet"
 msgstr "selektorn %<requires%> stödjs inte ännu"
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, gcc-internal-format
 msgid "expected context selector set name"
 msgstr "namn på kontextväljare förväntades"
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "%<match%> förväntades"
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, gcc-internal-format
 msgid "variant %qD is not a function"
 msgstr "varianten %qD är inte en funktion"
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "varianten %qD och basen %qD har inkompatibla typer"
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr "varianten %qD är en inbyggd"
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare %s%> som inte omedelbart följs av en funktionsdefinition eller -deklaration"
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare %s%> som inte omedelbart följs av en ensam funktionsdeklaration eller -definition"
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr "%qD angivet både i deklarationsmålets %<link%>- och %qs-klausuler"
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr "%qD angivet både i deklarationsmålets %<link%>- och %<to%>- eller %<enter%>-klausuler"
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr "direktiv med endast %<device_type%>- eller %<indirect%>-klausul"
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, gcc-internal-format
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr "klausulen %<device_type%> måste ange ”any” när den används med en %<indirect%>-klausul"
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> förväntades"
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, gcc-internal-format
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr "%<declare target%> eller %<assumes%> förväntades"
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr "%<#pragma omp end declare target%> utan en motsvarande %<#pragma omp declare target%> eller %<#pragma omp begin declare target%>"
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr "%qs i attributsyntax som avslutas med %qs i pragma-syntax"
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, gcc-internal-format
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr "%qs i pragma-syntax som avslutas med %qs i attributsyntax"
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, gcc-internal-format
 msgid "expected %<declare%> or %<assumes%>"
 msgstr "%<declare%> eller %<assumes%> förväntades"
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr "%<#pragma omp declare reduction%> inte med fil- eller blockräckvidd"
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr "fördeklarerad aritmetisk typ i %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr "funktions- eller vektortyp i %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, gcc-internal-format
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr "%<_Atomic%>-kvalificerad typ i %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr "const-, volatile- eller restrict-kvalificerad typ i %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr "omdeklaration av %qs %<#pragma omp declare reduction%> för typen %qT"
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "tidigare %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr "%<omp_priv%> eller funktionsnamn förväntades"
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "funktionsnamn %<(%> förväntades"
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "en av initierarens anropsargument skall vara %<&omp_priv%>"
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%<simd%>, %<reduction%>, %<target%> eller %<variant%> förväntades"
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, gcc-internal-format
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr "%<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> eller %<seq_cst%> förväntades"
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr "en klausul %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> eller %<atomic_default_mem_order%> förväntades"
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr "klausulen %qs använd lexikalt efter första målkonstruktionen eller avlastnings-API:et"
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr "mer än en klausul %<atomic_default_mem_order%> i en enskild kompileringsenhet"
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr "klausulen %<atomic_default_mem_order%> använd lexikalt efter första konstruktionen %<atomic%> utan minnesordningsklausul"
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr "%<pragma omp requires%> kräver åtminstone en klausul"
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, gcc-internal-format
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr "nollstor typ %qT i %<reduction%>-klausul"
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, gcc-internal-format
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "typen %qT med variabel storlek i-%<reduction%>-klausul"
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, gcc-internal-format
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr "%<at%>-, %<severity%>- eller %<message%>-klausul förväntades"
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, gcc-internal-format
 msgid "expected %qs or %qs"
 msgstr "%qs eller %qs förväntades"
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, gcc-internal-format
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr "%<#pragma omp error%> med %<at(execution)%>-klausul får bara användas i sammansatta satser"
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr "%<pragma omp error%> påträffat: %s"
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr "%<pragma omp error%> påträffat"
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, gcc-internal-format
 msgid "expected at least one assumption clause"
 msgstr "åtminstone enn assumption-klausul förväntades"
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, gcc-internal-format
 msgid "expected directive name"
 msgstr "ett direktivnamn förväntades"
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr "okänt OpenMP-direktivnamn i attributargumentet %qs"
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr "%<%s%s%s%s%s%>-direktivet nämnt i både %<absent%>- %<contains%>-klausuler"
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr "%<%s%s%s%s%s%>-direktivet nämnt flera gånger i %qs-klausuler"
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, gcc-internal-format
 msgid "unknown assumption clause %qs"
 msgstr "okänd assumption-klausul %qs"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, gcc-internal-format
 msgid "expected assumption clause"
 msgstr "assumption-klausul förväntades"
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE är deklarerad %<threadprivate%> efter första användningen"
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automatisk variabel %qE kan inte vara %<threadprivate%>"
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE har ofullständig typ"
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> utan att stöd för transaktionsminne är aktiverat"
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> inom en %<__transaction_relaxed%>"
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "yttre %<__transaction_cancel%> som inte är inuti en yttre %<__transaction_atomic%>- eller en %<transaction_may_cancel_outer%>-funktion"
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> inte inom %<__transaction_atomic%>"
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, gcc-internal-format
 msgid "no closing brace"
 msgstr "ingen avslutande klammer"
@@ -49198,7 +49221,7 @@ msgstr "derefererar %<void *%>-pekare"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indexerat värde är varken en vektor eller pekare"
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "fältindex är inte ett heltal"
@@ -49228,7 +49251,7 @@ msgstr "underspecificerad %qD refererad i sin initierare"
 msgid "enum constant defined here"
 msgstr "uppräkningskonstant definierad här"
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> på vektorfunktionsparametern %qE kommer returnera storleken på %qT"
@@ -49341,17 +49364,17 @@ msgstr "implicit konvertering från %qT till %qT när argument skickas till en f
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "för få argument till den inbyggda funktionen %qE, %u förväntades"
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "jämförelse med stränglitteral resulterar i odefinierat beteende"
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "jämförelse mellan pekare och teckenkonstanten noll"
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "tänkte du dereferera pekaren?"
@@ -49376,7 +49399,7 @@ msgstr "pekare till funktion använd i subtraktion"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "aritmetik på pekare till ofullständig typ"
 
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "aritmetik på pekare till ett tomt aggregat"
@@ -49669,7 +49692,7 @@ msgstr "typkonvertering från pekare till heltal av annan storlek"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "typkonvertering från funktionsanrop av typ %qT till typ %qT matchar inte"
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "typkonvertering till pekare från heltal med annan storlek"
@@ -49841,7 +49864,7 @@ msgstr "vänsterhandssida av tilldelning kan vara en kandidat för ett formatatt
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "vänsterhandssida av initiering kan vara en kandidat för ett formatattribut"
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "returtypen kan vara en kandidat för ett formatattribut"
@@ -50041,12 +50064,12 @@ msgstr "%<constexpr%>-initierare för en reell typ har komplex typ"
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr "%<constexpr%>-initierare för en binär flyttalstyp har en decimal typ"
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "initiering av medlem som är en flexibel vektor"
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "det går inte att initiera vektorn av %qT från en stränglitteral med typvektor %qT"
@@ -50056,7 +50079,7 @@ msgstr "det går inte att initiera vektorn av %qT från en stränglitteral med t
 msgid "array of inappropriate type initialized from string constant"
 msgstr "vektor av typ som inte passar initierad från strängkonstant"
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ogiltig användning av icke-l-värde-vektor"
@@ -50087,7 +50110,7 @@ msgstr "initierarelement är inte ett konstant uttryck"
 msgid "initializer element is not computable at load time"
 msgstr "initierarelement är inte beräkningsbart vid laddtidpunkt"
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "ogenomskinliga vektortyper kan inte initieras"
@@ -50102,7 +50125,7 @@ msgstr "extra klammergrupp vid slutet av initierare"
 msgid "braces around scalar initializer"
 msgstr "klamrar runt skalär initierare"
 
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "initiering av medlem som är en flexibel vektor i nästat sammanhang"
@@ -50192,7 +50215,7 @@ msgstr "överflödiga element i postinitierare"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "positionsinitiering av fält i %<struct%> deklarerad med attributet %<designated_init%>"
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "icke-statisk initiering av an flexibel vektormedlem"
@@ -50232,7 +50255,7 @@ msgstr "ISO C förbjuder %<goto *expr;%>"
 msgid "computed goto must be pointer type"
 msgstr "beräknat goto måste vara en pekartyp"
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "funktion deklarerad %<noreturn%> har en %<return%>-sats"
@@ -50287,7 +50310,7 @@ msgstr "%<default%>-etikett som inte ligger i en switch-sats"
 msgid "break statement not within loop or switch"
 msgstr "break-sats som inte är i en loop eller switch"
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -50333,27 +50356,27 @@ msgstr "jämförelsen kommer alltid beräknas till %<false%> för att adressen t
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr "jämförelsen kommer alltid beräknas till %<true%> för att adressen till %qE aldrig kommer att vara NULL"
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "jämför vektorer med skilda elementtyper"
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "jämför vektorer med olika antal element"
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "jämförelse mellan typer %qT och %qT"
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "det går inte att hitta en heltalstyp med samma storlek som %qT"
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "att jämföra flyttal med %<==%> eller %<!=%> är osäkert"
@@ -50425,29 +50448,29 @@ msgstr "värde av uniontyp använt där skalär krävs"
 msgid "used vector type where scalar is required"
 msgstr "vektortyp använd där skalär krävs"
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> måste ange en av klausulerna %<parallel%>, %<for%>, %<sections%> eller %<taskgroup%>"
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "%<cancel%> %<if%>-klausulmodifierare förväntades"
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> måste ange en av klausulerna %<parallel%>, %<for%>, %<sections%> eller %<taskgroup%>"
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD är inte en variabel i en %qs-klausul"
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE är inte en variabel i en %qs-klausul"
@@ -50458,85 +50481,85 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%> %qD i %qs-klausul"
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD är en trådprivat variabel i en %qs-klausul"
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "undre gränsen %qE i vektorsektion har inte heltalstyp"
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "längden %qE i vektorsektion har inte heltalstyp"
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "en enda pekare förväntades i en %qs-klausul"
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "nollängds vektorsektion i en %qs-klausul"
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "för en vektor med okänd gräns måste ett längduttryck anges"
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "negativ nedre gräns i vektorsektion i %qs-klausul"
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "negativ längd i vektorsektion i en %qs-klausul"
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "nedre gränsen %qE över storleken på vektorsektionen i en %qs-klausul"
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "längden %qE över storleken på vektorsektionen i en %qs-klausul"
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "övre gräns %qE ovanför storleken på vektorsektionen i en %qs-klausul"
 
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr "för en vektorfunktionsparameter måste ett längduttryck anges"
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "för pekartyper måste ett längduttryck anges"
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "vektorsektionen är inte sammanhängande i %qs-klausulen"
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE har inte pekar- eller vektortyp"
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "iteratorn %qD har varken heltals- eller pekartyp"
@@ -50546,17 +50569,17 @@ msgstr "iteratorn %qD har varken heltals- eller pekartyp"
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "iteratorn %qD har %<_Atomic%>-kvalificerad typ"
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr "iteratorn %qD har const-kvalificerad typ"
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "iteratorsteg med en icke-heltalstyp"
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr "iteratorn %qD har nollsteg"
@@ -50566,32 +50589,32 @@ msgstr "iteratorn %qD har nollsteg"
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr "typ av iteratorn %qD refererar till den yttre iteratorn %qD"
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr "startuttrycket refererar till den yttre iteratorn %qD"
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr "slututtrycket refererar till den yttre iteratorn %qD"
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr "steguttrycket refererar till den yttre iteratorn %qD"
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr "pekare förväntades i en %qs-klausul"
 
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "%<inscan%>- och icke-%<inscan%> %<reduction%>-klausul på samma konstruktion"
 
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr "en %<inscan%> %<reduction%>-klausul med vektorsektion"
@@ -50621,7 +50644,7 @@ msgstr "typen %qT med variabel storlek i %qs-klausul"
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE har ogiltig typ för %<reduction(%s)%>"
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "ingen användardefinierad reduktion funnen för %qE"
@@ -50631,17 +50654,17 @@ msgstr "ingen användardefinierad reduktion funnen för %qE"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "elementtyp med variabel längd i vektor-%<reduction%>-klausul"
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "en %<nowait%>-klausul får inte användas tillsammans med %<copyprivate%>"
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE måste vara %<threadprivate%> för %<copyin%>"
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
 msgstr "modifierare skall inte anges i %<linear%>-klausul på %<simd%>- eller %<for%>-konstruktioner när man inte använder OpenMP 5.2-modiferare"
@@ -50656,23 +50679,23 @@ msgstr "en linjär klausul använd på variabel som inte är heltal och inte pek
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "%<_Atomic%> %qD i %<linear%>-klausul"
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "%<linear%>-klausulens steg %qE är varken en konstant eller en parameter"
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE är inte en variabel i klausul %qs"
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, gcc-internal-format
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr "%qD förekommer mer än en gång i datadelningsklausuler"
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD förekommer mer än en gång i reduktionsklausuler"
@@ -50684,32 +50707,32 @@ msgstr "%qE förekommer mer än en gång i dataklausuler"
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD förekommer mer än en gång i dataklausuler"
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD förekommer både i data- och map-klausuler"
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE är inte en variabel i klausul %<firstprivate%>"
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE är inte en variabel i klausul %<lastprivate%>"
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE är inte en variabel i %<aligned%>-klausul"
@@ -50729,7 +50752,7 @@ msgstr "%<_Atomic%> %qD i %<aligned%>-klausul"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE förekommer mer än en gång i %<aligned%>-klausuler"
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE är inte en variabel i en %<nontemporal%>-klausul"
@@ -50739,7 +50762,7 @@ msgstr "%qE är inte en variabel i en %<nontemporal%>-klausul"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE förekommer mer än en gång i %<nontemporal%>-klausuler"
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qE är inte en variabel i %<allocate%>-klausul"
@@ -50749,76 +50772,76 @@ msgstr "%qE är inte en variabel i %<allocate%>-klausul"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE förekommer mer än en gång i %<allocate%>-klausuler"
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr "klausulen %<depend%> med beroendetyp %<depobj%> på vektorsektion"
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr "%<omp_all_memory%> använt med en annan %<depend%>-sortkind än %<out%> eller %<inout%>"
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr "%qE är varken ett l-värdeuttryck eller en vektorsektion i en %qs-klausul"
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr "%qE har inte en typ %<omp_depend_t%> i klausulen %<depend%> med beroendetyp %<depobj%>"
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr "%qE skall inte ha en typ %<omp_depend_t%> i klausulen %<depend%> med annan beroendetyp än %<depobj%>"
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "vektorsektionen har inte en avbildbar typ i %qs-klausulen"
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, gcc-internal-format
 msgid "unsupported map expression %qE"
 msgstr "ej stött avbildningsuttryck %qE"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD förekommer mer än en gång i rörelseklausuler"
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD förekommer mer än en gång i avbildningsklausuler"
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD har inte en avbildbar typ i %qs-klausul"
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE är varken en variabel eller ett funktionsnamn i klausulen %qs"
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE förekommer mer än en gång i samma %<declare target%>-direktiv"
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD är inte en ett argument i en %<uniform%>-klausul"
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE är inte ett argument i en %<uniform%>-klausul"
@@ -50833,22 +50856,22 @@ msgstr "variabeln %qs är inte en pekare"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "%qs-variabeln är varken en pekare eller en vektor"
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "en %<order%>-klausul får inte användas tillsammans med %<ordered%>"
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr "för många %qs-klausuler på en task-konstruktion"
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "en %<inbranch%>-klausul är inkompatibel med %<notinbranch%>"
 
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE är förutbestämd som %qs för %qs"
@@ -50858,38 +50881,38 @@ msgstr "%qE är förutbestämd som %qs för %qs"
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "%<const%>-kvalificerad %qE kan förekomma endast i klausuler %<shared%> eller %<firstprivate%>"
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "%<simdlen%>-klausulvärde är större än %<safelen%>-klausulvärde"
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "%<nonmonotonic%>-schemaläggningsmodifierare angiven tillsammans med %<ordered%>-klausul"
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "en %qs-klausul angiven tillsammans med en %<inscan%> %<reduction%>-klausul"
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "%<linear%>-klausulsteg är en parameter %qD inte angiven i %<uniform%>-klausul"
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "en %<nogroup%>-klausul får inte användas tillsammans med en %<reduction%>-klausul"
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr "en %<detach%>-klausul får inte användas tillsammans med en %<mergeable%>-klausul"
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr "händelsehanteraren för en %<detach%>-klausul skall inte finnas i en datadelningsklausul"
@@ -51154,14 +51177,14 @@ msgstr "  ingen känd konvertering från %qH till %qI"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  ingen känd konvertering för argument %d från %qH till %qI"
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  kandidaten förväntade sig åtminstone %d argument, %d fanns"
 msgstr[1] "  kandidaten förväntade sig åtminstone %d argument, %d fanns"
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -51470,555 +51493,555 @@ msgstr "villkorsuttryck mellan flyttalstypen %qT och uppräkningstypen %qT bör
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "uppräknings- och inte uppräkningstyp i villkorsuttryck"
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "ingen %<%D(int)%> deklarerad för postfix %qs, försöker med prefixoperator istället"
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "ingen %<%D(int)%> deklarerad för postfix %qs"
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr "i C++20 anropar denna jämförelse den aktuella funktionen rekursivt med omvända argument"
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "returtypen för %qD är inte %qs"
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr "använd som omskriven kandidat för jämförelse mellan %qT och %qT"
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "jämförelse mellan %q#T och %q#T"
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, gcc-internal-format
 msgid "no match for call to %<%T::operator[] (%A)%>"
 msgstr "ingen träff för anrop till %<%T::operator[] (%A)%>"
 
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, gcc-internal-format
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr "anrop av %<%T::operator[] (%A)%> är tvetydigt"
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr "undantagsuppstädning för denna placerande new väljer icke-placerande %<operator delete%>"
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD är som en vanlig (icke placerande) avallokeringsfunktion i C++14 (eller med %<-fsized-deallocation%>)"
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD är en vanlig (utan placering) avallokeringsfunktion"
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "ingen motsvarande avallokeringsfunktion för %qD"
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr "förstörande delete %qD kan inte användas för att släppa det allokerade minnet om initieringen kastar eftersom objektet inte är konstruerat ännu"
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "ingen passande %<operator %s%> för %qT"
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "%q#D är privat inom denna kontext"
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "deklarerad privat här"
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%q#D är skyddad inom denna kontext"
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "deklarerad skyddad här"
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D är oåtkomlig inom denna kontext"
 
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "skickar NULL till icke-pekarargument %P till %qD"
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, gcc-internal-format
 msgid "  declared here"
 msgstr "  deklarerad här"
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "konverterar till icke-pekartyp %qT från NULL"
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "konverterar %<false%> till pekartyp för argument %P till %qD"
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "konverterar %<false%> till pekartyp %qT"
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  initierar argument %P till %qD"
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "konverteringar till vektorer med okänd gräns är endast tillgängliga med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "för många klamrar runt initierare för %qT"
 
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "konvertering till %qH från %qI behöver en direktinitiering"
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr "ISO C++ tillåter inte konvertering till %qH från %qI med en större konverteringsordning"
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr "ISO C++ tillåter inte konvertering till %qH från %qI med oordnad konverteringsordningar"
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "ogiltig användardefinierad konvertering från %qH till %qI"
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 msgid "invalid conversion from %qH to %qI"
 msgstr "ogiltig konvertering från %qH till %qI"
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "att konvertera till %qT från initierarlista skulle använda den explicita konstrueraren %qD"
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "i C++11 och senare kan en standardkonstruerare vara explicit"
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "kan inte binda r-värdesreferens av typen %qH till ett l-värde av typ %qI"
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr "kan inte binda icke-const-l-värde av typen %qH till ett värde av typ %qI"
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "kan inte binda icke-const-l-värde av typen %qH till ett r-värde av typ %qI"
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "kan inte binda l-värdesreferens av typen %qH till ett r-värde av typen %qI"
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "det går inte att binda en referens av typen %qH till %qI på grund av olika vektorgränser"
 
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "att binda en referens av typen %qH till %qI kastar kvalificerare"
 
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "det går inte att binda bitfält %qE till %qT"
 
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "det går inte att binda packat fält %qE till %qT"
 
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "det går inte att binda rvalue %qE till %qT"
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "implicit konvertering från %qH till %qI när argument skickas till en funktion"
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr "enum %qT med räckvidd skickad vidare %<...%> som %qT före %<-fabi-version=6%>, %qT efter"
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "att skicka objekt av ej trivialt kopierbar typ %q#T via %<...%> är villkorligt stött"
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "det går inte att referera typen %qT via %<...%>"
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "att ta emot objekt av ej trivialt kopierbar typ %q#T via %<...%> är villkorligt stött"
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "rekursiv beräkning av standardargument till %q#D"
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "anrop till %qD använder standardargumentet för parameter %P, vilket inte definierats ännu"
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "argument till funktionsanrop kan vara en kandidat för ett formatattribut"
 
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "användning av multiversionsfunktion utan ett standardfall"
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr "använd %<-fdiagnostics-all-candidates%> för att visa kandidater som övervägts"
 
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "att skicka %qT som %<this%>-argument kastar kvalificerare"
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  i anrop till %qD"
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT är inte en åtkomlig bas till %qT"
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "skickar argument till ellips av den ärvda konstrueraren %qD"
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "tilldelning från en temporär %<initializer_list%> utökar inte livslängden på den underliggande vektorn"
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr "%qD skriver till ett objekt av typen %#qT utan någon trivial kopieringstilldelning"
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%qD skriver till ett object av den icke-triviala typen %#qT%s"
 
 # %qs blir "protected" eller "private"
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr "%qD skriver till ett objekt av typen %#qT med %qs-medlem %qD"
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr "%qD skriver till ett objekt av typen %#qT som innehåller en pekare till datamedlem%s"
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr "; använd tilldelning eller värdeinitiering istället"
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "; använd tilldelning istället"
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "; använd värdeinitiering istället"
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD nollställer ett objekt av typen %#qT utan någon trivial kopieringstilldelning%s"
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD nollställer ett objekt av den icke-triviala typen %#qT%s"
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr "%qD nollställer ett objekt av typen %#qT som innehåller en pekare-till-medlem%s"
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "; använd kopieringstilldelning eller kopieringsinitiering istället"
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr "; använd kopieringstilldelning istället"
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "; använd kopieringsinitiering istället"
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD skriver till ett objekt av typen %#qT utan någon trivial kopieringstilldelning%s"
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "%qD skriver till ett objekt av typen %#qT som inte är trivialt kopierbar%s"
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr "%qD skriver till ett objekt med en borttagen kopieringskonstruerare"
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr "%qD kopierar ett objekt med en icke-trivial typ %#qT från en vektor av %#qT"
 
 # %qs blir "protected" eller "private"
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr "%qD kopierar ett objekt av typen %#qT med %qs-medlem %qD från en vektor av %#qT; använd tilldelning eller kopieringsinitiering istället"
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr "%qD skriver till ett objekt med en icke-trivial typ %#qT och lämnar %wu byte oförändrade"
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr "%qD skriver till ett objekt av en icke-trivial typ %#qT och lämnar %wu byte oförändrade"
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "%qD flyttar ett objekt av en icke trivialt kopierbar typ %#qT; använd %<new%> och %<delete%> istället"
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr "%qD flyttar ett objekt av typen %#qT med en borttagen kopieringskonstruerare; använd %<new%> och %<delete%> istället"
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr "%qD flyttar ett objekt av typen %#qT med en borttagen destruerare"
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr "%qD flyttar ett objekt av den icke-triviala typen %#qT och storleken %E in i en region av storleken %E"
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT är deklarerad här"
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, gcc-internal-format
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr "argument %u i anropet av funktionen %qE har en pekare till en icke trivialt kopierbar typ (%qT)"
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "konstruerare delegerar till sig själv"
 
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 msgid "cannot convert %qH to %qI"
 msgstr "det går inte att konvertera %qH till %qI"
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "ingen matchande funktion för anrop av %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "ingen matchande funktion för anrop av %<%T::%s%E(%A)%#V%>"
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "anrop av icke-funktion %qD"
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "kan inte anropa konstrueraren %<%T::%D%> direkt"
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "för en typkonvertering i funktionsstil, ta bort det överflödiga %<::%D%>"
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "ingen funktion som stämmer för anrop av %<%s(%A)%>"
 
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "anrop av överlagrad %<%s(%A)%> är tvetydigt"
 
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "pure virtual %q#D anropad från initierare av ickestatisk datamedlem"
 
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "pure virtual %q#D anropad från en konstruerare"
 
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "pure virtual %q#D anropad från en destruerare"
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "det går inte att anropa medlemsfunktion %qD utan ett objekt"
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "att skicka %qT väljer %qT framför %qT"
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, gcc-internal-format
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr "C++20 säger att dessa är tvetydiga, trots att den andra är reverserad:"
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, gcc-internal-format
 msgid "try making the operator a %<const%> member function"
 msgstr "försök att göra operatorn till en %<const%>-medlemsfunktion"
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "väljer %qD framför %qD"
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 msgid "  for conversion from %qH to %qI"
 msgstr "  för konvertering från %qH till %qI"
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  för att konverteringssekvensen för argumentet är bättre"
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "standardargument stämmer inte överens i upplösning av överlagring"
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " kandidat 1: %q#F"
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " kandidat 2: %q#F"
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ säger att dessa är tvetydiga, trots att den sämsta konverteringen för den första är bättre än den sämsta konverteringen för den andra:"
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "en temporär bunden till %qD består endast tills konstrueraren avslutar"
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "ogiltig initiering av icke konstant referens av typ %qH från ett r-värde av typ %qI"
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "ogiltig initiering av referens av typ %qH från uttryck av typ %qI"
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, gcc-internal-format
 msgid "possibly dangling reference to a temporary"
 msgstr "möjlig hängande referens till en temporär"
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr "den temporära destruerades vid slutet av det fullständiga uttrycket %qE"
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, gcc-internal-format
 msgid "explicit conversion function was not considered"
 msgstr "en explicit konverteringsfunktion övervägdes inte"
@@ -52064,7 +52087,7 @@ msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q#D kan inte överlagras med %q#D"
 
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "tidigare deklaration %q#D"
@@ -52485,7 +52508,7 @@ msgstr "flexibel vektor medlem %qD i en i övrigt tom %q#T"
 msgid "next member %q#D declared here"
 msgstr "nästa medlem %q#D är deklarerad här"
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "omdefinition av %q#T"
@@ -52616,7 +52639,7 @@ msgstr "ogiltig typ för parameter %d till %<constexpr%>-funktion %q+#D"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr "lambdan är implicit %<constexpr%> endast i C++17 och senare"
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<constexpr%>-destruerare är endast tillgängliga med %<-std=c++20%> eller %<-std=gnu++20%>"
@@ -52657,7 +52680,7 @@ msgstr "kroppen i %<constexpr%>-funktionen %qD är inte en retursats"
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%qD är inte användbar som en %<constexpr%>-funktion eftersom:"
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr "förstör %qE utanför dess livstid"
@@ -52675,7 +52698,7 @@ msgstr "%<constexpr%>-anrop flödar förbi slutet på funktionen"
 msgid "%q+E is not a constant expression"
 msgstr "%q+E är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -52696,7 +52719,7 @@ msgstr "%qE beräknas till falskt"
 msgid "failed %<assume%> attribute assumption"
 msgstr "misslyckat %<assume%>-attributantagande"
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, gcc-internal-format
 msgid "call to internal function %qE"
@@ -52743,7 +52766,7 @@ msgstr "%qT är en tvetydig basklass till den dynamiska typen %qT av sin operand
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr "den dynamiska typen %qT av sin operand har inte en otvetydig publik basklass %qT"
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -52871,18 +52894,18 @@ msgstr "vektorindexvärdet %qE är utanför gränserna för vektortypen %qT"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "icke-noll vektorindex %qE används med en vektor av typen %qT med okända gränser"
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "använder oinitierat vektorelement"
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "derefererar en nollpekare i %qE"
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -52890,470 +52913,470 @@ msgstr "derefererar en nollpekare i %qE"
 msgid "%qE is not a constant expression"
 msgstr "%qE är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "muterbar %qD är inte användbart i ett konstant uttryck"
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "använder oinitierad medlem %qD"
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "använder medlem %qD istället för initierad medlem %qD i ett konstant uttryck"
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "%qs är inte ett konstant uttryck eftersom %qT är en uniontyp"
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "%qs är inte ett konstant uttryck eftersom %qT innehåller en uniontyp"
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "%qs är inte ett konstant uttryck eftersom %qT är en pekartyp"
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "%qs är inte ett konstant uttryck eftersom %qT innehåller en pekartyp"
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "%qs är inte ett konstant uttryck eftersom %qT är en referenstyp"
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "%qs är inte ett konstant uttryck eftersom %qT innehåller en referenstyp"
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "%qs är inte ett konstant uttryck eftersom %qT är en pekare-till-medlem-typ"
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "%qs är inte ett konstant uttryck eftersom %qT innehåller en pekare-till-medlem-typ"
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "%qs är inte ett konstant uttryck eftersom %qT är volatil"
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "%qs är inte ett konstant uttryck eftersom  %qT innehåller ett volatilt delobjekt"
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "%qs kan inte beräknas konstant på denna målarkitektur"
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr "%qs kan inte vara konstant beräknat eftersom typen är för stor"
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr "%qs kan inte beräknas konstant eftersom argumentet inte kan kodas"
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "%qs använder oinitierad byte vid avståndet %d"
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "%qs kan inte beräknas konstant eftersom argumentet inte kan tolkas"
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "använder värdet av %qE genom ett %qT-glvalue i ett konstant uttryck"
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "användning av allokerad lagring efter deallokering i ett konstant uttryck"
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, gcc-internal-format
 msgid "allocated here"
 msgstr "allokerad här"
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
 msgstr "åtkomst av %qE utanför sin livstid"
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "innehållet av den oinitierade lagringen är inte användbart i ett konstant uttryck"
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "värdet på %qD är inte användbart i ett konstant uttryck"
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD använd i sin egen initierare"
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D är inte const"
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q+#D är volatile"
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD initierades inte med ett konstant uttryck"
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD deklarerades inte %<constexpr%>"
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD har inte heltals- eller uppräkningstyp"
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, gcc-internal-format
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr "ändring av allokerad lagring efter deallokering är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, gcc-internal-format
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr "ändring av %qE utanför sin livstid är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, gcc-internal-format
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr "att förstöra %qE utanför den nuvarande beräkningen är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, gcc-internal-format
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr "ändring av %qE från utanför den nuvarande beräkningen är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr "ändring av den aktiva medlemmen av en union %qD till %qD är inte ett konstant uttryck före C++20"
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr "%qD börjar inte implicit sin livstid eftersom %qT inte har någon oraderad trivial standardkonstruerare, använd %<std::construct_at%> istället"
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr "initiering av %qD kräver ett medlemsåtkomstuttryck som vänster operand i tilldelningen"
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "ändring av den aktiva medlemmen av en union %qD till %qD under initiering"
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "satsen är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "%<constexpr%>-slingiterationsantal överskrider gränsen på %d (använd %<-fconstexpr-loop-limit=%> för att öka gränsen)"
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "inline-assembler är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr "endast oevaluerad inline:ad assembler är tillåten i en %<constexpr%>-funktion i C++20"
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, gcc-internal-format
 msgid "use of %qD"
 msgstr "användning av %qD"
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr "dess värde kan variera mellan kompilatorversioner eller med olika flaggor %<-mtune%> eller %<-mcpu%>"
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr "om denna användning är en del av ett publikt ABI, byt det till att istället använda en konstant variabel du definierar"
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr "standardvärdet för den aktuella CPU-trimningen är %d byte"
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr "man kan stabilisera detta värde med %<--param hardware_destructive_interference_size=%d%>, eller avaktivera denna varning med %<-Wno-interference-size%>"
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "värdet %qE av typen %qT är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "antalet %<constexpr%>-evalueringsoperationer överskrider gränsen på %wd (använd %<-fconstexpr-ops-limit=%> för att öka gränsen)"
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr "kontrollen skickas via definitionen av %qD med trådlagringsvaraktighet"
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, gcc-internal-format
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "kontrollen skickas via definitionen av %qD med statisk Lagringsvaraktighet"
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporär av den ej litterala typen %qT i ett konstant uttryck"
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "en %<reinterpret_cast%> är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "konvertering från pekartypen %qT till den aritmetiska typen %qT i ett konstant uttryck"
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr "typkonvertering från %qT är inte tillåtet i ett konstant uttryck eftersom den utpekade typen %qT inte liknar %qT"
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, gcc-internal-format
 msgid "pointed-to object declared here"
 msgstr "utpekat objekt är deklarerat här"
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr "typkonvertering från %qT är inte tillåtet i ett konstant uttryck eftersom %qE inte pekar på ett objekt"
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr "typkonvertering från %qT är inte tillåtet i ett konstant uttryck före C++26"
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "%qE är inte ett konstant uttryck när kassen %qT fortfarande är ofullständig"
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "uttrycket %qE är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "kontraktspredikatet är falskt i ett konstant uttryck"
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "oväntat mall-id %qE"
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr "funktionskoncept måste anropas"
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "adressen för ett anrop av %qs är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "oväntat uttryck %qE av sorten %s"
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE är inte ett konstant uttryck eftersom det har referenser till muterbara delobjekt av %qT"
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE är inte ett konstant uttryck eftersom det refererar till en ofullständigt initierad variabel"
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qE är inte ett konstant uttryck eftersom det refererar ett resultat av %<operator new%>"
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qE är inte ett konstant uttryck eftersom allokerad lagring inte har avallokerats"
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr "omedelbar evaluering returnerar adressen till en omedelbar funktion %qD"
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, gcc-internal-format
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr "konstantevaluering returnerar adressen till en omedelbar funktion %qD"
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "konvertering av l-värde till r-värde av ett volatilt l-värde %qE med typen %qT"
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "lambdafångst av %qE är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "för att det används som ett gl-värde"
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "%<reinterpret_cast%> från heltal till pekare"
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "adress-av på ett objekt %qE med trådlokal eller automatisk lagring är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%<this%> används i ett konstant uttryck"
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "lambdauttryck är inte ett konstant uttryck före C++17"
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "new-uttryck är inte ett konstant uttryck före C++20"
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "virtuella funktioner kan inte %<constexpr%> före C++20"
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "%<typeid%> är inte ett konstant uttryck eftersom %qE har polymorf typ"
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "typkonvertering till %qT som inte är en heltalstyp i ett konstant uttryck"
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "%qD är definierad %<thread_local%> i en %<constexpr%>-kontext"
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "%qD är definierad %<static%> i en %<constexpr%>-kontext"
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "division med noll är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> är inte ett konstant uttryck"
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "ingendera grenen av %<if%> är ett konstant uttryck"
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "ickekonstant vektorinitierare"
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "en etikettdefinition i en %<constexpr%>-funktion är endast tillgängligt med %<-std=c++2b%> eller %<-std=gnu++2b%>"
 
 # ast = abstract syntax tree
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "oväntat AST av sorten %s"
@@ -54063,7 +54086,7 @@ msgstr "riktningsargumentet till %<__builtin_coro_promise%> måste vara en konst
 msgid "no suspend point info for %qD"
 msgstr "ingen suspenderingspunktsinformation för %qD"
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr "%qE tillhandahålls av %qT men är inte användbart med funktionssignaturen %qD"
@@ -54083,23 +54106,23 @@ msgstr "vänteuttryck är inte tillåtna i hanterare"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "vektorer med variabel längd stödjs inte ännu i korutiner"
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr "%qE tillhandahålls av %qT men %qE är inte markerad %<throw()%> eller %<noexcept%>"
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr "%qE är markerad %<throw()%> eller %<noexcept%> men ingen användbar %<get_return_object_on_allocation_failure%> tillhandahålls av %qT"
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr "%qE tillhandahålls av %qT men %<std::nothrow%> finns inte"
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr "det går inte att initiera ett returobjekt av typen %qT med ett r-värde av typen %<void%>"
@@ -54119,68 +54142,68 @@ msgstr "%qD befordrades till en omedelbar funktion eftersom dess kropp innehåll
 msgid "%qD was promoted to an immediate function"
 msgstr "%qD befordrades till en omedelbar funktion"
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "tar adressen till en omedelbar funktion %qD"
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, gcc-internal-format
 msgid "call to consteval function %qE is not a constant expression"
 msgstr "anrop av consteval-funktionen %qE är inte ett konstant uttryck"
 
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%<throw%> kommer alltid anropa %<terminate%>"
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "i C++11 är standard för destruerare %<noexcept%>"
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr "i C++11 kommer denna %<throw%> att anropa %<terminate%> eftersom standard för destruerare är %<noexcept%>"
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "ignorerar attributet %qE efter tidigare %qE"
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, gcc-internal-format
 msgid "pack expansion of %qE attribute"
 msgstr "paketexpandering av attributet %qE"
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, gcc-internal-format
 msgid "use fold expression in the attribute argument instead"
 msgstr "använd vikningsuttryck i attributargumentet istället"
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD är inte en typ"
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qD är inte en klasstyp"
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qD har inte typen %<const char *%>"
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%qD har inte heltalstyp"
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr "%<std::source_location::__impl%> innehåller inte endast icke-statiska datamedlemmar %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> och %<_M_column%>"
@@ -54221,7 +54244,7 @@ msgstr "konvertering till icke konstant referens av typ %q#T från ett r-värde
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "konvertering från %qH till %qI kastar kvalificerare"
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "typkonvertering av %qT till %qT derefererar inte pekare"
@@ -54604,7 +54627,7 @@ msgstr "än tidigare deklaration av %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "omdeklaration av %qD skiljer i %qs från tidigare deklaration"
 
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "tidigare deklaration %qD"
@@ -54744,8 +54767,8 @@ msgstr "tidigare %<pragma omp declare reduction%>-deklaration"
 msgid "%q#D previously defined here"
 msgstr "%q#D definierades tidigare här"
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q#D tidigare deklarerad här"
@@ -54820,52 +54843,37 @@ msgstr "standardargumentet angivet för parameter %d till %q#D"
 msgid "previous specification in %q#D here"
 msgstr "tidigare specifikation i %q#D här"
 
-#: cp/decl.cc:2285
-#, gcc-internal-format
-msgid "declaration %qD conflicts with builtin"
-msgstr "deklarationen %qD står i konflikt med inbyggd"
-
-#: cp/decl.cc:2288
-#, gcc-internal-format
-msgid "declaration %qD conflicts with import"
-msgstr "deklaration %qD står i konflikt med import"
-
-#: cp/decl.cc:2289
-#, gcc-internal-format
-msgid "import declared %q#D here"
-msgstr "importdeklarerad %q#D här"
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, gcc-internal-format
 msgid "conflicting exporting for declaration %qD"
 msgstr "motstridande exporterande för deklaration av %qD"
 
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, gcc-internal-format
 msgid "previously declared here without exporting"
 msgstr "tidigare deklarerad här utan att exporteras"
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "tidigare definition av %qD här"
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "tidigare deklaration av %qD här"
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "funktionen %qD är deklarerad %<[[noreturn]]%> men dess första deklaration var inte det"
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "överflödig omdeklaration av %qD i samma definitionsområde"
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr "borttagen definition av %qD är inte första deklarationen"
@@ -54878,44 +54886,44 @@ msgstr "borttagen definition av %qD är inte första deklarationen"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "explicit specialisering av %qD efter första användningen"
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%qD: synlighetsattributet ignoreras eftersom det står i konflikt med tidigare deklaration"
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "omdefinition av %q#D"
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD står i konflikt med använd funktion"
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D inte deklarerad i klassen"
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D omdeklarerad inline med attributet %<gnu_inline%>"
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D omdeklarerad inline utan attributet %<gnu_inline%>"
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr "jämförelseoperatorn %q+D standarddefinierades efter sin första deklaration"
@@ -54923,2501 +54931,2501 @@ msgstr "jämförelseoperatorn %q+D standarddefinierades efter sin första deklar
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "omdeklaration av vän %q#D kan inte ha standardmallargument"
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "trådlokal deklaration av %q#D följer på icke trådlokal deklaration"
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "icke trådlokal deklaration av %q#D följer på trådlokal deklaration"
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "omdeklaration av %q#D"
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "överflödig omdeklaration av statisk %<constexpr%>-datamedlem %qD"
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "den lokala etiketten %qE står i konflikt med en befintlig etikett"
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, gcc-internal-format
 msgid "previous label"
 msgstr "tidigare etikett"
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, gcc-internal-format
 msgid "jump to label %qD"
 msgstr "hopp till etikett %qD"
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr "hopp till case-etikett"
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr "  som ett möjligt mål för beräknad goto"
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  härifrån"
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  går ut från OpenMP-strukturerat block"
 
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  passerar initiering av %q#D"
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr "  går in i %<try%>-block"
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "  går in i %<catch%>-block"
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  går in i OpenMP-strukturerat block"
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "  går in i synkroniserad eller atomär sats"
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, gcc-internal-format
 msgid "  enters statement expression"
 msgstr "  går in i satsuttryck"
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "  går in i %<constexpr if%>-sats"
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, gcc-internal-format
 msgid "  enters %<consteval if%> statement"
 msgstr "  går in i %<consteval if%>-sats"
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, gcc-internal-format
 msgid "  does not destroy %qD"
 msgstr "  förstör inte %qD"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, gcc-internal-format
 msgid "  does not clean up handled exception"
 msgstr "  städar inte upp det hanterade undantaget"
 
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  hoppar över initiering av %q#D"
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "%qD använd utan mallargument"
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, gcc-internal-format
 msgid "%qD is a function, not a type"
 msgstr "%qD är en funktion, inte en typ"
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T är inte en klass"
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "ingen klassmall med namnet %q#T i %q#T"
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "ingen typ med namnet %q#T i %q#T"
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "uppslagning av %qT i %qT är tvetydig"
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> namnger %q#T, som inte är en klassmall"
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> namnger %q#D, som inte är en typ"
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "mallparametrar stämmer inte med mallen %qD"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "%<-faligned-new=%d%> är inte en potens av två"
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr "%<--param destructive-interference-size=%d%> är mindre än %d"
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr "%<--param destructive-interference-size=%d%> är mindre än %<--param l1-cache-line-size=%d%>"
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr "%<--param constructive-interference-size=%d%> är mindre än %d"
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr "%<--param constructive-interference-size=%d%> är större än %<--param l1-cache-line-size=%d%>"
 
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D ogiltig, en anonym union kan bara ha publika ickestatiska datamedlemmar"
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "denna flexibilitet bör undvikas och kommer tas bort"
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr "anonym post med basklasser"
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "medlem %q+#D med konstruerare inte tillåten i anonymt aggregat"
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "medlem %q+#D med destruerare inte tillåten i anonymt aggregat"
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "medlem %q+#D med kopieringstilldelningsoperator är inte tillåten i anonymt aggregat"
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "attribut ignoreras i deklaration av %q#T"
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "attribut för %q#T måste komma efter nyckelordet %qs"
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "flera typer i en deklaration"
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "omdeklaration av inbyggd C++-typ %qT"
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> kan endast anges för variabler eller funktionsdeklarationer"
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typnamn saknas i typedef-deklaration"
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ förbjuder anonyma poster"
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> kan endast anges för funktioner"
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> kan endast anges för funktioner"
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> kan endast anges inuti en klass"
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> kan endast anges för konstruerare"
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "en lagringsklass kan bara anges för objekt och funktioner"
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> kan bara anges för objekt och funktioner"
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> ignorerades i denna deklaration"
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%qs kan inte användas till typdeklarationer"
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "attribut ignoreras i explicit instansiering av %q#T"
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "inget attribut kan användas på en explicit instansiering"
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "ignorerar attribut använda på klasstypen %qT utanför dess definition"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "ignorerar attribut använda på beroende typ %qT utan en associerad deklaration"
 
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD är initierad (använd %qs istället)"
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "deklarationen av %q#D har %<extern%> och är initierad"
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "definitionen av %q#D är markerad %<dllimport%>"
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D är inte en statisk datamedlem i %q#T"
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "icke-medlemsmalldeklaration av %qD"
 
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "stämmer inte med medlemsmalldeklarationen här"
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ tillåter inte %<%T::%D%> att definieras som %<%T::%D%>"
 
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "dubblerad initierare av %qD"
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "deklaration av %q#D utanför en klass är inte en definition"
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr "extern-deklaration %q#D med blockräckvidd får inte kopplas till en namngiven modul"
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%qD definierad %<thread_local%> i en %qs-funktion är endast tillgängligt med %<-std=c++2b%> eller %<-std=gnu++2b%>"
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%qD definierad %<static%> i en %qs-funktion är endast tillgängligt med %<-std=c++2b%> eller %<-std=gnu++2b%>"
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "variabeln %q#D har initierare men ofullständig typ"
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "elementen i vektorn %q#D har ofullständig typ"
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "aggregatet %q#D har ofullständig typ och kan inte definieras"
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD är deklarerad som en referens men inte initierad"
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "namn använt i en designerad initierare i GNU-stil för en vektor"
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "namnet %qD använt i en designerad initierare i GNU-stil för en vektor"
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "icketriviala designerade initierare stödjs inte"
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "C99-beteckningen %qE är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "initierare misslyckas med att bestämma storleken på %qD"
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "vektorstorlek saknas i %qD"
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "vektor med storlek noll %qD"
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "lagringsstorlek på %qD är inte känd"
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "lagringsstorlek på %qD är inte konstant"
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "tyvärr: semantiken för inline-variabeln %q#D är felaktig (du kommer få flera exemplar)"
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "tyvärr: semantiken för inline-funktioners statiska data %q#D är felaktig (du kommer få flera exemplar)"
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "du kan gå runt detta genom att ta bort initieraren"
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "oinitierad %<const %D%>"
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "oinitierad variabel %qD i %<constexpr%>-funktion"
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "oinitierad variabel %qD i %<constexpr%>-kontext"
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T har ingen användardefinierad standardkonstruerare"
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "konstrueraren är inte användarens egna eftersom den är uttryckligen standarddefinierad i klasskroppen"
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "och den implicit definierade konstrueraren initierar inte %q#D"
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "ogiltig typ %qT som initierare för en vektor med typ %qT"
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "initierare för %qT måste vara inom klamrar"
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> använt i en designerad initierare i GNU-stil för klassen %qT"
 
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "begäran av medlem %qD är tvetydig"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT har ingen icke-statisk medlem med namnet %qD"
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD har inte en direkt medlem i %qT"
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "ogiltig initierare för %q#D"
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99-beteckningen %qE utanför aggregatinitierare"
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "för många initierare för %qT"
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "klamrar runt skalär initierare för typen %qT"
 
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "för många klamrar runt skalär initierare för typen %qT"
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "klamrar saknas runt initierare för %qT"
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "strukturerad bindning har en ofullständig typ %qT"
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "element i vektorn %q#T har ofullständig typ"
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "sammansatta litteral med variabel storlek"
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D har ofullständig typ"
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "skalärt objekt %qD kräver ett element i initieraren"
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "i C++98 måste %qD initieras med en konstruerare, inte med %<{...}%>"
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "vektor %qD initierad från strängkonstant inom parentes %qE"
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "initierare är ogiltig för statisk medlem med konstruerare"
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ej konstant initiering inom klassen av statisk medlem %qD"
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ej konstant initiering inom klassen är felaktig för icke inline statisk medlem %qD"
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(en initiering utanför klassen krävs)"
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "referensen %qD initieras med sig själv"
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "kunde inte hitta en variantdeklaration"
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%<declare variant%> på konstrueraren %qD"
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "%<declare variant%> på destrueraren %qD"
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "%<declare variant%> på standarddefinierad %qD"
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr "%<declare variant%> på raderad %qD"
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%<declare variant%> på virtuell %qD"
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "tilldelning (inte initiering) i deklaration"
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++17 tillåter inte specificeraren %<register%> av lagringsklass"
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "specificeraren %<register%> av lagringsklass angiven"
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "deklarationen av %q#D har ingen initierare"
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "initieraren för %<decltype(auto) %D%> har funktionstyp; glömde du %<()%>?"
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, gcc-internal-format
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "härledd typ %qT för %qD är ofullständig"
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "variabelkoncept har ingen initierare"
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "skuggar tidigare typdeklaration av %q#D"
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%<constinit%> kan bara tillämpas på en variabel med statisk eller trådlagringsvaraktighet"
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "funktionen %q#D är initierad som en variabel"
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "det går inte dekomponera klasstypen %qT för att den har en anonym struct-medlem"
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "kan inte dekomponera klasstypen %qT för att den har en anonym unionsmedlem"
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "det går inte att dekomponera en oåtkomlig medlem %qD av %qT"
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "kan inte dekomponera klasstypen %qT: både den och dess basklass %qT har ickestatiska datamedlemmar"
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "kan inte dekomponera klasstypen %qT: dess basklasser %qT och %qT har ickestatiska datamedlemmar"
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "strukturerad bindning refererar till ofullständig typ %qT"
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "det går inte att dekomponera en vektor %qT med variabel längd"
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%u namn angivet för strukturerad bindning"
 msgstr[1] "%u namn angivna för strukturerad bindning"
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] "endast %u namn angivet för strukturerad bindning"
 msgstr[1] "endast %u namn angivna för strukturerad bindning"
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] "medan %qT dekomponeras till %wu element"
 msgstr[1] "medan %qT dekomponeras till %wu element"
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "det går inte att dekomponera en vektor %qT med variabel längd"
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "medan %qT dekomponeras till %E element"
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr "%<std::tuple_element<%u, %T>::type%> är %<void%>"
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "i initieringen av variabel %qD i strukturerad bindning"
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "det går inte att dekomponera unionstypen %qT"
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "det går inte att dekomponera typen %qT som inte är en klass eller vektor"
 
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "det går inte att dekomponera lambdahöljestypen %qT"
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "strukturerad bindning refererar till ofullständig klasstyp %qT"
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "det går inte att dekomponera klasstypen %qT utan icke-statiska datamedlemmar"
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "ickelokal variabel %qD deklarerad %<__thread%> behöver dynamisk initiering"
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "den icke-lokala variabeln %qD deklarerad %<__thread%> har en icke-trivial destruerare"
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "C++11 %<thread_local%> tillåter dynamisk initialisering och destruktion"
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "initierare misslyckas med att bestämma storleken på %qT"
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "vektorstorlek saknas i %qT"
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "vektor med storlek noll %qT"
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "destruerare för främmande class %qT kan inte vara en medlem"
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruerare för främmande klass %qT kan inte vara en medlem"
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD deklarerad som en %<virtual%>-variabel"
 
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i variabeldeklaration"
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD deklarerad som en %<virtual%>-parameter"
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD deklarerad som en %<inline%>-parameter"
 
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i parameterdeklaration"
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD deklarerad som en %<virtual%>-typ"
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD deklarerad som en %<inline%>-typ"
 
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i typdeklaration"
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD deklarerat som ett %<virtual%>-fält"
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD deklarerat som ett %<inline%>-fält"
 
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i fältdeklaration"
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D deklarerad som en vän"
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D deklarerad med en undantagsspecifikationer"
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "definitionen av %qD är inte i en namnrymd som innesluter %qT"
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statisk medlemsfunktion %q#D deklarerad med typkvalificerare"
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "konceptet %q#D deklarerad med funktionsparametrar"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "konceptet %q#D deklarerat med en härledd returtyp"
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "koncept %q#D med icke-%<bool%>-returtyp %qT"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "konceptet %qD har ingen definition"
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "ett funktionskoncept kan inte begränsas"
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "begränsning av en funktion som inte är en mall"
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, gcc-internal-format
 msgid "constrained non-template friend declaration must be a definition"
 msgstr "begränsad vändeklaration som inte är en mall måste vara en definition"
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr "en vänfunktionsmall med begränsningar som beror på yttre mallparametrar måste vara en definition"
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "definierar explicit specialisering %qD i vändeklaration"
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ogiltig användning av mall-id %qD i deklaration av primär mall"
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "standardargument är inte tillåtna i deklaration av vänmallspecialisering %qD"
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> är inte tillåtet i deklaration av vänmallspecialisering %qD"
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "vändeklarationen av %qD anger standardargument och är inte en definition"
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "det går inte att deklarera %<::main%> som en mall"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "det går inte att deklarera %<::main%> som inline"
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "det går inte att deklarera %<::main%> som %qs"
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "det går inte att deklarera %<::main%> som static"
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "icke-medlemsfunktion %qD kan inte ha cv-kvalificerare"
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "statisk medlemsfunktion %qD kan inte ha cv-kvalificerare"
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, gcc-internal-format
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr "explicit objektmedlemsfunktion %qD kan inte ha cv-kvalificerare"
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "icke-medlemsfunktion %qD kan inte ha ref-kvalificerare"
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "statisk medlemsfunktion %qD kan inte ha ref-kvalificerare"
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, gcc-internal-format
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr "explicit objektmedlemsfunktion %qD kan inte ha ref-kvalificerare"
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, gcc-internal-format
 msgid "explicit object parameter declared here"
 msgstr "explicit objektparameter deklarerad här"
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "härledningsguiden %qD måste deklareras med i samma räckvidd som %qT"
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "härledningsguiden %qD måste ha samma åtkomst som %qT"
 
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "härledningsguiden %qD får inte ha en funktionskropp"
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "litteral operator med C-länkning"
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD har en ogiltig argumentlista"
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "heltalssuffixet %qs skuggas av implementationen"
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "flyttalssuffixet %qs skuggas av implementationen"
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "litterala operatorsuffix som inte föregås av %<_%> är reserverade för framtida standardisering"
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD måste vara en icke-medlems-funktion"
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> måste returnera %<int%>"
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "omdefinition av implicit deklarerad %qD"
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "definition av explicit standarddefinierad %q+D"
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D explicit standarddefinierad här"
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "ingen medlemsfunktion %q#D deklarerad i klassen %qT"
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "det går inte att deklarera %<::main%> som en global variabel"
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "en icke-mallvariabel variabel kan inte vara %<concept%>"
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr "koncept måste definieras med namnrymdsräckvidd"
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "koncept måste ha typen %<bool%>"
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "ett variabelkoncept kan inte begränsas"
 
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "initiering i klassen av statisk datamedlem %q#D med ofullständig typ"
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> behövs för initiering i klassen av statisk datamedlem med icke heltalstyp %q#D"
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "initiering i klassen av statisk datamedlem %q#D med icke-litteral typ"
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ogiltig initiering i klassen av statisk datamedlem med icke heltalstyp %qT"
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ förbjuder initiering inom klassen av icke-konstant statisk medlem %qD"
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ förbjuder initiering av medlemskonstant %qD av icke heltalstyp %qT"
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "storlek på vektorn %qD av typen %qT är inte en heltalstyp"
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "storlek på vektorn av typen %qT är inte en heltalstyp"
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "storlek på vektorn %qD är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "storlek på vektorn är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ förbjuder vektor %qD med storlek noll"
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ förbjuder vektor med storlek noll"
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ förbjuder vektor %qD med variabel längd"
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ förbjuder vektor med variabel längd"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "vektor %qD med variabel längd används"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "vektor med variabel längd används"
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "spill i vektordimension"
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%qD är deklarerad som en vektor av mallens platshållartyp %qT"
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr "skapar en vektor av mallens platshållartyp %qT"
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "deklaration av %qD som en vektor av void"
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "skapar vektor av void"
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "deklaration av %qD som en vektor av funktioner"
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "skapar vektor av funktioner"
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "deklaration av %qD som en vektor av referenser"
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "skapar vektor av referenser"
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "deklaration av %qD som en vektor av funktionsmedlemmar"
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "skapar vektor av funktionsmedlemmar"
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklaration av %qD som flerdimensionell vektor måste ha gränser för alla dimensioner utom den första"
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "flerdimensionell vektor måste ha gränser för alla dimensioner utom den första"
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr "vektor med variabel längd av %<auto%>"
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "en returtypsspecifikation för konstruerare är ogiltig"
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "kvalificerare är inte tillåtna vid konstruerardeklaration"
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "specifikation av returtyp för destruerare är ogiltigt"
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "kvalificerare är inte tillåtna vid destruerardeklaration"
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "returtyp angiven för %<operator %T%>"
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "kvalificerare är inte tillåtna på deklaration av %<operator %T%>"
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "returtypen angiven för härledningsguiden"
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "kvalificerare är inte tillåtna på deklaration av härledningsguide"
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "mallmallparameter %qT i deklaration av härledningsguide"
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "%<decl-specifier%> i deklaration av härledningsguide"
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "namnlös variabel eller fält deklarerad void"
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variabel eller fält deklarerad void"
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "specificeraren %<inline%> är ogiltig för variabeln %qD deklarerad med blockräckvidd"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "inline-variabler är endast tillgängliga med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT som en typ snarare en enkel %<decltype(auto)%>"
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "%<decltype(auto)%> får inte vara cv-kvalificerad"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ogiltig användning av kvalificerat namn %<::%D%>"
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ogiltig användning av kvalificerat namn %<%T::%D%>"
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ogiltig användning av kvalificerat namn %<%D::%D%>"
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%q#T är inte en klass eller namnrymd"
 
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "deklaration av %qE som en icke-funktion"
 
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "deklaration av %qE som icke-medlem"
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "deklarerar-id saknas, använder reserverat ord %qD"
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "funktionsdefinition deklarerar inte parametrar"
 
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "deklaration av %qD som en icke-funktion"
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "deklaration av %qD som %<typedef%>"
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "deklaration av %qD som en parameter"
 
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr "både %qs och %qs angivna"
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%qs kan inte förekomma i en typedef-deklaration"
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr "man kan använda högst en av specificerarna %<constinit%> och %<constexpr%>"
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "två eller fler datatyper i deklaration av %qs"
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C++ stödjer inte bara %<complex%> i meningen %<double complex%>"
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ förbjuder deklaration av %qs utan typ"
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> stödjs inte på denna målarkitektur"
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ stödjer inte %<__int%d%> för %qs"
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> och %<unsigned%> givna tillsammans"
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> och %<short%> angivna tillsammans"
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qs specificerad med %qT"
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, gcc-internal-format
 msgid "%qs specified with typedef-name %qD"
 msgstr "%qs specificerad med typedef-namn %qD"
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs specificerad med %<decltype%>"
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qs specificerad med %<typeof%>"
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex ogiltig för %qs"
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr "mallargumentlistan saknas efter %qE; för härledning måste mallplatshållare följas av ett enkelt deklarerar-id"
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "medlem %qD kan inte deklareras både %<virtual%> och %<static%>"
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "medlem %qD kan deklareras både %<virtual%> och %<constexpr%> endast i %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef-deklaration ogiltig i parameterdeklaration"
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "lagringsklass angiven för mallparameter %qs"
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "lagringsklass angiven för parameter %qs"
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "en parameter kan inte deklareras %qs"
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> utanför klassdeklaration"
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "deklaration av strukturerad bindning får inte vara %qs"
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "strukturerade bindningsdeklarationer kan vara %qs endast i %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "%<volatile%>-kvalificerad strukturerad bindning bör undvikas"
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "deklaration av strukturerad bindning får inte vara C++98 %<auto%>"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "deklaration av strukturerad bindning får inte ha typen %qT"
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "typen måste vara en cv-kvalificerad %<auto%> eller en referens till en cv-kvalificerad %<auto%>"
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "deklaration av strukturerad bindning får inte ha begränsat %<auto%>-typ %qT"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "flera lagringsklasser i deklaration av %qs"
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "lagringsklass angiven för %qs"
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "nästad funktion %qs är deklarerad %<extern%>"
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "toppnivådeklaration av %qs anger %<auto%>"
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "funktionsdefinitionsområde %qs implicit auto och deklarerat %<__thread%>"
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "ogiltig specificerare av lagringsklass i vänfunktionsdeklarationer"
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attributet ignorerat"
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "ett attribut som gäller en viss typspecificerare ignoreras"
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "onödiga parenteser i deklaration av %qs"
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr "ta bort parenteser"
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, gcc-internal-format
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "explicita objektmedlemsfunktioner är endast tillgängliga med %<-std=c++23%> eller %<-std=gnu++23%>"
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, gcc-internal-format
 msgid "a function type cannot have an explicit object parameter"
 msgstr "en funktionstyp kan inte ha en explicit objektparameter"
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, gcc-internal-format
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr "en pekare på en funktionstyp kan inte ha en explicit objektparameter"
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, gcc-internal-format
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr "en pekare på en medlemsfunktionstyp kan inte ha en explicit objektparameter"
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr "typen på en pekare till en explicit objektmedlemsfunktion är en vanlig pekare på en funktionstyp"
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, gcc-internal-format
 msgid "the type of an explicit object member function is a regular function type"
 msgstr "type på en explicit objektmedlemsfunktion är en normal funktionstyp"
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr "endast den första parametern till en medlemsfunktion kan deklareras som en explicit objektparameter"
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "valid explicit object parameter declared here"
 msgstr "giltig explicit objektparameter deklarerad här"
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "requires-klausul på returtypen"
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "funktionen %qs använder typspecificeraren %<auto%> utan avslutande returtyp"
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "härledd returtyp är endast tillgänglig med %<-std=c++14%> eller %<-std=gnu++14%>"
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "en virtuell funktion kan inte ha härledd returtyp"
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "funktionen %qs med avslutande returtyp har %qT som sin typ istället för bara %<auto%>"
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "funktionen %qs med avslutande returtyp har %<decltype(auto)%> som sin typ istället för bara %<auto%>"
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "ogiltig användning av %<decltype(auto)%>"
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "härledd klasstyp %qD i funktionens returtyp"
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "härledningsguiden för %qT måste ha en avslutande returtyp"
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "den avslutande returtypen %qT hos deduktionsguiden är inte en specialisering av %qT"
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "avslutande returtyp är endast tillgänglig med %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "funktionen %qs med avslutande returtyp är inte deklarerad med typspecificeraren %<auto%>"
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "en konverteringsfunktion kan inte ha en avslutande returtyp"
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "%<volatile%>-kvalificerad returtyp bör undvikas"
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs är deklarerad som en funktion som returnerar en funktion"
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs är deklarerad som en funktion som returnerar en vektor"
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<constinit%> på en funktions returtyp är inte tillåtet"
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "destruerare kan inte vara en statisk medlemsfunktion"
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "konstruerare kan inte vara en statisk medlemsfunktion"
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "destruerare får inte vara cv-kvalificerade"
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "konstruerare får inte vara cv-kvalificerade"
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "destruerare får inte vara ref-kvalificerade"
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "konstruerare får inte vara ref-kvalificerade"
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "konstruerare kan inte deklareras %<virtual%>"
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "virtuella funktioner kan inte vara vänner"
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "vändeklaration är inte i klassdefinition"
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "det går inte att definiera vänfunktion %qs i en lokal klassdefinition"
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr "vänfunktionsdefinitionen %qs får inte ha ett namn kvalificerat med %<::%>"
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr "vänfunktionsdefinitionen %qs får inte ha ett namn kvalificerat med %<%D::%>"
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, gcc-internal-format
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr "en icke-medlemsfunktion kan inte ha en explicit objektparameter"
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr "en explicit objektmedlemsfunktion får inte vara %<virtual%>"
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<static%>"
 msgstr "en explicit objektmedlemsfunktion kan inte vara %<static%>"
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, gcc-internal-format
 msgid "%qD cannot be an explicit object member function"
 msgstr "%qD kan inte vara en explicit objektmedlemsfunktion"
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruerare får inte ha parametrar"
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "det går inte att deklarera pekare till %q#T"
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "det går inte att deklarera referens till %q#T"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "det går inte att deklarera pekare medlem av %q#T"
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "det går inte att deklarera en referens till en kvalificerad funktionstyp %qT"
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "det går inte att deklarera en pekare till en kvalificerad funktionstyp %qT"
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "det går inte att deklarera en referens till %q#T, som inte är ett typedef- eller ett malltypargument"
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "mall-id %qD använd som en deklarerare"
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "medlemsfunktioner är implicit vänner till sin klass"
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "extra kvalifikation %<%T::%> på medlem %qs"
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "det går inte att definiera medlemsfunktion %<%T::%s%> inuti %qT"
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "det går inte att deklarera medlemsfunktionen %<%T::%s%> inuti %qT"
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "det går inte att deklarera medlem %<%T::%s%> inuti %qT"
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "icke-parameter %qs kan inte vara ett parameterpaket"
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "datamedlem får inte ha variabel typ %qT"
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter får inte ha variabel typ %qT"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> utanför klassdeklaration"
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> i vändeklaration"
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "endast deklarationer av konstruerare och konverteringsoperatorer kan vara %<explicit%>"
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "icke-medlem %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "icke-objektmedlem %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "funktionen %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "%<static%> %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "%<const%> %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "referensen %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "typedef kan inte vara en funktionsdefinition"
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "typedef får inte vara en medlemsfunktionsdefinition"
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<auto%> är inte tillåtet i en aliasdeklaration"
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef deklarerad %<auto%>"
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "requires-klausul på typedef"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-namn får inte vara en nästad-namnspecificerare"
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ förbjuder nästad typ %qD med samma namn som en omgivande klass"
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> angivet för vänklassdeklaration"
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "mallparametrar kan inte vara vänner"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "vändeklaration kräver klassnyckel, d.v.s. %<friend class %T::%D%>"
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "vändeklaration kräver klassnyckel, d.v.s. %<friend %#T%>"
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "försöker göra klassen %qT en vän med global räckvidd"
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ogiltiga kvalificerare på typ som inte är medlemsfunktion"
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "requires-klausul på type-id"
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakt deklarerare %qT använd som deklaration"
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "requires-klausul vid deklaration av icke-funktionstypen %qT"
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "det går inte att använda %<::%> i parameterdeklaration"
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "det går inte att deklarera en parameter med %<decltype(auto)%>"
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr "saknad mallargumentlista efter %qE; platshållare för mall är inte tillåtet i en parameter"
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr "eller använd %<auto%> för en förkortad funktionsmall"
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "en %<auto%>-parameter är tillåten i detta sammanhang"
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parametern deklarerad %<auto%>"
 
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ogiltig användning av mallnamnet %qE utan en argumentlista"
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "ej statisk datamedlem deklarerad med platshållaren %qT"
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ förbjuder den flexibla vektormedlemmen %qs"
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C++ förbjuder flexibla vektormedlemmar"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ogiltig användning av %<::%>"
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "deklaration av funktionen %qD i ogiltig kontext"
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "funktionen %qD deklarerad %<virtual%> inuti en union"
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD kan inte deklareras %<virtual%>, eftersom den alltid är statisk"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "kvalificerat namn förväntades i vändeklaration för destruerare %qD"
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "deklaration av %qD som medlem av %qT"
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "en destruerare kan inte vara %qs"
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "kvalificerat namn förväntades i vändeklaration för konstruerare %qD"
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "en konstruerare kan inte vara %<concept%>"
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "ett koncept kan inte vara en medlemsfunktion"
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%qD kan inte vara %qs"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "specialisering av variabelmall %qD deklarerad som en funktion"
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "variabelmallen är deklarerad här"
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "fältet %qD har den ofullständiga typen %qT"
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "namnet %qT har ofullständig typ"
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE är varken en funktion eller medlemsfunktion, kan inte deklareras som vän"
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "ett namnlöst fält är varken en funktion eller medlemsfunktion, kan inte deklareras som vän"
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr "ett attribut som tillhör en vändeklaration som inte är en definition ignoreras"
 
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "statisk datamedlem %qE deklarerad %qs"
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "statiska %<constexpr%>-datamedlemmen %qD måste ha en initierare"
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "ickestatisk datamedlem %qE deklarerad %qs"
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "lagringsklassen %<auto%> är ogiltig för funktionen %qs"
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "lagringsklassen %<register%> är ogiltig för funktionen %qs"
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "lagringsklassen %<__thread%> är ogiltig för funktionen %qs"
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "lagringsklassen %<thread_local%> är ogiltig för funktionen %qs"
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, gcc-internal-format
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr "specificeraren %<constinit%> är ogiltig för funktionen %qs"
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-specificerare i %qs är inte tillåtet utanför en klassdefinition"
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "specificerare %<static%> är ogiltigt för funktion %qs deklarerad utanför global räckvidd"
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "specificerare %<inline%> är ogiltig för funktionen %qs deklarerad utanför global räckvidd"
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuell icke klassfunktion %qs"
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs definierad utan att vara i klassräckvidd"
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs deklarerad utan att vara i klassräckvidd"
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "det går inte deklarera medlemsfunktionen %qD att ha statisk länkklass"
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "kan inte deklarera en statisk funktion i en annan funktion"
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> får inte användas vid definition (till skillnad mot deklaration) av statisk datamedlem"
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statisk medlem %qD deklarerad %<register%>"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "det går inte att deklarera medlem %q#D att ha extern länkklass"
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "deklarationen av %<constexpr%>-variabeln %qD är inte en definition"
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "en variabel kan inte deklareras %<consteval%>"
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initierad och deklarerad %<extern%>"
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs har både %<extern%> och initierare"
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "standardargument %qE använder %qD"
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "standardargument %qE använder lokal variabel %qD"
 
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "felaktig användning av cv-kvalificerad typ %qT i en parameterdeklaration"
 
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "felaktig användning av typen %<void%> i en parameterdeklaration"
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "%<volatile%>-kvalificerad parameter bör undvikas"
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qD ogiltigt deklarerad metodtyp"
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameter %qD inkluderar pekare till vektor %qT med okänd gräns"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parameter %qD inkluderar referens till vektor %qT med okänd gräns"
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ogiltig konstruerare, du menade förmodligen %<%T (const %T&)%>"
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD är kanske inte deklarerad i en namnrymd"
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD får inte deklareras som statisk"
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "%qD måste vara en icke-statisk medlemsfunktion"
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "%qD måste vara en medlemsfunktion"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "%qD får bara vara en statisk medlemsfunktion med %<-std=c++23%> eller %<-std=gnu++23%>"
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD måste vara antingen en medlemsfunktion som inte är statisk eller funktion som inte är medlem"
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD måste ha ett argument med klass- eller uppräkningstyp"
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ förhindrar överlagring av %<operator ?:%>"
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD får inte ha variabelt antal argument"
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD måste ha antingen noll eller ett argument"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD måste ha antingen ett eller två argument"
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfix %qD måste ha %<int%> som sitt argument"
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfix %qD måste ha %<int%> som sitt andra argument"
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD får inte ha några argument"
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD måste ha exakt ett argument"
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD måste ha exakt två argument"
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD kan inte ha standardargument"
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "konvertering av %qT till %<void%> kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "konvertering av %qT till en referens till samma typ kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "konvertering av %qT till samma typ kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "konvertering av %qT till en referens till basklassen %qT kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "konvertering av %qT till basklassen %qT kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "användardefinierad %qD beräknar alltid båda argumenten"
 
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "prefix %qD skall returnera %qT"
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "postfix %qD skall returnera %qT"
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD skall returnera som värde"
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "malltypparametern %qT används efter %qs"
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "användning av aliasmallspecialisering %qT efter %qs"
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "typedef-namnet %qD används efter %qs"
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD har en tidigare deklaration här"
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT refererad till som %qs"
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT har en tidigare deklaration här"
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT refererad till som enum"
@@ -57429,115 +57437,100 @@ msgstr "%qT refererad till som enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "mallargument krävs för %<%s %T%>"
 
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "referens till %qD är tvetydig"
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr "klassmallen %qD omdeklarerad som en icke-mall"
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD har samma namn som klassen den är deklarerad i"
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT är inte en mall"
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "kanske du vill explicit lägga till %<%T::%>"
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "enum %q#D används utan tidigare deklaration"
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "omdeklaration av %qT som en icke-mall"
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, gcc-internal-format
-msgid "cannot declare %qD in a different module"
-msgstr "det går inte att deklarera %qD i en annan modul"
-
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, gcc-internal-format
-msgid "previously declared here"
-msgstr "tidigare deklarerad här"
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "härledd unionen %qT ogiltig"
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT definierad med flera direkta baser"
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT definierad med en direkt virtuell bas"
 
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "bastyp %qT är ingen post- eller klasstyp"
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiv typ %qT odefinierad"
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "upprepat bastyp %qT ogiltig"
 
-#: cp/decl.cc:16984
-#, gcc-internal-format
-msgid "cannot declare %qD in different module"
-msgstr "det går inte att deklarera %qD i en annan modul"
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "uppräkningstyp med/utan räckviddsbegränsning stämmer inte överens för enum %q#T"
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "tidigare definition här"
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "underliggande typ stämmer inte överens i enum %q#T"
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "olika underliggande typ i enum %q#T"
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "underliggande typ %qT till %qT måste vara en heltalstyp"
@@ -57546,82 +57539,82 @@ msgstr "underliggande typ %qT till %qT måste vara en heltalstyp"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ingen heltalstyp kan representera alla uppräkningsvärdena i %qT"
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "uppräkningsvärde för %qD är inte en heltalstyp eller uppräkningstyp utan räckviddsbegränsning"
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "uppräkningsvärde för %qD är inte en heltalskonstant"
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ökat uppräkningsvärde är för stort för %<unsigned long%>"
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ökat uppräkningsvärde är för stort för %<long%>"
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "överspill i uppräkningsvärden vid %qD"
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "uppräkningsvärdet %qE är utanför intervallet för den underliggande typen %qT"
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "fler definitioner av %q#T"
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "returtypen %q#T är ofullständig"
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> skall returnera en referens till %<*this%>"
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "inga retursatser i funktion som returnerar %qT"
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "endast enkel returtyp %<auto%> kan härledas till %<void%>"
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "ingen retursats i %<constexpr%>-funktion som returnerar icke-void"
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD är redan definierad i klassen %qT"
 
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, gcc-internal-format
 msgid "using %qs"
 msgstr "använder %qs"
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "användning av %qD före härledning av %<auto%>"
@@ -57676,7 +57669,7 @@ msgstr "det går inte att radera en funktion.  Endast pekare till objekt är gil
 msgid "deleting %qT is undefined"
 msgstr "radera %qT är odefinierat"
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "malldeklaration av %q#D"
@@ -57686,7 +57679,7 @@ msgstr "malldeklaration av %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "mallparameterlistan som ges stämmer inte mallparametrarna till %qD"
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "destrueraren %qD deklarerad som medlemsmall"
@@ -57870,64 +57863,64 @@ msgstr "en förstörande %<operator delete%> måste vara en vanlig avallokerings
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> tar typen %qT som första parameter"
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr "%qT har ett fält %q#D vars typ inte har någon länkklass"
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT har ett fält %qD vars typ beror på typen %qT som inte har någon länkklass"
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr "%qT har ett fält %q#D vars typ inte har intern länkklass"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr "%qT har ett fält %q#D vars typ använder den anonyma namnrymden"
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT är deklarerad med större synlighet än typen för dess fält %qD"
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, gcc-internal-format
 msgid "%qT has a base %qT which has no linkage"
 msgstr "%qT har en bas %qT som inte har någon länkklass"
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, gcc-internal-format
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr "%qT har en bas %qT vilken beror på typen %qT vilken inte har någon länkklass"
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, gcc-internal-format
 msgid "%qT has a base %qT which has internal linkage"
 msgstr "%qT har en bas %qT vilken har intern länkklass"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, gcc-internal-format
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr "%qT har en bas %qT vilken använder den anonyma namnrymden"
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT är deklarerad med större synlighet än sin bas %qT"
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr "%q#D, deklarerad med en namnlös typ, används men är aldrig definierad"
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but not defined"
 msgstr "%q#D, deklarerad med en namnlös typ, används men är inte definierad"
@@ -57936,104 +57929,104 @@ msgstr "%q#D, deklarerad med en namnlös typ, används men är inte definierad"
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "namnlös typ utan länkklass används för att deklarera variabeln %q#D med länkklass"
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "namnlös typ utan länkklass används för att deklarera funktionen %q#D med länkklass"
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q#D refererar inte till den okvalificerade typen, så den används int för länkklass"
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q#D, deklarerad med en lokal typ %qT, används men är aldrig definierad"
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr "%q#D, deklarerad med en lokal typ %qT, används men är inte definierad här"
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "typen %qT utan länkklass använd för att deklarera variabeln %q#D med länkklass"
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "typen %qT utan någon länkklass använd för att deklarera funktionen %q#D med länkklass"
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "mangling av %q#D som %qE står i konflikt med en tidigare mangling"
 
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "tidigare mangling %q#D"
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, gcc-internal-format
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr "en senare %<-fabi-version=%> (eller =0) undviker detta fel med en ändring av manglingen"
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr "programmet borde även definiera %qD"
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "inline-funktion %qD använd men aldrig definierad"
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q#D"
 msgstr "standardargumentet saknas för parameter %P till %q#D"
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, gcc-internal-format
 msgid "...following parameter %P which has a default argument"
 msgstr "… följande parameter %P som har ett standardargument"
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, gcc-internal-format
 msgid "implicitly-declared %qD is deprecated"
 msgstr "implicit deklarerad %qD bör undvikas"
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr "för att %qT har användarlevererad %qD"
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "konverterar lambda som använder %<...%> till funktionspekare"
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "användning av borttagen funktion %qD"
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "användning av funktionen %qD med ej uppfyllda begränsningar"
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "användning av det inbyggda parameterpaketet %qD utanför en mall"
@@ -58138,7 +58131,7 @@ msgstr "referens till %<%T::%D%> är tvetydig"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD är inte en medlem av %qT; menade du %qs?"
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD har inte en medlem av %qT"
@@ -58148,7 +58141,7 @@ msgstr "%qD har inte en medlem av %qT"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD är inte en medlem av %qD; menade du %qs?"
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD är inte en medlem av %qD"
@@ -58173,47 +58166,47 @@ msgstr "undantagshantering avslagen, använd %<-fexceptions%> för att aktivera"
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr "kastar NULL, som har heltals-, inte pekartyp"
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, gcc-internal-format
 msgid "  in thrown expression"
 msgstr "  i kastat uttryck"
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, gcc-internal-format
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr "det går inte att deklarera en parameter till %<catch%> att vara av rvalue-referenstyp %qT"
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, gcc-internal-format
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr "det går inte att kasta ett uttryck av typen %qT eftersom typer av variabel storlek är inblandade"
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, gcc-internal-format
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr "det går inte att fånga typen %qT eftersom typer av variabel storlek är inblandade"
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, gcc-internal-format
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr "undantag av typ %qT kommer att fångas av en tidigare hanterare"
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, gcc-internal-format
 msgid "for type %qT"
 msgstr "för typen %qT"
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, gcc-internal-format
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr "%<...%>-hanterare måste vara den sista hanteraren i sitt try-block"
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr "noexcept-uttrycket beräknas till %<false%> på grund av ett anrop till %qD"
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
 msgstr "men %qD kastar inte, kanske den skulle deklareras %<noexcept%>"
@@ -58480,12 +58473,12 @@ msgstr "typ %qT är inte en direkt eller virtuell bas till %qT"
 msgid "type %qT is not a direct base of %qT"
 msgstr "typ %qT är inte en direkt bas till %qT"
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "vektorer måste initieras med en initierare inom klamrar"
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT är inte en klasstyp"
@@ -58500,12 +58493,12 @@ msgstr "ofullständig typ %qT har inte medlem %qD"
 msgid "invalid pointer to bit-field %qD"
 msgstr "ogiltigt pekare till bitfält %qD"
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "ogiltig användning av icke-statisk medlemsfunktion %qD"
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ogiltig användning av icke-statisk datamedlem %qD"
@@ -58700,52 +58693,52 @@ msgstr "radering av objekt av den abstrakta klasstypen %qT som har en ej virtuel
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "radering av objekt av den polymorfa klasstypen %qT som har en ej virtuell destruerare kommer medföra odefinierat beteende"
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "typ till vektor-delete är varken pekar- eller vektortyp"
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr "vektor- och körtidsgränser kan inte fångas av kopiering, endast via referens"
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr "fångst av den variabelt modifierade typen %qT som inte är en N3639-vektor av körtidsgräns"
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr "eftersom vektorelementtypen %qT har variabel storlek"
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "det går inte att fånga %qE via referens"
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "fångst av kopia av ofullständig typ %qT"
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr "försök att fånga %qD i instansiering av en generisk lambda"
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr "implicit fångst av %qE via %<[=]%> bör undvikas i C++20"
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr "lägg till explicit fångst av %<this%> eller %<*this%>"
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> fångades inte för denna lambdafunktion"
@@ -59120,223 +59113,268 @@ msgstr "oväntat inkapslingsformat eller -typ"
 msgid "encapsulation is malformed"
 msgstr "inkapslingen är felgjord"
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, gcc-internal-format
 msgid "conflicting global module declaration %#qD"
 msgstr "motstridande global moduldeklaration %#qD"
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, gcc-internal-format
 msgid "existing declaration %#qD"
 msgstr "befintlig deklaration %#qD"
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, gcc-internal-format
 msgid "definition of %qD does not match"
 msgstr "definitionen av %qD matchar inte"
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, gcc-internal-format
 msgid "existing definition %qD"
 msgstr "befintlig definition %qD"
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, gcc-internal-format
 msgid "... this enumerator %qD"
 msgstr "… denna uppräkningstyp %qD"
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, gcc-internal-format
 msgid "enumerator %qD does not match ..."
 msgstr "uppräkningstypen %qD stämmer inte med …"
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr "ytterligare uppräknare som börjar med %qD"
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr "uppräkningsintervallen skiljer"
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr "%q#D refererar entiteten %q#D med intern länkning"
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, gcc-internal-format
 msgid "recursive lazy load"
 msgstr "rekursiv lat laddning"
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr "det går inte att importera en modul i sin egen räckvidd"
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, gcc-internal-format
 msgid "module %qs declared here"
 msgstr "modulen %qs är deklarerad här"
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, gcc-internal-format
 msgid "indirect import %qs is not already loaded"
 msgstr "indirekt import %qs är inte laddad redan"
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr "import %qs har CRC som inte stämmer"
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr "kan inte representera ytterligare importerade källplatser"
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr "exporterar inte %<#define %E%> eftersom det är ett nyckelord"
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, gcc-internal-format
 msgid "macro definitions of %qE corrupted"
 msgstr "makrodefinitionen av %qE är trasig"
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, gcc-internal-format
 msgid "inconsistent imported macro definition %qE"
 msgstr "inkonsistent importerad makrodefinition %qE"
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr "%<#undef %E%>"
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr "%<#define %s%>"
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, gcc-internal-format
 msgid "compiled module file is %qs"
 msgstr "kompilerad modulfil är %qs"
 
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, gcc-internal-format, gfc-internal-format
 msgid "compiled module is %sversion %s"
 msgstr "kompilerad modul är %sversion %s"
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, gcc-internal-format, gfc-internal-format
 msgid "compiler is %sversion %s%s%s"
 msgstr "kompilatorn är %sversion %s%s%s"
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, gcc-internal-format
 msgid "module %qs found"
 msgstr "modulen %qs finns"
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr "huvudmodul förväntades, modul %qs fanns"
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr "modul %qs förväntades, huvudmodul fanns"
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr "modul %qs har CRC som inte stämmer"
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr "mål & värd är %qs:%qs, %qs:%qs förväntades"
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr "språkdialekten skiljer %qs, %qs förväntades"
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, gcc-internal-format
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr "modulen innehåller OpenMP, använd %<-fopenmp%> för att aktivera"
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, gcc-internal-format
 msgid "fixed tree mismatch"
 msgstr "fixade träd som inte stämde"
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, gcc-internal-format
 msgid "interface partition is not exported"
 msgstr "gränssnittspartitionen exporteras inte"
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module cluster %u: %s"
 msgstr "misslyckades att läsa det kompilerade modulklustret %u: %s"
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module: %s"
 msgstr "misslyckades att läsa en kompilerad modul: %s"
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr "överväg att använda %<-fno-module-lazy%>, att öka värdet på %<-param-lazy-modules=%u%> eller att öka gränsen på beskrivare per process"
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr "importer måste byggas före de importeras"
 
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr "återvänder till grinden för ett mekaniskt problem"
 
-#: cp/module.cc:19283
+#: cp/module.cc:19117
+#, gcc-internal-format
+msgid "declaration %qD conflicts with builtin"
+msgstr "deklarationen %qD står i konflikt med inbyggd"
+
+#: cp/module.cc:19122
+#, gcc-internal-format
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr "omdeklaration av %qD i modulen %qs står i konflikt med import"
+
+#: cp/module.cc:19125
+#, gcc-internal-format
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr "omdeklaration av %qD i den globala modulen står i konflikt med import"
+
+#: cp/module.cc:19130
+#, gcc-internal-format
+msgid "import declared attached to module %qs"
+msgstr "import deklarerad ansluten till modulen %qs"
+
+#: cp/module.cc:19134
+#, gcc-internal-format
+msgid "import declared in global module"
+msgstr "import deklarerad i den globala modulen"
+
+#: cp/module.cc:19140
+#, gcc-internal-format
+msgid "conflicting declaration of %qD in module %qs"
+msgstr "motstridig deklaration av %qD i modulen %qs"
+
+#: cp/module.cc:19143
+#, gcc-internal-format
+msgid "conflicting declaration of %qD in global module"
+msgstr "motstridig deklaration av %qD i den globala modulen"
+
+#: cp/module.cc:19148
+#, gcc-internal-format
+msgid "previously declared in module %qs"
+msgstr "tidigare deklarerad i modulen %qs"
+
+#: cp/module.cc:19152
+#, gcc-internal-format
+msgid "previously declared in global module"
+msgstr "tidigare deklarerad i den globala modulen"
+
+#: cp/module.cc:19404
 #, gcc-internal-format
 msgid "reading CMI %qs"
 msgstr "läser CMI %qs"
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E%>"
 msgstr "misslyckades att ladda bindningen %<%E%s%E%>"
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr "misslyckades att ladda bindningen %<%E%s%E@%s%>"
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr "under laddning av bindningen %<%E%s%E%>"
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr "under laddning av bindningen %<%E%s%E@%s%>"
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, gcc-internal-format
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr "misslyckades att ladda väntande för %<%E%s%E%>"
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, gcc-internal-format
 msgid "during load of pendings for %<%E%s%E%>"
 msgstr "under laddning av väntande för %<%E%s%E%>"
@@ -59348,390 +59386,390 @@ msgstr "under laddning av väntande för %<%E%s%E%>"
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr "import av den namngivna modulen %qs inuti språklänkningsblock"
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, gcc-internal-format
 msgid "module already declared"
 msgstr "modulen är redan deklarerad"
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, gcc-internal-format
 msgid "module already imported"
 msgstr "modulen är redan importerad"
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, gcc-internal-format
 msgid "module %qs imported here"
 msgstr "modulen %qs importerades här"
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown Compiled Module Interface: %s"
 msgstr "okänt kompilerat modulgränssnitt: %s"
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr "det går inte att avgöra %<#include%>-översättning av %s: %s"
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr "inkluderingen %qs översatt till import"
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr "inkluderingen %qs bearbetad textuellt"
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, gcc-internal-format
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr "C++-moduler är inkompatibla med förkompilerade huvuden"
 
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, gcc-internal-format
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr "C++-moduler är inkompatibla med traditionell preprocessning"
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr "makrofelsökningsutdata kan vara ofullständig med moduler"
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr "modulberoenden kräver preprocessning"
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, gcc-internal-format
 msgid "you should use the %<-%s%> option"
 msgstr "du behöver använda flaggan %<-%s%>"
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, gcc-internal-format
 msgid "invalid header name %qs"
 msgstr "felaktigt huvudnamn %qs"
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, gcc-internal-format
 msgid "invalid module name %qs"
 msgstr "felaktig modulnamn %qs"
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr "%<-fmodule-only%> använd för annat än gränssnitt"
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, gcc-internal-format
 msgid "writing CMI %qs"
 msgstr "skriver CMI %qs"
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, gcc-internal-format
 msgid "not writing module %qs due to errors"
 msgstr "skriver inte modulen %qs på grund av fel"
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to write compiled module: %s"
 msgstr "misslyckades att skriva en kompilerad modul: %s"
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, gcc-internal-format
 msgid "unknown header kind %qs"
 msgstr "okänd huvudsort %qs"
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, gcc-internal-format
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr "namnoberoende deklarationer är endast tillgängliga med %<-std=c++2c%> eller %<-std=gnu++2c%>"
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "omdeklaration av %q#D med andra mallparametrar"
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D står i konflikt med tidigare deklaration"
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D döljer konstruerare för %q#D"
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "motstridande deklaration av C-länkning av %q#D"
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "på grund av olika undantagsspecifikationer"
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "lambdaparametern %qD är deklarerad tidigare som en fångst"
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "deklaration av %q#D skuggar en parameter"
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "deklarationen av %qD skuggar en medlem av %qT"
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "vändeklaration %qD i lokal klass utan en tidigare lokal deklaration"
 
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %<%s(%E)%> %p %d"
 
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d"
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, gcc-internal-format
 msgid "exporting %q#D that does not have external linkage"
 msgstr "exporterar %q#D som inte har extern länkning"
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, gcc-internal-format
 msgid "%q#D declared here with no linkage"
 msgstr "%q#D är deklarerad här utan någon länkning"
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, gcc-internal-format
 msgid "%q#D declared here with internal linkage"
 msgstr "%q#D är deklarerad här med intern länkning"
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, gcc-internal-format
 msgid "%q#D declared here with module linkage"
 msgstr "%q#D är deklarerad här med modullänkning"
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T%s%D%> namnger en destruerare"
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "using-deklaration för icke-medlem vid klassräckvidd"
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<using%> med uppräkningsräckvidd %q#T är endast tillgängligt med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qT är inte en klass, namnrymd eller uppräkning"
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "icke-medlems using-deklaration namnger konstrueraren för %qT"
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "using-deklaration för medlem vid icke-klass-räckvidd"
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, gcc-internal-format
 msgid "%qT is not a direct base of %qT"
 msgstr "%qT är inte en direkt bas till %qT"
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr "menade du %<using enum %T::%D%>?"
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "%qD har inte deklarerats i %qD"
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "en using-deklaration får inte namnge namnrymden %qD"
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> namnger konstruerare i %qT"
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "deklaration av %qD inte i namnrymd som omger %qD"
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "explicit-kvalifikation i deklaration av %qD"
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD borde ha deklarerats inuti %qD"
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD har inte deklarerats inom %qD"
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "endast här som %<friend%>"
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "attributet %qD kräver ett ensamt NTBS-argument"
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "attributet %qD är meningslöst eftersom medlemmar av den anonyma namnrymden får lokala symboler"
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "ignorerar attributet %qD på en anonym namnrymd"
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "ignorerar attributet %qD på en namnrymd som inte är inline"
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "attributdirektivet %qD ignorerat"
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "maxgräns på %d namnrymder sökta %qE"
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "föreslaget alternativ:"
 msgstr[1] "föreslagna alternativ:"
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr "%<std::%s%> är definierad i huvudet %qs; detta går förmodligen att lösa genom att lägga till %<#include %s%>"
 
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<std::%s%> är bara tillgänglig från %s och framåt"
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "makrot %qs har inte definierats ännu"
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr "det definierades senare här"
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "definitionen av %<std::initializer_list%> matchar inte %<#include <initializer_list>%>, är inte en mall"
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "ett %<strong%> using-direktiv stödjs inte längre"
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr "du kan använda en inline-namnrymd istället"
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, gcc-internal-format
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr "%<omp::%E%> är inte tillåtet att anges i detta sammanhang"
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "det går inte att nästa mer än %d namnrymder"
 
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%<namespace %E%> är tvetydig"
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "namnrymdsalias %qD inte tillåtet här, antar %qD"
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "inline-namnrymder måste anges vid den ursprungliga definitionen"
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD definierades här"
 
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%s-namnrymd %qD står i konflikt med nåbar definition"
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "nåbar %s-definition här"
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX går in i %<pop_everything ()%>"
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr "XXX lämnar %<pop_everything ()%>"
@@ -59756,7 +59794,7 @@ msgstr "identifieraren %qE är ett nyckelord i C++20"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr "%<LEXER_DEBUGGING_ENABLED_P%> är inte satt till true"
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> som inte omedelbart följs av en funktionsdeklaration eller -definition"
@@ -60002,7 +60040,7 @@ msgstr "C++20 %<constinit%> är endast tillgängligt med %<-std=c++20%> eller %<
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<concept%> är endast tillgängligt med %<-std=c++20%> eller %<-fconcepts%>"
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<requires%> är endast tillgängligt med %<-std=c++20%> eller %<-fconcepts%>"
@@ -60182,7 +60220,7 @@ msgstr "satsuttryck är inte tillåtna utanför funktioner eller i mallargumentl
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "vikningsuttryck är endast tillgängliga med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "primäruttryck förväntades"
@@ -60238,7 +60276,7 @@ msgid "template-id not allowed for destructor in C++20"
 msgstr "mall-id är inte tillåtet för destruerare i C++20"
 
 # %qs blir den fixa strängen "< >"
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, gcc-internal-format
 msgid "remove the %qs"
 msgstr "ta bort %qs"
@@ -60258,7 +60296,7 @@ msgstr "typedef-namnet %qD använt som destruerardeklarerare"
 msgid "expected unqualified-id"
 msgstr "okvalificerat id förväntades"
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD är inte en mall"
@@ -60308,7 +60346,7 @@ msgstr "typer får inte definieras i ett %<typeid%>-uttryck"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "fel antal argument till %<__builtin_addressof%>"
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "fel antal argument till %<__builtin_launder%>"
@@ -60343,7 +60381,7 @@ msgstr "typer får inte definieras inuti anrop av %<__builtin_classify_type%>"
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr "kan inte använda multidimensionellt index i OpenMP-vektorsektionen"
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "ogiltig användning av %qD"
@@ -60368,7 +60406,7 @@ msgstr "ISO C++ tillåter inte %<alignof%> med annat än en typ"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "typer får inte definieras i %<noexcept%>-uttryck"
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "typer får inte definieras i en %qs-uttryck"
@@ -60518,8 +60556,8 @@ msgstr "tom initierare för lambdas init-fångst"
 msgid "capture of non-variable %qE"
 msgstr "fångst av en icke-variabel %qE"
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D är deklarerad här"
@@ -60559,7 +60597,7 @@ msgstr "standardargumentet angivet för lambdaparameter"
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "en parameterdeklaration före lambdadeklarationsspecificerare är endast valfritt med %<-std=c++2b%> eller %<-std=gnu++2b%>"
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr "ett lambda med fångster kan inte ha en explicit objektparameter av en orelaterad typ"
@@ -60684,7 +60722,7 @@ msgstr "%<if consteval%> kräver en sammansatt sats"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "init-satsen i valsatser är endast tillgängliga med %<-std=c++17%> eller %<-std=gnu++17%>"
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "selektionssats förväntades"
@@ -60746,7 +60784,7 @@ msgstr "intervallbaserat %<for%>-uttryck av typen %qT har ofullständig typ"
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "inkonsistenta start-/sluttyper i intervallbaserad %<for%>-sats: %qT och %qT"
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "iterationssats förväntades"
@@ -60772,7 +60810,7 @@ msgstr "%<goto%> i %<constexpr%>-funktioner är endast tillgängligt med %<-std=
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ förbjuder beräknade goto"
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "hoppsats förväntades"
@@ -61053,12 +61091,12 @@ msgstr "endast konstruerare tar medlemsinitierare"
 msgid "cannot expand initializer for member %qD"
 msgstr "det går inte att expandera initierare för medlem %qD"
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "minnesinitierare för %qD följer en konstruerardelegering"
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "konstruerardelegering följer mem-initierare för %qD"
@@ -61696,7 +61734,7 @@ msgstr "mallargument saknas efter %qE"
 msgid "%qT not permitted in template argument"
 msgstr "%qT är inte tillåtet i mallargument"
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, gcc-internal-format
 msgid "invalid use of %qT"
@@ -61875,12 +61913,12 @@ msgstr "föregående definition av %q#T"
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, gcc-internal-format
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr "oexpanderat parameterpack i en lokal klass i lambda"
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "klassnyckel förväntades"
@@ -62082,37 +62120,37 @@ msgstr "attribut som använder prefix är endast tillgängligt med %<-std=c++17%
 msgid "expression must be enclosed in parentheses"
 msgstr "uttrycket måste vara inneslutet i parenteser"
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr "ytterligare %<requires%> saknas för att inleda ett requires-uttryck"
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr "testar om ett koncept-id är ett giltigt uttryck; lägg till %<requires%> för att kontrollera uppfyllnad"
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr "resultattypen är inte en enkel typbegränsning"
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "returtypskravet är inte en typbegränsning"
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "specialisering av medlem %<%T::%E%> kräver %<template<>%>-syntax"
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ogiltig omdeklaration av %<%T::%E%>"
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "för få mallparameterlistor"
@@ -62121,438 +62159,438 @@ msgstr "för få mallparameterlistor"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "för många mallparameterlistor"
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, gcc-internal-format
 msgid "template-id not allowed for constructor in C++20"
 msgstr "mall-id är inte tillåtet för konstruerare i C++20"
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "namngivna returvärden stödjs inte längre"
 
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr "ISO C++ antog inte mallar för stränglitteralsoperatorer som tar argumentpaket av tecken"
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "den litterala operatormallen %qD har ogiltig parameterlista; ett mallargument som inte är en typ pack %<<char...>%> eller en ensam icke-typparameter av klasstyp förväntades"
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "den litterala operatormallen %qD har ogiltig parameterlista; en mallparameter som inte är en typ pack %<<char...>%> förväntades"
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr "mallintroduktioner är inte en del av C++20 koncept; använd %qs för att aktivera"
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "det finns inget matchande koncept för mallintroduktionen"
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "ogiltig deklaration av medlemsmall i lokal klass"
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "mall med C-länkning"
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ogiltig explicit specifikation"
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "malldeklaration av %<typedef%>"
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "en klassmallsdeklaration får inte deklarera något annat"
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "explicit mallspecialisering kan inte ha en lagringsklass"
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> skulle vara %<> >%> inuti en nästad mallargumentlista"
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "vilsekommet %<>>%>, använd %<>%> för att avsluta en mallargumentlista"
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, gcc-internal-format
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr "%qs skall vara %qs för att avsluta en mallargumentlista"
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "argument till %<sizeof...%> måste omges av parenteser"
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ogiltig användning av %qD i länkklasspecifikation"
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, gcc-internal-format
 msgid "duplicate %qD specifier"
 msgstr "dubblerade %qD-specificerare"
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, gcc-internal-format
 msgid "%qD specifier conflicts with %qs"
 msgstr "%qD-specificerare står i konflikt med %qs"
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> före %qD"
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, gcc-internal-format
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr "%qD-specificerare står i konflikt med %<typedef%>"
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 stödjer inte %<long long%>"
 
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "både %<__thread%> och %<thread_local%> angivna"
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "dubblerad %qD"
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "dubblerad %qs"
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> förväntades"
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> förväntades"
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> förväntades"
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> förväntades"
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> förväntades"
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> förväntades"
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> förväntades"
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> förväntades"
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> förväntades"
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> förväntades"
 
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> förväntades"
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> förväntades"
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> förväntades"
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> förväntades"
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> förväntades"
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "%<auto%> förväntades"
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> förväntades"
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> förväntades"
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> förväntades"
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> förväntades"
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> förväntades"
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> förväntades"
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "%<co_yield%> förväntades"
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> förväntades"
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> förväntades"
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> förväntades"
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> förväntades"
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> eller %<::%> förväntades"
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> eller %<template%> förväntades"
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr "överflödig enum-nyckel %<enum%s%> i referens till %q#T"
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs-tagg använd vid namngivning av %q#T"
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T deklarerades tidigare här"
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "överflödig klassnyckel %qs i referens till %q#T"
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT är deklarerad med en klassnyckel som inte stämmer %qs"
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr "ta bort klassnyckeln eller ersätt den med %qs"
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "ersätt klassnyckeln med %qs"
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "%qT är definierad som %qs här"
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "%qT är först deklarerad som %qs här"
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD omdeklarerad med annan åtkomst"
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "i C++98 är %<template%> (för att lösa upp tvetydighet) är endast tillåtet inuti mallar"
 
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "filen slutar i standardargument"
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "felplacerad Objective-C++-konstruktion %<@%D%>"
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c++-meddelandemottagare förväntades"
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++-meddelandeargument förväntades"
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> måste ange en typ som ett argument"
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "ogiltigt Objective-C++-väljarnamn"
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "metoddeklaration i objective-c++ förväntades"
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "metodattribut måste anges på slutet"
 
 # %qs blir "{" eller "}"
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "vilsekommet %qs mellan Objective-C++ metoder"
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "ogiltig typ för iterationsvariabel"
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "identifierare förväntades efter %<@protocol%>"
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "attribut får inte anges före Objective-C++-nyckelordet %<@%D%>"
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "prefixattribut ignoreras före %<@%D%>"
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ogiltig typ på egenskap"
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr "okänt egenskapsattribut %qE"
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "heltalsuttryckslista förväntades"
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%<wait%>-uttryck måste vara heltal"
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr "%<scalar%>, %<aggregate%>, %<all%> förväntades"
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ogiltig reduktionsidentifierare"
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "typer får inte definieras i iteratortyp"
@@ -62561,12 +62599,12 @@ msgstr "typer får inte definieras i iteratortyp"
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "%<#pragma omp allocate%> stödjs inte ännu"
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "initiering i parenteser är inte tillåtet i en OpenMP-%<for%>-slinga"
@@ -62576,133 +62614,133 @@ msgstr "initiering i parenteser är inte tillåtet i en OpenMP-%<for%>-slinga"
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "en %<ordered%>-klausul med parameter på en intervallbaserad %<for%>-slinga"
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "iterationsvariabel %qD skall inte vara reduction"
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp declare %s%> följt av %<#pragma omp declare %s%>"
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr "OpenMP-direktiv andra än %<declare simd%> eller %<declare variant%> hör till en deklaration"
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ogiltig initierarklausul"
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "id-uttryck förväntades (argument)"
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "en av initieraranropets argument skall vara %<omp_priv%> eller %<&omp_priv%>"
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "typer får inte definieras i en declare reduction-typlista"
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "en fördeklarerad aritmetisk typ %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "funktions- eller vektortyp %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "referenstyp %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "%<const%>-, %<volatile%>- eller %<__restrict%>-kvalificerad typ %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> namnger en mängd överlagrade"
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD refererar inte till en funktion med namnrymdsräckvidd"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr "%<atomic_cancel%>"
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> utan stöd för transaktionsminne aktiverat"
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> utan stöd för transaktionsminne aktiverat"
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "yttre %<__transaction_cancel%> som inte är inom en yttre %<__transaction_atomic%>"
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  eller en %<transaction_may_cancel_outer%>-funktion"
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "felformat %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp requires%> kan endast användas med fil- eller namnrymdsräckvidd"
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, gcc-internal-format
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp assumes%> kan endast användas med fil- eller namnrymdsräckvidd"
 
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, gcc-internal-format
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr "%<#pragma GCC %s%> måste vara inuti en funktion"
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr "flerkällskompileringar är inte implementerade för C++"
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "en platshållartyp är inte tillåtet i denna kontext"
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "implicita mallar får inte vara %<virtual%>"
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr "%<extern \"C\"%>-länkning startade här"
@@ -62732,7 +62770,7 @@ msgstr "inneslutande klassmallar är inte explicit specialiserade"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "specialisering av %qD i förekomma i namnrymdsräckvidd"
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "specialisering av %qD i en annan namnrymd"
@@ -62747,170 +62785,170 @@ msgstr "  från definitionen av %q#D"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "explicit instansiering av %qD i namnrymden %qD (som inte omsluter namnrymden %qD)"
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "namn på klass skuggar mallmallparameter %qD"
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "specialisering av aliasmall %qD"
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "explicit specialisering av icke-mall %qT"
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "specialisering av %qT efter instansiering"
 
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, gcc-internal-format
 msgid "from definition of %q#D"
 msgstr "från definitionen av %q#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "specialisering %qT efter instansiering %qT"
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "mallspecialisering av %qD är inte tillåten av ISO C++"
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "specialisering av %qD efter instansiering"
 
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %#qD"
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD är inte en funktionsmall"
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD är inte en variabelmall"
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "mall-id %qD för %q+D stämmer inte med någon malldeklaration"
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "såg %d %<template<>%>, behöver %d för specialisering av medlemsfunktionsmall"
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "tvetydig mallspecialisering %qD för %q+D"
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "variabelmallar är endast tillgängliga med %<-std=c++14%> eller %<-std=gnu++14%>"
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "fel antal mallhuvuden för %qD (skulle vara %d)"
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr "medlemmar av en explicit specialiserad klass definieras utan ett mallhuvud"
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "explicit specialisering av %qD utanför dess namnrymd måste använda en nästat-namn-specificerare"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "explicit instansiering av %qD utanför dess namnrymd måste använda en nästat-namn-specificerare"
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "explicit specialisering %q#D kan sakna attribut"
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "primära mallattribut %s saknas"
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "primärt mallattribut %s saknas"
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr "mall-id %qE i deklaration av primär mall"
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "mallparameterlista använd i explicit instansiering"
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "definition given för explicit instansiering"
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "för många mallparameterlistor i deklarationen av %qD"
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "för få mallparameterlistor i deklarationen av %qD"
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "explicit specialisering av %qD måste inledas av %<template <>%>"
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "explicit specialisering  deklarerad %<concept%>"
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "partiell specialisering som inte är en typ av %qE är inte tillåten"
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "partiell specialisering som inte är en klass eller variabel av %qE är inte tillåten"
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "standardargument angivet i explicit specialisering"
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD är inte en mallfunktion"
@@ -62923,154 +62961,154 @@ msgstr "%qD är inte en mallfunktion"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "specialisering av implicit deklarerad specialmedlemsfunktion"
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "ingen medlemsfunktion %qD är deklarerad i %qT"
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "vändeklarationen %qD är inte synlig för en explicit specialisering"
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, gcc-internal-format
 msgid "friend declaration here"
 msgstr "vändeklarationen här"
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "explicit specialisering av funktionskonceptet %qD"
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "argument till %<__integer_pack%> måste vara mellan 0 och %d"
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "basinitierarexpansionen %qT innehåller inga parameterpaket"
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "expansionsmönster %qT innehåller inga parameterpaket"
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "expansionsmönster %qE innehåller inga parameterpaket"
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "parameterpaket expanderas inte med %<...%>:"
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr "        %s"
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "deklaration av mallparametern %q+D skuggar en mallparameter"
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "deklaration av %q+#D skuggar en mallparameter"
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "mallparametern %qD deklarerad här"
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "specialisering av variabelkonceptet %q#D"
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "mallparameter är inte härledbara i partiell specialisering:"
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "partiell specialisering %q+D specialiserar inte något mallargument; för att definiera den primära mallen, ta bort mallargumentlistan"
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "partiell specialisering %q+D specialiserar inte något mallargument och är inte mer begränsad än den primära mallen; för att definiera den primära mallen, ta bort mallargumentlistan"
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "huvudmall här"
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "partiell specialisering är inte mer specialiserad än huvudmallen eftersom den ersätter flera parametrar med en paketexpansion"
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "för många argument till en partiell specialisering %qT"
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "partiell specialisering %qD är inte mer specialiserad än"
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "huvudmallen %qD"
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "parameterpaketargument %qE måste vara vid slutet av mallens argumentlista"
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "parameterpaketargument %qT måste vara vid slutet av mallens argumentlista"
 
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "typ %qT för mallargument %qE beror på en mallparameter"
 msgstr[1] "typ %qT för mallargument %qE beror på mallparametrar"
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "deklaration av %qD gör tidigare mallinstansiering av %qD tvetydig"
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "partiell specialisering %qD efter instansiering av %qD"
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "inget standardargument för %qD"
@@ -63079,47 +63117,47 @@ msgstr "inget standardargument för %qD"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "parameterpaket %q+D måste vara vid slutet av mallens parameterlista"
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "standardmallargument får inte användas i vänomdeklaration av funktionsmall"
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "standardmallargument får inte användas i vändeklarerade mallar"
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "standarmallargument får inte användas i funktionsmallar utan %<-std=c++11%> eller %<-std=gnu++11%>"
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "standardmallargument får inte användas i partiella specialiseringar"
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "standardargumentet för mallparameter för klass om omsluter %qD"
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "mallen %qD deklarerad"
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "mallklass utan ett namn"
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "medlemsmallen %qD kan inte ha virt-specificerare"
@@ -63129,506 +63167,506 @@ msgstr "medlemsmallen %qD kan inte ha virt-specificerare"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "ogiltig malldeklaration av %qD"
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "malldefinition av icke-mall %q#D"
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "%d nivåer av mallparametrar förväntades till %q#D, %d fanns"
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "fick %d mallparametrar till %q#D"
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "fick %d mallparametrar till %q#T"
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  men %d behövs"
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "mallargument till %qD stämmer inte med originalmallen %qD"
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "använd %<template<>%> för en explicit specialisering"
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, gcc-internal-format
 msgid "redeclaration of %qD with different constraints"
 msgstr "omdeklaration av %qD med andra begränsningar"
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT är inte en malltyp"
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "mallspecificerare inte angivna i deklarationen av %qD"
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "omdeklarerad med %d mallparameter"
 msgstr[1] "omdeklarerad med %d mallparametrar"
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "tidigare deklaration av %qD använde %d mallparameter"
 msgstr[1] "tidigare deklaration av %qD använde %d mallparametrar"
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "mallparameter %q+#D"
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "omdeklarerad här som %q#D"
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, gcc-internal-format
 msgid "redeclared here"
 msgstr "omdeklarerad här"
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "deklaration av mallparametern %q+#D med andra begränsningar"
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "ursprunglig deklaration fanns här"
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, gcc-internal-format
 msgid "redeclaration of %q#D with different constraints"
 msgstr "omdeklaration av %q#D med andra begränsningar"
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT"
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "det måste vara adressen till en funktion med extern lagringsklass"
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "det måste vara namnet på en funktion med extern lagringsklass"
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom %qD inte har någon länkklass"
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qD inte har extern länkklass"
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "det måste vara en pekare-till-medlem på formen %<&X::Y%>"
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "för att den är en medlem av %qT"
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  kunde inte härleda mallparametrar %qD"
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  typerna %qT och %qT har inkompatibla cv-kvalificerare"
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  typerna %qT och %qT stämmer inte överens"
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  mallparameter %qD är inte ett parameterpaket, men argument %qD är det"
 
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  mallargument %qE stämmer inte med pekare till medlem-konstanten %qE"
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE är inte ekvivalent med %qE"
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  inkonsistent härledning av parameterpaket med %qT och %qT"
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  härledda typer i konflikt för parametern %qT (T%qT och %qT)"
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  härledda värden i konflikt för icke-typ-parametern %qE (%qE och %qE)"
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  vektortypen %qT med variabel storlek är inte ett giltigt mallargument"
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  medlemsfunktionstypen %qT är inte ett giltigt mallargument"
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  kan inte konvertera %qE (typen %qT) till typ %qT"
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT är en tvetydig basklass till %qT"
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT är inte härledd från %qT"
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  mallparametrarna till ett mallmallargument är inkonsistenta med andra härledda mallargument"
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  det går inte att härleda en mall för %qT från typen %qT som inte är en mall"
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "  mallargument %qE stämmer inte med %qE"
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qE inte är en variabel eller funktion"
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE är inte ett giltigt mallargument av typ %qT i C++98 eftersom %qD inte har extern länkklass"
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qD inte har någon länkklass"
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "adressen till %qD är inte ett giltigt mallargument"
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "adressen till underobjektet %qT till %qD är inte ett giltigt mallargument"
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "adressen till %qD är inte ett giltigt mallargument eftersom den inte har statisk lagringsvaraktighet"
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD är inte ett giltigt mallargument för att %qD är en variabel, inte adressen till en variabel"
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE är inte ett giltigt mallargument till %qT för det är inte adressen till en variabel"
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom strängkonstanter aldrig kan användas i detta sammanhang"
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "i mallargument för typen %qT"
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "mallargumentet %qE för typen %qT är inte ett kompileringstidskonstant"
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom det står i konflikt med cv-kvalificeringar"
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom inte är ett l-värde"
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D är inte ett giltigt mallargument till typen %qT eftersom en referensvariabel inte har en konstant adress"
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom det är en pekare"
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "försök att använda %qE istället"
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom det är av typen %qT"
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "ignorerar attribut på mallargumentet %qT"
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "ignorerar attribut i mallargumentet %qE"
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "inskjutet klassnamn %qD använt som mallmallargument"
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ogiltig användning av destrueraren %qE som en typ"
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "för att referera till en typmedlem av en mallparameter, använd %<typename %E%>"
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "typ/värde stämmer inte vid argument %d i mallparameterlistan till %qD"
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  förväntade en konstant av typen %qT, fick %qT"
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "  tvetydigt mallargument till en mallparameter som inte är en typ hanteras som en funktionstyp"
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  förväntade en klassmall, fick %qE"
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  förväntade en typ, fick %qE"
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  förväntade en typ, fick %qT"
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  förväntade en klassmall, fick %qT"
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  förväntade en mall av typen %qD, fick %qT"
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "begränsningar stämmer inte vid argument %d i mallparameterlistan till %qD"
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  %qD förväntades men fick %qD"
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "kunde inte konvertera mallargument %qE från %qT till %qT"
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "mallargument %d är ogiltigt"
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "fel antal mallargument (%d, skulle vara %d)"
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "fel antal mallargument (%d, skulle vara åtminstone %d)"
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "angivna till %qD"
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "pack-expansionsargument för icke-pack-parametern %qD till aliasmall %qD"
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "pack-expansionsargument för icke-pack-parametern %qD till konceptet %qD"
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "så varje instansiering med ett icke-tomt parameterpaket vore felformulerad"
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D är inte en funktionsmall"
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "icke-malltyp %qT använd som en mall"
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "för malldeklaration %q+D"
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "mallbegränsningsfel för %qD"
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "användning av felaktig variabelmall %qE"
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "mallinstansieringsdjupet överskrider maxvärdet på %d (använd %<-ftemplate-depth=%> för att öka maxvärdet)"
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "värdesargument måste vara ett konstant heltalsuttryck"
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "värdesargumentet måste vara ickenegativt"
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "egenskaper måste vara ett konstant heltalsuttryck eller en strängkonstant"
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "flexibel vektormedlem %qD i union"
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "fold över tom expansion över %O"
 
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE är inte hela mönstret av paketexpansionen"
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "argumentpaketlängder stämmer inte överens vid expansion av %qT"
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "argumentpaketlängder stämmer inte överens vid expansion av %qE"
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "  vid instansiering av standardargument för anrop av %qD"
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "skapar pekare till medlemsfunktion i typ %qT som inte är en klass"
 
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, gcc-internal-format, gfc-internal-format
 msgid "mismatched argument pack lengths (%d vs %d)"
 msgstr "argumentpaketlängder stämmer inte överens (%d mot %d)"
@@ -63646,301 +63684,301 @@ msgstr "argumentpaketlängder stämmer inte överens (%d mot %d)"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabeln %qD har funktionstyp"
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ogiltig parametertyp %qT"
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "i deklaration %q+D"
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "funktion som returnerar en vektor"
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "funktion som returnerar en funktion"
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "formar referens till void"
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "formar pekare till en referenstyp %qT"
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "formar referens till en referenstyp %qT"
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "formerar en pekare till en kvalificerad funktionstyp %qT"
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "formerar en referens till en kvalificerad funktionstyp %qT"
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "skapar pekare till medlem av typ %qT som inte är en klass"
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "skapar pekare till medlemsreferenstyp %qT"
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "skapar pekare till medlem av typ void"
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "skapar vektor av %qT"
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr "%qD instansieras för ett tomt paket"
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT är inte en klass-, post- eller unionstyp"
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT slås upp till %qT som inte är en uppräkningstyp"
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT löses upp till %qT, som inte är en klasstyp"
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "användning av %qs i mall"
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "kvalificerande typ %qT matchar inte destruerarnamnet ~%qT"
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "namnet %qE i den beroende tolkas som något annat än en typ, men instansiering ger en typ"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "säg %<typename %E%> om en typ avses"
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "initierare för %q#D expanderar till en tom uttryckslista"
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "ogiltig användning av paketexpansionsuttryck"
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "använd %<...%> för att expandera argumentpaket"
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "tom initierare i lambdas init-fångst"
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD deklarerades inte i detta definitionsområde, och inga deklarationer hittades av en argumentberoende uppslagning vid instansieringspunkten"
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "deklarationer i beroende bas %qT hittas inte av en okvalificerad uppslagning"
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "använd %<this->%D%> istället"
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "använd %<%T::%D%> istället"
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD är deklarerad här, senare i översättningsenheten"
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "fel antal argument till %<__builtin_convertvector%>"
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, gcc-internal-format
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "fel antal argument till attributet %<assume%>"
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT är inte en klass eller namnrymd"
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD är inte en klass eller namnrymd"
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "användning av ogiltigt fält %qD"
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT är/använder en namnlös typ"
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "mallargumentet för %qD använder lokal typ %qT"
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT är en variabel typ"
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "heltalsuttryck %qE är inte konstant"
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  försöker instansiera %qD"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "tvetydig mallinstansiering av %q#T"
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "tvetydig mallinstansiering av %q#D"
 
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "explicit instansiering av icke-mall %q#D"
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "explicit instansiering av variabelkonceptet %q#D"
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "explicit instansiering av funktionskonceptet %q#D"
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD är inte en statisk datamedlem i en klassmall"
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "det finns ingen matchande mall för %qD"
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "typ %qT för explicit instansiering %qD stämmer inte med deklarerad typ %qT"
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "explicit instansiering av %q#D"
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "dubblerad explicit instansiering av %q#D"
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 förbjuder användning av %<extern%> vid explicita instansieringar"
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "lagringsklass %qD tillämpad på mallinstansiering"
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "explicit instansieringar av mallen %q#D som inte är en klass"
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "explicit instansieringar av icke-malltyp %qT"
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "explicit instansiering av %q#T före definitionen av mallen"
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ förbjuder användning av %qE vid explicita instansieringar"
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "dubblerad explicit instansiering av %q#T"
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "explicit specifikation av %qD beror på sig själv"
@@ -63952,163 +63990,163 @@ msgstr "explicit specifikation av %qD beror på sig själv"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "explicit instansiering av %qD men ingen definition tillgänglig"
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "mallinstansieringsdjupet överskrider maxvärdet på %d vid instansiering av %q+D, möjligen från generering av virtuell tabell (använd %<-ftemplate-depth=%> för att öka maxvärdet)"
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "mallparameter av härledd klasstyp som inte är en typ är endast tillgängligt med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%qT är inte en giltig typ för en mallparameter som inte är en typ eftersom det inte är en struktur"
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "mallparameter av klasstyp som inte är en typ är endast tillgängligt med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "ogiltig mallparameter som inte är en typ"
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T är inte en giltig typ för en mallparameter som inte är en typ"
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "nyckelordet %<template%> är inte tillåtet i deklarerar-id"
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "ett koncept kan inte begränsas"
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "konceptet %qE är inte i namnrymdsräckvidd"
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr "konceptet %qE har multipla mallparameterlistor"
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "härledning från klammeromsluten initierarlista kräver %<#include <initializer_list>%>"
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "icke härledbar mall %qT använd utan mallargument"
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "aliasmallhärledning är endast tillgängligt med %<-std=c++20%> eller %<-std=gnu++20%>"
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr "använd %qD direkt istället"
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "kan inte härleda mallargument för kopieinitiering av %qT, eftersom den inte har några icke-explicita härledningsguider eller användardeklarerade konstruerare"
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "kan inte härleda mallargument till %qT, eftersom den inte några användbara härledningsguider"
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "härledning av klassmallargument misslyckades:"
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "explicita härledningsguider övervägs inte vid kopieinitiering"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "klassmallargumentshärledningen för %qT misslyckades: explicit härledningsguide vald i kopieringslistinitiering"
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "explicit härledningsguide deklarerad här"
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "%qT är kanske inte avsett att stödja härledning av klassmallargument"
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr "lägg till en härledningsguide för att undertrycka denna varning"
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direkt listinitiering av %<auto%> tar precis ett element"
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "för härledning till %<std::initializer_list%>, använd kopielistinitiering (d.v.s. lägg till %<=%> före %<{%>)"
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "kan inte härleda lambdareturtyp från %qE"
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "kan inte härleda %qT från %qE"
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "platshållarbegränsningar är inte uppfyllt"
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "härledd initierare uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "härledd returtyp uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "härledd uttryckstyp uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "felaktig användning av %qT i mallargument"
@@ -64314,630 +64352,630 @@ msgstr "typen på %<asm%>-operanden %qE kunde inte avgöras"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "%<__label__%>-deklarationer får bara förekomma på funktionsnivå"
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "ogiltig användning av %qD i en statisk medlemsfunktion"
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, gcc-internal-format
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr "ogiltig användning av %qD i ett konsturearar-%<pre%>-kontrakt"
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, gcc-internal-format
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr "ogiltig användning av %qD i ett destruerar-%<post%>-kontrakt"
 
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr "%qE mallargument saknas"
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr "ett satsuttryck är otillräckligt sammanhang för upplösning av överlagring"
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr "det går inte att anropa ett koncept som en funktion"
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "argument till destruerare är inte tillåtet"
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, gcc-internal-format
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr "%<this%> är inte tillgängligt i explicita objektmedlemsfunktioner"
 
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, gcc-internal-format
 msgid "use explicit object parameter %qs instead"
 msgstr "använd en explicit objektparameter %qs istället"
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, gcc-internal-format
 msgid "name the explicit object parameter"
 msgstr "namnge den explicita objektdparametern"
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> är inte tillgängligt i en statisk medlemsfunktion"
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, gcc-internal-format
 msgid "invalid use of %<this%> before it is valid"
 msgstr "ogiltig användning av %<this%> före det är giltigt"
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, gcc-internal-format
 msgid "invalid use of %<this%> after it is valid"
 msgstr "ogiltig användning av %<this%> efter att det är giltigt"
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "ogiltig användning av %<this%> i icke-medlemsfunktion"
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "ogiltig användning av %<this%> på toppnivå"
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ogiltigt kvalificerande räckvidd i pseudodestruerarnamn"
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "kvalificerad typ %qT matchar inte destruerarnamnet ~%qT"
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE har inte typen %qT"
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "sammansatt litteral för ej objekttyp %qT"
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, gcc-internal-format
 msgid "%<auto{x}%> cannot be constrained"
 msgstr "%<auto{x}%> kan inte begränsas"
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, gcc-internal-format
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<auto{x}%> är endast tillgängligt med %<-std=c++2b%> eller %<-std=gnu++2b%>"
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "malltypparametrar måste använda nyckelordet %<class%> eller %<typename%>"
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "ogiltig användning av typ %qT som standardvärde för en mallmallparameter"
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "ogiltigt standardargument för en mallmallparameter"
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "definition av %q#T inuti mallparameterlista"
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "ogiltig definition av kvalificerad typ %qT"
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "ogiltig basklasspecifikation"
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "kan inte fånga medlemmen %qD i anonym union"
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD är inte fångad"
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "lambdat har ingen standardfångst"
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr "lambda i lokal klass %q+T kan inte fånga variabler från det omgivande sammanhanget"
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "användning av lokal variabel med automatisk lagringsklass från en kringliggande funktion"
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "användning av parameter från den kringliggande funktionen"
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "användning av parameter utanför funktionskroppen"
 
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr "mallargument saknas"
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "mallparameter %qD av typ %qT är inte tillåten i ett konstant heltalsuttryck eftersom den inte är av heltals- eller uppräkningstyp"
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "användning av klassmall %qT som uttryck"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "begäran av medlem %qD är tvetydig i gitter av multipelt arv"
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD får inte finnas i ett konstantuttryck"
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "typen på %qE är okänd"
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT är inte ett uppräkningstyp"
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr "indexet till %<__type_pack_element%> är inte en heltalskonstant"
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr "indexet till %<__type_pack_element%> är negativt"
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is out of range"
 msgstr "indexet till %<__type_pack_element%> är utanför intervallet"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "parameterpaketets %<__bases%> är endast giltiga i malldeklarationer"
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "det går inte att applicera %<offsetof%> på destrueraren %<~%T%>"
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "det går inte att använda %<offsetof%> på medlemsfunktion %qD"
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "det går inte att använda %<offsetof%> på en medlemsfunktion"
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "det går inte att använda %<offsetof%> på en uppräknare %qD"
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr "%<offsetof%> inom icke-standardlayouttypen %qT är villkorligt stött"
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, gcc-internal-format
 msgid "pointer-to-member mapping %qE not supported"
 msgstr "pekar-till-medlems-avbildningen %qE stödjs ej"
 
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "användardefinierad reduktionsuppslagning är tvetydig"
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "%qE i %<reduction%>-klausul är en vektor med storlek noll"
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE har const-typ för %<reduction%>"
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "användardefinierad reduktion med konstruerarinitierare för basklassen %qT"
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, gcc-internal-format
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr "en annan modifierare än %<val%> ingiven i en %<linear%>-klausul på %<simd%>- eller %<for%>-konstruktioner när OpenMP 5.2-modifierare används"
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr "linjär klausul med modifieraren %qs tillämpad på en variabel som inte är en referens med typen %qT"
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "linjär klausul tillämpad på en variabel som inte är heltal och inte pekare med typen %qT"
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "ett linjärt steguttryck måste vara ett heltal"
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> tillåtet i OpenMP endast i %<declare simd%>-klausuler"
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD är inte en variabel i klausul %qs"
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD är inte en variabel i klausul %<firstprivate%>"
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD är inte en variabel i klausul %<lastprivate%>"
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "%<gang%>-statiskt uttryck måste vara heltal"
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<gang%>-statiskt värde måste vara positivt"
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "%<gang%>-numeriskt uttryck måste vara ett heltal"
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "%<vector%>-längduttryck måste vara ett heltal"
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "%<worker%>-numeriskt uttryck måste vara ett heltal"
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<gang%>-numeriskt värde måste vara positivt"
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<vector%>-längdvärdet måste vara positivt"
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<worker%>-numeriskt värde måste vara positivt"
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "uttryck för styckesstorlek för schemaläggning måste vara heltal"
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "%qs-längduttryck måste vara ett heltal"
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%qs längduttryck måste vara ett positivt konstant heltalsuttryck"
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%>-uttryck måste vara heltal"
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%>-uttryck måste vara heltal"
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "%<device%>-id måste vara ett heltal"
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "%<dist_schedule%> styckesstorleksuttryck måste vara heltal"
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD är inte en variabel i %<aligned%>-klausul"
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE i %<aligned%>-klausul är varken en pekare eller en vektor eller en referens till pekare eller vektor"
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD förekommer mer än en gång i %<aligned%>-klausuler"
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "%<aligned%>-klausuls justeringsuttryck måste vara heltal"
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD är inte en variabel i %<nontemporal%>-klausul"
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD förekommer mer än en gång i %<nontemporal%>-klausuler"
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%<this%> är inte en tillåtet i en %<allocate%>-klausul"
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD är inte en variabel i %<allocate%>-klausul"
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD förekommer mer än en gång i %<allocate%>-klausuler"
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr "%qD är inte ett l-värdeuttryck eller vektorsektion i en %qs-klausul"
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "mallen %qE i-klausulen %qs"
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "överlagrad funktion med namnet %qE i klausulen %qs"
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "%<grainsize%>-uttryck måste vara ett heltal"
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "%<priority%>-uttryck måste vara ett heltal"
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "%<hint%>-uttryck måste vara heltal"
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%<hint%>-uttryck måste vara ett konstant heltalsuttryck"
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, gcc-internal-format
 msgid "%<filter%> expression must be integral"
 msgstr "%<filter%>-uttryck måste vara heltal"
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "variabeln %qs är varken en pekare eller en referens till en pekare"
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "%qs-variabeln är varken en pekare, eller en vektor eller en referens till pekare eller vektor"
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tile%>-argumentet behöver en heltalstyp"
 
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "%<const%>-kvalificerad %qE utan en %<mutable%>-medlem kan endast förekomma i klausuler %<shared%> eller %<firstprivate%>"
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD är inte fil-, namnrymds- eller blockräckviddsvariabel"
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE-direktiv inte i %qT-definition"
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "skillnaden mellan %qE och %qD har inte heltalstyp"
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> använt med klassiterationsvariabeln %qE"
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> använder två olika uttryck för minne"
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr "meddelandet i %<static_assert%> måste vara en strängliteral eller ett objekt med medlemmarna %<size%> och %<data%>"
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr "meddelandet %<size()%> till %<static_assert%> måste vara implicit konverterbart till %<std::size_t%>"
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr "meddelandet %<data()%> till %<static_assert%> måste vara implicit konverterbart till %<const char*%>"
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr "meddelandet %<size()%> till %<static_assert%> måste vara ett konstant uttryck"
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr "meddelandet %<size()%> till %<static_assert%> %qE är för stort"
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr "meddelandet %<data()[%d]%> till %<static_assert%> måste vara ett konstant uttryck"
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr "meddelandet %<data()%> till %<static_assert%> måste vara ett kärnkonstant uttryck"
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, gcc-internal-format
 msgid "static assertion failed: %.*s"
 msgstr "statisk försäkran misslyckades: %.*s"
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "icke-konstant villkor i statisk deklaration"
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "argument till %<decltype%> måste vara ett uttryck"
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%<decltype%> kan inte lösa upp adressen till en överlagrad funktion"
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr "%<__builtin_is_pointer_interconvertible_with_class%> behöver ett ensamt argument"
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr "argumentet till %<__builtin_is_pointer_interconvertible_with_class%> är inte en pekare till en medlem"
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr "%<__builtin_is_corresponding_member%> är inte väldefinierat för anonyma unioner"
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr "%<__builtin_is_corresponding_member%> behöver två argument"
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr "argumentet till %<__builtin_is_corresponding_member%> är inte en pekare till en medlem"
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "%qD är inte en klass- eller aliasmall"
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "operanden till vikningsuttrycket har inget oexpanderat parameterpaket"
 
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "båda argumenten i en binär vikning har oexpanderade parameterpaket"
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "inga oexpanderade parameterpack i binär fold"
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "icke-pekar-argument till %<__builtin_launder%>"
@@ -64945,1158 +64983,1158 @@ msgstr "icke-pekar-argument till %<__builtin_launder%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr "%<__builtin_bit_cast%>-måltyp %qT är en vektortyp"
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr "%<__builtin_bit_cast%>-måltyp %qT är inte trivialt kopierbar"
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr "%<__builtin_bit_cast%>-källtyp %qT är inte trivialt kopierbar"
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr "%<__builtin_bit_cast%>-källstorlek %qE är inte lika med måltypstorleken %qE"
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV-kvalificerare kan inte tillämpas på %qT"
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "satsuttryck i ett konstant uttryck"
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr "%<-fabi-version=13%> (GCC 8.2) fixar anropskonventionen för %qT, som ändrades av misstag i 8.1"
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr "%<-fabi-version=12%> (GCC 8.1) ändrar av misstag anropskonventionen för %qT"
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, gcc-internal-format
 msgid " declared here"
 msgstr " deklarerad här"
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr "anropskonventionen för %qT ändras i %<-fabi-version=13%> (GCC 8.2)"
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr " för att alla dess kopierings- och flyttkonstruerare är borttagna"
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "basklassen %qT är inte publik"
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, gcc-internal-format
 msgid "%qD is not public"
 msgstr "%qD är inte publik"
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, gcc-internal-format
 msgid "%qD is mutable"
 msgstr "%qD är muterbar"
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr "%qD är en icke-strukturell typ"
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr "attributet %qE kan bara användas på funktioner eller parametrar"
 
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr "argument till attribut %qE måste vara en strängkonstant"
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "attributet %qE kan bara användas på funktioner eller på klass- eller uppräkningstyper"
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "attributet %qE kan bara användas på icke-statiska datamedlemmar"
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, gcc-internal-format
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "attributet %qE kan inte tillämpas på ett bitfält"
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "attributet %qE tar inga argument"
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "ISO C++-attributet %qE är inte tillämpligt på funktioner; hanteras som %<[[gnu::%E]]%>"
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, gcc-internal-format
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "begärd %<init_priority%> är inte en heltalskonstant"
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "det går bara att använda attributet %qE på definitioner av objekt- eller klasstyp med filräckvidd"
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "begärd %<init_priority%> %i är utanför sitt intervall [0, %i]"
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "begärd %<init_priority%> %i är reserverad för internt bruk"
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "omdeklaration av %qD lägger till abi-taggen %qE"
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "attributet %qE behöver argument"
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "argumenten till attributet %qE måste vara smala strängkonstanter"
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "argumenten till attributet %qE måste innehålla giltiga identifierare"
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%c%> är inte ett giltigt första tecken för en identifierare"
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%c%> är inte ett giltig bokstav i en identifierare"
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "attributet %qE använt på typen %qT som inte är en klass eller uppräkningstyp"
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "attributet %qE använt på %qT efter dess definition"
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "ignorerar attributet %qE använt på mallinstansieringen %qT"
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "ignorerar attributet %qE använt på mallspecialiseringen %qT"
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "attributet %qE tillämpat på %qD som inte är en funktion eller variabel"
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "attributet %qE tillämpat på extern \"C\"-deklaration %qD"
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, gcc-internal-format
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr "argument till attribut %qE måste vara ett uttryck som beräknas till sant eller falskt"
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "noll som en nollpekarkonstant"
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "%<lang_*%>-kontroll: misslyckades i %s, vid %s:%d"
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "jämförelse mellan olika pekartyper %qT och %qT saknar en typkonvertering"
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "konvertering mellan olika pekartyper %qT och %qT saknar en typkonvertering"
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "villkorsuttryck mellan olika pekartyper %qT och %qT saknar en typkonvertering"
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ förbjuder jämförelser mellan pekare av typ %<void *%> och pekare till funktioner"
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ förbjuder konvertering mellan pekare av typ %<void *%> och pekare till funktioner"
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ förbjuder villkorliga uttryck mellan pekare av typ %<void *%> och pekare till funktioner"
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "jämförelse mellan olika pekare-på-medlem-typer %qT och %qT saknar en typkonvertering"
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "konvertering mellan olika pekare-på-medlem-typer %qT och %qT saknar en typkonvertering"
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "villkorsuttryck mellan olika pekare-på-medlem-typer %qT och %qT saknar en typkonvertering"
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "kanoniska typer skiljer för identiska typer %qT och %qT"
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "samma kanoniska typnod för olika typer %qT och %qT"
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "ogiltig användning av %qs på en medlemsfunktion"
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "ogiltig användning av %<sizeof%> på ett bitfält"
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ förbjuder användning av %<sizeof%> på ett uttryck med funktionstyp"
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "ogiltig användning av %<__alignof%> på ett bitfält"
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ förbjuder användning av %<__alignof%> på ett uttryck med funktionstyp"
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "argumentet till %<alignas%> har typen %qT som inte är en heltalstyp"
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "ogiltig användning av icke-statisk medlemsfunktion av typen %qT"
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ förbjuder konvertering av en strängkonstant till %qT"
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "konvertering från strängkonstant till %qT bör undvikas"
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "begäran av medlem %qD i %qE, som är av pekartypen %qT (kanske du hade tänkt använda %<->%> ?)"
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "begäran av medlem %qD i %qE, som är av icke-klasstyp %qT"
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "ogiltig användning av icke-statisk datamedlem %qE"
 
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "ogiltig åtkomst av icke-statisk datamedlem %qD i virtuell bas till NULL-objekt"
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "objekttyp %qT stämmer inte med destruerarnamnet ~%qT"
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "typen som destrueras är %qT, men destrueraren refererar till %qT"
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "fältet %q#D kan kommas åt via %q#D"
 
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T har ingen medlem med namnet %qE"
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%q#T har ingen medlem med namnet %qE, menade du %q#D? (åtkomligt via %q#D)"
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%q#T har ingen medlem med namnet %qE, menade du %q#D? (inte åtkomlig från detta sammanhang)"
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T har ingen medlem med namnet %qE, menade du %qE?"
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> är inte en medlem av %qT"
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT är inte en basklass till %qT"
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD är inte en medlemsmallfunktion"
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT är inte en pekare-på-objekt-typ"
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "ogiltig användning av vektorindexering på pekare till medlem"
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "ogiltig användning av unärt %<*%> på pekare till medlem"
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "ogiltig användning av implicit konvertering av pekare till medlem"
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr "vänstra operanden till %<->*%> måste vara en pekare på en klass, men är en pekare på en medlem av typen %qT"
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "index saknas i vektorreferens"
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "indexering av vektor deklarerad %<register%>"
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indexerat värde är varken en vektor eller pekare"
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "objekt saknas i användning av %qE"
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ förbjuder anrop av %<::main%> inifrån program"
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "man måste använda %<.*%> eller %<->*%> för att anropa en pekare-till-medlems-funktion i %<%E (...)%>, t.ex. %<(... ->* %E) (...)%>"
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE kan inte användas som en funktion"
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD kan inte användas som en funktion"
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "uttryck kan inte användas som en funktion"
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "för många argument till konstrueraren %q#D"
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "för få argument till konstrueraren %q#D"
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "för många argument till medlemsfunktionen %q#D"
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "för få argument till medlemsfunktionen %q#D"
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "för många argument till funktionen %q#D"
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "för få argument till funktionen %q#D"
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "för många argument till metoden %q#D"
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "för få argument till metoden %q#D"
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "för många argument till funktion"
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "för få argument till funktion"
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "parameter %P till %qD har ofullständig typ %qT"
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parametern %P har ofullständig typ %qT"
 
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, gcc-internal-format
 msgid "the address %qE will never be NULL"
 msgstr "adressen %qE kommer aldrig vara NULL"
 
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "adressen till %qD kommer aldrig vara NULL"
 
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr "kompilatorn kan anta att adressen till %qE aldrig kommer att vara NULL"
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr "jämför resultatet av pekaraddition %qE och NULL"
 
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "kompilatorn kan anta att adressen till %qD aldrig kommer att vara NULL"
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr "bitvis operation mellan olika uppräkningstyper %qT och %qT"
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "bitvis konvertering mellan olika uppräkningstyper %qT och %qT bör undvikas"
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr "aritmetik mellan olika uppräkningstyper %qT och %qT"
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "aritmetik mellan olika uppräkningstyper %qT och %qT bör undvikas"
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr "jämförelse av uppräkningstypen %qT med flyttalstypen %qT"
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr "jämförelse av flyttalstypen %qT med uppräkningstypen %qT"
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr "jämförelse av uppräkningstypen %qT med flyttalstypen %qT är föråldrad"
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "jämförelse av flyttalstypen %qT med uppräkningstypen %qT bör undvikas"
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr "aritmetik mellan uppräkningstypen %qT och flyttalstypen %qT"
 
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr "aritmetik mellan flyttalstypen %qT och uppräkningstypen %qT"
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "aritmetik mellan uppräkningstypen %qT och flyttalstypen %qT är föråldrad"
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "aritmetik mellan flyttalstypen %qT och uppräkningstypen %qT är föråldrad"
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "antar typkonvertering till %qT från överlagrad funktion"
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL använd i aritmetik"
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ förbjuder jämförelse mellan pekare och heltal"
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "operandtyper är %qT och %qT"
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr "trevägsjämförelse av vektorer"
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "ordningsjämförelse av pekare med heltalet noll (%qT och %qT)"
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr "oordnad jämförelse av argument som inte är flyttal"
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "implicit konvertering från %qH till %qI för att matcha den andra operanden i binärt uttryck"
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "ogiltiga operander av typ %qT och %qT till binär %qO"
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ förbjuder användning av pekare av typ %<void *%> i subtraktion"
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ förbjuder användning av pekare till en funktion i subtraktion"
 
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ förbjuder användning av pekare till en metod i subtraktion"
 
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "ogiltig användning av en pekare till en ofullständig typ i pekararitmetik"
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "tar adressen till konstrueraren %qD"
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "tar adressen till destrueraren %qD"
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "ogiltig användning av %qE för att skapa en pekare-till-medlem-funktion"
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  ett kvalificerat id krävs"
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "parenteser runt %qE kan inte användas för att skapa en pekare-till-medlem-funktion"
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ förbjuder att ta adressen till en okvalificerad eller parentetiserad icke-statisk medlemsfunktion för att skapa en pekare till en medlemsfunktion.  Säg %<&%T::%D%>"
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr "ISO C++ förbjuder att ta adressen till en okvalificerad eller parentetiserad icke-statisk medlemsfunktion för att skapa en pekare till en explicit objektmedlemsfunktion"
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ förbjuder att ta adressen till en bunden medlemsfunktion för att skapa en pekare till medlemsfunktion.  Säg %<&%T::%D%>"
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr "ISO C++ förbjuder att ta adressen till en bunden medlemsfunktion för att skapa en pekare på en explicit objektmedlemsfunktion"
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, gcc-internal-format
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr "en pekare på en explicit objektmedlemsfunktion kan bara skapas med %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "tar adress till ett r-värde"
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ förbjuder att ta adressen till funktionen %<::main%>"
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "kan inte skapa pekare till referensmedlem %qD"
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "försök att ta adressen till bitfält"
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<~%> på ett uttryck av typen %<bool%>"
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "tänkte du använda logiskt icke (%<!%>)?"
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ förbjuder ökning av enum"
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ förbjuder minskning av enum"
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "det går inte att öka en pekare på en ofullständig typ %qT"
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "det går inte att minska en pekare på en ofullständig typ %qT"
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ förbjuder ökning av pekare på typ %qT"
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ förbjuder minskning av pekare på typ %qT"
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr "%qs-uttryck av en %<volatile%>-kvalificerad typ bör undvikas"
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr "användning av en operand av typen %qT i %<operator--%> är förbjudet"
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr "användning av en operand av typen %qT i %<operator++%> är förbjudet i C++17"
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr "användning av en operand av typen %qT i %<operator++%> bör undvikas"
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "kan inte ta adressen till %<this%>, som är ett rvalue-uttryck"
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "adress till explicit registervariabel %qD begärd"
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "adress begärd till %qD, som är deklarerad %<register%>"
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "listinitierare för en typ som inte är en klass får inte vara inom parenteser"
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "uttryckslista behandlas som sammansatt uttryck i initierare"
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "uttryckslista behandlas som sammansatt uttryck i medlemsinitierare"
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "uttryckslista behandlas som sammansatt uttryck i funktionstypkonvertering"
 
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "uttryckslistan %s behandlas som sammansatt uttryck"
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "ingen kontext för att lösa upp typen på %qE"
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "konvertering från typ %qT till typ %qT slänger bort kvalificerare"
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%<static_cast%> från typ %qT till typ %qT slänger bort kvalificerare"
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%<reinterpret_cast%> från typ %qT till typ %qT slänger bort kvalificerare"
 
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "oanvändbar konvertering till typen %q#T"
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "typkvalificerare ignoreras för typkonverterings resultattyp"
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "ogiltig %<static_cast%> från typ %qT till typ %qT"
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "returtypen %qT är ofullständig"
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 msgid "converting from %qH to %qI"
 msgstr "konvertering från %qH till %qI"
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, gcc-internal-format
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "ogiltig typkonvertering av ett pr-värdeuttryck av typ %qT till typ %qT"
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 msgid "cast from %qH to %qI loses precision"
 msgstr "konvertering från %qH till %qI förlorar precision"
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr "konvertering mellan inkompatibla funktionstyper från %qH till %qI"
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "typkonvertering mellan inkompatibla pekare till medlemstyper från %qH till %qI"
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "typkonvertering från %qH till %qI ökar kravet på justering för måltypen"
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "typkonvertering mellan pekare-till-funktion och pekare-till-objekt stödjs villkorligt"
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "ogiltig konvertering från typ %qT till typ %qT"
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ogiltig användning av %<const_cast%> med typ %qT, som inte är en pekare, referens, eller pekare-till-datamedlem-typ"
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "ogiltig användning av %<const_cast%> med typ %qT, som är en pekare eller referens till en funktionstyp"
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "ogiltig %<const_cast%> av ett rvärde av typ %qT till typ %qT"
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "ogiltig %<const_cast%> från typ %qT till typ %qT"
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ förbjuder typkonvertering till en vektortyp %qT"
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "ogiltig konvertering till funktionstyp %qT"
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, gcc-internal-format
 msgid "moving %qE of type %qT to itself"
 msgstr "flyttar %qE av typen %qT till sig själv"
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr "ta bort anrop av %<std::move%>"
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  i beräkningen av %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "tilldelning till en vektor från en initierarlista"
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "inkompatibla typer i tilldelning av %qT till %qT"
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "vektor använd som initierare"
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "ogiltig vektortilldelning"
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   i konvertering av pekare till medlemsfunktion"
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "konvertering av pekare till medlem via virtuell bas %qT"
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   i konvertering av pekare till medlem"
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ogiltig konvertering till typ %qT från typ %qT"
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "det går inte att konvertera %qH till %qI i standardargument"
 
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "det går inte att konvertera %qH till %qI när argument skickas"
 
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "det går inte att konvertera %qH till %qI i initiering"
 
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 msgid "cannot convert %qH to %qI in return"
 msgstr "det går inte att konvertera %qH till %qI i retur"
 
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "det går inte att konvertera %qH till %qI i tilldelning"
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "parameter %qP till %qD kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "parameter kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "målet för konvertering kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "målet för initialisering kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "vänsterhandssida av tilldelning kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "när argument %P till %qD skickades"
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "returnerar referens till en temporär"
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, gcc-internal-format
 msgid "returning pointer to temporary"
 msgstr "returnerar pekare på en temporär"
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "att returnera en temporär %<initializer_list%> utökar inte livslängden på den underliggande vektorn"
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "referens till lokal variabel %qD returnerad"
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr "att returnera en lokal %<initializer_list%>-variabel %qD utökar inte livslängden på den underliggande vektorn"
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "adressen till etiketten %qD returnerad"
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "adress till lokal variabel %qD returnerad"
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr "att flytta ett temporärobjekt förhindrar att kopiering undviks"
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr "att flytta ett lokalt objekt i en retursats förhindrar att kopiering undviks"
 
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "redundant förflyttning i retursats"
 
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, gcc-internal-format
 msgid "redundant move in initialization"
 msgstr "redundant förflyttning i initiering"
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "returnerar ett värde från en destruerare"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "det går inte att returnerar från en hanterare i ett funktions-try-block eller en konstruerare"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "returnerar ett värde från en konstruerare"
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return-sats utan värde i funktion som returnerar %qT"
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "returnerar en initierarlista"
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "inkonsistenta typer %qT och %qT härledda för lambda-returtypen"
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "inkonsistent härledning för auto-returtyp: %qT och sedan %qT"
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "return-sats med ett värde i funktion som returnerar %qT"
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> får inte returnera NULL om den inte är deklarerad %<throw()%> (eller %<-fcheck-new%> är aktivt)"
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, gcc-internal-format
 msgid "not eliding copy on return from %qD"
 msgstr "utelämnar inte kopiering vid retur från %qD"
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr "utelämnar inte kopiering vid retur i %qD"
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "använder r-värde som l-värde"
@@ -66317,155 +66355,155 @@ msgstr "överlagrad funktion utan typinformation från sammanhanget"
 msgid "insufficient contextual information to determine type"
 msgstr "otillräcklig sammanhangsinformation för att avgöra typen"
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "konstruerarsyntax använd, men ingen konstruerare är deklarerad för typ %qT"
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "%<constinit%>-variabeln %qD har inte en konstant initierare"
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "avsmalnande konvertering av %qE från %qH till %qI är felaktig i C++11"
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "avsmalnande konvertering av %qE från %qH till %qI"
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr " uttrycket har ett konstant värde men är inte ett C++ konstant uttryck"
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, gcc-internal-format
 msgid "initializer-string for %qT is too long"
 msgstr "initierarsträng för %qT är för lång"
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr "att initiera en basklass av typ %qT resulterar i objektskivning"
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, gcc-internal-format
 msgid "remove %<{ }%> around initializer"
 msgstr "ta bort %<{ }%> runt initierare"
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "det går inte att initiera aggregat med typ %qT med en sammansatt litteral"
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "initierare saknas för medlem %qD"
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "medlem %qD är oinitierad referens"
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "medlem %qD med oinitierade referensfält"
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "ordningen på designeraren för fält %qD stämmer inte med deklarationsordningen i %qT"
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "inget fält %qD finns i unionen som initieras"
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "indexvärde istället för fältnamn i unioninitierare"
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "cirkulär pekardelegering detekterad"
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "basoperanden till %<->%> har icke-pekartyp %qT"
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "resultatet av %<operator->()%> ger annat än pekare"
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "basoperanden till %<->%> är inte en pekare"
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE kan inte användas som en medlemspekare eftersom den är av typen %qT"
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "det går inte att applicera medlemspekare %qE på %qE, som är av typ %qT som inte är en klass"
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "pekare-på-medlemstyp %qT är inkompatibel med objekttyp %qT"
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "pekare-till-medlemsfunktionstyp %qT kräver ett r-värde"
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "pekare-till-medlemsfunktiontyp %qT kräver ett l-värde"
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "pekare-till-medlemsfunktiontyp %qT kräver ett l-värde före C++20"
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "funktionell konvertering till vektortypen %qT"
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "%<auto(x)%> kan inte begränsas"
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<auto(x)%> är endast tillgängligt med %<-std=c++2b%> eller %<-std=gnu++2b%>"
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "ogiltig värdeinitiering av referenstyper"
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "anrop till funktion %qD som kastar ofullständig typ %q#T"
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "anrop till funktion som kastar ofullständig typ %q#T"
@@ -67443,7 +67481,7 @@ msgstr "BOZ-litteralkonstanten vid %L kan inte vara ett aktuellt argument till %
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "Argument till %qs vid %L och %L kan inte båda vara litterala BOZ-konstanter"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "Felaktig användning av en BOZ-litteralkonstant vid %L"
@@ -68766,7 +68804,7 @@ msgstr "Felaktig INTENT-specifikation vid %C"
 msgid "deferred type parameter at %C"
 msgstr "fördröjd typparameter vid %C"
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Skalärt INTEGER-uttryck förväntades vid %L"
@@ -68981,7 +69019,7 @@ msgstr "Komponenten %qs med CLASS vid %C måste vara allokerbar eller en pekare"
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Vektorkomponent i post vid %C måste ha fördröjd form"
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "Komponenten %qs vid %C är redan deklarerad vid %L"
@@ -69782,7 +69820,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr "Formell argumentlista förväntades i funktionsdefinitionen vid %C"
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "Attribut BIND(C) vid %L kan endast användas för variabler och common-block"
@@ -70589,12 +70627,12 @@ msgstr "identical_array_ref(): inkonsistenta dimensioner"
 msgid "are_identical_variables: Bad type"
 msgstr "are_identical_variables: Felaktig typ"
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr "Aktuellt INTENT(%s)-argument vid %L kan störa det aktuella argumentet vid %L."
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr "gfc_check_dependency: en EXPR_VARIABLE förväntades"
@@ -70842,273 +70880,273 @@ msgstr "Parameter %qs vid %L har inte deklarerats eller är en variabel, som int
 msgid "check_init_expr(): Unknown expression type"
 msgstr "check_init_expr(): Okänd uttryckstyp"
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr "Specifikationsfunktionen %qs vid %L kan inte vara en satsfunktion"
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr "Specifikationsfunktionen %qs vid %L kan inte vara en intern funktion"
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, gcc-internal-format
 msgid "Specification function %qs at %L must be PURE"
 msgstr "Specifikationsfunktionen %qs vid %L måste vara PURE"
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr "Specifikationsfunktionen %qs vid %L får inte vara RECURSIVE"
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, gcc-internal-format
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr "Attrappvariabeln %qs är inte tillåten i uttrycket vid %L"
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr "Attrappargumentet %qs vid %L får inte vara OPTIONAL"
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr "Attrappargumentet %qs vid %L får inte vara INTENT(OUT)"
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr "Variabeln %qs kan inte förekomma i uttrycket vid %L"
 
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, gcc-internal-format
 msgid "check_restricted(): Unknown expression type"
 msgstr "check_restricted(): Okänd uttryckstyp"
 
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr "Uttryck vid %L måste vara av INTEGER-typ, hittade %s"
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, gcc-internal-format
 msgid "Function %qs at %L must be PURE"
 msgstr "Funktionen %qs vid %L måste vara PURE"
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr "Uttryck vid %L måste vara skalärt"
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr "optype_msgid-spill: %d"
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr "Inkompatibla ordningar i %s (%d och %d) vid %L"
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "Olika form för %s vid %L på dimension %d (%d och %d)"
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr "Tilldelning till en LEN- eller KIND-part_ref vid %L tillåts inte"
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr "%qs vid %L är inte ett VALUE"
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal assignment to external procedure at %L"
 msgstr "Otillåten tilldelning till extern procedur vid %L"
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "Inkompatibla ordningar %d och %d i tilldelning vid %L"
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "Variabeltypen är OKÄND i tilldelning vid %L"
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "NULL finns på högersidan i tilldelning vid %L"
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "POINTER-värd funktion förekommer på högersidan av tilldelning vid %L"
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr "litteral BOZ-konstant nära %L kan inte tilldelas till en %qs-variabel"
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr "Tilldelningen till en KIND- eller LEN-komponent i en parametriserad typ vid %L tillåts inte"
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Inkompatibla typer i DATA-sats vid %L, försökte med konvertering av %s till %s"
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "Pekartilldelningsmålet är inte en POINTER vid %L"
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "%qs i pekartilldelningen vid %L kan inte vara ett l-värde eftersom det är en procedur"
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Begränsningsspecifikation för %qs förväntades vid %L"
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Begränsningsspecifikation för %qs i pekartilldelning vid %L"
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "Steg får inte finnas vid %L"
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr "Ordningsommappning kräver en lista av specifikationer %<undre-gräns : övre-gräns%> vid %L"
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr "En specifikation som lista av %<undre-gräns :%> eller lista av %<undre-gräns : övre-gräns%> förväntades vid %L"
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "Pekarobjektet vid %L kan inte ha ett co-index"
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Ogiltig procedurpekartilldelning vid %L"
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Funktionsresultatet %qs är ogiltigt i proc-mål i procedurpekartilldelning vid %L"
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Abstrakt gränssnitt %qs är ogiltigt i procedurpekartilldelning vid %L"
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Satsfunktion %qs är ogiltigt i procedurpekartilldelning vid %L"
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Intern procedur %qs är ogiltigt i procedurpekartilldelning vid %L"
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Inbyggd %qs vid %L är ogiltigt i procedurpekartilldelning"
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Den ej inbyggda elementära proceduren %qs är ogiltig i procedurpekartilldelning vid %L"
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "Det stämmer inte i procedurpekartilldelningen vid %L: anropskonventionen stämmer inte"
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "Gränssnitten stämmer inte överens i procedurpekartilldelning vid %L: %qs är inte en subrutin"
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Explicit gränssnitt krävs för komponenten %qs vid %L: %s"
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Explicit gränssnitt krävs för %qs vid %L: %s"
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Gränssnitten stämmer inte överens i procedurpekartilldelning vid %L: %s"
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr "Procedurpekarmålet %qs vid %L måste vara antingen en inbyggd, värd, värd- eller användningsassocierad, refererad eller ha attributet EXTERNAL"
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr "Pekartilldelningsmålet får inte vara en konstant vid %L"
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr "Datapekarobjekt vid %L måste vara obegränsat polymorft, eller av en typ med attributet BIND eller SEQUENCE, för att vara kompatibel med ett obegränsat polymorft mål"
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Olika typer i pekartilldelning vid %L, försökte med tilldelning av %s till %s"
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Olika sorters typparametrar i pekartilldelning vid %L"
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Olika ordning i pekartilldelning vid %L"
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "Målet för översättning av ordningen är mindre än storleken på pekaren (%ld < %ld) vid %L"
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "Målet för översättning av målet måste ha ordning 1 eller vara enkelt sammanhängande vid %L"
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "Målet för översättning av ordning är inte av ordning 1 vid %L"
@@ -71116,192 +71154,192 @@ msgstr "Målet för översättning av ordning är inte av ordning 1 vid %L"
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "Datamålet vid %L får inte ha co-index"
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Måluttryck i pekartilldelning vid %L måste leverera ett pekarresultat"
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr "Nollstor vektor detekterad vid %L där en entitet med attributet TARGET förväntades"
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "Målet för pekartilldelningen i initieraruttrycket har inte attributet TARGET vid %L"
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, gcc-internal-format, gfc-internal-format
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr "Varje index till målspecifikationen vid %L måste vara ett konstant uttryck"
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr "Delsträngens start- och slutpunkter i målspecifikationen vid %L måste vara konstanta uttryck"
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Pekartilldelningsmål är vare sig TARGET eller POINTER vid %L"
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Felaktigt mål i pekartilldelning i PURE-procedur vid %L"
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Pekartilldelning med vektorindexering på högersidan vid %L"
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Pekartilldelningsmålet har attributet PROTECTED vid %L"
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr "Tilldelning till sammanhängande pekare från icke sammanhängande mål vid %L"
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "Pekare vid %L i pekartilldelning kan överleva pekarmålet"
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Pekarinitieringsmål vid %L får inte vara ALLOCATABLE"
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Målet för pekarinitieringen vid %L måste ha attributet TARGET"
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Pekarinitieringsmål vid %L måste ha attributet SAVE"
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "Procedurpekarinitieringsmål vid %L får inte vara en procedurpekare"
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Intern procedur %qs är ogiltigt i procedurpekarinitiering vid %L"
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Attrapproceduren %qs är ogiltig i procedurpekarinitiering vid %L"
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr "generate_isocbinding_initializer(): felaktig iso_c_binding-typ, %<c_ptr%> eller %<c_funptr%> förväntades"
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Pekarfunktioner i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Icke variabelt uttryck i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Namngiven konstant %qs i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qs i variabeldefinitionssammanhang (%s) vid %L är inte en variabel"
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Icke-POINTER i pekarassociationssammanhang (%s) vid %L"
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Typen är oåtkomlig i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_EVENT i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, gcc-internal-format
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr "%qs-parameterfråga för %qs i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Attrappargument %qs med INTENT(IN) i pekarassociationssammanhang (%s) vid %L"
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Attrappargument %qs med INTENT(IN) i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "Variabeln %qs är PROTECTED och kan inte förekomma i ett pekarassociationssammanhang (%s) vid %L"
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "Variabeln %qs är PROTECTED och kan inte förekomma i ett variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Variabeln %qs kan inte förekomma i ett variabeldefinitionssammanhang (%s) vid %L i en PURE-procedur"
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr "%qs vid %L som är associerad med vektorindexerat mål kan inte användas i ett variabeldefinitionssammanhang (%s)"
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "%qs vid %L som är associerad med uttryck kan inte användas i ett variabeldefinitionssammanhang (%s)"
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, gcc-internal-format
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr "%qs vid %L som är associerad med ett pekarfunktionsmål används i ett variabeldefinitionssammanhang (%s)"
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "Associationsnamn %qs kan inte förekomma i ett variabeldefinitionssammanhang (%s) vid %L eftersom dess mål vid %L inte heller kan"
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "Element med samma värde vid %L och %L i vektorindex i ett variabeldefinitionssammanhang (%s)"
@@ -71322,8 +71360,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Otillåtet id i copy_walk_reduction_arg"
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "Skapar vektortemporär vid %L"
@@ -71403,7 +71441,7 @@ msgstr "Variabeln %qs vid %L satt till odefinierad inuti slingan som börjar vid
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Variabeln %qs vid %L ej definierbar inuti slingan som börjar vid %L är argument INTENT(INOUT) till funktionen %qs"
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr "Kod för omallokering av den allokerbara vektorn vid %L kommer läggas till"
@@ -71538,12 +71576,12 @@ msgstr "Första argumentet till definierad tilldelning vid %L måste vara INTENT
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Andra argumentet av definierad tilldelning vid %L måste vara INTENT(IN)"
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Första argumentet till operatorgränssnitt vid %L måste vara INTENT(IN)"
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Andra argumentet till operatorgränssnitt vid %L måste vara INTENT(IN)"
@@ -72413,7 +72451,7 @@ msgstr "Konvertering från %s till %s vid %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "Kan inte konvertera %s till %s vid %L"
@@ -72964,7 +73002,7 @@ msgstr "NAMELIST %qs i READ-sats vid %L innehåller symbolen %qs som inte får s
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST-objekt %qs i namnlistan %qs vid %L är polymorf och behöver en definierad input/output-procedur"
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "NAMELIST-objektet %qs i namnlistan %qs vid %L med ALLOCATABLE- eller POINTER-komponenter"
@@ -73130,6 +73168,11 @@ msgstr "identifierarspill: %d"
 msgid "check_charlen_present(): length not set"
 msgstr "check_charlen_present(): längden inte satt"
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr "ATTGÖRA: obegränsad polymorf MOLD i inbyggd TRANSFER vid %L"
+
 #: fortran/match.cc:118
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
@@ -73531,7 +73574,7 @@ msgstr "STOP-koden vid %L måste vara standard tecken-KIND=%d"
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "STOP-kod vid %L måste vara standard heltal KIND=%d"
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr "QUIET-specificerare vid %L måste vara en skalär LOGICAL"
@@ -74054,82 +74097,82 @@ msgstr "parsningsfel i SELECT TYPE-sats vid %C"
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "Väljare i SELECT TYPE vid %C är inte en namngiven variabel, använd associationsnamn =>"
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr "SELECT RANK-sats vid %C"
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr "Selektorn SELECT RANK vid %C måste vara en variabel med antagen ordning"
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "parsningsfel i SELECT RANK-sats vid %C"
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Oväntad CASE-sats vid %C"
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Syntaxfel i CASE-specifikation vid %C"
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Oväntad TYPE IS-sats vid %C"
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr "Typspecifikationen skall inte specificera en sekvens härledd typ eller en typ med attributet BIND i SELECT TYPE vid %C [F2003:C815]"
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr "Alla LEN-typparametrar i satsen TYPE IS vid %C måste vara ASSUMED"
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Syntaxfel i TYPE IS-specifikation vid %C"
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Syntaxfel i CLASS IS-specifikation vid %C"
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr "Oväntad RANK-sats vid %C"
 
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "SELECT RANK CASE-uttrycket vid %C måste vara en skalär heltalskonstant"
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr "Värdet på SELECT RANK CASE-uttrycket vid %C får inte vara mindre än noll eller större än %d"
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr "Syntaxfel i RANK-specifikation vid %C"
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "ELSEWHERE-sats vid %C inte innesluten i WHERE-block"
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "Etiketten %qs vid %C stämmer inte med WHERE-etikett %qs"
@@ -75546,8 +75589,8 @@ msgstr "ORDERED-klausulparameter är mindre än COLLAPSE vid %L"
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr "en ORDER-klausul får inte användas tillsammans med ORDERED vid %L"
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF-klausul vid %L kräver ett skalärt LOGICAL-uttryck"
@@ -77911,12 +77954,12 @@ msgstr "Den inbyggda %qs deklarerad INTRINSIC vid %L är inte tillgänglig i den
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Icke RECURSIVE procedur %qs från modulen %qs anropar kanske sig själv rekursivt i proceduren %qs. Deklarera den RECURSIVE eller använd %<-frecursive%>"
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Icke RECURSIVE procedur %qs vid %L anropar kanske sig själv rekursivt.  Deklarera den RECURSIVE eller använd %<-frecursive%>"
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Etikett %d som refereras vid %L är aldrig definierad"
@@ -78036,7 +78079,7 @@ msgstr "Saknad explicit deklaration med attributet EXTERNAL för symbolen %qs vi
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Funktionen %qs vid %L har ingen IMPLICIT-typ; menade du %qs?"
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Funktionen %qs vid %L har ingen IMPLICIT-typ"
@@ -78435,278 +78478,283 @@ msgstr "Variabeln %s med antagen typ vid %L skall inte ha en subobjektreferens"
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Variabeln %s med antagen ordning vid %L skall inte ha en subobjektreferens"
 
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, gcc-internal-format
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr "Den skalära variabeln %qs har en vektorreferens vid %L"
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel %qs, använd i ett specifikationsuttryck, refereras vid %L före ENTRY-satsen i vilken den är en parameter"
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel %qs används vid %L före ENTRY-satsen i vilken den är en parameter"
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Polymorft subobjekt till co-indexerat objekt vid %L"
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Co-indexerat objekt med polymorf allokerbar delkomponent vid %L"
 
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "Att använda variabeln %qs vid %L bör undvikas"
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid array reference at %L"
+msgstr "Felaktig vektorreferens vid %L"
+
+#: fortran/resolve.cc:6433
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr "%qs vid %L är värdassocierad vid %L in i en innesluten procedur med en intern procedur med samma namn"
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "Fel i typbundet anrop vid %L"
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Skickat objekt vid %L måste vara skalär"
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Basobjekt för procedurpekarkomponentanrop vid %L är av ABSTRACT typ %qs"
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Basobjekt för typbundet proceduranrop vid %L är av ABSTRACT typ %qs"
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Basobjekt för typbundet NOPASS-proceduranrop vid %L måste vara skalärt"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Hittade ingen matchande specifik bindning för anropet till GENERIC %qs vid %L"
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs vid %L skulle vara en SUBROUTINE"
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs vid %L skulle vara en FUNCTION"
 
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Felaktig uttryckstyp"
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s vid %L måste vara en skalär"
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s vid %L måste vara ett heltal"
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s vid %L måste vara INTEGER"
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Steguttryck i DO-slinga vid %L får inte vara noll"
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO-slinga vid %L kommer köras noll gånger"
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "DO-slingan vid %L är odefinierad eftersom den spiller över"
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "DO-slingan vid %L är odefinierad eftersom den spiller under"
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL-indexnamn vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL-slututtryck vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL-slututtryck vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL-steguttryck vid %L måste vara en skalär %s"
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL-steguttryck vid %L får inte vara noll"
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL-index %qs får inte förekomma i triplettspecifikation vid %L"
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allokeringsobjekt vid %L måste vara ALLOCATABLE eller en POINTER"
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Co-indexerat allokerbart objekt vid %L"
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Källuttryck vid %L måste vara skalärt eller ha samma ordning som allokeringsobjektet vid %L"
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Källuttryck vid %L och allokeringsobjekt vid %L måste ha samma form"
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Typen på entiteten vid %L är typinkompatibel med källuttrycket vid %L"
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Allokeringsobjektet vid %L och källuttrycket vid %L skall ha samma sorts typparameter"
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Källuttrycket vid %L skall varken vara av typen LOCK_TYPE eller ha en LOCK_TYPE-komponent om det allokerbara objektet vid %L är en co-vektor"
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "Källuttrycket vid %L skall varken vara av typen EVENT_TYPE eller ha en EVENT_TYPE-komponent om det allokerbara objektet vid %L är en co-vektor"
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Allokering %s av ABSTRACT bastyp vid %L behöver en typspecifikation eller source-uttryck"
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Allokerar %s vid %L med typspecifikation kräver samma teckenlängdsparameter som i deklarationen"
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Vektorspecifikation krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Vektorspecifikation eller vektorvärt SOURCE=-uttryck krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Co-vektorspecifikation krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Felaktig co-vektorspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr "Övre cobound är mindre än den lägre cobound vid %L"
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr "Övre cobound är mindre än lägre cobound av 1 vid %L"
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Felaktig vektorspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs får inte förekomma i vektorspecifikationen vid %L i samma ALLOCATE-sats där den själv allokeras"
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "%<*%> förväntades i co-indexspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Statvariabel vid %L måste vara en INTEGER-variabel"
 
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Statvariabel vid %L skall inte %s:as i samma %s-sats"
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG vid %L är oanvändbart utan en STAT-tagg"
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "ERRMSG-variabeln vid %L måste vara en skalär standard-CHARACTER-variabel"
 
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Errmsg-variabel vid %L skall inte %s:as i samma %s-sats"
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allokeringsobjekt vid %L förekommer också vid %L"
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allokeringsobjekt vid %L är underobjekt till objekt vid %L"
@@ -78715,284 +78763,284 @@ msgstr "Allokeringsobjekt vid %L är underobjekt till objekt vid %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-etikett vid %L överlappar med CASE-etikett vid %L"
 
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "uttryck i CASE-sats vid %L måste vara av typ %s"
 
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Uttryck i CASE-sats vid %L måste ha sort %d"
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Uttryck i CASE-sats vid %L måste vara skalärt"
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Valuttryck i beräknad-GOTO-sats vid %L måste vara ett skalärt heltalsuttryck"
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argument till SELECT-sats vid %L kan inte vara %s"
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argumentet till SELECT-satsen vid %L måste vara ett skalärt uttryck"
 
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Uttryck i CASE-sats vid %L ligger inte i intervallet %s"
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "DEFAULT CASE vid %L får inte följas av ett andra DEFAULT CASE vid %L"
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Logiskt intervall CASE-sats vid %L är inte tillåtet"
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Konstant logiskt värde i CASE-sats upprepas vid %L"
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Intervallspecifikationen vid %L kan aldrig matchas"
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logiskt SELECT CASE-block vid %L har mer än två fall"
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Den associerande entiteten %qs vid %L är en procedurpekare"
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Den härledda typen %qs får inte användas som en variabel vid %L"
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Den associerande entiteten %qs vid %L är ett procedurnamn"
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr "Det associerande selector-uttrycket vid %L ger en procedur"
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Selektorn vid %L får inte vara NULL()"
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Selektorn vid %L har ingen typ"
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Associationsnamn %qs vid %L används som en vektor"
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "CLASS-väljare vid %L behöver en temporär som inte är implementerad ännu"
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Selektorer skall vara polymorfiska i SELECT TYPE-sats vid %L"
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Selektorn vid %L får inte vara co-indexerad"
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS vid %L överlappar med TYPE IS vid %L"
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Härledd typ %qs vid %L måste vara utökningsbar"
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Härledd typ %qs vid %L måste vara en utökning av %qs"
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Oväntad inbyggd typ %qs vid %L"
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Typspecifikationen vid %L skall ange att varje längdtypparameter är antagen"
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Dubbelt CLASS IS-block i SELECT TYPE-sats vid %L"
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr "RANK DEFAULT vid %L upprepas vid %L"
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr "RANK (*) vid %L upprepas vid %L"
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr "RANK (%i) vid %L upprepas vid %L"
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr "RANK (*) vid %L får inte användas med en pekare eller allokerbar selector vid %L"
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ogiltigt sammanhang för inbyggd NULL () vid %L"
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "DTIO %s-procedur vid %L måste vara rekursiv"
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte vara polymorft om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha POINTER-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Dataöverföringselement vid %L får inte ha procedurpekarkomponenter"
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha ALLOCATABLE-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Dataöverföringselement vid %L får inte ha PRIVATE-komponenter"
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha PRIVATE-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Dataöverföringselement vid %L får inte vara en full referens till en vektor med antagen storlek"
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Låsvariabel vid %L måste vara en skalär av typen LOCK_TYPE"
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "Händelsevariabeln vid %L måste vara en skalär av typen EVENT_TYPE"
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Händelsevariabelargumentet vid %L måste vara en co-vektor eller co-indexerat"
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Händelsevariabelargumentet vid %L måste vara en co-vektor men inte co-indexerat"
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT=-argumentet vid %L måste vara en skalär INTEGER-variabel"
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG=-variabeln vid %L måste vara en skalär CHARACTER-variabel"
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK=-argumentet vid %L måste vara en skalär LOGICAL-variabel"
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "UNTIL_COUNT=-argumentet vid %L måste vara ett skalärt INTEGER-uttryck"
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Bildmängdsargument vid %L måste vara ett skalärt eller INTEGER-uttryck av ordning 1"
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Bildmängdsargument vid %L måste vara mellan 1 och num_images()"
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Sats vid %L är inte en giltig grenmålssats för grensatsen vid %L"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Gren vid %L kan orsaka en oändlig slinga"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO-sats vid %L lämnar CRITICAL-konstruktion för etikett vid %L"
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO-sats vid %L lämnar DO CONCURRENT-konstruktion för etikett vid %L"
@@ -79000,212 +79048,212 @@ msgstr "GOTO-sats vid %L lämnar DO CONCURRENT-konstruktion för etikett vid %L"
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Etiketten vid %L är inte i samma block som GOTO-satsen vid %L"
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE-mask vid %L har inkonsistent form"
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE-tilldelningsmål vid %L har inkonsistent form"
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Ej ELEMENTAL användardefinierad tilldelning i WHERE vid %L"
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Ej stödd sats inuti WHERE vid %L"
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Tilldelning till en FORALL-indexvariabel vid %L"
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL med index %qs används inte på vänster sida av en tilldelning vid %L och kan därför orsaka multipla tilldelningar till detta objekt"
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "FORALL-konstruktion vid %L"
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL-indexnamn vid %L måste vara en skalär variabel av heltalstyp"
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "En yttre FORALL-konstruktion har redan ett index med detta namn %L"
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE-klausul vid %L kräver en LOGICAL-vektor"
 
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Felaktig blocktyp"
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr "Variabeln i den ordinära tilldelningen vid %L är en procedurpekarkomponent"
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, gcc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr "CHARACTER-uttryck kommer att huggas av i tilldelning (%wd/%wd) vid %L"
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Co-indexerat uttryck vid %L är tilldelat till en härledd typvariabel med en POINTER-komponent i en PURE-procedur"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr "I ett rent underprogram skall inte ett INTENT(IN) attrappargument användas som uttrycket vid %L av en inbyggd tilldelningssats i vilken variabeln är av an härledd typ om den härledda typen har en pekarkomponent på någon nivå av komponentvalet."
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Tilldelning till en co-indexerad variabel vid %L i en PURE-procedur"
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Tilldelning till en polymorf co-vektor vid %L är inte tillåtet"
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Tilldelning till en allokerbar polymorf variabel vid %L"
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Tilldelning till en allokerbar polymorf variabel vid %L kräver %<-frealloc-lhs%>"
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr "Ej allokerbar variabel får inte vara polymorf i inbyggd tilldelning vid %L - kontrollera att det finns en matchande specifik subrutin för operatorn %<=%>"
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Co-indexerad variabel får inte ha en allokerbar yttersta komponent i tilldelningen vid %L"
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "ATT GÖRA: typbegränsad definierad tilldelning vid %L inte gjord för att multipla delvektorreferenser skulle uppträda i intermediära uttryck."
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Procedurpekartilldelning vid %L"
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Funktionsresultatet på vänstersidan av tilldelningen vid %L måste ha attributet pointer."
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "TEAM-argumentet till %qs vid %L måste vara ett skalärt uttryck av typen TEAM_TYPE"
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "TEAM NUMBER-argumentet till FORM TEAM vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "ASSIGNED GOTO-sats vid %L kräver en skalär INTEGER-variabel"
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variabeln %qs har inte tilldelats någon måletikett vid %L"
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternativ RETURN-sats vid %L kräver en SCALAR-INTEGER-returspecificerare"
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "Inbyggd tilldelning förväntades i OMP WORKSHARE vid %L"
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN-sats vid %L kräver en skalär standard-INTEGER-variabel"
 
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "Ogiltig NULL vid %L"
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Aritmetisk IF-sats vid %L kräver ett skalärt REAL- eller INTEGER-uttryck"
 
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Inget uttryck i DO WHILE"
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Avslutsvillkor i DO WHILE-slinga vid %L måste vara ett skalärt LOGICAL-uttryck"
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL-maskklausul vid %L kräver ett skalärt LOGICAL-uttryck"
 
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Felaktig satskod"
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Att använda parametern %qs deklarerad vid %L bör undvikas"
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Variabeln %qs med bindningsetiketten %qs vid %L använder samma globala identifierare som en entitet vid %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "Variabeln %qs från modulen %qs med bindningsetikett %qs vid %L använder samma globala identifierare som entiteten vid %L från modulen %qs"
@@ -79213,999 +79261,999 @@ msgstr "Variabeln %qs från modulen %qs med bindningsetikett %qs vid %L använde
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Proceduren %qs med bindningsetiketten %qs vid %L använder samma globala identifierare som entiteten vid %L"
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Stränglängden vid %L är för stor"
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Den allokerbara vektorn %qs vid %L måste ha en fördröjd form eller antagen ordning"
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Skalärt objekt %qs vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Vektorpekaren %qs vid %L måste ha en fördröjd form eller antagen ordning"
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Vektor %qs vid %L kan inte ha en fördröjd form"
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Typen %qs på CLASS-variabeln %qs vid %L är inte utvidgningsbar"
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS-variabel %qs vid %L måste vara en attrapp, allokerbar eller pekare"
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Typen %qs kan inte vara värdassocierad vid %L för att den blockeras av ett inkompatibelt objekt med samma namn deklarerat vid %L"
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Implicerad SAVE för modulvariabeln %qs vid %L, behövs på grund av standardinitieringar"
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Enheten %qs vid %L har en fördröjd typparameter och kräver antingen attributet POINTER eller ALLOCATABLE"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Modul- eller huvudprogramvektorn %qs vid %L måste ha konstant form"
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entitet med antagen teckenlängd vid %L måste vara ett attrappargument eller en PARAMETER"
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs vid %L måste ha konstant teckenlängd i detta sammanhang"
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON-variabeln %qs vid %L måste ha konstant teckenlängd"
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Allokerbar %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Extern %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Attrapp-%qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Inbyggd %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktionsresultat %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automatisk vektor %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s vid %L"
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Teckenvärd satsfunktion %qs vid %L måste ha konstant längd"
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs är av en PRIVATE-typ och kan inte vara ett attrappargument till %qs, som är PUBLIC vid %L"
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Proceduren %qs i PUBLIC-gränssnittet %qs vid %L tar attrappargument för %qs som är PRIVATE"
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktion %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Externt objekt %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-funktion %qs vid %L måste ha ett skalärt resultat"
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Satsfunktionen %qs vid %L får inte ha attributet pointer eller allocatable"
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte ha vektorvärde"
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte ha pekarvärde"
 
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte vara pure"
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte vara rekursiv"
 
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*)-funktionen %qs vid %L"
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Procedurpekaren %qs vid %L skall inte vara elementär"
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Attrapprocedur %qs vid %L skall inte vara elementär"
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Funktionens resultatvariabel %qs vid %L för den elementära funktionen %qs skall inte ha ett attribut ALLOCATABLE eller POINTER"
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med SAVE-attribut i %qs vid %L"
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med INTENT-attribut i %qs vid %L"
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med RESULT-attribut i %qs vid %L"
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL-attribut i konflikt med FUNCTION-attribut i %qs vid %L"
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Procedurpekarresultat %qs vid %L saknar pekarattributet"
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "ELEMENTAL-attribut stämmer inte mellan MODULE PROCEDURE vid %L och dess gränssnitt i %s"
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "PURE-attribut stämmer inte mellan MODULE PROCEDURE vid %L och dess gränssnitt i %s"
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "RECURSIVE-attribut stämmer inte mellan MODULE PROCEDURE vid %L och dess gränssnitt i %s"
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s mellan MODULE PROCEDURE-deklarationen i MODULE %qs och deklarationen vid %L i (SUB)MODULE %qs"
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr "Gränssnittet för %qs vid %L måste vara explicit"
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL-procedur %qs vid %L är inte en SUBROUTINE"
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL-procedur vid %L måste ha precis ett argument"
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argument till FINAL-procedur vid %L måste ha typen %qs"
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr "FINAL-procedur vid %L med argument med antagen ordning måste vara den enda avslutaren med samma sort/typ (F2018: C790)"
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Argument till FINAL-procedur vid %L får inte vara en POINTER"
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argument till FINAL-procedur vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argument till FINAL-procedur vid %L får inte vara OPTIONAL"
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argument till FINAL-procedur vid %L får inte vara INTENT(OUT)"
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Ickeskalär FINAL-procedur vid %L skulle ha argument med antagen form"
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "FINAL-procedur %qs deklarerad vid %L har samma ordning (%d) som %qs"
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr "Endast vektor-FINAL-procedurer deklarerade för den härledda typen %qs definierade vid %L, föreslår även en skalär om inte en avslutare med antagen ordning har deklarerats"
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs och %qs kan inte blandad FUNCTION/SUBROUTINE för GENERIC %qs vid %L"
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs och %qs för GENERIC %qs vid %L är tvetydiga"
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Odefinierad specifik bindning %qs som mål för GENERIC %qs vid %L"
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs vid %L måste ha som mål en specifik bindning, %qs är också GENERIC"
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC %qs vid %L kan inte åsidosätta en specifik bindning med samma namn"
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Typbindningsoperator vid %L kan inte vara NOPASS"
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs måste vara en modulprocedur eller en extern procedur med ett explicit gränssnitt vid %L"
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Proceduren %qs med PASS(%s) vid %L har inget argument %qs"
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Procedur %qs med PASS vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Ickepolymorfa attrappargument för pass-objekt till %qs vid %L"
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste ha den härledda typen %qs"
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste ha den parametriskt härledda typen %qs"
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr "Alla parametrar av typen LEN i det skickade attrappargumentet %qs till %qs vid %L måste vara ASSUMED"
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Skickat objekt-attrappargument till %qs vid %L måste vara skalärt"
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Skickat objekt-attrappargument till %qs vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Skickat objekt-attrappargument till %qs vid %L får inte vara POINTER"
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Procedur %qs vid %L har samma namn som en komponent i %qs"
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Proceduren %qs vid %L har samma namn som den ärvd komponent i %qs"
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Härledd typ %qs deklarerad vid %L måste vara ABSTRACT för att %qs är DEFERRED och inte åsidosatt"
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Co-vektorkomponent %qs vid %L måste vara allokerbar med fördröjd form"
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Komponenten %qs vid %L av TYPE(C_PTR) eller TYPE(C_FUNPTR) får inte vara en co-vektor"
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Komponenten %qs vid %L med co-vektorkomponent skall skalär som inte är en pekare eller allokerbar"
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Component %qs vid %L har attributet CONTIGUOUS men är inte en vektorpekare"
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Komponenten %qs med typen BIND(C) vid %L måste ha längden ett"
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Procedurpekarkomponent %qs med PASS(%s) vid %L har inget argument %qs"
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Procedurpekarkomponent %qs med PASS vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste ha den härledda typen %qs"
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste vara skalärt"
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumentet %qs till %qs med PASS(%s) vid %L får inte ha attributet POINTER"
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argumentet %qs till %qs med PASS(%s) vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponent %qs i %qs vid %L har samma namn som en ärvd typbunden procedur"
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Teckenlängd på komponent %qs behöver vara ett konstant specifikationsuttryck vid %L"
 
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "Teckenlängdsuttrycket för komponenten %qs vid %L måste vara av typen INTEGER, hittade %s"
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Teckenkomponent %qs av %qs vid %L med fördröjd längd måste vara en POINTER eller ALLOCATABLE"
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "komponenten %qs är en PRIVATE-typ och kan inte vara en komponent i %qs, som är PUBLIC vid %L"
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorf komponent %s vid %L i SEQUENCE- eller BIND(C)-typ %s"
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponent %s av SEQUENCE-typ deklarerad vid %L har inte attributet SEQUENCE"
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Initierare som står i konflikt i unionen vid %L och %L"
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Eftersom utvidgningen av %qs vid %L har en co-vektorkomponent, skall föräldratypen %qs också ha en"
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Ej utvidgningsbar härledd typ %qs vid %L får inte vara ABSTRACT"
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Den parametriserade typen %qs har inte någon komponent som motsvarar parametern %qs vid %L"
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Det generiska namnet %qs på funktionen %qs vid %L är samma namn som den härledda typen vid %L"
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Härledd typ %qs vid %L har inte deklarerats"
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Vektor %qs med antagen storlek i namnlistan %qs vid %L är inte tillåtet"
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med antagen form i namnlistan %qs vid %L"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med icke-konstant form in namnlistan %qs vid %L"
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med icke-konstant längd i namnlistan %qs vid %L"
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs deklarerades PRIVATE och kan inte vara medlem av PUBLIC-namnlista %qs vid %L"
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs har användningsassociativa PRIVATE-komponenter och kan inte vara medlem av namnlistan %qs vid %L"
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs har PRIVATE-komponenter och kan inte vara medlem av PUBLIC-namnlista %qs vid %L"
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med NAMELIST-attribut i %qs vid %L"
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parametervektor %qs vid %L kan inte ha automatisk eller fördröjd form"
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Implicit typad PARAMETER %qs vid %L matchar inte en senare IMPLICIT-typ"
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Inkompatibel härledd typ i PARAMETER vid %L"
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "CLASS-variabeln %qs vid %L får inte ha attributet PARAMETER"
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Enheten %qs vid %L har en fördröjd LEN-parameter %qs och kräver antingen attributet POINTER eller ALLOCATABLE"
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "AUTOMATIC-objektet %qs vid %L får inte ha attributet SAVE eller vara en variabel deklarerad i huvudprogrammet, en modul eller en submodul(F08/C513)"
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "Objektet %qs vid %L med ASSUMED typparametrar måste vara en attrapp eller en SELECT TYPE-selektor(F08/4.2)"
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Ledsen, allocatable/pointer-komponenter i co-vektor av polymorf (CLASS)-typ vid %L stödjs inte"
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr "%<omp_all_memory%>, deklarerat vid %L, får endast användas i OpenMP-klausulen DEPEND"
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Attributet PROTECTED står i konflikt med attributet EXTERNAL vid %L"
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Attributet PROCEDURE står i konflikt med attributet PROTECTED vid %L"
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs vid %L har attributet CONTIGUOUS, men är inte en vektorpekare eller en vektor med antagen form eller antagen ordning"
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Felaktig specifikation för vektor med antagen storlek vid %L"
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Vektor med antagen storlek vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Vektor med antagen form vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Vektor med antagen ordning vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Vektor med antagen ordning vid %L kan inte ha attributet VALUE eller CODIMENSION"
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Symbol vid %L är inte en DUMMY-variabel"
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs vid %L kan inte ha attributet VALUE eftersom det inte är ett attrappargument"
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Teckenvärd attrappvariabel %qs vid %L med attributet VALUE måste ha konstant längd"
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C-interoperativ teckenattrappvariabel %qs vid %L med attributet VALUE måste ha längd ett"
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Den härledda typen %qs vid %L har typen %qs, som inte har definierats"
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall vara ett attrappargument"
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall ha typen TYPE(*) eller en numerisk inbyggd typ"
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får inte ha attributet ALLOCATABLE, CODIMENSION, POINTER eller VALUE"
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får inte ha attributet INTENT(OUT)"
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall antingen vara en skalär eller en vektor med förmodad storlek"
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Den antagna typen på variabeln %s vid %L är bara tillåten för attrappvariabler"
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabeln ”%s” med antagen typ vid %L får inte ha attributet ALLOCATABLE, CODIMENSION, POINTER eller VALUE"
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variabeln ”%s” med antagen typ vid %L får inte ha attributet INTENT(OUT)"
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Variabeln %s med antagen typ vid %L får inte vara en vektor med explicit form"
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variabel %qs vid %L kan inte vara BIND(C) eftersom den varken är ett COMMON-block eller deklarerad med räckvidd modulnivå"
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "BIND(C)-variabeln %qs vid %L måste ha längden ett"
 
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs vid %L har PRIVATE härledd typ %qs"
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Variabeln %s vid %L av typen LOCK_TYPE eller med en delkomponent av typen LOCK_TYPE måste vara en co-vektor"
 
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "Variabeln %s vid %L av typen EVENT_TYPE eller med en delkomponent av typen EVENT_TYPE måste vara en co-vektor"
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT)-attrappargumentet %qs vid %L har ASSUMED SIZE och kan därför inte ha en standardinitierare"
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Attrappargumentet %qs vid %L av LOCK_TYPE får inte vara INTENT(OUT)"
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Attrappargumentet %qs vid %L av EVENT_TYPE får inte vara INTENT(OUT)"
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktionsresultat %qs vid %L skall inte vara en co-vektor eller ha en co-vektorkomponent"
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Variabeln %qs vid %L av TYPE(C_PTR) eller TYPE(C_FUNPTR) får inte vara en co-vektor"
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Variabeln %qs vid %L med co-vektorkomponent skall vara en skalär som inte är en pekare eller allokerbar och inte en co-vektor"
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Variabeln %qs vid %L är en co-vektor och är inte ALLOCATABLE, SAVE eller ett attrappargument"
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Co-vektorvariabeln %qs vid %L skall inte ha co-dimensioner med fördröjd form"
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Allokerbar co-vektorvariabel %qs vid %L måste ha en fördröjd form"
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Variabeln %qs vid %L är INTENT(OUT) och kan alltså inte vara en allokerbara co-vektor eller har co-vektorkomponenter"
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Co-attrappvariabeln %qs vid %L är inte tillåten i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-attrappargumentet %qs vid %L med icke-C_Bool-sort i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-resultatvariabeln %qs vid %L med icke-C_Bool-sort i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Namnlistan %qs får inte vara ett argument till en subrutin eller funktion vid %L"
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Trådprivat vid %L är inte SAVE:ad"
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "!$OMP DECLARE TARGET-variabeln %qs vid %L är inte SAVE:ad"
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "Definierbar entitet förväntades nära %L"
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA-element %qs vid %L måste vara i COMMON"
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA-vektor %qs vid %L måste anges i en tidigare deklaration"
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA-elementet %qs vid %L kan inte ha ett co-index"
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA-element %qs vid %L är en pekare och måste då vara en fullständig vektor"
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr "DATA-objektet nära %L har pekarattributet och det motsvarande DATA-värdet är inte ett giltigt initialt-data-mål"
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "DATA-elementet %qs vid %L får inte ha attributet ALLOCATABLE"
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Ickekonstant vektorsektion vid %L i DATA-sats"
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-sats vid %L har fler variabler än värden"
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant character length at %L in DATA statement"
 msgstr "Ickekonstant teckenlängd vid %L i DATA-sats"
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "början av implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "slutet av implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "steget i implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "steget i implicerad do-slinga vid %L skall inte vara noll"
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-sats vid %L har fler värden än variabler"
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Etiketten %d vid %L är definierad men inte använd"
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Etiketten %d vid %L är definierad men kan inte användas"
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L måste ha attributet SEQUENCE för att vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L kan inte ha ALLOCATABLE-komponenter för att vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Härledd typvariabel %qs vid %L med standardinitiering kan inte vara i EQUIVALENCE med en variabel i COMMON"
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L med pekarkomponent(er) kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaxfel i EQUIVALENCE-sats vid %L"
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Antingen alla eller inget av objekten i EQUIVALENCE-mängden vid %L kan ha attributet PROTECTED"
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "COMMON-blockmedlem %qs vid %L kan inte vara ett EQUIVALENCE-objekt i den rena proceduren %qs"
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Namngiven konstant %qs vid %L kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Vektor %qs vid %L med icke-konstanta gränser kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Postkomponent %qs vid %L kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Delsträng vid %L har längden noll"
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Självreferens i uttrycket för teckenlängd för %qs vid %L"
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC-funktionen %qs vid %L har PRIVATE typ %qs"
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs vid %L har ingen IMPLICIT-typ"
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Användaroperatorprocedur %qs vid %L måste vara en FUNCTION"
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Användaroperatorprocedur %qs vid %L får inte ha antagen teckenlängd"
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Användaroperatorprocedur %qs vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Första argumentet till operatorgränssnitt vid %L får inte vara frivilligt"
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Andra argumentet till operatorgränssnitt vid %L får inte vara valfritt"
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Operatorgränssnitt vid %L måste ha, högst, två argument"
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Innesluten procedur %qs vid %L i en PURE-procedur måste också vara PURE"
@@ -80749,127 +80797,127 @@ msgstr "Implicit deklarerad variabel %qs vid %L får inte vara C-interoperativ m
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr "Funktionsresultat %qs vid %L har ingen IMPLICIT-typ"
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr "%s-attribut i konflikt med %s-attribut vid %L"
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, gcc-internal-format
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr "%s-attribut i konflikt med %s-attribut i %qs vid %L"
+
+#: fortran/symbol.cc:508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr "%s-attribut är inte tillåtet i programenheten BLOCK DATA vid %L"
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "Namnlistegruppnamnet vid %L kan inte ha attributet SAVE"
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, gcc-internal-format
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr "den interna proceduren %qs vid %L står i konflikt med DUMMY-argument"
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "Procedurpekare vid %C"
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "%s-attribut applicerat på %s %s vid %L"
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) applicerat på %s %s vid %L"
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, gcc-internal-format, gfc-internal-format
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr "%s-attribut i konflikt med %s-attribut vid %L"
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, gcc-internal-format
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr "%s-attribut i konflikt med %s-attribut i %qs vid %L"
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "Det går inte att ändra attribut på USE-associerad symbol vid %L"
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "Det går inte att ändra attribut på USE-associerad symbol %s vid %L"
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "Dubblerat %s-attribut angivna vid %L"
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr "ALLOCATABLE angiven utanför INTERFACE-kropp vid %L"
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr "Dubblerat AUTOMATIC-attribut angivet vid %L"
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "CODIMENSION angiven för %qs utanför dess INTERFACE-kropp vid %L"
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "DIMENSION angiven för %qs utanför dess INTERFACE-kropp vid %L"
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "Cray-utpekad vid %L förekommer i flera pointer()-satser"
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "Dubblerat PROTECTED-attribut angivet vid %L"
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "SAVE-attribut vid %L kan inte anges i en PURE-procedur"
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "Dubblerat SAVE-attribut angivet vid %L"
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "Dubblerat VALUE-attribut angivet vid %L"
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Dubblerat VOLATILE-attribut angivet vid %L"
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr "Attributet VOLATILE vid %L kan inte anges i en PURE-procedur"
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Dubblerat ASYNCHRONOUS-attribut angivet vid %L"
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "%s-attribut på %qs i konflikt med %s-attribut vid %L"
 
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -80878,204 +80926,204 @@ msgstr ""
 "%s-proceduren vid %L är redan deklarerad som en %s-procedur. \n"
 "F2008: En tilldelning av funktionspekare är tvetydig om det är dn första exekverbara satsen efter specifikationsblocket.  Lägg någon annan sorts exekverbar sats före den. FIXAMIG"
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "Proceduren ”%s” vid %L är redan deklarerad som %s-procedur"
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) står i konflikt med INTENT(%s) vid %L"
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "ACCESS-specifikation vid %L var redan angiven"
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Dubblerat BIND-attribut angivna vid %L"
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "BIND(C) vid %L"
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Dubblerat EXTENDS-attribut angivet vid %L"
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "EXTENDS vid %L"
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Symbolen %qs vid %L har redan ett explicit gränssnitt"
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "%qs vid %L har attribut angivna utanför dess INTERFACE-kropp"
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "Symbolen %qs vid %L står i konflikt med symbolen från modulen %qs, användningsassocierad vid %L"
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Symbolen %qs vid %L har redan grundtypen %s"
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Procedur %qs vid %L får inte ha grundtypen %s"
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Symbolen %qs vid %L kan inte ha en typ"
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Komponenten %qs vid %C finns redan i föräldratypen vid %L"
 
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Symbolen %qs vid %C är tvetydig"
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Härledd typ %qs vid %C används före den är definierad"
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Komponent %qs vid %C är en PRIVATE-komponent i %qs"
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "%qs vid %C är inte en medlem av posten %qs; menade du %qs?"
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs vid %C är inte en medlem av posten %qs"
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Dubblerad satsetikett %d vid %L och %L"
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Etikett %d vid %C är redan refererad som ett grenmål"
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Etiketten %d vid %C är redan refererad som en formatetikett"
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr "DO avslutningssats som inte är END DO eller CONTINUE med etikett %d vid %C"
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Etikett %d vid %C användes tidigare som en FORMAT-etikett"
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Etikett %d vid %C användes tidigare som ett grenmål"
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "Delad DO-avslutningsetikett %d vid %C"
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr "Etiketterad DO-sats vid %L"
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Namnet %qs vid %C är en tvetydig referens till %qs från modulen %qs"
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "Namnet %qs vid %C är en tvetydig referens till %qs från den aktuella programenheten"
 
 # Vad är "host associated"?
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Symbolen %qs vid %C har redan blivit host-associerad"
 
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr "verify_bind_c_derived_type(): Den angivna symbolen är oväntat NULL"
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Härledd typ %qs deklarerad vid %L måste ha attributet BIND för att vara ett C-interoperativ"
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "Härledd typ %qs med attributet BIND(C) vid %L är tom, och kan vara otillgängliga av C-följeslagarprocessorn"
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponent %qs vid %L får inte ha attributet POINTER eftersom det är en medlem av den BIND(C)-härledda typen %qs vid %L"
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "Procedurpekarkomponenten %qs vid %L kan inte vara en medlem av den BIND(C)-härledda typen %qs vid %L"
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponent %qs vid %L får inte ha attributet ALLOCATABLE eftersom det är en medlem av den BIND(C)-härledda typen %qs vid %L"
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "Komponent %qs i härledd typ %qs vid %L får inte vara C-interoperativ, trots att den härledda typen %qs är BIND(C)"
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "Komponent %qs i härledd typ %qs vid %L får inte vara C-interoperativ"
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Härledd typ %qs vid %L kan inte ha attributet SEQUENCE för att den är BIND(C)"
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "Symbolen %qs används före den har fått sin typ vid %L"
@@ -81105,24 +81153,24 @@ msgstr "Överlappande olika initierare i EQUIVALENCE vid %L"
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "Överlappande olika initierare i EQUIVALENCE vid %C"
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr "Postkonstrueraren vid %C har avslutats. Denna funktion togs bart av f08/0011. Använd -std=f2018 eller -std=gnu för att eliminera avslutningen."
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "Antalet element i vektorkonstrueraren vid %L kräver en ökning av den tillåtna övre gränsen %d.  Se flaggan %<-fmax-array-constructor%>"
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Skapar vektortemporär vid %L för argument %qs"
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "felaktig uttryckstyp under genomlöpning (%d)"
@@ -81308,37 +81356,37 @@ msgstr "Returvärdet %qs för funktionen %qs deklarerad vid %L är inte satt"
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr "Ledsen, !$ACC DECLARE vid %L är inte tillåtet i BLOCK-konstruktion"
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr "Kan inte beräkna längden på teckenvektorn vid %L."
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr "Kod för omallokering av den allokerbara variabeln vid %L kommer läggas till"
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Ledsen, co-indexerad åtkomst till ett obegränsat polymorft objekt vid %L stödjs inte ännu"
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Ledsen, co-indexerad åtkomst till en obegränsat polymorf komponent vid %L stödjs inte"
 
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Okänd inbyggd op"
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Okänd argumentlistefunktion vid %L"
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr "Om ommappning av gränser anges vid %L skall pekarmålet inte vara NULL"
@@ -81349,17 +81397,17 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "Inbyggd funktion %qs (%d) känns inte igen"
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "%<dim%>-argumentet till inbyggd %s vid %L är inte ett giltigt dimensionsindex"
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "Ledsen, händelsekomponenten hos härledd typ vid %L stödjs inte ännu"
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "Händelsevariabeln vid %L får inte vara co-indexerad"
@@ -81499,7 +81547,7 @@ msgstr "Ledsen, låskomponenten hos härledd typ vid %L stödjs inte ännu"
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr "Tyvärr, endast stöd för heltalssort %d implementerad för bildmängden vid %L"
 
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr "gfc_trans_select(): Felaktig typ för Bad type for case-uttryck."
@@ -81865,6 +81913,11 @@ msgstr "variabeln %qD omdeklarerad som en funktion"
 msgid "function %qD redeclared as variable"
 msgstr "funktionen %qD omdeklarerad som en variabel"
 
+#: lto/lto-symtab.cc:865
+#, gcc-internal-format
+msgid "previously declared here"
+msgstr "tidigare deklarerad här"
+
 #: lto/lto.cc:174
 #, gcc-internal-format
 msgid "%<lto_obj_file_open()%> failed"
@@ -83102,7 +83155,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr "%<-fobjc-sjlj-exceptions%> ignoreras för %<-fgnu-runtime%>"
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, gcc-internal-format
 msgid "non-objective-c type %qT cannot be caught"
 msgstr "typen %qT som inte är objective-c kan inte fångas"
@@ -83112,7 +83165,7 @@ msgstr "typen %qT som inte är objective-c kan inte fångas"
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr "%<-fobjc-sjlj-exceptions%> är det enda undantagssystem som stödjs för %<-fnext-runtime%> med %<-fobjc-abi-version%>-argument mindre än 2"
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, gcc-internal-format
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
 msgstr "%<-fobjc-sjlj-exceptions%> ignoreras för %<-fnext-runtime%> när %<-fobjc-abi-version%> är större än 1"
diff --git a/gcc/po/tr.po b/gcc/po/tr.po
index c5677215f9d..e953deaa8ed 100644
--- a/gcc/po/tr.po
+++ b/gcc/po/tr.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 5.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
 "PO-Revision-Date: 2015-09-11 20:22+0300\n"
 "Last-Translator: Nilgün Belma Bugüner <nilgun@fide.org>\n"
 "Language-Team: Turkish <gnu-tr-u12a@lists.sourceforge.net>\n"
@@ -456,7 +456,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr "hem -C hem de -o belirtilemez"
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 msgid "shared and mdll are not compatible"
 msgstr "shared ve mdll uyumsuz"
 
@@ -21456,18 +21456,18 @@ msgstr "tanımlanamayan komut:"
 msgid "insn does not satisfy its constraints:"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "`%s''in farklı ayarları ile oluşturulup kullanılmış"
 
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "-fpic'in farklı ayarları ile oluşturulup kullanıldı"
 
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 #, fuzzy
 #| msgid "created and used with different settings of -fpie"
 msgid "created and used with different settings of %<-fpie%>"
@@ -21803,7 +21803,7 @@ msgstr "strfmon biçiminde uzunluk değiştirici"
 msgid "<command-line>"
 msgstr "<komut-satırı>"
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "unsupported operand for code '%c'"
@@ -21824,9 +21824,9 @@ msgstr "terim, kod `%c' için geçersiz"
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid vector constant"
@@ -21849,7 +21849,7 @@ msgstr "terim, kod `%c' için geçersiz"
 msgid "incompatible register operand for '%%%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, c-format
 msgid "missing operand"
 msgstr "terim eksik"
@@ -21884,93 +21884,93 @@ msgstr "adres geçersiz"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "iki terimli %s için terimler geçersiz"
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, c-format
 msgid "invalid %%J value"
 msgstr "%%J değeri geçersiz"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, c-format
 msgid "invalid %%r value"
 msgstr "%%r değeri geçersiz"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, c-format
 msgid "invalid %%R value"
 msgstr "%%R değeri geçersiz"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, c-format
 msgid "invalid %%N value"
 msgstr "%%N değeri geçersiz"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, c-format
 msgid "invalid %%P value"
 msgstr "%%P değeri geçersiz"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, c-format
 msgid "invalid %%h value"
 msgstr "%%h değeri geçersiz"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, c-format
 msgid "invalid %%L value"
 msgstr "%%L değeri geçersiz"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, c-format
 msgid "invalid %%m value"
 msgstr "%%m değeri geçersiz"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, c-format
 msgid "invalid %%M value"
 msgstr "%%M değeri geçersiz"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, c-format
 msgid "invalid %%U value"
 msgstr "%%U değeri geçersiz"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, c-format
 msgid "invalid %%s value"
 msgstr "%%s değeri geçersiz"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, c-format
 msgid "invalid %%C value"
 msgstr "%%C değeri geçersiz"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, c-format
 msgid "invalid %%E value"
 msgstr "%%E değeri geçersiz"
 
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "bilinmeyen yerdeğişim unspec"
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, c-format
 msgid "invalid %%xn code"
 msgstr "%%xn kodu geçersiz"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid operand address"
@@ -22073,37 +22073,37 @@ msgstr "terim olarak UNSPEC geçersiz"
 msgid "unrecognized supposed constant"
 msgstr "tanınmayan tahmini sabit"
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, fuzzy, c-format
 #| msgid "invalid %%f operand"
 msgid "invalid shift operand"
 msgstr "geçersiz %%f terimi"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "isnatlı Thumb komutu"
 
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "koşullu dizilimde isnatlı komut"
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "Unsupported operand for code '%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -22111,134 +22111,134 @@ msgstr "terim, kod `%c' için geçersiz"
 msgid "invalid operand for code '%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, fuzzy, c-format
 #| msgid "instruction never exectued"
 msgid "instruction never executed"
 msgstr "komut hiç çalıştırılmadı"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "%<__fpreg%> türünden dönüşüm geçersiz"
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "%qT'ye %qT'den dönüşüm geçersiz"
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr ""
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 #, fuzzy
 #| msgid "output operand %d must use %<&%> constraint"
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "çıktı terimi %d %<&%> kısıtını kullanmalı"
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 #, fuzzy
 #| msgid "bad address, not (reg+disp):"
 msgid "bad address, not an I/O address:"
 msgstr "hatalı adres, (reg+disp) değil:"
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 #, fuzzy
 #| msgid "address offset not a constant"
 msgid "bad address, not a constant:"
 msgstr "adres mesafesi bir sabit değil"
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 msgid "bad address, not (reg+disp):"
 msgstr "hatalı adres, (reg+disp) değil:"
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "hatalı adres, post_inc veya pre_dec değil:"
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr "derleyici iç hatası.  Hatalı adres:"
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 msgid "internal compiler error.  Unknown mode:"
 msgstr "Derleyici iç hatası.  Bilinmeyen kip:"
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 msgid "invalid insn:"
 msgstr "geçersiz komut:"
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 msgid "incorrect insn:"
 msgstr "yanlış komut:"
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 msgid "unknown move insn:"
 msgstr "bilinmeyen taşıma komutu:"
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 msgid "bad shift insn:"
 msgstr "hatalı kaydırma komutu:"
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "derleyici iç hatası.  Yanlış kaydırma:"
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 #, fuzzy
 #| msgid "unsupported combination: %s"
 msgid "unsupported fixed-point conversion"
 msgstr "desteklenmeyen birleşim: %s"
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "variable"
 msgstr "Değişken izleme uygulanır"
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "function parameter"
 msgstr "%q+D parametresinin yeniden tanımlanması"
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 #, fuzzy
 #| msgid "%q+#D previously defined here"
 msgid "structure field"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 #, fuzzy
 #| msgid "creating array of %qT"
 msgid "return type of function"
 msgstr "%qT dizisi oluşturulması"
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 #, fuzzy
 #| msgid "PRINT_OPERAND null pointer"
 msgid "pointer"
@@ -22279,7 +22279,7 @@ msgstr "beklenmeyen terim"
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -22616,55 +22616,55 @@ msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "terim kodu `%c' geçersiz"
 
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "kısıtlar terim için geçersiz"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, fuzzy, c-format
 #| msgid "invalid conditional operand"
 msgid "invalid vector immediate"
 msgstr "koşullu terim geçersiz"
 
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 msgid "unknown insn mode"
 msgstr "bilinmeyen komut kipi"
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr "%<__fpreg%> türünden dönüşüm geçersiz"
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr "%<__fpreg%> türünden dönüşüm geçersiz"
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr "%<__fpreg%> türüne dönüşüm geçersiz"
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr "%qT'ye %qT'den dönüşüm geçersiz"
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
 msgstr ""
 
@@ -22696,7 +22696,7 @@ msgstr "%<__fpreg%> üzerinde geçersiz işlem"
 msgid "invalid %%P operand"
 msgstr "%%P terimi geçersiz"
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, c-format
 msgid "invalid %%p value"
 msgstr "%%p değeri geçersiz"
@@ -22727,30 +22727,30 @@ msgstr ""
 msgid "invalid addressing mode"
 msgstr "adres geçersiz"
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, fuzzy, c-format
 #| msgid "'%s' is not a valid class name"
 msgid "'%%%c' is not a valid operand prefix"
 msgstr "'%s' geçerli bir sınıf ismi değil"
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, fuzzy, c-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of '%%%c'"
@@ -22783,7 +22783,7 @@ msgid "post-increment address is not a register"
 msgstr "sonradan arttırımlı adres bir yazmaç değil"
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 msgid "bad address"
 msgstr "hatalı adres"
 
@@ -22957,7 +22957,7 @@ msgstr "desteklenmeyen birleşim: %s"
 msgid "unsupported memory expression:"
 msgstr "desteklenmeyen birleşim: %s"
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, fuzzy, c-format
 #| msgid "invalid %%P operand"
 msgid "invalid vector operand"
@@ -23018,278 +23018,278 @@ msgstr "--resource, -o gerektirir"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "Kıymetsiz baytın başta olduğu kod üretilir"
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "hatalı test"
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%A value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%D value"
 msgstr "%%D değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, c-format
 msgid "invalid %%f value"
 msgstr "%%f değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, c-format
 msgid "invalid %%F value"
 msgstr "%%F değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, c-format
 msgid "invalid %%G value"
 msgstr "%%G değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, c-format
 msgid "invalid %%j code"
 msgstr "%%j kodu geçersiz"
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, c-format
 msgid "invalid %%J code"
 msgstr "%%J kodu geçersiz"
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, c-format
 msgid "invalid %%k value"
 msgstr "%%k değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, c-format
 msgid "invalid %%K value"
 msgstr "%%K değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, c-format
 msgid "invalid %%O value"
 msgstr "%%O değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, c-format
 msgid "invalid %%q value"
 msgstr "%%q değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, c-format
 msgid "invalid %%T value"
 msgstr "%%T değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, c-format
 msgid "invalid %%u value"
 msgstr "%%u değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, c-format
 msgid "invalid %%v value"
 msgstr "%%v değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, c-format
 msgid "invalid %%x value"
 msgstr "%%x değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "kısıt içindeki `%qc' işareti geçersiz"
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec argümanı prototipsiz işleve aktarıldı"
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Her işlev için tek çıkış noktası üretilmez"
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "aşağıdakiler için yeniden yüklemeler üretilemiyor:"
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "%<__fpreg%> türünden dönüşüm geçersiz"
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "%<__fpreg%> türüne dönüşüm geçersiz"
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "%<__fpreg%> türünden dönüşüm geçersiz"
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "%<__fpreg%> türüne dönüşüm geçersiz"
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, c-format
 msgid "cannot decompose address"
 msgstr "adres çözümlenemez"
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "'b' değiştirici için terim geçersiz"
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid reference for 'J' output modifier"
 msgstr "'b' değiştirici için terim geçersiz"
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, fuzzy, c-format
 #| msgid "invalid operand for 'O' modifier"
 msgid "invalid address for 'O' output modifier"
 msgstr "'O' değiştiricisi için terim geçersiz"
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'R' output modifier"
 msgstr "'b' değiştirici için terim geçersiz"
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'S' output modifier"
 msgstr "'b' değiştirici için terim geçersiz"
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant for output modifier '%c'"
 msgstr "'o' değiştiricisi için terim geçersiz"
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, fuzzy, c-format
 #| msgid "invalid operand output code"
 msgid "invalid constant - try using an output modifier"
 msgstr "geçersiz terim çıktı kodu"
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "'o' değiştiricisi için terim geçersiz"
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid expression - try using an output modifier"
 msgstr "terim olarak ifade geçersiz"
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid expression for output modifier '%c'"
 msgstr "'o' değiştiricisi için terim geçersiz"
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "AltiVec argümanı prototipsiz işleve aktarıldı"
 
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "dönüş değerinde gösterici hedefleri farklı signed'lıkta"
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 #, fuzzy
 #| msgid "target format does not support infinity"
 msgid "binary operator does not support vector bool operand"
 msgstr "hedef biçim sonsuzu desteklemiyor"
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -23494,12 +23494,12 @@ msgstr "<anonim>"
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> umuluyordu"
@@ -23512,7 +23512,7 @@ msgstr "%<;%> umuluyordu"
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -23521,7 +23521,7 @@ msgstr "%<;%> umuluyordu"
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -23530,7 +23530,7 @@ msgstr "%<{%> umuluyordu"
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -23544,31 +23544,31 @@ msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<(%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
 msgstr "%<{%> umuluyordu"
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> umuluyordu"
@@ -23578,18 +23578,18 @@ msgstr "%<{%> umuluyordu"
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
@@ -23599,8 +23599,8 @@ msgstr "%<{%> umuluyordu"
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -23613,19 +23613,19 @@ msgid "expected %<.%>"
 msgstr "%<{%> umuluyordu"
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -23634,35 +23634,35 @@ msgstr "%<,%> veya %<;%> umuluyordu"
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> umuluyordu"
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<else%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<}%>"
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<,%> veya %<}%> umuluyordu"
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr ""
 
@@ -23672,7 +23672,7 @@ msgstr ""
 msgid "(anonymous)"
 msgstr "<anonim>"
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -23691,13 +23691,13 @@ msgstr "sınıf ismi umuluyordu"
 msgid "candidate:"
 msgstr "1. aday:"
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 #, fuzzy
 #| msgid "Enable use of DB instruction"
 msgid "  after user-defined conversion:"
 msgstr "DB komutunun kullanımı etkin olur"
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -23705,11 +23705,11 @@ msgid_plural "candidates are:"
 msgstr[0] "1. aday:"
 msgstr[1] "1. aday:"
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr "1. aday:"
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr "2. aday:"
 
@@ -24002,7 +24002,7 @@ msgstr ""
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 msgid "candidates are:"
 msgstr "adaylar:"
 
@@ -24060,50 +24060,50 @@ msgstr ""
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "tek terimli eksiye yanlış türde argüman"
 
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "tek terimli artıya yanlış türde argüman"
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "bit-tümler için yanlış türde argüman"
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "abs'a yanlış türde argüman"
 
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "mantıksal çarpım için yanlış türde argüman"
 
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 #, fuzzy
 #| msgid "wrong type argument to unary plus"
 msgid "in argument to unary !"
 msgstr "tek terimli artıya yanlış türde argüman"
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 msgid "no pre-increment operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 msgid "no post-increment operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 msgid "no pre-decrement operator for type"
 msgstr ""
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 msgid "no post-decrement operator for type"
 msgstr ""
 
@@ -24186,7 +24186,7 @@ msgstr ""
 msgid "Deleted feature:"
 msgstr ""
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 #, fuzzy
 #| msgid "Array assignment"
 msgid "array assignment"
@@ -24387,11 +24387,11 @@ msgstr "blok IF"
 msgid "implied END DO"
 msgstr "örtük END DO"
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 msgid "assignment"
 msgstr "atama"
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 msgid "pointer assignment"
 msgstr "gösterici ataması"
 
@@ -24592,59 +24592,59 @@ msgstr "%%L'deki '%s' kullanıcı işlecinin terimi %s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "%%L'deki '%s' kullanıcı işlecinin terimleri %s/%s"
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "iterator variable"
 msgstr "Değişken izleme uygulanır"
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "terim olarak ifade geçersiz"
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "YERAÇ "
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "AYIR "
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -24653,11 +24653,11 @@ msgstr ""
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr ""
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
@@ -24672,12 +24672,12 @@ msgstr ""
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -24686,84 +24686,84 @@ msgstr ""
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, fuzzy, c-format
 #| msgid "different shape for arguments '%s' and '%s' at %L for intrinsic 'dot_product'"
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "'%s' ve '%s' argümanları 'dot_product' yerleşiği için (%L'de) farklı biçimde"
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, fuzzy, c-format
 #| msgid "different shape for arguments '%s' and '%s' at %L for intrinsic 'dot_product'"
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "'%s' ve '%s' argümanları 'dot_product' yerleşiği için (%L'de) farklı biçimde"
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, fuzzy, c-format
 #| msgid "Argument of SQRT at %L has a negative value"
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "%L'de SQRT'nin argümanı negatif değer içeriyor"
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, c-format
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, c-format
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
@@ -24789,15 +24789,15 @@ msgstr "Atanmış yafta bir hedef yaftası değil"
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 msgid "Loop variable has been modified"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 msgid "DO step value is zero"
 msgstr ""
 
@@ -24884,7 +24884,7 @@ msgid "expected boolean type"
 msgstr "İfade türü umuluyordu"
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -24966,7 +24966,7 @@ msgstr "argüman yok"
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments for format"
 msgid "too many arguments"
@@ -25710,7 +25710,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "static TPF-OS'da desteklenmiyor"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s deyiminde sözdizimi hatası (%C'de)"
@@ -26207,8 +26207,8 @@ msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration here"
@@ -26228,7 +26228,7 @@ msgstr "%qs öznitelik yönergesi yoksayıldı"
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr "%qs öznitelik yönergesi yoksayıldı"
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments specified for %qE attribute"
@@ -26240,7 +26240,7 @@ msgstr "%qs özniteliği için belirtilen argüman sayısı yanlış"
 msgid "expected %i or more, found %i"
 msgstr "Beklenmeyen modül sonu"
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %i, found %i"
@@ -26311,12 +26311,12 @@ msgstr "tür öznitelikleri sadece tür tanımlarında uygulanabilir"
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -26325,7 +26325,7 @@ msgstr "tür öznitelikleri sadece tür tanımlarında uygulanabilir"
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -26347,8 +26347,8 @@ msgstr "%qE özniteliği yoksayıldı"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %qD"
@@ -26466,7 +26466,7 @@ msgstr "sınıf %s için dosya bulunamıyor"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "göreli konum sabit dizgenin sınırlarının dışında"
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qE declared here"
@@ -26583,7 +26583,7 @@ msgstr "\"%s\" için argüman eksik"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
@@ -26607,46 +26607,46 @@ msgstr "%<__builtin_longjmp%>'in ikinci argümanı 1 olmalı"
 msgid "target format does not support infinity"
 msgstr "hedef biçim sonsuzu desteklemiyor"
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, fuzzy, gcc-internal-format
 #| msgid "%<va_start%> used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> işlev içinde sabit sayıda argümanla kullanılmış"
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %<va_start%>"
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "%<va_start%> işlevine çok az argüman verilmiş"
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> argümansız çağrılmış"
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %<va_start%>"
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "%<va_start%> işlevine çok az argüman verilmiş"
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%>'in ikinci parametresi isimli son argüman değil"
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr "%H%D için ilk argüman bir gösterici, ikinci argüman sabit olmalıdır"
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, fuzzy, gcc-internal-format
 #| msgid "%Hlast argument of %D is not integer constant between 0 and 3"
 msgid "last argument of %qD is not integer constant between 0 and 3"
@@ -27775,12 +27775,12 @@ msgstr ""
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F işlevi tanımlanmadan kullanılmış"
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
@@ -28388,7 +28388,7 @@ msgstr "dizi bölge ağacıyla eşleşmiyor"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "dizi bölge ağacıyla eşleşmiyor"
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, fuzzy, gcc-internal-format
 #| msgid "can't open input file: %s"
 msgid "%qs failed"
@@ -28420,19 +28420,19 @@ msgstr "Kod Boehm GC için üretilir"
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "call to %qs declared with attribute error: %s"
 msgstr "%q+D işlevinin yeniden bildirimi inline öznitelikli değil"
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "call to %qs declared with attribute warning: %s"
 msgstr "%q+D işlevinin yeniden bildirimi inline öznitelikli değil"
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
 msgstr ""
@@ -28472,7 +28472,7 @@ msgstr "büyük tamsayı örtük olarak unsigned türe indirgendi"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "karşılaştırma bit alanının genişliğinden dolayı daima %d"
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -28659,7 +28659,7 @@ msgstr "süreç zamanlarını almada başarısızlık"
 msgid "%s signal terminated program %s"
 msgstr "Diğer yazmaç isimleri kullanılır"
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized command-line option %qs"
@@ -28953,7 +28953,7 @@ msgstr "multilib spec '%s' geçersiz"
 msgid "multilib exclusions %qs is invalid"
 msgstr "multilib dışlaması olarak '%s' geçersiz"
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, fuzzy, gcc-internal-format
 #| msgid "multilib select '%s' is invalid"
 msgid "multilib select %qs %qs is invalid"
@@ -29292,24 +29292,24 @@ msgstr ""
 msgid "%qD specified bound %E equals source length"
 msgstr ""
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr "%Jesnek dizi yapının son üyesi değil"
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr ""
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%s not supported for variable length aggregates"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%s not supported on this target"
@@ -29354,16 +29354,16 @@ msgid "function returns address of local variable"
 msgstr "işlev yerel değişkenin adresi ile dönüyor"
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, fuzzy, gcc-internal-format
@@ -29376,370 +29376,370 @@ msgstr "burada bildirilmiş %q+D"
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "referenced argument declared here"
 msgstr "deyim umuluyordu"
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments to %s at %L"
 msgid "directive argument %qE"
 msgstr "%s için argümanlar %L'de çok fazla"
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "directive argument in the range [%E, %E]"
 msgstr "seçici 0..%wi aralığında bir tamsayı sabit olmalı"
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgid_plural "%qE output %wu bytes into a destination of size %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 msgid "%qE argument %Z overlaps destination object %qE"
 msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 msgid "%qE argument %Z may overlap destination object %qE"
 msgid_plural "%qE arguments %Z may overlap destination object %qE"
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, gcc-internal-format
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, fuzzy, gcc-internal-format
 #| msgid "PRINT_OPERAND null pointer"
 msgid "null destination pointer"
 msgstr "PRINT_OPERAND boş gösterici"
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, fuzzy, gcc-internal-format
 #| msgid "%s in format string at %C"
 msgid "null format string"
@@ -30512,12 +30512,12 @@ msgstr "gösterici kipi olarak %qs geçersiz"
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -31330,7 +31330,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid use of attribute %<fallthrough%>"
@@ -31700,17 +31700,17 @@ msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 msgid "mismatching definition"
 msgstr "tanım eksik"
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr ""
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, gcc-internal-format
 msgid "IPA modref summary is missing in input file"
 msgstr ""
@@ -32831,83 +32831,83 @@ msgstr "%s yazılırken hata: %m"
 msgid "error closing optimization records %qs"
 msgstr "Çapraz atlama eniyilemesi uygulanır"
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, fuzzy, gcc-internal-format
 #| msgid "command line option %qs is not supported by this configuration"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "komut satırı seçeneği %qs bu yapılandırmada desteklenmiyor"
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"%s\""
 msgid "missing argument to %qs"
 msgstr "\"%s\" için argüman eksik"
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr "\"%s\" için argüman sıfır ya da pozitif bir tamsayı olmalı"
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "argument to %qs should be a non-negative integer"
 msgstr "\"%s\" için argüman sıfır ya da pozitif bir tamsayı olmalı"
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-loops=%d is not between 0 and %d"
 msgid "argument to %qs is not between %d and %d"
 msgstr "-malıgn-loops=%d, 0 ile %d arasında değil"
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "invalid argument in option %qs"
 msgstr "komut satırı seçeneği \"%s\" tanınmıyor"
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr ""
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, fuzzy, gcc-internal-format
 #| msgid "-mips16 and -mdsp cannot be used together"
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr "-mips16 ve -mdsp birlikte kullanılamaz"
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized argument in option %qs"
 msgstr "komut satırı seçeneği \"%s\" tanınmıyor"
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "switch %qs artık desteklenmiyor"
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qs is bigger than %d"
 msgstr "%qs özniteliğine argüman %d den büyük"
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, gcc-internal-format
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
 msgstr ""
@@ -32989,8 +32989,8 @@ msgstr "\"%s\" için argüman sıfır ya da pozitif bir tamsayı olmalı"
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%qs is incompatible with %qs"
@@ -33769,7 +33769,7 @@ msgstr "genel yazmaç değişkeni bir işlev tanımını izliyor"
 msgid "register of %qD used for multiple global register variables"
 msgstr "yazmaç iki genel yazmaç değişkeni için kullanılmış"
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, fuzzy, gcc-internal-format
 #| msgid "  conflict with %q+D"
 msgid "conflicts with %qD"
@@ -34245,47 +34245,47 @@ msgstr ""
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "__builtin_saveregs bu hedef tarafından desteklenmiyor"
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, fuzzy, gcc-internal-format
 #| msgid "global destructors not supported on this target"
 msgid "nested functions not supported on this target"
 msgstr "bu hedefte global yıkıcılar desteklenmiyor"
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, fuzzy, gcc-internal-format
 #| msgid "-ffunction-sections not supported for this target"
 msgid "nested function trampolines not supported on this target"
 msgstr "bu hedefte -ffunction-sections desteklenmiyor"
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "bu hedefte global yapıcılar desteklenmiyor"
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "bu hedefte global yıkıcılar desteklenmiyor"
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "bu platformda %qE özniteliği desteklenmiyor"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "bu platformda %qE özniteliği desteklenmiyor"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma extern_prefix not supported on this target"
 msgid "%<#pragma GCC target%> is not supported for this machine"
@@ -35541,89 +35541,89 @@ msgstr "BB %i son deyiminin bölgesi yanlış belirlenmiş"
 msgid "BB %i has incorrect fallthru edge"
 msgstr "düşen ayrıtta yanlış komut"
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it receives a non-local goto"
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr "%q+F işlevi yerel olmayan goto içerdiğinden satıriçine alınamaz"
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses variable sized variables"
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr "%q+F işlevi değişken boyutlu değişkenler kullandığından satıriçine alınamaz"
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr "%q+F işlevi alloca kullandığından satıriçine alınamaz (always_inline özniteliği ile zorlanabilir)"
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr "%q+F işlevi setjmp kullandığından asla satıriçine alınamaz"
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr "%q+F işlevi değişkin argüman listesi kullandığından asla satıriçine alınamaz"
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr "%q+F işlevi setjmp-longjmp olağandışılık eylemcisi kullandığından asla satıriçine alınamaz"
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr "%q+F işlevi yerel olmayan goto içerdiğinden asla satıriçine alınamaz"
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses __builtin_return or __builtin_apply_args"
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr "%q+F işlevi __builtin_return veya __builtin_apply_args kullandığından satıriçine alınamaz"
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr "%q+F işlevi bir hesaplanmış goto içerdiğinden satıriçine alınamaz"
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr "%q+F işlevi değişkin argüman listesi kullandığından asla satıriçine alınamaz"
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it is suppressed using -fno-inline"
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr "%q+F işlevi -fno-inline kullanılarak engellendiğinden satır içine alınamaz"
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr "%q+F işlevinin öznitelikleri satıriçine alınma ile çeliştiğinden işlev asla satıriçine alınamaz"
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, fuzzy, gcc-internal-format
 #| msgid "inlining failed in call to %q+F: %s"
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr "%q+F çağrısında satıriçine alma başarısız: %s"
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr "buradan çağrıldı"
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "called from this function"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, gcc-internal-format
 msgid "inlining failed in call to %q+F: %s"
 msgstr "%q+F çağrısında satıriçine alma başarısız: %s"
@@ -35681,29 +35681,29 @@ msgstr "%qE özniteliği için vektör türü geçersiz"
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr "%qE özniteliği için vektör türü geçersiz"
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "in a call to non-static member function %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "in a call to built-in function %qD"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "in a call to function %qD declared %qs"
@@ -35920,7 +35920,7 @@ msgstr "ilklendirici yok"
 msgid "%qs may be used uninitialized"
 msgstr "%H%qD bu işlevde ilklendirilmeden kullanılmış olmalı"
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD was declared here"
@@ -36161,7 +36161,7 @@ msgstr ""
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -36176,132 +36176,132 @@ msgstr ""
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "işlev dizileri anlamlı değil"
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "işlevin dönüş türü işlev olamaz"
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$s, %4$s dosyasının %5$d. satırında %3$s işlevinde %2$s var"
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$s umulmuyordu, %4$s dosyasının %5$d. satırında %3$s işlevinde %2$s var"
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, fuzzy, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$qs sınıfı umuluyordu, %5$s dosyasının %6$d. satırında %4$s işlevinde %2$qs (%3$s) var"
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, fuzzy, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$qs sınıfı umuluyordu, %5$s dosyasının %6$d. satırında %4$s işlevinde %2$qs (%3$s) var"
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, fuzzy, gcc-internal-format
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$s umulmuyordu, %4$s dosyasının %5$d. satırında %3$s işlevinde %2$s var"
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, fuzzy, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$qs yapısını içeren ağaç umuluyordu, %4$s dosyasının %5$d. satırında %3$s işlevinde %2$qs var"
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, fuzzy, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr "ağaç denetimi: %4$s dosyasının %5$d. satırında %3$s işlevinde %2$d öğelik ağaç vektörünün %1$d. öğesine erişildi"
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, fuzzy, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr "ağaç denetimi: %4$s dosyasının %5$d. satırında %3$s işlevinde %2$d öğelik ağaç vektörünün %1$d. öğesine erişildi"
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "ağaç denetimi: %5$s dosyasının %6$d. satırında %4$s işlevinde %3$d terimli %2$s düğümünün %1$d. terimine erişildi"
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, fuzzy, gcc-internal-format
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "ağaç denetimi: %5$s dosyasının %6$d. satırında %4$s işlevinde %3$d terimli %2$s düğümünün %1$d. terimine erişildi"
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated: %s"
 msgstr "%qs önerilmiyor"
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated"
 msgstr "%qs önerilmiyor"
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated: %s"
 msgstr "%qs önerilmiyor"
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated"
 msgstr "%qs önerilmiyor"
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type is deprecated"
 msgid "type is deprecated: %s"
 msgstr "tür önerilmiyor"
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "tür önerilmiyor"
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is unavailable: %s"
 msgstr "%qD bir şablon değil"
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is unavailable"
 msgstr "%qD bir şablon değil"
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qE is unavailable: %s"
 msgstr "%qD bir şablon değil"
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qE is unavailable"
 msgstr "%qD bir şablon değil"
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "can't open input file: %s"
 msgid "type is unavailable: %s"
 msgstr "girdi dosyası açılamıyor: %s"
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "type is unavailable"
@@ -36327,269 +36327,269 @@ msgstr "%qD bir şablon değil"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, fuzzy, gcc-internal-format
 #| msgid "%s:stamp mismatch with graph file\n"
 msgid "first mismatch is field"
 msgstr "%s: zaman damgası çizge dosyası ile çelişiyor\n"
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "type is not compatible with its variant"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qT is not a template type"
 msgid "type %s is not an opaque type"
 msgstr "%qT bir şablon türü değil"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "type %s is not with opaque mode"
 msgstr "%qT türü bir doğrudan %qT tabanı değil"
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr ""
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr ""
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "main variant is not defined"
 msgstr "ortam değişkeni DJGPP atanmamış"
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "%qs dizisinin boyutu tamsayı tür değil"
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has an incomplete type"
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "%qD bir tamamlanmamış tür içeriyor"
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -36827,7 +36827,7 @@ msgstr "%Jtakma ad tanımlamaları bu yapılandırmada desteklenmiyor"
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "görünürlük özniteliği bu yapılandırmada desteklenmiyor; yoksayıldı"
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr ""
@@ -37060,7 +37060,7 @@ msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE özniteliği sadece genel nesnelerde etkilidir"
@@ -37265,7 +37265,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for local variables"
@@ -37628,7 +37628,7 @@ msgstr "assert: %s %s ile uyumlu atanıyor"
 msgid "%qE argument is not a function"
 msgstr "cleanup argümanı bir işlev değil"
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "deprecated message is not a string"
@@ -38184,7 +38184,7 @@ msgstr "new bir işlev türe uygulanamaz"
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr "new bir işlev türe uygulanamaz"
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, gcc-internal-format
 msgid "invalid application of %qs to a void type"
 msgstr "bir void türe %qs uygulanması geçersiz"
@@ -38323,17 +38323,17 @@ msgstr ""
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "öntanımlı argüman %2$q#D bildiriminin %1$d. parametresi için"
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "%qE işlevi için çok az argüman belirtildi"
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, gcc-internal-format
@@ -38473,126 +38473,126 @@ msgstr "bit-alanı yapısının %qD üyesinin adresi alınmaya çalışılıyor"
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of array is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, fuzzy, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "%2$qE işlevinin %1$d. argümanı için tür uyumsuz"
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, fuzzy, gcc-internal-format
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımı sırasında bir tür dönüşümü olmaksızın tamsayıdan gösterici yapılıyor"
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "both arguments must be compatible"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "incorrect number of arguments to function %qE"
 msgstr "%qE işlevi için çok az argüman belirtildi"
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "%qs argümanı 2 bitlik işaretsiz bir sabit olmalı"
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr "%H%D için ilk argüman bir gösterici, ikinci argüman sabit olmalıdır"
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "%H%D için ilk argüman bir gösterici, ikinci argüman sabit olmalıdır"
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "%H%D için ilk argüman bir gösterici, ikinci argüman sabit olmalıdır"
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "%H%D için ilk argüman bir gösterici, ikinci argüman sabit olmalıdır"
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "size mismatch in argument %d of %qE"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr "%H%D için ilk argüman bir gösterici, ikinci argüman sabit olmalıdır"
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr "%2$qE işlevinin %1$d. argümanına aktarım gösterici hedef türündeki niteleyicileri iptal ediyor"
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr "%H%D için ilk argüman bir gösterici, ikinci argüman sabit olmalıdır"
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr "%2$qE işlevinin %1$d. argümanına aktarım gösterici hedef türündeki niteleyicileri iptal ediyor"
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, fuzzy, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "%2$qE işlevinin %1$d. argümanı için tür uyumsuz"
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid memory model argument %d of %qE"
 msgstr "%qs için tür argümanı geçersiz"
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, fuzzy, gcc-internal-format
 #| msgid "Substring end index at %L is out of bounds"
 msgid "index value is out of bound"
 msgstr "%L'deki altdizge son indisi sınırların dışında"
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qT to vector %qT involves truncation"
@@ -38600,59 +38600,59 @@ msgstr "%qT türünden %qT türüne dönüşüm belirsiz"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qE must be directly called"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "size of array %qE is not a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array is not a constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "%qs dizisinin boyutu negatif"
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "dizi boyutu negatif"
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "%qs dizisinin boyutu negatif"
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -39321,7 +39321,7 @@ msgstr "tamsayı sabit %qs türü için oldukça büyük"
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr "tamsayı sabit %qs türü için oldukça büyük"
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<_BitInt(%d)%> is not supported on this target"
@@ -39408,7 +39408,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr "geleneksel C dizge sabitlerin birleştirilmesine izin vermez"
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -39465,7 +39465,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid type for iteration variable %qE"
@@ -39483,18 +39483,18 @@ msgstr "%qE özniteliği için vektör türü geçersiz"
 msgid "%qE is not initialized"
 msgstr "ilklendirici yok"
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conditional operand"
 msgid "invalid controlling predicate"
 msgstr "koşullu terim geçersiz"
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, fuzzy, gcc-internal-format
 #| msgid "assignment suppression"
 msgid "missing increment expression"
@@ -39505,7 +39505,7 @@ msgstr "atama engelleme"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, fuzzy, gcc-internal-format
 #| msgid "invalid truth-value expression"
 msgid "invalid increment expression"
@@ -39598,7 +39598,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -39609,7 +39609,7 @@ msgstr ""
 msgid "%qD is not a function argument"
 msgstr "%qD bir işlev şablonu değil"
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE in %qs clause"
@@ -40270,7 +40270,7 @@ msgid "wrong type argument to %s"
 msgstr "abs'a yanlış türde argüman"
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -41297,35 +41297,35 @@ msgstr "%q#T ile %q#T arasında karşılaştırma"
 
 #: c-family/c-warn.cc:3832
 #, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3836
+#: c-family/c-warn.cc:3839
 #, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr ""
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr ""
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr ""
@@ -41559,120 +41559,120 @@ msgstr "-mregparm=%d, 0 ile %d arasında değil"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, gcc-internal-format
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, gcc-internal-format
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, gcc-internal-format
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr "-mcpu=%s ile -march= seçenekleri çelişiyor"
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, fuzzy, gcc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr "-mcpu=%s ile -march= seçenekleri çelişiyor"
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, gcc-internal-format
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qE is unknown"
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "%qE türü bilinmiyor"
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr ""
@@ -42115,13 +42115,13 @@ msgstr "%q.*s biçiminin %<%T%s%> türünde olması umuluyor, ama %d. argüman %
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "%q.*s biçiminin %<%T%s%> türünde olması umuluyor, ama %d. argüman %qT türünde"
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma GCC pch_preprocess, ignored"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
@@ -42725,7 +42725,7 @@ msgstr ""
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
@@ -42808,12 +42808,12 @@ msgid "unknown tuning option (%s)"
 msgstr "bilinmeyen '%s' spec işlevi"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
@@ -42824,7 +42824,7 @@ msgid "specify a system register with a small string length"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid output file"
 msgid "%qs is not a valid offset in %qs"
@@ -43020,9 +43020,9 @@ msgstr ""
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
@@ -43080,19 +43080,19 @@ msgid "virtual function multiversioning not supported"
 msgstr "yığıt sınırlama ifadesi desteklenmiyor"
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "__builtin_eh_return bu hedefte desteklenmiyor"
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
@@ -43105,8 +43105,8 @@ msgstr ""
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %wd"
@@ -43118,7 +43118,7 @@ msgstr "desteklenmeyen birleşim: %s"
 msgid "GCC does not currently support return type %qT for simd"
 msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported return type %qT for simd"
@@ -43130,7 +43130,7 @@ msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd"
@@ -43232,8 +43232,8 @@ msgstr "%2$s için L%1$d arabellek gecikmesi bilinmiyor"
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "-mmemory-latency için değer %qs hatalı"
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr "hatalı yerleşik fcode"
@@ -43365,18 +43365,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "%qs özniteliğinin argümanı \"ilink1\" ya da \"ilink2\" değildir"
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -43504,7 +43504,7 @@ msgid "argument of %qE attribute is missing"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute allows only an integer constant argument"
@@ -43528,25 +43528,25 @@ msgstr "%qs özniteliği sadece işlev türlerine uygulanır"
 msgid "argument of %qE attribute ignored"
 msgstr "%qE özniteliği yoksayıldı"
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only applies to variables"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown %<asm%> flag output %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for %<asm%> flag output"
@@ -43806,7 +43806,7 @@ msgstr "hedef işlemci THUMB komutlarını desteklemiyor"
 msgid "target CPU does not support unaligned accesses"
 msgstr "hedef işlemci beraber çalışmayı desteklemiyor"
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -43863,7 +43863,7 @@ msgstr "veri yapısı boyut sınırı sadece %s ye ayarlanabilir"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
@@ -43978,7 +43978,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -44024,44 +44024,44 @@ msgstr "%qE özniteliği sadece genel nesnelerde etkilidir"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qs özniteliği sadece işlev türlerine uygulanır"
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "yığıttaki parametrenin gerçek konumu hesaplanamıyor"
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Beklenmeyen modül sonu"
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "yüksek yazmaçları çekmeye elverişli düşük yazmaç yok"
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "sistem kesmesi Servis İşlemleri Thumb kipinde kodlanamaz"
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -44070,24 +44070,24 @@ msgstr "%qs özniteliğinin argümanı geçersiz"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "%qE özniteliği için vektör türü geçersiz"
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown target attribute or pragma %qs"
 msgstr "bilinmeyen yazmaç ismi: %s"
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
@@ -44148,177 +44148,177 @@ msgstr ""
 msgid "unknown core architecture %qs specified with %qs"
 msgstr "%qs ile belirtilmiş sınıf ismi yok"
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "%<-fpic%> is not supported"
 msgstr "-pipe desteklenmiyor"
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "%<-fPIC%> is not supported"
 msgstr "-pipe desteklenmiyor"
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "%<-fpie%> is not supported"
 msgstr "-pipe desteklenmiyor"
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "%<-fPIE%> is not supported"
 msgstr "-pipe desteklenmiyor"
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, fuzzy, gcc-internal-format
 #| msgid "-G and -static are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-G ve -static birlikte kullanılamaz"
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have arguments"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, fuzzy, gcc-internal-format
 #| msgid "Function does not return a value"
 msgid "%qs function cannot return a value"
 msgstr "işlev bir değer ile donmuyor"
 
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, fuzzy, gcc-internal-format
 #| msgid "%qs appears to be a misspelled signal handler"
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs imlası bozuk bir sinyal eylemcisi gibi görünüyor"
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, gcc-internal-format
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Number of registers used to pass integer arguments"
 msgid "fixed register %s used to pass parameter to function"
 msgstr "Tamsayı argümanları aktarmada kullanılan yazmaçların sayısı"
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D not supported"
 msgid "writing to address space %qs not supported"
 msgstr "%q+D zayıf bildirimi desteklenmiyor"
 
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variadic functions"
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "%qE özniteliği sadece değişkin işlevlere uygulanır"
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "bu platformda %qE özniteliği desteklenmiyor"
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute does not apply to types"
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr "%qs özniteliği veri türlerine uygulanmaz"
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute on non-volatile variable"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "bu hedefte -fdata-sections desteklenmiyor"
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, fuzzy, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr "%qD satıriçi öznitelikli olmayan bildirimi satıriçi bildirimi izliyor"
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, fuzzy, gcc-internal-format
 #| msgid "only uninitialized variables can be placed in the .noinit section"
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr ".noinit alanına sadece ilklendirilmiş değişkenler yerleştirilebilir"
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, fuzzy, gcc-internal-format
 #| msgid "only initialized variables can be placed into program memory area"
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr "program bellek alanına sadece ilklendirilmiş değişkenler yerleştirilebilir"
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, fuzzy, gcc-internal-format
 #| msgid "only initialized variables can be placed into program memory area"
 msgid "uninitialized variable %q+D put into program memory area"
@@ -44328,48 +44328,48 @@ msgstr "program bellek alanına sadece ilklendirilmiş değişkenler yerleştiri
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr "Ayrılabilir '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%qs uyumsuz özniteliği yoksayıldı"
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, fuzzy, gcc-internal-format
 #| msgid "MCU %qs supported for assembler only"
 msgid "architecture %qs supported for assembler only"
 msgstr "MCU `%qs' sadece sembolik çevirici için desteklenir"
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "conversion from address space %qs to address space %qs"
 msgstr "%s den %s e dönüşüm (%L'de)"
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of module in string constant"
 msgid "%s expects a compile time integer constant"
 msgstr "Dizge sabitinde umulmadık modül sonu"
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -44525,7 +44525,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr ""
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, fuzzy, gcc-internal-format
@@ -45230,8 +45230,8 @@ msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %s does not support PIC mode"
@@ -45307,277 +45307,277 @@ msgstr "%qs ile belirtilmiş sınıf ismi yok"
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "ESA/390 kipinde 64 bitlik ABI desteklenmiyor."
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, fuzzy, gcc-internal-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "Önerilmiyor; yerine -Wextra kullanın"
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, fuzzy, gcc-internal-format
 #| msgid "-f%s not supported: ignored"
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "-f%s  desteklenmiyor: yoksayıldı"
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr "bu hedefte -fdata-sections desteklenmiyor"
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, fuzzy, gcc-internal-format
 #| msgid "static is not supported on TPF-OS"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "static TPF-OS'da desteklenmiyor"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "PIC kipinde %s kod modeli desteklenmiyor"
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-m%s bu yapılandırmada desteklenmiyor"
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i bitlik kip bunun içinde derlenmiş değil:"
 
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "Seçtiginiz işlemci  x86-64 komutlarını desteklemiyor."
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "-march= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "-march= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "-mtune= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "-mtune= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, fuzzy, gcc-internal-format
 #| msgid "-mgp32 used with a 64-bit ABI"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "-mgp32 bir 64-bit ABI ile kullanılmış"
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d, 0 ile %d arasında değil"
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, fuzzy, gcc-internal-format
 #| msgid "typedef declaration invalid in parameter declaration"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "typedef bildirimi parametre bildiriminde geçersiz"
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr ""
@@ -45585,323 +45585,323 @@ msgstr ""
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr ""
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "bu hedefte -fprefetch-loop-arrays desteklenmiyor"
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d, %d ile 12 arasında değil"
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d, %d ile 12 arasında değil"
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "modüller arası eniyilemeler henüz C++ için gerçeklenmedi"
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "-msseregparm SSE etkin değilken kullanılmış"
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "-msseregparm SSE etkin değilken kullanılmış"
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE komut kümesi iptal edildi, 387 aritmetiği kullanılıyor"
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 komut kümesi iptal edildi, SSE aritmetiği kullanılıyor"
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, fuzzy, gcc-internal-format
 #| msgid "unknown -m%s= option specified: '%s'"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "bilinmeyen -m%s= seçeneği belirtilmiş: '%s'"
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr ""
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s ile -mcall-%s uyumsuz."
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s ile -mcall-%s uyumsuz."
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "standart uzlaşımlara bu bağlam içinde izin verilmez"
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, fuzzy, gcc-internal-format
 #| msgid "Use a stack protection method for every function"
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "Her işlev için bir yığıt koruma yöntemi kullanılır"
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall ve regparm öznitelikleri uyumlu değil"
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qs özniteliğine argüman %d den büyük"
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "%qs uyumsuz özniteliği yoksayıldı"
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, fuzzy, gcc-internal-format
 #| msgid "'-%c' option must have argument"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "'-%c' seçeneğinde argüman eksik"
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
@@ -46114,48 +46114,48 @@ msgstr "ek yazmaç için desteklenmeyen terim boyutu"
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, fuzzy, gcc-internal-format
 #| msgid "no low registers available for popping high registers"
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr "yüksek yazmaçları çekmeye elverişli düşük yazmaç yok"
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr ""
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr ""
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "unknown architecture specific memory model"
 msgstr "%qs ile belirtilmiş sınıf ismi yok"
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr ""
@@ -46178,8 +46178,8 @@ msgstr "dllimport'lu sınıfın %q+D durağan veri üyesinin tanımı"
 msgid "malformed %<#pragma builtin%>"
 msgstr "#pragma builtin bozuk"
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid argument of %qE attribute"
@@ -46243,13 +46243,13 @@ msgstr "PRINT_OPERAND: '%c' noktalaması bilinmiyor"
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr "PRINT_OPERAND boş gösterici"
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "%qd argümanı bir sabit değil"
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, fuzzy, gcc-internal-format
 #| msgid "failed to reclaim unneeded function"
 msgid "failed to expand built-in function"
@@ -46385,19 +46385,19 @@ msgstr "assert: %s %s ile uyumlu atanıyor"
 msgid "%qs cannot be used for compiling a shared library"
 msgstr "%s burada asm içinde kullanılamaz"
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for register variables"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "multiple %qE attribute"
@@ -46515,12 +46515,12 @@ msgstr "çok sayıda işlev türü öznitelik belirtilmiş"
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "yığıt sınırlama ifadesi desteklenmiyor"
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<-fexcess-precision=16%> is not supported on this target"
@@ -46564,7 +46564,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr ""
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires a string argument"
@@ -46610,140 +46610,140 @@ msgstr ""
 msgid "argument to %qE attribute is not intstack"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, gcc-internal-format
 msgid "cannot handle inconsistent calls to %qs"
 msgstr "tutarsız %qs çağrıları elde edilemez"
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr ""
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr ""
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr ""
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, fuzzy, gcc-internal-format
 #| msgid "function_profiler support for MMIX"
 msgid "built-in function %qE not supported for MIPS16"
 msgstr "MMIX için function_profiler desteği"
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs does not support MIPS16 code"
 msgstr "%s %s desteği vermiyor"
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr ""
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, gcc-internal-format
 msgid "MIPS16 %<-mxgot%> code"
 msgstr ""
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, gcc-internal-format
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr ""
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, fuzzy, gcc-internal-format
 #| msgid "Generate SH1 code"
 msgid "MSA MIPS16 code"
 msgstr "SH1 kodu üretilir"
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, gcc-internal-format
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr ""
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported combination: %s"
 msgstr "desteklenmeyen birleşim: %s"
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, fuzzy, gcc-internal-format
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr "bir %2$s işlemci belirten diğer mimarı seçenekleri ile -%1$s çelişiyor"
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, fuzzy, gcc-internal-format
 #| msgid "-mgp64 used with a 32-bit processor"
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr "-mgp64 bir 32-bit işlemci ile kullanılmış"
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, fuzzy, gcc-internal-format
 #| msgid "-mgp32 used with a 64-bit ABI"
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr "-mgp32 bir 64-bit ABI ile kullanılmış"
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, fuzzy, gcc-internal-format
 #| msgid "-mgp64 used with a 32-bit ABI"
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr "-mgp64 bir 32-bit ABI ile kullanılmış"
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, fuzzy, gcc-internal-format
 #| msgid "z/Architecture mode not supported on %s"
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "z/Architecture kipi %s üzerinde desteklenmiyor"
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr ""
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr ""
@@ -46753,132 +46753,132 @@ msgstr ""
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr "hedef işlemci THUMB komutlarını desteklemiyor"
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr "hedef işlemci THUMB komutlarını desteklemiyor"
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr ""
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported combination: %qs%s %s"
 msgstr "desteklenmeyen birleşim: %s"
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported combination: %qs %s"
 msgstr "desteklenmeyen birleşim: %s"
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, fuzzy, gcc-internal-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "cannot generate position-independent code for %qs"
 msgstr "Mümkünse, konumdan bağımsız kod üretilir (büyük kip)"
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, fuzzy, gcc-internal-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "position-independent code requires %qs"
 msgstr "Mümkünse, konumdan bağımsız kod üretilir (büyük kip)"
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr ""
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, fuzzy, gcc-internal-format
 #| msgid "z/Architecture mode not supported on %s"
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr "z/Architecture kipi %s üzerinde desteklenmiyor"
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, fuzzy, gcc-internal-format
 #| msgid "z/Architecture mode not supported on %s"
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr "z/Architecture kipi %s üzerinde desteklenmiyor"
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, fuzzy, gcc-internal-format
 #| msgid "-mips3d requires -mpaired-single"
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr "-mips3d seçeneği -mpaired-single gerektirir"
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, fuzzy, gcc-internal-format
 #| msgid "-frepo must be used with -c"
 msgid "%qs must be used with %qs"
 msgstr "-frepo, -c ile kullanilmalı"
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, gcc-internal-format
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr ""
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr "hedef işlemci THUMB komutlarını desteklemiyor"
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr ""
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "the %qs architecture does not support DSP instructions"
 msgstr "hedef işlemci THUMB komutlarını desteklemiyor"
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, gcc-internal-format
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr ""
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, gcc-internal-format
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr ""
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, fuzzy, gcc-internal-format
 #| msgid "Use the bit-field instructions"
 msgid "%qs requires branch-likely instructions"
 msgstr "Bit alanı komutları kullanılır"
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "the %qs architecture does not support the synci instruction"
 msgstr "hedef işlemci THUMB komutlarını desteklemiyor"
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr "mips16 işlev ayrımlama"
@@ -47831,60 +47831,60 @@ msgstr "%<#pragma%> burada kullanılamaz"
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "'#pragma options' sonunda karışıklık"
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, gcc-internal-format
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, gcc-internal-format
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr "bu platformda %qE özniteliği desteklenmiyor"
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "malformed %<target()%> attribute"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "alias argümanı bir dizge değil"
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, gcc-internal-format
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma pack%> - ignored"
 msgid "malformed %<target(\"%s\")%> attribute"
@@ -47954,186 +47954,210 @@ msgstr "%qT türü %qT türüne dönüştürülemiyor"
 msgid "capture by copy of RVV type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, fuzzy, gcc-internal-format
+#| msgid "built-in function %q+D declared as non-function"
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, fuzzy, gcc-internal-format
+#| msgid "built-in function %q+D declared as non-function"
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, fuzzy, gcc-internal-format
+#| msgid "built-in function %q+D declared as non-function"
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, fuzzy, gcc-internal-format
+#| msgid "built-in function %q+D declared as non-function"
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function call to %qE with empty arguments"
 msgstr "%<%D(%A)%> çağrısı ile eşleşen bir işlev yok"
 
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown value %qs of -mmacosx-version-min"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "-mmacosx-version-min için %qs değeri bilinmiyor"
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, gcc-internal-format
 msgid "this operation requires the RVV ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr "AltiVec argümanı prototipsiz işleve aktarıldı"
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, fuzzy, gcc-internal-format
 #| msgid "Use the Cray Pointer extension"
 msgid "%s %qT requires the V ISA extension"
 msgstr "Cray Göstericisi eklentisi kullanılır"
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, gcc-internal-format
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, gcc-internal-format
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, gcc-internal-format
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, gcc-internal-format
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr ""
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "function attribute %qs requires the V ISA extension"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr ""
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qs applied to non-RVV type %qT"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qs requires an integer constant"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr "hedef işlemci beraber çalışmayı desteklemiyor"
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, fuzzy, gcc-internal-format
 msgid "code model %qs with %qs"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, gcc-internal-format
 msgid "rv64e requires lp64e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr ""
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d, %d ile 12 arasında değil"
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid class name"
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs geçerli bir sınıf ismi değil"
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid output file"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs geçerli bir çıktı dosyası değil"
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr ""
@@ -48410,33 +48434,33 @@ msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr "%2$qE işlevinin %1$d. argümanına aktarım gösterici hedef türündeki niteleyicileri iptal ediyor"
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "AltiVec yerleşiği için parametre birleşimi geçersiz"
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, gcc-internal-format
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
@@ -48480,32 +48504,24 @@ msgstr "%qT ve %qT türündeki terimler iki terimli `%qO' için geçersiz"
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektörü başvurusu tarafından aktarıldı: bir uyumluluk garanti etmeksizin standartdışı ABI eklentisi"
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, fuzzy, gcc-internal-format
-#| msgid "Use EABI"
-msgid "%qs requires the ELFv2 ABI"
-msgstr "EABI kullanılır"
-
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "yığıt çerçevesi çok büyük"
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "unsupported number of nops before function entry (%u)"
 msgstr "%qE işlevi için çok az argüman belirtildi"
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qs uses register r29"
 msgstr "%<__thread%> %<register%> ile kullanılmış"
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
@@ -48644,118 +48660,128 @@ msgstr "Çağrı taşırmalı hedef yazmacı gerekir"
 msgid "unknown option for %<%s=%s%>"
 msgstr "bilinmeyen -m%s= seçeneği belirtilmiş: '%s'"
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4837
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4855
 #, fuzzy, gcc-internal-format
 #| msgid "Deprecated.  This switch has no effect"
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "Önerilmiyor. Bu seçenek etkisizdir."
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "bu ABI için 64 bitlik profilleme kodu yok"
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "bir sağ taraf ifadesi olan %<this%>'in adresi alınamaz"
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "AltiVec türlerde %<long double%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "AltiVec türlerde mantıksal türlerin kullanımı geçersiz"
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "AltiVec türlerde %<complex%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, fuzzy, gcc-internal-format
 #| msgid "use of boolean types in AltiVec types is invalid"
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "AltiVec türlerde mantıksal türlerin kullanımı geçersiz"
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "AltiVec türlerde %<long%> kullanımı 64 bitlik kod için geçersiz"
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "AltiVec türlerde %<long%> kullanımı önerilmiyor; %<int%> kullanın"
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "AltiVec türlerde %<long long%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "AltiVec türlerde %<double%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%s%qs%s is not allowed"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "spec '%s' geçersiz"
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "yığıt sınırlama ifadesi desteklenmiyor"
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "type %<__vector_pair%> requires the %qs option"
@@ -48804,7 +48830,7 @@ msgstr ""
 msgid "builtin %qs can only be used on vector types"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "constant value required for builtin %qF argument %d"
@@ -48880,247 +48906,247 @@ msgstr "%qs önerilmiyor"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "sabit argüman %qs için aralık dışında"
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr "%d. şablon argümanı geçersiz"
 
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr "sabit argüman %qs için aralık dışında"
 
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr "sabit argüman %qs için aralık dışında"
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher"
 msgstr ""
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher"
 msgstr ""
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "unresolved overloaded builtin"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, fuzzy, gcc-internal-format
 #| msgid "bad builtin fcode"
 msgid "bad builtin icode"
 msgstr "hatalı yerleşik fcode"
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "invalid argument %d for builtin %qF"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "Yerel değişkenlerin toplam boyutu mimarinin izin verdigi sınırı aşıyor"
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr ""
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr ""
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "%qs çerçevi boyutu "
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs özdevimli yığıt tahsisi kullanıyor"
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr ""
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "iç işlev %qs %<extern%> olarak bildirilmiş"
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "ESA/390 kipinde 64 bitlik ABI desteklenmiyor."
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
 msgid "hardware vector support not available on %s"
 msgstr "Donanım kayan nokta komutlarının kullanımını 32 bitlik işlemlerle sınırlar"
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr "Donanım kayan nokta komutlarının kullanımını 32 bitlik işlemlerle sınırlar"
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, fuzzy, gcc-internal-format
 #| msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr "Donanım kayan nokta komutlarının kullanımını 32 bitlik işlemlerle sınırlar"
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float bir arada desteklenmiyor"
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "yığıt boyutunun yığıt koruma değerinden büyük olması gerekir"
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "yığıt boyutu 64k'dan büyük olmamalıdır"
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard, -mstack-size uyguluyor"
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "bu platformda %qE özniteliği desteklenmiyor"
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "\"%s\" için argüman sıfır ya da pozitif bir tamsayı olmalı"
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%qs özniteliğine argüman %d den büyük"
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr "alias argümanı bir dizge değil"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "__builtin_saveregs bu hedef tarafından desteklenmiyor"
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, fuzzy, gcc-internal-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid cc output constraint: %qs"
 msgstr "kısıt içindeki `%qc' işareti geçersiz"
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, fuzzy, gcc-internal-format
 #| msgid "multiple function type attributes specified"
 msgid "multiple cc output constraints not supported"
 msgstr "çok sayıda işlev türü öznitelik belirtilmiş"
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, fuzzy, gcc-internal-format
 #| msgid "asm-specifier for variable %qs conflicts with asm clobber list"
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr "%qs değişkeni için asm belirteci, asm taşırma listesi ile çelişiyor"
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for cc output constraint"
@@ -49602,8 +49628,8 @@ msgstr "%qE özniteliği yoksayıldı"
 msgid "attribute %qs applies to array types only"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void değer yoksayılması gerekirken yoksayılmadı"
@@ -49682,7 +49708,7 @@ msgstr "%q+D dizisinin türü örtük ilklendirme ile uyumsuz olarak tamamlanmı
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr "%qD zaten bu bağlamda bildirilmiş"
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "originally defined here"
@@ -49934,7 +49960,7 @@ msgstr "%qD bildirimi bir önceki değişken olmayan bildirimi gölgeliyor"
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%qD bildirimi bir global bildirimi gölgeliyor"
@@ -49944,7 +49970,7 @@ msgstr "%qD bildirimi bir global bildirimi gölgeliyor"
 msgid "declaration of %qD shadows a previous local"
 msgstr "%qD bildirimi önceki yereli gölgeliyor"
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, fuzzy, gcc-internal-format
 #| msgid "%Jshadowed declaration is here"
 msgid "shadowed declaration is here"
@@ -50018,7 +50044,7 @@ msgstr "%H%qE bildirilmemiş (bu işlevde ilk kullanımı)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "%H(Bildirilmemiş her betimleyici görüldüğü her işlev"
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "%qE yaftası işlev dışına başvuruyor"
@@ -50055,7 +50081,7 @@ msgstr "deyim ifadesine jump"
 msgid "duplicate label declaration %qE"
 msgstr "%qE yaftası bildirimi yinelenmiş"
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "yinelenmiş %qD yaftası"
@@ -50095,7 +50121,7 @@ msgstr "deyim ifadesine jump"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%H%qEyanlış etiket çeşidi olarak tanımlı"
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute applied to %qD with void return type"
@@ -50252,12 +50278,12 @@ msgstr "ISO C90 %<[*]%> dizi bildirimlerini desteklemez"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<omp::%s%> not allowed to be specified in this context"
@@ -50268,7 +50294,7 @@ msgstr "bu kapsamda %<this%> kullanılamaz"
 msgid "%q+D is usually a function"
 msgstr "%q+D çoğu kez bir işlevdir"
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
@@ -50351,7 +50377,7 @@ msgstr "oynak alanlı nesne yazmaça konulamaz"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "ilklendirilmemiş sabit %qD"
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -50556,7 +50582,7 @@ msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 msgid "storage class specified for unnamed parameter"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "veri türü ismi için saklama sınıfı belirtildi"
@@ -50629,7 +50655,7 @@ msgstr "işlev dizisi olarak %qs bildirimi"
 msgid "declaration of type name as array of functions"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "esnek dizi üyeli yapı kullanımı geçersiz"
@@ -50753,7 +50779,7 @@ msgstr "%qs dizi ile dönen işlev olarak bildirilmiş"
 msgid "function definition has qualified void return type"
 msgstr "işlev tanımı nitelikli void dönüş türü içeriyor"
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tür niteleyicileri işlev dönüş türünde yok sayıldı"
@@ -50898,7 +50924,7 @@ msgstr "ISO C 'const' ya da 'volatile' işlev türlerini yasaklar"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "veri üyesi değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "void bildirimli değişken ya da alan %qE"
@@ -51017,7 +51043,7 @@ msgstr "değişkene göre değişen türde betimleyici etki alanına jump"
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "işlev bildirimi bir prototip değil"
@@ -51112,18 +51138,18 @@ msgstr "%<union %E%> iç içe yeniden tanımlanmış"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "%<struct %E%> iç içe yeniden tanımlanmış"
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, fuzzy, gcc-internal-format
 #| msgid "unknown field %qE specified in initializer"
 msgid "%qT defined in underspecified object initializer"
 msgstr "ilklendiricide bilinmeyen %qE alanı belirtilmiş"
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "bildirim hiçbir şey bildirmiyor"
@@ -51155,387 +51181,387 @@ msgstr ""
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union hiç isimli üye içermiyor"
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union hiç üye içermiyor"
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "yapı hiç isimli üye içermiyor"
 
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "yapı hiç üye içermiyor"
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
 msgstr "%Junion içinde esnek dizi üye"
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member not at end of struct"
 msgstr "%Jesnek dizi yapının son üyesi değil"
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in a struct with no named members"
 msgstr "%Junion içinde esnek dizi üye"
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr "%Jesnek dizi yapının son üyesi değil"
 
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "type %qT is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, gcc-internal-format
 msgid "type punning toggles scalar storage order"
 msgstr ""
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "birleşik yapı şeffaf olamaz"
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, fuzzy, gcc-internal-format
 #| msgid "jump into scope of identifier with variably modified type"
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr "değişkene göre değişen türde betimleyici etki alanına jump"
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %<struct %E%>"
 msgid "redefinition of struct or union %qT"
 msgstr "%<struct %E%> yeniden tanımlanmış"
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "%<enum %E%> iç içe yeniden tanımlanmış"
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%> yeniden bildirilmiş"
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
 msgstr "belirtilen kip sırali sayısal değerler için çok küçük"
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "sembolik sabit grubunun değerleri en büyük tamsayı aralığını aşıyor."
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration values exceed range of largest integer"
 msgid "enumeration values exceed range of %qs"
 msgstr "sembolik sabit grubunun değerleri en büyük tamsayı aralığını aşıyor."
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of %<enum %E%>"
 msgid "conflicting redefinition of enum %qT"
 msgstr "%<enum %E%> iç içe yeniden tanımlanmış"
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "sembolik sabit listesi değerlerinde taşma"
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration values exceed range of largest integer"
 msgid "enumerator value outside the range of underlying type"
 msgstr "sembolik sabit grubunun değerleri en büyük tamsayı aralığını aşıyor."
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "enumerator value outside the range of %qs"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute %qs"
 msgstr "satıriçi %q+D işlevine satıriçi olmayan öznitelik verilmiş"
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "dönüş türü, bir içi boş tür"
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "dönen tür %<int%> türüne öntanımlıdir"
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "%qs alanı bir işlev olarak bildirilmiş"
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, fuzzy, gcc-internal-format
 #| msgid "no previous prototype for %q+D"
 msgid "no previous prototype for %qD"
 msgstr "%q+D için önceki prototip yok"
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D tanımlanmadan önce prototipsiz kullanılmış"
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no declaration before its definition"
 msgid "%qD was used with no declaration before its definition"
 msgstr "%q+D tanımından önce bildirimsiz kullanılmış"
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %<int%>"
 msgstr "%q+D için dönüş türü %<int%> değil"
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is normally a non-static function"
 msgstr "%q+D normalde bir static olmayan işlevdir"
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style parameter declarations in prototyped function definition"
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "%Jprototipli işlev tanımında eski tarz parametre bildirimi"
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtraditional C rejects ISO C style function definitions"
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "%Jgeleneksel C, ISO C tarzı işlev tanımlarına izin vermez"
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr ""
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "old-style function definition"
 msgstr "%Jeski tarz işlev tanımı"
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name missing from parameter list"
 msgid "parameter name missing from parameter list"
 msgstr "%Jparametre ismi parametre listesinde yok"
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "%qD declared as a non-parameter"
 msgstr "%q+D bir parametre olarak bildirilmemiş"
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, fuzzy, gcc-internal-format
 #| msgid "multiple parameters named %q+D"
 msgid "multiple parameters named %qD"
 msgstr "%q+D isimli çok sayıda parametre"
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "parameter %qD declared with void type"
 msgstr "%q+D parametresi void olarak bildirilmiş"
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, fuzzy, gcc-internal-format
 #| msgid "type of %q+D defaults to %<int%>"
 msgid "type of %qD defaults to %<int%>"
 msgstr "%q+D için tür öntanımlı olarak %<int%>"
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "parameter %qD has incomplete type"
 msgstr "%q+D parametresi tamamlanmamış türde"
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, fuzzy, gcc-internal-format
 #| msgid "declaration for parameter %q+D but no such parameter"
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "%q+D parametresi için bildirim var ama böyle bir parametre yok"
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "argüman sayısı yerleşik prototiple uyumsuz"
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "argüman sayısı prototiple uyumsuz"
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, fuzzy, gcc-internal-format
 #| msgid "%Hprototype declaration"
 msgid "prototype declaration"
 msgstr "%Hprototip bildirimi"
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "yükseltgenmiş argüman %qD yerleşik prototiple uyumsuz"
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "yükseltgenmiş argüman %qD prototiple uyumsuz"
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "%qD argümanı yerleşik prototiple eslesmiyor"
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "%qD argümanı prototiple uyumsuz"
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
 msgstr "%qD parametresi ilklendirilmiş"
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declaration used outside C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> döngüsünün ilk bildirimi C99 kipinin dışında kullanılmış"
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use -fpermissive G++ will accept your code)"
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "(-fpermissive kullanırsanız G++ kodunuzu kabul edecek)"
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 %<[*]%> dizi bildirimlerini desteklemez"
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of static variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "%<for%> döngüsünün ilk bildiriminde statik değişken %q+D bildirimi"
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "%<for%> döngüsünün ilk bildiriminde %<extern%> değişken %q+D bildirimi"
 
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> %<for%> döngüsünün ilk bildiriminde bildirilmiş"
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> %<for%> döngüsünün ilk bildiriminde bildirilmiş"
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> %<for%> döngüsünün ilk bildiriminde bildirilmiş"
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of non-variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "%<for%> döngüsünün ilk bildiriminde değişken olmayan %q+D bildirimi"
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "bildirim belirteçlerinde çok sayıda saklama sınıfı"
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qs used with %<auto%>"
@@ -51543,277 +51569,277 @@ msgstr "%<__thread%> %<auto%> ile kullanılmış"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%<auto%> used with %<constexpr%>"
 msgstr "%<__thread%> %<register%> ile kullanılmış"
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "bildirim belirteçleri içinde iki veya daha fazla veri türü"
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> GCC için çok uzun"
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 karmaşık türleri desteklemez"
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE yinelenmiş"
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 karmaşık türleri desteklemez"
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "fixed-point types not supported for this target"
 msgstr "bu hedefte -fdata-sections desteklenmiyor"
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr ""
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE bir typedef veya yerleşik veri türü olarak başarısız"
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE bildirimin başlangıcında değil"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> %<auto%> ile kullanılmış"
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> %<register%> ile kullanılmış"
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> %<typedef%> ile kullanılmış"
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<constexpr%>"
 msgstr "%<__thread%> %<register%> ile kullanılmış"
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s %s desteği vermiyor"
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<extern%> öncesinde %<__thread%>"
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<static%>  öncesinde %<__thread%>"
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%<typedef%> used with %<auto%>"
 msgstr "%<__thread%> %<auto%> ile kullanılmış"
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<extern%>"
 msgstr "%<__thread%> %<register%> ile kullanılmış"
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%qE used with %qs"
 msgstr "%<__thread%> %qE ile kullanılmış"
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%qs used with %qE"
 msgstr "%<__thread%> %qE ile kullanılmış"
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%<constexpr%> used with %qE"
 msgstr "%<__thread%> %qE ile kullanılmış"
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, fuzzy, gcc-internal-format
 #| msgid "%<@try%> without %<@catch%> or %<@finally%>"
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<@catch%> veya %<@finally%> olmaksızın %<@try%>"
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C salt %<complex%>i %<double complex%> anlamında desteklemez"
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, fuzzy, gcc-internal-format
 #| msgid "Fixed line length must be at least seven."
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr "Sabit satır uzunluğu en az yedi olmalıdır"
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr "ISO C++ %<long long%> desteklemez"
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "sola kaydırma sayısı negatif"
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "sola kaydırma sayısı negatif"
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "sağa kaydırma sayısı negatif"
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "sola kaydırma sayısı tür genişliğinden büyük ya da eşit"
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "sağa kaydırma sayısı tür genişliğinden büyük ya da eşit"
@@ -51846,7 +51872,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "%J  diğer tür burada"
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -51858,8 +51884,8 @@ msgstr "Beklenmeyen modül sonu"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C boş kaynak dosyalarına izin vermez"
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr ""
@@ -51902,9 +51928,9 @@ msgstr "bilinmeyen yazmaç ismi: %s"
 msgid "unknown type name %qE"
 msgstr "bilinmeyen yazmaç ismi: %s"
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "bildirim belirteçleri umuluyordu"
@@ -51938,7 +51964,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "betimleyici veya %<(%> umuluyordu"
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -51962,7 +51988,7 @@ msgstr "Öznitelik bit ismi umuluyordu"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "bölüm özniteliğine %q+D için izin verilmez"
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<assume%> attribute not followed by %<;%>"
@@ -52064,7 +52090,7 @@ msgstr "bütünleyen ifade %qE bir sabit değil"
 msgid "static assertion failed: %E"
 msgstr "CRIS-port olumlaması başarısız: "
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, fuzzy, gcc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed"
@@ -52143,10 +52169,10 @@ msgstr "%d. şablon argümanı geçersiz"
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "betimleyici umuluyordu"
@@ -52305,7 +52331,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr ""
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr ""
@@ -52315,8 +52341,8 @@ msgstr ""
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs attribute argument"
 msgstr ""
@@ -52502,12 +52528,12 @@ msgstr "ISO C ?: üç terimlisinin orta teriminin atlanmasına izin vermez"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -52676,7 +52702,7 @@ msgstr "ISO C90 %<[*]%> dizi bildirimlerini desteklemez"
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, gcc-internal-format
 msgid "expected expression"
 msgstr "ifade umuluyordu"
@@ -53026,12 +53052,12 @@ msgstr "bildirim belirteçleri umuluyordu"
 msgid "no type or storage class may be specified here,"
 msgstr "%qs için saklatım sınıfı belirtilmiş"
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr ""
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, fuzzy, gcc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing property attribute"
@@ -53043,61 +53069,61 @@ msgstr "Code özniteliği eksik"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "Hatalı işleç"
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, fuzzy, gcc-internal-format
 #| msgid "misplaced %<@%D%> Objective-C++ construct"
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "yanlış yere konmuş %<@%D%> Nesnel-C++ oluşumu"
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected %qE selector name"
 msgstr "bildirim veya deyim umuluyordu"
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr ""
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "bu kapsamda %<this%> kullanılamaz"
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
@@ -53108,13 +53134,13 @@ msgstr ""
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement expected at %L"
 msgid "for, while or do statement expected"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma GCC pch_preprocess, ignored"
 msgid "%<#pragma GCC pch_preprocess%> must be first"
@@ -53122,13 +53148,13 @@ msgstr "#pragma GCC pch_preprocess bozuk, yoksayıldı"
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
@@ -53146,73 +53172,73 @@ msgstr "%L'deki ifade değişmez olmalı"
 msgid "expected %<)%> or %<,%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a variable"
 msgstr "%qD bir şablon değil"
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a pointer variable"
 msgstr "%qD bir şablon değil"
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr "%<=%>, %<,%>, %<;%>, %<asm%> veya %<__attribute__%> umuluyordu"
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected constant logical expression"
 msgstr "ifade umuluyordu"
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<data%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses without modifier"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -53237,25 +53263,25 @@ msgstr ""
 msgid "%<num_tasks%> value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<grainsize%> value must be positive"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%<priority%> value must be non-negative"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "ifade umuluyordu"
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr ""
@@ -53266,105 +53292,105 @@ msgstr ""
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be scalar"
 msgid "%qs expression must be integral"
 msgstr "%L'deki ifade değişmez olmalı"
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "%qs value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments for format"
 msgid "too many %<static%> arguments"
 msgstr "biçim için argüman sayısı çok fazla"
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, fuzzy, gcc-internal-format
 #| msgid "Expected attribute bit name"
 msgid "unexpected argument"
 msgstr "Öznitelik bit ismi umuluyordu"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qs öznitelik argümanı bir tamsayı sabit değil"
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<self%> clauses"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<concurrent%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "chunk size value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_double operand"
 msgid "invalid schedule kind"
@@ -53375,22 +53401,22 @@ msgstr "const_double terim geçersiz"
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr ""
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<allocator%> or %<align%>"
@@ -53402,24 +53428,24 @@ msgstr "%<,%> veya %<;%> umuluyordu"
 msgid "duplicate %qs modifier"
 msgstr "%qs yinelenmiş"
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple linear modifiers"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple %<step%> modifiers"
@@ -53440,70 +53466,70 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "geçersiz %%d terimi"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid doacross kind"
 msgstr "mask geçersiz"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<always%> modifiers"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<close%> modifiers"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<present%> modifiers"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "mask geçersiz"
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr ""
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, gcc-internal-format
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr ""
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_double operand"
 msgid "invalid dist_schedule kind"
@@ -53521,97 +53547,97 @@ msgstr "geçersiz döngü komutu"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected an OpenACC clause"
 msgstr "sınıf ismi umuluyordu"
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid output file"
 msgid "%qs is not valid for %qs"
 msgstr "%qs geçerli bir çıktı dosyası değil"
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a nested class of %qT"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qT %qT'nin alt sınıfı değil"
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected an OpenMP clause"
 msgstr "sınıf ismi umuluyordu"
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a global declaration"
 msgid "array section in %<#pragma acc declare%>"
 msgstr "%qD bildirimi bir global bildirimi gölgeliyor"
 
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is a variably modified type"
 msgid "invalid OpenACC clause at file scope"
 msgstr "%qT değişkene göre değişen türde"
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<for%> döngüsünün ilk bildiriminde %<extern%> değişken %q+D bildirimi"
 
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "statik üye işlevde üye %q+D kullanımı geçersiz"
 
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "dizge sabiti umuluyordu"
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr ""
@@ -53628,7 +53654,7 @@ msgstr "%qD bildirilmemişti"
 msgid "expected function name"
 msgstr "umulmadık düğüm"
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a function"
@@ -53640,25 +53666,25 @@ msgstr "%qD bir üye şablon işlevi değil"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
@@ -53685,7 +53711,7 @@ msgstr ""
 msgid "modified here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
@@ -53726,122 +53752,122 @@ msgstr ""
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr ""
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many atomic clauses"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many memory order clauses"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qs clause requires %qs clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr "%C'deki işlev bildiriminden sonra umulmayan döküntü"
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, gcc-internal-format
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr ""
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma align%>"
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr "%<#pragma align%> bozuk"
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "unexpected %<else%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma align%>"
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr "%<#pragma align%> bozuk"
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma align%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma align%> bozuk"
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on %<__fpreg%>"
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<__fpreg%> üzerinde geçersiz işlem"
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr ""
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "%<depobj%> expression is not lvalue expression"
@@ -53853,30 +53879,30 @@ msgstr "bütünleyen ifade %qE bir sabit değil"
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr ""
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr "%<=%>, %<,%>, %<;%>, %<asm%> veya %<__attribute__%> umuluyordu"
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "%<=%>, %<,%>, %<;%>, %<asm%> veya %<__attribute__%> umuluyordu"
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -53887,180 +53913,180 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "Beklenmeyen modül sonu"
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr ""
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<}%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "%<,%> veya %<}%> umuluyordu"
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<}%>"
 msgid "expected %<#pragma omp scan%>"
 msgstr "%<,%> veya %<}%> umuluyordu"
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr ""
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration declaration or initialization"
 msgstr "bildirim veya deyim umuluyordu"
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, fuzzy, gcc-internal-format
 #| msgid "not enough type information"
 msgid "not enough nested loops"
 msgstr "tür bilgisi yetersiz"
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement expected at %L"
 msgid "for statement expected"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr "%<#pragma align%> %D bildiriminden önce görünmeli, yoksayılıyor"
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> %D bildiriminden önce görünmeli, yoksayılıyor"
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected trait selector name"
 msgstr "bildirim veya deyim umuluyordu"
 
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown selector %qs for context selector set %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr ""
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr "%<friend%> sadece bir sınıf içinde belirtilebilir"
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "%<score%> argument must be constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%<score%> argument must be non-negative"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "dizge sabiti umuluyordu"
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "property must be constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
@@ -54068,314 +54094,314 @@ msgstr ""
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%<requires%> selector is not supported yet"
 msgstr "%<large%> kod modeli henüz desteklenmiyor"
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected context selector set name"
 msgstr "bildirim veya deyim umuluyordu"
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<match%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "variant %qD is not a function"
 msgstr "%q+D bir işlev değil,"
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "%q+D parametresi tamamlanmamış türde"
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma align%> %D bildiriminden önce görünmeli, yoksayılıyor"
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma align%> %D bildiriminden önce görünmeli, yoksayılıyor"
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, gcc-internal-format
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr ""
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr ""
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<declare%> or %<assumes%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a global declaration"
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr "%qD bildirimi bir global bildirimi gölgeliyor"
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr ""
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected function-name %<(%>"
 msgstr "betimleyici veya %<(%> umuluyordu"
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr "%<=%>, %<,%>, %<;%>, %<asm%> veya %<__attribute__%> umuluyordu"
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, gcc-internal-format
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<restrict%>"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "%<restrict%> kullanımı geçersiz"
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %qs or %qs"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, gcc-internal-format
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr ""
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr ""
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, gcc-internal-format
 msgid "expected at least one assumption clause"
 msgstr ""
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected directive name"
 msgstr "Umulmadık isim"
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr ""
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, fuzzy, gcc-internal-format
 #| msgid "unknown demangling style '%s'"
 msgid "unknown assumption clause %qs"
 msgstr "cendereleme tarzı %s bilinmiyor"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected assumption clause"
 msgstr "sınıf ismi umuluyordu"
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter %u has incomplete type"
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%J%u. parametre tamamlanmamış türde"
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, gcc-internal-format
 msgid "no closing brace"
 msgstr ""
@@ -54524,7 +54550,7 @@ msgstr "%<void *%> gösterici ilişkilendirmesi"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "indisli değer ne dizi ne de bir gösterici"
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "dizi indisi bir tamsayı değil"
@@ -54555,7 +54581,7 @@ msgstr "%qD başvuru olarak bildirilmiş ama ilklendirilmemiş"
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -54676,19 +54702,19 @@ msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "%qE işlevi için çok az argüman belirtildi"
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D after first use results in unspecified behavior"
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "%q+D zayıf bildirimi ilk kullanımdan sonra belirsiz davranışla sonuçlanıyor"
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "gösterici ile tamsayı arasında karşılaştırma"
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -54715,7 +54741,7 @@ msgstr "çıkartmada işlev göstericisi kullanılmış"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "bir içi boş tür göstericisi üzerinde aritmetik"
 
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -55039,7 +55065,7 @@ msgstr "göstericiden farklı tamsayı türlere dönüşüm"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "%qT türündeki işlev çağrısından eşleşmeyen %qT türüne dönüşüm"
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "farklı boyuttaki tamsayı türden göstericiye dönüşüm"
@@ -55234,7 +55260,7 @@ msgstr "atamada sol taraf bir biçim özniteliği adayı olabilir"
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "ilklendirmede sol taraf bir biçim özniteliği adayı olabilir"
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "dönüş türü bir biçim özniteliği adayı olabilir"
@@ -55452,12 +55478,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "esnek dizi üyesi ilklendirmesi"
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -55467,7 +55493,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr "dizge sabitten ilgisiz türde ilklendirilmiş dizi"
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "sol değersiz dizi kullanımı geçersiz"
@@ -55499,7 +55525,7 @@ msgstr "ilklendirici öğe bir sabit değil"
 msgid "initializer element is not computable at load time"
 msgstr "ilkledirici öğe yükleme sırasında hesaplanabilir değil"
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "opak vektör türleri ilklendirilemez"
@@ -55514,7 +55540,7 @@ msgstr "ilklendiricinin sonunda fazladan parantezli grup"
 msgid "braces around scalar initializer"
 msgstr "skalar ilklendiriciyi kuşatan parantezler"
 
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "iç içe bağlam içinde esnek dizi üyesi ilklendirmesi"
@@ -55608,7 +55634,7 @@ msgstr "struct ilklendiricide gereğinden fazla öğe"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "esnek dizi üyesinin statik olmayan ilklendirmesi"
@@ -55648,7 +55674,7 @@ msgstr "ISO C %<goto *expr;%> kullanımına izin vermez"
 msgid "computed goto must be pointer type"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%> olarak bildirilmiş işlev %<return%> deyimi içeriyor"
@@ -55706,7 +55732,7 @@ msgstr "%<default%> etiketi bir switch deyimi içinde değil"
 msgid "break statement not within loop or switch"
 msgstr "break deyimi switch ya da döngü içinde değil"
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -55753,29 +55779,29 @@ msgstr ""
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr ""
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "comparing vectors with different element types"
 msgstr "?: için terimler farklı türde"
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "comparison between types %qT and %qT"
 msgstr "%q#T ile %q#T türleri arasında karşılaştırma"
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
@@ -55852,31 +55878,31 @@ msgstr "doğrudan değer gereken yerde union türünde değer kullanılmış"
 msgid "used vector type where scalar is required"
 msgstr "doğrudan değer gereken yerde yapı türünde değer kullanılmış"
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %qs clause"
@@ -55889,92 +55915,92 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "girdi dosyası sayısı çok fazla"
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "expected single pointer in %qs clause"
 msgstr "işlev `%s' (%C'deki) zaten %L'de tanımlı"
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "zero length array section in %qs clause"
 msgstr "Dizi bölümlerini yordam girdisinde sürekli bir blokun içine kopyalar"
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Dizi bölümlerini yordam girdisinde sürekli bir blokun içine kopyalar"
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qE does not have pointer or array type"
 msgstr "%qE sınıf türüne sahip değil"
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, fuzzy, gcc-internal-format
 #| msgid "throwing NULL, which has integral, not pointer type"
 msgid "iterator %qD has neither integral nor pointer type"
@@ -55986,19 +56012,19 @@ msgstr "tumleyen, gösterici olmayan NULL yakalanıyor"
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "ISO C nitelikli işlev türlerini yasaklar"
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "iterator %qD has const qualified type"
 msgstr "%q+D parametresi tamamlanmamış türde"
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %q+#D with non-integral type"
 msgid "iterator step with non-integral type"
 msgstr "bit-alanı %q+#D tümleyen türde değil"
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
@@ -56008,35 +56034,35 @@ msgstr ""
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "end expression refers to outer iterator %qD"
 msgstr "'o' değiştiricisi için terim geçersiz"
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, fuzzy, gcc-internal-format
 #| msgid "expresion reference type error at %L"
 msgid "step expression refers to outer iterator %qD"
 msgstr "%L'de ifade başvuru türü hatası"
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected pointer in %qs clause"
 msgstr "Tamsayı umuluyordu"
 
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr ""
@@ -56070,7 +56096,7 @@ msgstr "'%s' tahmini boyutlu dizisine '%s' isim listesinde izin verilmiyor (%C'd
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction not found for %qE"
@@ -56081,17 +56107,17 @@ msgstr "%qD ile ilişkilendirme belirsiz"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
 msgstr ""
@@ -56106,25 +56132,25 @@ msgstr ""
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, gcc-internal-format
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -56136,34 +56162,34 @@ msgstr ""
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -56186,7 +56212,7 @@ msgstr "%qD değişken sayıda argümana sahip olmamalı"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %<nontemporal%> clause"
@@ -56197,7 +56223,7 @@ msgstr "'%s' geçerli bir sınıf ismi değil"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %<allocate%> clause"
@@ -56209,81 +56235,81 @@ msgstr "'%s' geçerli bir sınıf ismi değil"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "'%s' geçerli bir sınıf ismi değil"
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr ""
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr "'%s' geçerli bir sınıf ismi değil"
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported map expression %qE"
 msgstr "desteklenmeyen birleşim: %s"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not declare a template type"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD bir şablon türü bildirmiyor"
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD bir işlev şablonu değil"
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
@@ -56300,23 +56326,23 @@ msgstr "%<->%> için taban terim bir gösterici değil"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses on a task construct"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
@@ -56326,38 +56352,38 @@ msgstr ""
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
@@ -56666,14 +56692,14 @@ msgstr "  %qT türünden %qT türüne dönüşüm için seçiliyor,"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  %qT türünden %qT türüne dönüşüm için seçiliyor,"
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -57017,622 +57043,622 @@ msgstr "bir tür dönüşümü olmaksızın %s (belirgin gösterici türleri %qT
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "koşullu ifade içinde enum ve enum olmayan türler"
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, fuzzy, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "sonek %2$qs için  %<%1$D(int)%> bildirimi yok, yerine önek işleci deneniyor"
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, fuzzy, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "sonek %2$qs için  %<%1$D(int)%> bildirimi yok, yerine önek işleci deneniyor"
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "%q+D için dönüş türü %<int%> değil"
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "%q#T ile %q#T arasında karşılaştırma"
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to %<(%T) (%A)%>"
 msgid "no match for call to %<%T::operator[] (%A)%>"
 msgstr "%<(%T) (%A)%> çağrısı için eşleşme yok"
 
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, fuzzy, gcc-internal-format
 #| msgid "call of %<(%T) (%A)%> is ambiguous"
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr "%<(%T) (%A)%> çağrısı belirsiz"
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr ""
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qE işlevinin örtük bildirimi"
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr ""
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, fuzzy, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "%2$qT için uygun bir %<%1$s işleci%> yok"
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "bu bağlamda"
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared private here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "bu bağlamda"
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared protected here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D erişilebilir değil"
 
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, fuzzy, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "%2$qD işlevinin gösterici olmayan %1$P argümanına NULL aktarılması"
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "  declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "NULL'dan gösterici olmayan %qT türüne dönüşüm"
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "%4$qD işlevinin %3$qP. argümanı için %1$qT türü %2$qT türüne dönüştürülemez"
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting %<false%> to pointer type %qT"
 msgstr "NULL'dan gösterici olmayan türe dönüşüm"
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, fuzzy, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  %2$qD işlevinin %1$P argümanının ilklendirilmesi"
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, fuzzy, gcc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "too many braces around initializer for %qT"
 msgstr "%qT için ilklendiriciyi çevreleyen parantezler yok"
 
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 #, fuzzy
 #| msgid "converting to %qT from %qT"
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "%qT türüne %qT türünden dönüşüm"
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 #, fuzzy
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr ""
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "%qT türünden %qT türüne dönüşüm geçersiz"
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "%qT türünden %qT türüne dönüşüm geçersiz"
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "%qT türündeki başvurunun %qT türündeki ifadeden ilklendirilmesi geçersiz"
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr "%qT türündeki sabit olmayan başvurunun geçici %qT türünden ilklendirilmesi geçersiz"
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "%qT türündeki sabit olmayan başvurunun geçici %qT türünden ilklendirilmesi geçersiz"
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "%qT türündeki başvurunun %qT türündeki ifadeden ilklendirilmesi geçersiz"
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "%2$q#D işlevinin %<this%> parametresi olarak %1$qT aktarımı niteleyicileri iptal ediyor"
 
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "%qE bitalanı %qT türüne bağlanamaz"
 
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "%qE paketli alanı %qT türüne bağlanamaz"
 
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "sağ taraf değeri %qE, %qT türüne bağlanamaz"
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden aktarılamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden alınamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "%q#D için öntanımlı argümanın yeniden tanımı"
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "%2$qD işlevinin %1$d. parametresi için öntanımlı argüman henüz çözümlenmedi"
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "işlev çağrısı argümanı bir biçim özniteliği için aday olabilir"
 
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr ""
 
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "%2$q#D işlevinin %<this%> parametresi olarak %1$qT aktarımı niteleyicileri iptal ediyor"
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  %qD çağrısında"
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "%s %q+#D için argümanlar çok fazla"
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "bildirim içinde atama (ilklendirme değil)"
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "yerine #include kullanın"
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "; use value-initialization instead"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "bildirim içinde atama (ilklendirme değil)"
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "yerine #include kullanın"
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: re-initialization of '%s' at %L"
 msgid "; use copy-initialization instead"
 msgstr "Ek:`%s' için (%L'de) yeniden ilklendirme"
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden alınamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden alınamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%#qT declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, gcc-internal-format
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr ""
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "kurucular virtual olarak bildirilemez"
 
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "%<%T::%s(%A)%#V%> çağrısı ile eşleşen işlev yok"
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "%<%T::%s(%A)%#V%> çağrısı ile eşleşen işlev yok"
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "%<%D(%A)%> çağrısı ile eşleşen bir işlev yok"
 
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "aşırı yüklü %<%s(%A)%> çağrısı belirsiz"
 
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from constructor"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from destructor"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "üye işlev %qD nesne olmaksızın çağrılamaz"
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "%qT aktarımı %qT türünü %qT türü üzerinden seçiyor"
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr "İlkinin en kotü dönüşümü ikincisinden daha iyi olsa bile ISO C++ bunlar belirsizdir der:"
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "try making the operator a %<const%> member function"
 msgstr "%qD static olmayan bir üye işlev olmalıdır"
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "%qD %qD üzerinden,"
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  %qT türünden %qT türüne dönüşüm için seçiliyor,"
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  çünkü argüman için dönüşüm süreci daha iyi"
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "doğrudan özelleştirmede öntanımlı argüman belirtilmiş"
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid " candidate 1: %q#F"
 msgstr "aday: %+#D"
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid " candidate 2: %q#F"
 msgstr "aday: %+#D"
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "İlkinin en kotü dönüşümü ikincisinden daha iyi olsa bile ISO C++ bunlar belirsizdir der:"
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "%qT türündeki sabit olmayan başvurunun geçici %qT türünden ilklendirilmesi geçersiz"
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "%qT türündeki başvurunun %qT türündeki ifadeden ilklendirilmesi geçersiz"
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "possibly dangling reference to a temporary"
 msgstr "geçiciye başvuru dönüyor"
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr ""
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, gcc-internal-format
 msgid "explicit conversion function was not considered"
 msgstr ""
@@ -57686,7 +57712,7 @@ msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D,"
 
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %q#D"
@@ -58154,7 +58180,7 @@ msgstr "%Jbaşka bir boş yapı içinde esnek dizi"
 msgid "next member %q#D declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T sınıfın yeniden tanımı"
@@ -58296,7 +58322,7 @@ msgstr "işlev %q+#D için soyut dönüş değeri türü geçersiz"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
@@ -58341,7 +58367,7 @@ msgstr ""
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%q+D normalde bir static olmayan işlevdir"
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr ""
@@ -58361,7 +58387,7 @@ msgstr "dosya etki alanı boş bildiriminde %<register%>"
 msgid "%q+E is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
@@ -58384,7 +58410,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
@@ -58437,7 +58463,7 @@ msgstr "%qT bir belirsiz %qT tabanıdır"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
@@ -58585,20 +58611,20 @@ msgstr "dizi indisi bir tamsayı değil"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> gösterici ilişkilendirmesi"
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -58607,532 +58633,532 @@ msgstr "%<void *%> gösterici ilişkilendirmesi"
 msgid "%qE is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "%qD şablon parametresi %qT türündeyse butunleyen ya da sırali türde olmadığından bir butunleyen sabit ifadesinde kullanılmaz"
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr ""
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, fuzzy, gcc-internal-format
 #| msgid "global destructors not supported on this target"
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "bu hedefte global yıkıcılar desteklenmiyor"
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "allocated here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
 msgstr ""
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, fuzzy, gcc-internal-format
 #| msgid "no field %qD found in union being initialized"
 msgid "%qD used in its own initializer"
 msgstr "ilklendirilen union içinde %qD diye bir alan yok"
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%q#D is not const"
 msgstr "%q+D bir işlev değil,"
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is private"
 msgid "%q#D is volatile"
 msgstr "%q+#D private'dir"
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD bu etki alanında bildirilmemiş"
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr ""
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr ""
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr ""
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "statement is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "inline assembly is not a constant expression"
 msgstr "ilklendirici öğe bir sabit değil"
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "use of %qD"
 msgstr "%qD kullanımı geçersiz"
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr ""
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr ""
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr ""
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr ""
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, gcc-internal-format
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "koşullu ifade içinde enum ve enum olmayan türler"
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "ilklendirici öğe bir sabit değil"
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr "%qD şablon parametresi %qT türündeyse butunleyen ya da sırali türde olmadığından bir butunleyen sabit ifadesinde kullanılmaz"
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "pointed-to object declared here"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr "%qD şablon parametresi %qT türündeyse butunleyen ya da sırali türde olmadığından bir butunleyen sabit ifadesinde kullanılmaz"
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "contract predicate is false in constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "unexpected template-id %qE"
 msgstr "deyim umuluyordu"
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, fuzzy, gcc-internal-format
 #| msgid "function not inlinable"
 msgid "function concept must be called"
 msgstr "işlev satıriçine alınabilir değil"
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "ifade umuluyordu"
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "%qT türündeki bir sağ taraf değerinin %qT türüne dönüşümü geçersiz"
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "new-expression is not a constant expression before C++20"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "%H%qE burada bildirilmemiş (bir işlev içinde değil)"
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "ilklendiricide sabit olmayan dizi indisi"
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
@@ -59939,7 +59965,7 @@ msgstr "%<__builtin_prefetch%> için 3. argüman bir sabit olmalı"
 msgid "no suspend point info for %qD"
 msgstr "%q+D için önceki prototip yok"
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -59961,23 +59987,23 @@ msgstr "case değeri olarak göstericiler kullanılamaz"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, fuzzy, gcc-internal-format
 #| msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
@@ -59999,79 +60025,79 @@ msgstr ""
 msgid "%qD was promoted to an immediate function"
 msgstr "%qD bir şablon işlevi değildir"
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of an immediate function %qD"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "call to consteval function %qE is not a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD, will always evaluate as %<true%>"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "özniteliklerin şablon parametrelerine uygulanması gerçeklenmedi"
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "pack expansion of %qE attribute"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in template argument list"
 msgid "use fold expression in the attribute argument instead"
 msgstr "şablon argüman listesinde çözümleme hatası"
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a type"
 msgstr "%qD bir şablon değil"
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qD is not a class type"
 msgstr "%qE sınıf türüne sahip değil"
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE sınıf türüne sahip değil"
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral type"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
@@ -60124,7 +60150,7 @@ msgstr "%qT türündeki sabit olmayan başvurunun geçici %qT türünden ilklend
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "%qT türünden %qT türüne dönüşüm niteleyicileri iptal ediyor"
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "%qT türünden %qT türüne dönüşüm gösterici başvurusunu kaldırmaz"
@@ -60549,7 +60575,7 @@ msgstr "önceki %q+F bildirimindeki farklı olağandışılıkları yakalıyor"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -60714,8 +60740,8 @@ msgstr "önceden işlev olmayan bildirim %q+#D"
 msgid "%q#D previously defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#D previously declared here"
@@ -60799,60 +60825,42 @@ msgstr "öntanımlı argüman %2$q#D bildiriminin %1$d. parametresi için"
 msgid "previous specification in %q#D here"
 msgstr "%q+#D bildirimindeki önceki belirtimden sonra verilmiş"
 
-#: cp/decl.cc:2285
-#, fuzzy, gcc-internal-format
-#| msgid "conflicts with built-in declaration %q#D"
-msgid "declaration %qD conflicts with builtin"
-msgstr "%q#D yerleşik bildirimiyle çelişiyor"
-
-#: cp/decl.cc:2288
-#, fuzzy, gcc-internal-format
-#| msgid "conflicts with built-in declaration %q#D"
-msgid "declaration %qD conflicts with import"
-msgstr "%q#D yerleşik bildirimiyle çelişiyor"
-
-#: cp/decl.cc:2289
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D declared here"
-msgid "import declared %q#D here"
-msgstr "burada bildirilmiş %q+D"
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting exporting for declaration %qD"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "previously declared here without exporting"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD here"
 msgstr "%q+D'nin önceki tanımı buradaydı"
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD here"
 msgstr "%qD'nin önceki bildirimi buradaydı"
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, fuzzy, gcc-internal-format
 #| msgid "function declared %<noreturn%> has a %<return%> statement"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "%<noreturn%> olarak bildirilmiş işlev %<return%> deyimi içeriyor"
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "%qD bildiriminin aynı bağlamda bununla yeniden bildirimi anlamsız:"
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q+D"
 msgid "deleted definition of %qD is not first declaration"
@@ -60866,50 +60874,50 @@ msgstr "%q+D için yeniden tanımlama"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "ilk kullanımdan sonra %D'nin açıkça özelleştirilmesi"
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D: visibility attribute ignored because it"
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%q+D: görünürlük özniteliği yoksayıldı çünkü"
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "redefinition of %q#D"
 msgstr "%q#T sınıfın yeniden tanımı"
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%qD conflicts with used function"
 msgstr "%q#D önceki using bildirimi %q#D ile çelişiyor"
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, fuzzy, gcc-internal-format
 #| msgid "%qD not declared"
 msgid "%q#D not declared in class"
 msgstr "%qD bildirilmemiş"
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -60917,821 +60925,821 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, fuzzy, gcc-internal-format
 #| msgid "thread-local declaration of %q+D follows non-thread-local declaration"
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "%q+D'nin yerel-evreli bildirimi yerel-olmayan-evreli bildirimi izliyor"
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, fuzzy, gcc-internal-format
 #| msgid "non-thread-local declaration of %q+D follows thread-local declaration"
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "%q+D'nin yerel-olmayan-evreli bildirimi yerel-evreli bildirimi izliyor"
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D"
 msgid "redeclaration of %q#D"
 msgstr "%q#D yeniden bildirimi"
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "%qD bildiriminin aynı bağlamda bununla yeniden bildirimi anlamsız:"
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous label"
 msgstr "önceden %q+D bildirimi"
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, gcc-internal-format
 msgid "jump to label %qD"
 msgstr "%qD yaftasına jump"
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr "case yaftasına jump"
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr ""
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  buradan"
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr ""
 
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  %q+#D ilklendirmesini kesiyor"
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  try blokuna giriliyor"
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  catch blokuna giriyor"
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters OpenMP structured block"
 msgstr "  try blokuna giriliyor"
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, fuzzy, gcc-internal-format
 #| msgid "jump into statement expression"
 msgid "  enters statement expression"
 msgstr "deyim ifadesine jump"
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr ""
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, gcc-internal-format
 msgid "  enters %<consteval if%> statement"
 msgstr ""
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "  does not destroy %qD"
 msgstr "%s %s desteği vermiyor"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, gcc-internal-format
 msgid "  does not clean up handled exception"
 msgstr ""
 
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  %q+#D ilklendirmesi atlanıyor"
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is a function, not a type"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a template"
 msgid "%q#T is not a class"
 msgstr "%q#T bir şablon değil"
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, fuzzy, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "%2$q#T içinde %1$q#T isminde sınıf şablonu yok"
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "%2$q#T içinde %1$q#T isminde tür yok"
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "%qT türünden %qT türüne dönüşüm belirsiz"
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%qT bir sınıf türü olmayan %qT türüne çözümleniyor"
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<%T::%D%> bir tür değil"
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "şablon parametreleri bu şablonla uyuşmuyor:"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, fuzzy, gcc-internal-format
 #| msgid "trampolines not supported"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "trampolines desteklenmiyor"
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D geçersiz; bir anonim union sadece statik olmayan veri üyeleri içerebilir"
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous struct not inside named type"
 msgid "anonymous struct with base classes"
 msgstr "anonim yapı isimli türün içinde değil"
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "anonim kümeleme içinde kuruculu üye %q+#D kullanılamaz"
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "anonim kümeleme içinde yıkıcılı üye %q+#D kullanılamaz"
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "anonim kümeleme içinde kopya atama isleçli üye %q+#D kullanılamaz"
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in declaration of %q#T"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, fuzzy, gcc-internal-format
 #| msgid "attribute for %q+#T must follow the %qs keyword"
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "%q+#T için öznitelik %qs anahtar sözcüğünü izlemeli"
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "bir bildirimde birden fazla tür"
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "C++ yerleşik türü %qT için yeniden bildirim"
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typedef bildiriminde tür ismi eksik"
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ anonim yapıları (struct) yasaklar"
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> sadece bir sınıf içinde belirtilebilir"
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> sadece kurucular için belirtilebilir"
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "bir saklama sınıfı sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "niteliyiciler sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "niteliyiciler sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "niteliyiciler sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "bir saklama sınıfı sadece işlevler ve nesneler için belirtilebilir"
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, fuzzy, gcc-internal-format
 #| msgid "typedef declaration invalid in parameter declaration"
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "typedef bildirimi parametre bildiriminde geçersiz"
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, fuzzy, gcc-internal-format
 #| msgid "%<register%> in file-scope empty declaration"
 msgid "%qs cannot be used for type declarations"
 msgstr "dosya etki alanı boş bildiriminde %<register%>"
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use __typeof__ instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD ilklendirilmiş (yerine  __typeof__  kullanın)"
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "%q#D hem %<extern%> olarak bildirilmiş hem de ilklendirilmiş"
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D definition is marked dllimport"
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "%q+D işlevinin tanımı dllimport imli"
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D %qT'nin bir static olmayan üyesi değildir"
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D şablon bildirimi"
 
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "geçersiz üye sablonu bildirimi %qD"
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ %<%T::%D%>nin %<%T::%D%> olarak tanımlanmasına izin vermez"
 
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "%qD ilklendirmesi yinelenmiş"
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr ""
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "%q#D değişkeni ilklendirilmiş ama içi boş türde"
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "%q#D dizisinin elemanları içi boş türde"
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "küme %q#D içi boş türde olup tanımlı olamaz"
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD başvuru olarak bildirilmiş ama ilklendirilmemiş"
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "%qD ismi bir dizi için GNU tarzında tasarlanmış bir ilklendiricide kullanılmış"
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "%qD ismi bir dizi için GNU tarzında tasarlanmış bir ilklendiricide kullanılmış"
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "alelade olmayan ilklendiriciler desteklenmiyor"
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "ilklendirici %qD bildiriminin boyutunu saptayamıyor"
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD bildiriminde dizi boyutu eksik"
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "sıfır boyutlu dizi %qD"
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t known"
 msgid "storage size of %qD isn%'t known"
 msgstr "%q+D nin saklama uzunluğu bilinmiyor"
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of %q+D isn%'t constant"
 msgid "storage size of %qD isn%'t constant"
 msgstr "%q+D nin saklama genişligi sabit değil"
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "özür: satıriçi işlev static verisi %q+#D'nin kodlaması yanlış (sizi çoklu kopyalara sürükleyecek)"
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, fuzzy, gcc-internal-format
 #| msgid "sorry: semantics of inline function static data %q+#D are wrong (you'll wind up with multiple copies)"
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "özür: satıriçi işlev static verisi %q+#D'nin kodlaması yanlış (sizi çoklu kopyalara sürükleyecek)"
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, fuzzy, gcc-internal-format
 #| msgid "%J  you can work around this by removing the initializer"
 msgid "you can work around this by removing the initializer"
 msgstr "%J  ilklendiriciyi kaldırarak bunun olurunu bulabilirsiniz"
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "ilklendirilmemiş sabit %qD"
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has a user-defined constructor"
 msgid "%q#T has no user-provided default constructor"
 msgstr "%qs türü bir kullanıcı tanımlı yapıcıya sahip"
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, fuzzy, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "%2$qT türündeki bir vektör için ilklendirici olarak %1$qT türü geçersiz"
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "%qT için ilklendirici {} içinde olmalı"
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, fuzzy, gcc-internal-format
 #| msgid "name %qD used in a GNU-style designated initializer for an array"
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%qD ismi bir dizi için GNU tarzında tasarlanmış bir ilklendiricide kullanılmış"
 
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "üye %qD için istek belirsiz"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD %qT'nin bir üyesi değil"
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer for %q#D"
 msgstr "geçersiz ilklendirici"
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT için ilklendirici sayısı çok fazla"
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "%qT için skalar ilklendiriciyi kuşatan parantezler"
 
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "%qT için skalar ilklendiriciyi kuşatan parantezler"
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "%qT için ilklendiriciyi çevreleyen parantezler yok"
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "structured binding has incomplete type %qT"
 msgstr "%qD alanı içi boş türde"
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "elements of array %q#T have incomplete type"
 msgstr "%q#D dizisinin elemanları içi boş türde"
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids compound literals"
 msgid "variable-sized compound literal"
 msgstr "ISO C90 bileşik sabitlere izin vermez"
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has incomplete type"
 msgid "%q#D has incomplete type"
 msgstr "%qD içi boş türde"
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "scalar object %qD requires one element in initializer"
 msgstr "union ilklendiricide gereğinden fazla öğe"
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be initialized by constructor, not by %<{...}%>"
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "%qD bir kurucu ile ilklendirilmeli, %<{...}%> ile değil"
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, fuzzy, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "parantezli dizge sabiti %2$qE ile ilklendirilmiş %1$qD dizgesi"
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "kuruculu statik üye için ilklendirici geçersiz"
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "ISO C++ sabit olmayan statik %qD üyesinin sınıf içi ilklendirmesine izin vermez"
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "ISO C++ sabit olmayan statik %qD üyesinin sınıf içi ilklendirmesine izin vermez"
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(bir sınıf dışı ilklendirme gerekli)"
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "reference %qD is initialized with itself"
 msgstr "%qD parametresi ilklendirilmiş"
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "could not find variant declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%s %q+#D için argümanlar çok az"
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "enumerator %q+D yeniden bildirilmiş"
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "bildirim içinde atama (ilklendirme değil)"
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "%qs için saklatım sınıfı belirtilmiş"
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D has %<extern%> and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D hem %<extern%> olarak bildirilmiş hem de ilklendirilmiş"
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "dönüş türü %q#T bir içi boş türdür"
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "değişken uzunluklu nesne ilklendirilemeyebilir"
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "önceki %q#D tür bildirimini gölgeliyor"
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "%q#D işlevi bir değişken gibi ilklendirilmiş"
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  %q+D'deki atıl baglantı bir yıkıcıya sahip olduğundan kullanılamaz"
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT, bir erişilemeyen %qT tabanıdır"
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "içi boş ture gösterici ilişkilendirme"
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 değişken boyutlu %qs dizisini yasaklar"
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%u name provided for structured binding"
@@ -61739,1939 +61747,1939 @@ msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs yapı alan için saklama sınıfı belirtilmiş"
 msgstr[1] "%qs yapı alan için saklama sınıfı belirtilmiş"
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "%q#T türüne gösterici bildirilemez"
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "in initialization of structured binding variable %qD"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot decompose union type %qT"
 msgstr "bit alanı %qD işlev türü ile bildirilemez"
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "adres çözümlenemez"
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, fuzzy, gcc-internal-format
 #| msgid "return type is an incomplete type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "dönüş türü, bir içi boş tür"
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "static olmayan veri üyesi %qD kullanımı geçersiz"
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "ilklendirici %qD bildiriminin boyutunu saptayamıyor"
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "%qD bildiriminde dizi boyutu eksik"
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "sıfır boyutlu dizi %qD"
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "yabancı sınıf %qT için yıkıcı, bir üye olamaz"
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "yabancı sınıf %qT için kurucu, bir üye olamaz"
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D bir olağandışılık belirtimi ile bildirilmiş"
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD tanımı %qT bağlamını kapsayan isim alanınında değil"
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statik üye işlev %q#D tür niteleyicilerle bildirilmiş"
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%q+D bir parametre olarak bildirilmemiş"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "%q+D parametresi void olarak bildirilmiş"
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java yöntemi %qD Java olmayan %qT dönüş türünü içeriyor"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "concept %qD has no definition"
 msgstr "%Jeski tarz işlev tanımı"
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, fuzzy, gcc-internal-format
 #| msgid "union cannot be made transparent"
 msgid "a function concept cannot be constrained"
 msgstr "birleşik yapı şeffaf olamaz"
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD bir şablon işlevi değildir"
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "constrained non-template friend declaration must be a definition"
 msgstr "kardeş bildirimi sınıf bildiriminde değil"
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "%qD doğrudan özelleştirmesinin kardeş bildirimde tanımı"
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "birincil şablon bildiriminde %qD şablon kimliğinin kullanımı geçersiz"
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "kardeş şablon özelleştirmesi %qD bildiriminde %<inline%> kullanılamaz"
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "%<::main%> bir şablon olarak bildirilemez"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "%<::main%> inline olarak bildirilemez"
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "%<::main%> static olarak bildirilemez"
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "%<::main%> static olarak bildirilemez"
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "explicit object parameter declared here"
 msgstr "void bildirimli değişken ya da alan"
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr ""
 
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "işlev olmayan olarak %qD bildirimi"
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "C ilintilemeli şablon"
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "%qD has invalid argument list"
 msgstr "seçenek argümanı %qs geçersiz"
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "%qD static olmayan bir üye işlev olmalıdır"
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> %<int%> döndürmeli"
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "dolaylı bildirimli %qD tanımı"
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "dolaylı bildirimli %qD tanımı"
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "sınıf %2$qT içinde bildirilmiş %1$q#D diye bir üye işlev yok"
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%<::main%> bir şablon olarak bildirilemez"
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, fuzzy, gcc-internal-format
 #| msgid "strong using only meaningful at namespace scope"
 msgid "concept must be defined at namespace scope"
 msgstr "kesin kullanım sadece isimalanı kapsamında anlamlıdır"
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot be a sub-component"
 msgid "a variable concept cannot be constrained"
 msgstr "%C'deki döngü değişkeni bir alt bileşen olamaz"
 
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ sabit olmayan statik %qD üyesinin sınıf içi ilklendirmesine izin vermez"
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ tümlemeyen %2$qT türündeki %1$qD üye sabitinin ilklendirilmesine izin vermez"
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "%qD dizisinin boyutu tümlemeyen %qT türünde"
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "dizi boyutu tümlemeyen %qT türünde"
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ da sıfır boyutlu %qD dizisi yasaktır"
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++'da sıfır boyutlu dizi yasaktır"
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array %qD"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ değişken boyutlu %qD dizisine izin vermez"
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++  değişken boyutlu diziye izin vermez"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "dizi boyutunda taşma"
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "creating array of template placeholder type %qT"
 msgstr "%qT üye referans türünde gösterici oluşturulması"
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "void dizisi olarak %qs bildirimi"
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of void"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of functions"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of references"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "creating array of function members"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "çok boyutlu dizi olarak %qD bildiriminde ilki dışında tüm boyutlar sınırlanmış olmalıdır"
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "çok boyutlu dizi bildiriminde ilki dışında tüm boyutlar sınırlanmış olmalıdır"
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when a variable is unused"
 msgid "variable-length array of %<auto%>"
 msgstr "Bir değişken kullanılmamışsa uyarır"
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "kurucu için dönüş türü belirtimi geçersiz"
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "yıkıcı için dönüş türü belirtimi geçersiz"
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "%<operator %T%> için dönüş türü belirtilmiş"
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "yıkıcı için dönüş türü belirtimi geçersiz"
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD bildiriminde çok fazla şablon parametresi listeleniyor"
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "void bildirimli adsız değişken ya da alan"
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "void bildirimli değişken ya da alan"
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<inline%> belirteci geçersiz"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of undefined type %<%s %E%>"
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "tanımsız tür %<%s %E%> kullanımı geçersiz"
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of undefined type %<%s %E%>"
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "tanımsız tür %<%s %E%> kullanımı geçersiz"
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "işlev olmayan olarak %qD bildirimi"
 
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "üye olmayan olarak %qD bildirimi"
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "bildirimci kimliği eksik; yedek sözcük %qD kullanılıyor"
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<register%>"
 msgid "function definition does not declare parameters"
 msgstr "%<register%> bildirimli işlev tanımı"
 
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "işlev olmayan olarak %qD bildirimi"
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "%2$s olarak %1$qD bildirimi"
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, fuzzy, gcc-internal-format
 #| msgid "a template-id may not appear in a using-declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "using bildiriminde bir şablon kimliği bulunamaz"
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "%qs bildiriminde iki veya daha fazla veri türü"
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C salt %<complex%>i %<double complex%> anlamında desteklemez"
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ türsüz %qs bildirimine izin verilmez"
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs bu hedef tarafından desteklenmiyor"
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ %<long long%> desteklemez"
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, fuzzy, gcc-internal-format
 #| msgid "signed and unsigned given together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%qs için signed ve unsigned birlikte verilmiş"
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, fuzzy, gcc-internal-format
 #| msgid "long and short specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%qs için long ve short birlikte belirtilmiş"
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%qs specified with %qT"
 msgstr "%<__thread%> %qE ile kullanılmış"
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified with typedef-name %qD"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qs specified with %<decltype%>"
 msgstr "%<__thread%> %<typedef%> ile kullanılmış"
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> %<typedef%> ile kullanılmış"
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "%qs için complex geçersiz"
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "üye %qD, hem virtual hem de static olarak bildirilemez"
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "üye %qD, hem virtual hem de static olarak bildirilemez"
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef bildirimi parametre bildiriminde geçersiz"
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for template parameter %qs"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "a parameter cannot be declared %qs"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "sanal dış sınıf bildirimi"
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr ""
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs bildiriminde çok sayıda saklama sınıfı"
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "%qs için saklatım sınıfı belirtilmiş"
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "iç işlev %qs %<extern%> olarak bildirilmiş"
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "%qs için tepe-seviye bildirim %<auto%> belirtiyor"
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs işlevinin etki alanı dolaylı olarak auto ve %<__thread%> bildirimli"
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "saklatım sınıfı belirteçleri kardeş işlev bildirimlerinde geçersiz"
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "%qE özniteliği yoksayıldı"
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs bildiriminde çok sayıda saklama sınıfı"
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "Umulmadık sol parantez"
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, gcc-internal-format
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "a function type cannot have an explicit object parameter"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, gcc-internal-format
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr ""
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, gcc-internal-format
 msgid "the type of an explicit object member function is a regular function type"
 msgstr ""
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "valid explicit object parameter declared here"
 msgstr "void bildirimli değişken ya da alan"
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "requires-clause on return type"
 msgstr "%qE özniteliği veri türlerinde yoksayılır"
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "tür niteleyicileri işlev dönüş türünde yok sayıldı"
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr ""
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs işlevle dönen işlev olarak bildirilmiş"
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs dizi ile dönen işlev olarak bildirilmiş"
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, fuzzy, gcc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%L'deki CASE deyiminde mantıksal aralığa izin verilmez"
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "yıkıcı bir statik üye işlev olamaz"
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "kurucu bir statik üye işlev olamaz"
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "kurucular cv-nitelemeli olmayabilir"
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "kurucular virtual olarak bildirilemez"
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "kardeş bildirimi sınıf bildiriminde değil"
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "yerel sınıf tanımı içinde kardeş işlev %qs tanımlanamaz"
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD cannot be an explicit object member function"
 msgstr "%qD static olmayan bir üye işlev olmalıdır"
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "yıkıcılar parametre almayabilir"
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "%q#T türüne gösterici bildirilemez"
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "%q#T üyeye gösterici bildirilemez"
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "bit alanı %qD işlev türü ile bildirilemez"
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "şablon kimliği %qD bir bildirici olarak kullanılmış"
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "üye işlevler sınıflarının örtük kardeşleridir"
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, fuzzy, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "üye %2$qs üzerinde fazladan niteleme %<%1$T::%>"
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "üye işlev %<%T::%s%> %<%T%> içinde tanımlanamaz"
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "uye işlev %<%T::%s%> %<%T%> içinde bildirilemez"
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "üye %<%T::%s%> %qT içinde bildirilemez"
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "veri üyesi %qD bir üye şablon olamaz"
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "veri üyesi değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parametre değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "sanal dış sınıf bildirimi"
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "sadece kurucuların bildirimleri %<explicit%> olabilir"
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "nesne olmayan üye %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "işlev %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "static %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "sabit %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "işlev %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "typedef may not be a function definition"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "typedef may not be a member function definition"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef declared %<auto%>"
 msgstr "%<inline%> bildirimli typedef %q+D"
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%Jtypedef ismi bir iç içe isimli belirteç olmayabilir"
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ kapsayan sınıf ile aynı isimde yuvalanmış %qD türüne izin vermez"
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "kardeş sınıf bildirimi için %<inline%> belirtilmiş"
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend bildirimi sınıf anahtarı gerektirir, %<friend class %T::%D%> gibi"
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend bildirimi %<friend %#T%> gibi bir sınıf anahtarı gerektirir"
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "sınıf %qT genel bağlamın kardeşi yapılmaya çalışılıyor"
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "üye olmayan işlev türünde niteleyiciler geçersiz"
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "mutlak bildirimci %qT bildirim olarak kullanılmış"
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "parametre %q+D soyut %qT türünde bildirilemez"
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "bu kapsamda %<this%> kullanılamaz"
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter declared %<auto%>"
 msgstr "%<inline%> bildirimli %q+D parametresi"
 
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "bir argüman listesi olmaksızın %qE şablon isminin kullanımı geçersiz"
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ da sıfır boyutlu %qD dizisi yasaktır"
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 esnek dizi üyelerini desteklemez"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "C işlevi %q#D bildirimi"
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "işlev %qD bir union içinde virtual olarak bildirilmiş"
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD daima static olduğundan sanal olarak bildirilemez"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "yıkıcı %qD için kardeş bildiriminde nitelikli isim umuluyordu"
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%2$qT üyesi olarak %1$qD bildirimi"
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a destructor cannot be %qs"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, fuzzy, gcc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "yıkıcı %qD için kardeş bildiriminde nitelikli isim umuluyordu"
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a constructor cannot be %<concept%>"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "kurucu bir statik üye işlev olamaz"
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "%s açılamıyor"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "örtük bildirimli özel üye işlev özelleştirmesi"
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "void bildirimli değişken ya da alan"
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "%qD alanı içi boş türde"
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "%qT ismi içi boş türde"
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE ne işlev ne de üye işlev; friend olarak bildirilemez"
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE ne işlev ne de üye işlev; friend olarak bildirilemez"
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "static data member %qE declared %qs"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "Yerleşik '%s' %L'de bir ilklendiriciye sahip olamaz"
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "saklama sınıfı %<auto%> %qs işlevi için geçersiz"
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "saklama sınıfı %<register%> %qs işlevi için geçersiz"
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "saklama sınıfı %<__thread%> %qs işlevi için geçersiz"
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "saklama sınıfı %<__thread%> %qs işlevi için geçersiz"
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "bir işlev tanımında bir asm belirtimine izin verilmez"
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<static%> belirteci geçersiz"
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<inline%> belirteci geçersiz"
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "sınıf olmayan sanal işlev %qs"
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qs defined in a non-class scope"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qD bu etki alanında bildirilmemiş"
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "üye işlev %qD static ilintilemeli olarak bildirilemez"
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "statik işlev başka bir işlevin içinde bildirilemez"
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "bir statik veri üyesi tanımlarken (bildirime zit olarak) %<static%> kullanılamayabilir"
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "üye %q#D harici ilintilemeli olarak doğrudan bildirilemez"
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs ilklendirilmiş ve %<extern%> bildirilmiş"
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs hem %<extern%> olarak bildirilmiş hem de ilklendrilmiş"
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "öntanımlı argüman %qE %qD yerel değişkenini kullanıyor"
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "öntanımlı argüman %qE %qD yerel değişkenini kullanıyor"
 
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type %qT"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "geçersiz parametre türü %qT"
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parametre %qD geçersiz olarak yöntem türünde bildirilmiş"
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parametre %1$qD bilinmeyen sınırlı %3$qT dizisine %2$s içeriyor"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parametre %1$qD bilinmeyen sınırlı %3$qT dizisine %2$s içeriyor"
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "kurucu geçersiz; muhtemelen %<%T (const %T&)%> anlamında kullandınız"
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD bir isim alanı içinde bildirilemeyebilir"
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD static olarak bildirilemeyebilir"
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD static olmayan bir üye işlev olmalıdır"
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a member function"
 msgstr "%qD static olmayan bir üye işlev olmalıdır"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr ""
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD ya bir statik olmayan üye işlev ya da üye olmayan işlev olmalıdır"
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD ya bir sınıf argümanına sahip olmalı ya da enum türünde olmalı"
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ ?: üç terimlisinin aşırı yüklenmesini yasaklar"
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD ya hiç argüman almamalı ya da bir argüman almalı"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD ya bir ya da iki argüman almalı"
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "sonek %qD argüman olarak %<int%> almalı"
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "sonek %qD ikinci argümanı olarak %<int%> almalı"
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD sadece ve sadece iki argüman almalı"
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD sadece ve sadece bir argüman almalı"
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD sadece ve sadece iki argüman almalı"
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "kullanıcı tanımlı %qD daima her iki argümanıyla birlikte değerlendirilir"
 
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "önek %qD %qT döndürmeli"
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "sonek %qD %qT döndürmeli"
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD değeriyle döndürülmeli"
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "%2$qs sonrası şablon türü %1$qT parametresi kullanımı"
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "%2$q+D için şablon özelleştirmesi %1$qD belirsiz"
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, fuzzy, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "%2$qs sonrası typedef-ismi %1$qD kullanımı"
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D için burada önceki bir bildirim var"
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT türüne %qs olarak başvuruluyor"
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T için burada önceki bir bildirim var"
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT türüne enum olarak başvuruluyor"
@@ -63683,122 +63691,104 @@ msgstr "%qT türüne enum olarak başvuruluyor"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%> için şablon argüman gerekli"
 
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%qD ile ilişkilendirme belirsiz"
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "class template %qD redeclared as non-template"
 msgstr "şablon olarak şablon olmayan %qD kullanılmış"
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD bildirildiği sınıf ile aynı isimde"
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT bir şablon değil"
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "önceden bildirim olmaksızın enum %q#D kullanımı"
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare %qD to be a bit-field type"
-msgid "cannot declare %qD in a different module"
-msgstr "%qD bir bit alanı türü olarak bildirilemez"
-
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D previously declared here"
-msgid "previously declared here"
-msgstr "%q+#D evvelce burada bildirilmiş"
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "türetilmiş union %qT geçersiz"
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is already defined in the class %qT"
 msgid "%qT defined with multiple direct bases"
 msgstr "%qD zaten sınıf %qT içinde tanımlı"
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "%qT türü bir doğrudan ya da dolaylı %qT tabanı değil"
 
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "taban tür %qT bir yapı veya sınıf türü olarak hatalı"
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "ardışık tür %qT tanımsız"
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "yinelenmiş taban türü %qT geçersiz"
 
-#: cp/decl.cc:16984
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare reference to %q#T"
-msgid "cannot declare %qD in different module"
-msgstr "%q#T türüne başvuru bildirilemez"
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%Jönceden burada tanımlı"
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
@@ -63807,91 +63797,91 @@ msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarı
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "%qT için simgesel sabit değerlerinin tamamını hiçbir tümleyen tür temsil edemez"
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD'de simgesel sabit değerlerinde taşma"
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "çok sayıda %q#T tanımı"
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "dönüş türü %q#T bir içi boş türdür"
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%>, %<*this%> için bir başvuru döndürmeli"
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "işlevin dönüş türü %<volatile%> den dolayı uyumsuz"
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD zaten %qT sınıfında tanımlı"
 
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, fuzzy, gcc-internal-format
 #| msgid "%J%s %<%c%s%>"
 msgid "using %qs"
 msgstr "%J%s %<%c%s%>"
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -63947,7 +63937,7 @@ msgstr "bir işlev silinemez. Sadece nesnelerin göstericileri %<delete%>'e konu
 msgid "deleting %qT is undefined"
 msgstr "%qT silinmesi tanımsız"
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D şablon bildirimi"
@@ -63958,7 +63948,7 @@ msgstr "%q#D şablon bildirimi"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "şablon parametreleri bu şablonla uyuşmuyor:"
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "yıkıcı %qD üye şablon olarak bildirilmiş"
@@ -64158,65 +64148,65 @@ msgstr ""
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> ilk parametreyi %qT türünde alır"
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr ""
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, gcc-internal-format
 msgid "%qT has a base %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, gcc-internal-format
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, gcc-internal-format
 msgid "%qT has a base %qT which has internal linkage"
 msgstr ""
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, gcc-internal-format
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using an unnamed type, is used but not defined"
@@ -64226,115 +64216,115 @@ msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "%2$qL ilintili önceki %1$q+#D bildirimi"
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "%2$qL ilintili önceki %1$q+#D bildirimi"
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D niteliksiz türe başvurmuyor, dolasıyla ilintileme için kullanılmaz"
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "%2$qL ilintili önceki %1$q+#D bildirimi"
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q#D önceki using bildirimi %q#D ile çelişiyor"
 
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous mangling %q#D"
 msgstr "önceden %q+D bildirimi"
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, gcc-internal-format
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "satıriçi işlev %q+D tanımlanmadan kullanılmış"
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q#D"
 msgstr "%2$q+#D'nin %1$P. parametresi için öntanımlı argüman eksik"
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "...following parameter %P which has a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "implicitly-declared %qD is deprecated"
 msgstr "%qs önerilmiyor"
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "NULL'dan gösterici olmayan türe dönüşüm"
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "use of deleted function %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "C işlevi %q#D bildirimi"
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -64441,7 +64431,7 @@ msgstr "%<%T::%D%> ile ilişkilendirme belirsiz"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD %qT'nin bir üyesi değil"
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD %qT'nin bir üyesi değil"
@@ -64452,7 +64442,7 @@ msgstr "%qD %qT'nin bir üyesi değil"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD, %qD nin bir üyesi değil"
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD, %qD nin bir üyesi değil"
@@ -64479,53 +64469,53 @@ msgstr "olağandışılık yakalaması iptal edildi, etkinleştirmek için -fexc
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr "tumleyen, gösterici olmayan NULL yakalanıyor"
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, gcc-internal-format
 msgid "  in thrown expression"
 msgstr "  yakalanmış ifade içinde"
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr "parametre %q+D soyut %qT türünde bildirilemez"
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create type information for type %qT because its size is variable"
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr "boyutu değişken olduğundan tür %qT için tür bilgisi oluşturulamaz"
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, fuzzy, gcc-internal-format
 #| msgid "cannot create type information for type %qT because its size is variable"
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr "boyutu değişken olduğundan tür %qT için tür bilgisi oluşturulamaz"
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexception of type %qT will be caught"
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr "%H%qT türündeki olağandışılık yakalanmış olacak"
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, fuzzy, gcc-internal-format
 #| msgid "as %qD"
 msgid "for type %qT"
 msgstr "%qD olarak"
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<...%> handler must be the last handler for its try block"
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr "%H%<...%> eylemcisi kendi try blokundaki son eylemci olmalıdır"
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr ""
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
 msgstr ""
@@ -64814,12 +64804,12 @@ msgstr "%qT türü bir doğrudan ya da dolaylı %qT tabanı değil"
 msgid "type %qT is not a direct base of %qT"
 msgstr "%qT türü bir doğrudan %qT tabanı değil"
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qT is not a class type"
@@ -64835,12 +64825,12 @@ msgstr "içi boş tür %qT üye %qD'yi içermiyor"
 msgid "invalid pointer to bit-field %qD"
 msgstr "%qD bit alanına gösterici geçersiz"
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "static olmayan veri üyesi %qD kullanımı geçersiz"
@@ -65048,55 +65038,55 @@ msgstr ""
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, fuzzy, gcc-internal-format
 #| msgid "compound literal has variable size"
 msgid "because the array element type %qT has variable size"
 msgstr "bileşik sabit değişken boyuta sahip"
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot capture %qE by reference"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "capture by copy of incomplete type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<this%> was not captured for this lambda function"
@@ -65503,240 +65493,292 @@ msgstr "İfade türü umuluyordu"
 msgid "encapsulation is malformed"
 msgstr ""
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting global module declaration %#qD"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration %q+D"
 msgid "existing declaration %#qD"
 msgstr "%q+D bildiriminde"
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, fuzzy, gcc-internal-format
 #| msgid "extern declaration of %q#D doesn't match"
 msgid "definition of %qD does not match"
 msgstr "%q#D extern bildirim uyumsuz"
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, fuzzy, gcc-internal-format
 #| msgid "missing definition"
 msgid "existing definition %qD"
 msgstr "tanım eksik"
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "... this enumerator %qD"
 msgstr "enumerator %q+D yeniden bildirilmiş"
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, fuzzy, gcc-internal-format
 #| msgid "extern declaration of %q#D doesn't match"
 msgid "enumerator %qD does not match ..."
 msgstr "%q#D extern bildirim uyumsuz"
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr ""
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr ""
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr ""
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, gcc-internal-format
 msgid "recursive lazy load"
 msgstr ""
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr ""
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "module %qs declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, gcc-internal-format
 msgid "indirect import %qs is not already loaded"
 msgstr ""
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr ""
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr ""
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "macro definitions of %qE corrupted"
 msgstr "  %q+#D tanımından"
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "inconsistent imported macro definition %qE"
 msgstr "%L ve %L'de işliçler için sıralar uyumsuz"
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr ""
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr ""
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file '%s': %s\n"
 msgid "compiled module file is %qs"
 msgstr "%s: `%s' silinemiyor: %s\n"
 
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collect2 version %s\n"
 msgid "compiled module is %sversion %s"
 msgstr "collect2 %s sürümü\n"
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collect2 version %s\n"
 msgid "compiler is %sversion %s%s%s"
 msgstr "collect2 %s sürümü\n"
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs not found"
 msgid "module %qs found"
 msgstr "alan %qs yok"
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr ""
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr ""
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr ""
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr ""
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, gcc-internal-format
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr ""
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, fuzzy, gcc-internal-format
 #| msgid "multiple function type attributes specified"
 msgid "fixed tree mismatch"
 msgstr "çok sayıda işlev türü öznitelik belirtilmiş"
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "interface partition is not exported"
 msgstr "yığıt sınırlama ifadesi desteklenmiyor"
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module cluster %u: %s"
 msgstr ""
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to get process times"
 msgid "failed to read compiled module: %s"
 msgstr "süreç zamanlarını almada başarısızlık"
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr ""
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr ""
 
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr ""
 
-#: cp/module.cc:19283
+#: cp/module.cc:19117
+#, fuzzy, gcc-internal-format
+#| msgid "conflicts with built-in declaration %q#D"
+msgid "declaration %qD conflicts with builtin"
+msgstr "%q#D yerleşik bildirimiyle çelişiyor"
+
+#: cp/module.cc:19122
+#, fuzzy, gcc-internal-format
+#| msgid "asm declaration ignored due to conflict with previous rename"
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr "asm bildirimi önceki isim değişikliği ile çeliştiğinden yoksayıldı"
+
+#: cp/module.cc:19125
+#, fuzzy, gcc-internal-format
+#| msgid "using declaration %q+D conflicts with a previous using declaration"
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr "%q+D bildirimi kullanımı önceki bildirimlerden biri ile çelişiyor"
+
+#: cp/module.cc:19130
+#, gcc-internal-format
+msgid "import declared attached to module %qs"
+msgstr ""
+
+#: cp/module.cc:19134
+#, gcc-internal-format
+msgid "import declared in global module"
+msgstr ""
+
+#: cp/module.cc:19140
+#, fuzzy, gcc-internal-format
+#| msgid "conflicting declaration %q#D"
+msgid "conflicting declaration of %qD in module %qs"
+msgstr "%q#D bildirimi çelişkili"
+
+#: cp/module.cc:19143
+#, fuzzy, gcc-internal-format
+#| msgid "conflicts with new declaration with %qL linkage"
+msgid "conflicting declaration of %qD in global module"
+msgstr "%qL ilintili yeni bildirim ile çelişiyor"
+
+#: cp/module.cc:19148
+#, fuzzy, gcc-internal-format
+#| msgid "%q+#D previously declared here"
+msgid "previously declared in module %qs"
+msgstr "%q+#D evvelce burada bildirilmiş"
+
+#: cp/module.cc:19152
+#, fuzzy, gcc-internal-format
+#| msgid "%q+#D previously declared here"
+msgid "previously declared in global module"
+msgstr "%q+#D evvelce burada bildirilmiş"
+
+#: cp/module.cc:19404
 #, fuzzy, gcc-internal-format
 #| msgid "Creating '%s'\n"
 msgid "reading CMI %qs"
 msgstr "'%s' oluşturuluyor\n"
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, gcc-internal-format
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, gcc-internal-format
 msgid "during load of pendings for %<%E%s%E%>"
 msgstr ""
@@ -65748,435 +65790,435 @@ msgstr ""
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr ""
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "module already declared"
 msgstr "'%s' bileşeni (%C'deki) zaten %L'de bildirilmiş"
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "module already imported"
 msgstr "'%s' bileşeni (%C'deki) zaten %L'de bildirilmiş"
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "module %qs imported here"
 msgstr "%q+D yaftası tanımlı ama kullanılmamış"
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown Compiled Module Interface: %s"
 msgstr ""
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr ""
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr ""
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr ""
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, gcc-internal-format
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr ""
 
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, fuzzy, gcc-internal-format
 #| msgid "Enable traditional preprocessing"
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr "Geleneksel önişlem etkin olur"
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr ""
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr ""
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, gcc-internal-format
 msgid "you should use the %<-%s%> option"
 msgstr ""
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter %qs"
 msgid "invalid header name %qs"
 msgstr "geçersiz parametre %qs"
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode %qs"
 msgid "invalid module name %qs"
 msgstr "gösterici kipi olarak %qs geçersiz"
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr ""
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, fuzzy, gcc-internal-format
 #| msgid "error writing %qs"
 msgid "writing CMI %qs"
 msgstr "%qs yazılırken hata"
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing modules file: %s"
 msgid "not writing module %qs due to errors"
 msgstr "Modul dosyasına yazarken hata: %s"
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to get process times"
 msgid "failed to write compiled module: %s"
 msgstr "süreç zamanlarını almada başarısızlık"
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown header kind %qs"
 msgstr "bilinmeyen yazmaç ismi: %s"
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, gcc-internal-format
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr ""
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D önceki using bildirimi %q#D ile çelişiyor"
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D %q#T kurucusunu gizliyor"
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, fuzzy, gcc-internal-format
 #| msgid "Generate code to check exception specifications"
 msgid "due to different exception specifications"
 msgstr "Olağan dışılık belirtimlerini sınayacak kod üretilir"
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "parametre %qD geçersiz olarak yöntem türünde bildirilmiş"
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "%q#D bildirimi bir parametreyi gölgeliyor"
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "%2$qT üyesi olarak %1$qD bildirimi"
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, fuzzy, gcc-internal-format
 #| msgid "using declaration %q+D conflicts with a previous using declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "%q+D bildirimi kullanımı önceki bildirimlerden biri ile çelişiyor"
 
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, gcc-internal-format
 msgid "exporting %q#D that does not have external linkage"
 msgstr ""
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here with no linkage"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, fuzzy, gcc-internal-format
 #| msgid "%qD redeclared with different access"
 msgid "%q#D declared here with internal linkage"
 msgstr "%qD farklı erişimle tekrar bildirilmiş"
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here with module linkage"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names destructor"
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T::%D%> yıkıcı isimlendiriyor"
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "sınıf bağlamında üye olmayan için using bildirimi"
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "%q#D şablon bildirimi"
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "sınıf bağlamında üye olmayan için using bildirimi"
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "%qT is not a direct base of %qT"
 msgstr "%qT türü bir doğrudan %qT tabanı değil"
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, fuzzy, gcc-internal-format
 #| msgid "%qD not declared"
 msgid "%qD has not been declared in %qD"
 msgstr "%qD bildirilmemiş"
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "using-declaration may not name namespace %qD"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> %qT içinde kurucu isimlendiriyor"
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD bildirimi %qD'yi kuşatan isim alanında değil"
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD bildiriminde doğrudan niteleme"
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD %qD içinde bildirilmeliydi"
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, fuzzy, gcc-internal-format
 #| msgid "%qD not declared"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD bildirilmemiş"
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "%qD öznitelik yönergesi yoksayıldı"
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %qE"
 msgstr "  %q+#D"
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr ""
 
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "statik üye işlevlerde %<this%> kullanılmaz"
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be declared"
 msgid "the macro %qs had not yet been defined"
 msgstr "%q+#D bildirilemez"
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "it was later defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "switch %qs artık desteklenmiyor"
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr "bu kapsamda %<this%> kullanılamaz"
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD bir isim alanı içinde bildirilemeyebilir"
 
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "'%s' simgesi (%L'de) belirsiz"
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "burada isim alanı rumuzu %qD kullanılamaz, %qD varsayılıyor"
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "inline namespace must be specified at initial definition"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "%qD defined here"
 msgstr "%q+D yaftası tanımlı ama kullanılmamış"
 
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%q#D önceki using bildirimi %q#D ile çelişiyor"
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "reachable %s definition here"
 msgstr "%Jönceden burada tanımlı"
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX, pop_everything () işlevine giriyor\n"
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -66203,7 +66245,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
@@ -66482,7 +66524,7 @@ msgstr ""
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr ""
@@ -66681,7 +66723,7 @@ msgstr "deyim ifadelerine sadece işlevlerin içinde izin verilir"
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected primary-expression"
@@ -66742,7 +66784,7 @@ msgstr ""
 msgid "template-id not allowed for destructor in C++20"
 msgstr ""
 
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, gcc-internal-format
 msgid "remove the %qs"
 msgstr ""
@@ -66763,7 +66805,7 @@ msgstr "typedef ismi %qD yıkıcı bildiricisi olarak kullanılmış"
 msgid "expected unqualified-id"
 msgstr "belirteç niteleyici listesi umuluyordu"
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD bir şablon değil"
@@ -66821,7 +66863,7 @@ msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "%qs özniteliği için belirtilen argüman sayısı yanlış"
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to bit-complement"
 msgid "wrong number of arguments to %<__builtin_launder%>"
@@ -66860,7 +66902,7 @@ msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr ""
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "%qD kullanımı geçersiz"
@@ -66888,7 +66930,7 @@ msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %qs expressions"
@@ -67050,8 +67092,8 @@ msgstr ""
 msgid "capture of non-variable %qE"
 msgstr "salt-okunur değişken %qD için eksiltme"
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here"
@@ -67092,7 +67134,7 @@ msgstr "öntanımlı argüman %2$q#D bildiriminin %1$d. parametresi için"
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr ""
@@ -67226,7 +67268,7 @@ msgstr "asm deyiminde geçersiz sol taraf"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr ""
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
@@ -67295,7 +67337,7 @@ msgstr "ifade deyimi boş tür içeriyor"
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
@@ -67322,7 +67364,7 @@ msgstr ""
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ hesaplanmış goto'lara izin vermez"
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
@@ -67630,13 +67672,13 @@ msgstr "temel ilklendiricileri sadece kurucular alır"
 msgid "cannot expand initializer for member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D statik bildirimi statik olmayan bildirimi izliyor"
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -68350,7 +68392,7 @@ msgstr "%q#D için öntanımlı argüman %qT türünde"
 msgid "%qT not permitted in template argument"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
@@ -68554,12 +68596,12 @@ msgstr "%q+#T türünde önceden tanım"
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, gcc-internal-format
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr ""
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
@@ -68783,40 +68825,40 @@ msgstr ""
 msgid "expression must be enclosed in parentheses"
 msgstr "%L'deki ifade değişmez olmalı"
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr ""
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "istenen konum bir tamsayı sabit değil"
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "istenen hizalama bir sabit değil"
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "yeniden %q+D bildirimi geçersiz"
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "şablon parametresi listesi çok az"
@@ -68825,496 +68867,496 @@ msgstr "şablon parametresi listesi çok az"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "şablon parametresi listesi çok fazla"
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, gcc-internal-format
 msgid "template-id not allowed for constructor in C++20"
 msgstr ""
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "isimli dönüş değerleri artık desteklenmiyor"
 
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "%qD için eşleşen bir şablon yok"
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, fuzzy, gcc-internal-format
 #| msgid "invalid declaration of member template %q#D in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "yerel sınıf içinde %q#D üye şablonu bildirimi geçersiz"
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "C ilintilemeli şablon"
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %qs"
 msgid "template declaration of %<typedef%>"
 msgstr "%qs şablon bildirimi"
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "bildirim hiçbir şey bildirmiyor"
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization in non-namespace scope %qD"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "isim alanı olmayan %qD kapsamında doğrudan özelleştirme"
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> alt şablon argüman listesinde %<> >%> olmalıydı"
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "sahte  %<>>%>, bir şablon argüman listesini sonlandırmak için %<>%> kullanın"
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, fuzzy, gcc-internal-format
 #| msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr "sahte  %<>>%>, bir şablon argüman listesini sonlandırmak için %<>%> kullanın"
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate %qD specifier"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, fuzzy, gcc-internal-format
 #| msgid "  conflict with %q+D"
 msgid "%qD specifier conflicts with %qs"
 msgstr "  %q+D ile çelişiyor"
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> before %<extern%>"
 msgid "%<__thread%> before %qD"
 msgstr "%<extern%> öncesinde %<__thread%>"
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr "%<__thread%> %<typedef%> ile kullanılmış"
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ %<long long%> desteklemez"
 
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, fuzzy, gcc-internal-format
 #| msgid "both %<short%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "bildirim belirteçlerinde hem %<short%> hem de %<char%>"
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE yinelenmiş"
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs yinelenmiş"
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<auto%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<co_yield%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> veya %<...%> umuluyordu"
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs yaftası %q#T isimlemesinde kullanılmış"
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "replace the class-key with %qs"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "%qT defined as %qs here"
 msgstr "%q+D yaftası tanımlı ama kullanılmamış"
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qT first declared as %qs here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD farklı erişimle tekrar bildirilmiş"
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (bir belirsizlik giderici olarak) sadece şablonlarda kullanılabilir"
 
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "öntanımlı argüman içinde dosya sonu"
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "yanlış yere konmuş %<@%D%> Nesnel-C++ oluşumu"
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> bir argüman olarak bir tür belirtmeli"
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "Nesnel-C++ seçici ismi geçersiz"
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "objective-c++ method declaration is expected"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, fuzzy, gcc-internal-format
 #| msgid "illegal reference type specified for instance variable %qs"
 msgid "invalid type for instance variable"
 msgstr "gerçekleme değişkeni %qs için ilişkilendirme türü kuraldışı"
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%> sonrasında betimleyici umuluyordu"
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE özniteliği %qE için yoksayıldı"
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "tür argümanı geçersiz"
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown property attribute %qE"
 msgstr "bilinmeyen yazmaç ismi: %s"
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected integer expression list"
 msgstr "ifade umuluyordu"
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<wait%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "geçersiz ilklendirici"
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in iterator type"
@@ -69324,13 +69366,13 @@ msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma vtable no longer supported"
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "#pragma vtable artık desteklenmiyor"
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
@@ -69340,143 +69382,143 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "iteration variable %qD should not be reduction"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma align%> %D bildiriminden önce görünmeli, yoksayılıyor"
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr ""
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "geçersiz ilklendirici"
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "ifade umuluyordu"
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD bir üye şablon işlevi değil"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma GCC pch_preprocess, ignored"
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "#pragma GCC pch_preprocess bozuk, yoksayıldı"
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr ""
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, gcc-internal-format
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr ""
 
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "multi-source compilation not implemented for C++"
 msgstr "modüller arası eniyilemeler henüz C++ için gerçeklenmedi"
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "standart uzlaşımlara bu bağlam içinde izin verilmez"
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -69507,7 +69549,7 @@ msgstr "sınıf sablonlarının kapsanması doğrudan özelleştirilmez"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "farklı isim alanında %qD özelleştirmesi"
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "farklı isim alanında %qD özelleştirmesi"
@@ -69523,29 +69565,29 @@ msgstr "  %q+#D tanımından"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "%3$qD isim alanını kapsamayan %2$qD isim alanında doğrudan %1$qD bildirimi"
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, fuzzy, gcc-internal-format
 #| msgid "invalid default argument for a template template parameter"
 msgid "name of class shadows template template parameter %qD"
 msgstr "bir şablonun şablon parametresi için öntanımlı argüman geçersiz"
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "specialization of alias template %qD"
 msgstr "%q#D şablon bildirimi"
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "şablon olmayan %qT için doğrudan özelleştirme"
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "örneklenim sonrası %qT özelleştirmesi"
 
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "from definition of %q#D"
@@ -69553,155 +69595,155 @@ msgstr "  %q+#D tanımından"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, fuzzy, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "örneklenim %2$qT sonrası %1$qT özelleştirmesi"
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "işlev şablonu kısmi özelleştirmesi %qD bildiricisine izin verilmez"
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "örneklenim sonrası %qD özelleştirmesi"
 
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a variable template"
 msgstr "%qD bir şablon değil"
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "şablon kimliği %qD %q+D için hiçbir şablon bildirimi ile eşleşmiyor"
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "%2$q+D için şablon özelleştirmesi %1$qD belirsiz"
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr ""
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "ilk kullanımdan sonra %D'nin açıkça özelleştirilmesi"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "%3$qD isim alanını kapsamayan %2$qD isim alanında doğrudan %1$qD bildirimi"
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "ilk kullanımdan sonra %D'nin açıkça özelleştirilmesi"
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attributes %s"
 msgstr "Code özniteliği eksik"
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing primary template attribute %s"
 msgstr "Code özniteliği eksik"
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD in declaration of primary template"
 msgid "template-id %qE in declaration of primary template"
 msgstr "birincil şablon bildiriminde şablon kimliği %qD"
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "şablon parametre listesi doğrudan örneklenimde kullanılmış"
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "tanım doğrudan örneklenim için sağlanmış"
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "%qD bildiriminde çok fazla şablon parametresi listeleniyor"
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "%qD bildiriminde çok az şablon parametresi listeleniyor"
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "%qD doğrudan özelleştirmesi %<template <>%> tarafından vurgulanmalı"
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "şablon olmayan %qT için doğrudan özelleştirme"
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "işlev şablonu kısmi özelleştirmesi %qD bildiricisine izin verilmez"
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "işlev şablonu kısmi özelleştirmesi %qD bildiricisine izin verilmez"
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "doğrudan özelleştirmede öntanımlı argüman belirtilmiş"
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD bir şablon işlevi değildir"
@@ -69714,172 +69756,172 @@ msgstr "%qD bir şablon işlevi değildir"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "örtük bildirimli özel üye işlev özelleştirmesi"
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, fuzzy, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "%2$qT türünde bildirimli %1$qD isminde üye işlev yok"
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %q#D declares a non-template function"
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "friend bildirimi %q#D bir şablon olmayan işlev bildiriyor"
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "friend declaration here"
 msgstr "buradaki önceki %q+#D bildirimi ile çelişiyor"
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "şablon olmayan %qT için doğrudan özelleştirme"
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "%L'deki ACOS argümanı -1 .. 1 arasında olmalı"
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "veri üyesi %qD bir üye şablon olamaz"
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "veri üyesi %qD bir üye şablon olamaz"
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "        %qD"
 msgid "        %s"
 msgstr "        %qD"
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "şablon parametre türü %qT %<friend%> bildirimli"
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "specialization of variable concept %q#D"
 msgstr "%q#D şablon bildirimi"
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "kismi özelleştirmede kullanılmayan şablon parametreleri:"
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "%qE işlevi için çok fazla argüman belirtildi"
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label %qD"
 msgid "primary template %qD"
 msgstr "yinelenmiş %qD yaftası"
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "%2$qE şablon argümanının %1$qT türü şablon parametre(ler)ine bağımlı oluyor"
 msgstr[1] "%2$qE şablon argümanının %1$qT türü şablon parametre(ler)ine bağımlı oluyor"
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "örneklenim sonrası %qD özelleştirmesi"
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD için öntanımlı argüman yok"
@@ -69888,54 +69930,54 @@ msgstr "%qD için öntanımlı argüman yok"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "kismi özelleştirmede kullanılmayan şablon parametreleri:"
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "%qT türündeki parametre için öntanımlı argüman %qT türünde"
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "parametre %qD void olarak bildirilmiş"
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "bir isim olmaksızın şablon sınıfı"
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -69946,65 +69988,65 @@ msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD şablon bildirimi geçersiz"
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "şablon olmayan %q#D için şablon tanımı"
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "%d seviye umulurken %q#D için şablon parametresi seviyesi olarak %d seviye alındı"
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "%d şablon parametresi %q#D için alındı"
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "%d şablon parametresi %q#T için alındı"
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  ama %d gerekiyordu"
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "şablon parametreleri bu şablonla uyuşmuyor:"
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "sınıf sablonlarının kapsanması doğrudan özelleştirilmez"
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of %qT as a non-template"
 msgid "redeclaration of %qD with different constraints"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT bir şablon türü değil"
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qD bildiriminde şablon belirteçleri belirtilmemiş"
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -70012,7 +70054,7 @@ msgid_plural "redeclared with %d template parameters"
 msgstr[0] "%qD şablon parametreleri olmaksızın kullanılmış"
 msgstr[1] "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration %qD used %d template parameter"
@@ -70020,489 +70062,489 @@ msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "buradaki önceki %q+#D bildirimi ile çelişiyor"
 msgstr[1] "buradaki önceki %q+#D bildirimi ile çelişiyor"
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "şablon parametresi %q+#D"
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "burada %q#D olarak yeniden bildirilmiş"
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "redeclared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of typedef %q+D"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "typedef %q+D için yeniden tanımlama"
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "%J  ozgun tanımı burada görüldü"
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of %qT as a non-template"
 msgid "redeclaration of %q#D with different constraints"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir göstericidir"
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(bir üye göstericisi sadece %<&%E%> ile şekillendirilebilir)"
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD %qT'nin bir üyesi değil"
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "%d şablon parametresi %q#D için alındı"
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "  mismatched types %qT and %qT"
 msgstr "%q#T ile %q#T türleri arasında karşılaştırma"
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a base of %qT"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qT %qT tabanında değil"
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "%L ve %L'de işliçler için sıralar uyumsuz"
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "%qT türü %qT türüne dönüştürülemiyor"
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT bir belirsiz %qT tabanıdır"
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "  %qT is not derived from %qT"
 msgstr "%qT türü %qT türünden türetilmemiş"
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "%qT türündeki argüman %qT ile eşleşmiyor"
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "the address of %qD is not a valid template argument"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü bu bağlamda dizge sabitler kullanılamaz"
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "in template argument for type %qT"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "cv nitelemesinde çeliştiğinden dolayı %qE %qT türü için geçerli bir şablon argümanı değildir"
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a constant pointer"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir sabit göstericisi değildir"
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir göstericidir"
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "yerine %qE kullanmayı deneyin"
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qT türündedir"
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes on template argument %qT"
 msgstr "özniteliklerin şablon parametrelerine uygulanması gerçeklenmedi"
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes in template argument %qE"
 msgstr "özniteliklerin şablon parametrelerine uygulanması gerçeklenmedi"
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of constructor as a template"
 msgid "invalid use of destructor %qE as a type"
 msgstr "kurucunun şablon olarak kullanımı geçersiz"
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "bir şablon parametresinin bir tür üyesine basvurmak için %<typename %E%> kullanın"
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, fuzzy, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "%2$qD için şablon parametre listesindeki %1$d. argümanda tür/değer uyumsuzluğu"
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  %qT türünde bir sabit umulurken %qT alındı"
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "%qT türündeki parametre için öntanımlı argüman %qT türünde"
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  bir sınıf sablonu umulurken %qE alındı"
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  bir tür umulurken %qE alındı"
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  bir tür umulurken %qT alındı"
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  bir sınıf sablonu umulurken %qT alındı"
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  %qD türünde bir şablon umulurken %qD alındı"
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "%2$qD için şablon parametre listesindeki %1$d. argümanda tür/değer uyumsuzluğu"
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  bir tür umulurken %qE alındı"
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "şablon argümanı %qE %qT'ye dönüştürülemedi"
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "%d. şablon argümanı geçersiz"
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "%q+D için sağlanmış"
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "öntanımlı argüman %2$q#D bildiriminin %1$d. parametresi için"
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "şablon olarak şablon olmayan tür %qT kullanılmış"
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "%q+D şablon bildirimi için"
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "template constraint failure for %qD"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "use of invalid variable template %qE"
 msgstr "%qD bir şablon değil"
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "score argument must be constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "score argument must be non-negative"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "property must be constant integer expression or string literal"
 msgstr "seçici 0..%wi aralığında bir tamsayı sabit olmalı"
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "%Junion içinde esnek dizi üye"
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE bildirimin başlangıcında değil"
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "%q#D için öntanımlı argümanın yeniden tanımı"
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye işlev göstericisi oluşturulması"
 
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument"
 msgid "mismatched argument pack lengths (%d vs %d)"
@@ -70521,325 +70563,325 @@ msgstr "tür argümanı geçersiz"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD has initializer but incomplete type"
 msgid "variable %qD has function type"
 msgstr "%qD değişkeni ilklendiricili ama içi boş türde"
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "geçersiz parametre türü %qT"
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "%q+D bildiriminde"
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "bir dizi döndüren işlev"
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "bir işlev döndüren işlev"
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "void'e referans oluşturuluyor"
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "%2$qT işlev türüne ekli %1$qV niteleyicileri yoksayılıyor"
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "%2$qT işlev türüne ekli %1$qV niteleyicileri yoksayılıyor"
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "%qT üye referans türünde gösterici oluşturulması"
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "void türünde üyeye gösterici oluşturulması"
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ne bir class, ne struct, ne de union türünde"
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT bir enum türü olmayan %qT türüne çözümleniyor"
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT bir sınıf türü olmayan %qT türüne çözümleniyor"
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "şablonda %qs kullanımı"
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "yetkin tür %qT, yıkıcı ismi ~%qT ile eslesmiyor"
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "%qE bağımlı ismi bir tür olarak çözümlenmedi ama örneklenim onun bir tür olmasını istiyor"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "eğer bu bir tür anlamındaysa %<typename %E%> deyin"
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "ilklendirici öğe bir sabit değil"
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "void ifade kullanımı geçersiz"
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, fuzzy, gcc-internal-format
 #| msgid "%<...%> as arguments.)"
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> kabul edeceği varsayılacak.)"
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "use %<%T::%D%> instead"
 msgstr "%<%T::%D%> bir tür değil"
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<__builtin_choose_expr%> not a constant"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "%<__builtin_choose_expr%> için ilk argüman bir sabit değil"
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "%qs özniteliği için belirtilen argüman sayısı yanlış"
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ne bir sınıf ne de isim alanı"
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "geçersiz alan %qD kullanımı"
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT anonim türdür/tür kullanır"
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "template argument for %qD uses local type %qT"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT değişkene göre değişen türde"
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  %qD örneklenmeye çalışılıyor"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%qD is not a static data member of a class template"
 msgstr "%q#D %qT'nin bir static olmayan üyesi değildir"
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "%qD için eşleşen bir şablon yok"
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "%q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "yinelenmiş doğrudan %q#D örneklenimi"
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of %<extern%> on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ doğrudan örneklenimlerde %<extern%> kullanımına izin vermez"
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "şablon tanımından önce %q#T'nin doğrudan örneklenimi"
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ doğrudan örneklenimlerde %qE kullanımına izin vermez"
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "yinelenmiş doğrudan %q#T örneklenimi"
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -70852,182 +70894,182 @@ msgstr "ilk kullanımdan sonra %D'nin açıkça özelleştirilmesi"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "bir tanımlama olmadan %qD'nin doğrudan örneklenimi"
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %q+D örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T bir şablon sabiti parametresi için geçerli bir tür değildir"
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid template non-type parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T bir şablon sabiti parametresi için geçerli bir tür değildir"
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "şablonlar dışında %<typename%> kullanımına izin verilmez"
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, fuzzy, gcc-internal-format
 #| msgid "union cannot be made transparent"
 msgid "a concept cannot be constrained"
 msgstr "birleşik yapı şeffaf olamaz"
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT bir isim alanı değil"
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#T inside template parameter list"
 msgid "concept %qE has multiple template parameter lists"
 msgstr "şablon parametre listesi içinde %q#T tanımı"
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "use %qD directly instead"
 msgstr "yerine #include kullanın"
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "%d. şablon argümanı geçersiz"
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "işlev satıriçine alınma sırasında görmezden gelinir"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "explicit deduction guide declared here"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q+#D"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "%q+#D için ortak değişen dönüş türü geçersiz"
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, fuzzy, gcc-internal-format
 #| msgid "unable to emulate %qs"
 msgid "unable to deduce %qT from %qE"
 msgstr "%qs öykünümü mümkün değil"
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of %qT in template argument"
@@ -71255,692 +71297,692 @@ msgstr "asm terimi %qE'nin türü saptanamadı"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "Objective-C bildirimleri sadece genel etki alanında görünebilir"
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "statik üye işlevde üye %q+D kullanımı geçersiz"
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr "statik üye işlevde üye %q+D kullanımı geçersiz"
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr "statik üye işlevde üye %q+D kullanımı geçersiz"
 
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "%qE missing template arguments"
 msgstr "tür argümanı geçersiz"
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "cannot call a concept as a function"
 msgstr "%qE bir işlev olarak kullanilamaz"
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "yıkıcıların argümanı olmaz"
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr "statik üye işlevlerde %<this%> kullanılmaz"
 
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, gcc-internal-format
 msgid "use explicit object parameter %qs instead"
 msgstr ""
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "name the explicit object parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "statik üye işlevlerde %<this%> kullanılmaz"
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<this%> before it is valid"
 msgstr "tepe seviyede %<this%> kullanımı geçersiz"
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<this%> after it is valid"
 msgstr "tepe seviyede %<this%> kullanımı geçersiz"
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "üye olmayan işlevde %<this%> kullanımı geçersiz"
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "tepe seviyede %<this%> kullanımı geçersiz"
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "sözde yıkıcı isminde niteleyen etki alanı geçersiz"
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "yetkin tür %qT, yıkıcı ismi ~%qT ile eslesmiyor"
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE %qT türünde değil"
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, fuzzy, gcc-internal-format
 #| msgid "compound literal has variable size"
 msgid "compound literal of non-object type %qT"
 msgstr "bileşik sabit değişken boyuta sahip"
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, fuzzy, gcc-internal-format
 #| msgid "union cannot be made transparent"
 msgid "%<auto{x}%> cannot be constrained"
 msgstr "birleşik yapı şeffaf olamaz"
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, gcc-internal-format
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "şablon türü parametrelerde %<class%> ya da %<typename%> sözcüğü kullanılmalı"
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "bir şablonun şablon parametresinin öntanımlı değeri olarak %qT türünün kullanımı geçersiz"
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "bir şablonun şablon parametresi için öntanımlı argüman geçersiz"
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "şablon parametre listesi içinde %q#T tanımı"
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "nitelikli tür %qT tanımı geçersiz"
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "anonim union içinde protected üye %q+#D"
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not captured"
 msgstr "%qD bir şablon değil"
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "iceren işlevden %<auto%> kullanımı"
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "iceren işlevden parametre kullanımı"
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, fuzzy, gcc-internal-format
 #| msgid "use of parameter from containing function"
 msgid "use of parameter outside function body"
 msgstr "iceren işlevden parametre kullanımı"
 
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "missing template arguments"
 msgstr "tür argümanı geçersiz"
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "%qD şablon parametresi %qT türündeyse butunleyen ya da sırali türde olmadığından bir butunleyen sabit ifadesinde kullanılmaz"
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "sınıf sablonu %qT'nin ifade olarak kullanımı"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "uye %qD için istek çoklu miras kafesi içinde belirsiz"
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE türü bilinmiyor"
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
 msgstr "%qT bir şablon türü değil"
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr "istenen hizalama bir sabit değil"
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr ""
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, fuzzy, gcc-internal-format
 #| msgid "operand number out of range"
 msgid "%<__type_pack_element%> index is out of range"
 msgstr "terim numarası aralık dışında"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "saklatım sınıfı belirteçleri parametre bildiriminde geçersiz"
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, fuzzy, gcc-internal-format
 #| msgid "trampolines not supported"
 msgid "pointer-to-member mapping %qE not supported"
 msgstr "trampolines desteklenmiyor"
 
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "%qD ile ilişkilendirme belirsiz"
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<restrict%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%<restrict%> kullanımı geçersiz"
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, gcc-internal-format
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr ""
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<gang%> static expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "%<gang%> static value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<gang%> num expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<vector%> length expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<worker%> num expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "%<gang%> num value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, fuzzy, gcc-internal-format
 #| msgid "stack size must be an exact power of 2"
 msgid "%<vector%> length value must be positive"
 msgstr "yığıt boyutu ikinin üstel katlarında olmalı"
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "'%s' geçerli bir sınıf ismi değil"
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "template %qE in clause %qs"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<grainsize%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<priority%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<hint%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<filter%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "bir içi boş tür göstericisi üzerinde aritmetik"
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> bir gösterici türü olarak tanımlı değil"
 
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr ""
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr ""
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr ""
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr ""
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr ""
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, fuzzy, gcc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed: %.*s"
 msgstr "CRIS-port olumlaması başarısız: "
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, fuzzy, gcc-internal-format
 #| msgid "non-static declaration of %q+D follows static declaration"
 msgid "non-constant condition for static assertion"
 msgstr "%q+D statik olmayan bildirim statik bildirimi izliyor"
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr ""
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr ""
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr "%<__builtin_next_arg%> argümansız çağrılmış"
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a template"
 msgid "%qD is not a class or alias template"
 msgstr "%qE bir şablon değil"
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -71949,1309 +71991,1309 @@ msgstr "%<__builtin_return_address%>'e aktarılan argüman desteklenmiyor"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV niteleyicileri %qT'ye uygulanamaz"
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement-expression in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid " declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %qT is not public"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not public"
 msgstr "%qD bir şablon değil"
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is mutable"
 msgstr "%qD bir şablon değil"
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has an incomplete type"
 msgid "%qD has a non-structural type"
 msgstr "%qD bir tamamlanmamış tür içeriyor"
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr "%qs özniteliği sadece işlev türlerine uygulanır"
 
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "%qs öznitelik argümanı bir dizge sabit değil"
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires prototypes with named arguments"
 msgid "%qE attribute takes no arguments"
 msgstr "%qE özniteliği isimli argümanları olan prototipler gerektirir"
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "%qs özniteliği sadece işlevlere uygulanır"
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "istenen init_priority bir tamsayı sabit değil"
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "%qE özniteliği sadece sınıf türünde nesnelerin dosya bağlamı tanımlarında kullanılabilir"
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is out of range"
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "istenen init_priority aralık dışında"
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is reserved for internal use"
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "istenen init_priority iç kullanim için ayrilmiştir"
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "%2$s olarak %1$qD bildirimi"
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires prototypes with named arguments"
 msgid "the %qE attribute requires arguments"
 msgstr "%qE özniteliği isimli argümanları olan prototipler gerektirir"
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> geçerli bir bildirici değil"
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> geçerli bir bildirici değil"
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %qD applied to template instantiation"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %qD applied to template instantiation"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%J%qE özniteliği sadece işlevlere uygulanır"
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%J%qE özniteliği sadece işlevlere uygulanır"
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr "%qs öznitelik argümanı bir tamsayı sabit değil"
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "zero as null pointer constant"
 msgstr "dizi sınırı bir tamsayı sabit değil"
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, fuzzy, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "lang_* denetimi: %2$s dosyasının %3$d. satırındaki %1$s içinde başarısız"
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin gösterici türleri %qT ve %qT arasında)"
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin gösterici türleri %qT ve %qT arasında)"
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin gösterici türleri %qT ve %qT arasında)"
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type %<void *%> and pointer-to-function"
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++'da bir işlev göstericisi ile %<void *%> türünde göstericiler arasında %s yasaktir"
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type %<void *%> and pointer-to-function"
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++'da bir işlev göstericisi ile %<void *%> türünde göstericiler arasında %s yasaktir"
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %s between pointer of type %<void *%> and pointer-to-function"
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++'da bir işlev göstericisi ile %<void *%> türünde göstericiler arasında %s yasaktir"
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin üye göstericisi türleri %qT ve %qT arasında)"
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin üye göstericisi türleri %qT ve %qT arasında)"
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin üye göstericisi türleri %qT ve %qT arasında)"
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "?: için terimler farklı türde"
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "?: için terimler farklı türde"
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "bir üye işleve %qs uygulanması geçersiz"
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to a bit-field"
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "bir bit alanına %qs uygulanması geçersiz"
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids applying %qs to an expression of function type"
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ işlev türünde bir ifadeye %qs uygulanmasına izin vermez"
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, fuzzy, gcc-internal-format
 #| msgid "invalid application of %qs to a bit-field"
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "bir bit alanına %qs uygulanması geçersiz"
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids applying %qs to an expression of function type"
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ işlev türünde bir ifadeye %qs uygulanmasına izin vermez"
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "dizi boyutu tümlemeyen %qT türünde"
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting to an array type %qT"
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ %qT dizi türüne dönüşüme izin vermez"
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, fuzzy, gcc-internal-format
 #| msgid "deprecated conversion from string constant to %qT'"
 msgid "deprecated conversion from string constant to %qT"
 msgstr "dizge sabitten %qT'ye dönüşüm artik önerilmiyor"
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "sınıf olmayan %3$qT türündeki %2$qE içindeki %1$qD üyesi için istek"
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "sınıf olmayan %3$qT türündeki %2$qE içindeki %1$qD üyesi için istek"
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of nonstatic data member %qE"
 msgid "invalid use of non-static data member %qE"
 msgstr "static olmayan veri üyesi %qE kullanımı geçersiz"
 
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD of NULL object"
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "NULL nesnenin static olmayan veri üyesi  %qD'ye erişim geçersiz"
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "yetkin tür %qT, yıkıcı ismi ~%qT ile eslesmiyor"
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "iptal edilen tür %qT iken yıkıcı %qT ile ilişkili"
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT türü %qE isimli üye içermiyor"
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT türü %qE isimli üye içermiyor"
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%>, %qT'nin bir üyesi değil"
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT %qT tabanında değil"
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD bir üye şablon işlevi değil"
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT bir nesne göstericisi türü değil"
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of array indexing on pointer to member"
 msgstr "uye göstericisinde %qs kullanımı geçersiz"
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "uye göstericisinde %qs kullanımı geçersiz"
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qs on pointer to member"
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "uye göstericisinde %qs kullanımı geçersiz"
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "dizi başvurusunda altindis yok"
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "%<register%> olarak bildirilmiş dizi indislemesi"
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "indisli değer ne dizi ne de bir gösterici"
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "%qE kullanimında nesne eksik"
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ program içinden %<::main%> çağrısına izin vermez"
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, fuzzy, gcc-internal-format
 #| msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>"
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "%<%E (...)%> içinde üye gösterici işlevi çağrısı için %<.*%> veya %<->*%> kullanılmalı"
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE bir işlev olarak kullanilamaz"
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "%qD cannot be used as a function"
 msgstr "%qE bir işlev olarak kullanilamaz"
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "expression cannot be used as a function"
 msgstr "%qE bir işlev olarak kullanilamaz"
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to constructor %q#D"
 msgstr "%s %q+#D için argümanlar çok fazla"
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to constructor %q#D"
 msgstr "%s %q+#D için argümanlar çok az"
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to member function %q#D"
 msgstr "%qs işlevi için argümanlar çok fazla"
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to member function %q#D"
 msgstr "%qs işlevi için argümanlar çok az"
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "too many arguments to function %q#D"
 msgstr "%qs işlevi için argümanlar çok fazla"
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "too few arguments to function %q#D"
 msgstr "%qs işlevi için argümanlar çok az"
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "too many arguments to method %q#D"
 msgstr "%s %q+#D için argümanlar çok fazla"
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %s %q+#D"
 msgid "too few arguments to method %q#D"
 msgstr "%s %q+#D için argümanlar çok az"
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "işlev için çok fazla argüman belirtildi"
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "işlev için çok az argüman belirtildi"
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "%P parametresi %qD içinde tamamlanmamış %qT türünde"
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "parametre %P tamamlanmamış %qT türünde"
 
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD, will always evaluate as %<true%>"
 msgid "the address %qE will never be NULL"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD, will always evaluate as %<true%>"
 msgid "the address of %qD will never be NULL"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD, will always evaluate as %<true%>"
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr ""
 
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD, will always evaluate as %<true%>"
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr "?: için terimler farklı türde"
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin gösterici türleri %qT ve %qT arasında)"
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr "%q#T ile %q#T türleri arasında karşılaştırma"
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, fuzzy, gcc-internal-format
 #| msgid "%s between distinct pointer types %qT and %qT lacks a cast"
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin gösterici türleri %qT ve %qT arasında)"
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use hardware floating point"
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr "Donanım kayan nokta aritmetiği kullanılmaz"
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, fuzzy, gcc-internal-format
 #| msgid "cast from function call of type %qT to non-matching type %qT"
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr "%qT türündeki işlev çağrısından eşleşmeyen %qT türüne dönüşüm"
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of %qT to %qT"
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr "%qT'nin %qT'ye atanmasında türler uyumsuz"
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "aşırı yüklü işlevden %qT türüne dönüşüm yapildigi varsayılıyor"
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "aritmetik içinde NULL kullanımı"
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ da gösterici ile tamsayı arasında karşılaştırmaya izin verilmez"
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "%2$q#T içinde %1$q#T isminde tür yok"
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "tamsayı sıfır ile sıralı gösterici karşılaştırması"
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "gerçel sayı olmayan argümanlar arasında düzenlenmemiş karşılaştırma"
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 #, fuzzy
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "%qT ve %qT türündeki terimler iki terimli `%qO' için geçersiz"
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ bir çıkarma içinde %<void *%> türde gösterici kullanımına izin vermez"
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ bir çıkartma işlemi içindeki bir işlev göstericisi kullanımına izin vermez"
 
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ bir çıkartma işlemi içinde bir yöntem göstericisi kullanımına izin vermez"
 
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "gösterici aritmetiginde tamamlanmamış ture gösterici kullanımı geçersiz"
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of constructor %qD"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of destructor %qD"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "%qE kullanımı üye işleve gösterici biçiminde geçersiz"
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  bir nitelemeli kimlik gerekli"
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesis around %qE cannot be used to form a pointer-to-member-function"
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "parantez icene alınmis %qE üye işleve gösterici biçiminde kullanilamaz"
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ üye işleve bir gösterici şekillendirecek bir niteliksiz ya da parantezli statik olmayan üye işlevin adresinin alınmasına izin vermez.  %<&%T::%D%> denebilir."
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr "ISO C++ üye işleve bir gösterici şekillendirecek bir niteliksiz ya da parantezli statik olmayan üye işlevin adresinin alınmasına izin vermez.  %<&%T::%D%> denebilir."
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ üye işleve bir gösterici şekillendirecek bir sınır üye işlevin adresinin alınmasına izin vermez.  %<&%T::%D%> denebilir"
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr "ISO C++ üye işleve bir gösterici şekillendirecek bir sınır üye işlevin adresinin alınmasına izin vermez.  %<&%T::%D%> denebilir"
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr "(bir üye göstericisi sadece %<&%E%> ile şekillendirilebilir)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ %<::main%> işlevinin adresinin alınmasına izin vermez"
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "referans üye %qD için gösterici oluşturulamaz"
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "%qD bit-alanının adresi alınamaz"
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "gecicinin adresi alıniyor"
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ bir enum'um %s-lenmesine izin vermez"
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ bir enum'um %s-lenmesine izin vermez"
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ bir göstericinin %s işlemine %qT türündeyse izin vermez"
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing a pointer of type %qT"
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ bir göstericinin %s işlemine %qT türündeyse izin vermez"
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "bir sağ taraf ifadesi olan %<this%>'in adresi alınamaz"
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "%qD doğrudan yazmaç değişkeninin adresi istendi"
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr " %qD için adres istegi (%<register%> olarak bildirilmiş olan)"
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "%qT için ilklendirici {} içinde olmalı"
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in initializer"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "expression list treated as compound expression in functional cast"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "%qT türünden %qT türüne dönüşüm niteleyicileri iptal ediyor"
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%qT türünden %qT türüne static_cast geçersiz"
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%qT türünden %qT türüne static_cast geçersiz"
 
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, fuzzy, gcc-internal-format
 #| msgid "%qT uses local type %qT"
 msgid "useless cast to type %q#T"
 msgstr "%qT yerel tür %qT kullanıyor"
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "tür niteleyicileri işlev dönüş türünde yok sayıldı"
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "%qT türünden %qT türüne static_cast geçersiz"
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "dönüş türü %q#T bir içi boş türdür"
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "%qT'den %qT'ye dönüşüm"
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "%qT türündeki bir sağ taraf değerinin %qT türüne dönüşümü geçersiz"
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "%qT'den %qT'ye tür dönüşümü hassasiyet kaybi oluşturuyor"
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 #, fuzzy
 #| msgid "%s between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "bir tür dönüşümü olmaksızın %s (belirgin üye göstericisi türleri %qT ve %qT arasında)"
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "%qT türünden %qT türüne dönüşüm hedef türün hizalama gereksinimini arttiriyor"
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ işlev ve nesne göstericileri arasında dönüşüme izin vermez"
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "%qT türünden %qT türüne const_cast geçersiz"
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "ne bir gösterici türü ne de bir veri üyesine gösterici türü olan %qT ile const_cast kullanımı geçersiz"
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "bir gösterici ya da bir işlev türüne referans olan %qT türü ile const_cast kullanımı geçersiz"
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "%qT türündeki bir sağ taraf değerinden %qT türüne const_cast geçersiz"
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "%qT türünden %qT türüne const_cast geçersiz"
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ %qT dizi türüne dönüşüme izin vermez"
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qE from type %qT to type %qT"
 msgid "moving %qE of type %qT to itself"
 msgstr "%qE ifadesi %qT türünden %qT türüne dönüştürülemez"
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  %<%Q(%#T, %#T)%> nin gelisiminde"
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "assigning to an array from an initializer list"
 msgstr "ilklendiricide sabit olmayan dizi indisi"
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "%qT'nin %qT'ye atanmasında türler uyumsuz"
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, fuzzy, gcc-internal-format
 #| msgid "bad array initializer"
 msgid "array used as initializer"
 msgstr "dizi ilklendirici hatalı"
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "invalid array assignment"
 msgstr "atamanın sol tarafı geçersiz"
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   üye işleve gösterici dönüşümünde"
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "sanal taban %qT üzerinden üye göstericisine dönüşüm"
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   üyeye gösterici dönüşümünde"
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "%qT'ye %qT'den dönüşüm geçersiz"
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "%4$qD işlevinin %3$qP. argümanı için %1$qT türü %2$qT türüne dönüştürülemez"
 
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in return"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "%2$qE işlevinin %1$d. argümanı bir biçim özniteliği adayı olabilir"
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, fuzzy, gcc-internal-format
 #| msgid "return type might be a candidate for a format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "dönüş türü bir biçim özniteliği adayı olabilir"
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "işlev çağrısı argümanı bir biçim özniteliği için aday olabilir"
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "işlev çağrısı argümanı bir biçim özniteliği için aday olabilir"
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, fuzzy, gcc-internal-format
 #| msgid "assignment left-hand side might be a candidate for a format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "atamada sol taraf bir biçim özniteliği adayı olabilir"
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "%2$q+D işlevinin %1$P. argümanına aktarımda"
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "geçiciye başvuru dönüyor"
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "returning pointer to temporary"
 msgstr "geçiciye başvuru dönüyor"
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "yerel değişken %q+D'ye referans donduruldu"
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "yerel değişken %q+D adresi donduruldu"
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "yerel değişken %q+D adresi donduruldu"
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "redundant move in return statement"
 msgstr "asm deyiminde geçersiz sol taraf"
 
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "redundant move in initialization"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "bir yıkıcıdan değer donuyor"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "bir kurucunun bir işlev deneme blokunun bir tutamagından dondurulemez"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "kurucudan bir değer dondurulemez"
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "%qT donduren işlevde değer içermeyen return"
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "ilklendirici yok"
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "%L ve %L'de işliçler için sıralar uyumsuz"
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "%qT donduren işlevde değer içermeyen return"
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%>', %<throw()%> olarak bildirilmedikce (ya da -fcheck-new etkinken) NULL donmemeli"
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q+#D"
 msgid "not eliding copy on return from %qD"
 msgstr "%q+#D için ortak değişen dönüş türü geçersiz"
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr ""
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%s value"
 msgid "using rvalue as lvalue"
@@ -73502,172 +73544,172 @@ msgstr ""
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "kurucu sözdizimi kullanılmış ama %qT türü için kurucu bildirilmemiş"
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, fuzzy, gcc-internal-format
 #| msgid "interface %qE does not have valid constant string layout"
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "%qE arayüzü geçerli sabit dizge yerleşimi içermiyor"
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 #, fuzzy
 #| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "%qE ifadesinin %qT türünden %qT türüne dönüşümü belirsiz"
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 #, fuzzy
 #| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "%qE ifadesinin %qT türünden %qT türüne dönüşümü belirsiz"
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, fuzzy, gcc-internal-format
 #| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "karakter dizisi için dizge ilklendirici çok uzun"
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "skalar ilklendiriciyi kuşatan parantezler"
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "bir bileşik sabitli %qT türündeki küme ilklendirilemez"
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "uye %qD ilklendirilmemiş referanstir"
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "uye %qD ilklendirilmemiş referanstir"
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD for %q+D does not match any template declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "şablon kimliği %qD %q+D için hiçbir şablon bildirimi ile eşleşmiyor"
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "ilklendirilen union içinde %qD diye bir alan yok"
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "birlesik yapı ilklendiricideki alan isminin yerine index değeri"
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "döngüsel gösterici görevlendirmesi saptandi"
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%> için taban terim gösterici olmayan %qT türünde"
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr " %<operator->()%> gösterici olmayan sonuc veriyor"
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%> için taban terim bir gösterici değil"
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE bir üye göstericisi olarak kullanilamaz, cunku %qT türünde"
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply member pointer %qE to %qE, which is of non-aggregate type %qT"
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "uye göstericisi %qE %qE'ye kümeleme türü olmayan %qT türünde uygulanamaz"
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "%qT üye türünde gösterici nesne türü %qT ile uyumsuz"
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, fuzzy, gcc-internal-format
 #| msgid "union cannot be made transparent"
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "birleşik yapı şeffaf olamaz"
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr ""
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdefault-initialization of %q#D, which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "%Jreferans ture sahip %q#D'nin default ilklendirmesi"
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "%qD işlevine çağrı (ici boş tür `%q#T' yakalanırken)"
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "ici boş tür `%q#T' yakalanırken işleve çağrı"
@@ -74738,7 +74780,7 @@ msgstr ""
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "`%s' argümanı `%s' yerleşiği için  %L'de bir sabit olmalı"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad kind for logical constant at %C"
 msgid "Invalid use of BOZ literal constant at %L"
@@ -76228,7 +76270,7 @@ msgstr "%C'deki INTENT belirtimi hatalı"
 msgid "deferred type parameter at %C"
 msgstr "%2$qs sonrası şablon türü %1$qT parametresi kullanımı"
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -76467,7 +76509,7 @@ msgstr "'%s' dizi göstericisi %L'de ertelenmiş bir biçimde olmalı"
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Yapının dizi bileşeni %C'de dolaysız ya da ertelenmiş durumda olmalı"
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already declared at %L"
@@ -77356,7 +77398,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr "%C'deki işlev tanımında biçimsel argüman listesi umuluyordu"
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
@@ -78246,12 +78288,12 @@ msgstr ""
 msgid "are_identical_variables: Bad type"
 msgstr ""
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr ""
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr ""
@@ -78528,307 +78570,307 @@ msgstr "Bir sabit ifadesine indirgenmeyen '%s' parametresi %L'de ya bildirilmemi
 msgid "check_init_expr(): Unknown expression type"
 msgstr "İfade türü umuluyordu"
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be a statement function"
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr "Belirtim işlevi '%s' (%L'de) bir deyim işlevi olamaz"
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be an internal function"
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr "Belirtim işlevi '%s' (%L'de) dahili bir işlev olamaz"
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L must be PURE"
 msgid "Specification function %qs at %L must be PURE"
 msgstr "Belirtim işlevi '%s' (%L'de) PURE olmalı"
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be RECURSIVE"
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr "Belirtim işlevi '%s' (%L'de) RECURSIVE olamaz"
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be OPTIONAL"
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr "Sözde argüman '%s' (%L'de) OPTIONAL olamaz"
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "check_restricted(): Unknown expression type"
 msgstr "İfade türü umuluyordu"
 
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression at %L must be of INTEGER type"
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr "%L'deki ifade INTEGER türünde olmalı"
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L must be PURE"
 msgid "Function %qs at %L must be PURE"
 msgstr "Belirtim işlevi '%s' (%L'de) PURE olmalı"
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr "%L'deki ifade değişmez olmalı"
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr ""
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible ranks in %s at %L"
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr "%s (%L'de) içindeki sıra uyumsuz"
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "different shape for %s at %L on dimension %d (%d/%d)"
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "%s için %L'de %d. boyutta biçim farklı (%d/%d)"
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L is not a VALUE"
 msgid "%qs at %L is not a VALUE"
 msgstr "'%s' %L'de bir VALUE değil"
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal stride of zero at %L"
 msgid "Illegal assignment to external procedure at %L"
 msgstr "%L'de sıfır adım uzunluğu kuraldışı"
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "%d ve %d sıraları uyumsuz (%L'deki atamada)"
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "%L'deki atamada değişken UNKNOWN türünde"
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "NULL %L'deki atamanın sağ tarafında görünüyor"
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "POINTER valued function appears on right-hand side of assignment at %L"
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "POINTER değerli işlev %L'deki atamanın sağ tarafında görünüyor"
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr ""
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible types in assignment at %L, %s to %s"
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "%L'deki atamada uyumsuz türler, %s den %s'e"
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "%L'deki gösterici atamasının hedefi bir POINTER değil"
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "'%s' (%L'deki gösterici atamasındaki) bir yordam olduğundan bir sol taraf değeri olamaz"
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Expected bounds specification for %qs at %L"
 msgstr "%s belirtimi %C'de yinelenmiş"
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, fuzzy, gcc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "%L'deki gösterici atamasında farklı türler"
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "stack size must not be greater than 64k"
 msgid "Stride must not be present at %L"
 msgstr "yığıt boyutu 64k'dan büyük olmamalıdır"
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "Harici nesne '%s'  %L'de bir ilklendiriciye sahip olamayabilir"
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "%L'deki gösterici atamasında farklı türler"
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' requires argument list at %C"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "'%s' deyim işlevi %C'de argüman listesi gerektiriyor"
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "'%s' iç yordamına %L'de bir fiili argüman olarak izin verilmez."
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "%L'deki yerleşik '%s' seçilmiş standartta bulunmuyor"
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, fuzzy, gcc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "%L'deki gösterici atamasında farklı karakter uzunlukları"
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "%qs sınıfı için birden fazla arabirim bildirimi"
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "%qs sınıfı için birden fazla arabirim bildirimi"
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "%L'deki gösterici atamasında farklı karakter uzunlukları"
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr "%L'deki gösterici atamasının hedefi bir POINTER değil"
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "%L'deki gösterici atamasında farklı türler"
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "%L'deki gösterici atamasında farklı sıralamalar"
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Rank remapping target is not rank 1 at %L"
@@ -78837,205 +78879,205 @@ msgstr "%L'deki gösterici atamasının hedefi bir POINTER değil"
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data target at %L shall not have a coindex"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "%L'de hesaplanmış GOTO deyimindeki seçim ifadesi bir değişmez tamsayı ifadesi olmalıdır"
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr ""
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "%C'deki bileşen POINTER özniteliğinde olmalı"
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr ""
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "%L'deki gösterici atamasının hedefi ne TARGET ne de POINTER"
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "%L'deki PURE yordamdaki gösterici atamasında hedef berbat"
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "%L'de sağ tarafta vektör indisli gösterici ataması"
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "%L'deki gösterici atamasının hedefi bir POINTER değil"
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "%C'deki gösterici ilklendirmesi bir '=>' gerektirir, '=' değil"
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "%C'deki bileşen POINTER özniteliğinde olmalı"
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Nesne '%s' (%L'de), %s SAVE özniteliğine sahip olmalı"
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "'%s' iç yordamına %L'de bir fiili argüman olarak izin verilmez."
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "'%s' iç yordamına %L'de bir fiili argüman olarak izin verilmez."
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, gcc-internal-format
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, gcc-internal-format
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr ""
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -79058,8 +79100,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "creating array of %qT"
 msgid "Creating array temporary at %L"
@@ -79150,7 +79192,7 @@ msgstr "'%s' değişkeni (%C'deki), %L'de başlayan döngünün içinde yeniden
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "'%s' değişkeni (%C'deki), %L'de başlayan döngünün içinde yeniden tanımlanamaz"
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -79298,12 +79340,12 @@ msgstr "%L'de tanımlanmış atamanın ilk argümanı INTENT(IN) veya INTENT(INO
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L'de tanımlanmış atamanın ikinci argümanı INTENT(IN) olmalıdır"
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L'deki işleç arayüzünün ilk argümanı INTENT(IN) olmalıdır"
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L'deki işleç arayüzünün ikinci argümanı INTENT(IN) olmalıdır"
@@ -80264,7 +80306,7 @@ msgstr "%s den %s e dönüşüm (%L'de)"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
@@ -80896,7 +80938,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -81076,6 +81118,11 @@ msgstr "Tamsayı üstten taşması"
 msgid "check_charlen_present(): length not set"
 msgstr ""
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr ""
+
 #: fortran/match.cc:118
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
@@ -81529,7 +81576,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "%C'deki Cray göstericisi bir tamsayı olmalı."
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
@@ -82104,91 +82151,91 @@ msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "SELECT RANK statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "%C'de umulmadık CASE deyimi"
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CASE specification at %C"
 msgstr "%C'deki CASE belirtiminde sözdizimi hatası"
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "%C'de beklenmeyen END deyimi"
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "%C'deki CASE belirtiminde sözdizimi hatası"
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "%C'deki CASE belirtiminde sözdizimi hatası"
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected RANK statement at %C"
 msgstr "%C'de beklenmeyen END deyimi"
 
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL stride expression at %L must be a scalar %s"
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "%L'deki FORALL adım ifadesi bir değişmez %s olmalıdır"
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in RANK specification at %C"
 msgstr "%C'deki CASE belirtiminde sözdizimi hatası"
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "%C'deki ELSEWHERE deyimi WHERE bloku içinde değil"
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -83741,8 +83788,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "%L'deki IF deyimi bir sabit LOGICAL ifadesi gerektirir"
@@ -86314,12 +86361,12 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Yafta %d (%L'de başvurulu) hiç tanımlanmamış"
@@ -86454,7 +86501,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "'%s' işlevi (%L'de) hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -86892,295 +86939,301 @@ msgstr ""
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr "%L'de hatalı dizi başvurusu"
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "Using variable %qs at %L is deprecated"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Bad array reference at %L"
+msgid "Invalid array reference at %L"
+msgstr "%L'de hatalı dizi başvurusu"
+
+#: fortran/resolve.cc:6433
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Error in typebound call at %L"
 msgstr "Genişletme: %C'de eski tarz ilklendirme"
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be scalar"
 msgid "Passed-object at %L must be scalar"
 msgstr "%s' etiketi (%L'de) bir değişmez olmalı"
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Öğesel yordamın '%s' argümanı değişmez olmalı (%L'de)"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s' (%L'de) bir INTEGER olmalıdır"
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "İfade türü umuluyordu"
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%s at %L must be integer"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s' (%L'de) bir INTEGER olmalıdır"
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL başlatma ifadesi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL son ifadesi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L'deki FORALL adım ifadesi bir değişmez %s olmalıdır"
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L'deki FORALL adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "%L'de ALLOCATE deyimindeki ifade ya bir POINTER ya da ALLOCATABLE olmalı"
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "%L'deki yafta %L'deki GOTO deyimiyle aynı blokta değil"
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -87189,301 +87242,301 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "%L'deki CASE etiketi ile %L'deki CASE etiketi birbirinin üzerine taşıyor"
 
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be kind %d"
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "%L'de CASE deyimindeki ifade %d. çeşit olmalı"
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L'de CASE deyimindeki ifade bir değişmez olmalı"
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "%L'de hesaplanmış GOTO deyimindeki seçim ifadesi bir değişmez tamsayı ifadesi olmalıdır"
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L'deki SELECT deyiminin argümanı %s olamaz"
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "%L'deki DEFAULT CASE deyiminden sonra %L'de ikinci bir DEFAULT CASE olamaz"
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "%L'deki CASE deyiminde mantıksal aralığa izin verilmez"
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "%L'deki CASE deyiminde mantıksal aralığa izin verilmez"
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "%L'deki aralık belirtimi asla eşleşmeyebilir"
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "%L'deki mantıksal SELECT CASE blokunun ikiden fazla case'i var"
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "%L'deki yerleşik '%s' seçilmiş standartta bulunmuyor"
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "'%s' ismi (%C'de) tanımlı bir işleç olarak kullanılamaz"
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "%L'deki yerleşik '%s' seçilmiş standartta bulunmuyor"
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Selector at %L cannot be NULL()"
 msgstr "%L'deki yineleyici adımı sıfır olamaz"
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Selector at %L has no type"
 msgstr "'%s' işlevi (%L'de) hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "%L'deki EQUIVALENCE deyiminde söz dizimi hatası"
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "%L'deki CASE etiketi ile %L'deki CASE etiketi birbirinin üzerine taşıyor"
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Türetilmiş '%s' türü (%C'deki) tanımından önce kullanılıyor"
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Türetilmiş tür ismi '%s' %C'de zaten temel  %s türünde"
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Umulmadık %s deyimi (%C'de)"
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "%L'de dizi indisi değişmez olmalıdır"
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının PRIVATE bileşenleri olamaz"
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "%L'deki veri aktarım elemanının PRIVATE bileşenleri olamaz"
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "%L'deki veri aktarım elemanı tahmini boyutlu bir diziye bir tam başvuru olamaz"
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%L'deki ACOS argümanı -1 .. 1 arasında olmalı"
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "%L'deki deyim %L'deki dallanma deyimi için geçerli bir dallanma hedef deyimi değildir"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Branch at %L causes an infinite loop"
 msgid "Branch at %L may result in an infinite loop"
@@ -87491,12 +87544,12 @@ msgstr "%L'deki dallanma bir sonsuz döngüye sebep oluyor"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -87504,225 +87557,225 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "%L'deki yafta %L'deki GOTO deyimiyle aynı blokta değil"
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "%L'deki WHERE maskesi uyumsuz biçimde"
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "%L'deki WHERE atama hedefi uyumsuz biçimde"
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L'deki WHERE içinde desteklenmeyen deyim"
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' cause more than one assignment to this object at %L"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "'%s' indisli FORALL %L'de bu nesneye birden fazla atamaya sebep oluyor"
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "FORALL construct at %L"
 msgstr "Kurucu %s olmayabilir"
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Bir dış FORALL oluşumu zaten bu isimde bir indise sahip (%L'de)"
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L'deki WHERE/ELSEWHERE deyimi bir değişmez LOGICAL dizisi gerektirir"
 
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, gcc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "%L'deki atamanın sağ tarafı bir PURE yordamda bir POINTER içeren türetilmiş bir türdür"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "%L'deki gösterici atamasında farklı türler"
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "%L'de hesaplanmış GOTO deyimindeki seçim ifadesi bir değişmez tamsayı ifadesi olmalıdır"
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "%L'deki ASSIGNED GOTO deyimi bir INTEGER değişken gerektirir"
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "'%s' değişkenine %L'de bir hedef etiketi atanmış olmamalıydı"
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Alternate RETURN statement at %L requires an INTEGER return specifier"
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Diğer RETURN deyimi %L'de bir INTEGER dönüş belirteci gerektirir"
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected initialization expression in CASE at %C"
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "%C'deki CASE'de ilklendime ifadesi umuluyordu"
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "%L'deki aritmetik IF deyimi bir sayısal ifade gerektirir"
 
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "%L'deki DO WHILE döngüsünün çıkış koşulu bir sabit LOGICAL ifadesi olmalıdır"
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "%L'deki FORALL maske deyimi bir LOGICAL ifadesi gerektirir"
 
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Hatalı deyim kodu"
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "parametre %qD void olarak bildirilmiş"
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -87730,7 +87783,7 @@ msgstr "İsimli COMMON blok '%s' %L'de aynı boyutta olmalı"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
@@ -87739,63 +87792,63 @@ msgstr "İsimli COMMON blok '%s' %L'de aynı boyutta olmalı"
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "İsimli COMMON blok '%s' %L'de aynı boyutta olmalı"
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "'%s' sabit nesnesi %L'de ALLOCATABLE olmayabilir"
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "'%s' dizi göstericisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "'%s' dizisi %L'de ertelenmiş bir biçimde olamaz"
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, fuzzy, gcc-internal-format
 #| msgid "Possible frontend bug: Deferred array size without pointer or allocatable attribute."
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
@@ -87803,1035 +87856,1035 @@ msgstr "Olası önyüz hatası: gösterici veya tahsis edilebilir öznitelik olm
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Modül veya ana program dizisi '%s' %L'de sabit biçimde olmalı"
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "%L'deki tahmini karakter uzunluklu öğe ya bir sözde argüman ya da bir PARAMETER olmalı"
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Ayrılabilir '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Harici '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Yerleşik '%s' %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Özdevinimli dizi '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "%s işlevinde (%s dosyasının %d. satırı)"
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Karakter değerli deyim işlevi '%s'  %L'de sabit uzunlukta olmalı"
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "'%s' bir PRIVATE türündedir ve '%s' (%L'de PUBLIC tanımlı) için bir sözde argüman olamaz"
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Harici nesne '%s'  %L'de bir ilklendiriciye sahip olamayabilir"
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de dizi değerli olamaz"
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de gösterici değerli olamaz"
 
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de katıksız olamaz"
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de iç içe olamaz"
 
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de katıksız olamaz"
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' of PURE procedure at %L must also be PURE"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "PURE yordamının '%s' sözde yordamı da ayrıca PURE olmalı"
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "%s özniteliği ile %s özniteliği '%s' içinde %L'de çelişiyor"
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, fuzzy, gcc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Interface of %qs at %L must be explicit"
 msgstr "%L'deki yineleyici adımı sıfır olamaz"
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "%L'de ICHAR'ın argümanı bir uzunlukta olmalı"
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be OPTIONAL"
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) OPTIONAL olmamalı"
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "%L'deki işleç arayüzünün ilk argümanı INTENT(IN) olmalıdır"
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "%L'deki yineleyici adımı sıfır olamaz"
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) türetilmemiş bir türde olmalı"
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) türetilmemiş bir türde olmalı"
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr ""
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "`%s' argümanı `%s' yerleşiği için  %L'de bir değişmez olmalı"
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "'%s' dizi göstericisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "%L'de ICHAR'ın argümanı bir uzunlukta olmalı"
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) türetilmemiş bir türde olmalı"
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, fuzzy, gcc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Öğesel yordamın '%s' argümanı POINTER özniteliğine sahip olamaz (%L'de)"
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L must have constant array bounds."
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "'%s' ('%s'in bileşeni) %L'de sabit dizi sınırlarına sahip olmalı"
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L."
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Bileşen karakter uzunluğu '%s'in %L'de bir sabit belirtim ifadesi olması gerekir"
 
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be of INTEGER type"
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "%L'deki ifade INTEGER türünde olmalı"
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, fuzzy, gcc-internal-format
 #| msgid "The component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Bileşen '%s' bir PRIVATE türdür ve '%s' (%L'de PUBLIC tanımlı) bileşeni olamaz"
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component %s of SEQUENCE type declared at %C does not have the SEQUENCE attribute"
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "SEQUENCE türünün %s bileşeni SEQUENCE özniteliğine sahip değil (%C'de)"
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected an initialization expression at %C"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "%C'de bir ilklendirme ifadesi umuluyordu"
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L must have constant array bounds."
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "'%s' ('%s'in bileşeni) %L'de sabit dizi sınırlarına sahip olmalı"
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Türetilmiş '%s' türü (%C'deki) tanımından önce kullanılıyor"
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "'%s' tahmini boyutlu dizisine '%s' isim listesinde izin verilmiyor (%C'de)."
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "'%s' PRIVATE simgesi %L'de PUBLIC isim listesi üyesi olamaz"
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "'%s' PRIVATE simgesi %L'de PUBLIC isim listesi üyesi olamaz"
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or assumed shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parametre dizisi '%s' %L'de özdevinimli veya tahmini biçimli olamaz"
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Örtük olarak  PARAMETER türlü '%s' %L'de sonraki bir IMPLICIT türle eşleşmiyor"
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%L'de PARAMETER içindeki türetilmiş tür uyumsuz"
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, fuzzy, gcc-internal-format
 #| msgid "Possible frontend bug: Deferred array size without pointer or allocatable attribute."
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Olası önyüz hatası: gösterici veya tahsis edilebilir öznitelik olmaksızın ertelenmiş dizi boyutu"
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "%C'deki tahmini boyutlu dizi için belirtim hatalı"
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%L'deki tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L'deki simge bir DUMMY değişken değil"
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Karakter değerli deyim işlevi '%s'  %L'de sabit uzunlukta olmalı"
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Türetilmiş %qs türü %L'de tanımlanmamış olan %qs türündedir."
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC işlev '%s' %L'de PRIVATE '%s' türünde olamaz"
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) sözde argüman %qs %L'de ASSUMED SIZE olduğundan bir öntanımlı ilklerdiriciye sahip olamaz"
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "'%s' dizisi %L'de ertelenmiş bir biçimde olamaz"
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "%L'deki sözde yordama ELEMENTAL yordamında izin verilmez"
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s."
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "İsim listesinin ismi %s USE ilişkisiyle %s yapılamaz"
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting definable entity near %L"
 msgstr "%s deyimi umuluyordu (%C'de)"
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA öğesi %qs %L'de COMMON içinde olmalıdır"
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Öğesel yordamın '%s' argümanı POINTER özniteliğine sahip olamaz (%L'de)"
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "DATA deyiminde %L'de sabit olmayan dizi bölümü"
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "%L'deki DATA deyiminde değerden çok değişken var"
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Nonconstant array section at %L in DATA statement"
 msgid "Non-constant character length at %L in DATA statement"
 msgstr "DATA deyiminde %L'de sabit olmayan dizi bölümü"
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "%L'deki DATA deyiminde değişkenden çok değer var"
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "%d yaftası %L'de tanımlanmış ama kullanılmamış"
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "%d yaftası %L'de tanımlanmış ama kullanılamıyor"
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni %qs %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de gösterici bileşen(ler)le bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initializer cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de öntanımlı ilklendiriciyle bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni %qs %L'de gösterici bileşen(ler)le bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L'deki EQUIVALENCE deyiminde söz dizimi hatası"
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Ortak blok üyesi %qs %L'de, %qs pure yordamındaki bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%qs isimli sabiti %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Sınırları sabit olmayan %qs dizisi %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Yapı bileşeni %qs %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L'deki altdizge sıfır uzunlukta"
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, fuzzy, gcc-internal-format
 #| msgid "Syntax error in character length specification at %C"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "%C'deki karakter uzunluğu belirtiminde sözdizimi hatası"
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs %L'de hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Yerleşik işleç arayüzü %qs %L'de bir FUNCTION olmalı"
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Kullanıcı işleci yordamı %qs %L'de tahmini karakter uzunluğunda olamaz"
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı %qs %L'de için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "%L'deki işleç arayüzünün ilk argümanı isteğe bağlı olamaz"
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "%L'deki işleç arayüzünün ikinci argümanı isteğe bağlı olamaz"
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "%L'deki işleç arayüzünün en fazla iki argümanı olmalı"
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -89416,361 +89469,361 @@ msgstr ""
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr "'%s' işlevi (%L'de) hiç IMPLICIT tür içermiyor"
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, fuzzy, gcc-internal-format
+#| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr "%s özniteliği ile %s özniteliği '%s' içinde %L'de çelişiyor"
+
+#: fortran/symbol.cc:508
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr "'%s' özniteliğine %C'de BLOCK DATA program biriminde izin verilmez"
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr "'%s' iç yordamına %L'de bir fiili argüman olarak izin verilmez."
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "Procedure pointer at %C"
 msgstr "yordam ismi = %s"
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%s attribute applied to %s %s at %L"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, gcc-internal-format, gfc-internal-format
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, fuzzy, gcc-internal-format
-#| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr "%s özniteliği ile %s özniteliği '%s' içinde %L'de çelişiyor"
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "%L'de USE ile ilişkili simgenin öznitelikleri değiştirilemez"
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "USE ile ilişkili %s simgesinin öznitelikleri %L'de değiştirilemez"
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr "%L'de yinelenen SAVE özniteliği belirtilmiş"
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray Pointee at %L appears in multiple pointer() statements."
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "%L'deki Cray Göstericisi çok sayıda pointer() deyiminde görünüyor"
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "%L'de yinelenen SAVE özniteliği belirtilmiş"
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "%L'deki SAVE özniteliği bir PURE yordamında belirtilemez"
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "%L'de yinelenen SAVE özniteliği belirtilmiş"
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "%L'de yinelenen SAVE özniteliği belirtilmiş"
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "%L'de yinelenen SAVE özniteliği belirtilmiş"
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr "%L'deki SAVE özniteliği bir PURE yordamında belirtilemez"
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "%L'de yinelenen SAVE özniteliği belirtilmiş"
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "%s yordamı %L'de zaten %s yordamı olarak bildirilmiş"
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) ile INTENT(%s) %L'de çelişiyor"
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "ACCESS belirtimi %L'de zaten belirtilmiş"
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute specified at %L"
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "%L'de yinelenen %s özniteliği belirtilmiş"
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "%L'de yinelenen SAVE özniteliği belirtilmiş"
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "%qs simgesi %L'de zaten bir aleni arayüze sahip"
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "'%s' simgesi %L'de zaten temel %s türünde"
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "'%s' simgesi %L'de zaten temel %s türünde"
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "%qs simgesi (%L'de) bir türe sahip olamaz"
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "'%s' bileşeni (%C'deki) zaten %L'de bildirilmiş"
 
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "%qs simgesi %C'de belirsiz"
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Türetilmiş '%s' türü (%C'deki) tanımından önce kullanılıyor"
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "'%s' bileşeni (%C'deki) '%s'nin bir PRIVATE bileşenidir"
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "'%s' (%C'deki) '%s' yapısının bir üyesi değil"
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "'%s' (%C'deki) '%s' yapısının bir üyesi değil"
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr " %d yaftası %L ve %L'de yinelenmiş"
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "%d yaftası (%C'deki) zaten dallanma hedefi olarak başvurulu"
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "%d yaftası (%C'deki) zaten bir biçim yaftası olarak başvurulu"
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "%d yaftası (%C'deki) evvelce bir biçim yaftası olarak kullanılmış"
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "%d yaftası (%C'deki) evvelce dallanma hedefi olarak kullanılmış"
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Shared DO termination label %d at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "Labeled DO statement at %L"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "'%s' ismi (%C'deki) '%s'e '%s' modülünden belirsiz bir başvurudur"
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "%qs ismi (%C'deki) şu an ki program biriminden %qs'e belirsiz bir başvurudur"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "%qs simgesi (%C'deki) zaten konakla ilişkiliymiş"
 
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' requires an argument list at %C"
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "'%s' işlevi %C'de bir argüman listesi gerektiriyor"
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -89802,24 +89855,24 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "%C'deki G/C listesinde virgül umuluyordu"
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "yürüyüş sırasında ifade türü hatalı (%d)"
@@ -90034,38 +90087,38 @@ msgstr "FPU yazmaçlarındaki işlevlerin değerleri döner"
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Bilinmeyen yerleşik terim"
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing argument list in function '%s' at %C"
 msgid "Unknown argument list function at %L"
 msgstr "'%s' işlevinde argüman listesi eksik (%C'de)"
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -90076,18 +90129,18 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "Yerleşik işlev %qs (%d) tanınmiyor"
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of '%s' intrinsic at %L is not a valid dimension index"
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "`dim' argümanı `%s' yerleşiği için  (%L'de) geçerli bir boyut indisi değil"
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Complex argument of LOG at %L cannot be zero"
 msgid "The event variable at %L shall not be coindexed"
@@ -90244,7 +90297,7 @@ msgstr ""
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_trans_select(): Bad type for case expr."
@@ -90662,6 +90715,12 @@ msgstr "%qs alanı bir işlev olarak bildirilmiş"
 msgid "function %qD redeclared as variable"
 msgstr "işlev %q+D 'inline' olarak yeniden bildirilmiş"
 
+#: lto/lto-symtab.cc:865
+#, fuzzy, gcc-internal-format
+#| msgid "%q+#D previously declared here"
+msgid "previously declared here"
+msgstr "%q+#D evvelce burada bildirilmiş"
+
 #: lto/lto.cc:174
 #, gcc-internal-format
 msgid "%<lto_obj_file_open()%> failed"
@@ -91998,7 +92057,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr ""
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, fuzzy, gcc-internal-format
 #| msgid "non-object member %qs cannot be declared %<mutable%>"
 msgid "non-objective-c type %qT cannot be caught"
@@ -92009,7 +92068,7 @@ msgstr "nesne olmayan üye %qs %<mutable%> olarak bildirilemez"
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr ""
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, gcc-internal-format
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
 msgstr ""
@@ -93800,21 +93859,11 @@ msgstr ""
 #~ msgid "argument 1 of __builtin_spe_predicate must be a constant"
 #~ msgstr "__builtin_spe_predicate'in 1. argümanı bir sabit olmalı"
 
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#~| msgid "built-in function %q+D declared as non-function"
-#~ msgid "Builtin function %s requires the -mhtm option"
-#~ msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
-
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #~| msgid "built-in function %q+D declared as non-function"
 #~ msgid "Builtin function %s requires the -maltivec option"
 #~ msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#~| msgid "built-in function %q+D declared as non-function"
-#~ msgid "Builtin function %s requires the -mpaired option"
-#~ msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
-
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #~| msgid "built-in function %q+D declared as non-function"
 #~ msgid "Builtin function %s requires the -mspe option"
diff --git a/gcc/po/uk.po b/gcc/po/uk.po
index b89cbfb1cb1..5c63b7eb8fa 100644
--- a/gcc/po/uk.po
+++ b/gcc/po/uk.po
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 13.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
 "PO-Revision-Date: 2023-07-28 15:23+0300\n"
 "Last-Translator: Volodymyr Lisivka <vlisivka@gmail.com>\n"
 "Language-Team: Ukrainian <trans-uk@lists.fedoraproject.org>\n"
@@ -385,7 +385,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr "не вказуйте одночасно -march=... та -mcpu=..."
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 msgid "shared and mdll are not compatible"
 msgstr "shared та mdll несумісні"
 
@@ -19289,16 +19289,16 @@ msgstr "нерозпізнаваний insn:"
 msgid "insn does not satisfy its constraints:"
 msgstr "insn не задовольняє свої обмеження:"
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "створено і використовується з різними налаштуваннями «%s»"
 
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "створено і використано з різними налаштуваннями %<-fpic%>"
 
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 msgid "created and used with different settings of %<-fpie%>"
 msgstr "створено і використано з різними налаштуваннями %<-fpie%>"
 
@@ -19619,7 +19619,7 @@ msgstr "модифікатор довжини у форматі strfmon"
 msgid "<command-line>"
 msgstr "<командний рядок>"
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "непідтримуваний операнд для коду '%c'"
@@ -19638,9 +19638,9 @@ msgstr "недійсний операнд для '%%%c'"
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, c-format
 msgid "invalid vector constant"
 msgstr "недійсна векторна константа"
@@ -19661,7 +19661,7 @@ msgstr "несумісний операнд з регістром для '%%%c'"
 msgid "incompatible register operand for '%%%c'"
 msgstr "несумісний операнд з регістром для '%%%c'"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, c-format
 msgid "missing operand"
 msgstr "відсутній операнд"
@@ -19690,93 +19690,93 @@ msgstr "неприпустимий режим адреси"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "не можна комбінувати вектори GNU та SVE в бінарній операції"
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "'%%&' використовується без будь-яких локальних динамічних посилань TLS"
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, c-format
 msgid "invalid %%J value"
 msgstr "неприпустиме значення %%J"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, c-format
 msgid "invalid %%r value"
 msgstr "неприпустиме значення %%r"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, c-format
 msgid "invalid %%R value"
 msgstr "неприпустиме значення %%R"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, c-format
 msgid "invalid %%N value"
 msgstr "неприпустиме значення %%N"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, c-format
 msgid "invalid %%P value"
 msgstr "недійсне значення %%P"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, c-format
 msgid "invalid %%h value"
 msgstr "недійсне значення %%h"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, c-format
 msgid "invalid %%L value"
 msgstr "недійсне значення %%L"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, c-format
 msgid "invalid %%m value"
 msgstr "недійсне значення %%m"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, c-format
 msgid "invalid %%M value"
 msgstr "недійсне значення %%M"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, c-format
 msgid "invalid %%U value"
 msgstr "недійсне значення %%U"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, c-format
 msgid "invalid %%s value"
 msgstr "недійсне значення %%s"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, c-format
 msgid "invalid %%C value"
 msgstr "недійсне значення %%C"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, c-format
 msgid "invalid %%E value"
 msgstr "недійсне значення %%E"
 
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "невідома перерозташування unspec"
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, c-format
 msgid "invalid %%xn code"
 msgstr "недійсний код %%xn"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, c-format
 msgid "invalid operand address"
 msgstr "недійсна адреса операнда"
@@ -19872,35 +19872,35 @@ msgstr "недійсний UNSPEC як операнд: %d"
 msgid "unrecognized supposed constant"
 msgstr "нерозпізнана припущена константа"
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, c-format
 msgid "invalid shift operand"
 msgstr "недійсний операнд зсуву"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "умовна інструкція Thumb"
 
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "умовна інструкція в умовній послідовності"
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Непідтримуваний операнд для коду '%c'"
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -19908,113 +19908,113 @@ msgstr "Непідтримуваний операнд для коду '%c'"
 msgid "invalid operand for code '%c'"
 msgstr "недійсний операнд для коду '%c'"
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, c-format
 msgid "instruction never executed"
 msgstr "інструкція ніколи не виконується"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "застарілий код формату Maverick '%c'"
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "недійсне перетворення з типу %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "недійсне перетворення до типу %<bfloat16_t%>"
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr "операція не дозволена для типу %<bfloat16_t%>"
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "операнд адреси потребує обмеження для регістра X, Y або Z"
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "операнди для %T/%t повинні бути reg + const_int:"
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 msgid "bad address, not an I/O address:"
 msgstr "погана адреса, не адреса введення/виведення:"
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 msgid "bad address, not a constant:"
 msgstr "погана адреса, не константа:"
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 msgid "bad address, not (reg+disp):"
 msgstr "погана адреса, не (reg+disp):"
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "неправильна адреса, не post_inc або pre_dec:"
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr "внутрішня помилка компілятора. Погана адреса:"
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "Непідтримуваний код '%c' для фіксованої точки:"
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 msgid "internal compiler error.  Unknown mode:"
 msgstr "внутрішня помилка компілятора. Невідомий режим:"
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 msgid "invalid insn:"
 msgstr "неправильна інструкція:"
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 msgid "incorrect insn:"
 msgstr "неправильна інструкція:"
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 msgid "unknown move insn:"
 msgstr "невідома інструкція переміщення:"
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 msgid "bad shift insn:"
 msgstr "неправильна інструкція зсуву:"
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "внутрішня помилка компілятора. Неправильний зсув:"
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 msgid "unsupported fixed-point conversion"
 msgstr "непідтримуване перетворення з фіксованою точкою"
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 msgid "variable"
 msgstr "змінна"
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 msgid "function parameter"
 msgstr "параметр функції"
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 msgid "structure field"
 msgstr "поле структури"
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 msgid "return type of function"
 msgstr "тип повернення функції"
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 msgid "pointer"
 msgstr "вказівник"
 
@@ -20050,7 +20050,7 @@ msgstr "непідтримуваний операнд"
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -20369,56 +20369,56 @@ msgstr "операнд не є цілочисельним, недійсний к
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "операнд не є конкретним цілочисельним, недійсний код операнду 'R'"
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "недійсний код операнду '%c'"
 
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "недійсні обмеження для операнду"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, c-format
 msgid "invalid vector immediate"
 msgstr "недійсне векторне негайне значення"
 
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 msgid "unknown insn mode"
 msgstr "невідомий режим інструкції"
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 #, fuzzy
 #| msgid "invalid conversion from type %<bfloat16_t%>"
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr "недійсне перетворення з типу %<bfloat16_t%>"
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 #, fuzzy
 #| msgid "invalid conversion from type %<bfloat16_t%>"
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr "недійсне перетворення з типу %<bfloat16_t%>"
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 #, fuzzy
 #| msgid "invalid conversion to type %<bfloat16_t%>"
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr "недійсне перетворення до типу %<bfloat16_t%>"
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 #, fuzzy
 #| msgid "invalid conversion to type %<bfloat16_t%>"
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr "недійсне перетворення до типу %<bfloat16_t%>"
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 #, fuzzy
 #| msgid "operation not permitted on type %<bfloat16_t%>"
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr "операція не дозволена для типу %<bfloat16_t%>"
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 #, fuzzy
 #| msgid "operation not permitted on type %<bfloat16_t%>"
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
@@ -20451,7 +20451,7 @@ msgstr "недійсна операція на %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "недійсний операнд %%P"
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, c-format
 msgid "invalid %%p value"
 msgstr "недійсне значення %%p"
@@ -20478,29 +20478,29 @@ msgstr "не можна використовувати неглобальну в
 msgid "invalid addressing mode"
 msgstr "неприпустимий режим адресації"
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, c-format
 msgid "'%%%c' is not a valid operand prefix"
 msgstr "«%%%c» не є дійсним префіксом операнда"
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "неприпустиме використання '%%%c'"
@@ -20532,7 +20532,7 @@ msgid "post-increment address is not a register"
 msgstr "адреса з постінкрементом не є регістром"
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 msgid "bad address"
 msgstr "неправильна адреса"
 
@@ -20690,7 +20690,7 @@ msgstr "непідтримувана адреса константи:"
 msgid "unsupported memory expression:"
 msgstr "непідтримуваний вираз памʼяті:"
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, c-format
 msgid "invalid vector operand"
 msgstr "недійсний операнд вектора"
@@ -20738,242 +20738,242 @@ msgstr "%<-mquad-memory-atomic%> потребує 64-бітний режим"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "%<-mquad-memory%> недоступний в режимі little endian"
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 msgid "bad move"
 msgstr "неправильний хід"
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 msgid "Bad 128-bit move"
 msgstr "Неправильний 128-бітний хід"
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, c-format
 msgid "invalid %%A value"
 msgstr "неправильне значення %%A"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%D value"
 msgstr "неправильне значення %%D"
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, c-format
 msgid "invalid %%e value"
 msgstr "неправильне значення %%e"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, c-format
 msgid "invalid %%f value"
 msgstr "неправильне значення %%f"
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, c-format
 msgid "invalid %%F value"
 msgstr "неправильне значення %%F"
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, c-format
 msgid "invalid %%G value"
 msgstr "неправильне значення %%G"
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, c-format
 msgid "invalid %%j code"
 msgstr "неправильний код %%j"
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, c-format
 msgid "invalid %%J code"
 msgstr "неправильний код %%J"
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, c-format
 msgid "invalid %%k value"
 msgstr "неправильне значення %%k"
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, c-format
 msgid "invalid %%K value"
 msgstr "неправильне значення %%K"
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, c-format
 msgid "invalid %%O value"
 msgstr "недійсне значення %%O"
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, c-format
 msgid "invalid %%q value"
 msgstr "недійсне значення %%q"
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, c-format
 msgid "invalid %%t value"
 msgstr "недійсне значення %%t"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, c-format
 msgid "invalid %%T value"
 msgstr "недійсне значення %%T"
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, c-format
 msgid "invalid %%u value"
 msgstr "недійсне значення %%u"
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, c-format
 msgid "invalid %%v value"
 msgstr "недійсне значення %%v"
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, c-format
 msgid "invalid %%V value"
 msgstr "недійсне значення %%V"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, c-format
 msgid "invalid %%x value"
 msgstr "недійсне значення %%x"
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, c-format
 msgid "invalid %%z value"
 msgstr "недійсне значення %%z"
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "недійсне значення %%y, спробуйте використати обмеження 'Z'"
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Неприпустиме змішування типів з плаваючою комою IEEE 128 біт та IBM 128 біт"
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Аргумент AltiVec, переданий у функцію без прототипу"
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 msgid "Could not generate addis value for fusion"
 msgstr "Не вдалося згенерувати значення addis для злиття"
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Не вдалося згенерувати зсув завантаження/збереження для злиття"
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 msgid "Bad GPR fusion"
 msgstr "Погане злиття GPR"
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "недійсне перетворення з типу %<__vector_quad%>"
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "недійсне перетворення на тип %<__vector_quad%>"
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "недійсне перетворення з типу %<__vector_pair%>"
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "недійсне перетворення на тип %<__vector_pair%>"
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "символічні посилання на памʼять підтримуються лише на z10 або пізніше"
 
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, c-format
 msgid "cannot decompose address"
 msgstr "не вдається розкласти адресу"
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "недійсний оператор порівняння для модифікатора виводу «E»"
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "недійсне посилання для модифікатора виводу «J»"
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "неправильна адреса для модифікатора виводу 'O'"
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "неправильна адреса для модифікатора виводу 'R'"
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "очікується посилання на памʼять для модифікатора виводу 'S'"
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "неправильна адреса для модифікатора виводу 'S'"
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "очікується регістр або вираз памʼяті для модифікатора виводу 'N'"
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "очікується регістр або вираз памʼяті для модифікатора виводу 'M'"
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "неправильна константа для модифікатора виводу '%c'"
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "неправильна константа - спробуйте використати модифікатор виводу"
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "неправильний вектор констант для модифікатора виводу '%c'"
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "неприпустимий вираз - спробуйте використати модифікатор виводу"
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "неприпустимий вираз для модифікатора виводу '%c'"
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 msgid "vector argument passed to unprototyped function"
 msgstr "векторний аргумент переданий до функції без прототипу"
 
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 msgid "types differ in signedness"
 msgstr "типи відрізняються за знаком"
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 msgid "binary operator does not support two vector bool operands"
 msgstr "бінарний оператор не підтримує два векторних операнди типу bool"
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 msgid "binary operator does not support vector bool operand"
 msgstr "бінарний оператор не підтримує векторний операнд типу bool"
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "бінарний оператор не підтримує змішування векторного операнду типу bool з векторним операндом типу з плаваючою точкою"
 
@@ -21165,12 +21165,12 @@ msgstr "({анонімний})"
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "очікувався %<;%>"
@@ -21183,7 +21183,7 @@ msgstr "очікувався %<;%>"
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -21192,7 +21192,7 @@ msgstr "очікувався %<;%>"
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "очікувався %<)%>"
@@ -21200,7 +21200,7 @@ msgstr "очікувався %<)%>"
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "очікувався %<]%>"
@@ -21211,29 +21211,29 @@ msgstr "очікувався %<;%>, %<,%> або %<)%>"
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "очікувався %<(%>"
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "очікувався %<[%>"
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "очікувався %<{%>"
@@ -21243,17 +21243,17 @@ msgstr "очікувався %<{%>"
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "очікувався %<:%>"
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "очікувався %<while%>"
@@ -21262,8 +21262,8 @@ msgstr "очікувався %<while%>"
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "очікувався %<,%>"
@@ -21273,17 +21273,17 @@ msgid "expected %<.%>"
 msgstr "очікувався %<.%>"
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "очікувався %<@end%>"
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "очікувався %<>%>"
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "очікувався %<,%> або %<)%>"
@@ -21291,32 +21291,32 @@ msgstr "очікувався %<,%> або %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "очікувалось %<=%>"
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "очікувалось %<}%>"
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, gcc-internal-format
 msgid "expected %<else%>"
 msgstr "очікувалось %<else%>"
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "очікувалось %<#pragma omp section%> або %<}%>"
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr "<повідомлення невідоме на етапі компіляції>"
 
@@ -21324,7 +21324,7 @@ msgstr "<повідомлення невідоме на етапі компіл
 msgid "(anonymous)"
 msgstr "(анонімний)"
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "очікувалось %<<%>"
@@ -21339,22 +21339,22 @@ msgstr "очікувалася мітка"
 msgid "candidate:"
 msgstr "кандидат:"
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 msgid "  after user-defined conversion:"
 msgstr "  після користувацького перетворення:"
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "кандидат є:"
 msgstr[1] "кандидати є:"
 msgstr[2] "кандидати є:"
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr "кандидат 1:"
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr "кандидат 2:"
 
@@ -21588,7 +21588,7 @@ msgstr "%r%s:%d:%d:%R   у розширенні %<constexpr%> %qs"
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%R   у розширенні %<constexpr%> %qs"
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 msgid "candidates are:"
 msgstr "кандидати:"
 
@@ -21632,48 +21632,48 @@ msgstr "перетворення відкидає константність"
 msgid "source type is not polymorphic"
 msgstr "тип джерела не є поліморфним"
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "неправильний тип аргументу для унарного мінуса"
 
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "неправильний тип аргументу для унарного плюса"
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "неправильний тип аргументу для бітового доповнення"
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "неправильний тип аргументу для abs"
 
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "неправильний тип аргументу для конʼюгації"
 
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 msgid "in argument to unary !"
 msgstr "в аргументі для унарного !"
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 msgid "no pre-increment operator for type"
 msgstr "немає оператора преінкремента для цього типу"
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 msgid "no post-increment operator for type"
 msgstr "немає оператора постінкремента для цього типу"
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 msgid "no pre-decrement operator for type"
 msgstr "немає оператора предекремента для цього типу"
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 msgid "no post-decrement operator for type"
 msgstr "немає оператора постдекремента для цього типу"
 
@@ -21761,7 +21761,7 @@ msgstr "Застаріла функція:"
 msgid "Deleted feature:"
 msgstr "Видалена функція:"
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 msgid "array assignment"
 msgstr "присвоєння масиву"
 
@@ -21954,11 +21954,11 @@ msgstr "блок IF"
 msgid "implied END DO"
 msgstr "неявний END DO"
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 msgid "assignment"
 msgstr "присвоєння"
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 msgid "pointer assignment"
 msgstr "присвоєння вказівника"
 
@@ -22118,47 +22118,47 @@ msgstr "Операнд користувацького оператора %%<%s%%
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнди користувацького оператора %%<%s%%> на %%L є %s/%s"
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 msgid "Loop variable"
 msgstr "Змінна циклу"
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 msgid "iterator variable"
 msgstr "змінна ітератора"
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 msgid "Start expression in DO loop"
 msgstr "Початковий вираз у циклі DO"
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 msgid "End expression in DO loop"
 msgstr "Кінцевий вираз у циклі DO"
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 msgid "Step expression in DO loop"
 msgstr "Вираз кроку у циклі DO"
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 msgid "DEALLOCATE object"
 msgstr "ЗВІЛЬНИТИ обʼєкт"
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 msgid "ALLOCATE object"
 msgstr "ВИДІЛИТИ обʼєкт"
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 msgid "STAT variable"
 msgstr "змінна STAT"
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 msgid "ERRMSG variable"
 msgstr "змінна ERRMSG"
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 msgid "item in READ"
 msgstr "елемент у READ"
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 msgid "ACQUIRED_LOCK variable"
 msgstr "змінна ACQUIRED_LOCK"
 
@@ -22167,11 +22167,11 @@ msgstr "змінна ACQUIRED_LOCK"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "Різні довжини CHARACTER (%ld/%ld) у конструкторі масиву"
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "Переповнення цілочисельного типу при обчисленні обсягу памʼяті для виділення"
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr "Значення параметра PDT LEN '%s' не збігається з тим, що в декларації-пустуні"
@@ -22186,12 +22186,12 @@ msgstr "Фактична довжина рядка не відповідає о
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Фактична довжина рядка коротша за визначену для фіктивного аргументу '%s' (%ld/%ld)"
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Ціль перенумерування рангу занадто мала (%ld < %ld)"
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 msgid "Assignment of scalar to unallocated array"
 msgstr "Присвоєння скаляру невиділеному масиву"
 
@@ -22200,81 +22200,81 @@ msgstr "Присвоєння скаляру невиділеному масив
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Нерівні довжини символів (%ld/%ld) в %s"
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr "Аргумент POS (%ld) поза діапазоном 0:%ld в вбудованій функції BTEST"
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "Аргумент POS (%ld) поза діапазоном 0:%ld в вбудованій функції %s"
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr "Аргумент POS (%ld) поза діапазоном 0:%ld в вбудованій функції IBITS"
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr "Аргумент LEN (%ld) поза діапазоном 0:%ld в вбудованій функції IBITS"
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) в інтринсичній функції IBITS"
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, c-format
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "Аргумент SHIFT (%ld) поза межами діапазону 0:%ld в інтринсичній функції %s"
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr "Аргумент SHIFT (%ld) поза межами діапазону -%ld:%ld в інтринсичній функції ISHFT"
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr "Аргумент SIZE (%ld) поза межами діапазону 1:%ld в інтринсичній функції ISHFTC"
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr "Аргумент SHIFT (%ld) поза межами діапазону -%ld:%ld в інтринсичній функції ISHFTC"
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Аргумент NCOPIES інтринсичної функції REPEAT є відʼємним (його значення %ld)"
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "Аргумент NCOPIES інтринсичної функції REPEAT є занадто великим"
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, c-format
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "Аргумент FROMPOS (%ld) поза межами діапазону 0:%d в інтринсичній функції MVBITS"
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "Аргумент LEN (%ld) поза межами діапазону 0:%d в інтринсичній функції MVBITS"
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, c-format
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "Аргумент TOPOS (%ld) поза межами діапазону 0:%d в інтринсичній функції MVBITS"
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) в інтринсичній функції MVBITS"
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) в інтринсичній функції MVBITS"
@@ -22296,15 +22296,15 @@ msgstr "Призначена мітка не є цільовою міткою"
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Недійсний номер зображення %d в SYNC IMAGES"
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr "Цикл виконується нескінченно"
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 msgid "Loop variable has been modified"
 msgstr "Змінено змінну циклу"
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 msgid "DO step value is zero"
 msgstr "Значення кроку DO дорівнює нулю"
 
@@ -22382,7 +22382,7 @@ msgid "expected boolean type"
 msgstr "очікувався булевий тип"
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "очікувалася цілочисельна величина"
@@ -22445,7 +22445,7 @@ msgstr "недостатньо аргументів"
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "забагато аргументів"
@@ -23081,7 +23081,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "%<-mrelax%> підтримується лише для RTP PIC"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Синтаксична помилка в операторі %s на %C"
@@ -23523,8 +23523,8 @@ msgstr "атрибут %qE ігнорується, оскільки він ко
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "попереднє оголошення тут"
@@ -23541,7 +23541,7 @@ msgstr "директива атрибуту %qE ігнорується"
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr "директива атрибуту в області %<%E::%E%> ігнорується"
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, gcc-internal-format
 msgid "wrong number of arguments specified for %qE attribute"
 msgstr "вказано неправильну кількість аргументів для атрибуту %qE"
@@ -23551,7 +23551,7 @@ msgstr "вказано неправильну кількість аргумен
 msgid "expected %i or more, found %i"
 msgstr "очікувалося %i або більше, знайдено %i"
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, gcc-internal-format, gfc-internal-format
 msgid "expected %i, found %i"
 msgstr "очікувалося %i, знайдено %i"
@@ -23618,12 +23618,12 @@ msgstr "атрибути типу ігноруються після вже ви
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -23632,7 +23632,7 @@ msgstr "атрибути типу ігноруються після вже ви
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -23654,8 +23654,8 @@ msgstr "атрибут %qE ігнорується"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "відсутній атрибут %<target%> для багатоверсійного %qD"
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "попереднє оголошення %qD"
@@ -23766,7 +23766,7 @@ msgstr "не вдалося прочитати профіль функції з
 msgid "offset %qwi outside bounds of constant string"
 msgstr "зміщення %qwi знаходиться поза межами константного рядка"
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qE оголошено тут"
@@ -23871,7 +23871,7 @@ msgstr "неприпустимий аргумент 0 для %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, gcc-internal-format
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "неприпустиме використання %<__builtin_va_arg_pack ()%>"
@@ -23893,42 +23893,42 @@ msgstr "другий аргумент %<__builtin_longjmp%> повинен бу
 msgid "target format does not support infinity"
 msgstr "цільовий формат не підтримує нескінченність"
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "%<va_start%> використовується в функції з фіксованими аргументами"
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "неправильна кількість аргументів для функції %<va_start%>"
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> викликано без аргумента"
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "неправильна кількість аргументів для функції %<__builtin_next_arg%>"
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "другий параметр %<va_start%> не є останнім іменованим аргументом"
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "невизначена поведінка, коли другий параметр %<va_start%> оголошений зі зберіганням %<register%>"
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, gcc-internal-format
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr "перший аргумент %qD повинен бути вказівником, другий - цілою константою"
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, gcc-internal-format
 msgid "last argument of %qD is not integer constant between 0 and 3"
 msgstr "останній аргумент %qD не є цілою константою від 0 до 3"
@@ -24974,12 +24974,12 @@ msgstr "атрибут %<weakref%> ігнорується, оскільки зм
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F використовується, але ніколи не було визначено"
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F оголошено як %<static%>, але ніколи не було визначено"
@@ -25529,7 +25529,7 @@ msgstr "%<region_array%> не відповідає %<region_tree%>"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "%<lp_array%> не відповідає %<region_tree%>"
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, gcc-internal-format
 msgid "%qs failed"
 msgstr "%qs не вдалося"
@@ -25559,17 +25559,17 @@ msgstr "зворотний порядок зберігання для режим
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr "запис %wu-бітних даних за межами обʼєкта-отримувача, дані обрізані до %wu-бітних"
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, gcc-internal-format
 msgid "call to %qs declared with attribute error: %s"
 msgstr "виклик %qs, оголошений з атрибутом помилки: %s"
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, gcc-internal-format
 msgid "call to %qs declared with attribute warning: %s"
 msgstr "виклик %qs, оголошений з атрибутом попередження: %s"
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
 msgstr "припускається, що при спрощенні %<X - Y %s 0%> до %<X %s Y%> не відбувається переповнення зі знаком"
@@ -25604,7 +25604,7 @@ msgstr "велика константа з фіксованою комою не
 msgid "comparison is always %d due to width of bit-field"
 msgstr "порівняння завжди %d через ширину біт-поля"
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "припускаючи, що знакове переповнення не відбувається при спрощенні тесту діапазону"
@@ -25775,7 +25775,7 @@ msgstr "не вдалося отримати часи процесу: %m"
 msgid "%s signal terminated program %s"
 msgstr "сигнал %s завершив програму %s"
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, gcc-internal-format
 msgid "unrecognized command-line option %qs"
 msgstr "невпізнана опція командного рядка %qs"
@@ -26037,7 +26037,7 @@ msgstr "специфікація multilib %qs недійсна"
 msgid "multilib exclusions %qs is invalid"
 msgstr "виключення multilib %qs недійсні"
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "вибір multilib %qs %qs недійсний"
@@ -26336,22 +26336,22 @@ msgstr "вказана межа %qD %E перевищує розмір приз
 msgid "%qD specified bound %E equals source length"
 msgstr "%qD вказана межа %E дорівнює довжині джерела"
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, gcc-internal-format
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr "гнучкий елемент масиву %qD не має чітко визначених бітів заповнення для %qs"
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr "обробка бітових полів PDP11 не підтримується в %qs"
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "%s not supported for variable length aggregates"
 msgstr "%s не підтримується для агрегатів зі змінною довжиною"
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "%s not supported on this target"
 msgstr "%s не підтримується на цій цілі"
@@ -26392,16 +26392,16 @@ msgid "function returns address of local variable"
 msgstr "функція повертає адресу локальної змінної"
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, gcc-internal-format
@@ -26413,27 +26413,27 @@ msgstr "оголошено тут"
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr "аргумент %<nonnull%> %qD порівнюється з NULL"
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr "вихід %qE може бути обрізаний до останнього символу формату"
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr "вихід %qE обрізаний до останнього символу формату"
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr "%qE може записати завершальний нуль поза межами призначення"
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr "%qE записує завершальний нуль поза межами призначення"
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -26441,7 +26441,7 @@ msgstr[0] "директива %<%.*s%> записує %wu байт в облас
 msgstr[1] "директива %<%.*s%> записує %wu байтів в область розміром %wu"
 msgstr[2] "директива %<%.*s%> записує %wu байтів в область розміром %wu"
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
@@ -26449,7 +26449,7 @@ msgstr[0] "Вивід директиви %<%.*s%> може бути обріза
 msgstr[1] "Вивід директиви %<%.*s%> може бути обрізаний при записі %wu байтів в область розміром %wu"
 msgstr[2] "Вивід директиви %<%.*s%> може бути обрізаний при записі %wu байтів в область розміром %wu"
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
@@ -26457,67 +26457,67 @@ msgstr[0] "Вивід директиви %<%.*s%> обрізаний при за
 msgstr[1] "Вивід директиви %<%.*s%> обрізаний при записі %wu байтів у регіон розміром %wu"
 msgstr[2] "Вивід директиви %<%.*s%> обрізаний при записі %wu байтів у регіон розміром %wu"
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr "вивід директиви %<%.*s%> може бути обрізаний при записі до %wu байтів у регіон розміром %wu"
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr "вивід директиви %<%.*s%> було обрізано при записі до %wu байтів у регіон розміром %wu"
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr "директива %<%.*s%> записує до %wu байтів у регіон розміром %wu"
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "вивід директиви %<%.*s%> може бути обрізаний при записі, ймовірно, %wu або більше байтів у регіон розміром %wu"
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "вивід директиви %<%.*s%> обрізаний при записі, ймовірно, %wu або більше байтів у регіон розміром %wu"
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr "директива %<%.*s%> записує, ймовірно, %wu або більше байтів у регіон розміром %wu"
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "Вивід директиви %<%.*s%> може бути обрізаний при записі від %wu до %wu байтів у регіон розміром %wu"
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "Вивід директиви %<%.*s%> може бути обрізаний при записі від %wu до %wu байтів у регіон розміром %wu"
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr "Директива %<%.*s%> записує від %wu до %wu байтів у регіон розміром %wu"
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr "Вивід директиви %<%.*s%> може бути обрізаний при записі %wu або більше байтів у регіон розміром %wu"
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr "Вивід директиви %<%.*s%> може бути обрізаний при записі %wu або більше байтів у регіон розміром %wu"
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr "Директива %<%.*s%> записує %wu або більше байтів у регіон розміром %wu"
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
@@ -26525,7 +26525,7 @@ msgstr[0] "Директива %<%.*s%> записує %wu байт у регіо
 msgstr[1] "Директива %<%.*s%> записує %wu байти у регіон розміром між %wu і %wu"
 msgstr[2] "Директива %<%.*s%> записує %wu байтів у регіон розміром між %wu і %wu"
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -26533,7 +26533,7 @@ msgstr[0] "%<%.*s%> директива може обрізати вивід, з
 msgstr[1] "%<%.*s%> директива може обрізати вивід, записуючи %wu байти у регіон розміром від %wu до %wu"
 msgstr[2] "%<%.*s%> директива може обрізати вивід, записуючи %wu байтів у регіон розміром від %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -26541,122 +26541,122 @@ msgstr[0] "Вивід директиви %<%.*s%> було обрізано, з
 msgstr[1] "Вивід директиви %<%.*s%> було обрізано, записуючи %wu байти у регіон розміром від %wu до %wu"
 msgstr[2] "Вивід директиви %<%.*s%> було обрізано, записуючи %wu байтів у регіон розміром від %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "Вивід директиви %<%.*s%> може бути обрізаний, записуючи до %wu байтів у регіон розміром від %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "Вивід директиви %<%.*s%> було обрізано, записуючи до %wu байтів у регіон розміром від %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "Директива %<%.*s%> записує до %wu байтів у регіон розміром від %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "Вивід директиви %<%.*s%> може бути обрізаний, записуючи, ймовірно, %wu або більше байтів у регіон розміром від %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "Вивід директиви %<%.*s%> обрізаний при записі, ймовірно, %wu або більше байтів у регіон розміром між %wu і %wu"
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "Директива %<%.*s%> ймовірно записує %wu або більше байтів у регіон розміром від %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "Вивід директиви %<%.*s%> може бути обрізаний при записі від %wu до %wu байтів у регіон розміром від %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "Вивід директиви %<%.*s%> обрізаний при записі від %wu до %wu байтів у регіон розміром від %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "Директива %<%.*s%> записує від %wu до %wu байтів у регіон розміром від %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "Вивід директиви %<%.*s%> може бути обрізаний при записі %wu або більше байтів у регіон розміром від %wu до %wu"
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "Виведення директиви %<%.*s%> обрізано при записі %wu або більше байтів в область розміром між %wu та %wu"
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "Директива %<%.*s%> записує %wu або більше байтів в область розміром між %wu та %wu"
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr "Аргумент директиви %<%.*s%> є нульовим"
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr "Виведення директиви %<%.*s%> розміром %wu байт перевищує мінімально необхідний розмір 4095"
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr "Виведення директиви %<%.*s%> розміром між %wu та %wu байтами перевищує мінімально необхідний розмір 4095"
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr "Виведення директиви %<%.*s%> розміром між %wu та %wu байтами може перевищувати мінімально необхідний розмір 4095"
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr "Виведення директиви %<%.*s%> розміром %wu байт перевищує %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr "Виведення директиви %<%.*s%> розміром між %wu та %wu байтами перевищує %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "Виведення директиви %<%.*s%> розміром %wu байтів призводить до перевищення результату %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "Виведення директиви %<%.*s%> розміром між %wu та %wu байтами призводить до перевищення результату над %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr "Виведення директиви %<%.*s%> розміром від %wu до %wu байт може призвести до перевищення максимального значення %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr "Аргумент директиви %<%.*s%> не є нуль-термінованою рядком"
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, gcc-internal-format
 msgid "referenced argument declared here"
 msgstr "звернений аргумент оголошений тут"
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
@@ -26664,22 +26664,22 @@ msgstr[0] "припускаючи, що виведення директиви %w
 msgstr[1] "припускаючи, що виведення директиви %wu байти"
 msgstr[2] "припускаючи, що виведення директиви %wu байтів"
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "аргумент директиви %qE"
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr "аргумент директиви в діапазоні [%E, %E]"
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr "використовується діапазон [%E, %E] для аргументу директиви"
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgid_plural "%qE output %wu bytes into a destination of size %wu"
@@ -26687,22 +26687,22 @@ msgstr[0] "%qE виводить %wu байт в призначення розм
 msgstr[1] "%qE виводить %wu байтів в призначення розміром %wu"
 msgstr[2] "%qE виводить %wu байтів в призначення розміром %wu"
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr "%qE виводить від %wu до %wu байтів в призначення розміром %wu"
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr "%qE виводить %wu або більше байтів (припускаючи %wu) в призначення розміром %wu"
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr "%qE виводить %wu або більше байтів в призначення розміром %wu"
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
@@ -26710,80 +26710,80 @@ msgstr[0] "%qE вивід %wu байт"
 msgstr[1] "%qE вивід %wu байти"
 msgstr[2] "%qE вивід %wu байтів"
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes"
 msgstr "%qE вивід від %wu до %wu байтів"
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr "%qE вивід %wu або більше байтів (припускаючи %wu)"
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes"
 msgstr "%qE вивід %wu або більше байтів"
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr "Ширина директиви %<%.*s%> виходить за межі допустимого діапазону"
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr "Точність директиви %<%.*s%> виходить за межі діапазону"
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr "Аргументи %qE %Z та можливо %Z перекривають обʼєкт призначення %qE"
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 msgid "%qE argument %Z overlaps destination object %qE"
 msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] "Аргумент %qE %Z перекриває обʼєкт призначення %qE"
 msgstr[1] "Аргументи %qE %Z перекривають обʼєкт призначення %qE"
 msgstr[2] "Аргументи %qE %Z перекривають обʼєкт призначення %qE"
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 msgid "%qE argument %Z may overlap destination object %qE"
 msgid_plural "%qE arguments %Z may overlap destination object %qE"
 msgstr[0] "Аргумент %qE %Z може перекривати обʼєкт призначення %qE"
 msgstr[1] "Аргументи %qE %Z можуть перекривати обʼєкт призначення %qE"
 msgstr[2] "Аргументи %qE %Z можуть перекривати обʼєкт призначення %qE"
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr "Обʼєкт призначення, на який посилається аргумент 1 з кваліфікатором %<restrict%>, був оголошений тут"
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr "Вказана межа %wu перевищує максимальний розмір обʼєкта %wu"
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr "Вказана межа %wu перевищує %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, gcc-internal-format
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr "Вказаний діапазон меж [%wu, %wu] перевищує %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, gcc-internal-format
 msgid "null destination pointer"
 msgstr "Вказівник призначення є нульовим"
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr "Вказана межа %wu перевищує розмір %wu обʼєкта призначення"
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, gcc-internal-format
 msgid "null format string"
 msgstr "нульовий рядок формату"
@@ -27522,12 +27522,12 @@ msgstr "використання висячого вказівника до %qD"
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD оголошено тут"
@@ -28303,7 +28303,7 @@ msgstr "токен %u має %<x-location == %u%>"
 msgid "token %u has %<y-location == %u%>"
 msgstr "токен %u має %<y-location == %u%>"
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "недійсне використання атрибуту %<fallthrough%>"
@@ -28653,17 +28653,17 @@ msgstr "імʼя %qs визначено з іншим значенням в ін
 msgid "mismatching definition"
 msgstr "неспівпадаюче визначення"
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr "недійсний fnsummary в потоці LTO"
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr "відсутня підсумкова інлайн-інформація ipa во вхідному файлі"
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, gcc-internal-format
 msgid "IPA modref summary is missing in input file"
 msgstr "відсутня підсумкова інформація IPA modref во вхідному файлі"
@@ -29734,72 +29734,72 @@ msgstr "помилка запису оптимізаційних записів
 msgid "error closing optimization records %qs"
 msgstr "помилка закриття файлу оптимізаційних записів %qs"
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, gcc-internal-format
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "опція командного рядка %qs не підтримується цією конфігурацією"
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "відсутній аргумент для %qs"
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr "аргумент для %qs повинен бути не відʼємним цілочисельним, за бажанням, за яким слідує одиниця розміру"
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer"
 msgstr "аргумент для %qs повинен бути не відʼємним цілочисельним"
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, gcc-internal-format
 msgid "argument to %qs is not between %d and %d"
 msgstr "аргумент для %qs не знаходиться між %d і %d"
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, gcc-internal-format
 msgid "invalid argument in option %qs"
 msgstr "недійсний аргумент в опції %qs"
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr "%qs вказано кілька разів в одній опції"
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, gcc-internal-format
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr "%qs взаємовиключний з %qs і не може бути вказаний разом"
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, gcc-internal-format
 msgid "unrecognized argument in option %qs"
 msgstr "невпізнаний аргумент в опції %qs"
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "допустимі аргументи для %qs: %s; ви мали на увазі %qs?"
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "допустимі аргументи для %qs: %s"
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "перемикач %qs більше не підтримується"
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, gcc-internal-format
 msgid "argument to %qs is bigger than %d"
 msgstr "аргумент для %qs більший за %d"
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, gcc-internal-format
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
 msgstr "неправильний %<COLLECT_GCC_OPTIONS%>"
@@ -29873,8 +29873,8 @@ msgstr "аргумент для %<-O%> повинен бути невідʼєм
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, gcc-internal-format
 msgid "%qs is incompatible with %qs"
 msgstr "%qs несумісний з %qs"
@@ -30588,7 +30588,7 @@ msgstr "глобальна змінна-регістр слідує за виз
 msgid "register of %qD used for multiple global register variables"
 msgstr "регістр %qD використовується для кількох глобальних змінних-регістрів"
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "конфліктує з %qD"
@@ -31038,44 +31038,44 @@ msgstr "Розділ псевдоніма %q+D повинен відповіда
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "%<__builtin_saveregs%> не підтримується цільовою платформою"
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, gcc-internal-format
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "аргумент %qs не підтримується для %qs на цільовій платформі"
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, gcc-internal-format
 msgid "nested functions not supported on this target"
 msgstr "вкладені функції не підтримуються на цій платформі"
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, gcc-internal-format
 msgid "nested function trampolines not supported on this target"
 msgstr "трампліни вкладених функцій не підтримуються на цій платформі"
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "глобальні конструктори не підтримуються на цій платформі"
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "глобальні деструктори не підтримуються на цій платформі"
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute is not supported on this machine"
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "атрибут цільової платформи не підтримується на цій машині"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute is not supported on this machine"
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "атрибут цільової платформи не підтримується на цій машині"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, gcc-internal-format
 msgid "%<#pragma GCC target%> is not supported for this machine"
 msgstr "%<#pragma GCC target%> не підтримується для цієї машини"
@@ -32197,82 +32197,82 @@ msgstr "Базовий блок %i має неправильне ребро"
 msgid "BB %i has incorrect fallthru edge"
 msgstr "Базовий блок %i має неправильне ребро fallthru"
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr "функцію %q+F неможливо скопіювати, оскільки вона отримує нелокальний перехід"
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr "функцію %q+F неможливо скопіювати, оскільки вона зберігає адресу локальної мітки в статичній змінній"
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr "функцію %q+F неможливо вбудувати, оскільки вона використовує alloca (перевизначте, використовуючи атрибут always_inline)"
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr "функцію %q+F неможливо вбудувати, оскільки вона використовує setjmp"
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr "функцію %q+F неможливо вбудувати, оскільки вона використовує змінні списки аргументів"
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr "функцію %q+F неможливо вбудувати, оскільки вона використовує обробку винятків setjmp-longjmp"
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr "функцію %q+F неможливо вбудувати, оскільки вона використовує нелокальний перехід goto"
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr "функцію %q+F неможливо вбудувати, оскільки вона використовує %<__builtin_return%> або %<__builtin_apply_args%>"
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr "функцію %q+F неможливо вбудувати, оскільки вона містить обчислюваний перехід goto"
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr "функцію %q+F неможливо вбудувати, оскільки вона має аргумент зі змінною довжиною масиву"
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr "функцію %q+F неможливо вбудувати, оскільки вона пригнічена за допомогою %<-fno-inline%>"
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr "функцію %q+F неможливо вбудувати, оскільки вона використовує атрибути, що конфліктують з вбудовуванням"
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, gcc-internal-format
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr "не вдалося вбудувати виклик %q+F з %<always_inline%>: %s"
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr "виклик звідси"
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, gcc-internal-format
 msgid "called from this function"
 msgstr "виклик з цієї функції"
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, gcc-internal-format
 msgid "inlining failed in call to %q+F: %s"
 msgstr "не вдалося вбудувати виклик %q+F: %s"
@@ -32327,27 +32327,27 @@ msgstr "неприпустимий атрибут специфікації fn «
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr "неприпустимий атрибут специфікації fn «%s» аргумент %i"
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr "вказівник %qs є нульовим"
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, gcc-internal-format
 msgid "in a call to non-static member function %qD"
 msgstr "при виклику нестатичного член-функції %qD"
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr "аргумент %u є нульовим, тоді як очікується ненульовий"
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "при виклику вбудованої функції %qD"
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, gcc-internal-format
 msgid "in a call to function %qD declared %qs"
 msgstr "у виклику функції %qD, оголошеної як %qs"
@@ -32558,7 +32558,7 @@ msgstr "%qs використовується неініціалізованим"
 msgid "%qs may be used uninitialized"
 msgstr "%qs може бути використаний неініціалізованим"
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD було оголошено тут"
@@ -32788,7 +32788,7 @@ msgstr "векторна умова буде розширена поштовха
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "операція перемішування вектора буде розширена поштовхами"
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr "векторизація не відбулася для циклу simd"
@@ -32803,122 +32803,122 @@ msgstr "неконстантний елемент у константному К
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr "елемент з побічними ефектами у КОНСТРУКТОРІ без побічних ефектів"
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "масиви функцій не мають сенсу"
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "тип повернення функції не може бути функцією"
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "перевірка дерева: %s, є %s у %s, на %s:%d"
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "перевірка дерева: очікується ні одного з %s, є %s у %s, на %s:%d"
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "перевірка дерева: очікується клас %qs, є %qs (%s) у %s, на %s:%d"
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "перевірка дерева: не очікував класу %qs, є %qs (%s) у %s, на %s:%d"
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, gcc-internal-format
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr "перевірка дерева: очікував %<omp_clause %s%>, є %qs у %s, на %s:%d"
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "перевірка дерева: очікував дерево, що містить структуру %qs, є %qs у %s, на %s:%d"
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr "перевірка дерева: доступ до елементу %d з %<tree_int_cst%> з %d елементів в %s, на %s:%d"
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr "перевірка дерева: доступ до елементу %d з %<tree_vec%> з %d елементів в %s, на %s:%d"
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "перевірка дерева: доступ до операнда %d з %s з %d операндів в %s, на %s:%d"
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, gcc-internal-format
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "перевірка дерева: доступ до операнда %d з %<omp_clause %s%> з %d операндів у %s, на %s:%d"
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD застарілий: %s"
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD застарілий"
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE застарілий: %s"
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE застарілий"
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "тип застарілий: %s"
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "тип застарілий"
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, gcc-internal-format
 msgid "%qD is unavailable: %s"
 msgstr "%qD недоступний: %s"
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, gcc-internal-format
 msgid "%qD is unavailable"
 msgstr "%qD недоступний"
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, gcc-internal-format
 msgid "%qE is unavailable: %s"
 msgstr "%qE недоступний: %s"
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, gcc-internal-format
 msgid "%qE is unavailable"
 msgstr "%qE недоступний"
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, gcc-internal-format, gfc-internal-format
 msgid "type is unavailable: %s"
 msgstr "тип недоступний: %s"
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, gcc-internal-format
 msgid "type is unavailable"
 msgstr "тип недоступний"
@@ -32943,262 +32943,262 @@ msgstr "тип недоступний"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr "варіант типу відрізняється на %s"
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr "варіант типу має різний %<TYPE_SIZE_UNIT%>"
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr "%<TYPE_SIZE_UNIT%> варіанту типу"
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr "%<TYPE_SIZE_UNIT%> типу"
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr "варіант типу з %<TYPE_ALIAS_SET_KNOWN_P%>"
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr "варіант типу має відмінне %<TYPE_VFIELD%>"
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr "варіант типу має відмінне %<TYPE_BINFO%>"
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr "%<TYPE_BINFO%> варіанту типу"
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr "%<TYPE_BINFO%> типу"
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr "варіант типу має різні %<TYPE_FIELDS%>"
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "перша невідповідність - поле"
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, gcc-internal-format
 msgid "and field"
 msgstr "і поле"
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr "варіант типу має різний %<TREE_TYPE%>"
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr "%<TREE_TYPE%> варіант типу"
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr "%<TREE_TYPE%> типу"
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "тип несумісний з його варіантом"
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is not an opaque type"
 msgstr "тип %s не є непрозорим типом"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, gcc-internal-format, gfc-internal-format
 msgid "type %s is not with opaque mode"
 msgstr "тип %s не має непрозорого режиму"
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr "тип %s відрізняється за %<TYPE_MODE%>"
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr "тип %s відрізняється за %<TYPE_SIZE%>"
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr "тип %s відрізняється за %<TYPE_ALIGN%>"
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr "тип %s відрізняється за %<TYPE_USER_ALIGN%>"
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, gcc-internal-format
 msgid "main variant is not defined"
 msgstr "головний варіант не визначений"
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr "%<TYPE_MAIN_VARIANT%> має різний %<TYPE_MAIN_VARIANT%>"
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr "%<TYPE_CANONICAL%> має різний %<TYPE_CANONICAL%>"
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr "%<TYPE_CANONICAL%> несумісний"
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr "%<TYPE_MODE%> %<TYPE_CANONICAL%> несумісний"
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr "%<TYPE_CANONICAL%> головного варіанту не є головним варіантом"
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr "%<TYPE_VFIELD%> не є %<FIELD_DECL%> або %<TREE_LIST%>"
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr "%<TYPE_NEXT_PTR_TO%> не є %<POINTER_TYPE%>"
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr "%<TYPE_NEXT_REF_TO%> не є %<REFERENCE_TYPE%>"
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr "%<TYPE_BINFO%> не є %<TREE_BINFO%>"
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr "тип %<TYPE_BINFO%> не є %<TYPE_MAIN_VARIANT%>"
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr "тип %<TYPE_METHOD_BASETYPE%> не є записом або обʼєднанням"
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr "тип %<TYPE_OFFSET_BASETYPE%> не є записом або обʼєднанням"
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr "розмір масиву %<TYPE_ARRAY_MAX_SIZE%> не є %<INTEGER_CST%>"
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr "значення %<TYPE_MAX_VALUE_RAW%> не є NULL"
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr "поле %<TYPE_LANG_SLOT_1 (binfo)%> не є NULL"
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr "значення перелічування не є %<CONST_DECL%> або %<INTEGER_CST%>"
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr "тип значення перелічування не є %<INTEGER_TYPE%> і не може бути перетворений на перелічування"
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr "імʼя значення перелічування не є %<IDENTIFIER_NODE%>"
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "масив %<TYPE_DOMAIN%> не є цілочисельним типом"
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "%<TYPE_FIELDS%> визначено в неповному типі"
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr "неправильне дерево в списку %<TYPE_FIELDS%>"
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr "%<TYPE_CACHED_VALUES_P%> дорівнює %i, тоді як %<TYPE_CACHED_VALUES%> дорівнює %p"
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr "%<TYPE_CACHED_VALUES%> не є %<TREE_VEC%>"
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr "неправильний запис %<TYPE_CACHED_VALUES%>"
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr "%<TREE_PURPOSE%> не є NULL у списку %<TYPE_ARG_TYPES%>"
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr "неправильний запис у списку %<TYPE_ARG_TYPES%>"
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr "поле %<TYPE_VALUES_RAW%> не є NULL"
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr "%<TYPE_CACHED_VALUES_P%> встановлено, хоча цього не повинно бути"
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr "%<TYPE_METHOD_BASETYPE%> не є основним варіантом"
@@ -33414,7 +33414,7 @@ msgstr "визначення псевдонімів не підтримують
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "атрибут видимості не підтримується в цій конфігурації; ігнорується"
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr "%+qD без атрибуту %<retain%> та %qD з атрибутом %<retain%> розміщені в розділі з такою самою назвою"
@@ -33624,7 +33624,7 @@ msgstr "Атрибут %qE ігнорується, оскільки %qD не є
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "Атрибут %qE проігноровано, оскільки %qD не є локальною змінною"
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "Атрибут %qE має вплив лише на публічні обʼєкти"
@@ -33806,7 +33806,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr "Ігнорується атрибут %qE, який не встановлено для змінної"
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for local variables"
 msgstr "Атрибут %qE не може бути вказаний для локальних змінних"
@@ -34121,7 +34121,7 @@ msgstr "%qD несумісний з %qD"
 msgid "%qE argument is not a function"
 msgstr "Аргумент %qE не є функцією"
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "Застаріле повідомлення не є рядком"
@@ -34627,7 +34627,7 @@ msgstr "ISO C++ не дозволяє застосовувати %<alignof%> д
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr "ISO C не дозволяє застосовувати %<_Alignof%> до типу функції"
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, gcc-internal-format
 msgid "invalid application of %qs to a void type"
 msgstr "недійсне застосування %qs до типу void"
@@ -34758,17 +34758,17 @@ msgstr "атрибут %<fallthrough%> вказано кілька разів"
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "атрибут %<fallthrough%> вказано з параметром"
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "замало аргументів для функції %qE"
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, gcc-internal-format
@@ -34897,166 +34897,166 @@ msgstr "спроба отримати адресу члена структури
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "індекс %E вказує на зміщення, більше розміру %qT"
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "розмір масиву занадто великий"
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "тип операнда %qT несумісний з аргументом %d функції %qE"
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, gcc-internal-format
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "очікується аргумент типу вказівник або цілочисельне для аргументу 1"
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr "обидва аргументи повинні бути сумісними"
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "неправильна кількість аргументів для функції %qE"
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "аргумент 1 функції %qE повинен бути вказівником на тип, що не є void"
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr "аргумент 1 функції %qE повинен бути вказівником на повний тип"
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "аргумент 1 функції %qE повинен бути вказівником на тип зі сталим розміром"
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "аргумент 1 функції %qE повинен бути вказівником на обʼєкт з розміром, відмінним від нуля"
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "аргумент %d з %qE повинен бути типом вказівника"
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "аргумент %d з %qE повинен бути вказівником на тип зі сталою розмірністю"
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "аргумент %d з %qE не повинен бути вказівником на функцію"
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "невідповідність розміру в аргументі %d з %qE"
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr "аргумент %d з %qE не повинен бути вказівником на тип %<const%>"
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, gcc-internal-format
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr "аргумент %d з %qE відкидає кваліфікатор %<const%>"
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr "аргумент %d з %qE не повинен бути вказівником на тип %<volatile%>"
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, gcc-internal-format
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr "аргумент %d з %qE відкидає кваліфікатор %<volatile%>"
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "аргумент %d з %qE для моделі памʼяті не є цілочисельним"
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "неприпустимий аргумент моделі памʼяті %d з %qE"
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr "ця ціль не визначає барʼєр спекуляції; ваша програма все ще буде виконуватись правильно, але неправильна спекуляція може не бути обмежена"
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "значення індексу виходить за межі"
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "перетворення скаляра %qT на вектор %qT включає відсікання"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "вбудовану функцію %qE потрібно викликати безпосередньо"
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, gcc-internal-format
 msgid "size of array %qE is not a constant expression"
 msgstr "розмір масиву %qE не є сталим виразом"
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, gcc-internal-format
 msgid "size of array is not a constant expression"
 msgstr "розмір масиву не є сталим виразом"
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr "розмір %qE масиву %qE є відʼємним"
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, gcc-internal-format
 msgid "size %qE of array is negative"
 msgstr "розмір %qE масиву є відʼємним"
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr "розмір %qE масиву %qE перевищує максимальний розмір обʼєкта %qE"
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr "розмір %qE масиву перевищує максимальний розмір обʼєкта %qE"
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "розмір масиву %qE перевищує максимальний розмір обʼєкта %qE"
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr "розмір масиву перевищує максимальний розмір обʼєкта %qE"
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr "змінна середовища %qs повинна розгортатися в невідʼємне цілочисельне, менше або рівне %wd"
@@ -35681,7 +35681,7 @@ msgstr "цілочисельна константа занадто велика
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr "цілочисельна константа занадто велика для типу %<unsigned long%>"
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int%d%> is not supported on this target"
 msgid "%<_BitInt(%d)%> is not supported on this target"
@@ -35763,7 +35763,7 @@ msgstr "непідтримуване нестандартне зʼєднання
 msgid "traditional C rejects string constant concatenation"
 msgstr "традиційне C відкидає зʼєднання констант рядків"
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr "%<#pragma omp critical%> з %<hint%> замиканням потребує імені, за винятком випадку, коли використовується %<omp_sync_hint_none%>"
@@ -35818,7 +35818,7 @@ msgstr "тип залежності %<depobj%> вказаний в замика
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "Модифікатор %<iterator%> не може бути вказаний на конструкції %<depobj%>"
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "Недійсний тип для змінної ітерації %qE"
@@ -35833,17 +35833,17 @@ msgstr "Змінна ітерації %qE має тип %<_Atomic%>"
 msgid "%qE is not initialized"
 msgstr "%qE не ініціалізовано"
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Відсутній контрольний предикат"
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Недійсний контрольний предикат"
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "Відсутній вираз інкремента"
@@ -35853,7 +35853,7 @@ msgstr "Відсутній вираз інкремента"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr "Інкремент не є константою 1 або -1 для умови %<!=%>"
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Недійсний вираз інкремента"
@@ -35940,7 +35940,7 @@ msgstr "недійсний модифікатор зведення %<task%> на
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr "%<inscan%> %<reduction%> замикання на конструкції, відмінній від %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr "%qD вказано в замиканні %<allocate%>, але не в явному замиканні приватизації"
@@ -35950,7 +35950,7 @@ msgstr "%qD вказано в замиканні %<allocate%>, але не в я
 msgid "%qD is not a function argument"
 msgstr "%qD не є аргументом функції"
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "бітове поле %qE в замиканні %qs"
@@ -36544,7 +36544,7 @@ msgid "wrong type argument to %s"
 msgstr "неправильний тип аргументу для %s"
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -37475,36 +37475,38 @@ msgid "comparison between two arrays"
 msgstr "порівняння між двома масивами"
 
 #: c-family/c-warn.cc:3832
-#, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+#, fuzzy, gcc-internal-format
+#| msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr "використовуйте унарний оператор %<+%>, який перетворює операнди в вказівники, або %<&%D[0] %s &%D[0]%>, щоб порівняти адреси"
 
-#: c-family/c-warn.cc:3836
-#, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+#: c-family/c-warn.cc:3839
+#, fuzzy, gcc-internal-format
+#| msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr "використовуйте %<&%D[0] %s &%D[0]%>, щоб порівняти адреси"
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr "результат виразу %<%wu ^ %wu%> дорівнює %wu; ви мали на увазі %<1 << %wu%> (%wu)?"
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr "результат виразу %<%wu ^ %wu%> дорівнює %wu; ви мали на увазі %<1LL << %wu%>?"
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr "результат виразу %<%wu ^ %wu%> дорівнює %wu; ви мали на увазі піднесення до степеня?"
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr "результат виразу %<%wu ^ %wu%> дорівнює %wu; ви мали на увазі %<1e%wu%>?"
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr "ви можете прибрати це попередження, використовуючи шістнадцяткову константу (%wx замість %wd)"
@@ -37714,127 +37716,127 @@ msgstr "Аргумент %<-misr-secure=%d%> не знаходиться у ді
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr "для опції %<-mcache-block-size=X%> допустимі значення X: 4, 8, 16, 32, 64, 128, 256 або 512"
 
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr "%<-march=%s%>: розширення %qs зустрічається більше одного разу"
 
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr "%<-march=%s%>: розширення %qs зустрічається більше одного разу"
 
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr "%<-march=%s%>: розширення %qs зустрічається більше одного разу"
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr "%<-march=%s%>: розширення %qs зустрічається більше одного разу"
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, gcc-internal-format
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr "%<-march=%s%>: після %<%dp%> очікується число"
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr "%<-march=%s%>: для %<%s%dp%dp?%> не підтримується номер версії з більш ніж 2 рівнями"
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr "%<-march=%s%>: рядок ISA повинен починатися з rv32 або rv64"
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr "%<-march=%s%>: rv%de не є дійсним базовим ISA"
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr "версія %<g%> буде пропущена, будь ласка, вкажіть версію для окремого розширення"
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr "%<-march=%s%>: перший піднабір ISA повинен бути %<e%>, %<i%> або %<g%>"
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr "%<-march=%s%>: після %<%dp%> очікується число"
 
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr "%<-march=%s%>: розширення %qs зустрічається більше одного разу"
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr "%<-march=%s%>: конфлікт z*inx з розширеннями з плаваючою комою"
 
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr "%<-march=%s%>: розширення %qs зустрічається більше одного разу"
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mcpu=%s%> conflicts with %<-march=%s%>"
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr "%<-mcpu=%s%> конфліктує з %<-march=%s%>"
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mcpu=%s%> conflicts with %<-march=%s%>"
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr "%<-mcpu=%s%> конфліктує з %<-march=%s%>"
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr "%<-march=%s%>: конфлікт z*inx з розширеннями з плаваючою комою"
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "%<-march=%s%>: імʼя %s повинно бути більше, ніж 1 літера"
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr "%<-march=%s%>: %s повинно бути розділено знаком %<_%>"
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr "%<-march=%s%>: імʼя %s повинно бути більше, ніж 1 літера"
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "%<-mcpu=%s%>: невідомий процесор"
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr "Не вдалося знайти задовільний набір multilib для %<-march=%s%>/%<-mabi=%s%>"
@@ -38238,12 +38240,12 @@ msgstr "очікується 64-бітна адреса, але аргумент
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "очікується 64-бітна адреса, але аргумент 2 має %d біт"
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC aarch64%> вимагає рядковий параметр"
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "невідома опція %qs для %<#pragma GCC aarch64%>"
@@ -38830,7 +38832,7 @@ msgstr "передача параметра для аргументу типу %
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr "передача параметра для аргументу типу %qT змінена в GCC 9.1"
@@ -38907,12 +38909,12 @@ msgid "unknown tuning option (%s)"
 msgstr "невідомий параметр настроювання (%s)"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr "несумісні параметри %<-mstack-protector-guard=global%> та %<-mstack-protector-guard-offset=%s%>"
 
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr "обидва параметри %<-mstack-protector-guard-offset%> та %<-mstack-protector-guard-reg%> повинні використовуватися з %<-mstack-protector-guard=sysreg%>"
@@ -38923,7 +38925,7 @@ msgid "specify a system register with a small string length"
 msgstr "вказати системний регістр з короткою довжиною рядка"
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs не є дійсним зсувом в %qs"
@@ -39108,9 +39110,9 @@ msgstr "директива або атрибут %<target(\"%s\")%> не доз
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "директива або атрибут %<target(\"%s=%s\")%> недійсний"
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "аргумент атрибуту %<target%> не є рядком"
@@ -39167,18 +39169,18 @@ msgid "virtual function multiversioning not supported"
 msgstr "мультіверсіонування віртуальних функцій не підтримується"
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "мультиверсіонування потребує %<ifunc%>, який не підтримується на цій цілі"
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr "передача параметра для аргументу типу %qT з %<[[no_unique_address]]%> членами змінилася %{у GCC 10.1%}"
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr "передача параметра для аргументу типу %qT при увімкненні C++17 змінилася, щоб відповідати C++14 %{у GCC 10.1%}"
 
@@ -39191,8 +39193,8 @@ msgstr "передача параметра для аргументу типу %
 msgid "lane %wd out of range %wd - %wd"
 msgstr "доріжка %wd поза межами %wd - %wd"
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "непідтримувана simdlen %wd"
@@ -39203,7 +39205,7 @@ msgstr "непідтримувана simdlen %wd"
 msgid "GCC does not currently support return type %qT for simd"
 msgstr "GCC наразі не підтримує тип повернення %qT для функцій %<simd%>"
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "непідтримуваний тип повернення %qT для simd"
@@ -39214,7 +39216,7 @@ msgstr "непідтримуваний тип повернення %qT для si
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr "GCC наразі не підтримує тип аргументу %qT для функцій %<simd%>"
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "непідтримуваний тип аргументу %qT для simd"
@@ -39307,8 +39309,8 @@ msgstr "затримка кешу L%d невідома для %s"
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "неправильне значення %qs для перемикача %<-mmemory-latency%>"
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr "неправильний вбудований fcode"
@@ -39428,18 +39430,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "аргумент атрибуту %qE не є «ilink» або «firq»"
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -39553,7 +39555,7 @@ msgid "argument of %qE attribute is missing"
 msgstr "відсутній аргумент атрибуту %qE"
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "атрибут %qE дозволяє лише цілочисловий константний аргумент"
@@ -39573,23 +39575,23 @@ msgstr "атрибут %qE застосовується лише до типів
 msgid "argument of %qE attribute ignored"
 msgstr "аргумент атрибута %qE проігноровано"
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "атрибут %qE застосовується лише до змінних"
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "альтернативи не дозволені в виводі прапорця %<asm%>"
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr "невідомий вивід прапорця %<asm%> %qs"
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "недійсний тип для виводу прапорця %<asm%>"
@@ -39839,7 +39841,7 @@ msgstr "цільовий процесор не підтримує THUMB інст
 msgid "target CPU does not support unaligned accesses"
 msgstr "цільовий процесор не підтримує незбалансований доступ"
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr "Ця архітектура не підтримує інструкції захисту гілок"
@@ -39889,7 +39891,7 @@ msgstr "межа розміру структури може бути встан
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC несумісний з %<-msingle-pic-base%>"
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "Режим FDPIC не підтримується в режимі Thumb-1"
@@ -39995,7 +39997,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr "аргумент типу %qT не допускається з %<-mgeneral-regs-only%>"
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "передача параметрів для аргументу типу %qT змінилася в GCC 7.1"
@@ -40035,42 +40037,42 @@ msgstr "Атрибут %qE не має впливу на функції зі с
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "Атрибут %qE застосовується тільки до базового типу вказівника на функцію"
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr "доступ до локального сховища потоку в даний час не підтримується з опцією %<-mpure-code%> або %<-mslow-flash-data%>"
 
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd поза діапазоном %wd - %wd"
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "не вдалося обчислити реальне розташування параметра у стеку"
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Неочікуваний далекий перехід thumb1"
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "немає доступних нижніх регістрів для викидання високих регістрів"
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "Процедури обслуговування переривань не можуть бути закодовані в режимі Thumb-1"
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "%<-fstack-check=specific%> для Thumb-1"
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "недійсний fpu для атрибуту або pragma %qs"
@@ -40078,22 +40080,22 @@ msgstr "недійсний fpu для атрибуту або pragma %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "автоматичний вибір fpu в даний момент тут не дозволяється"
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "недійсна архітектура для атрибуту або pragma %qs"
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "невідомий атрибут або pragma %qs"
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "прапорці %<asm%> не підтримуються в режимі thumb1"
@@ -40147,162 +40149,162 @@ msgstr "підтримувані архітектури ядра:%s"
 msgid "unknown core architecture %qs specified with %qs"
 msgstr "невідома архітектура ядра %qs, вказана з %qs"
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, gcc-internal-format
 msgid "%<-fpic%> is not supported"
 msgstr "%<-fpic%> не підтримується"
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, gcc-internal-format
 msgid "%<-fPIC%> is not supported"
 msgstr "%<-fPIC%> не підтримується"
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, gcc-internal-format
 msgid "%<-fpie%> is not supported"
 msgstr "%<-fpie%> не підтримується"
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, gcc-internal-format
 msgid "%<-fPIE%> is not supported"
 msgstr "%<-fPIE%> не підтримується"
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "атрибути функції %qs та %qs взаємовиключні"
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "функція %qs не може мати аргументів"
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "функція %qs не може повертати значення"
 
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, gcc-internal-format
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs, схоже, є неправильно написаним обробником %qs, відсутній префікс %<__vector%>"
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr "%qs є зарезервованим ідентифікатором в AVR-LibC. Розгляньте %<#include <avr/interrupt.h>%> перед використанням макросу %qs"
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr "%qs є зарезервованим ідентифікатором в AVR-LibC. Розгляньте %<#include <avr/interrupt.h>%> перед використанням макросу %qs"
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr "%<builtin_return_address%> містить лише 2 байти адреси"
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr "зміщення вказівника від символу може бути неправильним"
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr "доступ до памʼяті даних за адресою памʼяті програми"
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr "доступ до памʼяті програми за адресою памʼяті даних"
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr "фіксований регістр %s використовується для передачі параметра у функцію"
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "запис у простір адрес %qs не підтримується"
 
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "атрибут %qE застосовується тільки до змінних у статичному сховищі"
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "атрибут %qE підтримується тільки для зменшених ядер Tiny"
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute address out of range"
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr "адреса атрибуту %qE поза межами діапазону"
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr "як %s, так і атрибут %qE надають адресу"
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "Атрибут %qE на неволатильній змінній"
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "Адресні простори не підтримуються на зменшених пристроях Tiny"
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "Адресний простір %qs не підтримується на пристроях з розміром флеш-памʼяті до %d KiB"
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr "Вказівник, що спрямовується на адресний простір %qs, повинен бути const в %qT"
 
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr "Вказівник, що спрямовується на адресний простір %qs, повинен бути const в %s %q+D"
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables in static storage"
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr "атрибут %qE застосовується тільки до змінних у статичному сховищі"
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr "Змінна %q+D повинна бути константою, щоб бути поміщеною в розділ тільки для читання за допомогою %qs"
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, fuzzy, gcc-internal-format
 #| msgid "static IO declaration for %q+D needs an address"
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr "Статичне оголошення IO для %q+D потребує адресу"
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr "В розділ %<.noinit%> можна помістити лише неініціалізовані змінні"
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, gcc-internal-format
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr "Змінна %q+D з динамічною ініціалізацією поміщена в область памʼяті програми"
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "Неініціалізована змінна %q+D поміщена в область памʼяті програми"
@@ -40311,43 +40313,43 @@ msgstr "Неініціалізована змінна %q+D поміщена в 
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable %qs at %L cannot have an initializer"
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr "Змінна з можливістю виділення %qs у %L не може мати ініціалізатора"
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%q+D має несумісні атрибути %qs і %qs"
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr "Архітектура %qs підтримується лише асемблером"
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "Перетворення з адресного простору %qs в адресний простір %qs"
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "%s очікує цілочисельну константу на етапі компіляції"
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%s очікує довгу цілочисельну константу на етапі компіляції як перший аргумент"
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr "заокруглення до %d бітів не має ефекту для значення з фіксованою точкою з %d дробовими бітами"
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr "результат округлення завжди буде 0"
@@ -40483,7 +40485,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "непрямий виклик у функції, який не підтримується eBPF"
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, gcc-internal-format
@@ -41115,8 +41117,8 @@ msgstr "аргумент вбудованої функції %<xabort%> пови
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr "версії функцій не можуть бути позначені як %<gnu_inline%>, потрібно створювати тіла"
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "модель коду %s не підтримує режим PIC"
@@ -41182,257 +41184,257 @@ msgstr "Занадто багато діапазонів розмірів вка
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "Невідомий параметр для опції %<-mtune-ctrl%>: %s"
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "Intel МКП psABI не підтримується в режимі %s"
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> застаріло; використовуйте %<-mtune=k8%> або %<-mtune=generic%> замість цього, як це відповідає"
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> застаріло; використовуйте %<target(\"tune=k8\")%> або %<target(\"tune=generic\")%> замість цього, як це відповідає"
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "%<-mstringop-strategy=rep_8byte%> не підтримується для 32-бітного коду"
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, fuzzy, gcc-internal-format
 #| msgid "%<-muintr%> not supported for 32-bit code"
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "%<-muintr%> не підтримується для 32-бітного коду"
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr "Опція %<-mlam=%>: [u48|u57] не підтримується для 32-бітного коду"
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "%<-muintr%> не підтримується для 32-бітного коду"
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "Опція %<-mlam=%>: [u48|u57] не підтримується для 32-бітного коду"
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "Режим адреси %qs не підтримується в режимі %s біт"
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-mabi=ms%> не підтримується з X32 ABI"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "%<-mabi=%s%> не підтримується з %<-fsanitize=address%>"
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "%<-mabi=%s%> не підтримується з %<-fsanitize=kernel-address%>"
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "%<-mabi=%s%> не підтримується з %<-fsanitize=thread%>"
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "Модель коду %qs не підтримується в режимі %s біт"
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "Модель коду %qs не підтримується в режимі x32"
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "%<-masm=intel%> не підтримується в цій конфігурації"
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "Режим %i біт не скомпільований"
 
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "Процесор %<generic%> може використовуватись тільки для перемикача %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "Процесор %<generic%> може використовуватись тільки для атрибуту %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "Процесор %<intel%> може використовуватись тільки для перемикача %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "процесор %<intel%> може використовуватися лише для атрибуту %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "Вибраний вами процесор не підтримує набір інструкцій x86-64"
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, gcc-internal-format
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "неправильне значення %qs для перемикача %<-march=%>"
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "неправильне значення %qs для атрибуту %<target(\"arch=\")%>"
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "допустимі аргументи для перемикача %<-march=%> це: %s; ви мали на увазі %qs?"
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "допустимі аргументи для атрибуту %<target(\"arch=\")%> це: %s; ви мали на увазі %qs?"
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "допустимі аргументи для перемикача %<-march=%> це: %s"
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "допустимі аргументи для атрибуту %<target(\"arch=\")%> це: %s"
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "неправильне значення %qs для перемикача %<-mtune=%>"
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "неправильне значення %qs для атрибуту %<target(\"tune=\")%>"
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "дійсні аргументи для перемикача %<-mtune=%> це: %s; ви мали на увазі %qs?"
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "дійсні аргументи для атрибуту %<target(\"tune=\")%> це: %s; ви мали на увазі %qs?"
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "дійсні аргументи для перемикача %<-mtune=%> це: %s"
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "дійсні аргументи для атрибуту %<target(\"tune=\")%> це: %s"
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "%<-mregparm%> ігнорується в 64-бітному режимі"
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "%<-mregparm%> ігнорується для Intel МКП psABI"
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, gcc-internal-format
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "%<-mregparm=%d%> не знаходиться між 0 і %d"
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "%<-m96bit-long-double%> несумісний з цією ціллю"
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> ігнорується в 64-бітному режимі"
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> ігнорується в 64-бітному режимі"
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr ""
@@ -41440,290 +41442,290 @@ msgstr ""
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr ""
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "%<-mpreferred-stack-boundary%> не підтримується для цієї цілі"
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> не знаходиться між %d і %d"
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "%<-mincoming-stack-boundary=%d%> не знаходиться між %d і 12"
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%<-mnop-mcount%> несумісний з цією ціллю"
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "%<-mnop-mcount%> не реалізований для %<-fPIC%>"
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> використовується без увімкненого SSE"
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> використовується без увімкненого SSE"
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "Набір інструкцій SSE вимкнено, використовується арифметика 387"
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "Набір інструкцій 387 вимкнено, використовується арифметика SSE"
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "Перевірка стеку потребує %<-maccumulate-outgoing-args%> для правильності"
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "Перевірка стеку потребує %<target(\"accumulate-outgoing-args\")%> для правильності"
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "Фіксований регістр ebp потребує %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "фіксований регістр ebp вимагає %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "%<-mfentry%> не підтримується для 32-біт в поєднанні з %<-fpic%>"
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "%<-mno-fentry%> несумісний з SEH"
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr "%<-mcall-ms2sysv-xlogues%> наразі не підтримується з SEH"
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "невідома опція для %<-mrecip=%s%>"
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs не є дійсним числом в %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr "%qs не є дійсним зсувом в %<-mstack-protector-guard-offset=%>"
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr "%qs не є дійсним базовим регістром в %<-mstack-protector-guard-reg=%>"
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr ""
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%<-fcf-protection%> несумісний з цільовою платформою"
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "атрибути interrupt та naked несумісні"
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "Атрибути %qs та %qs несумісні"
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr "тільки формат відлагодження DWARF підтримується для обробки переривань"
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> та %<-mcmodel=large%> несумісні"
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mindirect-branch%> та %<-fcf-protection%> несумісні"
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> та %<-mcmodel=large%> несумісні"
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr "%<-mfunction-return%> та %<-fcf-protection%> несумісні"
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr "інструкції %s не дозволені в обробнику винятків"
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "інструкції %s не дозволені в обробнику переривань"
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "інструкції %s не дозволені в функції з атрибутом %<no_caller_saved_registers%>"
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "атрибути fastcall і regparm несумісні"
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "атрибути regparam і thiscall несумісні"
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "атрибут %qE вимагає цілочисловий константний аргумент"
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "аргумент для атрибуту %qE більший за %d"
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "атрибути fastcall і cdecl несумісні"
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "атрибути fastcall і stdcall несумісні"
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "атрибути fastcall і thiscall несумісні"
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "атрибути stdcall і cdecl несумісні"
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "Атрибути stdcall та fastcall несумісні"
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "Атрибути stdcall та thiscall несумісні"
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "Атрибути cdecl та thiscall несумісні"
 
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "Атрибут %qE використовується для методу, що не належить до класу"
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "Несумісний атрибут %qE ігнорується"
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "Атрибут %qE доступний лише для 32-бітних систем"
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "Аргумент атрибуту %qE не є нулем або одиницею"
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "Атрибут %qE вимагає аргументом рядкову константу"
 
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "аргумент атрибуту %qE не є (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "переривання службового режиму повинно мати вказівник як перший аргумент"
 
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "переривання службового режиму повинно мати %qs як другий аргумент"
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "переривання службового режиму може мати лише аргумент вказівника та необовʼязковий аргумент цілого числа"
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "процедура обробки переривання повинна повертати %<void%>"
@@ -41916,48 +41918,48 @@ msgstr "непідтримуваний розмір операнда для ро
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "неціле значення операнда використовується з кодом операнда %<z%>"
 
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr "зміни ABI передачі параметрів порожнього класу %qT в %<-fabi-version=12%> (GCC 8)"
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr "вирівнювання полів %<_Atomic %T%> змінилося в %{GCC 11.1%}"
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, fuzzy, gcc-internal-format
 #| msgid "no low registers available for popping high registers"
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr "немає доступних нижніх регістрів для викидання високих регістрів"
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "профілювання %<-mcmodel=large%> з PIC не підтримується"
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, fuzzy, gcc-internal-format
 #| msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC V13, be careful of implicit conversion between %<__bf16%> and %<short%>; a explicit bitcast may be needed here"
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr "%<__bfloat16%> переозначено з typedef %<short%> на real %<__bf16%> після версії GCC V13, будьте обережні з неявним перетворенням між %<__bf16%> та %<short%>; можливо, тут потрібне явне побітове приведення"
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "невідома архітектура конкретної моделі памʼяті"
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr "%<HLE_ACQUIRE%> не використовується з %<ACQUIRE%> або більш сильною моделлю памʼяті"
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr "%<HLE_RELEASE%> не використовується з %<RELEASE%> або більш сильною моделлю памʼяті"
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr "%<-fexcess-precision=16%> несумісний з %<-mfpmath=387%>"
@@ -41977,8 +41979,8 @@ msgstr "визначення статичного елемента даних %q
 msgid "malformed %<#pragma builtin%>"
 msgstr "неправильно сформований %<#pragma builtin%>"
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, gcc-internal-format
 msgid "invalid argument of %qE attribute"
 msgstr "недійсний аргумент атрибуту %qE"
@@ -42033,12 +42035,12 @@ msgstr "%<PRINT_OPERAND%>: Невідомий розділовий знак %<%c
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr "%<PRINT_OPERAND%> нульовий вказівник"
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "аргумент %d вбудованої функції повинен бути константою в діапазоні від %d до %d"
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, gcc-internal-format
 msgid "failed to expand built-in function"
 msgstr "не вдалося розгорнути вбудовану функцію"
@@ -42168,17 +42170,17 @@ msgstr "модель коду %qs несумісна з %s"
 msgid "%qs cannot be used for compiling a shared library"
 msgstr "%qs не може бути використаний для компіляції спільної бібліотеки"
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr "атрибут %qE не може бути вказаний для змінних, локальних для потоку"
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for register variables"
 msgstr "атрибут %qE не може бути вказаний для регістрових змінних"
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, gcc-internal-format
 msgid "multiple %qE attribute"
 msgstr "множинний атрибут %qE"
@@ -42279,12 +42281,12 @@ msgstr "не дозволяються кілька атрибутів перер
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr "%<interrupt_thread%> доступний лише на fido"
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "вираз обмеження стеку не підтримується"
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not supported on this target"
 msgstr "%<-fexcess-precision=16%> не підтримується на цій цілі"
@@ -42325,7 +42327,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr "%<-mxl-multiply-high%> потребує %<-mno-xl-soft-mul%>"
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "Атрибут %qE вимагає рядковий аргумент"
@@ -42366,133 +42368,133 @@ msgstr "вектор переривання для атрибуту %qE не є
 msgid "argument to %qE attribute is not intstack"
 msgstr "аргумент для атрибуту %qE не є intstack"
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr "ABI для передачі значення, що містить поля нульової ширини перед суміжним 64-бітним полем з плаваючою комою, було змінено в GCC %{12.1%}"
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr "ABI для повернення значення, що містить поля бітів нульової ширини, але в іншому випадку агрегат з лише одним або двома полями з плаваючою комою, було змінено в GCC %{12.1%}"
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr "ABI для повернення значення з C++17 порожніми базами, але в іншому випадку агрегатом з одним або двома полями з плаваючою комою було змінено в GCC %{12.1%}"
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, gcc-internal-format
 msgid "cannot handle inconsistent calls to %qs"
 msgstr "не можу обробити неузгоджені виклики до %qs"
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr "атрибут %<interrupt%> вимагає процесор MIPS32r2 або вище"
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr "обробники переривань не можуть бути функціями MIPS16"
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr "%<-fstack-check=specific%> не реалізовано для MIPS16"
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, gcc-internal-format
 msgid "built-in function %qE not supported for MIPS16"
 msgstr "вбудована функція %qE не підтримується для MIPS16"
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, gcc-internal-format
 msgid "%qs does not support MIPS16 code"
 msgstr "%qs не підтримує код MIPS16"
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr "MIPS16 PIC для ABIs, відмінних від o32 та o64"
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, gcc-internal-format
 msgid "MIPS16 %<-mxgot%> code"
 msgstr "код MIPS16 %<-mxgot%>"
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, gcc-internal-format
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr "код MIPS16 з %<hard-float%> для ABIs, відмінних від o32 та o64"
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, gcc-internal-format
 msgid "MSA MIPS16 code"
 msgstr "код MSA MIPS16"
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr "%<-mno-gpopt%> потребує %<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported combination: %s"
 msgstr "непідтримувана комбінація: %s"
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, gcc-internal-format
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr "%<-%s%> конфліктує з іншими параметрами архітектури, які вказують процесор %s"
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, gcc-internal-format
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr "%<-march=%s%> несумісний з обраною ABI"
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr "%<-mgp64%> використовується з 32-бітним процесором"
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, gcc-internal-format
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr "%<-mgp32%> використовується з 64-бітним ABI"
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr "%<-mgp64%> використовується з 32-бітним ABI"
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "архітектура %qs не підтримує %<-mfp32%>"
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr "%<-mgp32%> і %<-mfp64%> можуть бути поєднані лише якщо цільова платформа підтримує інструкції mfhc1 та mthc1"
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr "%<-mgp32%> і %<-mfp64%> можуть бути поєднані лише при використанні ABI o32"
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr "%<-mfpxx%> може використовуватися лише з ABI o32"
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr "%<-march=%s%> вимагає %<-mfp32%>"
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr "%<-mfpxx%> вимагає %<-mlra%>"
@@ -42502,117 +42504,117 @@ msgstr "%<-mfpxx%> вимагає %<-mlra%>"
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, gcc-internal-format
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr "поєднання %qs та %qs несумісне з %qs"
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, gcc-internal-format
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr "архітектура %qs не підтримує інструкції з ймовірним гілком"
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, gcc-internal-format
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr "архітектура %qs не підтримує інструкції madd або msub"
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr "архітектура %qs не підтримує непарні регістри одинарної точності"
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, gcc-internal-format
 msgid "unsupported combination: %qs%s %s"
 msgstr "непідтримувана комбінація: %qs%s %s"
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, gcc-internal-format
 msgid "unsupported combination: %qs %s"
 msgstr "непідтримувана комбінація: %qs %s"
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, gcc-internal-format
 msgid "cannot generate position-independent code for %qs"
 msgstr "не вдається згенерувати позиційно-незалежний код для %qs"
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, gcc-internal-format
 msgid "position-independent code requires %qs"
 msgstr "позиційно-незалежний код вимагає %qs"
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr "%<-mno-gpopt%> потребує %<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr "не можна використовувати доступ до малих даних для %qs"
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr "архітектура %qs не підтримує %<-m%s=legacy%>"
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr "архітектура %qs не підтримує %<-m%s=2008%>"
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, gcc-internal-format
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr "%<-mips3d%> потребує %<-mpaired-single%>"
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, gcc-internal-format
 msgid "%qs must be used with %qs"
 msgstr "%qs повинно використовуватися з %qs"
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, gcc-internal-format
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr "%<-mmsa%> повинно використовуватися з %<-mfp64%> і %<-mhard-float%>"
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, gcc-internal-format
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr "архітектура %qs не підтримує інструкції з подвійною точністю"
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr "%qs потребує ціль, яка надає інструкцію %qs"
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, gcc-internal-format
 msgid "the %qs architecture does not support DSP instructions"
 msgstr "архітектура %qs не підтримує інструкції DSP"
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, gcc-internal-format
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr "%<-mloongson-mmi%> повинно використовуватися з %<-mhard-float%>"
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, gcc-internal-format
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr "%<-mloongson-ext2%> повинно використовуватися з %<-mloongson-ext%>"
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, gcc-internal-format
 msgid "%qs requires branch-likely instructions"
 msgstr "%qs вимагає інструкцій гілки з високою ймовірністю"
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, gcc-internal-format
 msgid "the %qs architecture does not support the synci instruction"
 msgstr "архітектура %qs не підтримує інструкцію synci"
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr "профілювання функцій mips16"
@@ -43482,61 +43484,61 @@ msgstr "%<#pragma riscv intrinsic%> вимагає рядковий параме
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "невідома опція %qs для %<#pragma riscv intrinsic%>"
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, gcc-internal-format
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, gcc-internal-format
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute is not supported on this machine"
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr "атрибут цільової платформи не підтримується на цій машині"
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<target()%> pragma or attribute"
 msgid "malformed %<target()%> attribute"
 msgstr "некоректна директива або атрибут %<target()%>"
 
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, fuzzy, gcc-internal-format
 #| msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "директива або атрибут %<target(\"%s\")%> не приймає аргумент"
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, fuzzy, gcc-internal-format
 #| msgid "unknown attribute %qs"
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr "невідомий атрибут %qs"
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgid "malformed %<target(\"%s\")%> attribute"
@@ -43598,188 +43600,212 @@ msgstr "не вдається кинути або перехопити тип RV
 msgid "capture by copy of RVV type %qT"
 msgstr "захоплення копією типу RVV %qT"
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, fuzzy, gcc-internal-format
+#| msgid "this definition requires the MVE ISA extension"
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr "ця визначення потребує розширення MVE ISA"
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, fuzzy, gcc-internal-format
+#| msgid "this definition requires the MVE ISA extension"
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr "ця визначення потребує розширення MVE ISA"
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, fuzzy, gcc-internal-format
+#| msgid "this definition requires the MVE ISA extension"
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr "ця визначення потребує розширення MVE ISA"
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, fuzzy, gcc-internal-format
+#| msgid "this definition requires the MVE ISA extension"
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr "ця визначення потребує розширення MVE ISA"
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, fuzzy, gcc-internal-format
 #| msgid "this definition requires the MVE ISA extension"
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr "ця визначення потребує розширення MVE ISA"
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%s(%A)%>"
 msgid "no matching function call to %qE with empty arguments"
 msgstr "немає відповідної функції для виклику %<%s(%A)%>"
 
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "невідомий процесор %qs для %<-mtune%>"
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, gcc-internal-format
 msgid "this operation requires the RVV ISA extension"
 msgstr "ця операція вимагає розширення RVV ISA"
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr "ви можете увімкнути RVV, використовуючи параметр командного рядка %<-march%>, або за допомогою атрибуту або прагми %<target%>"
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI для структури зі згладженими полями нульової довжини змінився в GCC 10"
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, fuzzy, gcc-internal-format
 #| msgid "SVE type %qT cannot be passed to an unprototyped function"
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr "Тип SVE %qT не може бути переданий у функцію без прототипу"
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, fuzzy, gcc-internal-format
 #| msgid "%qE requires the SVE ISA extension"
 msgid "%s %qT requires the V ISA extension"
 msgstr "%qE вимагає розширення SVE ISA"
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, fuzzy, gcc-internal-format
 #| msgid "%qE requires the SVE ISA extension"
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr "%qE вимагає розширення SVE ISA"
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, fuzzy, gcc-internal-format
 #| msgid "%qE requires the SVE ISA extension"
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr "%qE вимагає розширення SVE ISA"
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, fuzzy, gcc-internal-format
 #| msgid "%qE requires the SVE ISA extension"
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr "%qE вимагає розширення SVE ISA"
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, fuzzy, gcc-internal-format
 #| msgid "%qE requires the SVE ISA extension"
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr "%qE вимагає розширення SVE ISA"
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, fuzzy, gcc-internal-format
 #| msgid "%qs requires the %qs option and either the %qs or %qs option"
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr "%qs потребує опцію %qs, а також опцію %qs або %qs"
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, fuzzy, gcc-internal-format
 #| msgid "calls to functions of type %qT require the SVE ISA extension"
 msgid "function attribute %qs requires the V ISA extension"
 msgstr "виклики функцій типу %qT вимагають розширення SVE ISA"
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "аргумент атрибуту %qE не є %<\"user\"%>, %<\"supervisor\"%> або %<\"machine\"%>"
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr ""
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, fuzzy, gcc-internal-format
 #| msgid "%qs applied to non-SVE type %qT"
 msgid "%qs applied to non-RVV type %qT"
 msgstr "%qs застосовується до не-SVE типу %qT"
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, fuzzy, gcc-internal-format
 #| msgid "%qs requires an integer constant expression"
 msgid "%qs requires an integer constant"
 msgstr "%qs вимагає цілочисловий константний вираз"
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr "%<-mdiv%> вимагає %<-march%>, щоб підкоритися розширенню %<M%>"
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support ARM mode"
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr "цільовий процесор не підтримує режим ARM"
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs with %<-f%s%>"
 msgid "code model %qs with %qs"
 msgstr "модель коду %qs з %<-f%s%>"
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr "запитана ABI вимагає %<-march%>, щоб підкоритися розширенню %qc"
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr "rv32e вимагає ABI ilp32e"
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, fuzzy, gcc-internal-format
 #| msgid "rv32e requires ilp32e ABI"
 msgid "rv64e requires lp64e ABI"
 msgstr "rv32e вимагає ABI ilp32e"
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, fuzzy, gcc-internal-format
 #| msgid "z*inx requires ABI ilp32, ilp32e or lp64"
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr "z*inx вимагає ABI ilp32, ilp32e або lp64"
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "ABI вимагає %<-march=rv%d%>"
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "%<-mpreferred-stack-boundary=%d%> повинно бути між %d і %d"
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr "Атрибут RISC-V ELF %<-mriscv-attribute%> вимагає GNU as 2.32 [%<-mriscv-attribute%>]"
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs не є дійсним базовим регістром в %qs"
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs не є дійсним числом в %qs"
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "Функція %qs не може мати різний тип переривання"
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr "не вдається виділити регістр vl для %qs на цій цілі"
@@ -44029,32 +44055,32 @@ msgstr "вбудована функція %qs приймає лише 2 аргу
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "вбудована функція %qs приймає лише 3 аргументи"
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "%<vec_lvsl%> застаріла для маленького порядку байтів; використовуйте присвоєння для незвʼязаних завантажень та зберігань"
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "%<vec_lvsr%> застаріла для little endian; використовуйте присвоєння для незвичайних завантажень і зберігань"
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, gcc-internal-format
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr "передача аргументу %d з %qE видаляє кваліфікатор %qs з типу цілі вказівника"
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "недійсна комбінація параметрів для вбудованої функції AltiVec %qs"
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, gcc-internal-format
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr "перевантажена вбудована функція %qs реалізована вбудованою функцією %qs"
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, gcc-internal-format
 msgid "%qs is not supported in this compiler configuration"
 msgstr "%qs не підтримується в цій конфігурації компілятора"
@@ -44094,29 +44120,22 @@ msgstr "недійсне використання операнда MMA типу
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-вектор, переданий за посиланням: нестандартне розширення ABI без гарантії сумісності"
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, gcc-internal-format
-msgid "%qs requires the ELFv2 ABI"
-msgstr "%qs потребує ELFv2 ABI"
-
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "рамка стеку занадто велика"
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported number of nops before function entry (%u)"
 msgstr "непідтримувана кількість nops перед входом у функцію (%u)"
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%qs використовує регістр r29"
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr "Рамка стеку, більша за 2G, не підтримується для %<-fsplit-stack%>"
@@ -44241,107 +44260,118 @@ msgstr "%qs потребує дійсного базового регістру"
 msgid "unknown option for %<%s=%s%>"
 msgstr "невідома опція для %<%s=%s%>"
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4837
+#, fuzzy, gcc-internal-format
+#| msgid "%qs requires the ELFv2 ABI"
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr "%qs потребує ELFv2 ABI"
+
+#: config/rs6000/rs6000.cc:4855
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs застарілий і не рекомендується в будь-яких обставинах"
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr "%qs є непрозорим типом, і ви не можете встановити його на інші значення"
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "немає профілювання 64-бітного коду для цієї ABI"
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "ви не можете отримати адресу вкладеної функції, якщо ви використовуєте опцію %qs"
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "використання %<long double%> в типах AltiVec є недійсним"
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "використання булевих типів у типах AltiVec є недійсним"
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "використання %<complex%> у типах AltiVec є недійсним"
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "використання десяткових типів з плаваючою комою у типах AltiVec є недійсним"
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "використання %<long%> у типах AltiVec є недійсним для 64-бітного коду без %qs"
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "використання %<long%> у типах AltiVec застаріло; використовуйте %<int%>"
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "використання %<long long%> у типах AltiVec є недійсним без %qs"
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "використання %<double%> у типах AltiVec є недійсним без %qs"
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "недійсний процесор %qs для %s%qs%s"
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s заборонено"
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s є недійсним"
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> вимикає %<-m%s%>"
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "атрибут %<target_clones%> потребує GLIBC (2.23 або новіше), яка експортує біти можливостей апаратного забезпечення"
 
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Мультиверсіювання віртуальних функцій не підтримується"
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr "результат інструкції xxspltidp не визначений для піднормальних значень введення"
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "тип %<__vector_quad%> вимагає опцію %qs"
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr "тип %<__vector_pair%> вимагає опцію %qs"
@@ -44386,7 +44416,7 @@ msgstr "Інструкції RX FPU не підтримують NaN та нес
 msgid "builtin %qs can only be used on vector types"
 msgstr "вбудована функція %qs може бути використана лише для векторних типів"
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "потрібне константне значення для вбудованого аргументу %qF %d"
@@ -44456,228 +44486,228 @@ msgstr "варіант %qs застарілий"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "константний аргумент %d для вбудованої функції %qF виходить за межі діапазону цільового типу"
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr "константний аргумент %d для вбудованої функції %qF недійсний (%s)"
 
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr "константний аргумент %d для вбудованої функції %qF виходить за межі діапазону (0-%wu)"
 
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr "константний аргумент %d для вбудованої функції %qF виходить за межі діапазону (%wd-%wd)"
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr "вбудована функція %qF не підтримується без %<-mhtm%> (за замовчуванням з %<-march=zEC12%> і вище)"
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr "вбудована функція %qF вимагає %<-mvx%> (за замовчуванням з %<-march=z13%> і вище)"
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher"
 msgstr "Вбудована функція %qF вимагає z14 або вище"
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher"
 msgstr "Вбудована функція %qF вимагає z15 або вище"
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "нерозрішена перевантажена вбудована функція"
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "неправильний вбудований icode"
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "недійсний аргумент %d для вбудованої функції %qF"
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "запитана атрибут %qE не є комами розділеними парами невідʼємних цілих констант або занадто велика (макс. %d)"
 
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "аргумент для атрибуту %qE не є (keep|thunk|thunk-extern)"
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "загальний розмір локальних змінних перевищує обмеження архітектури"
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr "розмір фрейму функції %qs становить %wd байт, що перевищує обмеження стеку, надане користувачем, у %d байтів; додається безумовна пастка"
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr "розмір фрейму функції %qs становить %wd байт, що більше, ніж половина розміру стеку; динамічна перевірка не буде надійною; для цієї функції не випускається перевірка"
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "розмір фрейму %qs становить %wd байтів"
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs використовує динамічне виділення стеку"
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr "передача параметрів для аргументу типу %qT зі зміненими членами полів бітів нульової ширини в GCC 12"
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "вкладені функції не можуть бути профілювані з %<-mfentry%> на s390"
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-бітний ABI не підтримується в режимі ESA/390"
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr "thunk-inline підтримується тільки з %<-mindirect-branch-jump%>"
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "підтримка апаратного вектора недоступна на %s"
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "підтримка апаратного вектора недоступна з %<-msoft-float%>"
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr "апаратні інструкції з десятковою плаваючою комою недоступні на %s"
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, gcc-internal-format
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr "апаратні інструкції з десятковою плаваючою комою недоступні в режимі ESA/390"
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr "%<-mhard-dfp%> не може використовуватися разом з %<-msoft-float%>"
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, gcc-internal-format
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> не підтримуються в поєднанні"
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "розмір стеку повинен бути більшим за значення захисту стеку"
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "розмір стеку не повинен перевищувати 64к"
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "%<-mstack-guard%> передбачає використання %<-mstack-size%>"
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr "%<-mtpf-trace-hook-prologue-check%> вимагає цілочисельне в діапазоні від 0 до 4095"
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr "%<-mtpf-trace-hook-prologue-target%> вимагає цілочисельне в діапазоні від 0 до 4095"
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr "%<-mtpf-trace-hook-epilogue-check%> вимагає цілочисельне в діапазоні від 0 до 4095"
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr "%<-mtpf-trace-hook-epilogue-target%> вимагає цілочисельне в діапазоні від 0 до 4095"
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%<-mfentry%> підтримується лише для 64-бітних процесорів"
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "аргументи для %qs повинні бути невідʼємними цілими числами"
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "аргумент для %qs занадто великий (макс. %d)"
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr "%<-mno-pic-data-is-text-relative%> не може бути використаний без %<-fpic%>/%<-fPIC%>"
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, gcc-internal-format
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr "аргумент %qs атрибуту %<target%> невідомий"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "значення %qs не підтримується атрибутом %<target%>"
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints"
 msgid "invalid cc output constraint: %qs"
 msgstr "недійсні обмеження"
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, fuzzy, gcc-internal-format
 #| msgid "double constants not supported"
 msgid "multiple cc output constraints not supported"
 msgstr "подвійні константи не підтримуються"
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, fuzzy, gcc-internal-format
 #| msgid "%<asm%> specifier for variable %qE conflicts with %<asm%> clobber list"
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr "специфікатор %<asm%> для змінної %qE конфліктує зі списком %<asm%> clobber"
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for make function"
 msgid "invalid type for cc output constraint"
@@ -45100,8 +45130,8 @@ msgstr "атрибут %qE не має ефекту"
 msgid "attribute %qs applies to array types only"
 msgstr "атрибут %qs застосовується тільки до типів масивів"
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "значення void не ігнорується так, як повинно бути"
@@ -45176,7 +45206,7 @@ msgstr "Тип масиву %q+D завершено несумісно з нея
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr "Недостатньо визначена декларація %qE, яка вже оголошена в цій області видимості"
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "початково визначено тут"
@@ -45409,7 +45439,7 @@ msgstr "Декларація %q+D затіняє попередню незмін
 msgid "declaration of %qD shadows a parameter"
 msgstr "Декларація %qD затіняє параметр"
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "Декларація %qD затіняє глобальну декларацію"
@@ -45419,7 +45449,7 @@ msgstr "Декларація %qD затіняє глобальну деклар
 msgid "declaration of %qD shadows a previous local"
 msgstr "Декларація %qD затіняє попередній локальний ідентифікатор"
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "Затінене оголошення знаходиться тут"
@@ -45484,7 +45514,7 @@ msgstr "%qE неоголошений (перше використання в ц
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "кожен не оголошений ідентифікатор повідомляється лише один раз для кожної функції, в якій він зʼявляється"
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "мітка %qE використовується поза будь-якою функцією"
@@ -45519,7 +45549,7 @@ msgstr "перехід до виразу заяви"
 msgid "duplicate label declaration %qE"
 msgstr "повторна декларація мітки %qE"
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "повторна мітка %qD"
@@ -45555,7 +45585,7 @@ msgstr "перехід у switch до виразу заяви"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE визначено як неправильний тип тегу"
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "атрибут %qE застосовується до %qD з типом повернення void"
@@ -45697,12 +45727,12 @@ msgstr "ISO C90 не підтримує декларатори масиву %<[*
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> дозволено тільки в області прототипу функції"
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, fuzzy, gcc-internal-format
 #| msgid "%<omp::%E%> not allowed to be specified in this context"
 msgid "%<omp::%s%> not allowed to be specified in this context"
@@ -45713,7 +45743,7 @@ msgstr "%<omp::%E%> не може бути вказано в цьому конт
 msgid "%q+D is usually a function"
 msgstr "%q+D зазвичай є функцією"
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "немає попередньої декларації для %qD"
@@ -45789,7 +45819,7 @@ msgstr "не можна помістити обʼєкт з волатильни
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "незініціалізований %<const %D%> недійсний у C++"
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D у директиві «declare target» не має відображального типу"
@@ -45974,7 +46004,7 @@ msgstr "вказано клас зберігання для параметра %
 msgid "storage class specified for unnamed parameter"
 msgstr "вказано клас зберігання для безіменного параметра"
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "вказано клас зберігання для typename"
@@ -46037,7 +46067,7 @@ msgstr "оголошення %qE як масиву з функціями"
 msgid "declaration of type name as array of functions"
 msgstr "оголошення типу як масиву з функцій"
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "недійсне використання структури з гнучким елементом масиву"
@@ -46143,7 +46173,7 @@ msgstr "імʼя типу оголошено як функцію, що пове
 msgid "function definition has qualified void return type"
 msgstr "визначення функції має кваліфікований тип повернення void"
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "кваліфікатори типу ігноруються для типу повернення функції"
@@ -46270,7 +46300,7 @@ msgstr "ISO C забороняє типи функцій const або volatile"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "елемент структури або обʼєднання не може мати змінюваний тип"
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "змінна або поле %qE оголошено як void"
@@ -46376,7 +46406,7 @@ msgstr "не-нестована функція з типом, який може
 msgid "object with variably modified type must have no linkage"
 msgstr "обʼєкт з типом, який може змінюватися, не може мати звʼязку"
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "оголошення функції не є прототипом"
@@ -46466,17 +46496,17 @@ msgstr "вкладене перевизначення %<union %E%>"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "вкладене перевизначення %<struct %E%>"
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "визначення типу в виразі %qs недійсне в C++"
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, gcc-internal-format
 msgid "%qT defined in underspecified object initializer"
 msgstr "%qT визначено в недостатньому ініціалізаторі обʼєкта"
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "оголошення нічого не оголошує"
@@ -46506,609 +46536,609 @@ msgstr "порожня структура має розмір 0 в C, розмі
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr "порожнє обʼєднання має розмір 0 в C, розмір 1 в C++"
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "обʼєднання не має іменованих членів"
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "обʼєднання не має членів"
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "структура не має іменованих членів"
 
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "структура не має членів"
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "гнучкий масив як член обʼєднання"
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "гнучкий масив не є останнім членом структури"
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "гнучкий масив як член структури без іменованих членів"
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr "гнучкий масив не є останнім членом структури"
 
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "тип %qT занадто великий"
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, gcc-internal-format
 msgid "type punning toggles scalar storage order"
 msgstr "типове перетворення змінює порядок зберігання скалярних значень"
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "обʼєднання не може бути зроблене прозорим"
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of typedef %q+D with variably modified type"
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr "перевизначення typedef %q+D зі зміненим типом"
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %<struct %E%>"
 msgid "redefinition of struct or union %qT"
 msgstr "перевизначення %<struct %E%>"
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "вкладене перевизначення %<enum %E%>"
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "перевизначення %<enum %E%>"
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr "%<enum%> оголошено з, але визначено без фіксованого базового типу"
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr "вказаний режим занадто малий для перелічованих значень"
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "значення перелічування перевищують діапазон найбільшого цілого числа"
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, gcc-internal-format
 msgid "enumeration values exceed range of %qs"
 msgstr "значення перелічування перевищують діапазон %qs"
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of %<enum %E%>"
 msgid "conflicting redefinition of enum %qT"
 msgstr "вкладене перевизначення %<enum %E%>"
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "значення перелічування для %qE не є цілочисельною константою"
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "значення перелічування для %qE не є цілочисельним константним виразом"
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "переповнення в значеннях перелічування"
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, gcc-internal-format
 msgid "enumerator value outside the range of underlying type"
 msgstr "значення перелічування знаходиться поза діапазоном базового типу"
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, gcc-internal-format
 msgid "enumerator value outside the range of %qs"
 msgstr "значення перелічування поза діапазоном %qs"
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr "ISO C обмежує значення перелічування діапазоном %<int%> до C2X"
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "вбудованій функції %qD надано атрибут %qs"
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "тип повернення є неповним типом"
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "тип повернення за замовчуванням - %<int%>"
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "%q+D визначено як варіативну функцію без прототипу"
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "немає попереднього прототипу для %qD"
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD використовувався без прототипу перед його визначенням"
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD було використано без попередньої декларації перед його визначенням"
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "тип повернення %qD не є %<int%>"
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "тип повернення %qD з кваліфікатором %<_Atomic%>"
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD зазвичай є нестатичною функцією"
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "старомодні оголошення параметрів у прототипі функції"
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "традиційне C відкидає визначення функцій у стилі ISO C"
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support omitting parameter names in function definitions before C2X"
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr "ISO C не підтримує пропуск імен параметрів у визначеннях функцій до C2X"
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "визначення функції у старому стилі"
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "відсутнє імʼя параметра у списку параметрів"
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD оголошено як непараметр"
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "декілька параметрів з іменем %qD"
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "параметр %qD оголошено з типом void"
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "тип %qD за замовчуванням - %<int%>"
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "параметр %qD має неповний тип"
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "оголошення для параметра %qD, але такого параметра немає"
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "кількість аргументів не відповідає вбудованому прототипу"
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "кількість аргументів не відповідає прототипу"
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "оголошення прототипу"
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "піднятий аргумент %qD не відповідає вбудованому прототипу"
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "переданий аргумент %qD не відповідає прототипу"
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "аргумент %qD не відповідає вбудованому прототипу"
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD не відповідає прототипу"
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "в функції, що повертає не void, відсутня інструкція return"
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "параметр %qD встановлено, але не використовується"
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "початкові оголошення циклу %<for%> дозволені лише в режимі C99 або C11"
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "використовуйте опцію %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> або %<-std=gnu11%> для компіляції вашого коду"
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, gcc-internal-format
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 не підтримує початкові оголошення циклу %<for%>"
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "оголошення статичної змінної %qD в початковому оголошенні циклу %<for%>"
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "оголошення %<extern%> змінної %qD в початковому оголошенні циклу %<for%>"
 
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> оголошено в початковому оголошенні циклу %<for%>"
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> оголошено в початковій декларації циклу %<for%>"
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> оголошено в початковій декларації циклу %<for%>"
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "оголошення незмінної %qD в початковій декларації циклу %<for%>"
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "несумісні кваліфікатори простору адрес %qs та %qs"
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "подвійний специфікатор оголошення %qE"
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "декілька класів зберігання в специфікаторах оголошення"
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, gcc-internal-format
 msgid "%qs used with %<auto%>"
 msgstr "%qs використовується з %<auto%>"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, gcc-internal-format
 msgid "%<auto%> used with %<constexpr%>"
 msgstr "%<auto%> використовується з %<constexpr%>"
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "два або більше типи даних в специфікаторах оголошення"
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> занадто довгий для GCC"
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 не підтримує %<long long%>"
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 не підтримує складні типи"
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C не підтримує насичені типи"
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "подвійне %qE"
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C не підтримує типи %<__int%d%>"
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> не підтримується на цій платформі"
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 не підтримує булеві типи"
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support the %<_Float%d%s%> type"
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr "ISO C не підтримує тип %<_Float%d%s%>"
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<_Float%d%s%> не підтримується для цільової платформи"
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating-point before C2X"
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr "ISO C не підтримує десяткові дробові числа до C2X"
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "фіксовані точкові типи не підтримуються для цільової платформи"
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C не підтримує типи з фіксованою комою"
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, fuzzy, gcc-internal-format
 #| msgid "case label is not an integer constant expression"
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr "мітка case не є цілочисельним константним виразом"
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant expression"
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr "значення перелічування для %qE не є цілочисельним константним виразом"
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr ""
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "Пошук %qD в C++ поверне поле, а не тип"
 
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE не є typedef або вбудованим типом"
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE не знаходиться на початку оголошення"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE використовується з %<auto%>"
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE використовується з %<register%>"
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE використовується з %<typedef%>"
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, gcc-internal-format
 msgid "%qE used with %<constexpr%>"
 msgstr "%qE використовується з %<constexpr%>"
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 не підтримує %qE"
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 не підтримує %qE"
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> перед %<extern%>"
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> перед %<static%>"
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, gcc-internal-format
 msgid "%<typedef%> used with %<auto%>"
 msgstr "%<typedef%> використовується з %<auto%>"
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, gcc-internal-format
 msgid "%qE used with %<extern%>"
 msgstr "%qE використовується з %<extern%>"
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, gcc-internal-format
 msgid "%qE used with %qs"
 msgstr "%qE використовується з %qs"
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "подвійне використання %<_Thread_local%> або %<__thread%>"
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs використовується з %qE"
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, gcc-internal-format
 msgid "%<constexpr%> used with %qE"
 msgstr "%<constexpr%> використовується з %qE"
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> використовується без %<_Fract%> або %<_Accum%>"
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не підтримує просте значення %<complex%>, що означає %<double complex%>"
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support %<auto%> type deduction before C2X"
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr "ISO C не підтримує виведення типу %<auto%> до C2X"
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr "%<__auto_type%>, за яким слідують атрибути %<[[]]%>"
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C не підтримує комплексні цілі типи"
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, fuzzy, gcc-internal-format
 #| msgid "Fixed line length must be at least seven"
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr "Фіксована довжина рядка повинна бути щонайменше сім"
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr "ISO C++ не підтримує %<__int%d%> для %qs"
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "%<#pragma omp declare reduction%> комбінатор посилається на змінну %qD, яка не є %<omp_out%> або %<omp_in%>"
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "%<#pragma omp declare reduction%> ініціалізатор посилається на змінну %qD, яка не є %<omp_priv%> або %<omp_orig%>"
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "зсув вліво відʼємного значення"
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "лічильник зсуву вліво є відʼємним"
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "лічильник зсуву вправо є відʼємним"
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "лічильник зсуву вліво >= ширини типу"
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "лічильник зсуву вправо >= ширини типу"
@@ -47138,7 +47168,7 @@ msgstr "маркер конфлікту контролю версій у фай
 msgid "to match this %qs"
 msgstr "щоб відповідати цьому %qs"
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "очікуваний кінець рядка"
@@ -47148,8 +47178,8 @@ msgstr "очікуваний кінець рядка"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C забороняє порожній переклад"
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr "%qs без відповідного %qs"
@@ -47189,9 +47219,9 @@ msgstr "невідоме імʼя типу %qE; мали на увазі %qs?"
 msgid "unknown type name %qE"
 msgstr "невідоме імʼя типу: %qE"
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "очікувані специфікатори декларації"
@@ -47221,7 +47251,7 @@ msgstr "атрибут %<fallthrough%> на верхньому рівні"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "очікується %<;%>, ідентифікатор або %<(%>"
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "префіксні атрибути ігноруються для методів"
@@ -47241,7 +47271,7 @@ msgstr "неочікуваний атрибут"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "атрибут %<fallthrough%> не слідує за %<;%>"
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, gcc-internal-format
 msgid "%<assume%> attribute not followed by %<;%>"
 msgstr "атрибут %<assume%> не слідує за %<;%>"
@@ -47332,7 +47362,7 @@ msgstr "вираз в статичному твердженні не є стал
 msgid "static assertion failed: %E"
 msgstr "статична перевірка не вдалася: %E"
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "статична перевірка не вдалася"
@@ -47404,10 +47434,10 @@ msgstr "порожнє перелічування недійсне"
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "очікуваний ідентифікатор"
@@ -47564,7 +47594,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr "умову %<nogroup%> не слід використовувати разом з умовою %<reduction%>"
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr "змішування директив OpenMP з атрибутами та синтаксисом pragma в одному операторі"
@@ -47575,8 +47605,8 @@ msgstr "змішування директив OpenMP з атрибутами т
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr "атрибут %<omp::%E%> вимагає аргумент"
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, fuzzy, gcc-internal-format
 #| msgid "unknown OpenMP directive name in %qs clause argument"
 msgid "unknown OpenMP directive name in %qs attribute argument"
@@ -47751,12 +47781,12 @@ msgstr "ISO C забороняє опускати середній термін
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr "ділення %<sizeof (%T) / sizeof (%T)%> не обчислює кількість елементів масиву"
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "перший операнд %<sizeof%> був оголошений тут"
@@ -47903,7 +47933,7 @@ msgstr "ISO C90 не підтримує попередньо визначени
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, gcc-internal-format
 msgid "expected expression"
 msgstr "очікується вираз"
@@ -48230,12 +48260,12 @@ msgstr "очікується оголошення методу objective-c"
 msgid "no type or storage class may be specified here,"
 msgstr "тут не може бути вказано тип або клас зберігання,"
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, gcc-internal-format
 msgid "empty property attribute list"
 msgstr "порожній список атрибутів властивості"
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, gcc-internal-format
 msgid "missing property attribute"
 msgstr "відсутній атрибут властивості"
@@ -48245,57 +48275,57 @@ msgstr "відсутній атрибут властивості"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "невідомий атрибут властивості %<%s%s%>"
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "невідомий атрибут властивості"
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "очікується %<=%> після Objective-C %qE"
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr "очікується назва селектора %qE"
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr "назви методів-сеттерів повинні закінчуватися на %<:%>"
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> вимагає виразу присвоєння, який обчислюється до невідʼємної цілочисельнної константи менше %u"
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr ""
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> може використовуватися тільки в складних операторах"
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> повинно бути на рівні файлу"
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp scan%> може використовуватися тільки в цикловій конструкції з замиканням %<inscan%> %<reduction%>"
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> може використовуватись тільки в конструкції %<#pragma omp sections%>"
@@ -48305,25 +48335,25 @@ msgstr "%<#pragma omp section%> може використовуватись ті
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr "%<#pragma %s%> може використовуватись тільки на рівні файлу"
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "очікується оператор for, while або do"
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> повинно бути першим"
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "забагато замиканнь %qs"
@@ -48338,64 +48368,64 @@ msgstr "вираз повинен бути цілочисельним"
 msgid "expected %<)%> or %<,%>"
 msgstr "очікується %<)%> або %<,%>"
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD не є змінною"
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD не є змінною-вказівником"
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "аргумент «collapse» потребує позитивний сталий цілочисельний вираз"
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "очікується %<none%> або %<present%>"
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, gcc-internal-format
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr "очікувався %<none%>, %<shared%>, %<private%> або %<firstprivate%>"
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, fuzzy, gcc-internal-format
 #| msgid "expected goto expression"
 msgid "expected constant logical expression"
 msgstr "очікуваний вираз «goto»"
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "очікувався %<data%>, %<update%>, %<enter%> або %<exit%>"
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "очікувався %<data%>"
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "занадто багато %<if%> замиканнь з модифікатором %qs"
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "занадто багато %<if%> замиканнь"
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "занадто багато %<if%> замиканнь без модифікатора"
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "якщо будь-яке %<if%> замикання має модифікатор, то всі %<if%> замикання повинні використовувати модифікатор"
@@ -48418,22 +48448,22 @@ msgstr "значення %<num_threads%> повинно бути позитив
 msgid "%<num_tasks%> value must be positive"
 msgstr "значення %<num_tasks%> повинно бути позитивним"
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "Значення %<grainsize%> повинно бути позитивним"
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "Значення %<priority%> повинно бути не відʼємним"
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "очікується константний цілочисельний вираз з дійсним значенням sync-hint"
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "очікується %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> або %<default%>"
@@ -48444,95 +48474,95 @@ msgstr "очікується %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstpri
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr "очікується %<scalar%>, %<aggregate%> або %<pointer%>"
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "занадто багато замиканнь %<defaultmap%> з категорією %qs"
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "занадто багато замиканнь %<defaultmap%> з невизначеною категорією"
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "вираз %qs повинен бути цілочисельним"
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "значення %qs повинно бути позитивним"
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "забагато аргументів %<static%>"
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "неочікуваний аргумент"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "аргумент %<tile%> повинен бути додатньою цілочисельною константою"
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses"
 msgid "too many %<self%> clauses"
 msgstr "занадто багато %<if%> замиканнь"
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, gcc-internal-format
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr "очікується %<reproducible%> або %<unconstrained%>"
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "очікується %<concurrent%>"
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "очікується %<teams%>, %<parallel%> або %<thread%>"
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "аргумент %<ordered%> повинен бути позитивним цілим виразом"
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "очікується %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> або ідентифікатор"
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "вказано обидва модифікатори %<monotonic%> і %<nonmonotonic%>"
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "розклад %<runtime%> не приймає параметр %<chunk_size%>"
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "розклад %<auto%> не приймає параметр %<chunk_size%>"
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "значення розміру частини повинно бути позитивним"
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "недійсний тип розкладу"
@@ -48542,22 +48572,22 @@ msgstr "недійсний тип розкладу"
 msgid "%<num_teams%> value must be positive"
 msgstr "значення %<num_teams%> повинно бути позитивним"
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr "нижня межа %qE для %<num_teams%> більша за верхню межу %qE"
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "значення %<thread_limit%> повинно бути позитивним"
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "вираз вирівнювання для замикання %<aligned%> повинен бути позитивним сталим цілочисельним виразом"
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, gcc-internal-format
 msgid "expected %<allocator%> or %<align%>"
 msgstr "очікується %<allocator%> або %<align%>"
@@ -48567,22 +48597,22 @@ msgstr "очікується %<allocator%> або %<align%>"
 msgid "duplicate %qs modifier"
 msgstr "подвійний модифікатор %qs"
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr "вираз алокатора в замиканні %<allocate%> має тип %qT, а не %<omp_allocator_handle_t%>"
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, gcc-internal-format
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr "аргумент модифікатора %<align%> в замиканні %<allocate%> має бути позитивним константним цілочисельним виразом, яке є степенем двійки"
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, gcc-internal-format
 msgid "multiple linear modifiers"
 msgstr "декілька модифікаторів linear"
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, gcc-internal-format
 msgid "multiple %<step%> modifiers"
 msgstr "декілька модифікаторів %<step%>"
@@ -48602,64 +48632,64 @@ msgstr "вираз в замиканні %<safelen%> має бути позит
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "вираз в замиканні %<simdlen%> має бути позитивним константним цілочисельним"
 
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "Модифікатор %<iterator%> несумісний з %qs"
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "Недійсний тип залежності"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, gcc-internal-format
 msgid "invalid doacross kind"
 msgstr "Недійсний тип doacross"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, gcc-internal-format
 msgid "too many %<always%> modifiers"
 msgstr "Забагато модифікаторів %<always%>"
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, gcc-internal-format
 msgid "too many %<close%> modifiers"
 msgstr "Забагато модифікаторів %<close%>"
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<close%> modifiers"
 msgid "too many %<present%> modifiers"
 msgstr "Забагато модифікаторів %<close%>"
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp target%> with modifier other than %<always%> or %<close%> on %<map%> clause"
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr "%<#pragma omp target%> з модифікатором, відмінним від %<always%> або %<close%>, на замиканні %<map%>"
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "Недійсний тип відображення"
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr "Модифікатор пристрою %<ancestor%> не передує директиві %<requires%> з замиканням %<reverse_offload%>"
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, gcc-internal-format
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr "очікувався %<ancestor%> або %<device_num%>"
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, gcc-internal-format
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr "вираз у замиканні %<device%> повинен обчислюватися як %<1%>"
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "недійсний тип розподілу розкладу"
@@ -48674,90 +48704,90 @@ msgstr "недійсний тип привʼязки процесу"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "очікується %<host%>, %<nohost%> або %<any%>"
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr "тип обробника події в замиканні %<detach%> - %qT, а не %<omp_event_handle_t%>"
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, fuzzy, gcc-internal-format
 #| msgid "expected assumption clause"
 msgid "expected an OpenACC clause"
 msgstr "очікується замикання припущення"
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs недійсний для %qs"
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr "замикання в режимі %<simd%> повинні бути розділені комою %<,%>"
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs повинен бути першою замиканням %qs"
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, fuzzy, gcc-internal-format
 #| msgid "expected assumption clause"
 msgid "expected an OpenMP clause"
 msgstr "очікується замикання припущення"
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "не вказано жодних дійсних замикань в %<#pragma acc declare%>"
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "секція масиву в %<#pragma acc declare%>"
 
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD повинна бути глобальною змінною в %<#pragma acc declare link%>"
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "недійсне замикання OpenACC у межах файлу"
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "недійсне використання %<extern%> змінної %qD в %<#pragma acc declare%>"
 
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "недійсне використання %<global%> змінної %qD в %<#pragma acc declare%>"
 
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "%qD повинна бути змінною, оголошеною в тому ж області, що й %<#pragma acc declare%>"
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "змінна %qD використовується більше одного разу з %<#pragma acc declare%>"
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "мало бути %<data%> після %<#pragma acc %s%>"
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> не має замикання переміщення даних"
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr ""
@@ -48772,7 +48802,7 @@ msgstr "%qE не було оголошено"
 msgid "expected function name"
 msgstr "мало бути вказано назву функції"
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD не посилається на функцію"
@@ -48782,22 +48812,22 @@ msgstr "%qD не посилається на функцію"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> не негайно слідує за декларацією або визначенням функції"
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> не негайно слідує за однією декларацією або визначенням функції"
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> має бути застосовано до використання"
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> має бути застосовано до визначення"
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> повинен містити принаймні одну замикання %<device%> або %<host%> або %<self%>"
@@ -48825,7 +48855,7 @@ msgstr ""
 msgid "modified here"
 msgstr "визначено тут"
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, gcc-internal-format
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
 msgstr "аргумент замикання %<align%> повинен бути позитивним сталим виразом цілого числа, яке є степенем двійки"
@@ -48870,112 +48900,112 @@ msgstr "замикання %<allocate%> повинна вказувати ало
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr "%<#pragma omp allocate%> ще не підтримується"
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "очікується замикання %<read%>, %<write%>, %<update%> або %<capture%>"
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr "очікується %<seq_cst%>, %<acquire%> або %<relaxed%>"
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "очікується замикання %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> або %<hint%>"
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "занадто багато атомних замикання"
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "занадто багато замиканнь порядку памʼяті"
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, gcc-internal-format
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr "замикання %qs несумісне з замиканнями %<read%> або %<write%>"
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, gcc-internal-format
 msgid "%qs clause requires %qs clause"
 msgstr "замикання %qs потребує замикання %qs"
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr "%<#pragma omp atomic write%> несумісний з замиканням %<acquire%>"
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr "%<#pragma omp atomic read%> несумісний з замиканням %<release%>"
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr "%<#pragma omp atomic read%> несумісний з замиканням %<release%>"
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr "%<#pragma omp atomic write%> несумісний з замиканням %<acquire%>"
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, gcc-internal-format
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr "очікується порівняння %<==%> в умові %<if%>"
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, gcc-internal-format
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr "очікується порівняння %<==%>, %<<%> або %<>%> в умові %<if%>"
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr "неправильна форма %<#pragma omp atomic compare%>"
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, gcc-internal-format
 msgid "unexpected %<else%>"
 msgstr "неочікуваний %<else%>"
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, gcc-internal-format
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr "неправильна форма %<pragma omp atomic compare%>"
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "неправильна форма %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "неправильний оператор для %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr "замикання %<weak%> вимагає атомарного порівняння на рівність"
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> використовує два різних вирази для памʼяті"
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "Вираз %<depobj%> не є виразом lvalue"
@@ -48986,27 +49016,27 @@ msgstr "Вираз %<depobj%> не є виразом lvalue"
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr "Вираз %<depobj%> не є виразом lvalue"
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr ""
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, gcc-internal-format
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr "очікується %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> або %<inoutset%>"
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "очікується замикання %<depend%>, %<destroy%> або %<update%>"
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "очікується %<seq_cst%>, %<acq_rel%>, %<release%> або %<acquire%>"
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr "список %<flush%> вказано разом з замиканням порядку памʼяті"
@@ -49016,170 +49046,170 @@ msgstr "список %<flush%> вказано разом з замиканням
 msgid "expected %<(%> or end of line"
 msgstr "очікується %<(%> або кінець рядка"
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr "%<[[omp::directive(%s)]]%> повинен бути єдиним вказаним атрибутом в операторі"
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr "%<#pragma omp ordered%> з %qs замиканням може використовуватися лише в складних операторах"
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "очікується замикання %<inclusive%> або %<exclusive%>"
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "очікується %<#pragma omp scan%>"
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr "%<#pragma omp ordered%> з %qs замиканням може використовуватися лише в складних операторах"
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "очікувалася оголошення або ініціалізація ітерації"
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, fuzzy, gcc-internal-format
 #| msgid "not enough perfectly nested loops"
 msgid "not enough nested loops"
 msgstr "недостатньо добре вкладених циклів"
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "параметр замикання %<ordered%> менше, ніж %<collapse%>"
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "очікувалася конструкція for"
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "змінна ітерації %qD не повинна бути firstprivate"
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> з %qs замиканням може використовуватися лише в складних операторах"
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "очікувався %<for%> після %qs"
 
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "очікувався %<point%>"
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> з типом відображення, відмінним від %<to%>, %<from%>, %<tofrom%> або %<alloc%> на замиканні %<map%>"
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp target data%> повинен містити принаймні одну замикання %<map%>, %<use_device_ptr%> або %<use_device_addr%>"
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> повинен містити принаймні одну замикання %<from%> або %<to%>"
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> з типом відображення, відмінним від %<to%>, %<tofrom%> або %<alloc%> на замиканні %<map%>"
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> повинен містити принаймні одну замикання %<map%>"
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> з типом відображення, відмінним від %<from%>, %<tofrom%>, %<release%> або %<delete%> на замиканні %<map%>"
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> повинен містити принаймні одну замикання %<map%>"
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> з типом відображення, відмінним від %<to%>, %<from%>, %<tofrom%> або %<alloc%> на замиканні %<map%>"
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp declare %s%> повинен бути відстежений декларацією або визначенням функції або іншим %<#pragma omp declare %s%>"
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> повинен бути відстежений декларацією або визначенням функції"
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "очікуване імʼя селектора ознаки"
 
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, fuzzy, gcc-internal-format
 #| msgid "selector %qs not allowed for context selector set %qs"
 msgid "unknown selector %qs for context selector set %qs"
 msgstr "селектор %qs не дозволений для набору селекторів контексту %qs"
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "селектор %qs не приймає жодних властивостей"
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr "%<friend%> може бути вказано лише всередині класу"
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, fuzzy, gcc-internal-format
 #| msgid "score argument must be constant integer expression"
 msgid "%<score%> argument must be constant integer expression"
 msgstr "аргумент score повинен бути цілим сталим виразом"
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, fuzzy, gcc-internal-format
 #| msgid "score argument must be non-negative"
 msgid "%<score%> argument must be non-negative"
 msgstr "аргумент score повинен бути не відʼємним"
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, gcc-internal-format
 msgid "expected identifier or string literal"
 msgstr "очікується ідентифікатор або літерал рядка"
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "властивість повинна бути цілим сталим виразом"
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "властивості для селектора %<simd%> не можуть бути вказані в %<metadirective%>"
@@ -49187,295 +49217,295 @@ msgstr "властивості для селектора %<simd%> не можу
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fpie%> is not supported"
 msgid "%<requires%> selector is not supported yet"
 msgstr "%<-fpie%> не підтримується"
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, fuzzy, gcc-internal-format
 #| msgid "expected trait selector name"
 msgid "expected context selector set name"
 msgstr "очікуване імʼя селектора ознаки"
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "очікується %<match%>"
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, gcc-internal-format
 msgid "variant %qD is not a function"
 msgstr "варіант %qD не є функцією"
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, gcc-internal-format
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "варіант %qD та база %qD мають несумісні типи"
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr "варіант %qD є вбудованим"
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare %s%> не негайно слідує за оголошенням або визначенням функції"
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare %s%> не негайно слідує за одним оголошенням або визначенням функції"
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr "%qD вказано як у замиканні declare target %<link%>, так і в замиканні %qs"
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr "%qD вказано як у замиканні declare target %<link%>, так і в замиканні %<to%> або %<enter%>"
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, fuzzy, gcc-internal-format
 #| msgid "directive with only %<device_type%> clause"
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr "директива з замиканням %<device_type%>"
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, fuzzy, gcc-internal-format
 #| msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr "умову %<detach%> не слід використовувати разом з умовою %<mergeable%>"
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "очікується %<target%>"
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, gcc-internal-format
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr "очікується %<declare target%> або %<assumes%>"
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr "%<#pragma omp end declare target%> без відповідного %<#pragma omp declare target%> або %<#pragma omp begin declare target%>"
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr "%qs в синтаксисі атрибуту завершується %qs в синтаксисі прагми"
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, gcc-internal-format
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr "%qs в синтаксисі прагми завершується %qs в синтаксисі атрибуту"
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, gcc-internal-format
 msgid "expected %<declare%> or %<assumes%>"
 msgstr "очікується %<declare%> або %<assumes%>"
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr "%<#pragma omp declare reduction%> не на рівні файлу або блоку"
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr "попередньо оголошений арифметичний тип у %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr "тип функції або масиву у %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, gcc-internal-format
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr "тип з кваліфікатором %<_Atomic%> у %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr "тип з кваліфікаторами const, volatile або restrict у %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr "повторне оголошення %qs %<#pragma omp declare reduction%> для типу %qT"
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "попереднє %<#pragma omp declare reduction%>"
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr "очікується %<omp_priv%> або імʼя функції"
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "очікується імʼя функції %<(%>"
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "один з аргументів виклику ініціалізатора повинен бути %<&omp_priv%>"
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "очікується %<simd%>, %<reduction%>, %<target%> або %<variant%>"
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr "очікується %<seq_cst%>, %<acq_rel%>, %<release%> або %<acquire%>"
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr "очікувалася замикання %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> або %<atomic_default_mem_order%>"
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr "%qs використовується лексично після першої конструкції цілі або API віддаленого виконання"
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr "більше однієї замикання %<atomic_default_mem_order%> в одній компіляційній одиниці"
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr "замикання %<atomic_default_mem_order%> використовується лексично після першої конструкції %<atomic%> без замикання порядку памʼяті"
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr "%<pragma omp requires%> вимагає принаймні одну замикання"
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, gcc-internal-format
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr "тип %qT нульового розміру в замиканні %<reduction%>"
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, gcc-internal-format
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "тип зі змінним розміром %qT в замиканні %<reduction%>"
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, gcc-internal-format
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr "очікується замикання %<at%>, %<severity%> або %<message%>"
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, gcc-internal-format
 msgid "expected %qs or %qs"
 msgstr "очікується %qs або %qs"
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, gcc-internal-format
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr "%<#pragma omp error%> з замиканням %<at(execution)%> може використовуватись тільки в складних операторах"
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr "зустрівся %<pragma omp error%>: %s"
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr "зустрівся %<pragma omp error%>"
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, gcc-internal-format
 msgid "expected at least one assumption clause"
 msgstr "очікується принаймні одне замикання припущення"
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, gcc-internal-format
 msgid "expected directive name"
 msgstr "очікується назва директиви"
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr "невідома назва директиви OpenMP в аргументі замикання %qs"
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr "директива %<%s%s%s%s%s%> згадується як у замиканні %<absent%>, так і у замиканні %<contains%>"
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr "директива %<%s%s%s%s%s%> згадується кілька разів у замиканнях %qs"
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, gcc-internal-format
 msgid "unknown assumption clause %qs"
 msgstr "невідомий замикання припущення %qs"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, gcc-internal-format
 msgid "expected assumption clause"
 msgstr "очікується замикання припущення"
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE оголошено як %<threadprivate%> після першого використання"
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "автоматична змінна %qE не може бути %<threadprivate%>"
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE має неповний тип"
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> без підтримки транзакційної памʼяті"
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> всередині %<__transaction_relaxed%>"
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "зовнішній %<__transaction_cancel%> не знаходиться всередині зовнішнього %<__transaction_atomic%> або функції %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> не в межах %<__transaction_atomic%>"
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, gcc-internal-format
 msgid "no closing brace"
 msgstr "відсутня закриваюча фігурна дужка"
@@ -49618,7 +49648,7 @@ msgstr "розіменування вказівника %<void *%>"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "індексоване значення не є ані масивом, ані вказівником, ані вектором"
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "індекс масиву не є цілочисельним"
@@ -49648,7 +49678,7 @@ msgstr "недостатньо визначений %qD, на який поси
 msgid "enum constant defined here"
 msgstr "константа перелічування визначена тут"
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr "%<sizeof%> на параметрі функції масиву %qE поверне розмір %qT"
@@ -49761,17 +49791,17 @@ msgstr "неявне перетворення з %qT на %qT при перед
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "недостатньо аргументів для вбудованої функції %qE, очікується %u"
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "порівняння з літералом рядка призводить до невизначеного поведінки"
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
 msgstr "порівняння між вказівником і нульовою символьною константою"
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
 msgstr "ви мали на увазі розіменування вказівника?"
@@ -49796,7 +49826,7 @@ msgstr "вказівник на функцію використовується
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "арифметика з вказівником на неповний тип"
 
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "арифметика з вказівником на порожню структуру"
@@ -50093,7 +50123,7 @@ msgstr "приведення з вказівника до цілого числ
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "приведення з виклику функції типу %qT до несумісного типу %qT"
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "приведення до вказівника з цілого числа іншого розміру"
@@ -50265,7 +50295,7 @@ msgstr "ліва частина присвоєння може бути канд
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "ліва частина ініціалізації може бути кандидатом на атрибут формату"
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "тип повернення може бути кандидатом на атрибут формату"
@@ -50466,12 +50496,12 @@ msgstr "Ініціалізатор %<constexpr%> для дійсного тип
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr "Ініціалізатор %<constexpr%> для двійкового типу з плаваючою комою має десятковий тип"
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "ініціалізація гнучкого члена масиву"
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr "не вдається ініціалізувати масив з %qT з літералу рядка з типом масиву %qT"
@@ -50481,7 +50511,7 @@ msgstr "не вдається ініціалізувати масив з %qT з
 msgid "array of inappropriate type initialized from string constant"
 msgstr "масив неприпустимого типу ініціалізовано зі стрічкової константи"
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "неприпустиме використання масиву, який не є lvalue"
@@ -50512,7 +50542,7 @@ msgstr "елемент ініціалізатора не є константни
 msgid "initializer element is not computable at load time"
 msgstr "елемент ініціалізатора не обчислюється під час завантаження"
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "неможливо ініціалізувати непрозорі векторні типи"
@@ -50527,7 +50557,7 @@ msgstr "додаткова група фігурних дужок в кінці
 msgid "braces around scalar initializer"
 msgstr "фігурні дужки навколо скалярного ініціалізатора"
 
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "ініціалізація гнучкого елемента масиву вкладеного контексту"
@@ -50618,7 +50648,7 @@ msgstr "зайві елементи в ініціалізаторі структ
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "позиційна ініціалізація поля в %<struct%>, оголошеного з атрибутом %<designated_init%>"
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "нестатична ініціалізація гнучкого елемента масиву"
@@ -50658,7 +50688,7 @@ msgstr "ISO C забороняє %<goto *expr;%>"
 msgid "computed goto must be pointer type"
 msgstr "обчислене перехід має бути типу вказівник"
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "функція, оголошена з %<noreturn%>, має оператор %<return%>"
@@ -50713,7 +50743,7 @@ msgstr "мітка %<default%> не знаходиться у блоку switch"
 msgid "break statement not within loop or switch"
 msgstr "оператор break не знаходиться у циклі або блоку switch"
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -50759,27 +50789,27 @@ msgstr "порівняння завжди буде оцінюватися як %
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr "порівняння завжди буде оцінюватися як %<true%> для адреси %qE ніколи не буде NULL"
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "порівняння векторів з різними типами елементів"
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "порівняння векторів з різною кількістю елементів"
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "порівняння між типами %qT та %qT"
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "не вдалося знайти цілочисельний тип такої ж розмірності, як %qT"
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr "порівнювати числа з рухомою комою за допомогою %<==%> або %<!=%> небезпечно"
@@ -50851,29 +50881,29 @@ msgstr "використано значення типу «union», де пот
 msgid "used vector type where scalar is required"
 msgstr "використано значення типу «vector», де потрібний скаляр"
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> повинен вказувати один з замиканнь %<parallel%>, %<for%>, %<sections%> або %<taskgroup%>"
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "очікується модифікатор замикання %<cancel%> %<if%>"
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> повинен вказувати один з замиканнь %<parallel%>, %<for%>, %<sections%> або %<taskgroup%>"
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD не є змінною в замиканні %qs"
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE не є змінною в замиканні %qs"
@@ -50884,85 +50914,85 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%> %qD в замиканні %qs"
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD є змінною, приватною для потоку, в замиканні %qs"
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "нижня межа %qE секції масиву не має цілочисельного типу"
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "довжина %qE секції масиву не має цілочисельного типу"
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "очікується один вказівник у замиканні %qs"
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "секція масиву з нульовою довжиною у замиканні %qs"
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "для масиву з невідомою межею типу необхідно вказати вираз довжини"
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "відʼємна нижня межа в секції масиву у замиканні %qs"
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "відʼємна довжина в секції масиву у замиканні %qs"
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "нижня межа %qE вище розміру секції масиву у замиканні %qs"
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "довжина %qE більше розміру секції масиву в замиканні %qs"
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "верхня межа %qE вище розміру розділу масиву в %qs замиканні"
 
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr "для параметра функції масиву необхідно вказати вираз довжини"
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "для типу вказівника необхідно вказати вираз довжини"
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "розділ масиву не є послідовним в %qs замиканні"
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE не має типу вказівника або масиву"
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr "ітератор %qD не має ні цілочисельного, ні вказівного типу"
@@ -50972,17 +51002,17 @@ msgstr "ітератор %qD не має ні цілочисельного, ні
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "ітератор %qD має тип з %<_Atomic%> кваліфікацією"
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr "ітератор %qD має тип з const кваліфікацією"
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "крок ітератора з не-цілочисельним типом"
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr "ітератор %qD має крок 0"
@@ -50992,32 +51022,32 @@ msgstr "ітератор %qD має крок 0"
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr "тип ітератора %qD посилається на зовнішній ітератор %qD"
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr "вираз початку посилається на зовнішній ітератор %qD"
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr "вираз кінця посилається на зовнішній ітератор %qD"
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr "вираз кроку посилається на зовнішній ітератор %qD"
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr "очікується вказівник в %qs замиканні"
 
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "%<inscan%> та не-%<inscan%> %<reduction%> замикання на одній конструкції"
 
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr "%<inscan%> Замикання %<reduction%> зі зрізом масиву"
@@ -51047,7 +51077,7 @@ msgstr "Тип %qT змінного розміру в замиканні %qs"
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE має недійсний тип для %<reduction(%s)%>"
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "не знайдено користувацьку визначену редукцію для %qE"
@@ -51057,17 +51087,17 @@ msgstr "не знайдено користувацьку визначену ре
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "Тип елемента змінної довжини в замиканні %<reduction%> масиву"
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "Замикання %<nowait%> не можна використовувати разом з %<copyprivate%>"
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE має бути %<threadprivate%> для %<copyin%>"
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
 msgstr "модифікатор не повинен бути вказаний в %<linear%> замиканні на конструкціях %<simd%> або %<for%>, коли не використовується модифікатор OpenMP 5.2"
@@ -51082,23 +51112,23 @@ msgstr "Замикання «linear» застосовано до змінної
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "%<_Atomic%> %qD у замиканні %<linear%>"
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "крок замикання %<linear%> %qE не є ані константою, ані параметром"
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE не є змінною в замиканні %qs"
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, gcc-internal-format
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr "%qD зʼявляється більше одного разу в замиканнях для обміну даними"
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD зʼявляється більше одного разу в редукційних замиканнях"
@@ -51110,32 +51140,32 @@ msgstr "%qE зʼявляється більше одного разу в зам
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD зʼявляється більше одного разу в замиканнях даних"
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD зʼявляється як в замиканнях даних, так і в замиканнях відображення"
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE не є змінною в замиканні %<firstprivate%>"
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE не є змінною в замиканні %<lastprivate%>"
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE не є змінною в замиканні %<aligned%>"
@@ -51155,7 +51185,7 @@ msgstr "%<_Atomic%> %qD в замиканні %<aligned%>"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE зʼявляється більше одного разу в замиканнях %<aligned%>"
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE не є змінною в замиканні %<nontemporal%>"
@@ -51165,7 +51195,7 @@ msgstr "%qE не є змінною в замиканні %<nontemporal%>"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE зʼявляється більше одного разу в замиканнях %<nontemporal%>"
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qE не є змінною в замиканні %<allocate%>"
@@ -51175,77 +51205,77 @@ msgstr "%qE не є змінною в замиканні %<allocate%>"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE зʼявляється більше одного разу в замиканнях %<allocate%>"
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr "Замикання %<depend%> з типом залежності %<depobj%> на секції масиву"
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr "%<omp_all_memory%> використовується з типом залежності %<depend%>, відмінним від %<out%> або %<inout%>"
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr "%qE не є виразом lvalue або секцією масиву в замиканні %qs"
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr "%qE не має типу %<omp_depend_t%> в замиканні %<depend%> з типом залежності %<depobj%>"
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr "%qE не повинен мати тип %<omp_depend_t%> у замиканні %<depend%> залежності з типом залежності, відмінним від %<depobj%>"
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "секція масиву не має відображального типу в замиканні %qs"
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported memory expression:"
 msgid "unsupported map expression %qE"
 msgstr "непідтримуваний вираз памʼяті:"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD зʼявляється більше одного разу в замиканнях руху"
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD зʼявляється більше одного разу в замиканнях відображення"
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD не має відображального типу в замиканні %qs"
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE не є змінною або імʼям функції в замиканні %qs"
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE зʼявляється більше одного разу в одній і тій же директиві %<declare target%>"
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD не є аргументом в замиканні %<uniform%>"
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE не є аргументом в замиканні %<uniform%>"
@@ -51260,22 +51290,22 @@ msgstr "змінна %qs не є вказівником"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "змінна %qs не є або вказівником, або масивом"
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "замикання %<order%> не повинен використовуватися разом з %<ordered%>"
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr "занадто багато замиканнь %qs у конструкції задачі"
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "замикання %<inbranch%> несумісний з замиканням %<notinbranch%>"
 
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE є передбаченим %qs для %qs"
@@ -51285,38 +51315,38 @@ msgstr "%qE є передбаченим %qs для %qs"
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "кваліфікована %qE з %<const%> може зʼявлятися тільки у замиканнях %<shared%> або %<firstprivate%>"
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "значення замикання %<simdlen%> більше, ніж значення замикання %<safelen%>"
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "модифікатор розкладу %<nonmonotonic%> вказаний разом з замиканням %<ordered%>"
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "замикання %qs вказаний разом з замиканням %<inscan%> %<reduction%>"
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "крок умови %<linear%> є параметром %qD, який не вказаний умовою %<uniform%>"
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr "умову %<nogroup%> не слід використовувати разом з умовою %<reduction%>"
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr "умову %<detach%> не слід використовувати разом з умовою %<mergeable%>"
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr "обробник події %<detach%> не повинен бути в замиканні, що спільно використовує дані"
@@ -51584,7 +51614,7 @@ msgstr "  немає відомого перетворення з %qH на %qI"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  немає відомого перетворення для аргументу %d з %qH на %qI"
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -51592,7 +51622,7 @@ msgstr[0] "  кандидат очікує принаймні %d аргумен
 msgstr[1] "  кандидат очікує принаймні %d аргументи, надано %d"
 msgstr[2] "  кандидат очікує принаймні %d аргументів, надано %d"
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -51905,557 +51935,557 @@ msgstr "умовний вираз між типом з плаваючою точ
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "перелічування та неперелічування типи в умовному виразі"
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "не оголошено %<%D(int)%> для постфіксного оператора %qs, спробую використати префіксний оператор замість цього"
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "не оголошено %<%D(int)%> для постфіксного оператора %qs"
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr "у C++20 це порівняння викликає поточну функцію рекурсивно з оберненими аргументами"
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "тип повернення %qD не є %qs"
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr "використовується як переписаний кандидат для порівняння %qT і %qT"
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "порівняння між %q#T і %q#T"
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, gcc-internal-format
 msgid "no match for call to %<%T::operator[] (%A)%>"
 msgstr "немає відповідності для виклику %<%T::operator[] (%A)%>"
 
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, gcc-internal-format
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr "виклик %<%T::operator[] (%A)%> є неоднозначним"
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr "очищення винятків для цього розміщення нового вибирає нерозміщене %<operator delete%>"
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD - це звичайна (нерозміщена) функція звільнення в C++14 (або з %<-fsized-deallocation%>)"
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD - це звичайна (нерозміщена) функція звільнення"
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "немає відповідної функції звільнення для %qD"
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr "знищення delete %qD не може бути використано для звільнення виділеної памʼяті, якщо ініціалізація викидається, оскільки обʼєкт ще не побудований"
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "немає задовільного %<operator %s%> для %qT"
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr "%q#D є приватним у цьому контексті"
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "оголошено приватним тут"
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr "%q#D є захищеним у цьому контексті"
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "оголошено захищеним тут"
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D недоступний у цьому контексті"
 
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "передача NULL невказівниковому аргументу %P у %qD"
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, gcc-internal-format
 msgid "  declared here"
 msgstr "  оголошено тут"
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "перетворення на невказівниковий тип %qT з NULL"
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "перетворення %<false%> на вказівниковий тип для аргументу %P у %qD"
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "перетворення %<false%> на вказівниковий тип %qT"
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  ініціалізація аргументу %P %qD"
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "конвертація в масиви невідомого розміру доступна лише з %<-std=c++20%> або %<-std=gnu++20%>"
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "занадто багато фігурних дужок навколо ініціалізатора для %qT"
 
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "конвертація в %qH з %qI вимагає прямої ініціалізації"
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 #, fuzzy
 #| msgid "converting to %qH from %qI with greater conversion rank"
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr "конвертація в %qH з %qI з більшим рангом конвертації"
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 #, fuzzy
 #| msgid "converting to %qH from %qI with unordered conversion ranks"
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr "перетворення на %qH з %qI з неупорядкованими рангами конверсії"
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "недійсне користувацьке перетворення з %qH на %qI"
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 msgid "invalid conversion from %qH to %qI"
 msgstr "недійсне перетворення з %qH на %qI"
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "перетворення в %qT зі списку ініціалізаторів використовуватиме явний конструктор %qD"
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "у C++11 і вище, конструктор за замовчуванням може бути явним"
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "не можна привʼязати rvalue-посилання типу %qH до lvalue типу %qI"
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr "не можна привʼязати неконстантне lvalue-посилання типу %qH до значення типу %qI"
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "не можна привʼязати неконстантне lvalue-посилання типу %qH до rvalue типу %qI"
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "не можна привʼязати lvalue-посилання типу %qH до rvalue типу %qI"
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "не можна привʼязати посилання типу %qH до %qI через різні межі масиву"
 
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "привʼязка посилання типу %qH до %qI відкидає кваліфікатори"
 
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, gcc-internal-format
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "не можна привʼязати біт-поле %qE до %qT"
 
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "не можна привʼязати упаковане поле %qE до %qT"
 
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "не можна привʼязати rvalue %qE до %qT"
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "неявне перетворення з %qH на %qI при передачі аргументу до функції"
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr "обмежене перелічування %qT передається через %<...%> як %qT до %<-fabi-version=6%>, %qT після"
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "передача обʼєктів типу %q#T, які не можуть бути просто скопійовані, через %<...%> підтримується умовно"
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "не можна отримати посилання типу %qT через %<...%>"
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "отримання обʼєктів типу %q#T, які не можуть бути просто скопійовані, через %<...%> є умовно підтримуваним"
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "рекурсивна оцінка стандартного аргументу для %q#D"
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "виклик %qD використовує стандартний аргумент для параметра %P, який ще не визначений"
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "аргумент виклику функції може бути кандидатом на атрибут формату"
 
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "використання функції з багатьма версіями без стандартного значення"
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr ""
 
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "передача %qT як аргументу %<this%> відкидає кваліфікатори"
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  в виклику %qD"
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT не є доступною базою для %qT"
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "передача аргументів до багатокрапки іспадкованого конструктора %qD"
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "присвоєння з тимчасового %<initializer_list%> не продовжує термін існування базового масиву"
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr "%qD запис до обʼєкту типу %#qT без тривіального копіювання"
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%qD запис до обʼєкту незвичайного типу %#qT%s"
 
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr "%qD запис до обʼєкту типу %#qT з елементом %qs %qD"
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr "%qD запис до обʼєкту типу %#qT, що містить вказівник на елемент даних%s"
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr "; використовуйте присвоєння або ініціалізацію значенням замість цього"
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, gcc-internal-format
 msgid "; use assignment instead"
 msgstr "; використовуйте присвоєння замість цього"
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "; використовуйте ініціалізацію значенням замість цього"
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD очищення обʼєкта типу %#qT без тривіального копіювання-присвоєння%s"
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD очищення обʼєкта незвичайного типу %#qT%s"
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr "%qD очищення обʼєкта типу %#qT, що містить вказівник на член%s"
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "; використовуйте присвоєння копії або ініціалізацію копією замість цього"
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, gcc-internal-format
 msgid "; use copy-assignment instead"
 msgstr "; використовуйте присвоєння копії замість цього"
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "; використовуйте ініціалізацію копією замість цього"
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr "%qD запис до обʼєкту типу %#qT без тривіального копіювання%s"
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "%qD запис до обʼєкту незвичайно копіюваного типу %#qT%s"
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr "%qD запис до обʼєкту з видаленим конструктором копіювання"
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr "%qD копіювання обʼєкту незвичайного типу %#qT з масиву з %#qT"
 
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr "%qD копіювання обʼєкту типу %#qT з елементом %qs %qD з масиву з %#qT; використовуйте замість цього присвоєння або копіювальну ініціалізацію"
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr "%qD запис до обʼєкту ненезначного типу %#qT залишає %wu байтів без змін"
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr "%qD запис до обʼєкту ненезначного типу %#qT залишає %wu байт без змін"
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "%qD переміщення обʼєкту ненезначного типу %#qT, який не може бути скопійований; використовуйте %<new%> і %<delete%> замість цього"
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr "%qD переміщення обʼєкту типу %#qT з видаленим конструктором копіювання; використовуйте %<new%> і %<delete%> замість цього"
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr "%qD переміщення обʼєкту типу %#qT з видаленим деструктором"
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr "%qD переміщення обʼєкту ненезначного типу %#qT та розміру %E в область розміру %E"
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%#qT оголошено тут"
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, gcc-internal-format
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr "аргумент %u у виклику функції %qE має вказівник на тип, який не можна просто скопіювати (%qT)"
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "конструктор делегує на себе"
 
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 msgid "cannot convert %qH to %qI"
 msgstr "не можу перетворити %qH в %qI"
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "немає відповідної функції для виклику %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "немає відповідної функції для виклику %<%T::%s%E(%A)%#V%>"
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "виклик не-функції %qD"
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "не можливо прямо викликати конструктор %<%T::%D%> безпосередньо"
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "для приведення типу у стилі функції, видаліть зайве %<::%D%>"
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "немає відповідної функції для виклику %<%s(%A)%>"
 
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "виклик перевантаженої функції %<%s(%A)%> є неоднозначним"
 
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "чистий віртуальний %q#D викликано з нестатичного ініціалізатора члена даних"
 
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "чистий віртуальний %q#D викликано з конструктора"
 
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "чистий віртуальний %q#D викликано з деструктора"
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "не можна викликати метод члена %qD без обʼєкта"
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "передача %qT обирає %qT замість %qT"
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, gcc-internal-format
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr "C++20 стверджує, що це неоднозначно, навіть якщо другий є зворотнім:"
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, gcc-internal-format
 msgid "try making the operator a %<const%> member function"
 msgstr "спробуйте зробити оператор функцією-членом зі специфікатором %<const%>"
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "обирається %qD замість %qD"
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 msgid "  for conversion from %qH to %qI"
 msgstr "  для перетворення з %qH до %qI"
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  тому що послідовність перетворення для аргументу краща"
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "несумісність аргументу за замовчуванням при вирішенні перевантаження"
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " кандидат 1: %q#F"
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " кандидат 2: %q#F"
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ каже, що це неоднозначно, навіть якщо найгірше перетворення для першого краще, ніж найгірше перетворення для другого:"
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "тимчасове звʼязування з %qD існує лише до виходу з конструктора"
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "неприпустима ініціалізація неконстантного посилання типу %qH з rvalue типу %qI"
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "неправильна ініціалізація посилання типу %qH з виразу типу %qI"
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, gcc-internal-format
 msgid "possibly dangling reference to a temporary"
 msgstr "можливо, посилання на тимчасовий обʼєкт"
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr "тимчасовий обʼєкт був знищений в кінці повного виразу %qE"
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, gcc-internal-format
 msgid "explicit conversion function was not considered"
 msgstr ""
@@ -52501,7 +52531,7 @@ msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q#D не може бути перевантажено з %q#D"
 
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "попереднє оголошення %q#D"
@@ -52922,7 +52952,7 @@ msgstr "гнучкий елемент масиву %qD в іншому поро
 msgid "next member %q#D declared here"
 msgstr "наступний елемент %q#D оголошений тут"
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "перевизначення %q#T"
@@ -53055,7 +53085,7 @@ msgstr "недійсний тип для параметра %d функції %<
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr "лямбда-функції є неявно %<constexpr%> лише у C++17 та пізніших версіях"
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<constexpr%> деструктори доступні лише з %<-std=c++20%> або %<-std=gnu++20%>"
@@ -53096,7 +53126,7 @@ msgstr "тіло функції %<constexpr%> %qD не є оператором 
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%qD не може бути використана як функція з атрибутом %<constexpr%>, оскільки:"
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr ""
@@ -53114,7 +53144,7 @@ msgstr "виклик %<constexpr%> виходить за межі функції
 msgid "%q+E is not a constant expression"
 msgstr "%q+E не є константним виразом"
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -53135,7 +53165,7 @@ msgstr "%qE обчислюється як false"
 msgid "failed %<assume%> attribute assumption"
 msgstr "помилка припущення атрибуту %<assume%>"
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, gcc-internal-format
 msgid "call to internal function %qE"
@@ -53182,7 +53212,7 @@ msgstr "%qT є неоднозначним базовим класом динам
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr "динамічний тип %qT операнда не має однозначного публічного базового класу %qT"
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -53312,18 +53342,18 @@ msgstr "індекс масиву %qE знаходиться поза межам
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "ненульовий індекс масиву %qE використовується з масивом типу %qT з невідомими межами"
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "доступ до неініціалізованого елемента масиву"
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "розіменування нульового вказівника в %qE"
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -53331,480 +53361,480 @@ msgstr "розіменування нульового вказівника в %q
 msgid "%qE is not a constant expression"
 msgstr "%qE не є константним виразом"
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "змінний %qD не може бути використаний в константному виразі"
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "доступ до неініціалізованого члена %qD"
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "доступ до члена %qD замість ініціалізованого члена %qD в константному виразі"
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "%qs не є константним виразом, оскільки %qT є типом обʼєднання"
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "%qs не є константним виразом, оскільки %qT містить тип обʼєднання"
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "%qs не є константним виразом, оскільки %qT є типом вказівника"
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "%qs не є константним виразом, оскільки %qT містить тип вказівника"
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "%qs не є константним виразом, оскільки %qT є типом посилання"
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "%qs не є константним виразом, оскільки %qT містить тип посилання"
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "%qs не є константним виразом, оскільки %qT є типом вказівника на член"
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "%qs не є константним виразом, оскільки %qT містить тип вказівника на член"
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "%qs не є константним виразом, оскільки %qT є волатильним"
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "%qs не є сталим виразом, оскільки %qT містить волатильний підобʼєкт"
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "%qs не може бути обчислено як константне на цільовій платформі"
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr "%qs не може бути обчислено як константне, оскільки тип занадто великий"
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr "%qs не може бути обчислено як константне, оскільки аргумент не може бути закодований"
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "%qs отримує доступ до неініціалізованого байта за зміщенням %d"
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "%qs не може бути обчислено як константне, оскільки аргумент не може бути інтерпретований"
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "доступ до значення %qE через gl-значення %qT в сталому виразі"
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "використання виділеного сховища після звільнення в константному виразі"
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, gcc-internal-format
 msgid "allocated here"
 msgstr "виділено тут"
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, fuzzy, gcc-internal-format
 #| msgid "Access terminates outside of its parent"
 msgid "accessing %qE outside its lifetime"
 msgstr "Доступ закінчується за межами батьківського обʼєкту"
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "вміст неініціалізованого сховища не може бути використаний в сталому виразі"
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "значення %qD не може бути використано в константному виразі"
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD використовується у своєму власному ініціалізаторі"
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D не є константою"
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D є волатильним"
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD не було ініціалізовано константним виразом"
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD не було оголошено як %<constexpr%>"
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD не має цілочисельного або перелічувального типу"
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, fuzzy, gcc-internal-format
 #| msgid "use of allocated storage after deallocation in a constant expression"
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr "використання виділеного сховища після звільнення в константному виразі"
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, fuzzy, gcc-internal-format
 #| msgid "modification of %qE is not a constant expression"
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr "зміна %qE не є константним виразом"
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, fuzzy, gcc-internal-format
 #| msgid "%<reinterpret_cast%> is not a constant expression"
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr "%<reinterpret_cast%> не є константним виразом"
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, fuzzy, gcc-internal-format
 #| msgid "modification of %qE is not a constant expression"
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr "зміна %qE не є константним виразом"
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, fuzzy, gcc-internal-format
 #| msgid "change of the active member of a union from %qD to %qD during initialization"
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr "зміна активного члена обʼєднання з %qD на %qD під час ініціалізації"
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr ""
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr ""
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "зміна активного члена обʼєднання з %qD на %qD під час ініціалізації"
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "вираз не є константним"
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "кількість ітерацій циклу %<constexpr%> перевищує обмеження в %d (використовуйте %<-fconstexpr-loop-limit=%>, щоб збільшити обмеження)"
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "вбудована асемблерна вставка не є константним виразом"
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr "у функції %<constexpr%> в C++20 дозволена лише невирахована вбудована асемблерна вставка"
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, gcc-internal-format
 msgid "use of %qD"
 msgstr "використання %qD"
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr "його значення може змінюватися між версіями компілятора або з різними прапорцями %<-mtune%> або %<-mcpu%>"
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr "якщо це використання є частиною публічного ABI, замініть його на використання константної змінної, яку ви визначаєте"
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr "значення за замовчуванням для поточної настройки процесора - %d байтів"
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr "ви можете стабілізувати це значення за допомогою %<--param hardware_destructive_interference_size=%d%>, або вимкнути це попередження за допомогою %<-Wno-interference-size%>"
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "значення %qE типу %qT не є константним виразом"
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "кількість операцій оцінки %<constexpr%> перевищує обмеження %wd (використовуйте %<-fconstexpr-ops-limit=%>, щоб збільшити обмеження)"
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr "керування проходить через визначення %qD з тривалістю зберігання потоку"
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, gcc-internal-format
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "керування проходить через визначення %qD зі статичною тривалістю зберігання"
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "тимчасовий обʼєкт нелітерального типу %qT в константному виразі"
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "%<reinterpret_cast%> не є константним виразом"
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "перетворення з типу вказівника %qT до арифметичного типу %qT в константному виразі"
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr "%qE не є константним виразом, оскільки він посилається на змінні підобʼєкти %qT"
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, fuzzy, gcc-internal-format
 #| msgid "pointer member %q+D declared here"
 msgid "pointed-to object declared here"
 msgstr "член-вказівник %q+D оголошений тут"
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr "%qs не є константним виразом, оскільки %qT є типом вказівника на член"
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, fuzzy, gcc-internal-format
 #| msgid "modifying a const object %qE is not allowed in a constant expression"
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr "зміна константного обʼєкту %qE не дозволена в константному виразі"
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "%qE не є константним виразом, коли клас %qT ще не завершений"
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> не є константним виразом"
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "Вираз %qE не є константним виразом"
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> не є константним виразом"
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "Умова контракту є хибною в константному виразі"
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "неочікуваний ідентифікатор шаблону %qE"
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr "функційне поняття повинно бути викликане"
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "адреса виклику %qs не є константним виразом"
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "неочікуваний вираз %qE типу %s"
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE не є константним виразом, оскільки він посилається на змінні підобʼєкти %qT"
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE не є константним виразом, оскільки він посилається на неповністю ініціалізовану змінну"
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qE не є константним виразом, оскільки він посилається на результат %<operator new%>"
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qE не є константним виразом, оскільки виділене сховище не було звільнено"
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr "негайна оцінка повертає адресу негайної функції %qD"
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, fuzzy, gcc-internal-format
 #| msgid "immediate evaluation returns address of immediate function %qD"
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr "негайна оцінка повертає адресу негайної функції %qD"
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "перетворення lvalue в rvalue від volatile lvalue %qE з типом %qT"
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "захоплення лямбди %qE не є константним виразом"
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr "тому що воно використовується як glvalue"
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "%<reinterpret_cast%> з цілого числа в вказівник"
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "адреса обʼєкта %qE з потоковим локальним або автоматичним сховищем не є константним виразом"
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "використання %<this%> в константному виразі"
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "вираз лямбди не є константним виразом до C++17"
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "вираз new не є константним виразом до C++20"
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, gcc-internal-format
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "віртуальні функції не можуть бути %<constexpr%> до C++20"
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "%<typeid%> не є константним виразом, оскільки %qE має поліморфний тип"
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "приведення до нецілочисельного типу %qT в константному виразі"
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "%qD визначено %<thread_local%> в контексті %<constexpr%>"
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "%qD визначено %<static%> в контексті %<constexpr%>"
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "ділення на нуль не є константним виразом"
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> не є константним виразом"
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "жодна гілка %<if%> не є константним виразом"
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "не константна ініціалізація масиву"
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "визначення мітки в функції %<constexpr%> доступне лише з %<-std=c++2b%> або %<-std=gnu++2b%>"
 
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "неочікуваний AST типу %s"
@@ -54523,7 +54553,7 @@ msgstr "аргумент direction для %<__builtin_coro_promise%> має бу
 msgid "no suspend point info for %qD"
 msgstr "немає інформації про точку призупинення для %qD"
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr "%qE надається %qT, але не може бути використаний зі сигнатурою функції %qD"
@@ -54543,23 +54573,23 @@ msgstr "вирази await не допускаються в обробниках
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "масиви змінної довжини ще не підтримуються в корутин"
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr "%qE надається %qT, але %qE не позначений %<throw()%> або %<noexcept%>"
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr "%qE позначений %<throw()%> або %<noexcept%>, але %qT не надає жодного використовуваного %<get_return_object_on_allocation_failure%>"
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr "%qE надається %qT, але %<std::nothrow%> не знайдено"
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr "не можливо ініціалізувати обʼєкт повернення типу %qT з rvalue типу %<void%>"
@@ -54580,69 +54610,69 @@ msgstr ""
 msgid "%qD was promoted to an immediate function"
 msgstr "%qD не є шаблонною функцією"
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "береться адреса негайної функції %qD"
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, fuzzy, gcc-internal-format
 #| msgid "address of a call to %qs is not a constant expression"
 msgid "call to consteval function %qE is not a constant expression"
 msgstr "адреса виклику %qs не є константним виразом"
 
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%<throw%> завжди викликає %<terminate%>"
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "у C++11 деструктори за замовчуванням є %<noexcept%>"
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr "у C++11 цей %<throw%> викличе %<terminate%>, оскільки деструктори за замовчуванням є %<noexcept%>"
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "ігнорується атрибут %qE після попереднього %qE"
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, gcc-internal-format
 msgid "pack expansion of %qE attribute"
 msgstr "розширення пакунку атрибуту %qE"
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, gcc-internal-format
 msgid "use fold expression in the attribute argument instead"
 msgstr "використовуйте складний вираз в аргументі атрибуту замість цього"
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD не є типом"
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qD не є типом класу"
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qD не має типу %<const char *%>"
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%qD не має цілочисельного типу"
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr "%<std::source_location::__impl%> містить не тільки нестатичні елементи даних %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> і %<_M_column%>"
@@ -54683,7 +54713,7 @@ msgstr "перетворення на неконстантне посиланн
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "конвертація з %qH до %qI відкидає кваліфікатори"
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "приведення типу %qT до %qT не розіменовує вказівник"
@@ -55066,7 +55096,7 @@ msgstr "з попереднього оголошення %qF"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "повторне оголошення %qD відрізняється в %qs від попереднього оголошення"
 
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "попереднє оголошення %qD"
@@ -55206,8 +55236,8 @@ msgstr "попереднє оголошення %<pragma omp declare reduction%>
 msgid "%q#D previously defined here"
 msgstr "%q#D раніше визначено тут"
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q#D раніше оголошено тут"
@@ -55289,54 +55319,39 @@ msgstr "задано типовий аргумент для параметра %
 msgid "previous specification in %q#D here"
 msgstr "попередня специфікація в %q#D тут"
 
-#: cp/decl.cc:2285
-#, gcc-internal-format
-msgid "declaration %qD conflicts with builtin"
-msgstr "декларація %qD конфліктує з вбудованою функцією"
-
-#: cp/decl.cc:2288
-#, gcc-internal-format
-msgid "declaration %qD conflicts with import"
-msgstr "декларація %qD конфліктує з імпортом"
-
-#: cp/decl.cc:2289
-#, gcc-internal-format
-msgid "import declared %q#D here"
-msgstr "імпорт оголошено %q#D тут"
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting exporting declaration %qD"
 msgid "conflicting exporting for declaration %qD"
 msgstr "конфліктна експортна декларація %qD"
 
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared here without exporting"
 msgstr "раніше оголошено тут"
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "попереднє визначення %qD тут"
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "попередня декларація %qD тут"
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, gcc-internal-format
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "функція %qD оголошена %<[[noreturn]]%>, але її перша декларація не була"
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "зайве повторне оголошення %qD в одній області видимості"
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr "видалене визначення %qD не є першою декларацією"
@@ -55349,44 +55364,44 @@ msgstr "видалене визначення %qD не є першою декл
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "явна спеціалізація %qD після першого використання"
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%qD: атрибут видимості ігнорується, оскільки він конфліктує з попереднім оголошенням"
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "перевизначення %q#D"
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD конфліктує з використовуваною функцією"
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D не оголошено в класі"
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D повторно оголошено в рядку з атрибутом %<gnu_inline%>"
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D повторно оголошено в рядку без атрибуту %<gnu_inline%>"
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr "оператор порівняння %q+D встановлено за замовчуванням після його першого оголошення"
@@ -55394,744 +55409,744 @@ msgstr "оператор порівняння %q+D встановлено за 
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "перевизначення друга %q#D не може мати аргументів шаблону за замовчуванням"
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "локальна для потоку декларація %q#D слідує за нелокальною декларацією"
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "нелокальна декларація %q#D слідує за локальною для потоку декларацією"
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "повторна декларація %q#D"
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "зайве перевизначення статичного члена даних %<constexpr%> %qD"
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr "локальна мітка %qE конфліктує з існуючою міткою"
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, gcc-internal-format
 msgid "previous label"
 msgstr "попередня мітка"
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, gcc-internal-format
 msgid "jump to label %qD"
 msgstr "перехід до мітки %qD"
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr "перехід до мітки case"
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr ""
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  звідси"
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  виходить зі структурованого блоку OpenMP"
 
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  перетинає ініціалізацію %q#D"
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr "  входить в блок %<try%>"
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "  входить в блок %<catch%>"
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  входить в структурований блок OpenMP"
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "  входить в синхронізовану або атомарну інструкцію"
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, gcc-internal-format
 msgid "  enters statement expression"
 msgstr "  входить у вираз інструкції"
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "  входить у інструкцію %<constexpr if%>"
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, gcc-internal-format
 msgid "  enters %<consteval if%> statement"
 msgstr "  входить у інструкцію %<consteval if%>"
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C99 does not support %qE"
 msgid "  does not destroy %qD"
 msgstr "ISO C99 не підтримує %qE"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not take any feature options"
 msgid "  does not clean up handled exception"
 msgstr "%s не приймає жодних опцій функцій"
 
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  пропускає ініціалізацію %q#D"
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, gcc-internal-format
 msgid "%qD used without template arguments"
 msgstr "%qD використовується без аргументів шаблону"
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, gcc-internal-format
 msgid "%qD is a function, not a type"
 msgstr "%qD - це функція, а не тип"
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T не є класом"
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "немає класового шаблону з назвою %q#T в %q#T"
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "немає типу з назвою %q#T в %q#T"
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "пошук %qT в %qT є неоднозначним"
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> називає %q#T, який не є класовим шаблоном"
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> називає %q#D, який не є типом"
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "параметри шаблону не відповідають шаблону %qD"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "%<-faligned-new=%d%> не є степенем двійки"
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr "%<--param destructive-interference-size=%d%> менше ніж %d"
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr "%<--param destructive-interference-size=%d%> менше ніж %<--param l1-cache-line-size=%d%>"
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr "%<--param constructive-interference-size=%d%> менше ніж %d"
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr "%<--param constructive-interference-size=%d%> більше ніж %<--param l1-cache-line-size=%d%>"
 
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D недійсний; анонімний обʼєднання може мати тільки публічні нестатичні члени даних"
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "ця гнучкість застаріла і буде видалена"
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr "анонімна структура з базовими класами"
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "член %q+#D з конструктором не допускається в анонімному агрегаті"
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "член %q+#D з деструктором не допускається в анонімному агрегаті"
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "член %q+#D з оператором присвоєння копіювання не допускається в анонімному агрегаті"
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "атрибут ігнорується в оголошенні %q#T"
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "атрибут для %q#T повинен слідувати за ключовим словом %qs"
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "декілька типів в одному оголошенні"
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "повторне оголошення вбудованого типу C++ %qT"
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> може бути вказано тільки для змінних або оголошень функцій"
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "відсутнє імʼя типу в оголошенні typedef"
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ забороняє анонімні структури"
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> може бути вказано тільки для функцій"
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> може бути вказано лише для функцій"
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> може бути вказано лише всередині класу"
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> може бути вказано лише для конструкторів"
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "клас сховища може бути вказано лише для обʼєктів та функцій"
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> може бути вказано лише для обʼєктів та функцій"
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> може бути вказано лише для обʼєктів та функцій"
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> може бути вказано лише для обʼєктів та функцій"
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> може бути вказано лише для обʼєктів та функцій"
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> було проігноровано в цьому оголошенні"
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%qs не може бути використано для оголошень типів"
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "атрибут проігноровано в явному інстанціюванні %q#T"
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "неможливо застосувати атрибут до явного інстанціювання"
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "ігноруються атрибути, застосовані до класового типу %qT поза визначенням"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "ігноруються атрибути, застосовані до залежного типу %qT без повʼязаного оголошення"
 
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD ініціалізовано (використовуйте %qs замість)"
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "оголошення %q#D має %<extern%> та ініціалізовано"
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "визначення %q#D має маркування %<dllimport%>"
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D не є статичним членом даних %q#T"
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "декларація неметодного шаблону %qD"
 
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "не відповідає декларації методного шаблону тут"
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ не дозволяє визначати %<%T::%D%> як %<%T::%D%>"
 
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "подвійна ініціалізація %qD"
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "декларація %q#D поза класом не є визначенням"
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, fuzzy, gcc-internal-format
 #| msgid "block-scope extern declaration %q#D not permitted in module purview"
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr "екстерна декларація %q#D з областю видимості блоку не дозволена в модульному контексті"
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%qD, визначений як %<thread_local%> у функції %qs, доступний лише з опцією %<-std=c++2b%> або %<-std=gnu++2b%>"
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%qD може бути визначено %<static%> тільки в функції %qs, доступній лише з %<-std=c++2b%> або %<-std=gnu++2b%>"
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "змінна %q#D має ініціалізатор, але неповний тип"
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "елементи масиву %q#D мають неповний тип"
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "агрегат %q#D має неповний тип і не може бути визначений"
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD оголошено як посилання, але не ініціалізовано"
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "імʼя, використане в GNU-стилі призначеного ініціалізатора для масиву"
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "імʼя %qD використане в GNU-стилі призначеного ініціалізатора для масиву"
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "не підтримуються складні призначені ініціалізатори"
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "індикатор C99 %qE не є цілочисельним константним виразом"
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "ініціалізатор не вдалося визначити розмір %qD"
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "відсутній розмір масиву в %qD"
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "масив нульового розміру %qD"
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "розмір сховища %qD невідомий"
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "розмір сховища %qD не є сталим"
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "вибачте: семантика вбудованої змінної %q#D неправильна (ви отримаєте кілька копій)"
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "вибачте: семантика статичних даних вбудованої функції %q#D неправильна (ви отримаєте кілька копій)"
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "Ви можете обійти це, видаливши ініціалізатор"
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, gcc-internal-format
 msgid "uninitialized %<const %D%>"
 msgstr "неініціалізована %<const %D%>"
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "неініціалізована змінна %qD у функції %<constexpr%>"
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "неініціалізована змінна %qD у контексті %<constexpr%>"
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T не має конструктора за замовчуванням, наданого користувачем"
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "конструктор не наданий користувачем, оскільки він явно заданий за замовчуванням у тілі класу"
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "і неявно визначений конструктор не ініціалізує %q#D"
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "недійсний тип %qT як ініціалізатор для вектора типу %qT"
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "ініціалізатор для %qT повинен бути включений у фігурні дужки"
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E] =%> використовується в ініціалізаторі з вказівкою у стилі GNU для класу %qT"
 
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "запит на член %qD є неоднозначним"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT не має нестатичного члена даних з іменем %qD"
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, gcc-internal-format
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD не є прямим членом %qT"
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "недійсний ініціалізатор для %q#D"
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99-означення %qE поза агрегатним ініціалізатором"
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "занадто багато ініціалізаторів для %qT"
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "фігурні дужки навколо скалярного ініціалізатора для типу %qT"
 
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, gcc-internal-format
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "занадто багато фігурних дужок навколо скалярного ініціалізатора для типу %qT"
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "відсутні фігурні дужки навколо ініціалізатора для %qT"
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "структуроване привʼязування має неповний тип %qT"
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "елементи масиву %q#T мають неповний тип"
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "складний літерал змінної розмірності"
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D має неповний тип"
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "скалярний обʼєкт %qD вимагає одного елемента в ініціалізаторі"
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "у C++98 %qD повинен бути ініціалізований конструктором, а не %<{...}%>"
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "масив %qD ініціалізований укладеною у дужки літеральною рядковою константою %qE"
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "ініціалізатор недійсний для статичного члена з конструктором"
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "недопустима неконстантна ініціалізація в класі для статичного члена %qD"
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "недопустима неконстантна ініціалізація в класі для неінлайнового статичного члена %qD"
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(потрібна ініціалізація поза класом)"
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "посилання %qD ініціалізовано самим собою"
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "не вдалося знайти оголошення варіанту"
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "%<declare variant%> на конструкторі %qD"
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "%<declare variant%> на деструкторі %qD"
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr "%<declare variant%> на за замовчуванням %qD"
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr "%<declare variant%> на видаленому %qD"
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr "%<declare variant%> на віртуальному %qD"
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "присвоєння (не ініціалізація) в оголошенні"
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++17 не дозволяє специфікатору класу зберігання %<register%>"
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "використано специфікатор класу зберігання %<register%>"
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "оголошення %q#D не має ініціалізатора"
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "ініціалізатор для %<decltype(auto) %D%> має тип функції; ви забули %<()%>?"
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, gcc-internal-format
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "визначений тип %qT для %qD є неповним"
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr "концепція змінної не має ініціалізатора"
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "затінення попереднього оголошення типу %q#D"
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "Атрибут %<constinit%> може бути застосований лише до змінної зі статичною або потоковою тривалістю зберігання"
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "функція %q#D ініціалізується як змінна"
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "не можна розкласти клас типу %qT, оскільки він має анонімний структурний член"
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "не можна розкласти клас типу %qT, оскільки він має анонімний член обʼєднання"
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "не можна розкласти недоступний член %qD класу %qT"
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "не можна розкласти клас типу %qT: як він сам, так і його базовий клас %qT мають нестатичні елементи даних"
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "не вдається розкласти клас типу %qT: його базові класи %qT та %qT мають нестатичні члени даних"
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "структуроване привʼязування посилається на неповний тип %qT"
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "не можу розкласти масив змінної довжини %qT"
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -56139,7 +56154,7 @@ msgstr[0] "надано %u імʼя для структурованого при
 msgstr[1] "надано %u імен для структурованого привʼязування"
 msgstr[2] "надано %u імен для структурованого привʼязування"
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -56147,7 +56162,7 @@ msgstr[0] "тільки %u імʼя надано для структурован
 msgstr[1] "тільки %u імен надано для структурованого привʼязування"
 msgstr[2] "тільки %u імен надано для структурованого привʼязування"
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -56155,1760 +56170,1760 @@ msgstr[0] "під час розкладання %qT на %wu елемент"
 msgstr[1] "під час розкладання %qT на %wu елементи"
 msgstr[2] "під час розкладання %qT на %wu елементів"
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "не можу розкласти вектор змінної довжини %qT"
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> не є сталим цілочисельним виразом"
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "під час розкладання %qT на %E елементів"
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr "%<std::tuple_element<%u, %T>::type%> є %<void%>"
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "при ініціалізації змінної структурованого звʼязування %qD"
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "не можу розкласти обʼєднаний тип %qT"
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "не можу розкласти тип, який не є масивом або класом %qT"
 
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "не можу розкласти тип замикання лямбди %qT"
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "структуроване звʼязування посилається на неповний класовий тип %qT"
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "не можливо розкласти класовий тип %qT без нестатичних членів даних"
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "нелокальна змінна %qD, оголошена %<__thread%>, потребує динамічної ініціалізації"
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "нелокальна змінна %qD, оголошена %<__thread%>, має незвичайний деструктор"
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "C++11 %<thread_local%> дозволяє динамічну ініціалізацію та знищення"
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "ініціалізатор не визначає розмір %qT"
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "відсутній розмір масиву в %qT"
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "масив нульового розміру %qT"
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "деструктор для класу-іноземця %qT не може бути членом"
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "конструктор для класу-іноземця %qT не може бути членом"
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD оголошено як %<virtual%> змінна"
 
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "Специфікатори функції %<const%> та %<volatile%> на %qD недійсні в оголошенні змінної"
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD оголошено як %<virtual%> параметр"
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD оголошено як %<inline%> параметр"
 
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "Специфікатори функції %<const%> та %<volatile%> на %qD недійсні в оголошенні параметра"
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD оголошено як %<virtual%> тип"
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD оголошено як %<inline%> тип"
 
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "Специфікатори функції %<const%> та %<volatile%> на %qD недійсні в оголошенні типу"
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD оголошено як %<virtual%> поле"
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD оголошено як %<inline%> поле"
 
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "Специфікатори функції %<const%> та %<volatile%> на %qD недійсні в оголошенні поля"
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D оголошено як «friend»"
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D оголошено зі специфікацією винятку"
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "визначення %qD не знаходиться в просторі імен, що оточує %qT"
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "статична функція-член %q#D оголошена з кваліфікаторами типу"
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "концепція %q#D оголошена з параметрами функції"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "концепція %q#D оголошена з виведеним типом повернення"
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "концепція %q#D з не-%<bool%> типом повернення %qT"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "концепція %qD не має визначення"
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "функційна концепція не може бути обмежена"
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, gcc-internal-format
 msgid "constraints on a non-templated function"
 msgstr "обмеження на функцію без шаблону"
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "constrained non-template friend declaration must be a definition"
 msgstr "Оголошення друзів не визначено в описі класу"
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "визначення явної спеціалізації %qD в декларації друга"
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "неприпустиме використання ідентифікатора шаблона %qD в декларації основного шаблону"
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "значення за замовчуванням не дозволені в декларації спеціалізації дружнього шаблону %qD"
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> не дозволено в оголошенні спеціалізації дружнього шаблону %qD"
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "оголошення-друга %qD вказує на аргументи за замовчуванням і не є визначенням"
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "не можна оголосити %<::main%> як шаблон"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "не можна оголосити %<::main%> як inline"
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "не можна оголосити %<::main%> як %qs"
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "не можна оголосити %<::main%> як static"
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "функція, не є членом %qD, не може мати cv-кваліфікатор"
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "статична функція-член %qD не може мати cv-кваліфікатор"
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr "статична функція-член %qD не може мати cv-кваліфікатор"
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "функція, не є методом класу %qD, не може мати кваліфікатор посилання"
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "статичний метод класу %qD не може мати кваліфікатор посилання"
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have ref-qualifier"
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr "статичний метод класу %qD не може мати кваліфікатор посилання"
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD declared here"
 msgid "explicit object parameter declared here"
 msgstr "параметр шаблона %qD оголошений тут"
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "посібник з виведення %qD повинен бути оголошений в тому ж області видимості, що й %qT"
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "посібник з виведення %qD повинен мати такий самий доступ, як %qT"
 
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "посібник з виведення %qD не повинен мати тіла функції"
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "літеральний оператор зі звʼязком C"
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD має недійсний список аргументів"
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "суфікс цілого числа %qs затінений реалізацією"
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "суфікс числа з плаваючою комою %qs затінений реалізацією"
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "суфікси операторів літералів, які не передують %<_%>, зарезервовані для майбутньої стандартизації"
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD повинна бути функцією, що не є членом"
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> повинна повертати %<int%>"
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "визначення неявно оголошеної %qD"
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "визначення явно за замовчуванням %qD"
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D явно задано тут"
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "не оголошено жодної член-функції %q#D в класі %qT "
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "не можна оголосити %<::main%> глобальною змінною"
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "нетемплейтна змінна не може бути %<concept%>"
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr "концепцію слід визначати на рівні простору імен"
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "концепція повинна мати тип %<bool%>"
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, gcc-internal-format
 msgid "a variable concept cannot be constrained"
 msgstr "змінна концепція не може бути обмежена"
 
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ініціалізація в класі статичного елемента даних %q#D неповного типу"
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "потрібно %<constexpr%> для ініціалізації в класі статичного елемента даних %q#D не-цілочисельного типу"
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "ініціалізація в класі статичного елемента даних %q#D не літерального типу"
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "недійсна ініціалізація в класі статичного члена даних не-цілочисельного типу %qT"
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ забороняє ініціалізацію в класі неконстантного статичного члена %qD"
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ забороняє ініціалізацію константного члена %qD не-цілочисельного типу %qT"
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "розмір масиву %qD має нецілочисельний тип %qT"
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "розмір масиву має нецілочисельний тип %qT"
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "розмір масиву %qD не є цілочисельним сталим виразом"
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "розмір масиву не є цілочисельним сталим виразом"
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ забороняє масив нульового розміру %qD"
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ забороняє масив нульового розміру"
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ забороняє масив змінної довжини %qD"
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ забороняє масив змінної довжини"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "використовується масив змінної довжини %qD"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "використовується масив змінної довжини"
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "переповнення в розмірі масиву"
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%qD оголошено як масив типу заповнювача шаблону %qT"
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, gcc-internal-format
 msgid "creating array of template placeholder type %qT"
 msgstr "створення масиву типу заповнювача шаблону %qT"
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "оголошення %qD як масиву типу void"
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "створення масиву типу void"
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "оголошення %qD як масиву функцій"
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "створення масиву функцій"
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "оголошення %qD як масиву посилань"
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "створення масиву посилань"
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "оголошення %qD як масиву елементів-функцій"
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "створення масиву з функційними елементами"
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "оголошення %qD як багатовимірного масиву повинно мати межі для всіх вимірів, крім першого"
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "багатовимірний масив повинен мати межі для всіх вимірів, крім першого"
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr "масив змінної довжини з %<auto%>"
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "недійсна специфікація типу повернення для конструктора"
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "кваліфікатори не дозволені в оголошенні конструктора"
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "недійсна специфікація типу повернення для деструктора"
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "кваліфікатори не дозволені в оголошенні деструктора"
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "вказано тип повернення для оператора %<operator %T%>"
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "кваліфікатори не дозволені при оголошенні %<operator %T%>"
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "тип повернення вказаний для довідника виведення"
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "кваліфікатори не дозволені в оголошенні довідника виведення"
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "параметр шаблону шаблону %qT в оголошенні довідника виведення"
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "%<decl-specifier%> в оголошенні довідника виведення"
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "неіменована змінна або поле оголошені як void"
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "змінна або поле оголошені як void"
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "специфікатор %<inline%> недійсний для змінної %qD, оголошеної в області блоку"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "змінні «inline» доступні лише з %<-std=c++17%> або %<-std=gnu++17%>"
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT як тип, а не просто %<decltype(auto)%>"
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, gcc-internal-format
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "%<decltype(auto)%> не може мати кваліфікаторів cv"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "неправильне використання кваліфікованого імені %<::%D%>"
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "неправильне використання кваліфікованого імені %<%T::%D%>"
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "неправильне використання кваліфікованого імені %<%D::%D%>"
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, gcc-internal-format
 msgid "%q#T is not a class or namespace"
 msgstr "%q#T не є класом або простором імен"
 
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, gcc-internal-format
 msgid "declaration of %qE as non-function"
 msgstr "оголошення %qE як не-функції"
 
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, gcc-internal-format
 msgid "declaration of %qE as non-member"
 msgstr "оголошення %qE як не-члена"
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "відсутній ідентифікатор декларатора; використовується зарезервоване слово %qD"
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "визначення функції не оголошує параметри"
 
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "оголошення %qD як не-функції"
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "оголошення %qD як %<typedef%>"
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "оголошення %qD як параметра"
 
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr "вказано як %qs, так і %qs"
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%qs не може зʼявлятися в оголошенні typedef"
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr "можна використовувати не більше одного зі специфікаторів %<constinit%> та %<constexpr%>"
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "два або більше типи даних в оголошенні %qs"
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C++ не підтримує просте значення %<complex%>, що означає %<double complex%>"
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ забороняє декларацію %qs без типу"
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> не підтримується цільовою платформою"
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ не підтримує %<__int%d%> для %qs"
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> і %<unsigned%> вказані разом"
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> і %<short%> вказані разом"
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qs вказано з %qT"
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, gcc-internal-format
 msgid "%qs specified with typedef-name %qD"
 msgstr "%qs вказано з іменем typedef %qD"
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qs вказано з %<decltype%>"
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qs вказано з %<typeof%>"
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "комплексне число недійсне для %qs"
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr "відсутній список аргументів шаблону після %qE; для виведення, заповнювач шаблону повинен слідувати за простим ідентифікатором декларатора"
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "елемент %qD не може бути одночасно оголошений як %<virtual%> та %<static%>"
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "елемент %qD може бути оголошений як %<virtual%> та %<constexpr%> лише в %<-std=c++20%> або %<-std=gnu++20%>"
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "оголошення typedef недійсне в оголошенні параметра"
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "вказано специфікатор зберігання для параметра шаблону %qs"
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "вказано специфікатор зберігання для параметра %qs"
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "параметр не може бути оголошений як %qs"
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> поза оголошенням класу"
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "оголошення структурованого звʼязування не може бути %qs"
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "декларація структурованого звʼязування може бути тільки %qs у %<-std=c++20%> або %<-std=gnu++20%>"
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "структуроване звʼязування з %<volatile%> є застарілим"
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "оголошення структурованого звʼязування не може бути C++98 %<auto%>"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "оголошення структурованого звʼязування не може мати тип %qT"
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "тип повинен бути cv-кваліфікованим %<auto%> або посиланням на cv-кваліфікований %<auto%>"
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "оголошення структурованого звʼязування не може мати обмежений %<auto%> тип %qT"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "оголошення %qs має кілька класів зберігання"
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "вказано клас зберігання для %qs"
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "вкладена функція %qs оголошена %<extern%>"
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "оголошення верхнього рівня для %qs вказує %<auto%>"
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "функція %qs в області видимості функції неявно має тип auto і оголошена %<__thread%>"
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "специфікатори класу зберігання недійсні в оголошеннях дружніх функцій"
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "атрибут ігнорується"
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "атрибут, що належить до типового специфікатора, ігнорується"
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "зайві дужки в оголошенні %qs"
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, gcc-internal-format
 msgid "remove parentheses"
 msgstr "видалити дужки"
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, fuzzy, gcc-internal-format
 #| msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "виведення псевдоніма шаблону доступне лише з %<-std=c++20%> або %<-std=gnu++20%>"
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, fuzzy, gcc-internal-format
 #| msgid "Function %qs at %L cannot have an initializer"
 msgid "a function type cannot have an explicit object parameter"
 msgstr "Функція %qs на %L не може мати ініціалізатора"
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, fuzzy, gcc-internal-format
 #| msgid "a conversion function cannot have a trailing return type"
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr "Функція перетворення не може мати приєднаний тип повернення"
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, fuzzy, gcc-internal-format
 #| msgid "  member function type %qT is not a valid template argument"
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr "  тип функції-члена %qT не є допустимим аргументом шаблона"
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr ""
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, fuzzy, gcc-internal-format
 #| msgid "typedef may not be a member function definition"
 msgid "the type of an explicit object member function is a regular function type"
 msgstr "typedef не може бути визначенням методу класу"
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD declared here"
 msgid "valid explicit object parameter declared here"
 msgstr "параметр шаблона %qD оголошений тут"
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "замикання requires в типі повернення"
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "функція %qs використовує специфікатор типу %<auto%> без наступного типу повернення"
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "Визначений тип повернення доступний лише з %<-std=c++14%> або %<-std=gnu++14%>"
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "Віртуальна функція не може мати визначений тип повернення"
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "Функція %qs з типом повернення в кінці має тип %qT, а не простий %<auto%>"
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "Функція %qs з типом повернення в кінці має тип %<decltype(auto)%>, а не простий %<auto%>"
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "Неправильне використання %<decltype(auto)%>"
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "Виявлений тип класу %qD в типі повернення функції"
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "Посібник з виведення для %qT повинен мати тип повернення в кінці"
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "Тип повернення в кінці %qT посібника з виведення не є спеціалізацією %qT"
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "Тип повернення в кінці доступний лише з %<-std=c++11%> або %<-std=gnu++11%>"
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "Функція %qs з приєднаним типом повернення не оголошена зі специфікатором типу %<auto%>"
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "Функція перетворення не може мати приєднаний тип повернення"
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "Тип повернення з кваліфікатором %<volatile%> є застарілим"
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs оголошено як функцію, що повертає функцію"
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs оголошено як функцію, що повертає масив"
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<constinit%> на типі повернення функції не дозволено"
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "Деструктор не може бути статичною функцією-членом"
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "Конструктор не може бути статичною функцією-членом"
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "Деструктори не можуть мати кваліфікаторів cv"
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "Конструктори не можуть мати кваліфікаторів cv"
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "Деструктори не можуть мати кваліфікаторів ref"
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "Конструктори не можуть мати кваліфікаторів ref"
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "конструктори не можуть бути оголошені як %<virtual%>"
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "віртуальні функції не можуть бути друзями"
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "Оголошення друзів не визначено в описі класу"
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "Не можна визначити дружню функцію %qs в описі локального класу"
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr "визначення friend-функції %qs не може мати імені, яке кваліфіковане з %<::%>"
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr "визначення friend-функції %qs не може мати імені, яке кваліфіковане з %<%D::%>"
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr "функція, не є членом %qD, не може мати cv-кваліфікатор"
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, fuzzy, gcc-internal-format
 #| msgid "implicit templates may not be %<virtual%>"
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr "імпліцитні шаблони не можуть бути %<virtual%>"
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a member function"
 msgid "%qD cannot be an explicit object member function"
 msgstr "%qD повинна бути функцією-членом"
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "деструктори не можуть мати параметрів"
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "не можна оголосити вказівник на %q#T"
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "не можна оголосити посилання на %q#T"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "не можна оголосити вказівник на елемент %q#T"
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "не можна оголосити посилання на кваліфікований тип функції %qT"
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "не можна оголосити вказівник на кваліфікований тип функції %qT"
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "не можна оголосити посилання на %q#T, який не є псевдонімом або аргументом типу шаблону"
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "ідентифікатор шаблону %qD використовується як декларатор"
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "члени-функції є неявними друзями свого класу"
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "додаткова кваліфікація %<%T::%> на члені %qs"
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "не можна визначити метод %<%T::%s%> всередині %qT"
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "не можна оголосити метод %<%T::%s%> всередині %qT"
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "не можна оголосити член %<%T::%s%> всередині %qT"
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "непараметр %qs не може бути пакетом параметрів"
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "член даних не може мати змінно-модифікований тип %qT"
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "параметр не може мати змінно-модифікований тип %qT"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> поза оголошенням класу"
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> в оголошенні friend"
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "тільки оголошення конструкторів та операторів перетворення можуть бути %<explicit%>"
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "неможливо оголосити неметод %qs як %<mutable%>"
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "неможливо оголосити неметод %qs як %<mutable%>"
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "функцію %qs не можна оголосити як %<mutable%>"
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "%qs не може бути оголошено як %<mutable%>, оскільки воно %<static%>"
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "%qs не може бути оголошено як %<mutable%>, оскільки воно %<const%>"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "посилання %qs не може бути оголошено як %<mutable%>"
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "typedef не може бути визначенням функції"
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "typedef не може бути визначенням методу класу"
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<auto%> не дозволено в оголошенні псевдоніма"
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef оголошено як %<auto%>"
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "замикання «requires» на typedef"
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "Імʼя typedef не може бути вкладеним іменем-специфікатором"
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ забороняє вкладений тип %qD з таким самим імʼям, як усамітнюючий клас"
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> вказано для декларації класу friend"
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "Параметри шаблону не можуть бути друзями"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "Декларація friend вимагає ключ класу, тобто %<friend class %T::%D%>"
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "декларація друга потребує ключ-класу, тобто %<friend %#T%>"
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "Спроба зробити клас %qT другом глобального обсягу"
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "недійсні кваліфікатори на типі функції, яка не є членом"
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "замикання requires на тип-ідентифікаторі"
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "абстрактний декларатор %qT використовується як декларація"
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "замикання requires в декларації типу, що не є функцією %qT"
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "не можна використовувати %<::%> в декларації параметра"
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "не можна оголосити параметр з %<decltype(auto)%>"
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr "відсутній список аргументів шаблона після %qE; шаблонний заповнювач не допускається в параметрі"
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr "або використовуйте %<auto%> для скороченого шаблону функції"
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<auto%> параметр не допускається в цьому контексті"
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "параметр оголошено як %<auto%>"
 
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "недійсне використання імені шаблону %qE без списку аргументів"
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "член даних, оголошений як нестатичний з заповнювачем %qT"
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ забороняє гнучкий елемент масиву %qs"
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C++ забороняє гнучкі елементи масиву"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "недійсне використання %<::%>"
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "оголошення функції %qD в недійсному контексті"
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "функцію %qD оголошено як %<virtual%> всередині обʼєднання"
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD не може бути оголошено як %<virtual%>, оскільки воно завжди статичне"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "очікувався кваліфікований ідентифікатор у декларації friend для деструктора %qD"
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "оголошення %qD як члена %qT"
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "деструктор не може бути %qs"
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "очікувався кваліфікований ідентифікатор у декларації friend для конструктора %qD"
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "конструктор не може бути %<concept%>"
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "концепція не може бути методом класу"
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, gcc-internal-format
 msgid "%qD cannot be %qs"
 msgstr "%qD не може бути %qs"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "спеціалізація шаблону змінної %qD оголошена як функція"
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "шаблон змінної оголошено тут"
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "поле %qD має неповний тип %qT"
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "імʼя %qT має неповний тип"
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE не є функцією або методом класу; не може бути оголошений другом"
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "безіменне поле не є функцією або методом класу; не може бути оголошений другом"
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr "атрибут, що належить до декларації друга, яка не є визначенням, ігнорується"
 
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "статичний член даних %qE оголошений як %qs"
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "статичний член даних %<constexpr%> %qD повинен мати ініціалізатор"
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "нестатичний елемент даних %qE оголошений як %qs"
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "клас зберігання %<auto%> недійсний для функції %qs"
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "клас зберігання %<register%> недійсний для функції %qs"
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "клас зберігання %<__thread%> недійсний для функції %qs"
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "клас зберігання %<thread_local%> недійсний для функції %qs"
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, fuzzy, gcc-internal-format
 #| msgid "alignment specified for function %qE"
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr "вказано вирівнювання для функції %qE"
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "специфікатори virt в %qs не дозволені поза визначенням класу"
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "специфікатор %<static%> недійсний для функції %qs, оголошеної поза глобальним контекстом"
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "специфікатор %<inline%> недійсний для функції %qs, оголошеної поза глобальним контекстом"
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "віртуальна функція, що не належить до класу %qs"
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs визначено в області, що не належить до класу"
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs оголошено в області, що не належить до класу"
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "не можна оголосити метод члена %qD зі статичним звʼязуванням"
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "не можна оголосити статичну функцію всередині іншої функції"
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> не може бути використано при визначенні (на відміну від оголошення) статичного елемента даних"
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "статичний член %qD оголошено зі специфікатором %<register%>"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "не можна явно оголосити члена %q#D зовнішнім звʼязком"
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "оголошення змінної %qD з %<constexpr%> не є визначенням"
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "змінну не можна оголосити як %<consteval%>"
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs ініціалізовано та оголошено як %<extern%>"
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs має як %<extern%>, так і ініціалізатор"
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "аргумент за замовчуванням %qE використовує %qD"
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "аргумент за замовчуванням %qE використовує локальну змінну %qD"
 
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "неприпустиме використання типу %qT з кваліфікатором cv в оголошенні параметра"
 
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "неприпустиме використання типу %<void%> в оголошенні параметра"
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "параметр з кваліфікатором %<volatile%> застарілий"
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "параметр %qD неправильно оголошений як тип методу"
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "параметр %qD містить вказівник на масив невідомого розміру %qT"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "параметр %qD містить посилання на масив невідомого розміру %qT"
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "неправильний конструктор; ви, ймовірно, мали на увазі %<%T (const %T&)%>"
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD не може бути оголошений в межах простору імен"
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD не може бути оголошений як статичний"
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, gcc-internal-format
 msgid "%qD must be a non-static member function"
 msgstr "%qD повинна бути нестатичною функцією-членом"
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "%qD повинна бути функцією-членом"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "%qD може бути статичною функцією-членом лише з %<-std=c++23%> або %<-std=gnu++23%>"
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD повинна бути або нестатичною функцією-членом, або функцією, що не є членом"
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD повинна мати аргумент класу або перелічуваного типу"
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ забороняє перевантаження %<operator ?:%>"
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD не повинна мати змінну кількість аргументів"
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD повинна мати нуль або один аргумент"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD повинна мати один або два аргументи"
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "постфіксний %qD повинен мати %<int%> як свій аргумент"
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "постфіксний %qD повинен мати %<int%> як свій другий аргумент"
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD не повинна мати аргументів"
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD повинна мати рівно один аргумент"
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD повинна мати рівно два аргументи"
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD не може мати аргументів за замовчуванням"
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "перетворення %qT в %<void%> ніколи не використовуватиме оператор перетворення типу"
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "перетворення %qT в посилання на той самий тип ніколи не використовуватиме оператор перетворення типу"
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "перетворення %qT на той самий тип ніколи не використовуватиме оператор перетворення типу"
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "перетворення %qT на посилання на базовий клас %qT ніколи не використовуватиме оператор перетворення типу"
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "перетворення %qT на базовий клас %qT ніколи не використовуватиме оператор перетворення типу"
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "користувацький %qD завжди оцінює обидва аргументи"
 
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "префіксний %qD повинен повертати %qT"
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "постфіксний %qD повинен повертати %qT"
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD повинен повертати за значенням"
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "використання параметра типу шаблону %qT після %qs"
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "використання спеціалізації псевдоніма шаблону %qT після %qs"
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "використання імені typedef %qD після %qs"
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD має попередню декларацію тут"
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT згадується як %qs"
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT має попереднє оголошення тут"
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT згадується як перелічування"
@@ -57920,116 +57935,100 @@ msgstr "%qT згадується як перелічування"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "потрібен аргумент шаблону для %<%s %T%>"
 
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "посилання на %qD є неоднозначним"
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr "шаблон класу %qD перевизначено як не-шаблон"
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD має те саме імʼя, що і клас, в якому воно оголошено"
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT не є шаблоном"
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "можливо, ви хочете явно додати %<%T::%>"
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "використання перелічування %q#D без попередньої декларації"
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "повторне оголошення %qT як не-шаблону"
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, gcc-internal-format
-msgid "cannot declare %qD in a different module"
-msgstr "не можна оголосити %qD в іншому модулі"
-
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, gcc-internal-format
-msgid "previously declared here"
-msgstr "раніше оголошено тут"
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "похідне обʼєднання %qT недійсне"
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT визначено з кількома прямими базами"
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT визначено з прямим віртуальним базовим класом"
 
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "базовий тип %qT не є структурою або класом"
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "рекурсивний тип %qT не визначений"
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "подвійний базовий тип %qT недійсний"
 
-#: cp/decl.cc:16984
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare %qD in a different module"
-msgid "cannot declare %qD in different module"
-msgstr "не можна оголосити %qD в іншому модулі"
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "невідповідність між з областю видимості та без області видимості в перелічуванні %q#T"
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "попереднє визначення тут"
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "невідповідність підставного типу в перелічуванні %q#T"
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "різний підставний тип в перелічуванні %q#T"
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "тип основи %qT для %qT повинен бути цілочисельним типом"
@@ -58038,82 +58037,82 @@ msgstr "тип основи %qT для %qT повинен бути цілочи
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "жоден цілочисельний тип не може представити всі значення перелічування для %qT"
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "значення перелічування для %qD повинно мати цілочисельний або необмежений тип перелічування"
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "значення перелічування для %qD не є цілочисельною константою"
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "значення збільшеного перелічування занадто велике для %<unsigned long%>"
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "значення збільшеного перелічування занадто велике для %<long%>"
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "переповнення значень перелічування на %qD"
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "значення перелічування %qE знаходиться поза діапазоном базового типу %qT"
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "множинне визначення %q#T"
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "тип повернення %q#T неповний"
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> повинен повертати посилання на %<*this%>"
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "в функції, що повертає %qT, відсутні оператори повернення"
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "тільки простий тип повернення %<auto%> може бути виведений як %<void%>"
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, gcc-internal-format
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "в %<constexpr%> функції, яка повертає не-void, відсутній оператор return"
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD вже визначено в класі %qT"
 
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, gcc-internal-format
 msgid "using %qs"
 msgstr "використання %qs"
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "використання %qD до виведення типу %<auto%>"
@@ -58168,7 +58167,7 @@ msgstr "неможливо видалити функцію. Лише вказі
 msgid "deleting %qT is undefined"
 msgstr "видалення %qT не визначено"
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "шаблонне оголошення %q#D"
@@ -58178,7 +58177,7 @@ msgstr "шаблонне оголошення %q#D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "надані списки параметрів шаблону не відповідають параметрам шаблону %qD"
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "деструктор %qD оголошено як шаблон члена"
@@ -58362,65 +58361,65 @@ msgstr "знищувальний %<operator delete%> повинен бути з
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> приймає тип %qT як перший параметр"
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr "%qT має поле %q#D, тип якого не має звʼязку"
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT має поле %qD, тип якого залежить від типу %qT, який не має звʼязку"
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr "%qT має поле %q#D, тип якого має внутрішнє звʼязування"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr "%qT має поле %q#D, тип якого використовує анонімний простір імен"
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT оголошено з більшою видимістю, ніж тип його поля %qD"
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, gcc-internal-format
 msgid "%qT has a base %qT which has no linkage"
 msgstr "%qT має базу %qT, яка не має звʼязку"
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, gcc-internal-format
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr "%qT має базу %qT, яка залежить від типу %qT, який не має звʼязку"
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, gcc-internal-format
 msgid "%qT has a base %qT which has internal linkage"
 msgstr "%qT має базу %qT, яка має внутрішнє звʼязування"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, gcc-internal-format
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr "%qT має базу %qT, яка використовує анонімний простір імен"
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT оголошено з більшою видимістю, ніж його база %qT"
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D, declared using unnamed type, is used but never defined"
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr "%q#D, оголошений за допомогою безіменного типу, використовується, але ніколи не визначений"
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D, declared using unnamed type, is used but never defined"
 msgid "%q#D, declared using an unnamed type, is used but not defined"
@@ -58430,105 +58429,105 @@ msgstr "%q#D, оголошений за допомогою безіменног
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "безіменний тип без звʼязку використовується для оголошення змінної %q#D зі звʼязком"
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "безіменний тип без звʼязку використовується для оголошення функції %q#D зі звʼязком"
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q#D не посилається на некваліфікований тип, тому він не використовується для звʼязку"
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q#D, оголошений за допомогою локального типу %qT, використовується, але ніколи не визначений"
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D, declared using local type %qT, is used but never defined"
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr "%q#D, оголошений за допомогою локального типу %qT, використовується, але ніколи не визначений"
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "тип %qT без звʼязку використовується для оголошення змінної %q#D зі звʼязком"
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "тип %qT без звʼязку використовується для оголошення функції %q#D зі звʼязком"
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "декорування %q#D як %qE конфліктує з попереднім декоруванням"
 
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "попереднє декорування %q#D"
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, gcc-internal-format
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr "пізніший %<-fabi-version=%> (або =0) уникне цю помилку при допомозі зміни декорування"
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr "програма також повинна визначати %qD"
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "використовується вбудована функція %qD, але ніколи не визначена"
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q#D"
 msgstr "відсутній аргумент за замовчуванням для параметра %P функції %q#D"
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, gcc-internal-format
 msgid "...following parameter %P which has a default argument"
 msgstr "...після параметра %P, який має аргумент за замовчуванням"
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, gcc-internal-format
 msgid "implicitly-declared %qD is deprecated"
 msgstr "неявно оголошений %qD застарілий"
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr "тому що %qT має користувацький %qD"
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "перетворення лямбда-функції, яка використовує %<...%>, в вказівник на функцію"
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "використання видаленої функції %qD"
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "використання функції %qD з незадовільними обмеженнями"
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "використання вбудованого пакету параметрів %qD поза шаблоном"
@@ -58633,7 +58632,7 @@ msgstr "посилання на %<%T::%D%> є неоднозначним"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD не є членом %qT; ви мали на увазі %qs?"
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD не є членом %qT"
@@ -58643,7 +58642,7 @@ msgstr "%qD не є членом %qT"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD не є членом %qD; ви мали на увазі %qs?"
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD не є членом %qD"
@@ -58668,47 +58667,47 @@ msgstr "обробка винятків вимкнена, використову
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr "кидається NULL, який має цілочисельний, а не вказівний тип"
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, gcc-internal-format
 msgid "  in thrown expression"
 msgstr "  у викинутому виразі"
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, gcc-internal-format
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr "не можна оголосити параметр %<catch%> з типом rvalue reference %qT"
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, gcc-internal-format
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr "не можна кинути вираз типу %qT, оскільки він містить типи змінної розмірності"
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, gcc-internal-format
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr "не можна перехопити тип %qT, оскільки він містить типи змінної розмірності"
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, gcc-internal-format
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr "виняток типу %qT буде перехоплений раніше визначеним обробником"
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, gcc-internal-format
 msgid "for type %qT"
 msgstr "для типу %qT"
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, gcc-internal-format
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr "обробник %<...%> повинен бути останнім обробником для свого блоку try"
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr "вираз noexcept обчислюється як %<false%> через виклик %qD"
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
 msgstr "але %qD не викидає виняток; можливо, його слід оголосити як %<noexcept%>"
@@ -58975,12 +58974,12 @@ msgstr "тип %qT не є прямим або віртуальним базов
 msgid "type %qT is not a direct base of %qT"
 msgstr "тип %qT не є прямим базовим класом для %qT"
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "масив повинен бути ініціалізований за допомогою ініціалізатора, заключеного у фігурні дужки"
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT не є типом класу"
@@ -58995,12 +58994,12 @@ msgstr "неповний тип %qT не має члена %qD"
 msgid "invalid pointer to bit-field %qD"
 msgstr "недійсний вказівник на біт-поле %qD"
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "недійсне використання нестатичного член-функції %qD"
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "недійсне використання нестатичного члена даних %qD"
@@ -59195,52 +59194,52 @@ msgstr "видалення обʼєкта абстрактного класу т
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "видалення обʼєкта поліморфного класу типу %qT, який має невіртуальний деструктор, може призвести до невизначеного поведінки"
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "тип, переданий для векторного видалення, не є або вказівником, або масивом"
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr "масив з обмеженням часу виконання не може бути захоплений копіюванням, тільки посиланням"
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr "захоплення змінюваного типу %qT, який не є масивом N3639 з обмеженням часу виконання"
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr "тому що тип елемента масиву %qT має змінний розмір"
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "не можу захопити %qE по посиланню"
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "захоплення копією неповного типу %qT"
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr "спроба захопити %qD при інстанціюванні загального лямбда-виразу"
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr "неявне захоплення %qE через %<[=]%> застаріло в C++20"
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr "додайте явне захоплення %<this%> або %<*this%>"
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> не було захоплено для цієї лямбда-функції"
@@ -59611,223 +59610,276 @@ msgstr "неочікуваний формат або тип інкапсуляц
 msgid "encapsulation is malformed"
 msgstr "інкапсуляція має неправильний формат"
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, gcc-internal-format
 msgid "conflicting global module declaration %#qD"
 msgstr "конфліктуюча глобальна декларація модуля %#qD"
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, gcc-internal-format
 msgid "existing declaration %#qD"
 msgstr "існуюча декларація %#qD"
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, gcc-internal-format
 msgid "definition of %qD does not match"
 msgstr "визначення %qD не відповідає"
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, gcc-internal-format
 msgid "existing definition %qD"
 msgstr "існуюче визначення %qD"
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, gcc-internal-format
 msgid "... this enumerator %qD"
 msgstr "... цей перелічувач %qD"
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, gcc-internal-format
 msgid "enumerator %qD does not match ..."
 msgstr "перелічувач %qD не відповідає ..."
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr "додаткові перелічувачі, що починаються з %qD"
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr "діапазон перелічення відрізняється"
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr "%q#D посилається на сутність з внутрішньою звʼязком %q#D"
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, gcc-internal-format
 msgid "recursive lazy load"
 msgstr "рекурсивне ліниве завантаження"
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr "не можна імпортувати модуль у його власну сферу"
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, gcc-internal-format
 msgid "module %qs declared here"
 msgstr "модуль %qs оголошено тут"
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, gcc-internal-format
 msgid "indirect import %qs is not already loaded"
 msgstr "непрямий імпорт %qs ще не завантажено"
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr "імпорт %qs має невідповідність контрольної суми CRC"
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr "неможливо представити додаткові імпортовані джерела"
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr "не експортується %<#define %E%>, оскільки це ключове слово"
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, gcc-internal-format
 msgid "macro definitions of %qE corrupted"
 msgstr "визначення макросу %qE пошкоджено"
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, gcc-internal-format
 msgid "inconsistent imported macro definition %qE"
 msgstr "неспівпадаюче визначення імпортованого макросу %qE"
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr "%<#undef %E%>"
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr "%<#define %s%>"
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, gcc-internal-format
 msgid "compiled module file is %qs"
 msgstr "файл скомпільованого модуля - %qs"
 
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, gcc-internal-format, gfc-internal-format
 msgid "compiled module is %sversion %s"
 msgstr "скомпільований модуль - %sверсія %s"
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, gcc-internal-format, gfc-internal-format
 msgid "compiler is %sversion %s%s%s"
 msgstr "компілятор - %sверсія %s%s%s"
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, gcc-internal-format
 msgid "module %qs found"
 msgstr "знайдено модуль %qs"
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr "очікувався заголовок модуля, знайдено модуль %qs"
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr "очікувався модуль %qs, знайдено заголовок модуля"
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr "неспівпадання контрольної суми модуля %qs"
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr "ціль та хост - %qs:%qs, очікувалося %qs:%qs"
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr "Діалект мови відрізняється %qs, очікувався %qs"
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, gcc-internal-format
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr "Модуль містить OpenMP, використовуйте %<-fopenmp%>, щоб увімкнути його"
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, gcc-internal-format
 msgid "fixed tree mismatch"
 msgstr "несумісність виправленого дерева"
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, gcc-internal-format
 msgid "interface partition is not exported"
 msgstr "інтерфейсна частина не експортується"
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module cluster %u: %s"
 msgstr "не вдалося прочитати скомпільований модульний кластер %u: %s"
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module: %s"
 msgstr "не вдалося прочитати скомпільований модуль: %s"
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr "розгляньте використання %<-fno-module-lazy%>, збільшення значення %<-param-lazy-modules=%u%> або збільшення обмеження файлових дескрипторів на процес"
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr "імпорти мають бути побудовані перед імпортом"
 
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr "повернення до гейту через технічну проблему"
 
-#: cp/module.cc:19283
+#: cp/module.cc:19117
+#, gcc-internal-format
+msgid "declaration %qD conflicts with builtin"
+msgstr "декларація %qD конфліктує з вбудованою функцією"
+
+#: cp/module.cc:19122
+#, fuzzy, gcc-internal-format
+#| msgid "declaration %qD conflicts with import"
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr "декларація %qD конфліктує з імпортом"
+
+#: cp/module.cc:19125
+#, fuzzy, gcc-internal-format
+#| msgid "declaration %qD conflicts with import"
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr "декларація %qD конфліктує з імпортом"
+
+#: cp/module.cc:19130
+#, fuzzy, gcc-internal-format
+#| msgid "import declared %q#D here"
+msgid "import declared attached to module %qs"
+msgstr "імпорт оголошено %q#D тут"
+
+#: cp/module.cc:19134
+#, fuzzy, gcc-internal-format
+#| msgid "import-declaration must be at global scope"
+msgid "import declared in global module"
+msgstr "Декларація імпорту повинна бути в глобальному контексті"
+
+#: cp/module.cc:19140
+#, fuzzy, gcc-internal-format
+#| msgid "conflicting declaration of template %q#D"
+msgid "conflicting declaration of %qD in module %qs"
+msgstr "конфліктна декларація шаблону %q#D"
+
+#: cp/module.cc:19143
+#, fuzzy, gcc-internal-format
+#| msgid "conflicting declaration of %q#D with %qL linkage"
+msgid "conflicting declaration of %qD in global module"
+msgstr "конфліктуюче оголошення %q#D з %qL звʼязком"
+
+#: cp/module.cc:19148
+#, fuzzy, gcc-internal-format
+#| msgid "previously declared as %s"
+msgid "previously declared in module %qs"
+msgstr "раніше оголошено як %s"
+
+#: cp/module.cc:19152
+#, fuzzy, gcc-internal-format
+#| msgid "previously declared as %s"
+msgid "previously declared in global module"
+msgstr "раніше оголошено як %s"
+
+#: cp/module.cc:19404
 #, gcc-internal-format
 msgid "reading CMI %qs"
 msgstr "читання CMI %qs"
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E%>"
 msgstr "не вдалося завантажити звʼязування %<%E%s%E%>"
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr "не вдалося завантажити звʼязування %<%E%s%E@%s%>"
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr "під час завантаження звʼязування %<%E%s%E%>"
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr "під час завантаження звʼязування %<%E%s%E@%s%>"
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, gcc-internal-format
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr "не вдалося завантажити очікувані одиниці для %<%E%s%E%>"
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, gcc-internal-format
 msgid "during load of pendings for %<%E%s%E%>"
 msgstr "під час завантаження очікуваних одиниць для %<%E%s%E%>"
@@ -59839,302 +59891,302 @@ msgstr "під час завантаження очікуваних одиниц
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr "імпорт іменованого модуля %qs всередині блоку мовного звʼязку"
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, gcc-internal-format
 msgid "module already declared"
 msgstr "модуль вже оголошено"
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, gcc-internal-format
 msgid "module already imported"
 msgstr "модуль вже імпортовано"
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, gcc-internal-format
 msgid "module %qs imported here"
 msgstr "модуль %qs імпортовано тут"
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown Compiled Module Interface: %s"
 msgstr "невідомий скомпільований інтерфейс модуля (CMI): %s"
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr "не вдалося визначити переклад %<#include%> для %s: %s"
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr "включення %qs перекладено як імпорт"
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr "включення %qs оброблено текстово"
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, gcc-internal-format
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr "Модулі C++ несумісні з попередньо скомпільованими заголовками"
 
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, gcc-internal-format
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr "Модулі C++ несумісні з традиційною попередньою обробкою"
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr "відлагоджувальний вивід макросів може бути неповним з модулями"
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr "залежності модулів вимагають попередньої обробки"
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, gcc-internal-format
 msgid "you should use the %<-%s%> option"
 msgstr "ви повинні використовувати опцію %<-%s%>"
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, gcc-internal-format
 msgid "invalid header name %qs"
 msgstr "неприпустиме імʼя заголовка %qs"
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, gcc-internal-format
 msgid "invalid module name %qs"
 msgstr "неприпустиме імʼя модуля %qs"
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr "%<-fmodule-only%> використовується для неінтерфейсу"
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, gcc-internal-format
 msgid "writing CMI %qs"
 msgstr "запис CMI %qs"
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, gcc-internal-format
 msgid "not writing module %qs due to errors"
 msgstr "не вдається записати модуль %qs через помилки"
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to write compiled module: %s"
 msgstr "не вдалося записати скомпільований модуль: %s"
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, gcc-internal-format
 msgid "unknown header kind %qs"
 msgstr "невідомий тип заголовка %qs"
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, fuzzy, gcc-internal-format
 #| msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr "виведення псевдоніма шаблону доступне лише з %<-std=c++20%> або %<-std=gnu++20%>"
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "перевизначення %q#D з різними параметрами шаблону"
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D конфліктує з попереднім оголошенням"
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D приховує конструктор для %q#D"
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "конфліктна декларація звʼязку мови C %q#D"
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "через різні специфікації винятків"
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, gcc-internal-format
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "параметр лямбда-виразу %qD вже був оголошений як захоплення"
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "оголошення %q#D затіняє параметр"
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "оголошення %qD затіняє член %qT"
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "дружня декларація %qD в локальному класі без попередньої локальної декларації"
 
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %<%s(%E)%> %p %d"
 
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, gcc-internal-format
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d"
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D does not have external linkage"
 msgid "exporting %q#D that does not have external linkage"
 msgstr "%q#D не має зовнішнього звʼязку"
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D declared here"
 msgid "%q#D declared here with no linkage"
 msgstr "%q#D оголошений тут"
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D does not have external linkage"
 msgid "%q#D declared here with internal linkage"
 msgstr "%q#D не має зовнішнього звʼязку"
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D declared here"
 msgid "%q#D declared here with module linkage"
 msgstr "%q#D оголошений тут"
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, gcc-internal-format
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T%s%D%> називає деструктор"
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "оголошення «using» для не-члена на рівні області класу"
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "%<using%> з областю перелічення %q#T доступний лише з %<-std=c++20%> або %<-std=gnu++20%>"
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qT не є класом, простором імен або переліченням"
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "оголошення «using» для не-члена називає конструктор %qT"
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr "оголошення «using» для члена на рівні поза класом"
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, gcc-internal-format
 msgid "%qT is not a direct base of %qT"
 msgstr "%qT не є прямим базовим класом %qT"
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr "ви мали на увазі %<using enum %T::%D%>?"
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "%qD не було оголошено в %qD"
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "оголошення «using» не може називати простір імен %qD"
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> називає конструктор в %qT"
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "оголошення %qD не знаходиться в просторі імен, що оточує %qD"
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "явна кваліфікація в оголошенні %qD"
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD повинно бути оголошено всередині %qD"
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD не було оголошено всередині %qD"
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, gcc-internal-format
 msgid "only here as a %<friend%>"
 msgstr "тільки тут як %<friend%>"
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "атрибут %qD вимагає одного аргументу NTBS"
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "атрибут %qD не має сенсу, оскільки елементи анонімного простору імен отримують локальні символи"
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "ігнорується атрибут %qD на анонімному просторі імен"
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "ігнорування атрибуту %qD на неінлайновому просторі імен"
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "ігнорування директиви атрибуту %qD"
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "максимальний ліміт %d просторів імен, що шукаються для %qE"
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -60142,94 +60194,94 @@ msgstr[0] "запропонована альтернатива:"
 msgstr[1] "запропоновані альтернативи:"
 msgstr[2] "запропоновані альтернативи:"
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, fuzzy, gcc-internal-format
 #| msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr "%<std::%s%> визначено в заголовку %qs; ви забули %<#include %s%>?"
 
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%<std::%s%> доступний лише з %s"
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "макро %qs ще не було визначено"
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, gcc-internal-format
 msgid "it was later defined here"
 msgstr "воно було пізніше визначено тут"
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "оголошення %<std::initializer_list%> не відповідає %<#include <initializer_list>%>, не є шаблоном"
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, gcc-internal-format
 msgid "%<strong%> using directive no longer supported"
 msgstr "%<strong%> директива using більше не підтримується"
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr "замість цього ви можете використовувати вбудований простір імен"
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, gcc-internal-format
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr "%<omp::%E%> не може бути вказано в цьому контексті"
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "не можна вкладати більше %d просторів імен"
 
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%<namespace %E%> є неоднозначним"
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "псевдонім простору імен %qD не дозволений тут, припускаємо %qD"
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "вбудований простір імен повинен бути вказаний при початковому визначенні"
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD визначено тут"
 
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "простір імен %s %qD конфліктує з досяжним визначенням"
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "досяжне визначення %s тут"
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, gcc-internal-format
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX входження в %<pop_everything ()%>"
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, gcc-internal-format
 msgid "XXX leaving %<pop_everything ()%>"
 msgstr "XXX залишає %<pop_everything ()%>"
@@ -60254,7 +60306,7 @@ msgstr "ідентифікатор %qE є ключовим словом в C++20
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr "%<LEXER_DEBUGGING_ENABLED_P%> не встановлено на true"
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare %s%> не негайно слідує за оголошенням або визначенням функції"
@@ -60500,7 +60552,7 @@ msgstr "C++20 %<constinit%> доступний лише з %<-std=c++20%> або
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<concept%> доступно лише з %<-std=c++20%> або %<-fconcepts%>"
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<requires%> доступно лише з %<-std=c++20%> або %<-fconcepts%>"
@@ -60680,7 +60732,7 @@ msgstr "вирази-оператори не дозволяються поза 
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "вирази складання доступні лише з %<-std=c++17%> або %<-std=gnu++17%>"
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "очікується первинний вираз"
@@ -60736,7 +60788,7 @@ msgstr "%<~auto%> доступний лише з %<-std=c++14%> або %<-std=gn
 msgid "template-id not allowed for destructor in C++20"
 msgstr "template-id не дозволено для деструктора"
 
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, fuzzy, gcc-internal-format
 #| msgid "remove parentheses"
 msgid "remove the %qs"
@@ -60757,7 +60809,7 @@ msgstr "імʼя typedef %qD використовується як деклар
 msgid "expected unqualified-id"
 msgstr "очікувано некваліфікований ідентифікатор"
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD не є шаблоном"
@@ -60807,7 +60859,7 @@ msgstr "типи не можуть бути визначені у виразі %
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "неправильна кількість аргументів для %<__builtin_addressof%>"
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "неправильна кількість аргументів для %<__builtin_launder%>"
@@ -60843,7 +60895,7 @@ msgstr "Типи не можуть бути визначені всередин
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr ""
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "неправильне використання %qD"
@@ -60868,7 +60920,7 @@ msgstr "ISO C++ не дозволяє %<alignof%> з не-типом"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "Типи не можуть бути визначені в виразах %<noexcept%>"
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "Типи не можуть бути визначені в виразах %qs"
@@ -61018,8 +61070,8 @@ msgstr "порожній ініціалізатор для захоплення
 msgid "capture of non-variable %qE"
 msgstr "захоплення незмінної %qE"
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D оголошений тут"
@@ -61059,7 +61111,7 @@ msgstr "вказано значення за замовчуванням для 
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "Оголошення параметра перед специфікаторами оголошення лямбди є необовʼязковим лише з %<-std=c++2b%> або %<-std=gnu++2b%>"
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr ""
@@ -61186,7 +61238,7 @@ msgstr "%<if consteval%> вимагає складений оператор"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "ініціалізуюча-інструкція в операторах вибору доступна лише з %<-std=c++17%> або %<-std=gnu++17%>"
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "очікується оператор вибору"
@@ -61248,7 +61300,7 @@ msgstr "вираз %<for%> на основі діапазону з типом %q
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "несумісні типи початку/кінця в операторі %<for%> на основі діапазону: %qT і %qT"
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "очікується оператор ітерації"
@@ -61274,7 +61326,7 @@ msgstr "%<goto%> у функції %<constexpr%> доступний лише з
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ забороняє обчислювані переходи"
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "очікується оператор переходу"
@@ -61558,12 +61610,12 @@ msgstr "лише конструктори приймають ініціаліз
 msgid "cannot expand initializer for member %qD"
 msgstr "не вдається розгорнути ініціалізатор для члена %qD"
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "ініціалізатор mem для %qD слідує за делегуванням конструктора"
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "делегування конструктора слідує за ініціалізатором mem для %qD"
@@ -62204,7 +62256,7 @@ msgstr "відсутні аргументи шаблону після %qE"
 msgid "%qT not permitted in template argument"
 msgstr "%qT не допускається в аргументі шаблону"
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, gcc-internal-format
 msgid "invalid use of %qT"
@@ -62386,12 +62438,12 @@ msgstr "попереднє визначення %q#T"
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, gcc-internal-format
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr "нерозгорнутий пакет параметрів у локальному класі в лямбді"
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "очікується ключ-клас"
@@ -62594,37 +62646,37 @@ msgstr "атрибут, що використовує префікс, досту
 msgid "expression must be enclosed in parentheses"
 msgstr "вираз повинен бути укладений у дужки"
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr "відсутнє додаткове %<requires%>, щоб почати вимогу-вираз"
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr "перевірка, чи є ідентифікатор концепції дійсним виразом; додайте %<requires%>, щоб перевірити задоволеність"
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, gcc-internal-format
 msgid "result type is not a plain type-constraint"
 msgstr "тип результату не є простою обмеженням типу"
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "%<return-type-requirement%> не є обмеженням типу"
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "спеціалізація члена %<%T::%E%> вимагає синтаксису %<template<>%>"
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "недійсна декларація %<%T::%E%>"
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "занадто мало списків параметрів шаблону"
@@ -62633,439 +62685,439 @@ msgstr "занадто мало списків параметрів шаблон
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "занадто багато списків параметрів шаблону"
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, fuzzy, gcc-internal-format
 #| msgid "template-id not allowed for destructor"
 msgid "template-id not allowed for constructor in C++20"
 msgstr "template-id не дозволено для деструктора"
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "іменовані значення повернення більше не підтримуються"
 
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr "ISO C++ не прийняв операторні шаблони літералів рядків, які приймають набір аргументів з символів"
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "шаблон оператора літералу %qD має неприпустимий список параметрів; очікувався набір не-типових параметрів шаблону %<<char...>%> або один не-типовий параметр класового типу"
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "шаблон оператора літералу %qD має неприпустимий список параметрів; очікувався шаблон для набору не-типових аргументів %<<char...>%>"
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr "введення шаблонів не є частиною концепцій C++20; використовуйте %qs для активації"
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "немає відповідної концепції для введення шаблону"
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "недійсна декларація шаблону члена в локальному класі"
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "шаблон з C-звʼязком"
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "недійсна явна спеціалізація"
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "декларація шаблону %<typedef%>"
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "декларація шаблону класу не повинна декларувати щось інше"
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "явна спеціалізація шаблону не може мати клас зберігання"
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> повинно бути %<> >%> в межах вкладеного списку аргументів шаблону"
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "неправильне використання %<>>%>, використовуйте %<>%>, щоб закінчити список аргументів шаблону"
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, gcc-internal-format
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr "%qs повинно бути %qs для завершення списку аргументів шаблону"
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "аргумент %<sizeof...%> повинен бути оточений дужками"
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "неправильне використання %qD в специфікації звʼязку"
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, gcc-internal-format
 msgid "duplicate %qD specifier"
 msgstr "повторний вказівник %qD"
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, gcc-internal-format
 msgid "%qD specifier conflicts with %qs"
 msgstr "вказівник %qD конфліктує з %qs"
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> перед %qD"
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, gcc-internal-format
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr "вказівник %qD конфліктує з %<typedef%>"
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 не підтримує %<long long%>"
 
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "вказано як %<__thread%>, так і %<thread_local%>"
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "подвійне %qD"
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "подвійне %qs"
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "очікується %<new%>"
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "очікується %<delete%>"
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "очікується %<return%>"
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "очікується %<extern%>"
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "очікується %<static_assert%>"
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "очікується %<decltype%>"
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "очікується %<operator%>"
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "очікується %<class%>"
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "очікується %<template%>"
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "очікується %<namespace%>"
 
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "очікувався %<using%>"
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "очікувався %<asm%>"
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "очікувався %<try%>"
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "очікувався %<catch%>"
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "очікувався %<throw%>"
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "очікувався %<auto%>"
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "очікувався %<__label__%>"
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "очікувався %<@try%>"
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "очікувався %<@synchronized%>"
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "очікувався %<@throw%>"
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "очікувався %<__transaction_atomic%>"
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "очікувався %<__transaction_relaxed%>"
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "очікувався %<co_yield%>"
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "очікувався %<::%>"
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "очікувався %<...%>"
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "очікувався %<*%>"
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "очікувався %<~%>"
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "очікувався %<:%> або %<::%>"
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "очікувався %<class%>, %<typename%> або %<template%>"
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr "зайвий ключ переліку %<enum%s%> у посиланні на %q#T"
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "тег %qs використовується при наданні імені %q#T"
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T було раніше оголошено тут"
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, gcc-internal-format
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "зайвий ключ класу %qs у посиланні на %q#T"
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT оголошено з несумісним ключем класу %qs"
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr "видаліть ключ класу або замініть його на %qs"
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "замініть ключ класу на %qs"
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "%qT визначено як %qs тут"
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "%qT вперше оголошено як %qs тут"
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD повторно оголошено з різним доступом"
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "у C++98 %<template%> (як розрізнювач) дозволено лише в межах шаблонів"
 
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "файл закінчується на типовий аргумент"
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "неправильно розташований конструкт Objective-C++ %<@%D%>"
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "очікується отримувач повідомлення objective-c++"
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "очікується аргумент(и) повідомлення objective-c++"
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> повинен вказувати тип як аргумент"
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "недійсне імʼя селектора Objective-C++"
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "очікується оголошення методу objective-c++"
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "атрибути методу повинні бути вказані в кінці"
 
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "зайвий %qs між методами Objective-C++"
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "недійсний тип для змінної екземпляра"
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "очікується ідентифікатор після %<@protocol%>"
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "атрибути не можуть бути вказані перед ключовим словом Objective-C++ %<@%D%>"
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "Префіксні атрибути ігноруються перед %<@%D%>"
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "Недійсний тип для властивості"
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr "Невідомий атрибут властивості %qE"
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "Очікувалась список цілочисельних виразів"
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "Вираз %<wait%> повинен бути цілочисельним"
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr "очікується %<scalar%>, %<aggregate%> або %<pointer%>"
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "Недійсний ідентифікатор зведення"
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "Типи не можуть бути визначені в типі ітератора"
@@ -63074,12 +63126,12 @@ msgstr "Типи не можуть бути визначені в типі іт
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, gcc-internal-format
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "%<#pragma omp allocate%> ще не підтримується"
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "У круглих дужках ініціалізація не дозволена в циклі OpenMP %<for%>"
@@ -63089,134 +63141,134 @@ msgstr "У круглих дужках ініціалізація не дозв
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "Замикання %<ordered%> з параметром в циклі %<for%> з діапазоном"
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "ітераційна змінна %qD не повинна бути зведенням"
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp declare %s%> за яким слідує %<#pragma omp declare %s%>"
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr "Директива OpenMP, відмінна від %<declare simd%> або %<declare variant%>, належить до оголошення"
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "недійсне замикання ініціалізатора"
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "очікується id-вираз (аргументи)"
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "одним з аргументів виклику ініціалізатора повинен бути %<omp_priv%> або %<&omp_priv%>"
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "типи не можуть бути визначені в списку типів для зведення"
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "попередньо визначений арифметичний тип %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "тип функції або масиву %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "тип посилання %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "тип %qT з кваліфікаторами %<const%>, %<volatile%> або %<__restrict%> в %<#pragma omp declare reduction%>"
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> називає набір перевантажень"
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD не посилається на функцію в області простору імен"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr "%<atomic_cancel%>"
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> без підтримки транзакційної памʼяті"
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> без включеної підтримки транзакційної памʼяті"
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "зовнішній %<__transaction_cancel%> не знаходиться всередині зовнішнього %<__transaction_atomic%>"
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  або функція %<transaction_may_cancel_outer%>"
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "неправильно сформований %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp requires%> може використовуватися тільки на рівні файлу або простору імен"
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, gcc-internal-format
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp assumes%> може використовуватися тільки на рівні файлу або простору імен"
 
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> повинен бути всередині функції"
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, gcc-internal-format
 msgid "multi-source compilation not implemented for C++"
 msgstr "багатоджерельна компіляція не реалізована для C++"
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, gcc-internal-format
 msgid "placeholder type not allowed in this context"
 msgstr "тип-заповнювач не дозволений в цьому контексті"
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "імпліцитні шаблони не можуть бути %<virtual%>"
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr "звʼязування %<extern \"C\"%> почалося тут"
@@ -63246,7 +63298,7 @@ msgstr "обрамлюючі шаблони класу не є явно спец
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "спеціалізація %qD повинна зʼявитися в області простору імен"
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "спеціалізація %qD в різних просторах імен"
@@ -63261,170 +63313,170 @@ msgstr "  з визначення %q#D"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "явне інстанціювання %qD в просторі імен %qD (який не містить простір імен %qD)"
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "назва класу затіняє параметр шаблону шаблону %qD"
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "спеціалізація псевдоніму шаблону %qD"
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "явна спеціалізація непатрону %qT"
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "спеціалізація %qT після інстанціювання"
 
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, gcc-internal-format
 msgid "from definition of %q#D"
 msgstr "з визначення %q#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "спеціалізація %qT після інстанціювання %qT"
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "спеціалізація шаблону %qD не дозволена за стандартом ISO C++"
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "спеціалізація %qD після інстанціювання"
 
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %#qD"
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD не є шаблоном функції"
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD не є шаблоном змінної"
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "template-id %qD для %q+D не відповідає жодній декларації шаблону"
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "знайдено %d %<template<>%>, потрібно %d для спеціалізації шаблону функції-члена"
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "неоднозначна спеціалізація шаблону %qD для %q+D"
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "змінні шаблони доступні лише з %<-std=c++14%> або %<-std=gnu++14%>"
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "занадто багато заголовків шаблону для %qD (повинно бути %d)"
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr "елементи явно спеціалізованого класу визначені без заголовка шаблону"
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "явна спеціалізація %qD поза його простором імен повинна використовувати вкладений імʼя"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "явне інстанціювання %qD поза його простором імен повинно використовувати вкладений імʼя"
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "явна спеціалізація %q#D може мати відсутні атрибути"
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "відсутні атрибути основного шаблону %s"
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "відсутній атрибут основного шаблону %s"
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, gcc-internal-format
 msgid "template-id %qE in declaration of primary template"
 msgstr "ідентифікатор шаблону %qE в оголошенні основного шаблону"
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "список параметрів шаблону, використаний у явному інстанціюванні"
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "надано визначення для явного інстанціювання"
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "занадто багато списків параметрів шаблону в оголошенні %qD"
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "занадто мало списків параметрів шаблону в оголошенні %qD"
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "явна спеціалізація %qD повинна бути введена за допомогою %<template <>%>"
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr "явна спеціалізація оголошена %<concept%>"
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "часткова спеціалізація без типу %qE не дозволена"
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "часткова спеціалізація %qE не дозволена для не-класів та не-змінних"
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "задано значення за замовчуванням у явній спеціалізації"
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD не є шаблонною функцією"
@@ -63437,137 +63489,137 @@ msgstr "%qD не є шаблонною функцією"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "спеціалізація неявно оголошеної спеціальної членової функції"
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "членова функція %qD не оголошена в %qT"
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "декларація friend %qD не видима для явної спеціалізації"
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, gcc-internal-format
 msgid "friend declaration here"
 msgstr "декларація friend тут"
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr "явна спеціалізація концепції функції %qD"
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, gcc-internal-format
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "аргумент для %<__integer_pack%> повинен бути між 0 і %d"
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "розширення базового ініціалізатора %qT не містить параметрних пакетів"
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "шаблон розширення %qT не містить параметричних пакетів"
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "шаблон розширення %qE не містить параметричних пакетів"
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "параметричні пакети не розгорнуті з %<...%>:"
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr "        %s"
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "оголошення параметра шаблона %q+D затіняє параметр шаблона"
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "оголошення %q+#D затіняє параметр шаблона"
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "параметр шаблона %qD оголошений тут"
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "спеціалізація концепції змінної %q#D"
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "параметри шаблону не можуть бути виведені в частковій спеціалізації:"
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "часткова спеціалізація %q+D не спеціалізує жодних аргументів шаблону; для визначення основного шаблону, видаліть список аргументів шаблону"
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "часткова спеціалізація %q+D не спеціалізує жодних аргументів шаблону і не є більш обмеженою, ніж основний шаблон; для визначення основного шаблону, видаліть список аргументів шаблону"
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "основний шаблон тут"
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "часткова спеціалізація не є більш спеціалізованою, ніж основний шаблон, оскільки вона замінює кілька параметрів розширенням пакета"
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, gcc-internal-format
 msgid "too many arguments for partial specialization %qT"
 msgstr "занадто багато аргументів для часткової спеціалізації %qT"
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "часткова спеціалізація %qD не є більш спеціалізованою, ніж"
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "основний шаблон %qD"
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "аргумент пакету параметрів %qE повинен бути в кінці списку аргументів шаблону"
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "аргумент пакету параметрів %qT повинен бути в кінці списку аргументів шаблону"
 
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -63575,17 +63627,17 @@ msgstr[0] "тип %qT аргументу шаблону %qE залежить в
 msgstr[1] "тип %qT аргументу шаблону %qE залежить від параметрів шаблону"
 msgstr[2] "тип %qT аргументу шаблону %qE залежить від параметрів шаблону"
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "декларація %qD ускладнює попередню інстанціацію шаблону для %qD"
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "часткова спеціалізація %qD після інстанціації %qD"
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "немає стандартного аргументу для %qD"
@@ -63594,47 +63646,47 @@ msgstr "немає стандартного аргументу для %qD"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "пакет параметрів %q+D повинен бути в кінці списку параметрів шаблону"
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "стандартні аргументи шаблону не можуть бути використані в повторній декларації дружньої функції шаблону"
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "стандартні аргументи шаблону не можуть бути використані в деклараціях дружніх шаблонів"
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "стандартні аргументи шаблону не можуть бути використані в функціональних шаблонах без %<-std=c++11%> або %<-std=gnu++11%>"
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "Стандартні аргументи шаблону не можуть використовуватися в часткових спеціалізаціях"
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "Стандартний аргумент для параметра шаблону для класу, що оточує %qD"
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "шаблон %qD оголошено"
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "шаблон класу без назви"
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "член шаблону %qD не може мати віртуальних специфікаторів"
@@ -63644,62 +63696,62 @@ msgstr "член шаблону %qD не може мати віртуальни
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "недійсне оголошення шаблону %qD"
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "визначення шаблону для нешаблону %q#D"
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "очікувалося %d рівнів параметрів шаблону для %q#D, отримано %d"
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "отримано %d параметрів шаблону для %q#D"
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "отримано %d параметрів шаблону для %q#T"
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  але потрібно %d"
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "аргументи шаблону для %qD не відповідають оригінальному шаблону %qD"
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "використовуйте %<template<>%> для явної спеціалізації"
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, gcc-internal-format
 msgid "redeclaration of %qD with different constraints"
 msgstr "повторна декларація %qD з різними обмеженнями"
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT не є типом шаблону"
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "специфікатори шаблону не вказані в оголошенні %qD"
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -63707,7 +63759,7 @@ msgstr[0] "повторно оголошено з %d параметром шаб
 msgstr[1] "повторно оголошено з %d параметрами шаблону"
 msgstr[2] "повторно оголошено з %d параметрами шаблону"
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -63715,437 +63767,437 @@ msgstr[0] "попереднє оголошення %qD використовув
 msgstr[1] "попереднє оголошення %qD використовувало %d параметри шаблону"
 msgstr[2] "попереднє оголошення %qD використовувало %d параметрів шаблону"
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "параметр шаблону %q+#D"
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "перевизначено тут як %q#D"
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, gcc-internal-format
 msgid "redeclared here"
 msgstr "перевизначено тут"
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "оголошення параметра шаблону %q+#D з різними обмеженнями"
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "оригінальне оголошення зʼявилося тут"
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, gcc-internal-format
 msgid "redeclaration of %q#D with different constraints"
 msgstr "перевизначення %q#D з різними обмеженнями"
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE не є дійсним аргументом шаблону для типу %qT"
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "це повинна бути адреса функції з зовнішнім звʼязком"
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "це повинно бути імʼя функції з зовнішнім звʼязком"
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE не є дійсним аргументом шаблону для типу %qT, оскільки %qD не має звʼязку"
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE не є дійсним аргументом шаблону для типу %qT, оскільки %qD не має зовнішнього звʼязку"
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "він повинен бути вказівником на член у вигляді %<&X::Y%>"
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "тому що він є членом %qT"
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  не вдалося вивести параметр шаблону %qD"
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  типи %qT і %qT мають несумісні cv-якірники"
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  несумісні типи %qT і %qT"
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  параметр шаблону %qD не є пакетом параметрів, але аргумент %qD є"
 
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  аргумент шаблону %qE не відповідає сталому вказівнику на члена %qE"
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE не еквівалентний %qE"
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  непослідовна виведення пакету параметрів з %qT і %qT"
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  виведені конфліктуючі типи для параметра %qT (%qT та %qT)"
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  виведені конфліктуючі значення для параметра не-типу %qE (%qE та %qE)"
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  тип масиву змінної розмірності %qT не є допустимим аргументом шаблона"
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  тип функції-члена %qT не є допустимим аргументом шаблона"
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  не вдається перетворити %qE (тип %qT) в тип %qT"
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT є неоднозначним базовим класом для %qT"
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT не походить від %qT"
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  параметри шаблона шаблонного аргумента несумісні з іншими виведеними шаблонними аргументами"
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  не можу вивести шаблон для %qT з нешаблонного типу %qT"
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "  аргумент шаблона %qE не відповідає %qE"
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr "%qE не є дійсним аргументом шаблона типу %qT, оскільки %qE не є змінною або функцією"
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE не є дійсним аргументом шаблона типу %qT в C++98, оскільки %qD не має зовнішнього звʼязку"
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE не є дійсним аргументом шаблону типу %qT, оскільки %qD не має звʼязку"
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "адреса %qD не є дійсним аргументом шаблону"
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "адреса підобʼєкта %qT обʼєкта %qD не є дійсним аргументом шаблону"
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "адреса %qD не є дійсним аргументом шаблону, оскільки вона не має статичної тривалості зберігання"
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD не є дійсним аргументом шаблону, оскільки %qD є змінною, а не адресою змінної"
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE не є дійсним аргументом шаблону для %qT, оскільки це не є адреса змінної"
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE не є дійсним аргументом шаблону для типу %qT, оскільки рядкові літерали ніколи не можуть бути використані в цьому контексті"
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "у аргументі шаблону для типу %qT"
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "аргумент шаблону %qE для типу %qT не є константою часу компіляції"
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE не є дійсним аргументом шаблону для типу %qT через конфлікти в cv-кваліфікації"
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE не є дійсним аргументом шаблону для типу %qT, оскільки він не є l-значенням"
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D не є допустимим аргументом шаблону для типу %qT, оскільки змінна посилання не має сталої адреси"
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE не є дійсним аргументом шаблону для типу %qT, оскільки це вказівник"
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "спробуйте використовувати %qE замість цього"
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE не є дійсним аргументом шаблону для типу %qT, оскільки він має тип %qT"
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "ігнорування атрибутів на аргументі шаблону %qT"
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "ігнорування атрибутів в аргументі шаблону %qE"
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "використання введеного імені класу %qD як аргументу шаблону"
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "недійсне використання деструктора %qE як типу"
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "щоб посилатися на член типу параметра шаблону, використовуйте %<typename %E%>"
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "неспівпадіння типу/значення в аргументі %d у списку параметрів шаблону для %qD"
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  очікувався константний тип %qT, отримано %qT"
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "  неоднозначний аргумент шаблону для неперемінного параметра шаблону розглядається як функційний тип"
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  очікувався класовий шаблон, отримано %qE"
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  очікувався тип, отримано %qE"
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  очікувався тип, отримано %qT"
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  очікувався класовий шаблон, отримано %qT"
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  очікувався шаблон типу %qD, отримано %qT"
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "несумісні обмеження для аргументу %d у списку параметрів шаблону для %qD"
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  очікувався %qD, отримано %qD"
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "не вдалося конвертувати аргумент шаблона %qE з %qT в %qT"
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "аргумент шаблону %d недійсний"
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "неправильна кількість аргументів шаблону (%d, повинно бути %d)"
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "неправильна кількість аргументів шаблону (%d, повинно бути щонайменше %d)"
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "надано для %qD"
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "аргумент розширення пакету для непакетного параметра %qD псевдоніма шаблону %qD"
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "аргумент розширення пакету для непакетного параметра %qD концепції %qD"
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "таким чином будь-яка інстанціація з непорожньою пакетом параметрів буде некоректною"
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D не є шаблоном функції"
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "тип %qT, який не є шаблоном, використовується як шаблон"
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "для оголошення шаблону %q+D"
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, gcc-internal-format
 msgid "template constraint failure for %qD"
 msgstr "помилка обмеження шаблону для %qD"
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "використання недійсного шаблону змінної %qE"
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "глибина інстанціювання шаблону перевищує максимум %d (використовуйте %<-ftemplate-depth=%>, щоб збільшити максимум)"
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "аргумент score повинен бути цілим сталим виразом"
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "аргумент score повинен бути не відʼємним"
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "властивість повинна бути цілим сталим виразом або літералом рядка"
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "гнучкий елемент масиву %qD в обʼєднанні"
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "згортка порожньої розгортки над %O"
 
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, gcc-internal-format
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE не є повністю шаблоном розгортки пакету"
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "невідповідні довжини пакету аргументів при розгортанні %qT"
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "невідповідні довжини пакету аргументів при розгортанні %qE"
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "  при створенні значення за замовчуванням для виклику %qD"
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "створення вказівника на функцію-член некласового типу %qT"
 
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, gcc-internal-format, gfc-internal-format
 msgid "mismatched argument pack lengths (%d vs %d)"
 msgstr "невідповідні довжини наборів аргументів (%d проти %d)"
@@ -64163,301 +64215,301 @@ msgstr "невідповідні довжини наборів аргумент
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "змінна %qD має тип функції"
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "недійсний тип параметра %qT"
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "у оголошенні %q+D"
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "функція, що повертає масив"
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "функція, що повертає функцію"
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "створення посилання на тип «void»"
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "створення вказівника на тип посилання %qT"
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "створення посилання на тип посилання %qT"
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "створення вказівника на кваліфікований тип функції %qT"
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "формування посилання на кваліфікований тип функції %qT"
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "створення вказівника на член типу, що не є класом %qT"
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "створення вказівника на тип посилання на член %qT"
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "створення вказівника на член типу void"
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "створення масиву з %qT"
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr "%qD інстанціюється для порожнього пакету"
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT не є класом, структурою або обʼєднанням"
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT розрішується як %qT, який не є перелічуванням"
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT розрішується як %qT, але це не класовий тип"
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "використання %qs у шаблоні"
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "тип, що кваліфікує %qT, не відповідає імені деструктора ~%qT"
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "залежне імʼя %qE розбирається як не-тип, але інстанціювання повертає тип"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "використовуйте %<typename %E%>, якщо мається на увазі тип"
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "ініціалізатор для %q#D розширюється до порожнього списку виразів"
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "неправильне використання виразу розгортання пакету"
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "використовуйте %<...%>, щоб розгорнути пакет аргументів"
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "порожня ініціалізатор в захопленні ініціалізатора лямбди"
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD не було оголошено в цій області видимості, і жодних оголошень не було знайдено за допомогою пошуку залежного від аргументу в точці інстанціювання"
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "оголошення в залежній базі %qT не знайдені за допомогою некваліфікованого пошуку"
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "використовуйте замість цього %<this->%D%>"
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "використовуйте замість цього %<%T::%D%>"
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD оголошено тут, пізніше в одиниці перекладу"
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "неправильна кількість аргументів для %<__builtin_convertvector%>"
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, gcc-internal-format
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "неправильна кількість аргументів для атрибуту %<assume%>"
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT не є класом або простором імен"
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD не є класом або простором імен"
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "використання недійсного поля %qD"
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT є/використовує безіменний тип"
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "аргумент шаблону для %qD використовує локальний тип %qT"
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT є типом зміненої модифікації"
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "цілочисельний вираз %qE не є константою"
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  спроба інстанціювати %qD"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "неоднозначна інстанціація шаблону для %q#T"
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "неоднозначна інстанціація шаблону для %q#D"
 
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "явна інстанціація нешаблону %q#D"
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "явна інстанціація концепції змінної %q#D"
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, gcc-internal-format
 msgid "explicit instantiation of function concept %q#D"
 msgstr "явна інстанціація концепції функції %q#D"
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD не є статичним елементом даних класу-шаблону"
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "не знайдено відповідного шаблону для %qD"
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "тип %qT для явної інстанціації %qD не відповідає оголошеному типу %qT"
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "явна інстанціація %q#D"
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "подвійна явна інстанціація %q#D"
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 забороняє використання %<extern%> при явних інстанціаціях"
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "клас зберігання %qD застосований до інстанціації шаблону"
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "явна інстанціація не-класового шаблону %qD"
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "явна інстанціація не-шаблонного типу %qT"
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "явна інстанціація %q#T перед визначенням шаблону"
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ забороняє використання %qE при явних інстанціаціях"
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "подвійна явна інстанціація %q#T"
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "специфікація винятку %qD залежить від себе"
@@ -64469,163 +64521,163 @@ msgstr "специфікація винятку %qD залежить від се
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "явна інстанціація %qD, але відсутня визначення"
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "глибина інстанціювання шаблону перевищує максимум %d при інстанціюванні %q+D, можливо, з генерації віртуальної таблиці (використовуйте %<-ftemplate-depth=%>, щоб збільшити максимум)"
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "нетипізовані параметри шаблону з виведеним типом класу доступні лише з %<-std=c++20%> або %<-std=gnu++20%>"
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%qT не є дійсним типом для нетипізованого параметра шаблону, оскільки він не є структурним"
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "не-типізовані параметри шаблону класу доступні лише з %<-std=c++20%> або %<-std=gnu++20%>"
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "недійсний не-типізований параметр шаблону"
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T не є дійсним типом для нетипізованого параметра шаблону"
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "слово %<template%> не дозволено в declarator-id"
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "концепцію не можна обмежити"
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "концепція %qE не знаходиться в області простору імен"
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr "концепція %qE має кілька списків параметрів шаблону"
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "виведення зі списку ініціалізаторів, заключених у фігурні дужки, потребує %<#include <initializer_list>%>"
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, gcc-internal-format
 msgid "non-deducible template %qT used without template arguments"
 msgstr "недедуктивний шаблон %qT використовується без аргументів шаблону"
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "виведення псевдоніма шаблону доступне лише з %<-std=c++20%> або %<-std=gnu++20%>"
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, gcc-internal-format
 msgid "use %qD directly instead"
 msgstr "використовуйте безпосередньо %qD замість цього"
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "не вдається вивести аргументи шаблону для копіювальної ініціалізації %qT, оскільки він не має неявних вказівок виведення або користувацьких конструкторів"
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "не вдається вивести аргументи шаблону %qT, оскільки він не має придатних посібників для виведення"
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "не вдалося вивести аргументи шаблону класу:"
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "експліцитні посібники для виведення не враховуються при копіювальній ініціалізації"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "не вдалося вивести аргументи шаблону класу для %qT: вибрано експліцитний посібник для виведення при копіювальній ініціалізації списком"
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "експліцитний посібник для виведення оголошено тут"
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "%qT, можливо, не планує підтримувати виведення аргументів для шаблону класу"
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr "додайте посібник з виведенням, щоб прибрати це попередження"
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "пряма ініціалізація списком %<auto%> потребує рівно один елемент"
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "для виведення до %<std::initializer_list%> використовуйте копіювальну ініціалізацію списком (тобто додайте %<=%> перед %<{%>)"
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "не вдається вивести тип повернення лямбда-функції з %qE"
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "не вдається вивести %qT з %qE"
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "обмеження для заповнювача не виконуються"
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "виведений ініціалізатор не відповідає обмеженням для заповнювача"
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "виведений тип повернення не відповідає обмеженням для заповнювача"
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "виведений тип виразу не відповідає обмеженням для заповнювача"
 
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "неприпустиме використання %qT в аргументі шаблона"
@@ -64835,640 +64887,640 @@ msgstr "не вдалося визначити тип операнда %<asm%> %
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "декларації %<__label__%> дозволені лише в областях функцій"
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "неприпустиме використання члена %qD у статичній функції-члені"
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, gcc-internal-format
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr "неприпустиме використання члена %qD у конструкторі контракту %<pre%>"
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, gcc-internal-format
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr "неприпустиме використання члена %qD у деструкторі контракту %<post%>"
 
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr "%qE відсутні аргументи шаблону"
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr "вираз-оператор є недостатнім контекстом для вирішення перевантаження"
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, gcc-internal-format
 msgid "cannot call a concept as a function"
 msgstr "неможливо викликати концепцію як функцію"
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "аргументи до деструктора не допускаються"
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr "%<this%> недоступний для статичних методів-членів"
 
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, fuzzy, gcc-internal-format
 #| msgid "use the apostrophe directive %qs instead"
 msgid "use explicit object parameter %qs instead"
 msgstr "використовуйте директиву апострофа %qs замість цього"
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template non-type parameter"
 msgid "name the explicit object parameter"
 msgstr "недійсний не-типізований параметр шаблону"
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> недоступний для статичних методів-членів"
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, gcc-internal-format
 msgid "invalid use of %<this%> before it is valid"
 msgstr "неправильне використання %<this%> до його дійсності"
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, gcc-internal-format
 msgid "invalid use of %<this%> after it is valid"
 msgstr "неправильне використання %<this%> після його дійсності"
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "неправильне використання %<this%> у функції, яка не є членом"
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "неправильне використання %<this%> на верхньому рівні"
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "неприпустимий обсяг кваліфікації в псевдо-імені деструктора"
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "обмежений тип %qT не відповідає імені деструктора ~%qT"
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE не є типом %qT"
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "складений літерал непредметного типу %qT"
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, gcc-internal-format
 msgid "%<auto{x}%> cannot be constrained"
 msgstr "%<auto{x}%> не може бути обмеженим"
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, gcc-internal-format
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<auto{x}%> доступний лише з %<-std=c++2b%> або %<-std=gnu++2b%>"
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "типові параметри шаблону повинні використовувати ключове слово %<class%> або %<typename%>"
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "неприпустиме використання типу %qT як значення за замовчуванням для параметра-шаблону шаблону"
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "неприпустимий значення за замовчуванням для параметра-шаблону шаблону"
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "визначення %q#T всередині списку параметрів шаблону"
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "неприпустиме визначення кваліфікованого типу %qT"
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "неприпустима специфікація базового класу"
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "не можна захопити член %qD анонімного обʼєднання"
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD не захоплено"
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "лямбда не має захоплення за замовчуванням"
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr "Лямбда-функція в локальному класі %q+T не може захоплювати змінні з оточуючого контексту"
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "Використання локальної змінної з автоматичним сховищем з вмістної функції"
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "Використання параметра з вмістної функції"
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "Використання параметра поза тілом функції"
 
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr "Відсутні аргументи шаблону"
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "Параметр шаблону %qD типу %qT не допускається в цілочисельному сталому виразі, оскільки він не є цілочисельним або перелічувальним типом"
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "Використання класового шаблону %qT як виразу"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "Запит на елемент %qD є неоднозначним у гратці множинного успадкування"
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD не може зʼявлятися у константному виразі"
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "тип %qE невідомий"
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT не є перелічувальним типом"
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not an integer constant"
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr "запитане вирівнювання не є цілочисельною константою"
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr ""
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, fuzzy, gcc-internal-format
 #| msgid "Reference statement index out of range"
 msgid "%<__type_pack_element%> index is out of range"
 msgstr "індекс заяви про посилання поза діапазоном"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "Пакет параметрів %<__bases%> дійсний лише в оголошенні шаблону"
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "не можна застосовувати %<offsetof%> до деструктора %<~%T%>"
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "не можна застосовувати %<offsetof%> до функції-члена %qD"
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "не можна застосовувати %<offsetof%> до функції-члена"
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "не можна застосовувати %<offsetof%> до перелічування %qD"
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr "%<offsetof%> в межах типу %qT, який не відповідає стандартному розташуванню, підтримується умовно"
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, fuzzy, gcc-internal-format
 #| msgid "constructor priorities are not supported"
 msgid "pointer-to-member mapping %qE not supported"
 msgstr "Пріоритети конструкторів не підтримуються"
 
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "Пошук зменшення, визначеного користувачем, є неоднозначним"
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "%qE в замиканні %<reduction%> є масивом нульового розміру"
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE має тип const для %<reduction%>"
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "Користувацьке визначення зменшення з ініціалізатором конструктора для базового класу %qT"
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, gcc-internal-format
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr "у замиканні %<linear%> на конструкціях %<simd%> або %<for%> вказано модифікатор, відмінний від %<val%>, при використанні модифікаторів OpenMP 5.2"
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr "замикання %qs модифікатора linear застосована до змінної, яка не є посиланням, з типом %qT"
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "Замикання 'linear' застосовано до змінної типу %qT, яка не є цілочисельним або вказівником"
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "Вираз кроку 'linear' повинен бути цілочисельним"
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> дозволено в OpenMP тільки в замиканнях %<declare simd%>"
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD не є змінною в замиканні %qs"
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD не є змінною в замиканні %<firstprivate%>"
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD не є змінною в замиканні %<lastprivate%>"
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "Вираз статичного %<gang%> повинен бути цілочисельним"
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "Значення статичного %<gang%> повинно бути позитивним"
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "Вираз номера %<gang%> повинен бути цілочисельним"
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "Вираз довжини %<vector%> повинен бути цілочисельним"
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "Вираз номера %<worker%> повинен бути цілочисельним"
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "Значення %<gang%> повинно бути позитивним"
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "Значення довжини %<vector%> повинно бути позитивним"
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "Значення номера %<worker%> повинно бути позитивним"
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "Вираз розміру частини розкладу повинен бути цілочисельним"
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "Вираз довжини %qs повинен бути цілочисельним"
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "Вираз довжини %qs повинен бути позитивним сталим цілим виразом"
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "Вираз %<async%> повинен бути цілочисельним"
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "Вираз %<thread_limit%> повинен бути цілочисельним"
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "Ідентифікатор %<device%> повинен бути цілочисельним"
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "Вираз розміру частини %<dist_schedule%> повинен бути цілочисельним"
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD не є змінною в замиканні %<aligned%>"
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE в замиканні %<aligned%> не є вказівником, масивом або посиланням на вказівник або масив"
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD зустрічається більше одного разу в замиканнях %<aligned%>"
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "вираз вирівнювання в замиканні %<aligned%> повинен бути цілочисельним"
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD не є змінною в замиканні %<nontemporal%>"
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD зустрічається більше одного разу в замиканнях %<nontemporal%>"
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%<this%> не дозволено в замиканні %<allocate%>"
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD не є змінною в замиканні %<allocate%>"
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD зустрічається більше одного разу в замиканнях %<allocate%>"
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr "%qD не є виразом lvalue або секцією масиву в замиканні %qs"
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "шаблон %qE в замиканні %qs"
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "перевантажене імʼя функції %qE в замиканні %qs"
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "вираз %<grainsize%> повинен бути цілочисельним"
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "вираз %<priority%> повинен бути цілочисельним"
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "вираз %<hint%> повинен бути цілочисельним"
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "вираз %<hint%> повинен бути сталим цілочисельним виразом"
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, gcc-internal-format
 msgid "%<filter%> expression must be integral"
 msgstr "dираз %<filter%> повинен бути цілочисельним"
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "Змінна %qs не є вказівником або посиланням на вказівник"
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "Змінна %qs не є вказівником, масивом або посиланням на вказівник або масив"
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "Аргумент для %<tile%> повинен мати цілочисельний тип"
 
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr "Кваліфікований %qE з %<const%>, без члена %<mutable%>, може зʼявлятися тільки в замиканнях %<shared%> або %<firstprivate%>"
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD не є змінною з областю видимості файлу, простору імен або блоку"
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "Директива %<threadprivate%> %qE не визначена в %qT"
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "різниця між %qE та %qD не має цілочисельного типу"
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> використовується з ітераційною змінною класу %qE"
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> використовує два різних вирази для памʼяті"
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr ""
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr ""
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr ""
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, fuzzy, gcc-internal-format
 #| msgid "%<hint%> expression must be constant integer expression"
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr "вираз %<hint%> повинен бути сталим цілочисельним виразом"
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr ""
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, fuzzy, gcc-internal-format
 #| msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> не є константним виразом"
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be an integer constant expression"
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr "аргумент %d функції %qE повинен бути цілочисельним константним виразом"
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %s"
 msgid "static assertion failed: %.*s"
 msgstr "статичне твердження не вдалося: %s"
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "неконстантна умова для статичного твердження"
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "аргумент для %<decltype%> повинен бути виразом"
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%<decltype%> не може вирішити адресу перевантаженої функції"
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr "%<__builtin_is_pointer_interconvertible_with_class%> потребує один аргумент"
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr "Аргумент %<__builtin_is_pointer_interconvertible_with_class%> не є вказівником на член"
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr "%<__builtin_is_corresponding_member%> не чітко визначений для анонімних обʼєднань"
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr "%<__builtin_is_corresponding_member%> потребує два аргументи"
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr "Аргумент %<__builtin_is_corresponding_member%> не є вказівником на член"
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "%qD не є класом або псевдонімом шаблону"
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "Операнд складеного виразу не має нерозгорнутих пакетів параметрів"
 
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "обидва аргументи в бінарному складеному мають нерозгорнуті пакети параметрів"
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "немає нерозгорнутих пакетів параметрів у бінарному складанні"
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "аргумент, який не є вказівником, до %<__builtin_launder%>"
@@ -65476,1170 +65528,1170 @@ msgstr "аргумент, який не є вказівником, до %<__buil
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr "тип призначення %qT %<__builtin_bit_cast%> є типом масиву"
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr "тип призначення %qT %<__builtin_bit_cast%> не є простим для копіювання"
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr "тип джерела %qT %<__builtin_bit_cast%> не є простим для копіювання"
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr "розмір джерела %qE %<__builtin_bit_cast%> не дорівнює розміру типу призначення %qE"
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "кваліфікатори %qV не можуть бути застосовані до %qT"
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "вираз-оператор в константному виразі"
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr "%<-fabi-version=13%> (GCC 8.2) виправляє конвенцію виклику для %qT, яка була помилково змінена в 8.1"
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr "%<-fabi-version=12%> (GCC 8.1) випадково змінює конвенцію виклику для %qT"
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, gcc-internal-format
 msgid " declared here"
 msgstr " оголошено тут"
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr "конвенція виклику для %qT змінюється в %<-fabi-version=13%> (GCC 8.2)"
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr " оскільки всі його конструктори копіювання та переміщення видалені"
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "базовий клас %qT не є публічним"
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, gcc-internal-format
 msgid "%qD is not public"
 msgstr "%qD не є публічним"
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, gcc-internal-format
 msgid "%qD is mutable"
 msgstr "%qD є змінним"
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr "%qD має неструктурний тип"
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr "Атрибут %qE можна застосовувати тільки до функцій або параметрів"
 
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr "Аргумент атрибуту %qE повинен бути рядковою константою"
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "Атрибут %qE можна застосовувати тільки до функцій або до класів або перелічувань"
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "Атрибут %qE можна застосовувати тільки до нестатичних членів даних"
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, gcc-internal-format
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "Атрибут %qE не може бути застосований до поля бітів"
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "Атрибут %qE не приймає аргументів"
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "Атрибут ISO C++ %qE не застосовується до функцій; розглядається як %<[[gnu::%E]]%>"
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, gcc-internal-format
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "запитаний %<init_priority%> не є цілочисельним"
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "можна використовувати атрибут %qE тільки на визначеннях обʼєктів класу на рівні файлу"
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "запитаний %<init_priority%> %i знаходиться поза межами діапазону [0, %i]"
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "запитаний %<init_priority%> %i зарезервований для внутрішнього використання"
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "повторне оголошення %qD додає мітку abi %qE"
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "атрибут %qE вимагає аргументів"
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "аргументи атрибуту %qE повинні бути вузькими літералами рядка"
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "аргументи для атрибуту %qE повинні містити дійсні ідентифікатори"
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%c%> не є допустимим першим символом для ідентифікатора"
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%c%> не є допустимим символом в ідентифікаторі"
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "атрибут %qE застосовується до типу %qT, який не є класом або перелічуванням"
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "атрибут %qE застосовується до %qT після його визначення"
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "ігнорується атрибут %qE, застосований до інстанціювання шаблону %qT"
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "ігнорується атрибут %qE, застосований до спеціалізації шаблону %qT"
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "атрибут %qE застосовується до %qD, який не є функцією або змінною"
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "атрибут %qE застосовується до зовнішньої «C»-декларації %qD"
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument must be a string constant"
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr "Аргумент атрибуту %qE повинен бути рядковою константою"
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "нуль як константа нульового вказівника"
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, gcc-internal-format
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "%<lang_*%> перевірка: не вдалося в %s, на %s:%d"
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "порівняння між різними типами вказівників %qT та %qT потребує приведення типу"
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "конвертація між різними типами вказівників %qT та %qT потребує приведення типу"
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "умовний вираз між різними типами вказівників %qT та %qT потребує приведення типу"
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ забороняє порівняння між вказівником типу %<void *%> та вказівником на функцію"
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ забороняє перетворення між вказівником типу %<void *%> та вказівником на функцію"
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ забороняє умовний вираз між вказівником типу %<void *%> та вказівником на функцію"
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "порівняння між різними типами вказівників на члена %qT та %qT не має приведення типу"
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "перетворення між різними типами вказівників на члена %qT та %qT не має приведення типу"
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "умовний вираз між різними типами вказівників на члена %qT та %qT не має приведення типу"
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "канонічні типи відрізняються для однакових типів %qT та %qT"
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "один і той самий вузол канонічного типу для різних типів %qT та %qT"
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "недійсне застосування %qs до функції-члена"
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "недійсне застосування %<sizeof%> до бітового поля"
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ забороняє застосування %<sizeof%> до виразу типу функції"
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "недійсне застосування %<__alignof%> до бітового поля"
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ забороняє застосування %<__alignof%> до виразу типу функції"
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "аргумент %<alignas%> має нецілочисельний тип %qT"
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr "неприпустиме використання нестатичного методу члена типу %qT"
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ забороняє конвертувати рядкову константу в %qT"
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "застаріла конвертація з рядкової константи в %qT"
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "запит на елемент %qD в %qE, який має тип вказівника %qT (можливо, ви мали на увазі використання %<->%> ?)"
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "запит на елемент %qD в %qE, який має тип не-класу %qT"
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qE"
 msgstr "недійсне використання нестатичного члена даних %qE"
 
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "недійсний доступ до нестатичного члена даних %qD в віртуальній базі нульового обʼєкта"
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "тип обʼєкта %qT не відповідає імені деструктора ~%qT"
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "тип, який знищується, це %qT, але деструктор посилається на %qT"
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr "поле %q#D можна отримати через %q#D"
 
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T не має члена з іменем %qE"
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%q#T не має члена з іменем %qE; мали на увазі %q#D? (доступно через %q#D)"
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%q#T не має члена з іменем %qE; мали на увазі %q#D? (не доступно з цього контексту)"
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T не має члена з іменем %qE; мали на увазі %qE?"
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> не є членом %qT"
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT не є базою для %qT"
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD не є шаблонною функцією-членом"
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT не є типом вказівника на обʼєкт"
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "неприпустиме використання індексування масиву на вказівнику на член"
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "неприпустиме використання унарного %<*%> на вказівнику на член"
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "неприпустиме використання неявного перетворення на вказівнику на член"
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr "лівий операнд %<->*%> повинен бути вказівником на клас, але є вказівником на член типу %qT"
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "відсутній індекс в посиланні на масив"
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "індексація масиву, оголошеного як %<register%>"
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "індексоване значення не є або масивом, або вказівником"
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "використання %qE без обʼєкта"
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ забороняє викликати %<::main%> з програми"
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "необхідно використовувати %<.*%> або %<->*%> для виклику функції-члена, що вказує на вказівник, в %<%E (...)%>, наприклад, %<(... ->* %E) (...)%>"
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE не може бути використано як функцію"
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD не може бути використано як функцію"
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "вираз не може бути використаний як функція"
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "забагато аргументів для конструктора %q#D"
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "замало аргументів для конструктора %q#D"
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "занадто багато аргументів для функції-члена %q#D"
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "занадто мало аргументів для функції-члена %q#D"
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "занадто багато аргументів для функції %q#D"
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "занадто мало аргументів для функції %q#D"
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "занадто багато аргументів для методу %q#D"
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "занадто мало аргументів для методу %q#D"
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "занадто багато аргументів для функції"
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "занадто мало аргументів для функції"
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "параметр %P функції %qD має неповний тип %qT"
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "параметр %P має неповний тип %qT"
 
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, gcc-internal-format
 msgid "the address %qE will never be NULL"
 msgstr "адреса %qE ніколи не буде NULL"
 
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "адреса обʼєкту %qD ніколи не буде NULL"
 
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr "компілятор може припустити, що адреса %qE ніколи не буде NULL"
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr "порівняння результату додавання вказівника %qE та NULL"
 
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "компілятор може припустити, що адреса %qD ніколи не буде NULL"
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, fuzzy, gcc-internal-format
 #| msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr "операція побітового І або АБО між різними типами перелічування %qT та %qT застаріла"
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "операція побітового І або АБО між різними типами перелічування %qT та %qT застаріла"
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr "арифметична операція між різними типами перелічування %qT та %qT застаріла"
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "арифметична операція між різними типами перелічування %qT та %qT застаріла"
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr "Порівняння перелічувального типу %qT з типом з плаваючою комою %qT є застарілим"
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr "Порівняння типу з плаваючою комою %qT з перелічувальним типом %qT є застарілим"
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr "Порівняння перелічувального типу %qT з типом з плаваючою комою %qT є застарілим"
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "Порівняння типу з плаваючою комою %qT з перелічувальним типом %qT є застарілим"
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr "Арифметика між перелічувальним типом %qT та типом з плаваючою комою %qT є застарілою"
 
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr "Арифметика між типом з плаваючою комою %qT та перелічувальним типом %qT є застарілою"
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr "Арифметика між перелічувальним типом %qT та типом з плаваючою комою %qT є застарілою"
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr "Арифметика між типом з плаваючою комою %qT та перелічувальним типом %qT є застарілою"
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "Припускається приведення до типу %qT з перевантаженої функції"
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL використовується в арифметиці"
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ забороняє порівняння між вказівником та цілочисельним"
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "Типи операндів: %qT та %qT"
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr "Тристороннє порівняння векторів"
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "упорядковане порівняння вказівника з нулем (%qT та %qT)"
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, gcc-internal-format
 msgid "unordered comparison on non-floating-point argument"
 msgstr "неупорядковане порівняння з нечисловим аргументом"
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "неявне перетворення з %qH на %qI для відповідності іншому операнду бінарного виразу"
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "недійсні операнди типів %qT і %qT для бінарного %qO"
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ забороняє використання відʼємного відʼємного типу %<void *%>"
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ забороняє використання відʼємного відʼємного типу для функції"
 
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ забороняє використання відʼємного відʼємного типу для методу"
 
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "недійсне використання вказівника на неповний тип в арифметиці вказівників"
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "береться адреса конструктора %qD"
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "береться адреса деструктора %qD"
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "недійсне використання %qE для створення вказівника на член-функцію"
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  потрібно вказати кваліфікований ідентифікатор"
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "Дужки навколо %qE не можуть бути використані для створення вказівника на член-функцію"
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ забороняє взяти адресу некваліфікованої або укладеної нестатичної член-функції для створення вказівника на член-функцію. Скажіть %<&%T::%D%>"
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr "ISO C++ забороняє взяти адресу некваліфікованої або укладеної нестатичної член-функції для створення вказівника на член-функцію. Скажіть %<&%T::%D%>"
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ забороняє взяти адресу привʼязаної член-функції для створення вказівника на член-функцію. Скажіть %<&%T::%D%>"
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr "ISO C++ забороняє взяти адресу привʼязаної член-функції для створення вказівника на член-функцію. Скажіть %<&%T::%D%>"
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr "(вказівник на член може бути створений лише з %<&%E%>)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, gcc-internal-format
 msgid "taking address of rvalue"
 msgstr "береться адреса rvalue"
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ забороняє взяти адресу функції %<::main%>"
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "не можна створити вказівник на посилання на член %qD"
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "спроба взяти адресу бітового поля"
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<~%> на виразі типу %<bool%>"
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr "чи мали ви на увазі використання логічного заперечення (%<!%>)?"
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ забороняє збільшувати перелічування"
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ забороняє зменшувати перелічування"
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "не можна збільшити вказівник на неповний тип %qT"
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "не можна зменшити вказівник на неповний тип %qT"
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ забороняє збільшення вказівника типу %qT"
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ забороняє зменшення вказівника типу %qT"
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr "Вираз %qs з кваліфікатором %<volatile%> є застарілим"
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr "Використання операнда типу %qT в %<operator--%> заборонено"
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr "Використання операнда типу %qT в %<operator++%> заборонено в C++17"
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr "використання операнда типу %qT в %<operator++%> є застарілим"
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "не можна взяти адресу %<this%>, який є виразом rvalue"
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "запитано адресу явної регістрової змінної %qD"
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "запитано адресу для %qD, яка оголошена як %<register%>"
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "ініціалізатор списку для типу, що не є класом, не повинен бути у дужках"
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "список виразів розглядається як складений вираз в ініціалізаторі"
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "список виразів розглядається як складений вираз в mem-ініціалізаторі"
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "список виразів розглядається як складений вираз в функціональному приведенні типу"
 
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "список виразів %s розглядається як складений вираз"
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "немає контексту для визначення типу %qE"
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "приведення типу %qT до типу %qT видаляє кваліфікатори"
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%<static_cast%> з типу %qT до типу %qT видаляє кваліфікатори"
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "%<reinterpret_cast%> з типу %qT до типу %qT видаляє кваліфікатори"
 
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "непотрібне приведення до типу %q#T"
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
 msgstr "кваліфікатори типу ігноруються на типі результату приведення"
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, gcc-internal-format
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "неприпустиме %<static_cast%> з типу %qT до типу %qT"
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "тип класу %qT є неповним"
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 msgid "converting from %qH to %qI"
 msgstr "перетворення з %qH на %qI"
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, gcc-internal-format
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "недійсне приведення типу виразу prvalue типу %qT до типу %qT"
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 msgid "cast from %qH to %qI loses precision"
 msgstr "приведення з %qH до %qI втрачає точність"
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr "приведення між несумісними типами функцій з %qH до %qI"
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "приведення між несумісними типами вказівників на члени від %qH до %qI"
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "приведення від %qH до %qI збільшує необхідне вирівнювання цільового типу"
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "приведення між вказівником на функцію та вказівником на обʼєкт підтримується умовно"
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "недійсне приведення з типу %qT до типу %qT"
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "недійсне використання %<const_cast%> з типом %qT, який не є вказівником, посиланням або вказівником на член даних"
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "недійсне використання %<const_cast%> з типом %qT, який є вказівником або посиланням на тип функції"
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, gcc-internal-format
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "недійсне %<const_cast%> rvalue типу %qT до типу %qT"
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, gcc-internal-format
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "недійсне %<const_cast%> з типу %qT до типу %qT"
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ забороняє приведення до типу масиву %qT"
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "недійсне приведення до типу функції %qT"
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, gcc-internal-format
 msgid "moving %qE of type %qT to itself"
 msgstr "переміщення %qE типу %qT в самого себе"
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr "видаліть виклик %<std::move%>"
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  при оцінці %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "присвоєння масиву зі списку ініціалізаторів"
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "несумісні типи при присвоєнні %qT до %qT"
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "масив використовується як ініціалізатор"
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "недійсне присвоєння масиву"
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "   при перетворенні на вказівник на функцію-член"
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "перетворення на вказівник на член через віртуальну базу %qT"
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "   при перетворенні на вказівник на член"
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "недійсне перетворення на тип %qT з типу %qT"
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "не можна перетворити %qH на %qI в аргументі за замовчуванням"
 
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "не можна перетворити %qH на %qI при передачі аргументу"
 
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "не можна перетворити %qH на %qI при ініціалізації"
 
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 msgid "cannot convert %qH to %qI in return"
 msgstr "не можна перетворити %qH на %qI при поверненні"
 
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "не можна перетворити %qH на %qI в присвоєнні"
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "параметр %qP з %qD може бути кандидатом на атрибут формату"
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "параметр може бути кандидатом на атрибут формату"
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "ціль конвертації може бути кандидатом на атрибут формату"
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "ціль ініціалізації може бути кандидатом на атрибут формату"
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "ліва сторона присвоєння може бути кандидатом на атрибут формату"
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "при передачі аргументу %P з %qD"
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "повернення посилання на тимчасовий обʼєкт"
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "returning pointer to temporary"
 msgstr "повернення посилання на тимчасовий обʼєкт"
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr "повернення тимчасового %<initializer_list%> не продовжує термін дії базового масиву"
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "повернуто посилання на локальну змінну %qD"
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr "повернення локальної змінної %<initializer_list%> %qD не продовжує термін існування базового масиву"
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "повернуто адресу мітки %qD"
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "повернуто адресу локальної змінної %qD"
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr "переміщення тимчасового обʼєкта запобігає оптимізації копіювання"
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr "переміщення локального обʼєкта в операторі повернення запобігає оптимізації копіювання"
 
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "зайве переміщення в операторі повернення"
 
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, gcc-internal-format
 msgid "redundant move in initialization"
 msgstr "зайве переміщення в ініціалізації"
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "повернення значення з деструктора"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "не можна повернути з обробника блоку function-try-блоку конструктора"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "повернення значення з конструктора"
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return-оператор без значення, у функції, що повертає %qT"
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "повернення списку ініціалізаторів"
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "несумісні типи %qT та %qT виведені для типу повернення лямбди"
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "неспівпадаюче виведення для типу автоматичного повернення: %qT і потім %qT"
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
 msgstr "return-оператор зі значенням, у функції, що повертає %qT"
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> не повинен повертати NULL, якщо він не оголошений %<throw()%> (або %<-fcheck-new%> активований)"
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q#D"
 msgid "not eliding copy on return from %qD"
 msgstr "недійсний коваріантний тип повернення для %q#D"
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr ""
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "використання rvalue як lvalue"
@@ -66860,155 +66912,155 @@ msgstr "перевантажена функція без контекстуал
 msgid "insufficient contextual information to determine type"
 msgstr "недостатня контекстуальна інформація для визначення типу"
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "використано синтаксис конструктора, але для типу %qT не оголошено конструктор"
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "змінна %qD з %<constinit%> не має константного ініціалізатора"
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "звужувальне перетворення %qE з %qH на %qI неприпустиме в C++11"
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "звужувальне перетворення %qE з %qH на %qI"
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr " вираз має стале значення, але не є сталим виразом у C++"
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, gcc-internal-format
 msgid "initializer-string for %qT is too long"
 msgstr "рядок ініціалізатора для %qT занадто довгий"
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr "ініціалізація базового класу типу %qT призводить до обрізання обʼєкта"
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, gcc-internal-format
 msgid "remove %<{ }%> around initializer"
 msgstr "видаліть %<{ }%> навколо ініціалізатора"
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "не вдається ініціалізувати агрегат типу %qT зі складним літералом"
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "відсутній ініціалізатор для члена %qD"
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "член %qD є неініціалізованим посиланням"
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "член %qD з неініціалізованими полями посилання"
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "порядок вказівника для поля %qD не відповідає порядку оголошення в %qT"
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "не знайдено поле %qD в ініціалізованому обʼєднанні"
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "значення індексу замість назви поля в ініціалізаторі обʼєднання"
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "виявлено циклічну делегацію вказівника"
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "базовий операнд %<->%> має тип, що не є вказівником %qT"
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "результат %<operator->()%> дає результат, що не є вказівником"
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "базовий операнд %<->%> не є вказівником"
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE не може бути використаний як вказівник на член, оскільки він має тип %qT"
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "не можна застосувати вказівник на член %qE до %qE, який має тип, що не є класом %qT"
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "тип вказівника на член %qT несумісний з типом обʼєкту %qT"
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "тип вказівника на функцію-член %qT вимагає r-значення"
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "тип вказівника на функцію-член %qT вимагає l-значення"
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "тип вказівника на функцію-член %qT вимагає l-значення до C++20"
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "функціональне приведення до типу масиву %qT"
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "%<auto(x)%> не може бути обмеженим"
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<auto(x)%> доступний лише з %<-std=c++2b%> або %<-std=gnu++2b%>"
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "неправильна ініціалізація значення типу посилання"
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "виклик функції %qD, яка генерує неповний тип %q#T"
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "виклик функції, яка генерує неповний тип %q#T"
@@ -67996,7 +68048,7 @@ msgstr "Літеральна константа BOZ на %L не може бут
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "Аргументи %qs на %L і %L не можуть обидва бути літеральними константами BOZ"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "Недійсне використання літеральної константи BOZ на %L"
@@ -69333,7 +69385,7 @@ msgstr "Неправильна специфікація INTENT в %C"
 msgid "deferred type parameter at %C"
 msgstr "відкладений тип параметра в %C"
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Очікується скалярний INTEGER вираз в %L"
@@ -69548,7 +69600,7 @@ msgstr "Компонент %qs з CLASS у %C повинен бути алоко
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Масивний компонент структури у %C повинен мати явну або відкладену форму"
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "Компонент %qs у %C вже оголошений у %L"
@@ -70350,7 +70402,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr "Очікувався формальний список аргументів у визначенні функції на %C"
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "Атрибут BIND(C) на %L може використовуватися лише для змінних або спільних блоків"
@@ -71157,12 +71209,12 @@ msgstr "identical_array_ref(): невідповідні розміри"
 msgid "are_identical_variables: Bad type"
 msgstr "are_identical_variables: Неправильний тип"
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr "Фактичний аргумент INTENT(%s) на %L може впливати на фактичний аргумент на %L."
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr "gfc_check_dependency: очікується EXPR_VARIABLE"
@@ -71410,273 +71462,273 @@ msgstr "Параметр %qs у %L не був оголошений або є з
 msgid "check_init_expr(): Unknown expression type"
 msgstr "check_init_expr(): Невідомий тип виразу"
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr "Специфікаційна функція %qs у %L не може бути функцією-оператором"
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr "Специфікаційна функція %qs на %L не може бути внутрішньою функцією"
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, gcc-internal-format
 msgid "Specification function %qs at %L must be PURE"
 msgstr "Специфікаційна функція %qs на %L повинна бути PURE"
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr "Специфікаційна функція %qs на %L не може бути RECURSIVE"
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, gcc-internal-format
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr "Фіктивний аргумент %qs не допускається в виразі на %L"
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr "Фіктивний аргумент %qs на %L не може бути OPTIONAL"
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr "Фіктивний аргумент %qs на %L не може бути INTENT(OUT)"
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr "Змінна %qs не може зʼявлятися в виразі на %L"
 
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, gcc-internal-format
 msgid "check_restricted(): Unknown expression type"
 msgstr "check_restricted(): Невідомий тип виразу"
 
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr "Вираз на %L повинен бути типу INTEGER, знайдено %s"
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, gcc-internal-format
 msgid "Function %qs at %L must be PURE"
 msgstr "Функція %qs на %L повинна бути PURE"
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr "Вираз на %L повинен бути скалярним"
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr "Переповнення optype_msgid: %d"
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr "Несумісні ранги в %s (%d і %d) на %L"
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "Різна форма для %s на %L по розмірності %d (%d і %d)"
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr "Присвоєння LEN або KIND part_ref на %L не дозволяється"
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr "%qs на %L не є VALUE"
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal assignment to external procedure at %L"
 msgstr "Недопустиме присвоєння зовнішній процедурі на %L"
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "Несумісні ранги %d і %d в присвоєнні на %L"
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "Тип змінної невідомий в присвоєнні на %L"
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "NULL зʼявляється на правій стороні при присвоєнні на %L"
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "Функція з POINTER-значенням зʼявляється на правій стороні при присвоєнні на %L"
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr "Літеральна константа BOZ поблизу %L не може бути присвоєна змінній %qs"
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr "Присвоєння компоненту KIND або LEN параметризованого типу на %L не дозволено"
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Несумісні типи в операторі DATA на %L; спроба перетворення %s на %s"
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "Ціль присвоєння вказівника не є POINTER на %L"
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "%qs в присвоєнні вказівника на %L не може бути l-значенням, оскільки це процедура"
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Очікується вказівка меж для %qs у %L"
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Вказівка меж для %qs у присвоєнні вказівника на %L"
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "Крок не повинен бути вказаний на %L"
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr "Переіндексація рангу вимагає списку специфікацій %<lower-bound : upper-bound%> на %L"
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr "Очікується список специфікацій %<lower-bound :%> або список специфікацій %<lower-bound : upper-bound%> на %L"
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "Обʼєкт-вказівник на %L не повинен мати спільного індексу"
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Недійсне призначення вказівника процедури на %L"
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Результат функції %qs є недійсним як ціль процедури у присвоєнні вказівника на процедуру у %L"
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Абстрактний інтерфейс %qs недійсний при присвоєнні вказівника на процедуру в %L"
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Функція-оператор %qs недійсна при присвоєнні вказівника на процедуру в %L"
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Внутрішня процедура %qs недійсна при присвоєнні вказівника на процедуру в %L"
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Вбудована функція %qs в %L недійсна при присвоєнні вказівника на процедуру"
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Невбудована елементарна процедура %qs недійсна при присвоєнні вказівника на процедуру в %L"
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "Неспівпадіння при присвоєнні вказівника на процедуру в %L: неспівпадіння у конвенції виклику"
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "Несумісність інтерфейсу при присвоєнні вказівника на процедуру в %L: %qs не є підпрограмою"
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Для компонента %qs на %L потрібний явний інтерфейс: %s"
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Для %qs на %L потрібний явний інтерфейс: %s"
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Несумісність інтерфейсу при присвоєнні вказівника на процедуру на %L: %s"
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr "Ціль вказівника на процедуру %qs на %L повинна бути або вбудованою, або повʼязаною з хостом або use, або посилатися на неї, або мати атрибут EXTERNAL"
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr "Ціль присвоєння вказівника не може бути константою на %L"
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr "Обʼєкт-вказівник даних на %L повинен бути необмежено поліморфним або мати атрибут BIND або SEQUENCE, щоб бути сумісним з необмежено поліморфною ціллю"
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Різні типи в призначенні вказівника на %L; спроба призначити %s до %s"
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Різні параметри типу виду в призначенні вказівника на %L"
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Різні ранги в призначенні вказівника на %L"
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "Ціль ремапінгу рангу менша за розмір вказівника (%ld < %ld) на %L"
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "Ціль рангового перенаправлення повинна мати ранг 1 або бути просто послідовною на %L"
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "Ціль перенаправлення рангу не має рангу 1 на %L"
@@ -71684,193 +71736,193 @@ msgstr "Ціль перенаправлення рангу не має ранг
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "Ціль даних на %L не повинна мати співіндексу"
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Вираз цілі в призначенні вказівника на %L повинен повертати результат вказівника"
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr "Виявлено масив нульового розміру на %L, де очікується сутність з атрибутом TARGET"
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "Ціль призначення вказівника в виразі ініціалізації не має атрибуту TARGET на %L"
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, gcc-internal-format, gfc-internal-format
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr "Кожний індекс підпису специфікації цілі на %L повинен бути константним виразом"
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr "Початкова і кінцева точки підстрічки специфікації цілі на %L повинні бути константними виразами"
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Ціль призначення вказівника не є TARGET або POINTER на %L"
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Недійсна ціль в призначенні вказівника в чистій процедурі на %L"
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Призначення вказівника з векторним підписом на rhs на %L"
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Ціль призначення вказівника має атрибут PROTECTED на %L"
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr "Призначення послідовного вказівника з непослідовної цілі на %L"
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "Вказівник на %L в призначенні вказівника може пережити ціль вказівника"
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Ціль ініціалізації вказівника на %L не повинна бути ALLOCATABLE"
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Ціль ініціалізації вказівника на %L повинна мати атрибут TARGET"
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Ціль ініціалізації вказівника на %L повинна мати атрибут SAVE"
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "Ціль ініціалізації вказівника на процедуру на %L не може бути вказівником на процедуру"
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Внутрішня процедура %qs недійсна в ініціалізації вказівника на процедуру на %L"
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Функція-заглушка %qs недійсна в ініціалізації вказівника на процедуру на %L"
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr "generate_isocbinding_initializer(): неправильний тип iso_c_binding, очікувався %<c_ptr%> або %<c_funptr%>"
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Функції-вказівники в контексті визначення змінної (%s) на %L"
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Не змінний вираз у контексті визначення змінної (%s) на %L"
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Іменована константа %qs у контексті визначення змінної (%s) на %L"
 
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qs у контексті визначення змінної (%s) на %L не є змінною"
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Не POINTER у контексті асоціації вказівника (%s) на %L"
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Тип недоступний у контексті визначення змінної (%s) на %L"
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE у контексті визначення змінної (%s) на %L"
 
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_EVENT у контексті визначення змінної (%s) на %L"
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, gcc-internal-format
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr "Запит параметра %qs для %qs у контексті визначення змінної (%s) на %L"
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Фіктивний аргумент %qs з INTENT(IN) в контексті асоціації вказівника (%s) на %L"
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Фіктивний аргумент %qs з INTENT(IN) в контексті визначення змінної (%s) на %L"
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "Змінна %qs є PROTECTED і не може зʼявлятися в контексті асоціації вказівника (%s) на %L"
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "Змінна %qs є PROTECTED і не може зʼявлятися в контексті визначення змінної (%s) на %L"
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Змінна %qs не може зʼявлятися в контексті визначення змінної (%s) на %L у чистій процедурі"
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr "%qs на %L, повʼязаний з вектор-індексованою ціллю, не може бути використаний в контексті визначення змінної (%s)"
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "%qs на %L, повʼязаний з виразом, не може бути використаний в контексті визначення змінної (%s)"
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr "%qs на %L, повʼязаний з виразом, не може бути використаний в контексті визначення змінної (%s)"
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "Імʼя асоціації %qs не може зʼявлятися в контексті визначення змінної (%s) на %L, оскільки його ціль на %L також не може"
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "Елементи з однаковим значенням на %L і %L в підписі вектора в контексті визначення змінної (%s)"
@@ -71891,8 +71943,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Недопустимий ідентифікатор в copy_walk_reduction_arg"
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "Створення тимчасового масиву на %L"
@@ -71972,7 +72024,7 @@ msgstr "Змінна %qs на %L встановлена на невизначе
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Змінну %qs на %L неможливо визначити всередині циклу, що починається з %L, як аргумент INTENT(INOUT) для функції %qs"
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr "Код для перерозподілу виділеного масиву на %L буде доданий"
@@ -72107,12 +72159,12 @@ msgstr "Перший аргумент визначеного присвоєнн
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Другий аргумент визначеного присвоєння на %L повинен бути INTENT(IN)"
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Перший аргумент інтерфейсу оператора на %L повинен бути INTENT(IN)"
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Другий аргумент інтерфейсу оператора на %L повинен бути INTENT(IN)"
@@ -72983,7 +73035,7 @@ msgstr "Конвертація з %s в %s у %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot convert %s to %s at %L"
 msgstr "Неможливо конвертувати %s в %s у %L"
@@ -73534,7 +73586,7 @@ msgstr "NAMELIST %qs в операторі READ на %L містить симв
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "Обʼєкт NAMELIST %qs в списку імен %qs на %L є поліморфним і вимагає визначеної процедури введення/виведення"
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "Обʼєкт NAMELIST %qs в списку імен %qs на %L має компоненти ALLOCATABLE або POINTER"
@@ -73700,6 +73752,11 @@ msgstr "переповнення ідентифікатора: %d"
 msgid "check_charlen_present(): length not set"
 msgstr "помилка: check_charlen_present(): довжина не встановлена"
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr ""
+
 #: fortran/match.cc:118
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
@@ -74101,7 +74158,7 @@ msgstr "Код STOP на %L повинен бути символьним тип
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "Код STOP на %L повинен бути цілочисельним типом KIND=%d за замовчуванням"
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr "Специфікатор QUIET на %L повинен бути скалярним типом LOGICAL"
@@ -74625,82 +74682,82 @@ msgstr "Помилка синтаксису в операторі SELECT TYPE в
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "Селектор в операторі SELECT TYPE в %C не є іменованою змінною; використовуйте associate-name=>"
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr "Оператор SELECT RANK в %C"
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr "Селектор в операторі SELECT RANK в %C повинен бути змінною з припущеним рангом"
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "Помилка синтаксису в операторі SELECT RANK в %C"
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Неочікуваний оператор CASE в %C"
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Синтаксична помилка в специфікації CASE в %C"
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Неочікувана інструкція TYPE IS на %C"
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr "Тип-специфікація не повинна вказувати послідовний похідний тип або тип з атрибутом BIND в SELECT TYPE на %C [F2003:C815]"
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr "Усі параметри типу LEN в інструкції TYPE IS на %C повинні бути ПРИПУЩЕНІ"
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Синтаксична помилка в специфікації TYPE IS на %C"
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Синтаксична помилка в специфікації CLASS IS на %C"
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected RANK statement at %C"
 msgstr "Неочікувана інструкція RANK на %C"
 
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "Вираз SELECT RANK CASE на %C повинен бути скалярною цілою константою"
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr "Значення виразу SELECT RANK CASE на %C не може бути менше нуля або більше %d"
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr "Синтаксична помилка в специфікації RANK на %C"
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "Інструкція ELSEWHERE на %C не вкладена в блок WHERE"
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "Мітка %qs на %C не відповідає мітці WHERE %qs"
@@ -76140,8 +76197,8 @@ msgstr "Параметр замикання ORDERED менший за COLLAPSE 
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr "Замикання ORDER не можна використовувати разом з ORDERED на рядку %L"
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "Замикання IF на рядку %L вимагає скалярний логічний вираз"
@@ -78525,12 +78582,12 @@ msgstr "Вбудована функція %qs, оголошена як INTRINSIC
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Можливо, нерекурсивна процедура %qs у %L викликається рекурсивно сама себе. Оголосіть її як RECURSIVE або використовуйте %<-frecursive%>"
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Можливо, нерекурсивна процедура %qs у %L викликається рекурсивно сама себе. Оголосіть її як RECURSIVE або використовуйте %<-frecursive%>"
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Мітка %d, на яку є посилання у %L, ніколи не визначена"
@@ -78650,7 +78707,7 @@ msgstr "Відсутня явна декларація з атрибутом EXT
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Функція %qs в %L не має ІМПЛІЦИТНОГО типу; ви мали на увазі %qs?"
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Функція %qs в %L не має ІМПЛІЦИТНОГО типу"
@@ -79049,279 +79106,285 @@ msgstr "Припущена змінна типу %s на %L не повинна
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Припущена змінна рангу %s на %L не повинна мати посилання на підобʼєкт"
 
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr "Погана посилання на масив на %L"
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Змінна %qs, яка використовується в специфікаційному виразі, має посилання на %L до заяви ENTRY, в якій вона є параметром"
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Змінна %qs використовується на %L до заяви ENTRY, в якій вона є параметром"
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Поліморфний підобʼєкт коіндексованого обʼєкта на %L"
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Коіндексований обʼєкт з поліморфною видільною підкомпонентою на %L"
 
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "Використання змінної %qs у %L є застарілим"
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Bad array reference at %L"
+msgid "Invalid array reference at %L"
+msgstr "Погана посилання на масив на %L"
+
+#: fortran/resolve.cc:6433
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr "%qs у %L повʼязано з хостом у %L в межах вкладеної процедури з внутрішньою процедурою з таким самим імʼям"
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "Помилка у типованому виклику у %L"
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Переданий обʼєкт у %L повинен бути скалярним"
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Базовий обʼєкт для виклику компоненти вказівника на процедуру у %L має абстрактний тип %qs"
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Базовий обʼєкт для типованого виклику процедури у %L має абстрактний тип %qs"
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Базовий обʼєкт для типованого виклику NOPASS-процедури у %L повинен бути скалярним"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Не знайдено відповідного специфічного звʼязування для виклику GENERIC %qs на %L"
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs на %L повинно бути ПІДПРОГРАМОЮ"
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs на %L повинно бути ФУНКЦІЄЮ"
 
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Поганий тип виразу"
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s на %L повинно бути скаляром"
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s на %L повинно бути цілочисельним"
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s на %L повинно бути INTEGER"
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Вираз кроку в DO-циклі на %L не може бути нулем"
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO-цикл на %L буде виконано нуль разів"
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "DO-цикл на %L не визначений, оскільки переповнюється"
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "DO-цикл на %L не визначений, оскільки підповнюється"
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "Індекс FORALL з іменем на %L повинен бути скалярним ЦІЛИМ"
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "Початковий вираз FORALL на %L повинен бути скалярним ЦІЛИМ"
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "Кінцевий вираз FORALL на %L повинен бути скалярним ЦІЛИМ"
 
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "Вираз кроку FORALL на %L повинен бути скалярним %s"
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "Вираз кроку FORALL на %L не може бути нулем"
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "Індекс FORALL %qs не може зʼявлятися в специфікації триплета на %L"
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Обʼєкт розподілу на %L повинен бути ALLOCATABLE або POINTER"
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Коіндексований обʼєкт розподілу на %L"
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Вихідний вираз на %L повинен бути скалярним або мати такий же ранг, як обʼєкт розподілу на %L"
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Вираз-джерело на %L та обʼєкт-виділення на %L повинні мати однакову форму"
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Тип сутності на %L несумісний з виразом-джерелом на %L"
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Обʼєкт-виділення на %L та вираз-джерело на %L повинні мати однаковий типовий параметр"
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Вираз-джерело на %L не може бути типу LOCK_TYPE або мати компонент LOCK_TYPE, якщо обʼєкт-виділення на %L є комасивом"
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "Вираз-джерело на %L не може бути типу EVENT_TYPE або мати компонент EVENT_TYPE, якщо обʼєкт-виділення на %L є комасивом"
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Виділення %s з базовим типом ABSTRACT на %L вимагає типової специфікації або виразу джерела"
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Виділення %s на %L з типовою специфікацією вимагає такого самого параметра довжини символів, як у декларації"
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "У ALLOCATE-операторі на %L потрібна специфікація масиву"
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "У ALLOCATE-операторі на %L потрібна специфікація масиву або виразу SOURCE= з масивним значенням"
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "У операторі ALLOCATE на %L потрібна специфікація ко-масиву"
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Неправильна специфікація ко-масиву в операторі ALLOCATE на %L"
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr "Верхня межа менша за нижню межу на %L"
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr "Верхня межа менша за нижню межу 1 на %L"
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Неправильна специфікація масиву в операторі ALLOCATE на %L"
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs не повинно зʼявлятися в специфікації масиву на %L в тому ж операторі ALLOCATE, де воно само алоціюється"
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "Очікується %<*%> в специфікації коіндексу в операторі ALLOCATE на %L"
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-змінна на %L повинна бути скалярною цілочисельною змінною"
 
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-змінна на %L не повинна бути %s в тому ж операторі %s"
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "Повідомлення про помилку на %L без тегу STAT нічого не значить"
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "Змінна ERRMSG на %L повинна бути скалярною змінною типу CHARACTER за замовчуванням"
 
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Змінна ERRMSG на %L не повинна бути %s в тій самій %s інструкції"
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Обʼєкт, що виділяється, на %L також зʼявляється на %L"
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Обʼєкт, що виділяється, на %L є підобʼєктом обʼєкта на %L"
@@ -79330,284 +79393,284 @@ msgstr "Обʼєкт, що виділяється, на %L є підобʼєкт
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "Мітка CASE на %L перекривається з міткою CASE на %L"
 
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Вираз в операторі CASE на %L повинен бути типу %s"
 
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Вираз в операторі CASE на %L повинен бути виду %d"
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Вираз в операторі CASE на %L повинен бути скалярним"
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Вираз вибору в обчисленому операторі GOTO на %L повинен бути скалярним цілим виразом"
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Аргумент оператора SELECT на %L не може бути %s"
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Аргумент оператора SELECT на %L повинен бути скалярним виразом"
 
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Вираз у CASE-операторі на %L не знаходиться у діапазоні %s"
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "Оператор DEFAULT CASE на %L не може слідувати за другим оператором DEFAULT CASE на %L"
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Логічний діапазон у CASE-операторі на %L не дозволяється"
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Константне логічне значення в операторі CASE повторюється на %L"
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Специфікація діапазону на %L ніколи не може збігатися"
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Логічний блок SELECT CASE на %L має більше двох випадків"
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "Асоціююча сутність %qs на %L є вказівником на процедуру"
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Похідний тип %qs не може бути використаний як змінна на %L"
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Асоціююча сутність %qs на %L є імʼям процедури"
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr "Асоціюючий вираз-селектор на %L повертає процедуру"
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Селектор на %L не може бути NULL()"
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Селектор на %L не має типу"
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Асоційоване імʼя %qs на %L використовується як масив"
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "Селектор CLASS на %L потребує тимчасовий обʼєкт, який ще не реалізований"
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Селектор повинен бути поліморфним в операторі SELECT TYPE на %L"
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Селектор на %L не повинен бути коіндексованим"
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS на %L перекривається з TYPE IS на %L"
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Похідний тип %qs на %L повинен бути розширюваним"
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Похідний тип %qs на %L повинен бути розширенням %qs"
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Неочікуваний вбудований тип %qs на %L"
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Тип-специфікація в %L повинна вказувати, що кожен параметр типу довжини припускається"
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Подвійний блок CLASS IS у операторі SELECT TYPE на %L"
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr "RANK DEFAULT на %L повторюється на %L"
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr "RANK (*) на %L повторюється на %L"
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr "RANK (%i) на %L повторюється на %L"
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr "RANK (*) на %L не може використовуватися з вказівником або виділеною селектором на %L"
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Недійсний контекст для вбудованої функції NULL () на %L"
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Процедура DTIO %s на %L повинна бути рекурсивною"
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Елемент передачі даних на %L не може бути поліморфним, якщо його не обробляє визначена процедура введення/виведення"
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Елемент передачі даних на %L не може мати компоненти POINTER, якщо він не обробляється визначеною процедурою введення/виведення"
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Елемент передачі даних на %L не може мати компоненти вказівника на процедуру"
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Елемент передачі даних на %L не може мати компоненти ALLOCATABLE, якщо він не обробляється визначеною процедурою введення/виведення"
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Елемент передачі даних на %L не може мати приватні компоненти"
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Елемент передачі даних на %L не може мати приватні компоненти, якщо він не обробляється визначеною процедурою введення/виведення"
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Елемент передачі даних на %L не може бути повною посиланням на масив з припущеним розміром"
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Змінна блокування на %L повинна бути скаляром типу LOCK_TYPE"
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "Змінна події на %L повинна бути скаляром типу EVENT_TYPE"
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Аргумент змінної події на %L повинен бути комасивом або коіндексований"
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Аргумент змінної події на %L повинен бути комасивом, але не коіндексований"
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "Аргумент STAT= на %L повинен бути скалярною цілочисельною змінною"
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "Аргумент ERRMSG= на %L повинен бути скалярною символьною змінною"
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "Аргумент ACQUIRED_LOCK= на %L повинен бути скалярною логічною змінною"
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Аргумент UNTIL_COUNT= на %L повинен бути скалярним цілочисельним виразом"
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Аргумент Imageset на %L повинен бути скалярним або ранг-1 цілочисельним виразом"
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Аргумент Imageset на %L повинен бути між 1 і num_images()"
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Заява на %L не є дійсною цільовою заявою гілки для заяви гілки на %L"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Гілка на %L може призвести до безкінечного циклу"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "Заява GOTO на %L залишає конструкцію CRITICAL для мітки на %L"
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "Заява GOTO на %L залишає конструкцію DO CONCURRENT для мітки на %L"
@@ -79615,214 +79678,214 @@ msgstr "Заява GOTO на %L залишає конструкцію DO CONCURR
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Мітка на %L не знаходиться в тому ж блоку, що й заява GOTO на %L"
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "Маска WHERE на %L має неузгоджену форму"
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "Ціль присвоєння WHERE на %L має неузгоджену форму"
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Не-елементарне користувацьке призначення в WHERE на %L"
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Непідтримувана заява всередині WHERE на %L"
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Присвоєння змінній індексу FORALL на %L"
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL з індексом %qs не використовується зліва від призначення на %L, тому може призвести до множинного призначення цього обʼєкта"
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "Конструкція FORALL на %L"
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "Індекс FORALL з іменем на %L повинен бути скалярною змінною типу цілочисельне"
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Зовнішня конструкція FORALL вже має індекс з таким імʼям на %L"
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "Замикання WHERE/ELSEWHERE на %L вимагає логічний масив"
 
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Неправильний тип блоку"
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have procedure pointer components"
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr "Елемент передачі даних на %L не може мати компоненти вказівника на процедуру"
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr "Вираз CHARACTER буде обрізаний при присвоєнні (%ld/%ld) на %L"
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Коіндексований вираз на %L присвоюється змінній похідного типу з POINTER компонентою в PURE процедурі"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr "У чистій підпрограмі INTENT(IN) фіктивний аргумент не повинен використовуватися як вираз на %L в інтегрованій інструкції присвоєння, в якій змінна є похідним типом, якщо похідний тип має POINTER компоненту на будь-якому рівні вибору компоненти."
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Присвоєння коіндексованій змінній на %L у чистій процедурі"
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Присвоєння поліморфному спільному масиву на %L не дозволяється"
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Присвоєння змінній з можливістю виділення памʼяті поліморфного типу на %L"
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Присвоєння змінній з можливістю виділення памʼяті поліморфного типу на %L потребує %<-frealloc-lhs%>"
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr "Невиділену змінну не повинно бути поліморфною в інтегрованому призначенні на %L - перевірте, що існує відповідна конкретна підпрограма для оператора %<=%>"
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Коіндексована змінна не повинна мати виділеної памʼяті остаточної компоненти в призначенні на %L"
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "TODO: типове обмежене призначення(я) на %L не виконано, оскільки в проміжних виразах виникають посилання на масив з кількома частинами."
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Призначення вказівника на процедуру на %L"
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Результат функції на лівій стороні призначення на %L повинен мати атрибут вказівника."
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "Аргумент TEAM для %qs на %L повинен бути скалярним виразом типу TEAM_TYPE"
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "Аргумент TEAM NUMBER для FORM TEAM на %L повинен бути скалярним INTEGER"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "Оператор ASSIGNED GOTO на %L вимагає скалярну цілочисельну змінну"
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Змінній %qs не було призначено цільової мітки на %L"
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Альтернативна RETURN-інструкція на %L потребує специфікатора повернення SCALAR-INTEGER"
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "Очікувалося вбудоване призначення в OMP WORKSHARE на %L"
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "Інструкція ASSIGN на %L потребує скалярну змінну INTEGER за замовчуванням"
 
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "Недійсний NULL на %L"
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Арифметична IF-інструкція на %L потребує скалярний вираз REAL або INTEGER"
 
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Немає виразу на DO WHILE"
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Умова виходу з циклу DO WHILE на %L повинна бути скалярним логічним виразом"
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "Замикання FORALL маски на %L вимагає скалярний логічний вираз"
 
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Поганий код оператора"
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Використання параметра %qs, оголошеного на %L, є застарілим"
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Змінна %qs з міткою привʼязки %qs на %L використовує той самий глобальний ідентифікатор, що й сутність на %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "Змінна %qs з модуля %qs з міткою звʼязування %qs на %L використовує той самий глобальний ідентифікатор, що й сутність на %L з модуля %qs"
@@ -79830,1003 +79893,1003 @@ msgstr "Змінна %qs з модуля %qs з міткою звʼязуван
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Процедура %qs з міткою звʼязування %qs на %L використовує той самий глобальний ідентифікатор, що й сутність на %L"
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Довжина рядка на %L занадто велика"
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Масив, що може бути виділений %qs на %L, повинен мати відкладену форму або припущений ранг"
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Скалярний обʼєкт %qs на %L не може бути виділеним"
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Вказівник на масив %qs на %L повинен мати відкладену форму або припущений ранг"
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Масив %qs на %L не може мати відкладену форму"
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Тип %qs змінної CLASS %qs на %L не є розширюваним"
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "Змінна CLASS %qs на %L повинна бути фіктивною, виділеною або вказівником"
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Тип %qs не може бути повʼязаним з хостом на %L, оскільки його блокує несумісний обʼєкт з таким самим імʼям, оголошений на %L"
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Неявне збереження для змінної модуля %qs на %L, необхідне через типову ініціалізацію"
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Сутність %qs на %L має відкладений параметр типу і вимагає атрибут POINTER або ALLOCATABLE"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Масив модуля або головної програми %qs на %L повинен мати сталу форму"
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Сутність з припущеною довжиною символів на %L повинна бути фіктивним аргументом або ПАРАМЕТРОМ"
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs на %L повинен мати сталу довжину символів в цьому контексті"
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "Змінна COMMON %qs на %L повинна мати сталу довжину символів"
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Змінна з можливістю виділення %qs у %L не може мати ініціалізатора"
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Зовнішня змінна %qs у %L не може мати ініціалізатора"
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Фіктивна змінна %qs у %L не може мати ініціалізатора"
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Вбудована змінна %qs у %L не може мати ініціалізатора"
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Результат функції %qs у %L не може мати ініціалізатора"
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Автоматичний масив %qs у %L не може мати ініціалізатора"
 
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s у %L"
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Функція заяви зі значенням символу %qs у %L повинна мати сталу довжину"
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs має приватний тип і не може бути фіктивним аргументом %qs, який є публічним у %L"
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Процедура %qs в публічному інтерфейсі %qs на %L приймає фіктивні аргументи %qs, які є ПРИВАТНИМИ"
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Функція %qs на %L не може мати ініціалізатора"
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Зовнішній обʼєкт %qs на %L не може мати ініціалізатора"
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-функція %qs на %L повинна мати скалярний результат"
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Функція-оператор %qs на %L не може мати атрибуту вказівника або атрибуту виділення памʼяті"
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "Функція CHARACTER(*) %qs на %L не може бути масивом"
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "Функція CHARACTER(*) %qs на %L не може бути вказівником"
 
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "Функція CHARACTER(*) %qs на %L не може бути чистою"
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Функція CHARACTER(*) %qs у рядку %L не може бути рекурсивною"
 
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Функція CHARACTER(*) %qs у рядку %L"
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Вказівник на процедуру %qs у рядку %L не може бути елементарним"
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Фіктивна процедура %qs у рядку %L не може бути елементарною"
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Змінна результату функції %qs у рядку %L елементарної функції %qs не може мати атрибут ALLOCATABLE або POINTER"
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "Атрибут PROCEDURE конфліктує з атрибутом SAVE у %qs у рядку %L"
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "Атрибут PROCEDURE конфліктує з атрибутом INTENT у %qs у рядку %L"
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "Атрибут PROCEDURE конфліктує з атрибутом RESULT в %qs на %L"
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "Атрибут EXTERNAL конфліктує з атрибутом FUNCTION в %qs на %L"
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Результат вказівника процедури %qs на %L не має атрибуту вказівника"
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Несумісність атрибуту ELEMENTAL між MODULE PROCEDURE на %L та його інтерфейсом в %s"
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Несумісність атрибуту PURE між MODULE PROCEDURE на %L та його інтерфейсом в %s"
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Несумісність атрибуту RECURSIVE між MODULE PROCEDURE на %L та його інтерфейсом в %s"
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s між оголошенням MODULE PROCEDURE в MODULE %qs та оголошенням на %L в (SUB)MODULE %qs"
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr "Інтерфейс %qs на %L повинен бути явним"
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL процедура %qs на %L не є SUBROUTINE"
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL процедура на %L повинна мати рівно один аргумент"
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Аргумент FINAL процедури на %L повинен бути типу %qs"
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr "FINAL процедура на %L з аргументом з припущеним рангом повинна бути єдиним фіналізатором з такою самою категорією/типом (F2018: C790)"
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Аргумент FINAL процедури на %L не може бути POINTER"
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Аргумент FINAL процедури на %L не може бути ALLOCATABLE"
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Аргумент FINAL процедури на %L не може бути OPTIONAL"
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Аргумент FINAL процедури на %L не може бути INTENT(OUT)"
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Нескалярна FINAL процедура на %L повинна мати аргумент з припущеною формою"
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "FINAL процедура %qs, оголошена на %L, має такий же ранг (%d), як %qs"
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr "Тільки масивні FINAL процедури оголошені для похідного типу %qs, визначеного на %L, рекомендується також скалярна, якщо не було оголошено фіналізатор з припущеним рангом"
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs та %qs не можуть бути змішані FUNCTION/SUBROUTINE для GENERIC %qs на %L"
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs та %qs для GENERIC %qs на %L є неоднозначними"
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Невизначена конкретна привʼязка %qs як ціль GENERIC %qs на %L"
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs на %L повинен мати конкретну привʼязку, %qs також є GENERIC"
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "GENERIC %qs на %L не може перезаписати конкретну привʼязку з таким самим імʼям"
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Оператор, повʼязаний з типом, на %L не може бути NOPASS"
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs повинен бути процедурою модуля або зовнішньою процедурою з явним інтерфейсом на %L"
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Процедура %qs з PASS(%s) на %L не має аргументу %qs"
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Процедура %qs з PASS на %L повинна мати принаймні один аргумент"
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Неполіморфний фіктивний аргумент переданого обʼєкту %qs на %L"
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Аргумент %qs функції %qs з PASS(%s) на %L повинен бути похідним типом %qs"
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, fuzzy, gcc-internal-format
 #| msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr "Аргумент %qs функції %qs з PASS(%s) на %L повинен бути похідним типом %qs"
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, fuzzy, gcc-internal-format
 #| msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr "Усі параметри типу LEN в інструкції TYPE IS на %C повинні бути ПРИПУЩЕНІ"
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Фіктивний аргумент переданого обʼєкту %qs на %L повинен бути скалярним"
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Фіктивний аргумент переданого обʼєкту %qs на %L не може бути ALLOCATABLE"
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Фіктивний аргумент переданого обʼєкту %qs на %L не може бути POINTER"
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Процедура %qs на %L має ту саму назву, що й компонент %qs"
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Процедура %qs на %L має ту саму назву, що й успадкований компонент %qs"
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Похідний тип %qs, оголошений на %L, повинен бути АБСТРАКТНИМ, оскільки %qs є ВІДКЛАДЕНИМ і не перевизначений"
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Компонент комасиву %qs на %L повинен бути виділенням з відкладеною формою"
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Компонент %qs на %L з типом TYPE(C_PTR) або TYPE(C_FUNPTR) не може бути комасивом"
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Компонент %qs у %L з компонентом комасиву повинен бути невказівниковим, невиділяемим скаляром"
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Компонент %qs в %L має атрибут CONTIGUOUS, але не є вказівником на масив"
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Компонент %qs типу BIND(C) в %L повинен мати довжину одиницю"
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Компонент вказівника на процедуру %qs з PASS(%s) в %L не має аргументу %qs"
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Компонент вказівника на процедуру %qs з PASS в %L повинен мати принаймні один аргумент"
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Аргумент %qs в %qs з PASS(%s) в %L повинен бути похідним типом %qs"
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Аргумент %qs в %qs з PASS(%s) в %L повинен бути скалярним"
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Аргумент %qs в %qs з PASS(%s) в %L не може мати атрибут POINTER"
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Аргумент %qs функції %qs з PASS(%s) на %L не може бути ALLOCATABLE"
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Компонент %qs функції %qs на %L має таке саме імʼя, як успадкована звʼязана з процедурою типу"
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Довжина символів компонента %qs має бути константним виразом специфікації на %L"
 
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "Вираз довжини символів компонента %qs на %L повинен бути типу INTEGER, знайдено %s"
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Символьний компонент %qs функції %qs на %L з відкладеною довжиною повинен бути POINTER або ALLOCATABLE"
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "компонент %qs є типом PRIVATE і не може бути компонентом %qs, який є PUBLIC на %L"
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Поліморфний компонент %s на %L у типі SEQUENCE або BIND(C) %s"
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Компонент %s типу SEQUENCE, оголошений на %L, не має атрибуту SEQUENCE"
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Конфліктуючі ініціалізатори в обʼєднанні на %L та %L"
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Оскільки розширюючий тип %qs на %L має компонент coarray, батьківський тип %qs також повинен мати один"
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Не розширюваний похідний тип %qs на %L не повинен бути АБСТРАКТНИМ"
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Параметризований тип %qs не має компонента, що відповідає параметру %qs на %L"
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Загальне імʼя %qs функції %qs на %L збігається з імʼям похідного типу на %L"
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "Похідний тип %qs на %L не був оголошений"
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Масив з припущеним розміром %qs у списку імен %qs на %L не дозволяється"
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Обʼєкт масиву NAMELIST %qs з припущеною формою у списку імен %qs в %L"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Обʼєкт масиву NAMELIST %qs з незмінною формою у списку імен %qs в %L"
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Обʼєкт NAMELIST %qs з незмінною довжиною символу у списку імен %qs в %L"
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "Обʼєкт NAMELIST %qs був оголошений як PRIVATE і не може бути членом PUBLIC списку імен %qs в %L"
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "Обʼєкт NAMELIST %qs має використовувані PRIVATE компоненти і не може бути членом списку імен %qs в %L"
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "Обʼєкт NAMELIST %qs має PRIVATE компоненти і не може бути членом PUBLIC списку імен %qs в %L"
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "Атрибут PROCEDURE конфліктує з атрибутом NAMELIST у %qs в %L"
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Масив параметрів %qs в %L не може бути автоматичним або мати відкладену форму"
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Неявно визначений ПАРАМЕТР %qs у %L не відповідає пізнішому неявному типу"
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Несумісний похідний тип в ПАРАМЕТРІ у %L"
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Змінна CLASS %qs у %L не може мати атрибут PARAMETER"
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, fuzzy, gcc-internal-format
 #| msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Сутність %qs на %L має відкладений параметр типу і вимагає атрибут POINTER або ALLOCATABLE"
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "АВТОМАТИЧНИЙ обʼєкт %qs на %L не повинен мати атрибуту SAVE або бути змінною, оголошеною в головній програмі, модулі або підмодулі (F08/C513)"
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "Обʼєкт %qs на %L з передбаченими параметрами типу повинен бути фіктивним або вибірником типу SELECT (F08/4.2)"
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "На жаль, компоненти, які можна виділяти або вказувати, в поліморфних (CLASS) типах комасивів на %L не підтримуються"
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr "%<omp_all_memory%>, оголошений на %L, може використовуватися лише в замиканні OpenMP DEPEND"
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Атрибут PROTECTED конфліктує з атрибутом EXTERNAL на %L"
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Атрибут PROCEDURE конфліктує з атрибутом PROTECTED на %L"
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs на %L має атрибут CONTIGUOUS, але не є вказівником на масив або масивом з таємною формою або таємним рангом"
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Неправильна специфікація для масиву з припущеним розміром на %L"
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Масив з припущеним розміром на %L повинен бути фіктивним аргументом"
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Масив з припущеною формою на %L повинен бути фіктивним аргументом"
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Масив з припущеним рангом на %L повинен бути фіктивним аргументом"
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Масив з припущеним рангом на %L не може мати атрибутів VALUE або CODIMENSION"
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Символ на %L не є фіктивною змінною"
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs на %L не може мати атрибут VALUE, оскільки це не є фіктивним аргументом"
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Фіктивна змінна символьного типу %qs на %L з атрибутом VALUE повинна мати сталу довжину"
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "Символьна фіктивна змінна %qs на %L з атрибутом VALUE, сумісна з C, повинна мати довжину одиницю"
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Похідний тип %qs на %L має тип %qs, який не був визначений"
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Змінна %s на %L з атрибутом NO_ARG_CHECK повинна бути фіктивним аргументом"
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Змінна %s на %L з атрибутом NO_ARG_CHECK повинна бути типу TYPE(*) або числового вбудованого типу"
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Змінна %s на %L з атрибутом NO_ARG_CHECK не може мати атрибутів ALLOCATABLE, CODIMENSION, POINTER або VALUE"
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Змінна %s на %L з атрибутом NO_ARG_CHECK не може мати атрибут INTENT(OUT)"
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Змінна %s на %L з атрибутом NO_ARG_CHECK повинна бути або скаляром, або масивом з передбачуваною розмірністю"
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Припущений тип змінної %s на %L дозволений лише для фіктивних змінних"
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Змінна %s припущеного типу на %L не може мати атрибути ALLOCATABLE, CODIMENSION, POINTER або VALUE"
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Припущена змінна %s на %L не може мати атрибут INTENT(OUT)"
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Припущена змінна %s на %L не може бути масивом з явною формою"
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Змінна %qs на %L не може бути BIND(C), оскільки вона не є загальним блоком або не оголошена на рівні модуля"
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Змінна BIND(C) %qs на %L повинна мати довжину одиницю"
 
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "ПУБЛІЧНА %s %qs на %L з приватним похідним типом %qs"
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Змінна %s на %L типу LOCK_TYPE або з підкомпонентом типу LOCK_TYPE повинна бути комасивом"
 
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "Змінна %s на %L типу EVENT_TYPE або з підкомпонентою типу EVENT_TYPE повинна бути комасивом"
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "Фіктивний аргумент INTENT(OUT) %qs на %L має ASSUMED SIZE і, отже, не може мати значення за замовчуванням"
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Фіктивний аргумент %qs на %L типу LOCK_TYPE не може бути INTENT(OUT)"
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Фіктивний аргумент %qs на %L типу EVENT_TYPE не може бути INTENT(OUT)"
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Результат функції %qs на %L не може бути комасивом або мати комасивну компоненту"
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Змінна %qs на %L типу TYPE(C_PTR) або TYPE(C_FUNPTR) не може бути комасивом"
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Змінна %qs на %L з компонентом комасиву має бути невказівником, неалокаційним скаляром, який не є комасивом"
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Змінна %qs на %L є комасивом і не є ВИДІЛЕНОЮ, ЗБЕРЕЖЕНОЮ або фіктивним аргументом"
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Комасивна змінна %qs на %L не повинна мати ко-розмірності з відкладеною формою"
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Змінна %qs на %L з можливістю виділення памʼяті має мати відкладену форму"
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Змінна %qs на %L має INTENT(OUT) і, отже, не може бути виділеним комасивом або мати компоненти комасиву"
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Фіктивна змінна комасиву %qs на %L не дозволена в процедурі BIND(C) %qs"
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "ЛОГІЧНИЙ фіктивний аргумент %qs в %L з не-C_Bool видом в процедурі BIND(C) %qs"
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "ЛОГІЧНА змінна результату %qs в %L з не-C_Bool видом в процедурі BIND(C) %qs"
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Список імен %qs не може бути аргументом підпрограми або функції в %L"
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate в %L не зберігається"
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "Змінна !$OMP DECLARE TARGET %qs на %L не зберігається"
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "Очікується визначений обʼєкт поблизу %L"
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "Елемент BLOCK DATA %qs на %L повинен бути в COMMON"
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "Масив DATA %qs на %L повинен бути вказаний в попередньому оголошенні"
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Елемент DATA %qs на %L не може мати спільного індексу"
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "Елемент DATA %qs на %L є вказівником і, отже, повинен бути повним масивом"
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr "Обʼєкт DATA поблизу %L має атрибут вказівника, а відповідне значення DATA не є дійсною початковою ціллю даних"
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "Елемент DATA %qs на %L не може мати атрибут ALLOCATABLE"
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Неконстантний розділ масиву у %L в інструкції DATA"
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "Інструкція DATA у %L має більше змінних, ніж значень"
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Nonconstant array section at %L in DATA statement"
 msgid "Non-constant character length at %L in DATA statement"
 msgstr "Неконстантний розділ масиву у %L в інструкції DATA"
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "початок неявного циклу DO у %L не може бути спрощений до константного значення"
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "кінець неявного циклу DO на %L не може бути спрощений до константного значення"
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "крок неявного циклу DO на %L не може бути спрощений до сталого значення"
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "крок неявного циклу DO на %L не може бути нулем"
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "інструкція DATA на %L має більше значень, ніж змінних"
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Мітка %d на %L визначена, але не використовується"
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Мітка %d на %L визначена, але не може бути використана"
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Змінна похідного типу %qs на %L повинна мати атрибут SEQUENCE, щоб бути обʼєктом EQUIVALENCE"
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Змінна похідного типу %qs на %L не може мати компоненти ALLOCATABLE, щоб бути обʼєктом EQUIVALENCE"
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Змінна похідного типу %qs на %L зі стандартною ініціалізацією не може бути в EQUIVALENCE змінною в COMMON"
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Змінна похідного типу %qs на %L з компонентами-вказівниками не може бути обʼєктом EQUIVALENCE"
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Помилка синтаксису в операторі EQUIVALENCE на %L"
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Або всі, або жоден з обʼєктів в наборі EQUIVALENCE на %L повинні мати атрибут PROTECTED"
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Елемент блоку COMMON %qs у %L не може бути обʼєктом EQUIVALENCE у чистій процедурі %qs"
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Іменована константа %qs на %L не може бути обʼєктом EQUIVALENCE"
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Масив %qs на %L з неконстантними межами не може бути обʼєктом EQUIVALENCE"
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Компонент структури %qs на %L не може бути обʼєктом EQUIVALENCE"
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Підрядок на %L має нульову довжину"
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "Самовідсилання в виразі довжини символу для %qs на %L"
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "ПУБЛІЧНА функція %qs на %L з ПРИВАТНИМ типом %qs"
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs на %L не має ІМПЛІЦИТНОГО типу"
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Процедура користувацького оператора %qs на %L повинна бути ФУНКЦІЄЮ"
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Процедура користувацького оператора %qs на %L не може мати припущену довжину символу"
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Процедура користувача оператора %qs на %L повинна мати принаймні один аргумент"
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Перший аргумент інтерфейсу оператора на %L не може бути необовʼязковим"
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Другий аргумент інтерфейсу оператора на %L не може бути необовʼязковим"
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Інтерфейс оператора на %L повинен мати, як максимум, два аргументи"
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Вкладена процедура %qs на %L PURE-процедури також повинна бути PURE"
@@ -81371,127 +81434,127 @@ msgstr "Неявно оголошена змінна %qs на %L може не 
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr "Результат функції %qs на %L не має неявного типу"
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr "Атрибут %s конфліктує з атрибутом %s у %L"
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, gcc-internal-format
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr "Атрибут %s конфліктує з атрибутом %s в %qs на %L"
+
+#: fortran/symbol.cc:508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr "Атрибут %s не дозволений в програмній одиниці BLOCK DATA на %L"
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "Імʼя групи списку імен на %L не може мати атрибут SAVE"
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, gcc-internal-format
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr "внутрішня процедура %qs на %L конфліктує з фіктивним аргументом"
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "Вказівник на процедуру у %C"
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "Атрибут %s застосовується до %s %s на %L"
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) застосовується до %s %s у %L"
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, gcc-internal-format, gfc-internal-format
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr "Атрибут %s конфліктує з атрибутом %s у %L"
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, gcc-internal-format
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr "Атрибут %s конфліктує з атрибутом %s в %qs на %L"
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "Не можна змінювати атрибути символу, повʼязаного з USE, у %L"
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "Не можна змінювати атрибути символу, повʼязаного з USE, %s у %L"
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "Повторно вказано атрибут %s у %L"
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr "ALLOCATABLE вказано поза тілом INTERFACE на %L"
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr "Повторно вказано атрибут AUTOMATIC на %L"
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "CODIMENSION вказано для %qs поза тілом його INTERFACE на %L"
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "DIMENSION вказано для %qs поза тілом його ІНТЕРФЕЙСу на %L"
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "Cray Pointee на %L зʼявляється в кількох вказівках pointer()"
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "Повторно вказано атрибут PROTECTED на %L"
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "Атрибут SAVE на %L не може бути вказаний в чистій процедурі"
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "Повторно вказано атрибут SAVE на %L"
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "Повторно вказано атрибут VALUE у %L"
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Повторно вказано атрибут VOLATILE у %L"
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr "Атрибут VOLATILE на %L не може бути вказаний в чистій процедурі"
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Повторно вказано атрибут ASYNCHRONOUS у %L"
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "Атрибут %s у %qs конфліктує з атрибутом %s у %L"
 
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -81500,203 +81563,203 @@ msgstr ""
 "Процедура %s у %L вже оголошена як процедура %s. \n"
 "F2008: Присвоєння функції-вказівника є неоднозначним, якщо воно є першим виконуваним оператором після блоку специфікації. Будь ласка, додайте будь-який інший виконуваний оператор перед ним. FIXME"
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "Процедура %s в %L вже оголошена як процедура %s"
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT(%s) конфліктує з INTENT(%s) в %L"
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "Специфікація ACCESS в %L вже була вказана"
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Повторно вказано атрибут BIND в %L"
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "BIND(C) в %L"
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Повторно вказано атрибут EXTENDS в %L"
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "EXTENDS в %L"
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Символ %qs в %L вже має явний інтерфейс"
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "%qs в %L має атрибути, вказані поза його тілом INTERFACE"
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "Символ %qs в %L конфліктує з символом з модуля %qs, використовується в %L"
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Символ %qs в %L вже має основний тип %s"
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Процедура %qs в %L не може мати основний тип %s"
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Символ %qs в %L не може мати типу"
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Компонент %qs в %C вже є в батьківському типі в %L"
 
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Символ %qs в %C є неоднозначним"
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Похідний тип %qs в %C використовується до його визначення"
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Компонент %qs в %C є ПРИВАТНИМ компонентом %qs"
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "%qs в %C не є членом структури %qs; ви мали на увазі %qs?"
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs в %C не є членом структури %qs"
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Подвійна мітка вказівки %d на %L і %L"
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Мітка %d на %C вже використовується як ціль гілки"
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Мітка %d на %C вже використовується як мітка формату"
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr "Заява про завершення DO, яка не є END DO або CONTINUE з міткою %d на %C"
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Мітка %d на %C раніше використовувалася як мітка формату"
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Мітка %d на %C раніше використовувалася як ціль гілки"
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "Спільна мітка завершення DO %d на %C"
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr "Позначена інструкція DO в %L"
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Імʼя %qs у %C є неоднозначним посиланням на %qs з модуля %qs"
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "Імʼя %qs в %C є неоднозначним посиланням на %qs з поточної одиниці програми"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Символ %qs в %C вже має асоціацію з хостом"
 
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr "verify_bind_c_derived_type(): Даний символ неочікувано має значення NULL"
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Похідний тип %qs, оголошений у %L, повинен мати атрибут BIND, щоб бути сумісним з C"
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "Похідний тип %qs з атрибутом BIND(C) у %L є порожнім і може бути недоступним для супутнього процесора C"
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Компонент %qs у %L не може мати атрибут POINTER, оскільки він є членом похідного типу BIND(C) %qs у %L"
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "Компонент вказівника на процедуру %qs на %L не може бути членом похідного типу BIND(C) %qs на %L"
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Компонент %qs на %L не може мати атрибут ALLOCATABLE, оскільки він є членом похідного типу BIND(C) %qs на %L"
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "Компонент %qs в похідному типі %qs на %L може бути несумісним з C, навіть якщо похідний тип %qs є BIND(C)"
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "Компонент %qs в похідному типі %qs на %L може бути несумісним з C"
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Похідний тип %qs на %L не може мати атрибут SEQUENCE, оскільки він є BIND(C)"
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "Символ %qs використовується до того, як він введений на %L"
@@ -81726,24 +81789,24 @@ msgstr "Перекриваються нерівні ініціалізатори
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "Перекриваються нерівні ініціалізатори в EQUIVALENCE на %C"
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr "Конструктор структури на %C був завершений. Ця функція була видалена за допомогою f08/0011. Використовуйте -std=f2018 або -std=gnu, щоб усунути завершення."
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "Кількість елементів у конструкторі масиву на %L вимагає збільшення дозволеного верхнього обмеження %d. Див. опцію %<-fmax-array-constructor%>"
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Створення тимчасового масиву на %L для аргументу %qs"
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "поганий тип виразу під час обходу (%d)"
@@ -81932,37 +81995,37 @@ msgstr "Значення повернення %qs функції %qs, оголо
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr "Вибачте, !$ACC DECLARE на %L не дозволено в конструкції BLOCK"
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr "Не вдалося обчислити довжину масиву char на %L."
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr "Код для перерозподілу змінної, яку можна виділити, на %L буде доданий"
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "Вибачте, доступ до необмеженого поліморфного обʼєкта з індексацією на %L не підтримується"
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "Вибачте, коіндексний доступ до необмеженого поліморфного компонента на %L не підтримується"
 
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Невідомий вбудований оператор"
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "Невідома функція списку аргументів на %L"
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr "Якщо переналаштування меж вказано на %L, ціль вказівника не повинна бути NULL"
@@ -81973,17 +82036,17 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "Вбудовану функцію %qs (%d) не впізнано"
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "Аргумент %<dim%> вбудованої функції %s на %L не є дійсним індексом розміру"
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "Вибачте, компонент події похідного типу на %L ще не підтримується"
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "Змінна події на %L не повинна бути співіндексованою"
@@ -82124,7 +82187,7 @@ msgstr "Вибачте, компонент блокування похідног
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr "Вибачте, підтримка лише для цілого типу %d реалізована для набору зображень на %L"
 
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr "gfc_trans_select(): Неправильний тип для виразу case."
@@ -82490,6 +82553,11 @@ msgstr "змінна %qD перевизначена як функція"
 msgid "function %qD redeclared as variable"
 msgstr "функція %qD перевизначена як змінна"
 
+#: lto/lto-symtab.cc:865
+#, gcc-internal-format
+msgid "previously declared here"
+msgstr "раніше оголошено тут"
+
 #: lto/lto.cc:174
 #, gcc-internal-format
 msgid "%<lto_obj_file_open()%> failed"
@@ -83729,7 +83797,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr "%<-fobjc-sjlj-exceptions%> ігнорується для %<-fgnu-runtime%>"
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, gcc-internal-format
 msgid "non-objective-c type %qT cannot be caught"
 msgstr "тип %qT, який не є Objective-C, не може бути перехоплений"
@@ -83739,7 +83807,7 @@ msgstr "тип %qT, який не є Objective-C, не може бути пер
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr "%<-fobjc-sjlj-exceptions%> є єдиним підтримуваним системою винятків для %<-fnext-runtime%> з аргументом %<-fobjc-abi-version%>, меншим за 2"
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, gcc-internal-format
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
 msgstr "%<-fobjc-sjlj-exceptions%> ігнорується для %<-fnext-runtime%>, коли %<-fobjc-abi-version%> більше 1"
@@ -84072,6 +84140,10 @@ msgstr ""
 #~ msgid "  enters scope of %q#D which has non-trivial destructor"
 #~ msgstr "  входить у область видимості %q#D, яка має незвичайний деструктор"
 
+#, gcc-internal-format
+#~ msgid "cannot declare %qD in a different module"
+#~ msgstr "не можна оголосити %qD в іншому модулі"
+
 #, gcc-internal-format
 #~ msgid "cannot define %qD in different module"
 #~ msgstr "не можна визначити %qD в іншому модулі"
diff --git a/gcc/po/vi.po b/gcc/po/vi.po
index 927073d1694..fdce5bf08ad 100644
--- a/gcc/po/vi.po
+++ b/gcc/po/vi.po
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 7.1-b20170101\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
 "PO-Revision-Date: 2017-01-08 08:33+0700\n"
 "Last-Translator: Trần Ngọc Quân <vnwildman@gmail.com>\n"
 "Language-Team: Vietnamese <translation-team-vi@lists.sourceforge.net>\n"
@@ -408,7 +408,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr "không dùng đồng thời hai tùy chọn -march=… và -mcpu=…"
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 msgid "shared and mdll are not compatible"
 msgstr "shared và mdll không tương thích với nhau"
 
@@ -19699,18 +19699,18 @@ msgstr "không nhận ra lệnh:"
 msgid "insn does not satisfy its constraints:"
 msgstr "lệnh không thỏa những ràng buộc của nó:"
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "được tạo và sử dụng với cài đặt khác nhau của “%s”"
 
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "được tạo và sử dụng với cài đặt khác nhau của -fpic"
 
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 #, fuzzy
 #| msgid "created and used with different settings of -fpie"
 msgid "created and used with different settings of %<-fpie%>"
@@ -20033,7 +20033,7 @@ msgstr "đồ sửa đổi chiều dài theo định dạng strfmon"
 msgid "<command-line>"
 msgstr "<dòng lệnh>"
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, fuzzy, c-format
 #| msgid "Unsupported operand for code '%c'"
 msgid "unsupported operand for code '%c'"
@@ -20053,9 +20053,9 @@ msgstr "toán hạng không hợp lệ đối với “%%%c”"
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector constant"
@@ -20078,7 +20078,7 @@ msgstr "toán hạng không hợp lệ đối với “%%%c”"
 msgid "incompatible register operand for '%%%c'"
 msgstr "toán hạn dấu chấm động / thanh ghi véctơ không tương thích cho “%%%c”"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, c-format
 msgid "missing operand"
 msgstr "toán hạng còn thiếu"
@@ -20110,93 +20110,93 @@ msgstr "sai đặt chế độ đặt địa chỉ"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "toán hạng không hợp lệ trong phép toán nhị phân"
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "“%%&” bị sử dụng mà không có tham chiếu TLS năng động cục bộ"
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, c-format
 msgid "invalid %%J value"
 msgstr "giá trị %%J sai"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, c-format
 msgid "invalid %%r value"
 msgstr "giá trị %%r sai"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, c-format
 msgid "invalid %%R value"
 msgstr "giá trị %%R sai"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, c-format
 msgid "invalid %%N value"
 msgstr "giá trị %%N sai"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, c-format
 msgid "invalid %%P value"
 msgstr "giá trị %%P sai"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, c-format
 msgid "invalid %%h value"
 msgstr "giá trị %%h sai"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, c-format
 msgid "invalid %%L value"
 msgstr "giá trị %%L sai"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, c-format
 msgid "invalid %%m value"
 msgstr "giá trị %%m sai"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, c-format
 msgid "invalid %%M value"
 msgstr "giá trị %%M sai"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, c-format
 msgid "invalid %%U value"
 msgstr "giá trị %%U sai"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, c-format
 msgid "invalid %%s value"
 msgstr "giá trị %%s sai"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, c-format
 msgid "invalid %%C value"
 msgstr "giá trị %%C sai"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, c-format
 msgid "invalid %%E value"
 msgstr "giá trị %%E sai"
 
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "không rõ bỏ ghi rõ bố trí lại"
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, c-format
 msgid "invalid %%xn code"
 msgstr "mã %%xn sai"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, c-format
 msgid "invalid operand address"
 msgstr "địa chỉ toán hạng không hợp lệ"
@@ -20293,35 +20293,35 @@ msgstr "UNSPEC không hợp lệ như là toán hạng: %d"
 msgid "unrecognized supposed constant"
 msgstr "không nhận ra điều nên là hằng số"
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, c-format
 msgid "invalid shift operand"
 msgstr "sai đặt toán hạng dời"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "lệnh Thumb căn cứ vào"
 
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "gặp lệnh căn cứ vào trong dãy có điều kiện"
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Không hỗ trợ toán hạng cho mã “%c”"
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -20329,125 +20329,125 @@ msgstr "Không hỗ trợ toán hạng cho mã “%c”"
 msgid "invalid operand for code '%c'"
 msgstr "sai đặt toán hạng cho mã “%c”"
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, c-format
 msgid "instruction never executed"
 msgstr "lệnh chưa bao giờ thực hiện"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "định dạng mã Maverick đã cũ “%c”"
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "sai chuyển đổi từ %<__fpreg%>"
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "sai chuyển đổi sang %<__fpreg%>"
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "toán hạng địa chỉ yêu cầu ràng buộc cho thanh ghi X, Y, hay Z"
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "các toán hạng cho %T/%t phải là reg + const_int:"
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 msgid "bad address, not an I/O address:"
 msgstr "Địa chỉ sai, không phải địa chỉ V/R:"
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 msgid "bad address, not a constant:"
 msgstr "địa chỉ sai, không phải là một hằng số:"
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 msgid "bad address, not (reg+disp):"
 msgstr "địa chỉ sai, không phải (reg+disp):"
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "địa chỉ sai, không phải post_inc hoặc pre_dec:"
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr "lỗi biên dịch nội bộ. Địa chỉ sai:"
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "Không hỗ trợ mã “%c” cho dấu chấm cố định:"
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 msgid "internal compiler error.  Unknown mode:"
 msgstr "lỗi biên dịch nội bộ. Không hiểu chế độ:"
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 msgid "invalid insn:"
 msgstr "lệnh sai:"
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 msgid "incorrect insn:"
 msgstr "lệnh không đúng:"
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 msgid "unknown move insn:"
 msgstr "không rõ lệnh di chuyển:"
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 msgid "bad shift insn:"
 msgstr "lệnh dời sai:"
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "lỗi biên dịch nội bộ. Dịch không đúng:"
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 msgid "unsupported fixed-point conversion"
 msgstr "không hỗ trợ chuyển đổi dấu chấm cố định"
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 #, fuzzy
 #| msgid "Loop variable"
 msgid "variable"
 msgstr "Biến vòng lặp"
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "function parameter"
 msgstr "định nghĩa lại của đối số %q+D"
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 #, fuzzy
 #| msgid "struct defined here"
 msgid "structure field"
 msgstr "struct được định nghĩa ở đây"
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 #, fuzzy
 #| msgid "creating array of functions"
 msgid "return type of function"
 msgstr "tạo mảng hàm"
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 #, fuzzy
 #| msgid "null pointer"
 msgid "pointer"
@@ -20487,7 +20487,7 @@ msgstr "gặp toán hạng bất thường"
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -20817,53 +20817,53 @@ msgstr "toán hạng không phải là một mã điều kiện, mã toán hạn
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "mã toán hạng sai “%c”"
 
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "sai đặt ràng buộc cho toán hạng"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, fuzzy, c-format
 #| msgid "invalid zero extract"
 msgid "invalid vector immediate"
 msgstr "trích số không không hợp lệ"
 
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 msgid "unknown insn mode"
 msgstr "không rõ chế độ lệnh"
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr "sai chuyển đổi từ %<__fpreg%>"
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr "sai chuyển đổi từ %<__fpreg%>"
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr "sai chuyển đổi sang %<__fpreg%>"
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
 msgstr ""
 
@@ -20894,7 +20894,7 @@ msgstr "thao tác sai %<__fpreg%>"
 msgid "invalid %%P operand"
 msgstr "gặp toán hạng %%P sai"
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, c-format
 msgid "invalid %%p value"
 msgstr "gặp giá trị %%p sai"
@@ -20921,29 +20921,29 @@ msgstr "không cho phép sử dụng địa chỉ tuyệt đối tương đối
 msgid "invalid addressing mode"
 msgstr "sai đặt chế độ đặt địa chỉ"
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, c-format
 msgid "'%%%c' is not a valid operand prefix"
 msgstr "“%%%c” không phải là một tiền tố toán hạng đúng"
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "sai sử dụng “%%%c”"
@@ -20975,7 +20975,7 @@ msgid "post-increment address is not a register"
 msgstr "địa chỉ hậu gia không phải là một thanh ghi"
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 msgid "bad address"
 msgstr "địa chỉ sai"
 
@@ -21143,7 +21143,7 @@ msgstr "Hóa hợp không được hỗ trợ: %s"
 msgid "unsupported memory expression:"
 msgstr "không hỗ trợ chuyển đổi dấu chấm cố định"
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, fuzzy, c-format
 #| msgid "invalid %%r operand"
 msgid "invalid vector operand"
@@ -21206,258 +21206,258 @@ msgstr "-mquad-memory-atomic cần chế độ 64-bit"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "-mquad-memory không sẵn sàng trên chế độ little endian"
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 msgid "bad move"
 msgstr "sai di chuyển"
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 msgid "Bad 128-bit move"
 msgstr "Di chuyển 128-bit sai"
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%A value"
 msgstr "giá trị %%J sai"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%D value"
 msgstr "giá trị %%D sai"
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, c-format
 msgid "invalid %%e value"
 msgstr "giá trị %%e sai"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, c-format
 msgid "invalid %%f value"
 msgstr "giá trị %%f sai"
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, c-format
 msgid "invalid %%F value"
 msgstr "giá trị %%F sai"
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, c-format
 msgid "invalid %%G value"
 msgstr "giá trị %%G sai"
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, c-format
 msgid "invalid %%j code"
 msgstr "mã %%j sai"
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, c-format
 msgid "invalid %%J code"
 msgstr "mã %%J sai"
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, c-format
 msgid "invalid %%k value"
 msgstr "giá trị %%k sai"
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, c-format
 msgid "invalid %%K value"
 msgstr "giá trị %%K sai"
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, c-format
 msgid "invalid %%O value"
 msgstr "giá trị %%O sai"
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, c-format
 msgid "invalid %%q value"
 msgstr "giá trị %%q sai"
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%t value"
 msgstr "giá trị %%J sai"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, c-format
 msgid "invalid %%T value"
 msgstr "giá trị %%T sai"
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, c-format
 msgid "invalid %%u value"
 msgstr "giá trị %%u sai"
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, c-format
 msgid "invalid %%v value"
 msgstr "giá trị %%v sai"
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%V value"
 msgstr "giá trị %%J sai"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, c-format
 msgid "invalid %%x value"
 msgstr "giá trị %%x sai"
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%z value"
 msgstr "giá trị %%J sai"
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "giá trị %%y sai, hãy thử sử dụng ràng buộc “Z”"
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 #, fuzzy
 #| msgid "Enable using IEEE 128-bit floating point instructions."
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "Bật sử dụng câu lệnh dấu số thực chấm động 128-bit IEEE."
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "đối số AltiVec bị gửi cho hàm không nguyên mẫu"
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 msgid "Could not generate addis value for fusion"
 msgstr "Không thể tạo addis cho sát nhập"
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Không thể tạo ra việc tải/lưu offset cho hợp nhất"
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 msgid "Bad GPR fusion"
 msgstr "Hợp nhất GPR sai"
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "sai chuyển đổi từ %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "sai chuyển đổi sang %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "sai chuyển đổi từ %<__fpreg%>"
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "sai chuyển đổi sang %<__fpreg%>"
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, c-format
 msgid "cannot decompose address"
 msgstr "không thể giải mã địa chỉ"
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "hằng không hợp lệ cho bổ nghĩa kết xuất “%c”"
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "hằng không hợp lệ - hãy thử dùng bổ nghĩa kết xuất"
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "véc-tơ hằng không hợp lệ cho bổ nghĩa kết xuất “%c”"
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "biểu thức không hợp lệ - hãy thử dùng bổ nghĩa kết xuất"
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "biểu thức không hợp lệ cho bộ sửa đầu ra “%c”"
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 #, fuzzy
 #| msgid "Vector argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "Đối số véc-tơ bị gửi cho hàm không nguyên mẫu"
 
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -21653,12 +21653,12 @@ msgstr "({nặc danh})"
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "cần %<;%>"
@@ -21671,7 +21671,7 @@ msgstr "cần %<;%>"
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -21680,7 +21680,7 @@ msgstr "cần %<;%>"
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "cần %<)%>"
@@ -21688,7 +21688,7 @@ msgstr "cần %<)%>"
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "cần %<]%>"
@@ -21699,29 +21699,29 @@ msgstr "cần %<;%>, %<,%> hoặc %<)%>"
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "cần %<(%>"
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "cần %<[%>"
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "cần %<{%>"
@@ -21731,17 +21731,17 @@ msgstr "cần %<{%>"
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "cần %<:%>"
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "cần %<while%>"
@@ -21750,8 +21750,8 @@ msgstr "cần %<while%>"
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "cần %<,%>"
@@ -21761,17 +21761,17 @@ msgid "expected %<.%>"
 msgstr "cần %<.%>"
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "cần %<@end%>"
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "cần %<>%>"
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "cần %<,%> hoặc %<)%>"
@@ -21779,33 +21779,33 @@ msgstr "cần %<,%> hoặc %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "cần %<=%>"
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "cần %<}%>"
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<delete%>"
 msgid "expected %<else%>"
 msgstr "cần %<delete%>"
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "cần %<#pragma omp section%> hoặc %<}%>"
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr ""
 
@@ -21813,7 +21813,7 @@ msgstr ""
 msgid "(anonymous)"
 msgstr "(nặc danh)"
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "cần %<<%>"
@@ -21830,22 +21830,22 @@ msgstr "cần kênh"
 msgid "candidate:"
 msgstr "ứng cử 1:"
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 #, fuzzy
 #| msgid "Enable user-defined instructions."
 msgid "  after user-defined conversion:"
 msgstr "Bật câu lệnh được người dùng xác định."
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "ứng cử là:"
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr "ứng cử 1:"
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr "ứng cử 2:"
 
@@ -22103,7 +22103,7 @@ msgstr "%r%s:%d:%d:%R   trong khai triển constexpr của %qs"
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%R   trong khai triển constexpr của %qs"
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 msgid "candidates are:"
 msgstr "các ứng cử là:"
 
@@ -22147,48 +22147,48 @@ msgstr "việc chuyển đổi cũng bỏ trình trạng bất biến"
 msgid "source type is not polymorphic"
 msgstr "nguồn không có loại nhiều dạng"
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "đối số có loại sai đối với dấu trừ nguyên phân"
 
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "đối số có loại sai đối với dấu cộng nguyên phân"
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "đối số có loại sai đối với phần bù bit"
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "đối số có loại sai đối với bộ tuyệt đối"
 
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "đối số có loại sai đối với phần chia"
 
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 msgid "in argument to unary !"
 msgstr "trong đối số tới bộ nguyên phân !"
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 msgid "no pre-increment operator for type"
 msgstr "không có toán tử tiền gia cho loại"
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 msgid "no post-increment operator for type"
 msgstr "không có toán tử hậu gia cho loại"
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 msgid "no pre-decrement operator for type"
 msgstr "không có toán tử giảm gia cho loại"
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 msgid "no post-decrement operator for type"
 msgstr "không có toán tử hậu giảm cho loại"
 
@@ -22270,7 +22270,7 @@ msgstr "Đặc tính cũ:"
 msgid "Deleted feature:"
 msgstr "Đặc tính đã bị xóa bỏ:"
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 msgid "array assignment"
 msgstr "sự gán mảng"
 
@@ -22469,11 +22469,11 @@ msgstr "IF (nếu) loại khối"
 msgid "implied END DO"
 msgstr "ngụ ý END DO (kết thúc làm)"
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 msgid "assignment"
 msgstr "sự gán"
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 msgid "pointer assignment"
 msgstr "sự gán hàm trỏ"
 
@@ -22635,47 +22635,47 @@ msgstr "Toán hạng của toán tử người dùng %%<%s%%> tại %%L là %s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Các toán hạng của toán tử người dùng %%<%s%%> tại %%L là %s/%s"
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 msgid "Loop variable"
 msgstr "Biến vòng lặp"
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 msgid "iterator variable"
 msgstr "biến iterator"
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 msgid "Start expression in DO loop"
 msgstr "Biểu thức bắt đầu trong vòng lặp DO (làm)"
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 msgid "End expression in DO loop"
 msgstr "Biểu thức kết thúc trong vòng lặp DO (làm)"
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 msgid "Step expression in DO loop"
 msgstr "Biểu thức bước trong vòng lặp DO (làm)"
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 msgid "DEALLOCATE object"
 msgstr "đối tượng DEALLOCATE"
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 msgid "ALLOCATE object"
 msgstr "đối tượng ALLOCATE"
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 msgid "STAT variable"
 msgstr "biến STAT"
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 msgid "ERRMSG variable"
 msgstr "Biến ERRMSG"
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 msgid "item in READ"
 msgstr "mục tin trong READ"
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 msgid "ACQUIRED_LOCK variable"
 msgstr "biến ACQUIRED_LOCK"
 
@@ -22684,11 +22684,11 @@ msgstr "biến ACQUIRED_LOCK"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "Bộ dựng mảng chứa các chiều dài KÝ_TỰ khác nhau (%ld/%ld)"
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr ""
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
@@ -22703,12 +22703,12 @@ msgstr "Chiều dài chuỗi thật không tương ứng với điều khai báo
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Chiều dài chuỗi thật vẫn nhỏ hơn điều khai báo cho đối số giả “%s” (%ld/%ld)"
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 msgid "Assignment of scalar to unallocated array"
 msgstr "Gán vô hướng cho mảng chưa cấp phát"
 
@@ -22717,83 +22717,83 @@ msgstr "Gán vô hướng cho mảng chưa cấp phát"
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, fuzzy, c-format
 #| msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "đối số “a%d” và “a%d” cho “%s” thực chất"
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, fuzzy, c-format
 #| msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "đối số “a%d” và “a%d” cho “%s” thực chất"
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Tham số NCOPIES của REPEAT (lặp lại) hạn chế là âm (giá trị của nó là %ld)"
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "Điều thực chất REPEAT (lặp lại) có đối số NCOPIES (số các bản sao) quá lớn"
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, c-format
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, c-format
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
@@ -22815,15 +22815,15 @@ msgstr "Nhãn đã gán không phải là một nhãn đích"
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Số ảnh không hợp lệ %d trong SYNC IMAGES"
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 msgid "Loop variable has been modified"
 msgstr "Biến vòng lặp bị sửa đổi"
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 msgid "DO step value is zero"
 msgstr "Giá trị bước DO (làm) là số không"
 
@@ -22902,7 +22902,7 @@ msgid "expected boolean type"
 msgstr "cần kiểu boolean"
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "Mong đợi một số nguyên"
@@ -22967,7 +22967,7 @@ msgstr "không đủ đối số"
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "quá nhiều đối số"
@@ -23629,7 +23629,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "-mrelax chỉ hỗ trợ cho RTP PIC"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr ""
@@ -24093,8 +24093,8 @@ msgstr "thuộc tính %s của %qs xung đột với thuộc tính %s tại %L"
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "khai báo trước ở đây"
@@ -24111,7 +24111,7 @@ msgstr ""
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr ""
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, gcc-internal-format
 msgid "wrong number of arguments specified for %qE attribute"
 msgstr ""
@@ -24122,7 +24122,7 @@ msgstr ""
 msgid "expected %i or more, found %i"
 msgstr "cần %<(%> hoặc xuống dòng"
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %<,%>"
 msgid "expected %i, found %i"
@@ -24190,12 +24190,12 @@ msgstr ""
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -24204,7 +24204,7 @@ msgstr ""
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -24226,8 +24226,8 @@ msgstr "thuộc tính %qE bị lờ đi"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "khai báo trước đây của %qD"
@@ -24340,7 +24340,7 @@ msgstr "không thể đọc hồ sơ hàm từ %s."
 msgid "offset %qwi outside bounds of constant string"
 msgstr ""
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qE declared here"
@@ -24453,7 +24453,7 @@ msgstr "thiếu đối số đối cho %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
@@ -24477,42 +24477,42 @@ msgstr "%<__builtin_longjmp%> đối số thứ hai phải là 1"
 msgid "target format does not support infinity"
 msgstr "định dạng đích không hỗ trợ vô cực"
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr ""
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "sai số lượng đối số cho hàm %<va_start%>"
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> được gọi mà không có đối số"
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "sai số lượng đối số cho hàm %<__builtin_next_arg%>"
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "đối số thứ hai của %<va_start%> không là đối số có tên cuối"
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, fuzzy, gcc-internal-format
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr "đối số %d của %qE phải là một địa chỉ"
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "last argument of %qD is not integer constant between 0 and 3"
@@ -25584,12 +25584,12 @@ msgstr ""
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F được dùng mà chưa từng được định nghĩa"
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -26169,7 +26169,7 @@ msgstr ""
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr ""
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, fuzzy, gcc-internal-format
 #| msgid "open %s failed: %s"
 msgid "%qs failed"
@@ -26200,17 +26200,17 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, fuzzy, gcc-internal-format
 msgid "call to %qs declared with attribute error: %s"
 msgstr "hàm %qD được khai báo lại là không chung dòng (inline) thuộc "
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, fuzzy, gcc-internal-format
 msgid "call to %qs declared with attribute warning: %s"
 msgstr "hàm %qD được khai báo lại là không chung dòng (inline) thuộc "
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
 msgstr ""
@@ -26247,7 +26247,7 @@ msgstr ""
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -26425,7 +26425,7 @@ msgstr "gặp lỗi khi lấy thời gian tiến trình: %m"
 msgid "%s signal terminated program %s"
 msgstr "Sử dụng tên thanh ghi xen kẽ."
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option %qs"
 msgid "unrecognized command-line option %qs"
@@ -26706,7 +26706,7 @@ msgstr "đặc tả đa thư viện %qs không hợp lệ"
 msgid "multilib exclusions %qs is invalid"
 msgstr "sự loại từ đa thư viện %qs không hợp lệ"
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "sự lựa chọn đa thư viện %qs %qs không hợp lệ"
@@ -27029,23 +27029,23 @@ msgstr ""
 msgid "%qD specified bound %E equals source length"
 msgstr ""
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, gcc-internal-format
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr ""
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr ""
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ISO C++ does not support variable-length array types"
 msgid "%s not supported for variable length aggregates"
 msgstr "ISO C++ không hỗ trợ các kiểu mảng có độ dài không cố định"
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SPE not supported in this target"
 msgid "%s not supported on this target"
@@ -27087,16 +27087,16 @@ msgid "function returns address of local variable"
 msgstr "hàm trả về địa chỉ của biến cục bộ"
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, gcc-internal-format
@@ -27108,356 +27108,356 @@ msgstr "được khai báo ở đây"
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, fuzzy, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr "Đối số âm N tại %L"
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, fuzzy, gcc-internal-format
 #| msgid "  declared here"
 msgid "referenced argument declared here"
 msgstr "  đã được khai báo ở đây"
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, fuzzy, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "Đối số âm N tại %L"
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgid_plural "%qE output %wu bytes into a destination of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 msgid "%qE argument %Z overlaps destination object %qE"
 msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 msgid "%qE argument %Z may overlap destination object %qE"
 msgid_plural "%qE arguments %Z may overlap destination object %qE"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, gcc-internal-format
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, fuzzy, gcc-internal-format
 msgid "null destination pointer"
 msgstr "con trỏ rỗng"
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, fuzzy, gcc-internal-format
 msgid "null format string"
 msgstr "%s trong chuỗi định dạng tại %L"
@@ -28210,12 +28210,12 @@ msgstr "chế độ con trỏ %qs không hợp lệ"
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD được khai báo ở đây"
@@ -28989,7 +28989,7 @@ msgstr "thẻ bài %u có x-location == %u"
 msgid "token %u has %<y-location == %u%>"
 msgstr "thẻ bài %u có y-location == %u"
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "dùng %<auto%> không hợp lệ"
@@ -29332,17 +29332,17 @@ msgstr "%+D đã khai báo weakref sau khi được dùng"
 msgid "mismatching definition"
 msgstr "thiếu định nghĩa"
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr ""
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr ""
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, gcc-internal-format
 msgid "IPA modref summary is missing in input file"
 msgstr ""
@@ -30450,76 +30450,76 @@ msgstr "lỗi ghi vào %s: %m"
 msgid "error closing optimization records %qs"
 msgstr "(gần chỗ khởi tạo cho %qs)"
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "%s không được hỗ trợ bởi cấu hình này"
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "thiếu đối số đối cho %qs"
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr ""
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer"
 msgstr ""
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-functions=%d is not between 0 and %d"
 msgid "argument to %qs is not between %d and %d"
 msgstr "-malign-functions=%d không nằm giữa 0 và %d"
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %qD"
 msgid "invalid argument in option %qs"
 msgstr "đối số không hợp lệ cho %qD"
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr ""
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, gcc-internal-format
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr ""
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, gcc-internal-format
 msgid "unrecognized argument in option %qs"
 msgstr "không nhận ra đối số tới tùy chọn %qs"
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "switch %qs không còn tiếp tục được hỗ trợ nữa"
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs is too large (max. %d)"
 msgid "argument to %qs is bigger than %d"
 msgstr "đối số cho %qs quá lớn (tối đa là %d)"
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, fuzzy, gcc-internal-format
 #| msgid "malformed COLLECT_GCC_OPTIONS"
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
@@ -30599,8 +30599,8 @@ msgstr ""
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, gcc-internal-format
 msgid "%qs is incompatible with %qs"
 msgstr "%qs không tương thích với %qs"
@@ -31369,7 +31369,7 @@ msgstr ""
 msgid "register of %qD used for multiple global register variables"
 msgstr ""
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "xung đột với %qD"
@@ -31830,45 +31830,45 @@ msgstr ""
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int%d%> is not supported on this target"
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, gcc-internal-format
 msgid "nested functions not supported on this target"
 msgstr ""
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, gcc-internal-format
 msgid "nested function trampolines not supported on this target"
 msgstr ""
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr ""
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr ""
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int%d%> is not supported on this target"
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int%d%> is not supported on this target"
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "%<#pragma GCC target%> is not supported for this machine"
@@ -33045,82 +33045,82 @@ msgstr "BB %i có cạnh sai"
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr ""
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr ""
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr ""
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr ""
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr ""
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr ""
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr ""
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr ""
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr ""
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr ""
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr ""
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr ""
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, gcc-internal-format
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr ""
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr "được gọi từ đây"
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, gcc-internal-format
 msgid "called from this function"
 msgstr "được gọi từ hàm này"
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, gcc-internal-format
 msgid "inlining failed in call to %q+F: %s"
 msgstr ""
@@ -33177,28 +33177,28 @@ msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr "dùng %<auto%> không hợp lệ"
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, fuzzy, gcc-internal-format
 #| msgid "In static member function %qs"
 msgid "in a call to non-static member function %qD"
 msgstr "Trong hàm bộ phận tĩnh %qs"
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, fuzzy, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "không thể tắt hàm dựng sẵn %qs"
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, fuzzy, gcc-internal-format
 msgid "in a call to function %qD declared %qs"
 msgstr "hàm chung dòng %q+D được khai báo yếu"
@@ -33403,7 +33403,7 @@ msgstr "%qE chưa được khởi tạo"
 msgid "%qs may be used uninitialized"
 msgstr "mảng được dùng như là bộ khởi tạo"
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD đã được khai báo ở đây"
@@ -33638,7 +33638,7 @@ msgstr ""
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -33653,131 +33653,131 @@ msgstr ""
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr ""
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "kiểu trả về hàm không thể là hàm"
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "kiểm tra cây: %s, có %s trong %s, tại %s:%d"
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "tree check: cần không gì của %s, có %s trong %s, tại %s:%d"
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "tree check: cần lớp %qs, có %qs (%s) trong %s, tại %s:%d"
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr "tree check: cần omp_clause %s, có %s trong %s, tại %s:%d"
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr "tree check: cần không gì của %s, có %s trong %s, tại %s:%d"
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr "tree check: cần không gì của %s, có %s trong %s, tại %s:%d"
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "tree check: cần omp_clause %s, có %s trong %s, tại %s:%d"
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD đã lạc hậu: %s"
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD đã lạc hậu"
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE đã lạc hậu: %s"
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE đã lạc hậu"
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "kiểu đã lạc hậu: %s"
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "kiểu đã lạc hậu"
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is unavailable: %s"
 msgstr "%qD không phải là một biến"
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is unavailable"
 msgstr "%qD không phải là một biến"
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qE is unavailable: %s"
 msgstr "%qD không phải là một biến"
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qE is unavailable"
 msgstr "%qD không phải là một biến"
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "open %s failed: %s"
 msgid "type is unavailable: %s"
 msgstr "mở %s gặp lỗi: %s"
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "type is unavailable"
@@ -33803,266 +33803,266 @@ msgstr "%qD không phải là một biến"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "type is not compatible with its variant"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qT is not a template type"
 msgid "type %s is not an opaque type"
 msgstr "%qT không phải là một kiểu mẫu"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "type %s is not with opaque mode"
 msgstr "kiểu %qT không là cơ sở trực tiếp của %qT"
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr ""
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr ""
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable %qs not defined"
 msgid "main variant is not defined"
 msgstr "chưa định nghĩa biến môi trường%qs"
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr ""
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr ""
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -34287,7 +34287,7 @@ msgstr ""
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr ""
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr ""
@@ -34508,7 +34508,7 @@ msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr ""
@@ -34700,7 +34700,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr "Thuộc tính %qE trên biến không hay thay đổi"
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for local variables"
 msgstr ""
@@ -35041,7 +35041,7 @@ msgstr "%qD không tương thích với %qD"
 msgid "%qE argument is not a function"
 msgstr ""
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
@@ -35572,7 +35572,7 @@ msgstr "ISO C++ không cho phép %<alignof%> áp dụng cho kiểu hàm"
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr ""
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, gcc-internal-format
 msgid "invalid application of %qs to a void type"
 msgstr ""
@@ -35703,17 +35703,17 @@ msgstr ""
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "quá ít đối số cho hàm %qE"
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, gcc-internal-format
@@ -35838,172 +35838,172 @@ msgstr ""
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "kích cỡ mảng là quá lớn"
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, gcc-internal-format
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr ""
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be channel"
 msgid "both arguments must be compatible"
 msgstr "đối số phải là kênh"
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr ""
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr ""
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr "đối số %d của %qE phải là một địa chỉ"
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr ""
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr ""
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr ""
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "đối số %d của %qE phải là một địa chỉ"
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "đối số %d của %qE phải là bội số của %d"
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr "đối số %d của %qE phải là một địa chỉ"
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, gcc-internal-format
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr ""
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr "đối số %d của %qE phải là một địa chỉ"
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, gcc-internal-format
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr ""
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "giá trị chỉ mục nằm ngoài phạm vi cho phép"
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr ""
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array %qE is not a constant expression"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array is not a constant expression"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "kích cỡ mảng %qE bị âm"
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "kích cỡ mảng bị âm"
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "kích cỡ mảng %qE bị âm"
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -36643,7 +36643,7 @@ msgstr ""
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr ""
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int%d%> is not supported on this target"
 msgid "%<_BitInt(%d)%> is not supported on this target"
@@ -36726,7 +36726,7 @@ msgstr ""
 msgid "traditional C rejects string constant concatenation"
 msgstr ""
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -36782,7 +36782,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -36797,17 +36797,17 @@ msgstr "biến iterator"
 msgid "%qE is not initialized"
 msgstr "%qE chưa được khởi tạo"
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "thiếu biểu thức gia số"
@@ -36817,7 +36817,7 @@ msgstr "thiếu biểu thức gia số"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "biểu thức gia không hợp lệ"
@@ -36903,7 +36903,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -36914,7 +36914,7 @@ msgstr ""
 msgid "%qD is not a function argument"
 msgstr "%qD không phải là đối số hàm"
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
@@ -37538,7 +37538,7 @@ msgid "wrong type argument to %s"
 msgstr "sai kiểu đối số cho %s"
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -38488,35 +38488,35 @@ msgstr "so sánh giữa %qT và %qT"
 
 #: c-family/c-warn.cc:3832
 #, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3836
+#: c-family/c-warn.cc:3839
 #, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr ""
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr ""
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr ""
@@ -38750,120 +38750,120 @@ msgstr "-mregparm=%d không nằm giữa 0 và %d"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, gcc-internal-format
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, gcc-internal-format
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, gcc-internal-format
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, fuzzy, gcc-internal-format
 #| msgid "-mcpu=%s conflicts with -march=%s"
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr "-mcpu=%s xung đột với -march=%s"
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, fuzzy, gcc-internal-format
 #| msgid "-mcpu=%s conflicts with -march=%s"
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr "-mcpu=%s xung đột với -march=%s"
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, gcc-internal-format
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, fuzzy, gcc-internal-format
 #| msgid "%<%s%> is unknown"
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "%<%s%> là không hiểu"
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr ""
@@ -39300,13 +39300,13 @@ msgstr "cần %qT nhưng đối số là kiểu %qT"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "cần %qT nhưng đối số là kiểu %qT"
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC optimize%> is not a string or number"
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC optimize%> không phải là một chuỗi hay số"
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr ""
@@ -39897,7 +39897,7 @@ msgstr ""
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
@@ -39977,12 +39977,12 @@ msgid "unknown tuning option (%s)"
 msgstr "không hiểu tùy chọn chỉnh (%s)"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
@@ -39993,7 +39993,7 @@ msgid "specify a system register with a small string length"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
@@ -40188,9 +40188,9 @@ msgstr ""
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "thuộc tính %<target%> không là một chuỗi"
@@ -40247,19 +40247,19 @@ msgid "virtual function multiversioning not supported"
 msgstr "dwarf phiên bản %d không được hỗ trợ"
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, fuzzy, gcc-internal-format
 #| msgid "the call requires ifunc, which is not supported by this target"
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "__builtin_thread_pointer không được hỗ trợ trên đích này"
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
@@ -40272,8 +40272,8 @@ msgstr ""
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported simdlen %d"
 msgid "unsupported simdlen %wd"
@@ -40285,7 +40285,7 @@ msgstr "simdlen không được hỗ trợ %d"
 msgid "GCC does not currently support return type %qT for simd"
 msgstr "ISO C không hỗ trợ kiểu saturating"
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %qD"
 msgid "unsupported return type %qT for simd"
@@ -40296,7 +40296,7 @@ msgstr "đối số không được hỗ trợ cho %D"
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %qD"
 msgid "unsupported argument type %qT for simd"
@@ -40394,8 +40394,8 @@ msgstr ""
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "giá trị sai %qs cho -mmemory-latency"
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr "fcode dựng sẵn sai"
@@ -40524,18 +40524,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "đối số của thuộc tính %qE không hợp lệ"
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -40653,7 +40653,7 @@ msgid "argument of %qE attribute is missing"
 msgstr "đối số của thuộc tính %qE không hợp lệ"
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr ""
@@ -40676,24 +40676,24 @@ msgstr "Thuộc tính %qE chỉ được áp dụng cho SH2A"
 msgid "argument of %qE attribute ignored"
 msgstr "thuộc tính %qE bị lờ đi"
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr ""
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, fuzzy, gcc-internal-format
 #| msgid "unknown linker output %qs"
 msgid "unknown %<asm%> flag output %qs"
 msgstr "không hiểu xuất bộ liên kết %qs"
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of asm flag output"
 msgid "invalid type for %<asm%> flag output"
@@ -40950,7 +40950,7 @@ msgstr "CPU đích không hỗ trợ chỉ lệnh THUMB"
 msgid "target CPU does not support unaligned accesses"
 msgstr "CPU đích không hỗ trợ truy cập chưa cân chỉnh"
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -41005,7 +41005,7 @@ msgstr ""
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC không tương thích với -msingle-pic-base"
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in x32 mode"
 msgid "FDPIC mode is not supported in Thumb-1 mode"
@@ -41120,7 +41120,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -41160,43 +41160,43 @@ msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd nằm ngoài vùng %wd - %wd"
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr ""
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-check=specific for Thumb-1"
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr "-fstack-check=specific cho Thumb-1"
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, fuzzy, gcc-internal-format
 #| msgid "invalid fpu for attribute(target(\"%s\"))"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -41205,23 +41205,23 @@ msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr ""
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, fuzzy, gcc-internal-format
 #| msgid "unknown property attribute"
 msgid "unknown target attribute or pragma %qs"
 msgstr "không hiểu thuộc tính tính chất"
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
@@ -41275,164 +41275,164 @@ msgstr ""
 msgid "unknown core architecture %qs specified with %qs"
 msgstr ""
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic is not supported"
 msgid "%<-fpic%> is not supported"
 msgstr "-fpic không được hỗ trợ"
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIC is not supported"
 msgid "%<-fPIC%> is not supported"
 msgstr "-fPIC không được hỗ trợ"
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, fuzzy, gcc-internal-format
 #| msgid "-fpie is not supported"
 msgid "%<-fpie%> is not supported"
 msgstr "-fpie không được hỗ trợ"
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIE is not supported"
 msgid "%<-fPIE%> is not supported"
 msgstr "-fPIE không được hỗ trợ"
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, fuzzy, gcc-internal-format
 #| msgid "-fwpa and -fltrans are mutually exclusive"
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-fwpa và -fltrans loại trừ lẫn nhau"
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs hàm không có đối số"
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "%qs hàm không trả về giá trị nào"
 
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, gcc-internal-format
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr ""
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, gcc-internal-format
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr ""
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr ""
 
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute address out of range"
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr "Thuộc tính %qE nằm ngoài vùng địa chỉ"
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "Thuộc tính %qE trên biến không hay thay đổi"
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr ""
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr ""
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, gcc-internal-format
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr ""
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, gcc-internal-format
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr ""
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr ""
@@ -41441,43 +41441,43 @@ msgstr ""
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, fuzzy, gcc-internal-format
 #| msgid "variable %D of type %<cb%> must be uninitialized"
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr "biến %D của kiểu %<cb%> phải không được khởi tạo"
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, fuzzy, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%qs không tương thích với %s %s"
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr ""
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr ""
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr ""
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr ""
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -41630,7 +41630,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "__builtin_thread_pointer không được hỗ trợ trên đích này"
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, gcc-internal-format
@@ -42298,8 +42298,8 @@ msgstr "đối số cuối phải là giá trị trực tiếp 8-bít"
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "mô hình mã %s không hỗ trợ chế độ PIC"
@@ -42368,270 +42368,270 @@ msgstr "không chỉ định tên lớp với %qs"
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%stune=x86-64%s đã lỗi thời, dùng %stune=k8%s hay %stune=generic%s để thay thế là thích hợp"
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%stune=x86-64%s đã lỗi thời, dùng %stune=k8%s hay %stune=generic%s để thay thế là thích hợp"
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte không hỗ trợ mã 32-bit"
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, fuzzy, gcc-internal-format
 #| msgid "-msx is not supported in coff"
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "-msx không hỗ trợ trong coff"
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte không hỗ trợ mã 32-bit"
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte không hỗ trợ mã 32-bit"
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, fuzzy, gcc-internal-format
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte không hỗ trợ mã 32-bit"
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, fuzzy, gcc-internal-format
 #| msgid "%<-Wabi=1%> is not supported, using =2"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-Wabi=1%> không được hỗ trợ, dùng =2"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, fuzzy, gcc-internal-format
 #| msgid "cannot specify -static with -fsanitize=address"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "không thể chỉ định -static với -fsanitize=địa_chỉ"
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, fuzzy, gcc-internal-format
 #| msgid "-fsanitize=address is incompatible with -fsanitize=kernel-address"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "-fsanitize=address xung khắc với -fsanitize=kernel-address"
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "-fsanitize=address xung khắc với -fsanitize=kernel-address"
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "mô hình mã %qs không được hỗ trợ trong chế độ x32"
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, fuzzy, gcc-internal-format
 #| msgid "-masm=intel not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-masm=intel không được hỗ trợ trong cấu hình này"
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "chế độ %i-bit chưa được biên dịch bên trong"
 
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "CPU bạn chọn không hỗ trợ chỉ lệnh x86-64"
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<-march=%> switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "sai giá trị (%qs) cho tùy chọn %<-march=%>"
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<-march=%> switch"
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "sai giá trị (%qs) cho tùy chọn %<-march=%>"
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "sai giá trị (%s) cho chuyển -mtune"
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "sai giá trị (%s) cho chuyển -mtune"
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored in 64-bit mode"
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "-mregparm bị bỏ qua trên chế độ 64-bit"
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm is ignored for Intel MCU psABI"
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "-mregparm bị bỏ qua trên chế độ 64-bit"
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d không nằm giữa 0 và %d"
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> bị bỏ qua trong chế độ 64bit"
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mrtd%> is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> bị bỏ qua trong chế độ 64bit"
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr ""
@@ -42639,304 +42639,304 @@ msgstr ""
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr ""
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary is not supported for this target"
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "-mpreferred-stack-boundary không được hỗ trợ trên đích này"
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d không nằm giữa %d và %d"
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, fuzzy, gcc-internal-format
 #| msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d không ở giữa %d và 12"
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not implemented for -fPIC"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "-mnop-mcount không được thực hiện cho -fPIC"
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> được dùng mà không bật SSE"
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, fuzzy, gcc-internal-format
 #| msgid "%<-msseregparm%> used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<-msseregparm%> được dùng mà không bật SSE"
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "Chỉ lệnh SSE đặt là tắt, sử dụng số học 387"
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, fuzzy, gcc-internal-format
 #| msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "-mfentry không hỗ trợ cho 32-bit trong tổ hợp cùng với -fpic"
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry không tương thích với SEH"
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, fuzzy, gcc-internal-format
 #| msgid "unknown option for -mrecip=%s"
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "không hiểu tùy chọn cho -mrecip=%s"
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr ""
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, fuzzy, gcc-internal-format
 #| msgid "cdecl and thiscall attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "các thuộc tính cdecl và thiscall không tương thích với nhau"
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and thiscall attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "các thuộc tính stdcall và thiscal không tương thích với nhau"
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s và -mcall-%s là không tương thích"
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s và -mcall-%s là không tương thích"
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "thuộc tính regparam và thiscall không tương thích với nhau"
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "các thuộc tính fastcall và thiscall không tương thích với nhau"
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "các thuộc tính stdcall và thiscal không tương thích với nhau"
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "các thuộc tính cdecl và thiscall không tương thích với nhau"
 
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "Thuộc tính %qE chỉ dùng được trên hệ thống 32-bit"
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr ""
@@ -43130,47 +43130,47 @@ msgstr ""
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "sử dụng loại toán hạng không hợp lệ với mã toán hạng “Z”"
 
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, gcc-internal-format
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr ""
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, gcc-internal-format
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr ""
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr ""
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, fuzzy, gcc-internal-format
 #| msgid "unknown pointer size model %qs"
 msgid "unknown architecture specific memory model"
 msgstr "không hiểu mô hình kích thước con trỏ %qs"
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr ""
@@ -43191,8 +43191,8 @@ msgstr ""
 msgid "malformed %<#pragma builtin%>"
 msgstr "%<#pragma align%> sai định dạng"
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, gcc-internal-format
 msgid "invalid argument of %qE attribute"
 msgstr "đối số của thuộc tính %qE không hợp lệ"
@@ -43251,12 +43251,12 @@ msgstr "PRINT_OPERAND: không hiểu dấu chấm “%c”"
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr "PRINT_OPERAND con trỏ null"
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "đối số %d của %qE phải nằm trong vùng %d…%d"
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, fuzzy, gcc-internal-format
 msgid "failed to expand built-in function"
 msgstr "Chấp nhận các hàm dựng sẵn."
@@ -43387,19 +43387,19 @@ msgstr "%qD không tương thích với %qD"
 msgid "%qs cannot be used for compiling a shared library"
 msgstr "%s không thể được dùng trong asm ở đây"
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables"
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables"
 msgid "%qE attribute cannot be specified for register variables"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "multiple %qE attribute"
@@ -43512,12 +43512,12 @@ msgstr ""
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int%d%> is not supported on this target"
 msgid "%<-fexcess-precision=16%> is not supported on this target"
@@ -43565,7 +43565,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr "-mxl-multiply-high cần -mno-xl-soft-mul"
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "Thuộc tính %qE cần tham số là chuỗi"
@@ -43605,136 +43605,136 @@ msgstr ""
 msgid "argument to %qE attribute is not intstack"
 msgstr ""
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, gcc-internal-format
 msgid "cannot handle inconsistent calls to %qs"
 msgstr ""
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr "thuộc tính %<interrupt%> cần bộ xử lý MIPS32r2 hay mới hơn"
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr ""
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-check=specific for Thumb-1"
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr "-fstack-check=specific cho Thumb-1"
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, gcc-internal-format
 msgid "built-in function %qE not supported for MIPS16"
 msgstr ""
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, gcc-internal-format
 msgid "%qs does not support MIPS16 code"
 msgstr "%qs không hỗ trợ mã MIPS16"
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr "MIPS16 PIC cho ABIs khác hơn o32 và o64"
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, fuzzy, gcc-internal-format
 #| msgid "MIPS16 -mxgot code"
 msgid "MIPS16 %<-mxgot%> code"
 msgstr "MIPS16 -mxgot mã"
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, fuzzy, gcc-internal-format
 #| msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr "MIPS16 PIC cho ABIs khác hơn o32 và o64"
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, fuzzy, gcc-internal-format
 msgid "MSA MIPS16 code"
 msgstr "Tạo ra mã MIPS16."
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr "%<-mno-gpopt%> cần %<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported combination: %s"
 msgstr "Hóa hợp không được hỗ trợ: %s"
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, gcc-internal-format
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr ""
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, gcc-internal-format
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr "%<-march=%s%> không tương thích với ABI đã chọn"
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr "%<-mgp64%> được dùng với bộ xử lý 32-bit"
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, gcc-internal-format
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr "%<-mgp32%> dùng với 64-bit ABI"
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr "%<-mgp64%> được dùng với 32-bit ABI"
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "đích này không hỗ trợ %qs"
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr "%<-mgp32%> và %<-mfp64%> chỉ có thể được tổ hợp cùng nhau khi sử dụng o32 ABI"
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr ""
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr ""
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr ""
@@ -43744,117 +43744,117 @@ msgstr ""
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, gcc-internal-format
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, gcc-internal-format
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, gcc-internal-format
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr ""
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, gcc-internal-format
 msgid "unsupported combination: %qs%s %s"
 msgstr ""
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, gcc-internal-format
 msgid "unsupported combination: %qs %s"
 msgstr ""
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, gcc-internal-format
 msgid "cannot generate position-independent code for %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, gcc-internal-format
 msgid "position-independent code requires %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr "%<-mno-gpopt%> cần %<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr ""
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr ""
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr ""
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, gcc-internal-format
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr "%<-mips3d%> cần %<-mpaired-single%>"
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, gcc-internal-format
 msgid "%qs must be used with %qs"
 msgstr "%qs phải được sử dụng cùng với %qs"
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, gcc-internal-format
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr ""
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, gcc-internal-format
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr ""
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, gcc-internal-format
 msgid "the %qs architecture does not support DSP instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, gcc-internal-format
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr ""
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, gcc-internal-format
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr ""
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, gcc-internal-format
 msgid "%qs requires branch-likely instructions"
 msgstr ""
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, gcc-internal-format
 msgid "the %qs architecture does not support the synci instruction"
 msgstr ""
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr ""
@@ -44772,60 +44772,60 @@ msgstr "%<#pragma GCC optimize%> không phải là một chuỗi hay số"
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "có rác ở cuối %<#pragma reset_options%>"
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, gcc-internal-format
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, gcc-internal-format
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, gcc-internal-format
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qE attribute"
 msgid "malformed %<target()%> attribute"
 msgstr "đối số của thuộc tính %qE không hợp lệ"
 
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, fuzzy, gcc-internal-format
 #| msgid "%<no-custom-%s%> does not accept arguments"
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%<no-custom-%s%> không chấp nhận đối số"
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, fuzzy, gcc-internal-format
 #| msgid "invalid fpu for attribute(target(\"%s\"))"
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma %s%>, ignored"
 msgid "malformed %<target(\"%s\")%> attribute"
@@ -44891,184 +44891,204 @@ msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 msgid "capture by copy of RVV type %qT"
 msgstr ""
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr "-mtoc-fusion cần -mpower8-fusion"
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr "-mtoc-fusion cần -mpower8-fusion"
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr "-mtoc-fusion cần -mpower8-fusion"
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr "-mtoc-fusion cần -mpower8-fusion"
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr "-mtoc-fusion cần -mpower8-fusion"
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, gcc-internal-format
 msgid "no matching function call to %qE with empty arguments"
 msgstr ""
 
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "không hiểu giá trị %qs dành cho -mtune"
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, gcc-internal-format
 msgid "this operation requires the RVV ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr ""
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, fuzzy, gcc-internal-format
 #| msgid "Vector argument passed to unprototyped function"
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr "Đối số véc-tơ bị gửi cho hàm không nguyên mẫu"
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, fuzzy, gcc-internal-format
 #| msgid "Use the SPE ABI extensions."
 msgid "%s %qT requires the V ISA extension"
 msgstr "Dùng lệnh mở rộng SPE ABI."
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, gcc-internal-format
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, gcc-internal-format
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, gcc-internal-format
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, gcc-internal-format
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr ""
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, gcc-internal-format
 msgid "function attribute %qs requires the V ISA extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr ""
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not of type %qT"
 msgid "%qs applied to non-RVV type %qT"
 msgstr "%qE không là kiểu %qT"
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, fuzzy, gcc-internal-format
 #| msgid "vectorlength must be an integer constant"
 msgid "%qs requires an integer constant"
 msgstr "chiều dài véc-tơ phải là một hằng nguyên"
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support ARM mode"
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr "CPU đích không hỗ trợ chế độ ARM"
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs with -f%s"
 msgid "code model %qs with %qs"
 msgstr "mô hình mã %qs với -f%s"
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, gcc-internal-format
 msgid "rv64e requires lp64e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr ""
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, fuzzy, gcc-internal-format
 #| msgid "%E requires %<-fgnu-tm%>"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "%E cần %<-fgnu-tm%>"
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d không nằm giữa %d và %d"
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid class name"
 msgid "%qs is not a valid base register in %qs"
 msgstr "“%qs” không phải là một tên lớp đúng"
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs không hợp lệ cho %qs"
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qs hàm không có đối số"
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr ""
@@ -45344,32 +45364,32 @@ msgstr "%s chỉ chấp nhận một tham số"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s chỉ chấp nhận một tham số"
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, gcc-internal-format
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, gcc-internal-format
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
@@ -45410,31 +45430,23 @@ msgstr ""
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, fuzzy, gcc-internal-format
-#| msgid "Use the ELFv2 ABI."
-msgid "%qs requires the ELFv2 ABI"
-msgstr "Sử dụng ELFv2 ABI."
-
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "khung stack quá lớn"
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported number of nops before function entry (%u)"
 msgstr ""
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<register%>"
 msgid "%qs uses register r29"
 msgstr "%qE được dùng với %<register%>"
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
@@ -45573,113 +45585,123 @@ msgstr "“%qs” không phải là một tên lớp đúng"
 msgid "unknown option for %<%s=%s%>"
 msgstr "không hiểu tùy chọn cho -mrecip=%s"
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4837
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4855
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated and has no effect"
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs đã lỗi thời và không có tác động gì"
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, fuzzy, gcc-internal-format
 #| msgid "Use decimal floating point instructions."
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "Sử dụng câu lệnh dấu chấm động thập phân bằng phần cứng."
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, fuzzy, gcc-internal-format
 #| msgid "%<long long%> invalid for %qs"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "%<long long%> không hợp lệ với %qs"
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "sai cpu \"%s\" cho %s\"%s\"%s"
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is not allowed"
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s là không được phép"
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s không hợp lệ"
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr ""
@@ -45727,7 +45749,7 @@ msgstr ""
 msgid "builtin %qs can only be used on vector types"
 msgstr "%<inline%> chỉ có thể được chỉ định cho hàm"
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -45800,237 +45822,237 @@ msgstr "%qs đã lạc hậu"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr ""
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr "đối số hằng nằm ngoài phạm vi cho %qs"
 
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr "đối số hằng nằm ngoài phạm vi cho %qs"
 
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr "đối số hằng nằm ngoài phạm vi cho %qs"
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher"
 msgstr ""
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher"
 msgstr ""
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "unresolved overloaded builtin"
 msgstr "<chưa giải quyết loại hàm quá tải>"
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "icode dựng sẵn sai"
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %qD"
 msgid "invalid argument %d for builtin %qF"
 msgstr "đối số không hợp lệ cho %qD"
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr ""
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr ""
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr ""
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr ""
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr ""
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, gcc-internal-format
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr ""
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use decimal floating point instructions."
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr "Sử dụng câu lệnh dấu chấm động thập phân bằng phần cứng."
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, fuzzy, gcc-internal-format
 #| msgid "Use decimal floating point instructions."
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr "Sử dụng câu lệnh dấu chấm động thập phân bằng phần cứng."
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, gcc-internal-format
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float không được hỗ trợ trong tổ hợp"
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, gcc-internal-format
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr ""
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mrtd%> is ignored in 64bit mode"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%<-mrtd%> bị bỏ qua trong chế độ 64bit"
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr ""
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "đối số cho %qs quá lớn (tối đa là %d)"
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %<target%> argument not a string"
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr "thuộc tính %<target%> không là một chuỗi"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int%d%> is not supported by this target"
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constant"
 msgid "invalid cc output constraint: %qs"
 msgstr "hằng không hợp lệ"
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, gcc-internal-format
 msgid "multiple cc output constraints not supported"
 msgstr ""
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, gcc-internal-format
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr ""
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for property"
 msgid "invalid type for cc output constraint"
@@ -46487,8 +46509,8 @@ msgstr ""
 msgid "attribute %qs applies to array types only"
 msgstr ""
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr ""
@@ -46564,7 +46586,7 @@ msgstr ""
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr ""
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "định nghĩa lần đầu ở đây"
@@ -46806,7 +46828,7 @@ msgstr ""
 msgid "declaration of %qD shadows a parameter"
 msgstr "khai báo của %qD như là đối số"
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr ""
@@ -46816,7 +46838,7 @@ msgstr ""
 msgid "declaration of %qD shadows a previous local"
 msgstr ""
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr ""
@@ -46882,7 +46904,7 @@ msgstr ""
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr ""
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr ""
@@ -46917,7 +46939,7 @@ msgstr ""
 msgid "duplicate label declaration %qE"
 msgstr ""
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "trùng nhãn %qD"
@@ -46952,7 +46974,7 @@ msgstr ""
 msgid "%qE defined as wrong kind of tag"
 msgstr ""
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "Thuộc tính %qE cần kiểu trả về là void"
@@ -47099,12 +47121,12 @@ msgstr ""
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<omp::%s%> not allowed to be specified in this context"
@@ -47115,7 +47137,7 @@ msgstr "%<this%> có lẽ không nên được dùng trong ngữ cảnh này"
 msgid "%q+D is usually a function"
 msgstr "%q+D thường là một hàm"
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "chưa có khai báo trước đây cho %qD"
@@ -47193,7 +47215,7 @@ msgstr ""
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "bộ khởi tạo cho %q#D không hợp lệ"
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -47379,7 +47401,7 @@ msgstr ""
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
@@ -47442,7 +47464,7 @@ msgstr "sự khai báo của %qE như là mảng của các hàm"
 msgid "declaration of type name as array of functions"
 msgstr ""
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr ""
@@ -47548,7 +47570,7 @@ msgstr ""
 msgid "function definition has qualified void return type"
 msgstr "định nghĩa hàm có kiểu trả về là void"
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
@@ -47675,7 +47697,7 @@ msgstr ""
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr ""
@@ -47781,7 +47803,7 @@ msgstr ""
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr ""
@@ -47871,18 +47893,18 @@ msgstr "định nghĩa lại bị lồng của %<union %E%>"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "định nghĩa lại bị lồng của %<struct %E%>"
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used in its own initializer"
 msgid "%qT defined in underspecified object initializer"
 msgstr "%qD được dùng trong bộ khởi tạo của chính nó"
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
@@ -47912,355 +47934,355 @@ msgstr ""
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union không có thành viên nào"
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union không có thành viên nào"
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "cấu có không thành viên đã đặt tên"
 
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct không có thành viên nào"
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr ""
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "cấu có không thành viên đã đặt tên"
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of flexible array member in a nested context"
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr "bộ phận mảng dẻo bị khởi tạo trong một ngữ cảnh lồng nhau"
 
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "kiểu %qT quá lớn"
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized scalar storage order value %qs"
 msgid "type punning toggles scalar storage order"
 msgstr "không nhận ra giá trị thứ tự kho vô hướng %qs"
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr ""
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of typedef %q+D with variably modified type"
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr "định nghĩa lại của typedef %q+D với kiểu sửa biến đổi"
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %<struct %E%>"
 msgid "redefinition of struct or union %qT"
 msgstr "định nghĩa lại của %<struct %E%>"
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr ""
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "khai báo lại của %<enum %E%>"
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, gcc-internal-format
 msgid "specified mode too small for enumerated values"
 msgstr ""
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr ""
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, gcc-internal-format
 msgid "enumeration values exceed range of %qs"
 msgstr ""
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, fuzzy, gcc-internal-format
 #| msgid "in the definition of %q#T"
 msgid "conflicting redefinition of enum %qT"
 msgstr "trong định nghĩa của %q#T"
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr ""
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "tràn giá trị liệt kê"
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, gcc-internal-format
 msgid "enumerator value outside the range of underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "enumerator value outside the range of %qs"
 msgstr "đối số hằng nằm ngoài phạm vi cho %qs"
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr ""
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D declared weak"
 msgid "inline function %qD given attribute %qs"
 msgstr "hàm chung dòng %q+D được khai báo yếu"
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "kiểu trả về là một kiểu không hoàn toàn"
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "trả về kiểu mặc định cho %<int%>"
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr ""
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "chưa có khai báo nguyên mẫu trước đây cho %qD"
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr ""
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr ""
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD thường không phải là hàm non-static"
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr ""
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr ""
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr ""
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "định nghĩa hàm theo cách cũ"
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr ""
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD đã được định nghĩa là không có tham số"
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr ""
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "đối số %qD được khai báo với kiểu void"
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "kiểu của %qD mặc định đến %<int%>"
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "đối số %qD có kiểu chưa đầy đủ"
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr ""
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "số lượng đối số không giống với nó khi khai báo mẫu hàm"
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "khai báo mẫu trước"
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "%<return%> (trả lại) không có giá trị, trong hàm trả lại non-void (không rỗng)"
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "đối số %qD đặt nhưng chưa được dùng"
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr ""
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 không hỗ trợ %<long long%>"
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> được khai báo trong khai báo khởi tạo vòng lặp %<for%>"
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> được khai báo trong khai báo khởi tạo vòng lặp %<for%>"
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> được khai báo trong khai báo khởi tạo vòng lặp %<for%>"
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "cần các định danh khai báo"
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<auto%>"
 msgid "%qs used with %<auto%>"
@@ -48268,259 +48290,259 @@ msgstr "%qE được dùng với %<auto%>"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<register%>"
 msgid "%<auto%> used with %<constexpr%>"
 msgstr "%qE được dùng với %<register%>"
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> là quá dài đối với GCC"
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 không hỗ trợ %<long long%>"
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 không hỗ trợ kiểu complex"
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C không hỗ trợ kiểu saturating"
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "lặp lại %qE"
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C không hỗ trợ kiểu %<__int%d%>"
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 không hỗ trợ kiểu lô-gíc"
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr "ISO C không hỗ trợ kiểu %<__int%d%>"
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr "ISO C không hỗ trợ kiểu dấu chấm động hệ thập phân"
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "kiểu dấu chấm cố định không được hỗ trợ trên đích này"
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C không hỗ trợ kiểu dấu chấm cố định"
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, fuzzy, gcc-internal-format
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, fuzzy, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr ""
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE không ở đầu của khai báo"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE được dùng với %<auto%>"
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE được dùng với %<register%>"
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE được dùng với %<typedef%>"
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<register%>"
 msgid "%qE used with %<constexpr%>"
 msgstr "%qE được dùng với %<register%>"
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 không hỗ trợ %qE"
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 không hỗ trợ %qE"
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> trước %<extern%>"
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> trước %<static%>"
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<auto%>"
 msgid "%<typedef%> used with %<auto%>"
 msgstr "%qE được dùng với %<auto%>"
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<register%>"
 msgid "%qE used with %<extern%>"
 msgstr "%qE được dùng với %<register%>"
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, fuzzy, gcc-internal-format
 #| msgid "%qs used with %qE"
 msgid "%qE used with %qs"
 msgstr "%qs được dùng với %qE"
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "trùng %<_Thread_local%> hay %<__thread%>"
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs được dùng với %qE"
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%<constexpr%> used with %qE"
 msgstr "%<__thread%> được dùng với %qE"
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> được dùng mà không có %<_Fract%> or %<_Accum%>"
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support %<__int%d%> types"
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr "ISO C không hỗ trợ kiểu %<__int%d%>"
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, fuzzy, gcc-internal-format
 #| msgid "last argument must be an immediate"
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr "đối số cuối phải là giá trị trực tiếp"
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr "ISO C++ không hỗ trợ %<__int%d%> cho %qs"
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "dịch trái của một giá trị âm"
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "số lượng dịch trái là số âm"
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "số lượng dịch trái là số âm"
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "số lượng dịch trái  >= độ rộng của kiểu"
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "số lượng dịch phải  >= độ rộng của kiểu"
@@ -48551,7 +48573,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "không khớp cho"
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "cần kết thúc dòng"
@@ -48561,8 +48583,8 @@ msgstr "cần kết thúc dòng"
 msgid "ISO C forbids an empty translation unit"
 msgstr ""
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr ""
@@ -48603,9 +48625,9 @@ msgstr "không hiểu kiểu tên %qE; ý bạn là %qs?"
 msgid "unknown type name %qE"
 msgstr "không hiểu tên kiểu %qE"
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "cần các định danh khai báo"
@@ -48638,7 +48660,7 @@ msgstr ""
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "cần %<;%>, định danh hoặc %<(%>"
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -48658,7 +48680,7 @@ msgstr "cần thuộc tính"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, gcc-internal-format
 msgid "%<assume%> attribute not followed by %<;%>"
 msgstr ""
@@ -48753,7 +48775,7 @@ msgstr ""
 msgid "static assertion failed: %E"
 msgstr ""
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "thẩm tra tĩnh gặp lỗi"
@@ -48827,10 +48849,10 @@ msgstr ""
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "cần định danh"
@@ -48988,7 +49010,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr ""
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr ""
@@ -48998,8 +49020,8 @@ msgstr ""
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs attribute argument"
 msgstr ""
@@ -49176,12 +49198,12 @@ msgstr ""
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, fuzzy, gcc-internal-format
 #| msgid "type of field declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -49338,7 +49360,7 @@ msgstr "ISO C90 không hỗ trợ từ hạn định %<_Atomic%>"
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, gcc-internal-format
 msgid "expected expression"
 msgstr "cần biểu thức"
@@ -49669,13 +49691,13 @@ msgstr ""
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, fuzzy, gcc-internal-format
 #| msgid "unknown property attribute"
 msgid "empty property attribute list"
 msgstr "không hiểu thuộc tính tính chất"
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, fuzzy, gcc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing property attribute"
@@ -49687,61 +49709,61 @@ msgstr "Thiếu thuộc tính Code (mã)"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "không hiểu thuộc tính tính chất"
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "không hiểu thuộc tính tính chất"
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<for%> after %qs"
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "cần %<for%> sau %qs"
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected %qE selector name"
 msgstr "cần selection-statement"
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr ""
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp section%> chỉ có thể sử dụng trong cấu trúc %<#pragma omp sections%>"
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> chỉ có thể sử dụng trong cấu trúc %<#pragma omp sections%>"
@@ -49751,25 +49773,25 @@ msgstr "%<#pragma omp section%> chỉ có thể sử dụng trong cấu trúc %<
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "cần câu lệnh for, while hoặc do"
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> phải là đầu tiên"
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "quá nhiều mệnh đề %qs"
@@ -49785,66 +49807,66 @@ msgstr "chỉ số phải là số nguyên"
 msgid "expected %<)%> or %<,%>"
 msgstr "cần %<,%> hoặc %<)%>"
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD không phải là một biến"
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD không phải là một biến trỏ"
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "cần %<none%> hoặc %<shared%>"
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr "cần %<=%>, %<,%>, %<;%>, %<asm%> hay %<__attribute__%>"
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, fuzzy, gcc-internal-format
 #| msgid "expected goto expression"
 msgid "expected constant logical expression"
 msgstr "cần điều lệnh goto"
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr ""
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "cần %<data%>"
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "quá nhiều mệnh đề %<if%>"
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -49867,23 +49889,23 @@ msgstr "%<num_threads%> giá trị phải dương"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_tasks%> giá trị phải dương"
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<grainsize%> giá trị phải dương"
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<priority%> giá trị phải dương"
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
@@ -49895,100 +49917,100 @@ msgstr "cần %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%>
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses"
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "quá nhiều mệnh đề %<if%>"
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "biểu thức %qs phải là số nguyên"
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%qs giá trị phải dương"
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "quá nhiều đối số %<static%>"
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "gặp tham số thừa"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, fuzzy, gcc-internal-format
 #| msgid "ordered argument needs positive constant integer expression"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<if%> clauses"
 msgid "too many %<self%> clauses"
 msgstr "quá nhiều mệnh đề %<if%>"
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr "cần %<none%> hoặc %<shared%>"
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%>"
 msgid "expected %<concurrent%>"
 msgstr "cần %<none%>"
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "cần %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> hoặc định danh"
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%qs giá trị phải dương"
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "kiểu lịch biểu không hợp lệ"
@@ -49998,22 +50020,22 @@ msgstr "kiểu lịch biểu không hợp lệ"
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_teams%> giá trị phải dương"
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr ""
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<thread_limit%> giá trị phải dương"
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<allocator%> or %<align%>"
@@ -50025,24 +50047,24 @@ msgstr "cần %<,%> hoặc %<)%>"
 msgid "duplicate %qs modifier"
 msgstr "trùng %qs"
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, fuzzy, gcc-internal-format
 #| msgid "ordered argument needs positive constant integer expression"
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, fuzzy, gcc-internal-format
 #| msgid "multiple ref-qualifiers"
 msgid "multiple linear modifiers"
 msgstr "đa ref-qualifiers"
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, fuzzy, gcc-internal-format
 #| msgid "multiple ref-qualifiers"
 msgid "multiple %<step%> modifiers"
@@ -50063,68 +50085,68 @@ msgstr ""
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %qs"
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "%qs không tương thích với %qs"
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "kiểu phụ thuộc không hợp lệ"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, fuzzy, gcc-internal-format
 #| msgid "invalid map kind"
 msgid "invalid doacross kind"
 msgstr "kiểu ánh xạ không hợp lệ"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<static%> arguments"
 msgid "too many %<always%> modifiers"
 msgstr "quá nhiều đối số %<static%>"
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<static%> arguments"
 msgid "too many %<close%> modifiers"
 msgstr "quá nhiều đối số %<static%>"
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, fuzzy, gcc-internal-format
 #| msgid "too many %<static%> arguments"
 msgid "too many %<present%> modifiers"
 msgstr "quá nhiều đối số %<static%>"
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "kiểu ánh xạ không hợp lệ"
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr ""
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%> or %<typename%>"
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr "cần %<class%>, hoặc %<typename%>"
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, gcc-internal-format
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr ""
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "kiểu dist_schedule không hợp lệ"
@@ -50140,89 +50162,89 @@ msgstr "kiểu proc_bind không hợp lệ"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "cần %<;%>, %<,%> hoặc %<)%>"
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, fuzzy, gcc-internal-format
 msgid "expected an OpenACC clause"
 msgstr "cần kết thúc của capture-list"
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs không hợp lệ cho %qs"
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs phải là mệnh đề đầu tiên của %qs"
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected an OpenMP clause"
 msgstr "cần mệnh đề %<#pragma omp%>"
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "cần %<class%>, hoặc %<typename%>"
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma omp cancel%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr ""
@@ -50237,7 +50259,7 @@ msgstr "%qE chưa được khai báo"
 msgid "expected function name"
 msgstr "cần tên hàm"
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD không phải là hàm thành viên mẫu"
@@ -50247,24 +50269,24 @@ msgstr "%qD không phải là hàm thành viên mẫu"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma acc routine%> must be applied before %s"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma acc routine%> must be applied before %s"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> phải chứa ít nhất là một mệnh đề %<device%> hay %<host%> hay %<self%>"
@@ -50291,7 +50313,7 @@ msgstr ""
 msgid "modified here"
 msgstr "union được định nghĩa ở đây"
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, fuzzy, gcc-internal-format
 #| msgid "ordered argument needs positive constant integer expression"
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
@@ -50332,120 +50354,120 @@ msgstr ""
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr ""
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "quá nhiều mệnh đề %qs"
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "quá nhiều mệnh đề %qs"
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %s %s"
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr "%qs không tương thích với %s %s"
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in %qs clause"
 msgid "%qs clause requires %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after union definition"
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr "cần %<;%> sau định nghĩa kiểu hỗn hợp"
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, gcc-internal-format
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr ""
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, fuzzy, gcc-internal-format
 #| msgid "invalid form of %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr "sai dạng thức của %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<delete%>"
 msgid "unexpected %<else%>"
 msgstr "cần %<delete%>"
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, fuzzy, gcc-internal-format
 #| msgid "invalid form of %<#pragma omp atomic%>"
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr "sai dạng thức của %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "sai dạng thức của %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "thao tác không hợp lệ cho %<#pragma omp atomic%>"
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr ""
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> sử dụng hai biểu thức khác nhau cho bộ nhớ"
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
@@ -50455,30 +50477,30 @@ msgstr "biểu thức %qE không phải là biểu thức hằng"
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr ""
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr "cần %<=%>, %<,%>, %<;%>, %<asm%> hay %<__attribute__%>"
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "cần %<;%>, %<,%> hoặc %<)%>"
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "cần %<=%>, %<,%>, %<;%>, %<asm%> hay %<__attribute__%>"
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -50488,178 +50510,178 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "cần %<(%> hoặc xuống dòng"
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr "%<#pragma omp cancel%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<}%> before %<else%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "cần %<}%> trước %<else%>"
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "cần mệnh đề %<#pragma omp%>"
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp cancel%> may only be used in compound statements"
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr "%<#pragma omp cancel%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "cần khai báo nhắc lại hay sự khởi tạo"
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, fuzzy, gcc-internal-format
 #| msgid "not enough arguments"
 msgid "not enough nested loops"
 msgstr "không đủ đối số"
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "cần câu lệnh for"
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp ordered%> with %<depend> clause may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "cần %<for%> sau %qs"
 
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "cần %<point%>"
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma acc update%> phải chứa ít nhất là một mệnh đề %<device%> hay %<host%> hay %<self%>"
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr ""
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> phải xuất hiện trước khai báo của %D, đang lờ đi"
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected trait selector name"
 msgstr "cần selection-statement"
 
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, gcc-internal-format
 msgid "unknown selector %qs for context selector set %qs"
 msgstr ""
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, fuzzy, gcc-internal-format
 #| msgid "%<no-custom-%s%> does not accept arguments"
 msgid "selector %qs does not accept any properties"
 msgstr "%<no-custom-%s%> không chấp nhận đối số"
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr "%<friend%> chỉ có thể được chỉ định trong một lớp"
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, fuzzy, gcc-internal-format
 #| msgid "ordered argument needs positive constant integer expression"
 msgid "%<score%> argument must be constant integer expression"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, fuzzy, gcc-internal-format
 #| msgid "%<priority%> value must be non-negative"
 msgid "%<score%> argument must be non-negative"
 msgstr "%<priority%> giá trị phải dương"
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "cần chuỗi văn chương"
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, fuzzy, gcc-internal-format
 #| msgid "ordered argument needs positive constant integer expression"
 msgid "property must be constant integer expression"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr ""
@@ -50667,310 +50689,310 @@ msgstr ""
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, fuzzy, gcc-internal-format
 #| msgid "Clause not supported yet"
 msgid "%<requires%> selector is not supported yet"
 msgstr "Mệnh đề vẫn chưa được hỗ trợ"
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected context selector set name"
 msgstr "cần selection-statement"
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<match%>"
 msgstr "cần %<catch%>"
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L is not a function"
 msgid "variant %qD is not a function"
 msgstr "“%qs” tại %L không phải là một hàm"
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD has incomplete type"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "đối số %qD có kiểu chưa đầy đủ"
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, gcc-internal-format
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "cần %<target%>"
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%> or %<typename%>"
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr "cần %<class%>, hoặc %<typename%>"
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr ""
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr ""
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute with %s attribute at %L"
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr "thuộc tính %s với thuộc tính %s tại %L"
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%> or %<typename%>"
 msgid "expected %<declare%> or %<assumes%>"
 msgstr "cần %<class%>, hoặc %<typename%>"
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr ""
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr "%<#pragma omp declare reduction%> trước"
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "%<#pragma omp declare reduction%> trước"
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr "cần %<omp_priv%> hoặc tên-hàm"
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "cần tên-hàm %<(%>"
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "cần %<=%>, %<,%>, %<;%>, %<asm%> hay %<__attribute__%>"
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr "cần %<=%>, %<,%>, %<;%>, %<asm%> hay %<__attribute__%>"
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr "%<_Atomic%> %qE trong mệnh đề %<reduction%>"
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, fuzzy, gcc-internal-format
 #| msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "%<_Atomic%> %qE trong mệnh đề %<reduction%>"
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr "cần %<;%>, %<,%> hoặc %<)%>"
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %qs or %qs"
 msgstr "cần %<,%> hoặc %<)%>"
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> với mệnh đề %<depend%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr ""
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr ""
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected at least one assumption clause"
 msgstr "cần mệnh đề %<#pragma omp%>"
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, fuzzy, gcc-internal-format
 #| msgid "expected function name"
 msgid "expected directive name"
 msgstr "cần tên hàm"
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr ""
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, fuzzy, gcc-internal-format
 #| msgid "unknown excess precision style %qs"
 msgid "unknown assumption clause %qs"
 msgstr "không hiểu kiểu chính xác bị vượt quá %qs"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, fuzzy, gcc-internal-format
 #| msgid "expected function name"
 msgid "expected assumption clause"
 msgstr "cần tên hàm"
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> nằm trong một %<__transaction_relaxed%>"
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, fuzzy, gcc-internal-format
 #| msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "vòng ngoài hơn %<__transaction_cancel%> không nằm trong vòng ngoài hơn %<__transaction_atomic%>"
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> không nằm trong %<__transaction_atomic%>"
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, fuzzy, gcc-internal-format
 msgid "no closing brace"
 msgstr "tác vụ bao quanh"
@@ -51111,7 +51133,7 @@ msgstr ""
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr ""
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "chỉ số mảng không phải là số nguyên"
@@ -51142,7 +51164,7 @@ msgstr "%qD được khai báo như là một tham chiếu nhưng lại chưa đ
 msgid "enum constant defined here"
 msgstr ""
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -51257,18 +51279,18 @@ msgstr ""
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "quá ít đối số cho hàm %qE"
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr ""
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about use of multi-character character constants."
 msgid "comparison between pointer and zero character constant"
 msgstr "Cảnh báo về sử dụng hằng số ký tự đa ký tự."
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, fuzzy, gcc-internal-format
 #| msgid "did you mean to use logical not?"
 msgid "did you mean to dereference the pointer?"
@@ -51294,7 +51316,7 @@ msgstr "con trỏ đến hàm được dùng trong phép trừ"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
@@ -51590,7 +51612,7 @@ msgstr ""
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
@@ -51769,7 +51791,7 @@ msgstr ""
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -51976,12 +51998,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "đã khởi tạo một bộ phận mảng dẻo"
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -51991,7 +52013,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr "mảng loại không thích hợp bị khởi tạo từ hằng số chuỗi"
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "sai sử dụng mảng không phải lvalue"
@@ -52022,7 +52044,7 @@ msgstr "yếu tố khởi tạo không phải là một biểu tượng hằng s
 msgid "initializer element is not computable at load time"
 msgstr "yếu tố khởi tạo không tính được vào lúc nạp"
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
@@ -52037,7 +52059,7 @@ msgstr "gặp nhóm ngoặc móc thừa tại kết thúc của bộ khởi tạ
 msgid "braces around scalar initializer"
 msgstr "ngoặc chung quanh bộ khởi tạo vô hướng"
 
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "bộ phận mảng dẻo bị khởi tạo trong một ngữ cảnh lồng nhau"
@@ -52128,7 +52150,7 @@ msgstr "gặp yếu tố thừa trong bộ khởi tạo cấu trúc"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "một bộ phận mảng dẻo bị khởi tạo một cách không phải tĩnh"
@@ -52169,7 +52191,7 @@ msgstr "ISO C cấm %<goto *expr;%>"
 msgid "computed goto must be pointer type"
 msgstr "không thể chuyển đổi thành kiểu con trỏ"
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "hàm đã khai báo %<noreturn%> có một câu lệnh %<return%>"
@@ -52224,7 +52246,7 @@ msgstr ""
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -52272,27 +52294,27 @@ msgstr "trình biên dịch sẽ coi rằng địa chỉ của %qD sẽ không b
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr "trình biên dịch sẽ coi rằng địa chỉ của %qD sẽ không bao giờ là NULL"
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, gcc-internal-format
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
 msgstr ""
@@ -52364,30 +52386,30 @@ msgstr ""
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma acc update%> phải chứa ít nhất là một mệnh đề %<device%> hay %<host%> hay %<self%>"
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma simd%> clause"
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "cần mệnh đề %<#pragma simd%>"
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE không phải một biến trong mệnh đề %qs"
@@ -52398,87 +52420,87 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%> %qD trong mệnh đề %qs"
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of file in %qs"
 msgid "expected single pointer in %qs clause"
 msgstr "Gặp kết thúc tập tin bất thường tại %qs"
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, fuzzy, gcc-internal-format
 #| msgid "%<vector%> length expression must be integral"
 msgid "for array function parameter length expression must be specified"
 msgstr "chiều dài %<vector%> phải là số nguyên"
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE không có con trỏ hay kiểu mảng"
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, gcc-internal-format
 msgid "iterator %qD has neither integral nor pointer type"
 msgstr ""
@@ -52489,18 +52511,18 @@ msgstr ""
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "%<_Atomic%> áp dụng cho kiểu hạn định"
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD has incomplete type"
 msgid "iterator %qD has const qualified type"
 msgstr "đối số %qD có kiểu chưa đầy đủ"
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr ""
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
@@ -52510,35 +52532,35 @@ msgstr ""
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression for output modifier '%c'"
 msgid "end expression refers to outer iterator %qD"
 msgstr "biểu thức không hợp lệ cho bộ sửa đầu ra “%c”"
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, fuzzy, gcc-internal-format
 #| msgid "linear step expression must be integral"
 msgid "step expression refers to outer iterator %qD"
 msgstr "biểu thức bước thẳng phải là số nguyên"
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected pointer in %qs clause"
 msgstr "cần con trỏ"
 
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr ""
 
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, fuzzy, gcc-internal-format
 #| msgid "%qD in %<reduction%> clause is a zero size array"
 msgid "%<inscan%> %<reduction%> clause with array section"
@@ -52571,7 +52593,7 @@ msgstr "mảng có độ dài biến đổi %qD được dùng"
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE có kiểu không hợp lệ cho %<reduction(%s)%>"
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -52581,17 +52603,17 @@ msgstr ""
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE phải là %<threadprivate%> với %<copyin%>"
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
 msgstr ""
@@ -52606,23 +52628,23 @@ msgstr ""
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, gcc-internal-format
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -52634,32 +52656,32 @@ msgstr ""
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE không phải một biến trong mệnh đề %<aligned%>"
@@ -52679,7 +52701,7 @@ msgstr "%qD không phải một biến trong mệnh đề  %<aligned%>"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<depend%> clause"
 msgid "%qE is not a variable in %<nontemporal%> clause"
@@ -52691,7 +52713,7 @@ msgstr "%qE không phải một biến trong mệnh đề %<depend%>"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE không phải một đối số trong mệnh đề %<uniform%>"
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<aligned%> clause"
 msgid "%qE is not a variable in %<allocate%> clause"
@@ -52703,78 +52725,78 @@ msgstr "%qE không phải một biến trong mệnh đề %<aligned%>"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE không phải một biến trong mệnh đề %<aligned%>"
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr ""
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %qs clause"
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr "%qE không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %qD"
 msgid "unsupported map expression %qE"
 msgstr "đối số không được hỗ trợ cho %D"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE không phải một biến cũng không phải tên hàm trong mệnh đề %qs"
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD không phải một đối số trong mệnh đề %<uniform%>"
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE không phải một đối số trong mệnh đề %<uniform%>"
@@ -52790,23 +52812,23 @@ msgstr "nguồn không phải là một hàm trỏ"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, gcc-internal-format
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr ""
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %qs clauses on a task construct"
 msgstr "quá nhiều mệnh đề %qs"
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
@@ -52816,38 +52838,38 @@ msgstr ""
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
@@ -53143,13 +53165,13 @@ msgstr "  cho chuyển đổi từ %qT thành %qT"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  không hiểu chuyển đổi cho đối số %d từ %qT thành %qT"
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  ứng cử cần ít nhất %d đối số, nhưng cung cấp %d"
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -53475,581 +53497,581 @@ msgstr ""
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "kiểu không khớp trong biểu thức điều kiện"
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr ""
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr ""
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "return type of %qD is not %qs"
 msgstr "kiểu trả về %q#T là một kiểu không hoàn toàn"
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "so sánh giữa %q#T và %q#T"
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to %<(%T) (%A)%>"
 msgid "no match for call to %<%T::operator[] (%A)%>"
 msgstr "cú gọi không khớp tới %<(%T) (%A)%>"
 
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, fuzzy, gcc-internal-format
 #| msgid "call of %<(%T) (%A)%> is ambiguous"
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr "cú gọi của %<(%T) (%A)%> chưa rõ ràng"
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is a usual (non-placement) deallocation function"
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "%qD thường không phải là hàm non-static"
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "%qD thường không phải là hàm non-static"
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr ""
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr ""
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr ""
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, gcc-internal-format
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "đã được khai báo ở đây"
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, gcc-internal-format
 msgid "%q#D is protected within this context"
 msgstr ""
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "được khai báo bảo vệ ở đây"
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
 msgstr "%q#D là không thể truy cập trong ngữ cảnh này"
 
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr ""
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, gcc-internal-format
 msgid "  declared here"
 msgstr "  đã được khai báo ở đây"
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr ""
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr ""
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr ""
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  đang khởi tạo đối số %P của %qD"
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, fuzzy, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr ""
 
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr ""
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 #, fuzzy
 #| msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr "ISO C++ không cho phép %<alignof%> với một non-type"
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr ""
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr ""
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 #, fuzzy
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr ""
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr ""
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 #, fuzzy
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr ""
 
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr ""
 
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind %qT lvalue to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "không thể buộc %qT lvalue thành %qT"
 
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr ""
 
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr ""
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr ""
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr ""
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr ""
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr ""
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr ""
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr ""
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr ""
 
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  trong gọi đến %qD"
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "sử dụng #include để thay thế"
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr ""
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "sử dụng #include để thay thế"
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, fuzzy, gcc-internal-format
 #| msgid "re-initialization of %qs at %L"
 msgid "; use copy-initialization instead"
 msgstr "khởi tạo lại của %qs tại %L"
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr ""
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared here"
 msgid "%#qT declared here"
 msgstr "%qT được khai báo ở đây"
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, fuzzy, gcc-internal-format
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr "Cảnh báo khi xóa một con trỏ tới kiểu không hoàn toàn."
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to %<(%T) (%A)%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "cú gọi không khớp tới %<(%T) (%A)%>"
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "không thể gọi cấu tử %<%T::%D%> một cách trực tiếp"
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "gọi hàm quá tải %<%s(%A)%> chưa rõ ràng"
 
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "trả về một giá trị từ cấu tử"
 
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "trả về một giá trị từ hủy tử"
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, gcc-internal-format
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr ""
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when converting the type of pointers to member functions."
 msgid "try making the operator a %<const%> member function"
 msgstr "Cảnh báo khi chuyển đổi loại hàm trỏ sang hàm thành viên."
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "đóng %qD thông qua %qD"
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  cho chuyển đổi từ %qT thành %qT"
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " ứng cử 1: %q#F"
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " ứng cử 2: %q#F"
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr ""
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr ""
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "possibly dangling reference to a temporary"
 msgstr "trả về tham chiếu đến tạm thời (temporary)"
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr ""
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, gcc-internal-format
 msgid "explicit conversion function was not considered"
 msgstr ""
@@ -54098,7 +54120,7 @@ msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D không thể được quá tải"
 
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "khai báo trước đây %q#D"
@@ -54533,7 +54555,7 @@ msgstr ""
 msgid "next member %q#D declared here"
 msgstr "thành viên kế %q#D đã khai báo ở đây"
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "định nghĩa lại của %q#T"
@@ -54668,7 +54690,7 @@ msgstr ""
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
@@ -54711,7 +54733,7 @@ msgstr ""
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%qD không phải là đối số hàm"
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr ""
@@ -54730,7 +54752,7 @@ msgstr "%<constexpr%> không thể dùng cho khai báo kiểu"
 msgid "%q+E is not a constant expression"
 msgstr "%q+E không phải biểu thức hằng"
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
@@ -54752,7 +54774,7 @@ msgstr ""
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
@@ -54802,7 +54824,7 @@ msgstr "  %qT là lớp cơ sở chưa rõ ràng của %qT"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -54934,18 +54956,18 @@ msgstr ""
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr ""
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr ""
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -54953,488 +54975,488 @@ msgstr ""
 msgid "%qE is not a constant expression"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr ""
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr ""
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr ""
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot be used in asm here"
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "%s không thể được dùng trong asm ở đây"
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr ""
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "Gặp biểu thức lambda trong biểu thức bất biến"
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "allocated here"
 msgstr "được khai báo ở đây"
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
 msgstr ""
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, fuzzy, gcc-internal-format
 #| msgid "array index in initializer is not an integer constant expression"
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "bộ khởi tạo chứa một chỉ mục mảng không phải là một biểu tượng hằng số nguyên"
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD được dùng trong bộ khởi tạo của chính nó"
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D không là const"
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D là volatile"
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD không được khởi tạo với một biểu thức hằng"
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD chưa được khai báo %<constexpr%>"
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, fuzzy, gcc-internal-format
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, fuzzy, gcc-internal-format
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr ""
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr ""
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr ""
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "inline assembly is not a constant expression"
 msgstr "yếu tố khởi tạo không phải là một biểu tượng hằng số"
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "use of %qD"
 msgstr "dùng %qD không hợp lệ"
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr ""
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr ""
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr ""
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr ""
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, gcc-internal-format
 msgid "control passes through definition of %qD with static storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, fuzzy, gcc-internal-format
 #| msgid "routine %qD declared here"
 msgid "pointed-to object declared here"
 msgstr "%qD được khai báo ở đây"
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr ""
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, fuzzy, gcc-internal-format
 #| msgid "%qD called in a constant expression"
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr "%qD được gọi trong một biểu thức hằng"
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, fuzzy, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-id"
 msgid "unexpected template-id %qE"
 msgstr "cần template-id"
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, gcc-internal-format
 msgid "function concept must be called"
 msgstr ""
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, fuzzy, gcc-internal-format
 msgid "address of a call to %qs is not a constant expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr ""
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr ""
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, gcc-internal-format
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, gcc-internal-format
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr ""
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "Gặp biểu thức lambda trong biểu thức bất biến"
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, fuzzy, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr ""
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, fuzzy, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, fuzzy, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "cần AST thuộc kiểu %s"
@@ -56229,7 +56251,7 @@ msgstr "đối số 1 của __builtin_paired_predicate phải là một hằng"
 msgid "no suspend point info for %qD"
 msgstr "chưa có khai báo nguyên mẫu trước đây cho %qD"
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -56251,23 +56273,23 @@ msgstr "biểu thức như là toán hạng không hợp lệ"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "mảng có độ dài biến đổi được dùng"
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr ""
@@ -56288,74 +56310,74 @@ msgstr ""
 msgid "%qD was promoted to an immediate function"
 msgstr "%qD không phải là một hàm mẫu"
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of an immediate function %qD"
 msgstr "lấy địa chỉ của hủy tử %qE"
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, fuzzy, gcc-internal-format
 msgid "call to consteval function %qE is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<concept%>"
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "hủy tử không thể là %<concept%>"
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu"
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qE attribute"
 msgid "pack expansion of %qE attribute"
 msgstr "đối số của thuộc tính %qE không hợp lệ"
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, gcc-internal-format
 msgid "use fold expression in the attribute argument instead"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD không phải là một kiểu"
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qD is not a class type"
 msgstr "%qT không phải là kiểu lớp"
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have pointer or array type"
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE không có con trỏ hay kiểu mảng"
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have pointer or array type"
 msgid "%qD does not have integral type"
 msgstr "%qE không có con trỏ hay kiểu mảng"
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
@@ -56404,7 +56426,7 @@ msgstr ""
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "chuyển đổi từ %qT sang %qT là chưa rõ ràng"
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr ""
@@ -56795,7 +56817,7 @@ msgstr "từ khai báo trước đây %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "sự khai báo lại %q+D khác trong %<constexpr%>"
 
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "khai báo trước đây %q#D"
@@ -56945,8 +56967,8 @@ msgstr ""
 msgid "%q#D previously defined here"
 msgstr "%q#D trước được định nghĩa ở đây"
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q#D trước định nghĩa ở đây"
@@ -57025,58 +57047,40 @@ msgstr ""
 msgid "previous specification in %q#D here"
 msgstr "sau đặc tả trước đây trong %q#D"
 
-#: cp/decl.cc:2285
-#, fuzzy, gcc-internal-format
-#| msgid "section type conflict with %D"
-msgid "declaration %qD conflicts with builtin"
-msgstr "kiểu phần xung đột với %D"
-
-#: cp/decl.cc:2288
-#, fuzzy, gcc-internal-format
-#| msgid "section type conflict with %D"
-msgid "declaration %qD conflicts with import"
-msgstr "kiểu phần xung đột với %D"
-
-#: cp/decl.cc:2289
-#, fuzzy, gcc-internal-format
-#| msgid "  declared here"
-msgid "import declared %q#D here"
-msgstr "  đã được khai báo ở đây"
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q+#D"
 msgid "conflicting exporting for declaration %qD"
 msgstr "khai báo xung đột %q+#D"
 
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared here without exporting"
 msgstr "đã khai báo trước ở đây"
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %qD here"
 msgstr "định nghĩa trước đây của %q+D là đây"
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD here"
 msgstr "khai báo trước đây của %q+D ở đây"
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared %<virtual%> inside a union"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "hàm %qD được khai báo %<virtual%> trong một union"
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr ""
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr ""
@@ -57089,44 +57093,44 @@ msgstr ""
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr ""
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr ""
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "định nghĩa lại của %q#D"
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr ""
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D chưa được khai báo trong lớp"
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr ""
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -57134,2576 +57138,2576 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr ""
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr ""
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr ""
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "khai báo lại của %q#D"
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, fuzzy, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "tái khai báo không hợp lệ cho %q+D"
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration"
 msgid "previous label"
 msgstr "khai báo trước"
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, gcc-internal-format
 msgid "jump to label %qD"
 msgstr "nhảy tới nhãn %qD"
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr "nhảy tới nhãn lệnh case"
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr ""
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  từ đây"
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  thoát khỏi khối được cấu trúc OpenMP"
 
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  sự khởi tạo chéo của %q+#D"
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  vào khối try"
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  vào khối catch"
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  vào khối được cấu trúc OpenMP"
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "  enters statement expression"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, fuzzy, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "cần biểu thức"
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, fuzzy, gcc-internal-format
 msgid "  enters %<consteval if%> statement"
 msgstr "cần biểu thức"
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C99 does not support %qE"
 msgid "  does not destroy %qD"
 msgstr "ISO C99 không hỗ trợ %qE"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, gcc-internal-format
 msgid "  does not clean up handled exception"
 msgstr ""
 
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  bỏ qua sự khởi tạo của %q#D"
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, fuzzy, gcc-internal-format
 #| msgid "non-class template %qT used without template arguments"
 msgid "%qD used without template arguments"
 msgstr "mẫu không phải lớp %qT được dùng mà không có đỗi số mẫu"
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is a function, not a type"
 msgstr "%qD không phải là một mẫu hàm"
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T không phải là một lớp"
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr ""
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "không có kiểu có tên %q#T trong %q#T"
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr ""
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr ""
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names the constructor, not the type"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<%T::%D%> tên cấu tử, không phải kiểu"
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr ""
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, fuzzy, gcc-internal-format
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "-falign-labels=%d không được hỗ trợ"
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, gcc-internal-format
 msgid "anonymous struct with base classes"
 msgstr ""
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr ""
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr ""
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr ""
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr ""
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr ""
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr ""
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr ""
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr ""
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
 msgstr "%<inline%> chỉ có thể được chỉ định cho hàm"
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
 msgstr "%<virtual%> chỉ có thể được chỉ định cho hàm"
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> chỉ có thể được chỉ định trong một lớp"
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "%<explicit%> chỉ có thể được chỉ định cho cấu tử"
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr ""
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "%<const%> chỉ có thể được chỉ định cho lớp và hàm"
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "%<volatile%> chỉ có thể được chỉ định cho đối tượng và hàm"
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "%<__restrict%> chỉ có thể được chỉ định cho đối tượng và hàm"
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "%<__thread%> chỉ có thể được chỉ định cho đối tượng và hàm"
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> bị bỏ qua trong khai báo này"
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%> không thể dùng cho khai báo kiểu"
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr ""
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr ""
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr ""
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr ""
 
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is initialized with itself"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "%qD được khởi tạo bằng chính nó"
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr ""
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr ""
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q+#D không phải là thành viên tĩnh của %q#T"
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr ""
 
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr ""
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ không cho phép %<%T::%D%> được định nghĩa như là %<%T::%D%>"
 
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "khởi tạo lặp lại cho %qD"
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr ""
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr ""
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++11 %<thread_local%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "việc dùng %<auto%> trong khai báo tham số chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr ""
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr ""
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr ""
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD được khai báo như là một tham chiếu nhưng lại chưa được khởi tạo"
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr ""
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr ""
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr ""
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "thiếu kích thước mảng trong %qD"
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "mảng có kích thước bằng không %qD"
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr ""
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr ""
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr ""
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr ""
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<const%>"
 msgid "uninitialized %<const %D%>"
 msgstr "lặp lại %<const%>"
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr ""
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr ""
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr ""
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr ""
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr ""
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr ""
 
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr ""
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD không phải là thành viên của %qT"
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "bộ khởi tạo cho %q#D không hợp lệ"
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "quá nhiều bộ khởi tạo cho %qT"
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr ""
 
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "ngoặc chung quanh bộ khởi tạo vô hướng"
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr ""
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, fuzzy, gcc-internal-format
 #| msgid "return type is an incomplete type"
 msgid "structured binding has incomplete type %qT"
 msgstr "kiểu trả về là một kiểu không hoàn toàn"
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr ""
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr ""
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "đối số %q#D có kiểu chưa đầy đủ"
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr ""
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr ""
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr ""
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr ""
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr ""
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "một bộ phận mảng dẻo bị khởi tạo một cách không phải tĩnh"
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr ""
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "tham chiếu %qD được khởi tạo bằng chính nó"
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%> không trong khai báo"
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to constructor %q#D"
 msgid "%<declare variant%> on constructor %qD"
 msgstr "quá ít đối số cho hủy tử %q#D"
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr ""
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ không cho phép %<alignof%> với một non-type"
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "khai báo của %q#D chưa có bộ khởi tạo"
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr ""
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "kiểu trả về %q#T là một kiểu không hoàn toàn"
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, gcc-internal-format
 msgid "variable concept has no initializer"
 msgstr ""
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr ""
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, fuzzy, gcc-internal-format
 #| msgid "source is a pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "nguồn là một hàm trỏ tới loại không hoàn toàn"
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializer provided for function"
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "bộ khởi tạo được cung cấp cho hàm"
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "(gần chỗ khởi tạo cho %qs)"
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "không thể giải mã địa chỉ"
 
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, fuzzy, gcc-internal-format
 #| msgid "source is of incomplete class type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "nguồn có loại lớp không hoàn toàn"
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "thiếu kích thước mảng trong %qT"
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "mảng có kích thước không %qT"
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD được khai báo là một biến %<virtual%>"
 
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD được khai báo như là đối số %<virtual%>"
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD được khai báo là một đối số %<inline%>"
 
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD được khai báo như là kiểu %<virtual%>"
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD được khai báo là một kiểu %<inline%>"
 
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD được khai báo như là trường %<virtual%>"
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD được khai báo là một trường %<inline%>"
 
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D được khai báo là friend"
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, fuzzy, gcc-internal-format
 #| msgid "function return type cannot be function"
 msgid "a function concept cannot be constrained"
 msgstr "kiểu trả về hàm không thể là hàm"
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD không phải là một hàm mẫu"
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, gcc-internal-format
 msgid "constrained non-template friend declaration must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, gcc-internal-format
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr ""
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "không thể khai báo con trỏ đến %q#T"
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, gcc-internal-format
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, gcc-internal-format
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, fuzzy, gcc-internal-format
 #| msgid "next member %q#D declared here"
 msgid "explicit object parameter declared here"
 msgstr "thành viên kế %q#D đã khai báo ở đây"
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr ""
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr ""
 
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr ""
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD phải là một hàm không-thành-viên"
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> phải trả về %<int%>"
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D đã là mặc định rõ ràng ở đây"
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr ""
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot be a coarray"
 msgid "a variable concept cannot be constrained"
 msgstr "Biến vòng lặp tại %C không thể là một coarray"
 
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ cấm mảng có kích thước bằng không %qD"
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ cấm mảng có kích thước bằng không"
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ cấm biến có kích thước biến đổi %qD"
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ cấm biến có kích thước biến đổi"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "mảng có độ dài biến đổi %qD được dùng"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "mảng có độ dài biến đổi được dùng"
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "tràn kích thước mảng"
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as array of %qT"
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%qD được khai báo là mảng của %qT"
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, fuzzy, gcc-internal-format
 #| msgid "Creating array temporary at %L"
 msgid "creating array of template placeholder type %qT"
 msgstr "Đang tạo mảng tạm tại %L"
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "sự khai báo của %qD như là mảng void"
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "tạo mảng void"
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "sự khai báo của %qD như là mảng của các hàm"
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "tạo mảng hàm"
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "sự khai báo của %qD như là mảng của các tham chiếu"
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "tạo mảng tham chiếu"
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "sự khai báo của %qD như là mảng của các thành viên hàm"
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "tạo mảng của thành viên hàm"
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable-length array of %<auto%>"
 msgstr "mảng có độ dài biến đổi được dùng"
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr ""
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, fuzzy, gcc-internal-format
 #| msgid "no processor type specified for linking"
 msgid "return type specified for deduction guide"
 msgstr "chưa ghi rõ loại bộ xử lý cần liên kết"
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "biến hay trường được khai báo là void"
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "%<inline%> được chỉ định cho khai báo lớp bạn"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, fuzzy, gcc-internal-format
 #| msgid "@catch parameter can not be protocol-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "đối số @catch không thể là từ hạn định giao thức"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "cách dùng không đúng tên từ hạn định %<::%D%>"
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "cách dùng không đúng tên từ hạn định %<%T::%D%>"
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "cách dùng không đúng tên từ hạn định %<%D::%D%>"
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT không phải là một lớp hay namespace"
 
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "sự khai báo của %qD như là non-function"
 
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "sự khai báo của %qD như là non-member"
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "định nghĩa hàm không khai báo đối số"
 
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "sự khai báo của %qD như là non-function"
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "sự khai báo của %qD như là %<typedef%>"
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "khai báo của %qD như là đối số"
 
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, fuzzy, gcc-internal-format
 #| msgid "%qs cannot appear in a constant-expression"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%qs không thể xuất hiện trong biểu thức hằng"
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr ""
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ không hỗ trợ %<__int%d%> cho %qs"
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, fuzzy, gcc-internal-format
 #| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> và %<unsigned%> được chỉ định cùng với nhau cho %qs"
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> và %<short%> được chỉ định cùng nhau với %qs"
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, fuzzy, gcc-internal-format
 #| msgid "%qs used with %qE"
 msgid "%qs specified with %qT"
 msgstr "%qs được dùng với %qE"
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<typedef%>"
 msgid "%qs specified with typedef-name %qD"
 msgstr "%qE được dùng với %<typedef%>"
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<typedef%>"
 msgid "%qs specified with %<decltype%>"
 msgstr "%qE được dùng với %<typedef%>"
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "%qE được dùng với %<typedef%>"
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "số ảo không hợp lệ cho %qs"
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, gcc-internal-format
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a parameter cannot be declared %qs"
 msgstr "các đối số tạm không thể là bạn"
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> ngoài khai báo lớp"
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "định nghĩa hàm được khai báo là %qs"
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr ""
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "định nghĩa hàm được khai báo là %qs"
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr ""
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr ""
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "thuộc tính bị bỏ qua"
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "cho khai báo hàm mẫu %q+D"
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "Mong đợi một dấu ngoặc đơn mở"
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, fuzzy, gcc-internal-format
 #| msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "định nghĩa namespaces lồng nhau chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, fuzzy, gcc-internal-format
 #| msgid "Function %qs at %L cannot have an initializer"
 msgid "a function type cannot have an explicit object parameter"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, gcc-internal-format
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, fuzzy, gcc-internal-format
 #| msgid "  member function type %qT is not a valid template argument"
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr ""
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, gcc-internal-format
 msgid "the type of an explicit object member function is a regular function type"
 msgstr ""
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, gcc-internal-format
 msgid "valid explicit object parameter declared here"
 msgstr ""
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, fuzzy, gcc-internal-format
 #| msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "kiểu trả về deduced chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr ""
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "dùng %<auto%> không hợp lệ"
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, fuzzy, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "kiểu lớp %qT chưa hoàn thiện"
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, fuzzy, gcc-internal-format
 #| msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "kiểu trả về deduced chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr ""
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not have parameters"
 msgid "constructors may not be ref-qualified"
 msgstr "hủy tử không được có đối số"
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr ""
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, gcc-internal-format
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, fuzzy, gcc-internal-format
 #| msgid "implicit templates may not be %<virtual%>"
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr "các mẫu ngầm không nên là %<virtual%>"
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, fuzzy, gcc-internal-format
 msgid "an explicit object member function cannot be %<static%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a non-member function"
 msgid "%qD cannot be an explicit object member function"
 msgstr "%qD phải là một hàm không-thành-viên"
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "hủy tử không được có đối số"
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "không thể khai báo con trỏ đến %q#T"
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "không thể khai báo con trỏ cho thành viên %q#T"
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD được dùng như bộ khai báo"
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> ngoài khai báo lớp"
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr ""
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, fuzzy, gcc-internal-format
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, fuzzy, gcc-internal-format
 #| msgid "old-style function definition"
 msgid "typedef may not be a function definition"
 msgstr "định nghĩa hàm theo cách cũ"
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, fuzzy, gcc-internal-format
 #| msgid "a concept cannot be a member function"
 msgid "typedef may not be a member function definition"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%> không trong khai báo"
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef được khai báo %<auto%>"
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> được chỉ định cho khai báo lớp bạn"
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "các đối số tạm không thể là bạn"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr ""
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "không thể dùng %<::%> trong khai báo đối số"
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "thành viên dữ liệu không-tĩnh được khai báo giữ chỗ %qT"
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ cấm mảng có kích thước bằng không %qD"
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 không hỗ trợ thành viên mảng linh động"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "dùng %<::%> không hợp lệ"
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "hàm %qD được khai báo %<virtual%> trong một union"
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "sự khai báo của %qD như là thành viên của %qT"
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %qs"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "cấu tử không thể là %<concept%>"
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "không thể mở %s"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr ""
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, gcc-internal-format
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, fuzzy, gcc-internal-format
 #| msgid "static data member %qD in unnamed class"
 msgid "static data member %qE declared %qs"
 msgstr "thành viên dữ liệu tĩnh %qD trong lớp không tên"
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %qD has non-literal type"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu không-văn-chương"
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member declared with placeholder %qT"
 msgid "non-static data member %qE declared %qs"
 msgstr "thành viên dữ liệu không-tĩnh được khai báo giữ chỗ %qT"
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> can only be specified for functions"
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr "%<inline%> chỉ có thể được chỉ định cho hàm"
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> không sử dụng khi định nghĩa (như ngược với khai báo) một thành viên dữ liệu tĩnh"
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "chưa định nghĩa biến môi trường%qs"
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared %<constexpr%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "%qD chưa được khai báo %<constexpr%>"
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr ""
 
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "không thể dùng %<::%> trong khai báo đối số"
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr ""
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD không được khai báo như là tĩnh"
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a non-member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD phải là một hàm không-thành-viên"
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a non-member function"
 msgid "%qD must be a member function"
 msgstr "%qD phải là một hàm không-thành-viên"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, fuzzy, gcc-internal-format
 #| msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "định nghĩa namespaces lồng nhau chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr ""
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD cần chính các là một đối số"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfix %qD phải nhận %<int%> như là đối số của nó"
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfix %qD phải nhận %<int%> như là đối số thứ hai của nó"
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD cần chính các là một đối số"
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD không thể có đối số mặc định"
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "tiền tố %qD cần trả về %qT"
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "hậu tố %qD cần trả về %qT"
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD cần trả về bằng giá trị"
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT được coi là %qs"
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%q+T có một khai báo trước ở đây"
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT được coi là enum"
@@ -59715,118 +59719,101 @@ msgstr "%qT được coi là enum"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD in declaration of primary template"
 msgid "class template %qD redeclared as non-template"
 msgstr "template-id %qD trong khai báo của mẫu nguyên gốc"
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT không phải một mẫu"
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr ""
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare reference to %q#T"
-msgid "cannot declare %qD in a different module"
-msgstr "không thể khai báo tham chiếu đến %q#T"
-
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, gcc-internal-format
-msgid "previously declared here"
-msgstr "đã khai báo trước ở đây"
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT được định nghĩa với cơ sở đa trực tiếp"
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT được định nghĩa cơ sở trực tiếp ảo"
 
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.cc:16984
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare reference to %q#T"
-msgid "cannot declare %qD in different module"
-msgstr "không thể khai báo tham chiếu đến %q#T"
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "định nghĩa trước ở đây"
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "đối số %d của %qE phải là một địa chỉ"
@@ -59835,85 +59822,85 @@ msgstr "đối số %d của %qE phải là một địa chỉ"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, fuzzy, gcc-internal-format
 #| msgid "increment of enumeration value is invalid in C++"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "phép gia tăng giá trị kiểu liệt kê là không hợp lệ trong C++"
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "nhiều định nghĩa cho %q#T"
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "kiểu trả về %q#T là một kiểu không hoàn toàn"
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> cần trả về một tham chiếu đến %<*this%>"
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "%<return%> (trả lại) không có giá trị, trong hàm trả lại non-void (không rỗng)"
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD đã sẵn định nghĩa trong %qT"
 
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, fuzzy, gcc-internal-format
 #| msgid "using %<%c%s%>"
 msgid "using %qs"
 msgstr "đang dùng %<%c%s%>"
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -59968,7 +59955,7 @@ msgstr ""
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "cho khai báo hàm mẫu %q+D"
@@ -59978,7 +59965,7 @@ msgstr "cho khai báo hàm mẫu %q+D"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr ""
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -60167,64 +60154,64 @@ msgstr ""
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> nhận kiểu %qT như là đối số thứ nhất"
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr ""
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, gcc-internal-format
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, gcc-internal-format
 msgid "%qT has a base %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, gcc-internal-format
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, gcc-internal-format
 msgid "%qT has a base %qT which has internal linkage"
 msgstr ""
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, gcc-internal-format
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr "hàm chung dòng %qD được dùng nhưng chưa bao giờ được định nghĩa"
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but not defined"
 msgstr "hàm chung dòng %qD được dùng nhưng chưa bao giờ được định nghĩa"
@@ -60233,109 +60220,109 @@ msgstr "hàm chung dòng %qD được dùng nhưng chưa bao giờ được đ
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr "hàm chung dòng %qD được dùng nhưng chưa bao giờ được định nghĩa"
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with a previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q#D xung đột với khai báo trước"
 
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q#D"
 msgid "previous mangling %q#D"
 msgstr "khai báo trước đây %q#D"
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, gcc-internal-format
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "hàm chung dòng %qD được dùng nhưng chưa bao giờ được định nghĩa"
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q#D"
 msgstr ""
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, gcc-internal-format
 msgid "...following parameter %P which has a default argument"
 msgstr ""
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, fuzzy, gcc-internal-format
 #| msgid "class %qE is deprecated"
 msgid "implicitly-declared %qD is deprecated"
 msgstr "lớp %qE đã lạc hậu"
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, fuzzy, gcc-internal-format
 #| msgid "converting far pointer to near pointer"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "không thể chuyển đổi thành kiểu con trỏ"
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "dùng hàm bị xóa %qD"
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "lệnh không thỏa những ràng buộc của nó:"
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -60457,7 +60444,7 @@ msgstr ""
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qT không có thành viên nào mang tên %qE; ý bạn là %qE?"
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD không phải là thành viên của %qT"
@@ -60468,7 +60455,7 @@ msgstr "%qD không phải là thành viên của %qT"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qT không có thành viên nào mang tên %qE; ý bạn là %qE?"
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD không phải là thành viên của %qD"
@@ -60494,49 +60481,49 @@ msgstr ""
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr ""
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, gcc-internal-format
 msgid "  in thrown expression"
 msgstr "  nằm trong biểu thức thrown"
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, gcc-internal-format
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr ""
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, gcc-internal-format
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr ""
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, gcc-internal-format
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr ""
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, fuzzy, gcc-internal-format
 #| msgid "exception of type %<%T%> will be caught"
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr "ngoại lệ kiểu %<%T%> sẽ được bắt"
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, fuzzy, gcc-internal-format
 #| msgid " (operand type is %qT)"
 msgid "for type %qT"
 msgstr " (kiểu toán hạng là %qT)"
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, gcc-internal-format
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr ""
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr ""
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
 msgstr ""
@@ -60806,12 +60793,12 @@ msgstr ""
 msgid "type %qT is not a direct base of %qT"
 msgstr "kiểu %qT không là cơ sở trực tiếp của %qT"
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT không phải là kiểu lớp"
@@ -60826,12 +60813,12 @@ msgstr ""
 msgid "invalid pointer to bit-field %qD"
 msgstr "con trỏ cho trường bít %qD không hợp lệ"
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr ""
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr ""
@@ -61029,52 +61016,52 @@ msgstr ""
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr ""
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr ""
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr ""
@@ -61464,236 +61451,286 @@ msgstr "cần template-id cho kiểu"
 msgid "encapsulation is malformed"
 msgstr ""
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q+#D"
 msgid "conflicting global module declaration %#qD"
 msgstr "khai báo xung đột %q+#D"
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration %q+D"
 msgid "existing declaration %#qD"
 msgstr "trong khai báo %q+D"
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q+D"
 msgid "definition of %qD does not match"
 msgstr "định nghĩa lại của %q+D"
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, fuzzy, gcc-internal-format
 #| msgid "missing definition"
 msgid "existing definition %qD"
 msgstr "thiếu định nghĩa"
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, gcc-internal-format
 msgid "... this enumerator %qD"
 msgstr ""
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, fuzzy, gcc-internal-format
 msgid "enumerator %qD does not match ..."
 msgstr "quá nhiều đối số cho cho phương thức %qE"
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr ""
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr ""
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr ""
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, gcc-internal-format
 msgid "recursive lazy load"
 msgstr ""
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr ""
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, fuzzy, gcc-internal-format
 #| msgid "routine %qD declared here"
 msgid "module %qs declared here"
 msgstr "%qD được khai báo ở đây"
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, gcc-internal-format
 msgid "indirect import %qs is not already loaded"
 msgstr ""
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr ""
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr ""
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q#D"
 msgid "macro definitions of %qE corrupted"
 msgstr "  từ định nghĩa của %q#D"
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, gcc-internal-format
 msgid "inconsistent imported macro definition %qE"
 msgstr ""
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr ""
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr ""
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, gcc-internal-format
 msgid "compiled module file is %qs"
 msgstr ""
 
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collect2 version %s\n"
 msgid "compiled module is %sversion %s"
 msgstr "collect2 phiên bản %s\n"
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collect2 version %s\n"
 msgid "compiler is %sversion %s%s%s"
 msgstr "collect2 phiên bản %s\n"
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, fuzzy, gcc-internal-format
 #| msgid "no %qs getter found"
 msgid "module %qs found"
 msgstr "không tìm thấy getter %qs"
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr ""
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr ""
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr ""
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr ""
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, gcc-internal-format
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr ""
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, fuzzy, gcc-internal-format
 #| msgid "function attribute mismatch"
 msgid "fixed tree mismatch"
 msgstr "thuộc tính hàm không khớp"
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, fuzzy, gcc-internal-format
 #| msgid "dwarf version %d is not supported"
 msgid "interface partition is not exported"
 msgstr "dwarf phiên bản %d không được hỗ trợ"
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to rename %s to state file %s [%s]"
 msgid "failed to read compiled module cluster %u: %s"
 msgstr "gặp lỗi khi đổi tên %s thành tập tin thống kê %s [%s]"
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module: %s"
 msgstr "không tìm thấy lớp “%s”"
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr ""
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr ""
 
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr ""
 
-#: cp/module.cc:19283
+#: cp/module.cc:19117
+#, fuzzy, gcc-internal-format
+#| msgid "section type conflict with %D"
+msgid "declaration %qD conflicts with builtin"
+msgstr "kiểu phần xung đột với %D"
+
+#: cp/module.cc:19122
+#, gcc-internal-format
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr ""
+
+#: cp/module.cc:19125
+#, gcc-internal-format
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr ""
+
+#: cp/module.cc:19130
+#, gcc-internal-format
+msgid "import declared attached to module %qs"
+msgstr ""
+
+#: cp/module.cc:19134
+#, gcc-internal-format
+msgid "import declared in global module"
+msgstr ""
+
+#: cp/module.cc:19140
+#, fuzzy, gcc-internal-format
+#| msgid "conflicting declaration %q+#D"
+msgid "conflicting declaration of %qD in module %qs"
+msgstr "khai báo xung đột %q+#D"
+
+#: cp/module.cc:19143
+#, fuzzy, gcc-internal-format
+#| msgid "conflicting declaration %q+#D"
+msgid "conflicting declaration of %qD in global module"
+msgstr "khai báo xung đột %q+#D"
+
+#: cp/module.cc:19148
+#, fuzzy, gcc-internal-format
+#| msgid "previously declared here"
+msgid "previously declared in module %qs"
+msgstr "đã khai báo trước ở đây"
+
+#: cp/module.cc:19152
+#, fuzzy, gcc-internal-format
+#| msgid "previously declared here"
+msgid "previously declared in global module"
+msgstr "đã khai báo trước ở đây"
+
+#: cp/module.cc:19404
 #, fuzzy, gcc-internal-format
 #| msgid "Creating '%s'\n"
 msgid "reading CMI %qs"
 msgstr "Đang tạo “%s”\n"
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, gcc-internal-format
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, gcc-internal-format
 msgid "during load of pendings for %<%E%s%E%>"
 msgstr ""
@@ -61705,423 +61742,423 @@ msgstr ""
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr ""
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol %qs already declared"
 msgid "module already declared"
 msgstr "Ký hiệu %qs đã sẵn được khai báo"
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, fuzzy, gcc-internal-format
 #| msgid "module procedure"
 msgid "module already imported"
 msgstr "thủ tục mô-đun"
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, fuzzy, gcc-internal-format
 #| msgid "module procedure"
 msgid "module %qs imported here"
 msgstr "thủ tục mô-đun"
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown Compiled Module Interface: %s"
 msgstr ""
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr ""
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr ""
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr ""
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, gcc-internal-format
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr ""
 
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, fuzzy, gcc-internal-format
 #| msgid "Enable traditional preprocessing."
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr "Bật tiền xử lý theo kiểu cổ điển."
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr ""
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr ""
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, gcc-internal-format
 msgid "you should use the %<-%s%> option"
 msgstr ""
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param name %qs"
 msgid "invalid header name %qs"
 msgstr "sai tên cho tùy chọn --param %qs"
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param name %qs"
 msgid "invalid module name %qs"
 msgstr "sai tên cho tùy chọn --param %qs"
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr ""
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, fuzzy, gcc-internal-format
 #| msgid "error writing %qs"
 msgid "writing CMI %qs"
 msgstr "lỗi ghi %qs"
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing modules file: %s"
 msgid "not writing module %qs due to errors"
 msgstr "Gặp lỗi khi ghi tập tin môt-đun: %s"
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to write compiled module: %s"
 msgstr "không tìm thấy lớp “%s”"
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, fuzzy, gcc-internal-format
 #| msgid "unknown IRA region %qs"
 msgid "unknown header kind %qs"
 msgstr "không hiểu vùng IRA %qs"
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, fuzzy, gcc-internal-format
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "khai báo của %qD như là đối số"
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D xung đột với khai báo trước"
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, fuzzy, gcc-internal-format
 #| msgid "%d constructor found\n"
 #| msgid_plural "%d constructors found\n"
 msgid "%q#D hides constructor for %q#D"
 msgstr "Tìm thấy %d bộ cấu trúc\n"
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q+#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "khai báo xung đột %q+#D"
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr ""
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D previously declared here"
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "%q#D trước định nghĩa ở đây"
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr ""
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "sự khai báo của các bóng %qD như là thành viên của %qT"
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "sự khai báo lại %q+D khác trong %<constexpr%>"
 
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, gcc-internal-format
 msgid "exporting %q#D that does not have external linkage"
 msgstr ""
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D declared here"
 msgid "%q#D declared here with no linkage"
 msgstr "%q#D được khai báo ở đây"
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here, later in the translation unit"
 msgid "%q#D declared here with internal linkage"
 msgstr "%+D đã khai báo weakref sau khi được dùng"
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D declared here"
 msgid "%q#D declared here with module linkage"
 msgstr "%q#D được khai báo ở đây"
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names destructor"
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T::%D%> tên hủy tử"
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr ""
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, fuzzy, gcc-internal-format
 #| msgid "%<::%E%> is not a class, namespace, or enumeration"
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%<::%E%> không phải là một lớp, namespace, hay enumeration"
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr ""
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, gcc-internal-format
 msgid "using-declaration for member at non-class scope"
 msgstr ""
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "%qT is not a direct base of %qT"
 msgstr "kiểu %qT không là cơ sở trực tiếp của %qT"
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared in %qD"
 msgstr "%qD chưa được khai báo trong %qD"
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of namespace %qD here"
 msgid "using-declaration may not name namespace %qD"
 msgstr "khai báo trước đây của không gian tên %qD ở đây"
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> các tên cấu tử trong %qT"
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared within %qD"
 msgstr "%qD chưa được khai báo trong %qD"
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D được khai báo là friend"
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr ""
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "các khả năng được gợi ý:"
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr ""
 
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, fuzzy, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has already been defined"
 msgid "the macro %qs had not yet been defined"
 msgstr "%qD đã định nghĩa rồi"
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "it was later defined here"
 msgstr "struct được định nghĩa ở đây"
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fabi-version=1%> is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "%<-fabi-version=1%> không còn tiếp tục được hỗ trợ nữa"
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr "%<this%> có lẽ không nên được dùng trong ngữ cảnh này"
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L is ambiguous"
 msgid "%<namespace %E%> is ambiguous"
 msgstr "%qs tại %L phải là số nguyên"
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "nhãn %qD được định nghĩa ở đây"
 
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr ""
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous definition here"
 msgid "reachable %s definition here"
 msgstr "định nghĩa trước ở đây"
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX vào pop_everything ()\n"
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -62147,7 +62184,7 @@ msgstr ""
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -62399,7 +62436,7 @@ msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "%<concept%> chỉ sẵn sàng với -fconcepts"
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, fuzzy, gcc-internal-format
 #| msgid "%<requires%> only available with -fconcepts"
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
@@ -62582,7 +62619,7 @@ msgstr ""
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "cần biểu thức cơ bản"
@@ -62639,7 +62676,7 @@ msgstr "%<~auto%> chỉ sẵn sàng trên -std=c++14 hay -std=gnu++14"
 msgid "template-id not allowed for destructor in C++20"
 msgstr ""
 
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, gcc-internal-format
 msgid "remove the %qs"
 msgstr ""
@@ -62659,7 +62696,7 @@ msgstr ""
 msgid "expected unqualified-id"
 msgstr "cần unqualified-id"
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD không phải một mẫu"
@@ -62710,7 +62747,7 @@ msgstr ""
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "sai số tham số cho %<__builtin_addressof%>"
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "đối số sai số lượng cho %<__builtin_launder%>"
@@ -62748,7 +62785,7 @@ msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiể
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr ""
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "dùng %qD không hợp lệ"
@@ -62773,7 +62810,7 @@ msgstr "ISO C++ không cho phép %<alignof%> với một non-type"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in casts"
 msgid "types may not be defined in %qs expressions"
@@ -62936,8 +62973,8 @@ msgstr ""
 msgid "capture of non-variable %qE"
 msgstr "trùng biến minh dụ %q+D"
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D được khai báo ở đây"
@@ -62979,7 +63016,7 @@ msgstr ""
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr ""
@@ -63108,7 +63145,7 @@ msgstr "%<#pragma omp cancel%> chỉ có thể sử dụng trong các biểu th
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "định nghĩa namespaces lồng nhau chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "cần selection-statement"
@@ -63174,7 +63211,7 @@ msgstr ""
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "cần iteration-statement"
@@ -63201,7 +63238,7 @@ msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ cấm tính toán gotos"
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "cần jump-statement"
@@ -63501,12 +63538,12 @@ msgstr ""
 msgid "cannot expand initializer for member %qD"
 msgstr "thiếu bộ khởi tạo cho thành viên %qD"
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
@@ -64171,7 +64208,7 @@ msgstr "thiếu đối số mẫu sau %qT"
 msgid "%qT not permitted in template argument"
 msgstr "các kiểu không nên được định nghĩa trong đối số mẫu"
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, gcc-internal-format
 msgid "invalid use of %qT"
@@ -64354,12 +64391,12 @@ msgstr "khai báo trước đây của %q+#T"
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, gcc-internal-format
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr ""
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "cần class-key"
@@ -64570,39 +64607,39 @@ msgstr "mẫu biến chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 msgid "expression must be enclosed in parentheses"
 msgstr "chỉ số phải là số nguyên"
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr ""
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "result type is not a plain type-constraint"
 msgstr "đối số %qd không phải hằng số"
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "return-type-requirement is not a type-constraint"
 msgstr "yếu tố khởi tạo không phải hằng số"
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "khai báo không hợp lệ của %<%T::%E%>"
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -64611,450 +64648,450 @@ msgstr ""
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, gcc-internal-format
 msgid "template-id not allowed for constructor in C++20"
 msgstr ""
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr ""
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr ""
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "đặc tả rõ ràng không hợp lệ"
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in template arguments"
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr "các kiểu không nên được định nghĩa trong đối số mẫu"
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "đối số cho %<sizeof…%> phải được bao quanh bởi dấu ngoặc đơn"
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate virt-specifier"
 msgid "duplicate %qD specifier"
 msgstr "trùng virt-specifier"
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, fuzzy, gcc-internal-format
 #| msgid "section type conflict with %D"
 msgid "%qD specifier conflicts with %qs"
 msgstr "kiểu phần xung đột với %D"
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> trước %qD"
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<typedef%>"
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr "%qE được dùng với %<typedef%>"
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr ""
 
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "đã chỉ ra cả hai %<__thread%> và %<thread_local%>"
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "trùng %qD"
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "trùng %qs"
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "cần %<new%>"
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "cần %<delete%>"
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "cần %<return%>"
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "cần %<extern%>"
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "cần %<static_assert%>"
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "cần %<decltype%>"
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "cần %<operator%>"
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "cần %<class%>"
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "cần %<template%>"
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "cần %<namespace%>"
 
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "cần %<using%>"
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "cần %<asm%>"
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "cần %<try%>"
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "cần %<catch%>"
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "cần %<throw%>"
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<data%>"
 msgid "expected %<auto%>"
 msgstr "cần %<data%>"
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "cần %<__label__%>"
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "cần %<@try%>"
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "cần %<@synchronized%>"
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "cần %<@throw%>"
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "cần %<__transaction_atomic%>"
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "cần %<__transaction_relaxed%>"
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "cần %<@end%>"
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "cần %<::%>"
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "cần %<…%>"
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "cần %<*%>"
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "cần %<~%>"
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "cần %<:%> hoặc %<::%>"
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T trước đã khai báo ở đây"
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr ""
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, fuzzy, gcc-internal-format
 #| msgid "expected class-key"
 msgid "replace the class-key with %qs"
 msgstr "cần class-key"
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qT defined as %qs here"
 msgstr "nhãn %qD được định nghĩa ở đây"
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared here"
 msgid "%qT first declared as %qs here"
 msgstr "%qT được khai báo ở đây"
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "kiểu không hợp lệ cho biến instance (minh dụ)"
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "kiểu không hợp lệ cho thuộc tính"
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, fuzzy, gcc-internal-format
 #| msgid "unknown property attribute"
 msgid "unknown property attribute %qE"
 msgstr "không hiểu thuộc tính tính chất"
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "cần biểu thức nguyên"
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "biểu thức %<wait%> phải là số nguyên"
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "bộ khởi tạo sai"
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in casts"
 msgid "types may not be defined in iterator type"
@@ -65064,13 +65101,13 @@ msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiể
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma vtable no longer supported"
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "#pragma vtable không còn được hỗ trợ nữa"
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
@@ -65080,140 +65117,140 @@ msgstr ""
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma omp section%> chỉ có thể sử dụng trong cấu trúc %<#pragma omp sections%>"
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr ""
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "mệnh đề khởi tạo không hợp lệ"
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "cần id-expression (các đối số)"
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, fuzzy, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "%<#pragma omp declare reduction%> trước"
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD không phải là hàm thành viên mẫu"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "vòng ngoài hơn %<__transaction_cancel%> không nằm trong vòng ngoài hơn %<__transaction_atomic%>"
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  hoặc một hàm %<transaction_may_cancel_outer%>"
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "%<#pragma GCC pch_preprocess%> phải là đầu tiên"
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp flush%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma grainsize%> must be inside a function"
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr "%<#pragma grainsize%> phải ở bên trong một hàm"
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not implemented for -fPIC"
 msgid "multi-source compilation not implemented for C++"
 msgstr "-mnop-mcount không được thực hiện cho -fPIC"
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "%<this%> có lẽ không nên được dùng trong ngữ cảnh này"
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "các mẫu ngầm không nên là %<virtual%>"
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -65243,7 +65280,7 @@ msgstr ""
 msgid "specialization of %qD must appear at namespace scope"
 msgstr ""
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr ""
@@ -65258,27 +65295,27 @@ msgstr "  từ định nghĩa của %q#D"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr ""
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr ""
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr ""
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr ""
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr ""
 
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q#D"
 msgid "from definition of %q#D"
@@ -65286,149 +65323,149 @@ msgstr "  từ định nghĩa của %q#D"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr ""
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr ""
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, fuzzy, gcc-internal-format
 #| msgid "%s %#D"
 msgid "%s %#qD"
 msgstr "%s %#D"
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD không phải là một mẫu hàm"
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD không phải là một biến"
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "template-id %qD cho %q+D không khớp bất kỳ khai báo mẫu nào"
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr ""
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr ""
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, fuzzy, gcc-internal-format
 #| msgid "variable templates only available with -std=c++14 or -std=gnu++14"
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "mẫu biến chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "too many template headers for %qD (should be %d)"
 msgstr "sai số lượng đối số hàm mẫu (%d, phải là %d)"
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr ""
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr ""
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing template arguments after %qT"
 msgid "missing primary template attributes %s"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing template arguments after %qT"
 msgid "missing primary template attribute %s"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD in declaration of primary template"
 msgid "template-id %qE in declaration of primary template"
 msgstr "template-id %qD trong khai báo của mẫu nguyên gốc"
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr ""
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr ""
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr ""
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr ""
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
 msgstr ""
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr ""
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr ""
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD không phải là một hàm mẫu"
@@ -65441,156 +65478,156 @@ msgstr "%qD không phải là một hàm mẫu"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr ""
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr ""
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr ""
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "khai báo trước ở đây"
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
 msgstr ""
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, fuzzy, gcc-internal-format
 #| msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "cả hai đối số cho %<__builtin___clear_cache%> phải là các con trỏ"
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr ""
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "          %s"
 msgid "        %s"
 msgstr "          %s"
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr ""
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr ""
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr ""
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr ""
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "mẫu nguyên gốc ở đây"
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "quá nhiều đối số cho hàm %qE"
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "mẫu nguyên gốc ở đây"
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] ""
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr ""
@@ -65599,47 +65636,47 @@ msgstr ""
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr ""
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -65649,519 +65686,519 @@ msgstr ""
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "phần khai báo mẫu của %qD không hợp lệ"
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr ""
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "nhận được %d đối số mẫu cho %q#D"
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "nhận được %d đối số mẫu cho %q#T"
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  nhưng cần %d"
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, fuzzy, gcc-internal-format
 #| msgid "invalid explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "đặc tả rõ ràng không hợp lệ"
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of typedef %q+D with different type"
 msgid "redeclaration of %qD with different constraints"
 msgstr "định nghĩa lại của typedef %q+D với kiểu khác"
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT không phải là một kiểu mẫu"
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] ""
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] ""
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "đối số mẫu %q+#D"
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "khai báo lại ở đây như là %q#D"
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "redeclared here"
 msgstr "được khai báo ở đây"
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of typedef %q+D with different type"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "định nghĩa lại của typedef %q+D với kiểu khác"
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr ""
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of typedef %q+D with different type"
 msgid "redeclaration of %q#D with different constraints"
 msgstr "định nghĩa lại của typedef %q+D với kiểu khác"
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD không phải là thành viên của %qT"
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "nhận được %d đối số mẫu cho %q#D"
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  kiểu không khớp %qT và %qT"
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE không tương đương với %qE"
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  không thể chuyển đổi %qE (kiểu %qT) thành kiểu %qT"
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT là lớp cơ sở chưa rõ ràng của %qT"
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT không được dẫn xuất từ %qT"
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "không thể giải mã địa chỉ"
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "quá nhiều đối số cho cho phương thức %qE"
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr ""
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, fuzzy, gcc-internal-format
 #| msgid "  member function type %qT is not a valid template argument"
 msgid "the address of %qD is not a valid template argument"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, fuzzy, gcc-internal-format
 #| msgid "  member function type %qT is not a valid template argument"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, fuzzy, gcc-internal-format
 #| msgid "missing template arguments after %qT"
 msgid "in template argument for type %qT"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "quá nhiều đối số cho cho phương thức %qE"
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "dùng %qE để thay thế"
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu"
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  cần hằng của kiểu %qT, nhưng lại nhận được %qT"
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr ""
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  cần mẫu lớp, nhưng lại nhận được %qE"
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  cần kiểu, nhưng lại nhận %qE"
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  cần một kiểu, nhưng lại nhận được %qT"
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  cần mẫu lớp, nhưng lại nhận được %qT"
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  cần mẫu kiểu %qD, nhưng lại nhận được %qT"
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  cần %qD nhưng lại nhận %qD"
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "không thể chuyển đổi %qE từ %qT thành %qT"
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "sai số lượng đối số hàm mẫu (%d, phải là %d)"
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "sai số lượng đối số mẫu (%d, cần ít nhất phải là %d)"
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "được cung cấp cho %qD"
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D không phải là hàm mẫu"
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "cho khai báo hàm mẫu %q+D"
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, fuzzy, gcc-internal-format
 #| msgid "template constraint failure"
 msgid "template constraint failure for %qD"
 msgstr "ràng buộc mẫu gặp lỗi nghiêm trọng"
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qD không phải là một biến"
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, fuzzy, gcc-internal-format
 #| msgid "ordered argument needs positive constant integer expression"
 msgid "score argument must be constant integer expression"
 msgstr "cần biểu thức nguyên"
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L must be nonnegative"
 msgid "score argument must be non-negative"
 msgstr "%s tại %L phải là số nguyên"
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr ""
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "cấu có không thành viên đã đặt tên"
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE không ở đầu của khai báo"
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
 msgstr "định nghĩa lại của đối số mặc định của %q#D"
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "mismatched arguments"
 msgid "mismatched argument pack lengths (%d vs %d)"
@@ -66180,309 +66217,309 @@ msgstr "các đối số không tương ứng với nhau"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "biến %qD có kiểu hàm"
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "kiểu đối số không hợp lệ %qT"
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "trong khai báo %q+D"
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "hàm trả về một mảng"
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "hàm trả về hàm"
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "đang tạo con trỏ đến thành viên của kiểu void"
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "đang tạo mảng của %qT"
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT không phải có kiểu lớp, cấu trúc hay union"
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT không phải là kiểu lớp"
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "dùng %qs trong mẫu"
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "yếu tố khởi tạo không phải là một biểu tượng hằng số"
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "dùng %<this->%D%> thay thế"
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "dùng %<%T::%D%> thay thế"
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%+D đã khai báo weakref sau khi được dùng"
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_choose_expr%>"
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "sai số lượng đối số cho %<__builtin_choose_expr%>"
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_complex%>"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "đối số sai số lượng cho %<__builtin_complex%>"
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT không phải là một lớp hay namespace"
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD không phải là một lớp hay namespace"
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "đang dùng trường không hợp lệ %qD"
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT là/dùng kiểu nặc danh"
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "biểu thức nguyên %qE không là hằng"
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 #, fuzzy
 #| msgid "%s %#S"
 msgid "%s %#qS"
 msgstr "%s %#D"
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate instance variable %q+D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "trùng biến minh dụ %q+D"
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, fuzzy, gcc-internal-format
 #| msgid "implicit declaration of function %qE"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "khai báo ngầm của hàm %qE"
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD không phải là một thành viên dữ liệu tĩnh của một mẫu lớp"
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, fuzzy, gcc-internal-format
 #| msgid "previous specification in %q#D here"
 msgid "exception specification of %qD depends on itself"
@@ -66495,168 +66532,168 @@ msgstr "sau đặc tả trước đây trong %q#D"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr ""
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr ""
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, fuzzy, gcc-internal-format
 #| msgid "a concept cannot be a member function"
 msgid "a concept cannot be constrained"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace or unscoped enum"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT không phải là một namespace hay enum không hoạt vi"
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, gcc-internal-format
 msgid "concept %qE has multiple template parameter lists"
 msgstr ""
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, fuzzy, gcc-internal-format
 #| msgid "non-class template %qT used without template arguments"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "mẫu không phải lớp %qT được dùng mà không có đỗi số mẫu"
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "use %qD directly instead"
 msgstr "sử dụng #include để thay thế"
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo hợp"
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "hàm không phải được tính để chèn vào trực tiếp"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo hợp"
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "hàm chung dòng %q+D được khai báo yếu"
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr ""
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in template argument"
 msgid "invalid use of %qT in template argument"
@@ -66871,660 +66908,660 @@ msgstr ""
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr ""
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr ""
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of constructor as a template"
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr "dùng cấu tử như là một mẫu là không hợp lệ"
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of constructor as a template"
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr "dùng cấu tử như là một mẫu là không hợp lệ"
 
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, fuzzy, gcc-internal-format
 #| msgid "missing template arguments after %qT"
 msgid "%qE missing template arguments"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "cannot call a concept as a function"
 msgstr "%qE không thể dùng như một hàm"
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr ""
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, gcc-internal-format
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr ""
 
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, gcc-internal-format
 msgid "use explicit object parameter %qs instead"
 msgstr ""
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, gcc-internal-format
 msgid "name the explicit object parameter"
 msgstr ""
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr ""
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<...%> with non-slice"
 msgid "invalid use of %<this%> before it is valid"
 msgstr "dùng %<…%> mà không có non-slice là không hợp lệ"
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<...%> with non-slice"
 msgid "invalid use of %<this%> after it is valid"
 msgstr "dùng %<…%> mà không có non-slice là không hợp lệ"
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr ""
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr ""
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE không là kiểu %qT"
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "%<auto{x}%> cannot be constrained"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, fuzzy, gcc-internal-format
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<~auto%> chỉ sẵn sàng trên -std=c++14 hay -std=gnu++14"
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr ""
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "định nghĩa không hợp lệ của kiểu hạn định %qT"
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "đặc tả lớp-cơ-sở không hợp lệ"
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "không thể chụp thành viên %qD trong hỗn hợp nặc danh"
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD không bị bắt"
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, fuzzy, gcc-internal-format
 #| msgid "use of deleted function %qD"
 msgid "use of parameter outside function body"
 msgstr "dùng hàm bị xóa %qD"
 
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, fuzzy, gcc-internal-format
 #| msgid "missing template arguments after %qT"
 msgid "missing template arguments"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "không hiểu kiểu của %qE"
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT không phải một kiểu enumeration"
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, fuzzy, gcc-internal-format
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr ""
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is out of range"
 msgstr ""
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, fuzzy, gcc-internal-format
 #| msgid "a concept cannot be a member function"
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, fuzzy, gcc-internal-format
 #| msgid "constructor priorities are not supported"
 msgid "pointer-to-member mapping %qE not supported"
 msgstr "các quyền ưu tiên cấu tử là không được hỗ trợ"
 
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, gcc-internal-format
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr ""
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "biểu thức bước thẳng phải là số nguyên"
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD không phải một biến trong mệnh đề %<lastprivate%>"
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "biểu thức tĩnh %<gang%> phải nguyên"
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, fuzzy, gcc-internal-format
 #| msgid "%<gang%> static value must bepositive"
 msgid "%<gang%> static value must be positive"
 msgstr "giá trị tĩnh %<gang%> phải dương"
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "biểu thức số %<gang%> phải nguyên"
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "chiều dài %<vector%> phải là số nguyên"
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "biểu thức số %<worker%> phải là số nguyên"
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<gang%> giá trị phải dương"
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, fuzzy, gcc-internal-format
 #| msgid "%<vector%> length value must bepositive"
 msgid "%<vector%> length value must be positive"
 msgstr "chiều dài %<vector%> giá trị phải dương"
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, fuzzy, gcc-internal-format
 #| msgid "%<worker%> num value must bepositive"
 msgid "%<worker%> num value must be positive"
 msgstr "%<worker%> giá trị phải dương"
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%> biểu thức phải nguyên"
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%> biểu thức phải nguyên"
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD không phải một biến trong mệnh đề  %<aligned%>"
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in %<depend%> clause"
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD không phải một biến trong mệnh đề %<depend%>"
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not an argument in %<uniform%> clause"
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD không phải một đối số trong mệnh đề %<uniform%>"
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in %<aligned%> clause"
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%qE không phải một biến trong mệnh đề %<aligned%>"
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in %<aligned%> clause"
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD không phải một biến trong mệnh đề  %<aligned%>"
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in %<aligned%> clause"
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD không phải một biến trong mệnh đề  %<aligned%>"
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in %qs clause"
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, fuzzy, gcc-internal-format
 #| msgid "%<wait%> expression must be integral"
 msgid "%<hint%> expression must be integral"
 msgstr "biểu thức %<wait%> phải là số nguyên"
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, fuzzy, gcc-internal-format
 #| msgid "%<wait%> expression must be integral"
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "biểu thức %<wait%> phải là số nguyên"
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, fuzzy, gcc-internal-format
 #| msgid "%<wait%> expression must be integral"
 msgid "%<filter%> expression must be integral"
 msgstr "biểu thức %<wait%> phải là số nguyên"
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, fuzzy, gcc-internal-format
 #| msgid "target is not pointer or reference to complete type"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "đích không phải là hàm trỏ hoặc tham chiếu đến loại hoàn toàn"
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, fuzzy, gcc-internal-format
 #| msgid "%<tile%> value must be integral"
 msgid "%<tile%> argument needs integral type"
 msgstr "giá trị %<tile%> phải là số nguyên"
 
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr ""
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr ""
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr ""
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr ""
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %s"
 msgid "static assertion failed: %.*s"
 msgstr "thẩm tra tĩnh gặp lỗi: %s"
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, fuzzy, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "<chưa giải quyết loại hàm quá tải>"
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr ""
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr ""
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr "%<__builtin_next_arg%> được gọi mà không có đối số"
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a class template"
 msgid "%qD is not a class or alias template"
 msgstr "%qE không phải một lớp mẫu"
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "đối số không được hỗ trợ cho %<__builtin_return_address%>"
@@ -67532,1214 +67569,1214 @@ msgstr "đối số không được hỗ trợ cho %<__builtin_return_address%>"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr ""
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "statement-expression in a constant expression"
 msgstr "Gặp biểu thức lambda trong biểu thức bất biến"
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, fuzzy, gcc-internal-format
 #| msgid "  declared here"
 msgid " declared here"
 msgstr "  đã được khai báo ở đây"
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, fuzzy, gcc-internal-format
 #| msgid "  base class %qT of %q+T is non-literal"
 msgid "base class %qT is not public"
 msgstr "  lớp cơ sở %qT của %q+T là non-literal"
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not captured"
 msgid "%qD is not public"
 msgstr "%qD không bị bắt"
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is mutable"
 msgstr "%qD không phải là một biến"
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD has a non-structural type"
 msgstr "%qD không phải là một kiểu"
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "đối số thuộc tính phần không phải là một hằng chuỗi"
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, fuzzy, gcc-internal-format
 #| msgid "%<typeof%> applied to a bit-field"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "%<typeof%> được áp dụng cho một bit-field"
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, fuzzy, gcc-internal-format
 #| msgid "the %qE attribute requires arguments"
 msgid "%qE attribute takes no arguments"
 msgstr "thuộc tính %qE cần tham số"
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute doesn't apply to functions"
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "Thuộc tính %qE không được áp dụng cho các hàm"
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, fuzzy, gcc-internal-format
 #| msgid "array index in initializer is not an integer constant expression"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "bộ khởi tạo chứa một chỉ mục mảng không phải là một biểu tượng hằng số nguyên"
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr ""
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, gcc-internal-format
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr ""
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "sự khai báo của %qD như là thành viên của %qT"
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "thuộc tính %qE cần tham số"
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr ""
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr ""
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr ""
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr ""
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr ""
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr ""
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr ""
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, fuzzy, gcc-internal-format
 #| msgid "Warn if a comparison always evaluates to true or false."
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr "Cảnh báo khi so sánh luôn ước lượng là đúng hoặc là sai."
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, fuzzy, gcc-internal-format
 #| msgid "lang_* check: failed in %s, at %s:%d"
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "lang_* check: gặp lỗi trong %s, tại %s:%d"
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr ""
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr ""
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "các toán hạng ?: có kiểu khác %qT và %qT"
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "các toán hạng ?: có kiểu khác %qT và %qT"
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr ""
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr ""
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr ""
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 has invalid type"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "đối số 2 có kiểu không hợp lệ"
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "ISO C++ cấm chuyển đổi hằng chuỗi thành %qT"
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "việc chuyển đổi từ chuỗi thành %qT đã lỗi thời"
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr ""
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of constructor as a template"
 msgid "invalid use of non-static data member %qE"
 msgstr "dùng cấu tử như là một mẫu là không hợp lệ"
 
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr ""
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr ""
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%q#T không có thành viên nào mang tên %qE"
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has no member named %qE; did you mean %qE?"
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%q#T không có thành viên nào mang tên %qE; ý bạn là %qE?"
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has no member named %qE; did you mean %qE?"
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%q#T không có thành viên nào mang tên %qE; ý bạn là %qE?"
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%q#T không có thành viên nào mang tên %qE; ý bạn là %qE?"
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> không phải là thành viên của %qT"
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT không là cơ sở của %qT"
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD không phải là hàm thành viên mẫu"
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT không phải kiểu con trỏ đến đối tượng"
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr ""
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr ""
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr ""
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr ""
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr ""
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr ""
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr ""
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ cấm gọi %<::main%> từ bên trong chương trình"
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr ""
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE không thể dùng như một hàm"
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qD không thể được dùng như một hàm"
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "biểu thức không thể được dùng như một hàm"
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "quá nhiều đối số cho cấu tử %q#D"
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "quá ít đối số cho hủy tử %q#D"
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "quá nhiều đối số cho hàm thành viên %q#D"
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "quá ít đối số cho hàm thành viên %q#D"
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "quá nhiều đối số cho hàm %q#D"
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "quá ít đối số cho hàm %q#D"
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "quá nhiều đối số cho phương thức %q#D"
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "quá ít đối số cho phương thức %q#D"
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "quá nhiều đối số cho hàm"
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "quá ít đối số cho hàm"
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will never be NULL"
 msgid "the address %qE will never be NULL"
 msgstr "địa chỉ của %qD sẽ không bao giờ là NULL"
 
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "địa chỉ của %qD sẽ không bao giờ là NULL"
 
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, fuzzy, gcc-internal-format
 #| msgid "the compiler can assume that the address of %qD will never be NULL"
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr "trình biên dịch sẽ coi rằng địa chỉ của %qD sẽ không bao giờ là NULL"
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr ""
 
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "trình biên dịch sẽ coi rằng địa chỉ của %qD sẽ không bao giờ là NULL"
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr "các toán hạng ?: có kiểu khác %qT và %qT"
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types %qT and %qT"
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr "các toán hạng ?: có kiểu khác %qT và %qT"
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr ""
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "NULL được dùng trong số học"
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr ""
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "các kiểu toán hạng là %qT và %qT"
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr ""
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, fuzzy, gcc-internal-format
 #| msgid "Unrecognized option to floating-point init value: %qs"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "Không nhận ra tùy chọn để khởi tạo giá trị dấu chấm động: %qs"
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr ""
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr ""
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr ""
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr ""
 
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr ""
 
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr ""
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of constructor %qE"
 msgid "taking address of constructor %qD"
 msgstr "lấy địa chỉ của cấu tử %qE"
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of destructor %qD"
 msgstr "lấy địa chỉ của hủy tử %qE"
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  cần qualified-id"
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr ""
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr ""
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr ""
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr ""
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, gcc-internal-format
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "đang lấy địa chỉ của mẫu"
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr ""
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr ""
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field"
 msgstr "không thể lấy địa chỉ của %qs"
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, fuzzy, gcc-internal-format
 #| msgid "%<~%> on a boolean expression"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "%<~%> trên một biểu thức lôgíc"
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr ""
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr ""
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr ""
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr ""
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr ""
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr ""
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr ""
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr ""
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr ""
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr ""
 
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr ""
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr ""
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr ""
 
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, fuzzy, gcc-internal-format
 #| msgid "useless cast to type %qT"
 msgid "useless cast to type %q#T"
 msgstr "trừ phi ép thành kiểu %qT"
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, fuzzy, gcc-internal-format
 #| msgid "%E qualifier ignored on asm"
 msgid "type qualifiers ignored on cast result type"
 msgstr "từ hạn định %E bị bỏ qua trên asm"
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "kiểu lớp %qT chưa hoàn thiện"
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "đang chuyển đổi từ %qT thành %qT"
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "áp đổi kiểu tử %qT thành %qT làm mất độ chính xác"
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "áp đổi kiểu tử %qT thành %qT yêu cầu tăng cân chỉnh của kiểu đích"
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr ""
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr ""
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr ""
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, gcc-internal-format
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr ""
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ cấm việc áp đổi kiểu của mảng %qT"
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr ""
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, gcc-internal-format
 msgid "moving %qE of type %qT to itself"
 msgstr ""
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  trong định giá %<%Q(%#T, %#T)%>"
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "gán giá trị cho mảng từ một danh sách bộ khởi tạo"
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "phép gán %qT cho %qT không tương thích kiểu"
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "mảng được dùng như là bộ khởi tạo"
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "gán mảng không hợp lệ"
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr ""
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr ""
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr ""
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr ""
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 #, fuzzy
 #| msgid "%qD cannot have default arguments"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "%qD không thể có đối số mặc định"
 
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI in return"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "trong đối số chuyển qua %P của %qD"
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "trả về tham chiếu đến tạm thời (temporary)"
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "returning pointer to temporary"
 msgstr "trả về tham chiếu đến tạm thời (temporary)"
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "tham chiếu đến biến cục bộ %qD được trả về"
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "địa chỉ của nhãn %qD được trả về"
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "địa chỉ của biến cục bộ %q+D được trả về"
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, fuzzy, gcc-internal-format
 #| msgid "too many values in return statement"
 msgid "redundant move in return statement"
 msgstr "quá nhiều giá trị trong lệnh trả về"
 
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, fuzzy, gcc-internal-format
 #| msgid "<During initialization>\n"
 msgid "redundant move in initialization"
 msgstr "<Khi khởi tạo>\n"
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "trả về một giá trị từ hủy tử"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "trả về một giá trị từ cấu tử"
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "trả về danh sách bộ khởi tạo"
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with a value, in function returning 'void'"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "biểu thức trả về với một giá trị, trong hàm trả lại “void”"
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr ""
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, gcc-internal-format
 msgid "not eliding copy on return from %qD"
 msgstr ""
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr ""
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, fuzzy, gcc-internal-format
 #| msgid "using temporary as lvalue"
 msgid "using rvalue as lvalue"
@@ -68965,162 +69002,162 @@ msgstr ""
 msgid "insufficient contextual information to determine type"
 msgstr ""
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, fuzzy, gcc-internal-format
 #| msgid "Function %qs at %L cannot have an initializer"
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr ""
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "chuyển đổi từ %qT thành %qT không hợp lệ"
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr ""
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %q#D is invalid"
 msgid "initializer-string for %qT is too long"
 msgstr "bộ khởi tạo cho %q#D không hợp lệ"
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "ngoặc chung quanh bộ khởi tạo vô hướng"
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "thiếu bộ khởi tạo cho thành viên %qD"
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "toán hạng cơ sở của %<->%> không phải là một con trỏ"
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr ""
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, fuzzy, gcc-internal-format
 #| msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "%<~auto%> chỉ sẵn sàng trên -std=c++14 hay -std=gnu++14"
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -70147,7 +70184,7 @@ msgstr "Danh sách tên “%s” không thể là đối số tại %L"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là hằng"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr ""
@@ -71490,7 +71527,7 @@ msgstr ""
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -71708,7 +71745,7 @@ msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là vô hướn
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "Thành phần “%qs” tại %C đã sẵn được khai báo tại %L"
@@ -72525,7 +72562,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
@@ -73341,12 +73378,12 @@ msgstr ""
 msgid "are_identical_variables: Bad type"
 msgstr ""
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr ""
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr ""
@@ -73600,276 +73637,276 @@ msgstr ""
 msgid "check_init_expr(): Unknown expression type"
 msgstr ""
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr ""
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, gcc-internal-format
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr ""
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, gcc-internal-format
 msgid "Specification function %qs at %L must be PURE"
 msgstr ""
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, fuzzy, gcc-internal-format
 #| msgid "Function %qs at %L must be PURE"
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr "Hàm %qs tại %L phải là PURE"
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, gcc-internal-format
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr ""
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr ""
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr ""
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, gcc-internal-format
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr "Biến %qs không thể xuất hiện trong biểu thức tại %L"
 
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, gcc-internal-format
 msgid "check_restricted(): Unknown expression type"
 msgstr "check_restricted(): không hiểu kiểu biểu thức"
 
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, gcc-internal-format
 msgid "Function %qs at %L must be PURE"
 msgstr "Hàm %qs tại %L phải là PURE"
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr "Biểu thức tại %L phải thuộc kiểu scalar"
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr ""
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr "Vùng không tương thích nhau trong %s (%d và %d) tại %L"
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr ""
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr ""
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal assignment to external procedure at %L"
 msgstr ""
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr ""
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr ""
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr ""
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr ""
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument %qs at %L"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Cần một thủ tục cho đối số %qs tại %L"
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "an assignment cannot appear in a constant-expression"
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr "phép gán không thể được xuất hiện trong biểu thức hằng"
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
@@ -73877,197 +73914,197 @@ msgstr ""
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr ""
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr ""
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr ""
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure %qs is used as actual argument at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Thủ tục nội tại %qs được dùng làm đối số thật tại %L"
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, fuzzy, gcc-internal-format
 #| msgid "Error in pointer initialization at %C"
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "Lỗi trong khởi tạo con trỏ tại %C"
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, gcc-internal-format
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "Biến %qs không thể xuất hiện trong biểu thức tại %L"
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "Biến %qs không thể xuất hiện trong biểu thức tại %L"
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs cannot appear in the expression at %L"
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Biến %qs không thể xuất hiện trong biểu thức tại %L"
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, gcc-internal-format
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr ""
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -74088,8 +74125,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "Đang tạo mảng tạm tại %L"
@@ -74172,7 +74209,7 @@ msgstr ""
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -74312,12 +74349,12 @@ msgstr ""
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -75201,7 +75238,7 @@ msgstr "Chuyển đổi từ %s sang %s tại %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
@@ -75781,7 +75818,7 @@ msgstr ""
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -75952,6 +75989,11 @@ msgstr "Tràn số nguyên"
 msgid "check_charlen_present(): length not set"
 msgstr ""
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr ""
+
 #: fortran/match.cc:118
 #, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
@@ -76362,7 +76404,7 @@ msgstr ""
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr ""
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
@@ -76902,85 +76944,85 @@ msgstr ""
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C"
 msgid "SELECT RANK statement at %C"
 msgstr "câu lệnh ENTRY tại %C"
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Không cần câu lệnh CASE tại %C"
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr ""
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr ""
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr ""
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected RANK statement at %C"
 msgstr "Không cần câu lệnh END tại %C"
 
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr ""
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in expression at %C"
 msgid "Syntax error in RANK specification at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -78461,8 +78503,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
@@ -80861,12 +80903,12 @@ msgstr ""
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -80987,7 +81029,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "%qE không phải tên một kiểu"
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -81392,282 +81434,288 @@ msgstr ""
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_variable_attr(): Bad array reference"
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr "gfc_variable_attr(): Tham chiếu mảng sai"
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%qs đã lạc hậu"
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Invalid character in name at %C"
+msgid "Invalid array reference at %L"
+msgstr "Tên có chứa ký tự không hợp lệ tại %C"
+
+#: fortran/resolve.cc:6433
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Error in type-spec at %L"
 msgid "Error in typebound call at %L"
 msgstr "Sai trong type-spec tại %L"
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs tại %L phải là THỦ TỤC CON"
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs tại %L phải là HÀM"
 
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): sai kiểu biểu thức"
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s tại %L phải là một scalar"
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s tại %L phải là số nguyên"
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s tại %L phải là SỐ-NGUYÊN"
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, fuzzy, gcc-internal-format
 #| msgid "Expected %<,%> or end of statement at %C"
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "cần %<,%> hoặc kết thúc câu lệnh tại %C"
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -81676,285 +81724,285 @@ msgstr ""
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr ""
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "Danh sách tên “%s” không thể là đối số tại %L"
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr ""
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter %u has void type"
 msgid "Selector at %L has no type"
 msgstr "tham số %u có kiểu void"
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Gặp kiểu hạn chế không cần %qs tại %L"
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ngữ cảnh sai cho hạn chế NULL() tại %L"
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Tham số %qs của thủ tục cơ bản tại %L phải là vô hướng"
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -81962,216 +82010,216 @@ msgstr ""
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BLOCK construct at %C"
 msgid "FORALL construct at %L"
 msgstr "cấu trúc BLOCK tại %C"
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Kiểu khối sai"
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr ""
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, gcc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr ""
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be a scalar"
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là tuyến tính"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr ""
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "NULL không hợp lệ %L"
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Không có biểu thức trên DO WHILE"
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Mã câu lệnh sai"
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, fuzzy, gcc-internal-format
 #| msgid "Unused parameter %qs declared at %L"
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "Đối số chưa dùng %qs được khai báo tại %L"
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -82179,1006 +82227,1006 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Chiều dài chuỗi tại %L là quá lớn"
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s tại %L"
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, fuzzy, gcc-internal-format
 #| msgid "Interface %qs at %L may not be a statement function"
 msgid "Interface of %qs at %L must be explicit"
 msgstr "Giao diện %qs tại %L không thể là hàm khai báo"
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Đối số của thủ tục FINAL tại %L phải là kiểu %qs"
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr ""
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr ""
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là kiểu dẫn xuất %qs"
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, fuzzy, gcc-internal-format
 #| msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là kiểu dẫn xuất %qs"
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr ""
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là dẫn xuất kiểu %qs"
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là vô hướng"
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%qE chưa được khai báo"
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist '%s' can not be an argument at %L"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "Danh sách tên “%s” không thể là đối số tại %L"
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %L"
 msgid "Expecting definable entity near %L"
 msgstr "Cần câu lệnh %s tại %L"
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant character length at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr ""
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Nhãn %d tại %L đã định nghĩa nhưng chưa được dùng"
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Chuỗi con tại %L có độ dài là không"
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, gcc-internal-format
 msgid "Self reference in character length expression for %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -83732,332 +83780,332 @@ msgstr ""
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr ""
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, gcc-internal-format
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr "thuộc tính %s xung đột với thuộc tính %s trong %sq tại %L"
+
+#: fortran/symbol.cc:508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr ""
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr ""
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, gcc-internal-format
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr ""
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr ""
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "thuộc tính %s được áp dụng cho %s %s tại %L"
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) được áp dụng với %s %s tại %L"
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, gcc-internal-format, gfc-internal-format
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr ""
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, gcc-internal-format
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr "thuộc tính %s xung đột với thuộc tính %s trong %sq tại %L"
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr ""
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr ""
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr "Trùng thuộc tính %s tại %L"
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr ""
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr ""
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr ""
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "thuộc tính %s của %qs xung đột với thuộc tính %s tại %L"
 
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "BIND(C) tại %L"
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "EXTENDS tại %L"
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr ""
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Thành phần “%qs” tại %C đã sẵn trong kiểu cha mẹ %L"
 
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %C is not a member of the %qs structure"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "%qs tại %C không phải là thành viên của cấu trúc %qs"
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs tại %C không phải là thành viên của cấu trúc %qs"
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Labeled DO statement at %L"
 msgstr "Không cần câu lệnh END tại %C"
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -84087,24 +84135,24 @@ msgstr ""
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr ""
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -84291,37 +84339,37 @@ msgstr "Trả lại giá trị %sq của hàm %qs khai báo tại %L chưa đặ
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "Không hiểu intrinsic op"
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr ""
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -84332,17 +84380,17 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr ""
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The event variable at %L shall not be coindexed "
 msgid "The event variable at %L shall not be coindexed"
@@ -84491,7 +84539,7 @@ msgstr ""
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr "gfc_trans_select(): Kiểu cho biểu thức case sai."
@@ -84873,6 +84921,11 @@ msgstr "biến %qD được định nghĩa lại là một hàm"
 msgid "function %qD redeclared as variable"
 msgstr "hàm %qD được định nghĩa lại thành một biến"
 
+#: lto/lto-symtab.cc:865
+#, gcc-internal-format
+msgid "previously declared here"
+msgstr "đã khai báo trước ở đây"
+
 #: lto/lto.cc:174
 #, fuzzy, gcc-internal-format
 #| msgid "lto_obj_file_open() failed"
@@ -86155,7 +86208,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr "%<-fobjc-sjlj-exceptions%> bị bỏ qua đối với %<-fgnu-runtime%>"
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, gcc-internal-format
 msgid "non-objective-c type %qT cannot be caught"
 msgstr ""
@@ -86166,7 +86219,7 @@ msgstr ""
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr "%<-fobjc-sjlj-exceptions%> bị lờ đi cho %<-fnext-runtime%> khi %<-fobjc-abi-version%> >= 2"
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> >= 2"
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
@@ -87248,10 +87301,6 @@ msgstr ""
 #~ msgid "argument 2 must be 0 or 1"
 #~ msgstr "đối số 2 phải là 0 hay 1"
 
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#~ msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
-#~ msgstr "-mtoc-fusion cần -mpower8-fusion"
-
 #, gcc-internal-format
 #~ msgid "AltiVec and SPE instructions cannot coexist"
 #~ msgstr "Các chỉ lệnh AltiVec và SPE không thể cùng tồn tại"
diff --git a/gcc/po/zh_CN.po b/gcc/po/zh_CN.po
index 7415bee6315..133c36a8ec4 100644
--- a/gcc/po/zh_CN.po
+++ b/gcc/po/zh_CN.po
@@ -32,10 +32,10 @@
 #
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 14.1-b20240218\n"
+"Project-Id-Version: gcc 14.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
-"PO-Revision-Date: 2024-02-24 14:20-0500\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
+"PO-Revision-Date: 2024-08-02 12:22-0400\n"
 "Last-Translator: Boyuan Yang <073plan@gmail.com>\n"
 "Language-Team: Chinese (simplified) <i18n-zh@googlegroups.com>\n"
 "Language: zh_CN\n"
@@ -44,7 +44,7 @@ msgstr ""
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=1; plural=0;\n"
 "X-Bugs: Report translation errors to the Language-Team address.\n"
-"X-Generator: Poedit 3.4.2\n"
+"X-Generator: Poedit 3.4.4\n"
 
 #: cif-code.def:39
 msgid "function not considered for inlining"
@@ -418,7 +418,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr "请勿同时指定 -march=... 和 -mcpu=..."
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 msgid "shared and mdll are not compatible"
 msgstr "shared 和 mdll 互不兼容"
 
@@ -1281,10 +1281,9 @@ msgid "Conform to the ISO Fortran 2018 standard."
 msgstr "遵循 ISO Fortran 2008 标准。"
 
 #: fortran/lang.opt:896
-#, fuzzy, no-c-format
-#| msgid "Conform to the ISO Fortran 2003 standard."
+#, no-c-format
 msgid "Conform to the ISO Fortran 2023 standard."
-msgstr "遵循 ISO Fortran 2003 标准。"
+msgstr "遵循 ISO Fortran 2023 标准。"
 
 #: fortran/lang.opt:900
 #, no-c-format
@@ -1573,10 +1572,9 @@ msgid "Enable most warning messages."
 msgstr "启用大部分警告信息。"
 
 #: c-family/c.opt:336
-#, fuzzy, no-c-format
-#| msgid "Warn about misuses of pragmas"
+#, no-c-format
 msgid "Warn on any use of alloca."
-msgstr "对错误使用的 pragma 加以警告"
+msgstr "对任何使用 alloca 的情况给出警告。"
 
 #: c-family/c.opt:340
 #, no-c-format
@@ -1650,14 +1648,14 @@ msgid "Warn about boolean expression compared with an integer value different fr
 msgstr ""
 
 #: c-family/c.opt:426
-#, fuzzy, no-c-format
+#, no-c-format
 msgid "Warn about certain operations on boolean expressions."
-msgstr "对被截断的字符表达式给出警告"
+msgstr "对在布尔表达式上的特定操作给出警告。"
 
 #: c-family/c.opt:430
 #, no-c-format
 msgid "Warn when a built-in function is declared with the wrong signature."
-msgstr "当内奸函数使用了错误的签名被声明时给出警告。"
+msgstr "当内建函数使用了错误的签名被声明时给出警告。"
 
 #: c-family/c.opt:434
 #, no-c-format
@@ -1665,16 +1663,14 @@ msgid "Warn when a built-in preprocessor macro is undefined or redefined."
 msgstr "当内建预处理宏未定义或重定义时给出警告。"
 
 #: c-family/c.opt:438
-#, fuzzy, no-c-format
-#| msgid "Warn about features not present in ISO C11, but present in ISO C2X."
+#, no-c-format
 msgid "Warn about features not present in ISO C11, but present in ISO C23."
-msgstr "对 ISO C11 中不存在但 ISO C2X 中存在的特性给出警告。"
+msgstr "对 ISO C11 中不存在但 ISO C23 中存在的特性给出警告。"
 
 #: c-family/c.opt:442
-#, fuzzy, no-c-format
-#| msgid "Deprecated in favor of -std=c11."
+#, no-c-format
 msgid "Deprecated in favor of -Wc11-c23-compat."
-msgstr "已弃用，请改用 -std=c11。"
+msgstr "已弃用，请改用 -Wc11-c23-compat。"
 
 #: c-family/c.opt:446
 #, no-c-format
@@ -1929,10 +1925,9 @@ msgid "Warn if type qualifiers on pointers are discarded."
 msgstr "当改变成员函数指针的类型时给出警告"
 
 #: c-family/c.opt:663
-#, fuzzy, no-c-format
-#| msgid "Warn about compile-time integer division by zero"
+#, no-c-format
 msgid "Warn about compile-time integer division by zero."
-msgstr "对编译时发现的零除给出警告"
+msgstr "对编译时发现的零除给出警告。"
 
 #: c-family/c.opt:667
 #, no-c-format
@@ -1957,10 +1952,9 @@ msgid "Warn about duplicated conditions in an if-else-if chain."
 msgstr ""
 
 #: c-family/c.opt:683
-#, fuzzy, no-c-format
-#| msgid "Warn about violations of Effective C++ style rules"
+#, no-c-format
 msgid "Warn about violations of Effective C++ style rules."
-msgstr "对不遵循《Effetive C++》的风格给出警告"
+msgstr "对不遵循《Effetive C++》的风格给出警告。"
 
 #: c-family/c.opt:687
 #, no-c-format
@@ -1980,22 +1974,19 @@ msgid "Warn about stray tokens after #else and #endif."
 msgstr "当 #elif 和 #endif 后面跟有其他标识符时给出警告"
 
 #: c-family/c.opt:699
-#, fuzzy, no-c-format
-#| msgid "Warn about comparison of different enum types"
+#, no-c-format
 msgid "Warn about comparison of different enum types."
-msgstr "对不同枚举类型之间的比较给出警告"
+msgstr "对不同枚举类型之间的比较给出警告。"
 
 #: c-family/c.opt:703
-#, fuzzy, no-c-format
-#| msgid "Warn about most implicit conversions"
+#, no-c-format
 msgid "Warn about implicit conversion of enum types."
-msgstr "对大多数隐式类型转换给出警告"
+msgstr "对枚举类型的隐式转换给出警告。"
 
 #: c-family/c.opt:707
-#, fuzzy, no-c-format
-#| msgid "Warn about subscripts whose type is \"char\""
+#, no-c-format
 msgid "Warn about enum/integer type mismatches."
-msgstr "当下标类型为“char”时给出警告"
+msgstr "对枚举/整型的类型不匹配给出警告。"
 
 #: c-family/c.opt:715
 #, no-c-format
@@ -3910,7 +3901,7 @@ msgstr "已弃用，请改用 -std=gnu11。"
 #: c-family/c.opt:2602 c-family/c.opt:2606
 #, no-c-format
 msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
-msgstr "遵循 ISO 2017 C 标准（发布于2018年），也支持 GNU 扩展"
+msgstr "遵循 ISO 2017 C 标准（发布于2018年），也支持 GNU 扩展。"
 
 #: c-family/c.opt:2610
 #, fuzzy, no-c-format
@@ -4088,7 +4079,7 @@ msgstr ""
 #: d/lang.opt:256
 #, no-c-format
 msgid "Compile in debug code."
-msgstr "生成大端序模式的代码"
+msgstr "编译为调试代码。"
 
 #: d/lang.opt:260
 #, no-c-format
@@ -8473,7 +8464,7 @@ msgstr "支持 AMX-TILE 内建函数及代码生成。"
 #: config/i386/i386.opt:1206
 #, no-c-format
 msgid "Support AMX-INT8 built-in functions and code generation."
-msgstr "支持 AMX-INT8 内建函数及代码生成"
+msgstr "支持 AMX-INT8 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1210
 #, no-c-format
@@ -8712,9 +8703,9 @@ msgid "Use ldcw/ldcd coherent cache-control hint."
 msgstr ""
 
 #: config/pa/pa.opt:58
-#, fuzzy, no-c-format
+#, no-c-format
 msgid "Disable FP regs.  Equivalent to -msoft-float."
-msgstr "打开本地回应"
+msgstr "禁用浮点寄存器。等效于 -msoft-float。"
 
 #: config/pa/pa.opt:62
 #, fuzzy, no-c-format
@@ -8902,9 +8893,9 @@ msgid "Enable relaxing in the assembler."
 msgstr "启用链接器松弛"
 
 #: config/v850/v850.opt:139
-#, fuzzy, no-c-format
+#, no-c-format
 msgid "Prohibit PC relative jumps."
-msgstr "禁止相对 PC 的函数调用"
+msgstr "禁止相对 PC 的跳转。"
 
 #: config/v850/v850.opt:143
 #, fuzzy, no-c-format
@@ -8917,9 +8908,9 @@ msgid "Allow the use of hardware floating point instructions for V850E2V3 and up
 msgstr "允许使用硬件浮点 ABI 和指令"
 
 #: config/v850/v850.opt:151
-#, fuzzy, no-c-format
+#, no-c-format
 msgid "Enable support for the RH850 ABI.  This is the default."
-msgstr "启用使用 RX FPU 指令。这是默认值。"
+msgstr "启用对 RH850 ABI 的支持。这是默认值。"
 
 #: config/v850/v850.opt:155
 #, no-c-format
@@ -9330,10 +9321,9 @@ msgid "Maintain backchain pointer."
 msgstr "维护链回上层栈帧的指针"
 
 #: config/s390/s390.opt:133
-#, fuzzy, no-c-format
-#| msgid "Additional debug prints"
+#, no-c-format
 msgid "Additional debug prints."
-msgstr "附加的调试输出"
+msgstr "额外的调试输出。"
 
 #: config/s390/s390.opt:137
 #, fuzzy, no-c-format
@@ -9405,7 +9395,7 @@ msgstr "在函数前言中生成额外代码以捕获堆栈大小越限"
 #: config/s390/s390.opt:199
 #, no-c-format
 msgid "Switches off the -mstack-size= option."
-msgstr ""
+msgstr "关闭 -mstack-size= 选项。"
 
 #: config/s390/s390.opt:207
 #, fuzzy, no-c-format
@@ -9532,22 +9522,19 @@ msgid "Selects the type of RL78 core being targeted (g10/g13/g14).  The default
 msgstr ""
 
 #: config/rl78/rl78.opt:77
-#, fuzzy, no-c-format
-#| msgid "Alias for --help=target"
+#, no-c-format
 msgid "Alias for -mcpu=g10."
-msgstr "--help=target 的别名"
+msgstr "-mcpu=g10 的别名。"
 
 #: config/rl78/rl78.opt:81
-#, fuzzy, no-c-format
-#| msgid "Alias for --help=target"
+#, no-c-format
 msgid "Alias for -mcpu=g13."
-msgstr "--help=target 的别名"
+msgstr "-mcpu=g13 的别名。"
 
 #: config/rl78/rl78.opt:85 config/rl78/rl78.opt:89
-#, fuzzy, no-c-format
-#| msgid "Alias for --help=target"
+#, no-c-format
 msgid "Alias for -mcpu=g14."
-msgstr "--help=target 的别名"
+msgstr "-mcpu=g14 的别名。"
 
 #: config/rl78/rl78.opt:93
 #, no-c-format
@@ -9808,10 +9795,9 @@ msgid "Enable unaligned word and halfword accesses to packed data."
 msgstr "启用 unaligned 字词和 halfword 访问到包装的数据。"
 
 #: config/arm/arm.opt:309
-#, fuzzy, no-c-format
-#| msgid "This switch is deprecated; use -Wextra instead"
+#, no-c-format
 msgid "This option is deprecated and has no effect."
-msgstr "已弃用此开关；请改用 -Wextra"
+msgstr "该选项已被弃用，且无任何效果。"
 
 #: config/arm/arm.opt:313
 #, no-c-format
@@ -9857,15 +9843,14 @@ msgstr ""
 
 #: config/sparc/sparc.opt:30 config/sparc/sparc.opt:34
 #: config/visium/visium.opt:37
-#, fuzzy, no-c-format
+#, no-c-format
 msgid "Use hardware FP."
 msgstr "使用硬件浮点单元。"
 
 #: config/sparc/sparc.opt:38 config/visium/visium.opt:41
-#, fuzzy, no-c-format
-#| msgid "Do not use hardware FP"
+#, no-c-format
 msgid "Do not use hardware FP."
-msgstr "不使用硬件浮点单元"
+msgstr "不使用硬件浮点单元。"
 
 #: config/sparc/sparc.opt:42
 #, fuzzy, no-c-format
@@ -10757,10 +10742,9 @@ msgid "Emit .gnu_attribute tags."
 msgstr ""
 
 #: config/alpha/alpha.opt:27
-#, fuzzy, no-c-format
-#| msgid "Use fp registers"
+#, no-c-format
 msgid "Use fp registers."
-msgstr "使用浮点寄存器"
+msgstr "使用浮点寄存器。"
 
 #: config/alpha/alpha.opt:35
 #, fuzzy, no-c-format
@@ -10781,16 +10765,14 @@ msgid "Do not emit complex integer constants to read-only memory."
 msgstr "不将复整常数存至只读内存"
 
 #: config/alpha/alpha.opt:50
-#, fuzzy, no-c-format
-#| msgid "Use VAX fp"
+#, no-c-format
 msgid "Use VAX fp."
-msgstr "使用 VAX 浮点单元"
+msgstr "使用 VAX 浮点单元。"
 
 #: config/alpha/alpha.opt:54
-#, fuzzy, no-c-format
-#| msgid "Do not use VAX fp"
+#, no-c-format
 msgid "Do not use VAX fp."
-msgstr "不使用 VAX 浮点单元"
+msgstr "不使用 VAX 浮点单元。"
 
 #: config/alpha/alpha.opt:58
 #, fuzzy, no-c-format
@@ -10913,20 +10895,19 @@ msgid "Enable sign extend instructions."
 msgstr "启用符号扩展指令"
 
 #: config/lm32/lm32.opt:40
-#, fuzzy, no-c-format
-#| msgid "Enable user-defined instructions"
+#, no-c-format
 msgid "Enable user-defined instructions."
-msgstr "启用用户自定义指令"
+msgstr "启用用户自定义指令。"
 
 #: config/loongarch/loongarch.opt:41
 #, no-c-format
 msgid "Basic ISAs of LoongArch:"
-msgstr ""
+msgstr "LoongArch 的基本 ISA："
 
 #: config/loongarch/loongarch.opt:49
 #, no-c-format
 msgid "FPU types of LoongArch:"
-msgstr "LoongArch 的 FPU 类型。"
+msgstr "LoongArch 的 FPU 类型："
 
 #: config/loongarch/loongarch.opt:62
 #, fuzzy, no-c-format
@@ -11263,14 +11244,14 @@ msgid "Valid options for GP-relative addressing (for -mgpopt):"
 msgstr ""
 
 #: config/nios2/nios2.opt:86
-#, fuzzy, no-c-format
+#, no-c-format
 msgid "Equivalent to -mgpopt=local."
-msgstr "打开本地回应"
+msgstr "等效于 -mgpopt=local。"
 
 #: config/nios2/nios2.opt:90
-#, fuzzy, no-c-format
+#, no-c-format
 msgid "Equivalent to -mgpopt=none."
-msgstr "NONE (无)"
+msgstr "等效于 -mgpopt=none。"
 
 #: config/nios2/nios2.opt:94 config/c6x/c6x.opt:30 config/mips/mips.opt:134
 #, no-c-format
@@ -20771,18 +20752,18 @@ msgstr "无法识别的指令："
 msgid "insn does not satisfy its constraints:"
 msgstr "指令不满足其约束："
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "创建和使用时使用了不同的‘%s’设定"
 
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "创建和使用时使用了不同的 -fpic 设定"
 
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 #, fuzzy
 #| msgid "created and used with different settings of -fpie"
 msgid "created and used with different settings of %<-fpie%>"
@@ -21105,7 +21086,7 @@ msgstr "strfmon 格式的长度修饰符"
 msgid "<command-line>"
 msgstr "<命令行>"
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "代码‘%c’的操作数无效"
@@ -21124,9 +21105,9 @@ msgstr "无效的操作数代码‘%c’"
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "%<#pragma pack%>中有无效常量 - 已忽略"
@@ -21146,7 +21127,7 @@ msgstr "无效的操作数代码‘%c’"
 msgid "incompatible register operand for '%%%c'"
 msgstr "无效的操作数代码‘%c’"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, c-format
 msgid "missing operand"
 msgstr "缺少操作数"
@@ -21178,93 +21159,93 @@ msgstr "无效寻址模式"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "二元操作中中操作数无效"
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "使用‘%%&’ 时没有指定任何动态 TLS 引用"
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, c-format
 msgid "invalid %%J value"
 msgstr "无效 %%J 值"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, c-format
 msgid "invalid %%r value"
 msgstr "无效 %%r 值"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, c-format
 msgid "invalid %%R value"
 msgstr "无效 %%R 值"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, c-format
 msgid "invalid %%N value"
 msgstr "无效 %%N 值"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, c-format
 msgid "invalid %%P value"
 msgstr "无效 %%P 值"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, c-format
 msgid "invalid %%h value"
 msgstr "无效 %%h 值"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, c-format
 msgid "invalid %%L value"
 msgstr "无效 %%L 值"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, c-format
 msgid "invalid %%m value"
 msgstr "无效 %%m 值"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, c-format
 msgid "invalid %%M value"
 msgstr "无效 %%M 值"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, c-format
 msgid "invalid %%U value"
 msgstr "无效 %%U 值"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, c-format
 msgid "invalid %%s value"
 msgstr "无效 %%s 值"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, c-format
 msgid "invalid %%C value"
 msgstr "无效 %%C 值"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, c-format
 msgid "invalid %%E value"
 msgstr "无效 %%E 值"
 
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "未指定未知的重定位方式"
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, c-format
 msgid "invalid %%xn code"
 msgstr "无效的 %%xn 代码"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, fuzzy, c-format
 msgid "invalid operand address"
 msgstr "fr30_print_operand：未处理的指针"
@@ -21361,35 +21342,35 @@ msgstr "无效的 UNSPEC 用作操作数"
 msgid "unrecognized supposed constant"
 msgstr "预期的常量无法识别"
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, c-format
 msgid "invalid shift operand"
 msgstr "无效的移位操作数"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "预测到的 Thumb 指令"
 
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "在条件序列中预测到的指令"
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "代码‘%c’的操作数无效"
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -21397,130 +21378,130 @@ msgstr "代码‘%c’的操作数无效"
 msgid "invalid operand for code '%c'"
 msgstr "代码‘%c’的操作数无效"
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, c-format
 msgid "instruction never executed"
 msgstr "指令从不被执行"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, fuzzy, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "不受支持的算符用于编码‘%c’"
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "从%<__fpreg%>的转换无效"
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "到类型%qT的转换无效，从类型%qT"
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "地址操作数需要 X、Y 或 Z 寄存器约束"
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 #, fuzzy
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "输出操作数 %d 必须使用%<&%>约束"
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 #, fuzzy
 msgid "bad address, not an I/O address:"
 msgstr ""
 "\n"
 "错误：不当的地址在 From: 标头内。\n"
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 #, fuzzy
 msgid "bad address, not a constant:"
 msgstr "地址偏移量不是一个常量"
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 msgid "bad address, not (reg+disp):"
 msgstr "地址错误，不是(reg+disp)："
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "错误的地址，不是 post_inc 或 pre_dec："
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr "编译器内部错误。错误的地址："
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, fuzzy, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "C++ 不支持定点类型"
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 msgid "internal compiler error.  Unknown mode:"
 msgstr "编译器内部错误。未知的模式："
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 msgid "invalid insn:"
 msgstr "无效指令："
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 msgid "incorrect insn:"
 msgstr "错误指令："
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 msgid "unknown move insn:"
 msgstr "无效的 move 指令："
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 #, fuzzy
 msgid "bad shift insn:"
 msgstr "错误的 shift 指令:"
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "编译器内部错误。不正确的移位量："
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 #, fuzzy
 msgid "unsupported fixed-point conversion"
 msgstr "整点转换中类型无效"
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 msgid "variable"
 msgstr "变量"
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "function parameter"
 msgstr "形参%q+D重定义"
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 #, fuzzy
 #| msgid "struct defined here"
 msgid "structure field"
 msgstr "结构在此定义"
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 #, fuzzy
 #| msgid "creating array of functions"
 msgid "return type of function"
 msgstr "创建函数的数组"
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 msgid "pointer"
 msgstr "指针"
 
@@ -21558,7 +21539,7 @@ msgstr "非预期的操作数"
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -21884,55 +21865,55 @@ msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "无效的操作数代码‘%c’"
 
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "操作数的约束无效"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, fuzzy, c-format
 #| msgid "invalid controlling predicate"
 msgid "invalid vector immediate"
 msgstr "无效的控制谓词"
 
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 msgid "unknown insn mode"
 msgstr "未知的指令模式"
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr "从%<__fpreg%>的转换无效"
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr "从%<__fpreg%>的转换无效"
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr "到类型%qT的转换无效，从类型%qT"
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 #, fuzzy
 #| msgid "invalid conversion to type %qT from type %qT"
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr "到类型%qT的转换无效，从类型%qT"
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
 msgstr ""
 
@@ -21963,7 +21944,7 @@ msgstr "对%<__fpreg%>的操作无效"
 msgid "invalid %%P operand"
 msgstr "无效的 %%P 操作数"
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, c-format
 msgid "invalid %%p value"
 msgstr "无效的 %%p 值"
@@ -21990,29 +21971,29 @@ msgstr "不能使用非 GP 相对的绝对地址"
 msgid "invalid addressing mode"
 msgstr "无效寻址模式"
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, c-format
 msgid "'%%%c' is not a valid operand prefix"
 msgstr "‘%%%c’不是一个有效的操作数前缀"
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, c-format
 msgid "invalid use of '%%%c'"
 msgstr "对‘%%%c’的使用无效"
@@ -22044,7 +22025,7 @@ msgid "post-increment address is not a register"
 msgstr "后自增地址不是一个寄存器"
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 msgid "bad address"
 msgstr "错误地址"
 
@@ -22207,7 +22188,7 @@ msgstr "不支持的组合：%s"
 msgid "unsupported memory expression:"
 msgstr "整点转换中类型无效"
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, fuzzy, c-format
 msgid "invalid vector operand"
 msgstr "%%R 的操作数无效"
@@ -22268,260 +22249,260 @@ msgstr "-mquad-memory 需要 64 位模式"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "生成小端在前的代码"
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 msgid "bad move"
 msgstr "错误的移动"
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%A value"
 msgstr "无效 %%J 值"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%D value"
 msgstr "无效的 %%D 值"
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, c-format
 msgid "invalid %%e value"
 msgstr "无效 %%e 值"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, c-format
 msgid "invalid %%f value"
 msgstr "无效 %%f 值"
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, c-format
 msgid "invalid %%F value"
 msgstr "无效 %%F 值"
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, c-format
 msgid "invalid %%G value"
 msgstr "无效 %%G 值"
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, c-format
 msgid "invalid %%j code"
 msgstr "无效 %%j 代码"
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, c-format
 msgid "invalid %%J code"
 msgstr "无效 %%J 代码"
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, c-format
 msgid "invalid %%k value"
 msgstr "无效 %%k 值"
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, c-format
 msgid "invalid %%K value"
 msgstr "无效 %%K 值"
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, c-format
 msgid "invalid %%O value"
 msgstr "无效 %%O 值"
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, c-format
 msgid "invalid %%q value"
 msgstr "无效 %%q 值"
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, c-format
 msgid "invalid %%t value"
 msgstr "无效 %%t 值"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, c-format
 msgid "invalid %%T value"
 msgstr "无效 %%T 值"
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, c-format
 msgid "invalid %%u value"
 msgstr "无效 %%u 值"
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, c-format
 msgid "invalid %%v value"
 msgstr "无效 %%v 值"
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, c-format
 msgid "invalid %%V value"
 msgstr "无效 %%V 值"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, c-format
 msgid "invalid %%x value"
 msgstr "无效 %%x 值"
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, c-format
 msgid "invalid %%z value"
 msgstr "无效 %%z 值"
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "无效 %%y 值，请试用“Z”约束"
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 #, fuzzy
 #| msgid "Use decimal floating point instructions"
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "使用十进制浮点指令"
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "传递 AltiVec 参数给无原型的函数"
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "不为每个函数生成单一的退出点"
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "无法生成重新载入，为："
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "从%<__fpreg%>的转换无效"
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "向%<__fpreg%>的转换无效"
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "从%<__fpreg%>的转换无效"
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "向%<__fpreg%>的转换无效"
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, fuzzy, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "符号内存参考是只有支持的于 z10 或稍后"
 
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, c-format
 msgid "cannot decompose address"
 msgstr "无法分解地址"
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "‘b’修饰符的操作数无效"
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "‘b’修饰符的操作数无效"
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "‘o’修饰符的操作数无效"
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "‘b’修饰符的操作数无效"
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, fuzzy, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "内存参考预期的用于‘S’输出修饰键"
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "%s：无效的输出格式"
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "暂存器或内存运算式预期的用于‘N’输出修饰键"
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "暂存器或内存运算式预期的用于‘公尺’输出修饰键"
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "CHARACTER 常量的种别 %d 无效，在%C处"
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "无效的操作数输出代码"
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "CHARACTER 常量的种别 %d 无效，在%C处"
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "无效的最小左值表达式"
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "C++ 不允许在%qs表达式中定义类型"
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "传递 AltiVec 参数给无原型的函数"
 
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "返回指针时目标与指针符号不一致"
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 #, fuzzy
 msgid "binary operator does not support vector bool operand"
 msgstr "目标格式不支持无限大浮点数"
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -22703,7 +22684,7 @@ msgstr "或称"
 
 #: c/c-objc-common.cc:360
 msgid "({anonymous})"
-msgstr "({匿名})"
+msgstr ""
 
 #. If we have
 #. declaration-specifiers declarator decl-specs
@@ -22721,12 +22702,12 @@ msgstr "({匿名})"
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "需要%<;%>"
@@ -22739,7 +22720,7 @@ msgstr "需要%<;%>"
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -22748,7 +22729,7 @@ msgstr "需要%<;%>"
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "需要%<)%>"
@@ -22756,7 +22737,7 @@ msgstr "需要%<)%>"
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "需要%<]%>"
@@ -22767,29 +22748,29 @@ msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "需要%<(%>"
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "需要%<[%>"
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "需要%<{%>"
@@ -22799,17 +22780,17 @@ msgstr "需要%<{%>"
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "需要 %<:%>"
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "需要 %<while%>"
@@ -22818,8 +22799,8 @@ msgstr "需要 %<while%>"
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "需要 %<,%>"
@@ -22829,17 +22810,17 @@ msgid "expected %<.%>"
 msgstr "需要%<.%>"
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "需要 %<@end%>"
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "需要 %<>%>"
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "需要 %<,%> 或 %<)%>"
@@ -22847,33 +22828,33 @@ msgstr "需要 %<,%> 或 %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "需要%<=%>"
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "需要 %<}%>"
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<delete%>"
 msgid "expected %<else%>"
 msgstr "需要%<delete%>"
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "需要%<#pragma omp section%>或%<}%>"
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr ""
 
@@ -22881,7 +22862,7 @@ msgstr ""
 msgid "(anonymous)"
 msgstr "(匿名)"
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "需要%<<%>"
@@ -22897,22 +22878,22 @@ msgstr "需要通道"
 msgid "candidate:"
 msgstr "备选："
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 #, fuzzy
 #| msgid "Enable user-defined instructions"
 msgid "  after user-defined conversion:"
 msgstr "启用用户自定义指令"
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "备选是："
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr "备选 1："
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr "备选 2："
 
@@ -22977,7 +22958,7 @@ msgstr "<返回值> "
 
 #: cp/error.cc:1350
 msgid "{anonymous}"
-msgstr "{匿名}"
+msgstr ""
 
 #: cp/error.cc:1352
 #, fuzzy
@@ -23177,7 +23158,7 @@ msgstr "%s:%d:%d：在%qs的广义常表达式扩展中"
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%s:%d：在%qs的广义常表达式扩展中"
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 msgid "candidates are:"
 msgstr "备选为："
 
@@ -23221,48 +23202,48 @@ msgstr "转换丢失了常量属性"
 msgid "source type is not polymorphic"
 msgstr "源类型不是多态的"
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "单目减的操作数类型错误"
 
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "单目加的操作数类型错误"
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "按位取反的参数类型错误"
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "不能对该类型的参数求绝对值"
 
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "不能对该类型的参数求共轭"
 
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 msgid "in argument to unary !"
 msgstr "单目 ! 的参数中"
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 msgid "no pre-increment operator for type"
 msgstr "类型没有前自增运算符"
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 msgid "no post-increment operator for type"
 msgstr "类型没有后自增运算符"
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 msgid "no pre-decrement operator for type"
 msgstr "类型没有前自减运算符"
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 msgid "no post-decrement operator for type"
 msgstr "类型没有后自减运算符"
 
@@ -23348,7 +23329,7 @@ msgstr "对声明中的过时用法给出警告"
 msgid "Deleted feature:"
 msgstr "删除的特性："
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 msgid "array assignment"
 msgstr "数组赋值"
 
@@ -23547,11 +23528,11 @@ msgstr "块 IF"
 msgid "implied END DO"
 msgstr "暗示的 END DO"
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 msgid "assignment"
 msgstr "赋值"
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 msgid "pointer assignment"
 msgstr "指针赋值"
 
@@ -23735,53 +23716,53 @@ msgstr "用户运算符‘%s’(位于 %%L)的操作数为 %s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "用户运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 msgid "Loop variable"
 msgstr "循环变量"
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 #, fuzzy
 msgid "iterator variable"
 msgstr "变量"
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 msgid "Start expression in DO loop"
 msgstr "DO 循环中的开始表达式"
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 msgid "End expression in DO loop"
 msgstr "DO 循环中结束表达式"
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 msgid "Step expression in DO loop"
 msgstr "DO 循环中的步进表达式"
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "试图 DEALLOCATE 未分配的‘%s’"
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "%L处的源表达式和%L处的分配对象必须有相同的外形"
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 #, fuzzy
 msgid "STAT variable"
 msgstr "%1$L处的统计变量不能在同一个 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "%1$L处的错误信息变量不能在同一 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 #, fuzzy
 msgid "item in READ"
 msgstr "读取概要："
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "无法锁定新归档文件"
@@ -23791,12 +23772,12 @@ msgstr "无法锁定新归档文件"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "数组构造函数中 CHARACTER 长度不同(%ld/%ld)"
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 #, fuzzy
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "试图分配负数大小的内存。可能有整数溢出"
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
@@ -23811,12 +23792,12 @@ msgstr "字符串的实际长度不匹配其虚参声明‘%s’(%ld/%ld)"
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "字符串的实际长度短于其虚参声明‘%s’(%ld/%ld)"
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, fuzzy, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "目标的分级重新映射太小 (%ld<%ld)"
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -23825,83 +23806,83 @@ msgstr ""
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "%3$s 中字符长度不相等 (%1$ld/%2$ld)"
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, fuzzy, c-format
 #| msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "‘a%d’和‘a%d’用作内建函数‘%s’的参数"
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, fuzzy, c-format
 #| msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "‘a%d’和‘a%d’用作内建函数‘%s’的参数"
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, fuzzy, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "内建函数 REPEAT 的 NCOPIES 参数为负(其值是 %lld)"
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "内建函数 REPEAT 的 NCOPIES 参数太大"
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, c-format
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, c-format
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
@@ -23923,15 +23904,15 @@ msgstr "赋值标号不是目标标号"
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "无效的影像号码 %d 在中同步影像"
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr "循环无限次迭代"
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 msgid "Loop variable has been modified"
 msgstr "循环变量已被修改"
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 msgid "DO step value is zero"
 msgstr "DO 步进值为零"
 
@@ -24014,7 +23995,7 @@ msgid "expected boolean type"
 msgstr "需要布尔类型"
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "需要整数"
@@ -24083,7 +24064,7 @@ msgstr "实参太少"
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, gcc-internal-format
 msgid "too many arguments"
 msgstr "实参太多"
@@ -24779,7 +24760,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "-mrelax 只在 RTP PIC 上受支持"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s 语句在%C处语法错误"
@@ -25231,8 +25212,8 @@ msgstr "%qE属性与 %s 属性冲突"
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "%q+T先前在此处有过声明"
@@ -25249,7 +25230,7 @@ msgstr "%qE属性指定被忽略"
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr "%qE属性指定被忽略"
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, gcc-internal-format
 msgid "wrong number of arguments specified for %qE attribute"
 msgstr "为%qE属性给定的实参数目错误"
@@ -25260,7 +25241,7 @@ msgstr "为%qE属性给定的实参数目错误"
 msgid "expected %i or more, found %i"
 msgstr "需要%<(%>或行尾"
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %i, found %i"
@@ -25328,12 +25309,12 @@ msgstr "类型属性在定义后被忽略"
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -25342,7 +25323,7 @@ msgstr "类型属性在定义后被忽略"
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -25365,8 +25346,8 @@ msgstr "%qE属性被忽略"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr "%qE不兼容的属性已被忽略"
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %qD"
 msgstr "%qD先前没有声明"
@@ -25476,7 +25457,7 @@ msgstr "无法从 “%s” 中读取 LTO decls"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "偏移量越过字符串常量界"
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%qE declared here"
@@ -25587,7 +25568,7 @@ msgstr "%qs缺少参数"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, fuzzy, gcc-internal-format
 #| msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
@@ -25611,45 +25592,45 @@ msgstr "%<__builtin_longjmp%>的第二个实参必须是 1"
 msgid "target format does not support infinity"
 msgstr "目标格式不支持无限大浮点数"
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, fuzzy, gcc-internal-format
 #| msgid "%<va_start%> used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "在定参数的函数中使用了%<va_start%>"
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "给函数%<va_start%>的参数数目不对"
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "调用%<__builtin_next_arg%>时没有给定实参"
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%>的第二个参数不是最后一个有名参数"
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, fuzzy, gcc-internal-format
 #| msgid "undefined behaviour when second parameter of %<va_start%> is declared with %<register%> storage"
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "当%<va_start%>的第二个参数有%<register%>存储时行为未经定义"
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, fuzzy, gcc-internal-format
 #| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "last argument of %qD is not integer constant between 0 and 3"
@@ -26716,12 +26697,12 @@ msgstr "%qE属性被忽略，因为%qT已被定义"
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F使用过但从未定义"
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F声明为%<static%>却从未定义过"
@@ -27046,13 +27027,12 @@ msgstr "对 %%d、%%x 或 %%X 的使用无效"
 #: coverage.cc:283
 #, gcc-internal-format
 msgid "%qs has overflowed"
-msgstr "%qs溢出"
+msgstr "%qs 已溢出"
 
 #: coverage.cc:284
-#, fuzzy, gcc-internal-format
-#| msgid "%s:corrupted\n"
+#, gcc-internal-format
 msgid "%qs is corrupted"
-msgstr "%s：已损坏\n"
+msgstr "%qs 已损坏"
 
 #: coverage.cc:311
 #, gcc-internal-format
@@ -27151,10 +27131,9 @@ msgid "closed intervals"
 msgstr "括入并行"
 
 #: diagnostic.cc:2659
-#, fuzzy, gcc-internal-format
-#| msgid "debug: "
+#, gcc-internal-format
 msgid "debug path"
-msgstr "调试："
+msgstr "调试路径"
 
 #: dominance.cc:1180
 #, gcc-internal-format, gfc-internal-format
@@ -27293,7 +27272,7 @@ msgstr "region_array 不匹配 region_tree"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "lp_array 不匹配 region_tree"
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, fuzzy, gcc-internal-format
 #| msgid "open %s failed: %s"
 msgid "%qs failed"
@@ -27325,19 +27304,19 @@ msgstr "生成用户模式的代码"
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, fuzzy, gcc-internal-format
 #| msgid "%Kcall to %qs declared with attribute error: %s"
 msgid "call to %qs declared with attribute error: %s"
 msgstr "%K调用%qs，声明有错误属性：%s"
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, fuzzy, gcc-internal-format
 #| msgid "%Kcall to %qs declared with attribute warning: %s"
 msgid "call to %qs declared with attribute warning: %s"
 msgstr "%K调用%qs，声明有警告属性：%s"
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, fuzzy, gcc-internal-format
 #| msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
@@ -27374,7 +27353,7 @@ msgstr "大定点常量隐式截断为定点类型"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "由于位段宽度所限，比较结果永远为 %d"
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "简化范围检查时假定有符号数从不溢出"
@@ -27554,7 +27533,7 @@ msgstr "无法获取进程时间"
 msgid "%s signal terminated program %s"
 msgstr "使用另一套寄存器名"
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, fuzzy, gcc-internal-format
 msgid "unrecognized command-line option %qs"
 msgstr "此配置不支持命令行选项%qs"
@@ -27823,7 +27802,7 @@ msgstr "%C处类型指定无效"
 msgid "multilib exclusions %qs is invalid"
 msgstr "属性%qs的参数无效"
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, fuzzy, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "属性%qs的参数无效"
@@ -28142,23 +28121,23 @@ msgstr ""
 msgid "%qD specified bound %E equals source length"
 msgstr ""
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr ""
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s not supported for variable length aggregates"
 msgstr "堆栈限制在此目标机上不受支持"
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SPE not supported in this target"
 msgid "%s not supported on this target"
@@ -28202,16 +28181,16 @@ msgid "function returns address of local variable"
 msgstr "函数返回局部变量的地址"
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, gcc-internal-format
@@ -28223,358 +28202,358 @@ msgstr "在此声明"
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, fuzzy, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr "%L处内建 REPEAT 的 NCOPIES 实参是负的"
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "referenced argument declared here"
 msgstr "模板形参类型%qT声明为%<friend%>"
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, fuzzy, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "%L处内建 REPEAT 的 NCOPIES 实参是负的"
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, fuzzy, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr "停用回合 %s 用于函数在中范围的 [%u，%u]"
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgid_plural "%qE output %wu bytes into a destination of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 #, fuzzy
 msgid "%qE argument %Z overlaps destination object %qE"
 msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] "属性%qE的参数无效"
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 msgid "%qE argument %Z may overlap destination object %qE"
 msgid_plural "%qE arguments %Z may overlap destination object %qE"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, gcc-internal-format
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, fuzzy, gcc-internal-format
 #| msgid "null pointer"
 msgid "null destination pointer"
 msgstr "空指针"
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, fuzzy, gcc-internal-format
 #| msgid "%s in format string at %L"
 msgid "null format string"
@@ -29352,12 +29331,12 @@ msgstr "无效的指针模式%qs"
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD在此声明"
@@ -30146,7 +30125,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of attribute %<fallthrough%>"
@@ -30486,18 +30465,18 @@ msgstr "%qE未声明(不在函数内)"
 msgid "mismatching definition"
 msgstr "定义缺失"
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function in gimple call"
 msgid "invalid fnsummary in LTO stream"
 msgstr "gimple 调用中有非法函数"
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, fuzzy, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr "ipa 内联概要缺少在中输入文件"
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, fuzzy, gcc-internal-format
 msgid "IPA modref summary is missing in input file"
 msgstr "ipa 内联概要缺少在中输入文件"
@@ -31611,75 +31590,75 @@ msgstr "写入 %s 时出错：%m"
 msgid "error closing optimization records %qs"
 msgstr "进行跨跳转优化"
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, fuzzy, gcc-internal-format
 #| msgid "command line option %qs is not supported by this configuration"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "此配置不支持命令行选项%qs"
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "%qs缺少参数"
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr "“%s”的实参应该是一个非负整数"
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer"
 msgstr "“%s”的实参应该是一个非负整数"
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-functions=%d is not between 0 and %d"
 msgid "argument to %qs is not between %d and %d"
 msgstr "-malign-functions=%d 不在 0 和 %d 之间"
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, fuzzy, gcc-internal-format
 msgid "invalid argument in option %qs"
 msgstr "%<...%>作为实参。)"
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr ""
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, fuzzy, gcc-internal-format
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr "-mcorea 和 -mcoreb 不能一起使用"
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument in option %qs"
 msgstr "memusage：无法识别的选项“$1”"
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "开关%qs不再被支持"
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute larger than %d"
 msgid "argument to %qs is bigger than %d"
 msgstr "%qE属性的实参大于 %d"
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, fuzzy, gcc-internal-format
 #| msgid "malformed COLLECT_GCC_OPTIONS"
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
@@ -31757,8 +31736,8 @@ msgstr "“%s”的实参应该是一个非负整数"
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with %qs"
 msgstr "%qs必须与%qs一起使用"
@@ -32530,7 +32509,7 @@ msgstr "全局寄存器变量出现在函数定义后"
 msgid "register of %qD used for multiple global register variables"
 msgstr "嵌套函数中使用了全局寄存器变量%qD"
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "%qD与已用的函数冲突"
@@ -32992,44 +32971,44 @@ msgstr ""
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "__builtin_saveregs 不为此目标所支持"
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, fuzzy, gcc-internal-format
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "堆栈限制在此目标机上不受支持"
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, gcc-internal-format
 msgid "nested functions not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, gcc-internal-format
 msgid "nested function trampolines not supported on this target"
 msgstr "嵌套函数蹦床在此目标机上不受支持"
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "全局构造函数在此目标机上不受支持"
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "全局析构函数在此目标机上不受支持"
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute is not supported on this machine"
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "target 属性在此目标机上不受支持"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute is not supported on this machine"
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "target 属性在此目标机上不受支持"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "%<#pragma GCC target%> is not supported for this machine"
@@ -34200,85 +34179,85 @@ msgstr "基本块 %i 有不正确的边"
 msgid "BB %i has incorrect fallthru edge"
 msgstr "基本块 %i 有不正确的下落边"
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr "函数%q+F无法被复制，因为它接受了非局部的 goto"
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, gcc-internal-format
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr "函数%q+F无法被复制，因为它在一个静态变量中保存了局部标号的地址"
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr "函数%q+F无法被内联，因为它使用了 alloca (使用 always_inline 属性强制内联)"
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr "函数%q+F无法被内联，因为它使用了 setjmp"
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr "函数%q+F无法被内联，因为它使用了变长实参表"
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr "函数%q+F无法被内联，因为它使用了 setjmp-longjmp 异常处理"
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr "函数%q+F无法被内联，因为使用了非局部的 goto"
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses __builtin_return or __builtin_apply_args"
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr "函数%q+F无法被内联，因为使用了 __builtin_return 或 __builtin_apply_args"
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr "函数%q+F无法被内联，因为包含一个计算转移"
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr "函数%q+F无法被内联，因为它使用了变长实参表"
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it is suppressed using -fno-inline"
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr "函数%q+F无法被内联，因为使用了 -fno-inline"
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr "函数%q+F无法被内联，因为它使用了与内联冲突的属性"
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, fuzzy, gcc-internal-format
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr "调用%q+F时内联失败：%s"
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr "从此处调用"
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, fuzzy, gcc-internal-format
 msgid "called from this function"
 msgstr "内部函数"
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, gcc-internal-format
 msgid "inlining failed in call to %q+F: %s"
 msgstr "调用%q+F时内联失败：%s"
@@ -34336,28 +34315,28 @@ msgstr "属性%qs的元素类型无效"
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr "错误地使用了%<auto%>"
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "in a call to non-static member function %qD"
 msgstr "对非静态成员函数%qD的使用无效"
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, fuzzy, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "内建函数实参无效"
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, fuzzy, gcc-internal-format
 msgid "in a call to function %qD declared %qs"
 msgstr "内联函数%q+D声明过但从未定义"
@@ -34561,7 +34540,7 @@ msgstr "%qE未经初始化"
 msgid "%qs may be used uninitialized"
 msgstr "此函数中的%qD在使用前可能未初始化"
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD在此声明"
@@ -34799,7 +34778,7 @@ msgstr "矢量作业将被展开 piecewise"
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "矢量随机播放作业将被展开 piecewise"
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -34814,130 +34793,130 @@ msgstr ""
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "函数数组是没有意义的"
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "函数不能返回函数"
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "树检查：%s，得到 %s 在 %s，于 %s:%d"
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "树检查：不需要 %s，得到 %s 在 %s，于 %s:%d"
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "树检查：需要类%qs，得到%qs(%s) 在 %s，于 %s:%d"
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "树检查：不需要类%qs，得到%qs(%s) 在 %s，于 %s:%d"
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr "树检查：需要 omp_clause %s，得到 %s 在 %s，于 %s:%d"
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "树检查：需要包含%qs结构的树，得到%qs在 %s，于 %s:%d"
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, fuzzy, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr "树检查：访问了 %3$s 中有 %2$d 个 elt  的 tree_vec 的 elt %1$d，于 %4$s:%5$d"
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr "树检查：访问了 %3$s 中有 %2$d 个 elt  的 tree_vec 的 elt %1$d，于 %4$s:%5$d"
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "树检查：在 %4$s 中访问有 %3$d 个操作数的 %2$s 的第 %1$d 个操作数，于 %5$s:%6$d"
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "树检查：在 %4$s 中访问有 %3$d 个操作数的 omp_clause %2$s 的第 %1$d 个操作数，于 %5$s:%6$d"
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "已弃用%qE：%s"
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "已弃用%qE"
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "已弃用%qE：%s"
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "已弃用%qE"
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "已弃用类型：%s"
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "已弃用此类型"
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is unavailable: %s"
 msgstr "%qD不是一个变量"
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is unavailable"
 msgstr "%qD不是一个变量"
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qE is unavailable: %s"
 msgstr "%qD不是一个变量"
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qE is unavailable"
 msgstr "%qD不是一个变量"
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "open %s failed: %s"
 msgid "type is unavailable: %s"
 msgstr "打开 %s 失败：%s"
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "type is unavailable"
@@ -34963,269 +34942,269 @@ msgstr "%qD不是一个变量"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, fuzzy, gcc-internal-format
 #| msgid "%s:stamp mismatch with notes file\n"
 msgid "first mismatch is field"
 msgstr "%s:时间戳与说明文件不匹配\n"
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "type is not compatible with its variant"
 msgstr "-mnop-mcount 与此目标不兼容"
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "type %s is not an opaque type"
 msgstr "%qE不是一个常量表达式"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "type %s is not with opaque mode"
 msgstr "%qE不是一个常量表达式"
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr ""
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr ""
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable %qs not defined"
 msgid "main variant is not defined"
 msgstr "环境变量%qs未定义"
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE has non-integer type"
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "数组%qE的大小的类型不是整数"
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE has incomplete type"
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "字段%qE的类型不完全"
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -35453,7 +35432,7 @@ msgstr "别名定义在此配置下不受支持"
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "可见性属性在此配置下不受支持；已忽略"
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr ""
@@ -35678,7 +35657,7 @@ msgstr "%qE属性被忽略，因为%qT已被定义"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "%qE属性被忽略，因为%qT已被定义"
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE属性只能应用到公共对象上"
@@ -35871,7 +35850,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr "%qE属性只能用于函数"
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, gcc-internal-format
 msgid "%qE attribute cannot be specified for local variables"
 msgstr "不能为局部变量指定%qE属性"
@@ -36212,7 +36191,7 @@ msgstr "选择%qD而不是%qD"
 msgid "%qE argument is not a function"
 msgstr "属性%qE的参数无效"
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "过时消息不是一个字符串"
@@ -36750,7 +36729,7 @@ msgstr "ISO C++ 不允许对非类型使用%<alignof%>"
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr "ISO C++ 不允许对非类型使用%<alignof%>"
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, gcc-internal-format
 msgid "invalid application of %qs to a void type"
 msgstr "%qs不能用于 void 类型"
@@ -36884,17 +36863,17 @@ msgstr "只能为类定义应用%qE属性"
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "为 lambda 形参指定了默认参数"
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "提供给函数%qE的实参太少"
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, gcc-internal-format
@@ -37019,175 +36998,175 @@ msgstr "试图取位段结构成员%qD的地址"
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "索引 %E 指定了一个大于%qT大小的偏移量"
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "数组太大"
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "%2$qE的第 %1$d 个实参类型不兼容"
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "传递%2$qE的第 %1$d 个参数时将整数赋给指针，未作类型转换"
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, fuzzy, gcc-internal-format
 #| msgid "left argument must be a slice"
 msgid "both arguments must be compatible"
 msgstr "左实参必须是一个切片"
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "提供给函数%qE的实参太多"
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "%2$qE的实参 %1$d 必须是地址"
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "%2$qE的实参 %1$d 必须是地址"
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "%2$qE的实参 %1$d 必须是地址"
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, fuzzy, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "%2$qE的第 %1$d 个参数必须是在 %3$d 和 %4$d 之间"
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr "传递%2$qE的第 %1$d 个实参时丢弃了指针目标类型的限定"
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr "传递%2$qE的第 %1$d 个实参时丢弃了指针目标类型的限定"
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, fuzzy, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "%2$qE的第 %1$d 个实参类型不兼容"
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "%2$qE的第 %1$d 个实参类型不兼容"
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "索引值越界"
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, fuzzy, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "从%qT到%qT的转换有歧义"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD takes one argument only"
 msgid "built-in function %qE must be directly called"
 msgstr "内建函数%qD只需要一个实参"
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "size of array %qE is not a constant expression"
 msgstr "数组%qD的大小不是一个整数常表达式"
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array is not a constant expression"
 msgstr "数组大小不是一个整数常表达式"
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "size %qE of array %qE is negative"
 msgstr "数组%qE的大小为负"
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "数组大小为负数"
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is negative"
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "数组%qE的大小为负"
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -37846,7 +37825,7 @@ msgstr "对%<unsigned long%>类型而言整数常量太大"
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr "对%<unsigned long%>类型而言整数常量太大"
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, fuzzy, gcc-internal-format
 msgid "%<_BitInt(%d)%> is not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
@@ -37929,7 +37908,7 @@ msgstr "不受支持的非标准字面字符串毗连"
 msgid "traditional C rejects string constant concatenation"
 msgstr "传统 C 不接受字符串常量毗连"
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -37986,7 +37965,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr "%<void%>作为仅有的参数时不能被限定"
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "迭代变量%qE类型无效"
@@ -38002,17 +37981,17 @@ msgstr "迭代变量%qE类型无效"
 msgid "%qE is not initialized"
 msgstr "%qE未经初始化"
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "缺少控制谓词"
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "无效的控制谓词"
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "缺少自增语句"
@@ -38022,7 +38001,7 @@ msgstr "缺少自增语句"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "无效的自增语句"
@@ -38115,7 +38094,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -38125,7 +38104,7 @@ msgstr ""
 msgid "%qD is not a function argument"
 msgstr "  初始化%2$qD的实参 %1$P"
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "字段%qE的类型不完全"
@@ -38763,7 +38742,7 @@ msgid "wrong type argument to %s"
 msgstr "不能对该类型的参数求绝对值"
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -39728,35 +39707,35 @@ msgstr "在%qT和%qT间比较"
 
 #: c-family/c-warn.cc:3832
 #, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3836
+#: c-family/c-warn.cc:3839
 #, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr ""
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr ""
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr ""
@@ -39980,122 +39959,122 @@ msgstr "-mregparm=%d 不在 0 和 %d 之间"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr "%<-march=%s%>与所选 ABI 不兼容"
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr "%<-march=%s%>与所选 ABI 不兼容"
 
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr "不使用位段指令"
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, fuzzy, gcc-internal-format
 #| msgid "-mcpu=%s conflicts with -march=%s"
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr "-mcpu=%s 与 -march=%s 冲突"
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, fuzzy, gcc-internal-format
 #| msgid "-mcpu=%s conflicts with -march=%s"
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr "-mcpu=%s 与 -march=%s 冲突"
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "%<-march=%s%>与所选 ABI 不兼容"
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr "%<-march=%s%>与所选 ABI 不兼容"
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr "%<-march=%s%>与所选 ABI 不兼容"
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, fuzzy, gcc-internal-format
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "%s%s：未知的主机。\n"
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr ""
@@ -40528,13 +40507,13 @@ msgstr "需要类型%qT，但实参的类型为%qT"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "需要类型%qT，但实参的类型为%qT"
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC optimize%> is not a string or number"
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<#pragma GCC optimize%>不是字符串或数字"
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, fuzzy, gcc-internal-format
 #| msgid "unknown #pragma GCC coprocessor %E"
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
@@ -41156,7 +41135,7 @@ msgstr ""
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
@@ -41234,12 +41213,12 @@ msgid "unknown tuning option (%s)"
 msgstr "spec 函数名格式错误"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
@@ -41250,7 +41229,7 @@ msgid "specify a system register with a small string length"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
@@ -41435,9 +41414,9 @@ msgstr "目标系统不支持调试输出"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "attribute(target(\"%s\"))未知"
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "%qE属性需要一个字符串常量作为实参"
@@ -41490,18 +41469,18 @@ msgid "virtual function multiversioning not supported"
 msgstr "联合成员函数%qD被声明为虚函数"
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
@@ -41514,8 +41493,8 @@ msgstr ""
 msgid "lane %wd out of range %wd - %wd"
 msgstr "操作数号超出范围"
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, fuzzy, gcc-internal-format
 msgid "unsupported simdlen %wd"
 msgstr "不支持的真理哈希类型 %d。\n"
@@ -41525,7 +41504,7 @@ msgstr "不支持的真理哈希类型 %d。\n"
 msgid "GCC does not currently support return type %qT for simd"
 msgstr "%<operator new%>必须返回%qT"
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "%<operator new%>必须返回%qT"
@@ -41535,7 +41514,7 @@ msgstr "%<operator new%>必须返回%qT"
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr "需要类型%qT，但实参的类型为%qT"
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "需要类型%qT，但实参的类型为%qT"
@@ -41637,8 +41616,8 @@ msgstr "L%d 缓存延迟未知，对 %s 来说"
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "-mmemory-latency 开关的值%qs错误"
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr "错误的内建 fcode"
@@ -41764,18 +41743,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -41895,7 +41874,7 @@ msgid "argument of %qE attribute is missing"
 msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qE属性需要一个整常量作为实参"
@@ -41917,24 +41896,24 @@ msgstr "%qE属性只能用于函数类型"
 msgid "argument of %qE attribute ignored"
 msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "属性%qE只能用于变量"
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "%L处上下文中不允许使用按值传递的实参"
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, fuzzy, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, fuzzy, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "向函数类型%qT的转换无效"
@@ -42187,7 +42166,7 @@ msgstr "目标 CPU 不支持 THUMB 指令"
 msgid "target CPU does not support unaligned accesses"
 msgstr "目标 CPU 不支持未对齐的访问"
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, fuzzy, gcc-internal-format
 #| msgid "the %qs architecture does not support branch-likely instructions"
 msgid "This architecture does not support branch protection instructions"
@@ -42243,7 +42222,7 @@ msgstr "结构大小边界只能被设定为 %s"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC 与 -msingle-pic-base 不兼容"
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
@@ -42360,7 +42339,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -42405,43 +42384,43 @@ msgstr "%qE属性只能用于函数"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qE属性只能用于函数类型"
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, fuzzy, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "操作数号超出范围"
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "无法计算出栈中参数的真实地址"
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "非预期的模块结束"
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "高寄存器弹栈时没有可用的低寄存器"
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "Thumb 模式中不能编码中断服务进程"
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, fuzzy, gcc-internal-format
 #| msgid "invalid element type for attribute %qs"
 msgid "invalid fpu for target attribute or pragma %qs"
@@ -42450,24 +42429,24 @@ msgstr "属性%qs的元素类型无效"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "属性%qE的向量类型无效"
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, fuzzy, gcc-internal-format
 #| msgid "target attribute or pragma changes SPE ABI"
 msgid "unknown target attribute or pragma %qs"
 msgstr "目标属性或 pragma 改变了 SPE ABI"
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "%<asm%> flags not supported in thumb1 mode"
@@ -42522,164 +42501,164 @@ msgstr "%s：支持的体系结构："
 msgid "unknown core architecture %qs specified with %qs"
 msgstr "不能为%q+D指定对齐"
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic is not supported"
 msgid "%<-fpic%> is not supported"
 msgstr "不支持 -fpic"
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIC is not supported"
 msgid "%<-fPIC%> is not supported"
 msgstr "不支持 -fPIC"
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, fuzzy, gcc-internal-format
 msgid "%<-fpie%> is not supported"
 msgstr "不支持"
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, fuzzy, gcc-internal-format
 msgid "%<-fPIE%> is not supported"
 msgstr "不支持"
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "-flto and -fwhopr 互斥"
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qD不能有默认参数"
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "不正确的函数返回值"
 
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, fuzzy, gcc-internal-format
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs似乎是一个拼写错的信号处理者"
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, gcc-internal-format
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, fuzzy, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr "‘builtin_return_address’只包含两字节地址"
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, fuzzy, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr "相对符号的指针偏移量可能不正确。"
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr "用程序内存地址访问数据内存"
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, fuzzy, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr "用程序内存地址访问数据内存"
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr "用以传递整数参数的寄存器个数"
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, fuzzy, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "不兼容的地址空间限定符%qs和%qs"
 
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables and functions"
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "%qE属性只能为变量或函数所使用"
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported for R8C target"
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "%qE属性在 R8C 目标机上不受支持"
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr "已弃用。此开关不起作用。"
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, fuzzy, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "嵌套函数蹦床在此目标机上不受支持"
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, fuzzy, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, fuzzy, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr "条件表达式中使用了指向不相交地址空间的指针"
 
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, fuzzy, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr "条件表达式中使用了指向不相交地址空间的指针"
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables and functions"
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr "%qE属性只能为变量或函数所使用"
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr "变量 %q+D 必须是常数以便是置放进入只读区段依靠 %qs"
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, fuzzy, gcc-internal-format
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr "%q+D的声明隐藏了一个形参"
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, fuzzy, gcc-internal-format
 #| msgid "only uninitialized variables can be placed in the .noinit section"
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr "只有未初始化的变量才能放在 .noinit 节中"
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr "只有初始化的变量才能放入程序内存区"
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "只有初始化的变量才能放入程序内存区"
@@ -42688,43 +42667,43 @@ msgstr "只有初始化的变量才能放入程序内存区"
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr "可分配的‘%s’在%L处不能有初始值设定"
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, fuzzy, gcc-internal-format
 #| msgid "%qE incompatible attribute ignored"
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%qE不兼容的属性已被忽略"
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, fuzzy, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr "MCU%qs只支持汇编器"
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, fuzzy, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "不兼容的地址空间限定符%qs和%qs"
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "字符串常量中出现非预期的模块结束"
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%qs需要一个常量实参"
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, fuzzy, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr "对两个互斥的相等比较取%<and%>的结果永远是 0"
@@ -42874,7 +42853,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "嵌套函数在此目标机上不受支持"
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, gcc-internal-format
@@ -43532,8 +43511,8 @@ msgstr "倒数第二个实参必须是一个 8 位立即数"
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "代码模式 %s 在 PIC 模式下不受支持"
@@ -43601,278 +43580,278 @@ msgstr "%qs没有指定类名"
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr "%L处参数列表函数未知"
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "已弃用%stune=x86-64%s；请视情况改用%stune=k8%s或%stune=generic%s"
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "已弃用%stune=x86-64%s；请视情况改用%stune=k8%s或%stune=generic%s"
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte 不支持用于 32 位代码"
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte 不支持用于 32 位代码"
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte 不支持用于 32 位代码"
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte 不支持用于 32 位代码"
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, fuzzy, gcc-internal-format
 #| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte 不支持用于 32 位代码"
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, fuzzy, gcc-internal-format
 #| msgid "%<-Wabi=1%> is not supported, using =2"
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "%<-Wabi=1%> 不受支持，将使用 =2"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, fuzzy, gcc-internal-format
 #| msgid "-fsanitize=address is incompatible with -fsanitize=kernel-address"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "-fsanitize=address 与 -fsanitize=kernel-address 不兼容"
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, fuzzy, gcc-internal-format
 #| msgid "-fsanitize=address is incompatible with -fsanitize=kernel-address"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "-fsanitize=address 与 -fsanitize=kernel-address 不兼容"
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, fuzzy, gcc-internal-format
 #| msgid "cannot specify -static with -fsanitize=thread"
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "不能同时指定 -static 及 -fsanitize=thread"
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, fuzzy, gcc-internal-format
 #| msgid "-masm=intel not supported in this configuration"
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-masm=intel 在此配置下不受支持"
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "未编译入对 %i 位模式的支持"
 
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "您选择的 CPU 不支持 x86-64 指令集"
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "-march= 的值(%s)不正确"
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %sarch=%s %s"
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "%2$sarch=%3$s %4$s所带参数(%1$s)不正确"
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %qs for -mtune switch"
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "-mtune 开关的值%qs错误"
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %stune=%s %s"
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "%2$stune=%3$s%4$s所带参数(%1$s)不正确"
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d 不在 0 和 %d 之间"
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "-mnop-mcount 与此目标不兼容"
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s 在 64 位模式下被忽略"
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s 在 64 位模式下被忽略"
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr ""
@@ -43880,309 +43859,309 @@ msgstr ""
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr ""
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "堆栈限制在此目标机上不受支持"
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 的值不在 %d 和 %d 之间"
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, fuzzy, gcc-internal-format
 #| msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d 不在 %d 和 12 之间"
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "-mnop-mcount 与此目标不兼容"
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "模块间优化未为 C++ 实现"
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "使用了 %ssseregparm%s 却没有启用 SEE"
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "使用了 %ssseregparm%s 却没有启用 SEE"
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 指令集已禁用，使用 387 指令"
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 指令集已禁用，使用 SSE 指令"
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, fuzzy, gcc-internal-format
 #| msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "-mfentry 在 32 位下不能和 -fpic 同时使用"
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry 与 SEH 不兼容"
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "未知的选项：%s %s %s"
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr ""
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "-mnop-mcount 与此目标不兼容"
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, fuzzy, gcc-internal-format
 #| msgid "ms_abi and sysv_abi attributes are not compatible"
 msgid "%qs and %qs attributes are not compatible"
 msgstr "ms_abi 和 sysv_abi 属性互不兼容"
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 与 -mcall-%s 互不兼容"
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 与 -mcall-%s 互不兼容"
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, fuzzy, gcc-internal-format
 #| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "2 字节 cop 指针不允许被用在 VLIW 模式中"
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr "为每个函数使用堆栈保护机制"
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall 和 regparm 属性互不兼容"
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE属性需要一个整常量作为实参"
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qE属性的实参大于 %d"
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall 和 stdcall 属性互不兼容"
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall 和 fastcall 属性互不兼容"
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl 和 thiscall 属性互不兼容"
 
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE不兼容的属性已被忽略"
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE属性只能在 32 位下使用"
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt function must have no arguments"
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "中断函数不能有参数"
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine must return %<void%>"
@@ -44389,48 +44368,48 @@ msgstr "扩展的寄存器不支持的操作数大小"
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "非整数操作数使用了操作数代码‘%c’"
 
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr ""
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, fuzzy, gcc-internal-format
 #| msgid "no low registers available for popping high registers"
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr "高寄存器弹栈时没有可用的低寄存器"
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "32 位系统不支持 -mcmodel="
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr ""
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "未知的架构特定的内存模型"
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, fuzzy, gcc-internal-format
 #| msgid "-fdirectives-only is incompatible with -traditional"
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
@@ -44452,8 +44431,8 @@ msgstr "%q#D是一个静态数据成员；它只能在定义时被初始化"
 msgid "malformed %<#pragma builtin%>"
 msgstr "#pragma builtin 格式错误"
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, gcc-internal-format
 msgid "invalid argument of %qE attribute"
 msgstr "属性%qE的参数无效"
@@ -44513,12 +44492,12 @@ msgstr "PRINT_OPERAND：未知的标点‘%c’"
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr "PRINT_OPERAND 空指针"
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "实参必须是常数"
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, fuzzy, gcc-internal-format
 #| msgid "failed to reclaim unneeded function"
 msgid "failed to expand built-in function"
@@ -44652,19 +44631,19 @@ msgstr "选择%qD而不是%qD"
 msgid "%qs cannot be used for compiling a shared library"
 msgstr "%<constexpr%>不能被用作类型声明"
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr "不能为局部变量指定%qE属性"
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute cannot be specified for local variables"
 msgid "%qE attribute cannot be specified for register variables"
 msgstr "不能为局部变量指定%qE属性"
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "multiple %qE attribute"
@@ -44775,12 +44754,12 @@ msgstr "不允许多个中断属性"
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr "interrupt_thread 只在 fido 中可用"
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "不支持堆栈限制表达式"
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-protector not supported for this target"
 msgid "%<-fexcess-precision=16%> is not supported on this target"
@@ -44825,7 +44804,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr "-mxl-multiply-high 需要 -mno-xl-soft-mul"
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires a string constant argument"
 msgid "%qE attribute requires a string argument"
@@ -44867,136 +44846,136 @@ msgstr ""
 msgid "argument to %qE attribute is not intstack"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, gcc-internal-format
 msgid "cannot handle inconsistent calls to %qs"
 msgstr "无法处理对%qs不一致的调用"
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, fuzzy, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr "%<interrupt%>属性需要 MIPS32r2 处理器"
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr "中断处理程序不能是 MIPS16 函数"
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr ""
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, gcc-internal-format
 msgid "built-in function %qE not supported for MIPS16"
 msgstr "MIPS16 不支持内建函数%qE"
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, gcc-internal-format
 msgid "%qs does not support MIPS16 code"
 msgstr "%qs不支持 MIPS16 代码"
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr "MIPS16 PIC 代码的 ABI 不是 o32 或 o64"
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, fuzzy, gcc-internal-format
 #| msgid "MIPS16 -mxgot code"
 msgid "MIPS16 %<-mxgot%> code"
 msgstr "MIPS16 -mxgot 代码"
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, fuzzy, gcc-internal-format
 #| msgid "hard-float MIPS16 code for ABIs other than o32 and o64"
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr "硬件浮点 MIPS16 代码的 ABI 不是 o32 或 o64"
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, fuzzy, gcc-internal-format
 #| msgid "Generate MIPS16 code"
 msgid "MSA MIPS16 code"
 msgstr "生成 MIPS16 代码"
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr "%<-mno-gpopt%>需要%<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported combination: %s"
 msgstr "不支持的组合：%s"
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, gcc-internal-format
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr "%<-%s%>与指定了 %s 处理器的其他架构选项冲突"
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, gcc-internal-format
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr "%<-march=%s%>与所选 ABI 不兼容"
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr "%<-mgp64%>与 32 位处理器一起使用"
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, gcc-internal-format
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr "%<-mgp32%>与 64 位 ABI 一起使用"
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr "%<-mgp64%>与 32 位 ABI 一起使用"
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "%qs 架构不支持 %<-mfp32%>"
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr "%<-mgp32%>和%<-mfp64%>只有当目标机支持 mfhc1 和 mthc1 指令时才能一起使用"
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr "%<-mgp32%>和%<-mfp64%>只有当使用 o32 ABI 时才能一起使用"
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, fuzzy, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr "%<-mgp32%>和%<-mfp64%>只有当使用 o32 ABI 时才能一起使用"
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr "%<-march=%s%>与所选 ABI 不兼容"
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr "%<-mfpxx%> 需要 %<-mlra%>"
@@ -45006,119 +44985,119 @@ msgstr "%<-mfpxx%> 需要 %<-mlra%>"
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, fuzzy, gcc-internal-format
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr "不兼容的地址空间限定符%qs和%qs"
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, gcc-internal-format
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr "%qs架构不支持 Branch-Likely 指令"
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, gcc-internal-format
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr "%qs 架构不支持 madd 或 msub 指令"
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr "%qs架构不支持配对单精度指令"
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported combination: %qs%s %s"
 msgstr "不支持的组合：%s"
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported combination: %qs %s"
 msgstr "不支持的组合：%s"
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, fuzzy, gcc-internal-format
 msgid "cannot generate position-independent code for %qs"
 msgstr "尽可能生成与位置无关的代码(大模式)"
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, fuzzy, gcc-internal-format
 msgid "position-independent code requires %qs"
 msgstr "尽可能生成与位置无关的代码(大模式)"
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr "%<-mno-gpopt%>需要%<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr "不能为%qs使用小数据访问"
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr "%qs 架构不支持 %<-m%s=legacy%>"
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr "%qs 架构不支持 %<-m%s=2008%>"
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, gcc-internal-format
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr "%<-mips3d%>需要%<-mpaired-single%>"
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, gcc-internal-format
 msgid "%qs must be used with %qs"
 msgstr "%qs必须与%qs一起使用"
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, gcc-internal-format
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr ""
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, gcc-internal-format
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr "%qs架构不支持配对单精度指令"
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr "%qs需要一个能提供%qs指令的目标机"
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, gcc-internal-format
 msgid "the %qs architecture does not support DSP instructions"
 msgstr "%qs 架构不支持 DSP 诸指令"
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, gcc-internal-format
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr ""
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, gcc-internal-format
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr ""
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, gcc-internal-format
 msgid "%qs requires branch-likely instructions"
 msgstr "%qs需要 Branch-Likely 指令"
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, gcc-internal-format
 msgid "the %qs architecture does not support the synci instruction"
 msgstr "%qs架构不支持 synci 指令"
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr "mips16 函数取样"
@@ -46021,57 +46000,57 @@ msgstr "%<#pragma GCC optimize%>不是字符串或数字"
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "未知‘# pragma externmodel’式样‘%s’(_M)"
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, fuzzy, gcc-internal-format
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr "%qE在数据子句中多次出现"
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, fuzzy, gcc-internal-format
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr "%qE在数据子句中多次出现"
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, fuzzy, gcc-internal-format
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr "%qE在数据子句中多次出现"
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> attribute"
 msgstr "异常的 URL"
 
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%s 只接受 2 个参数"
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, fuzzy, gcc-internal-format
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr "不能设置只读属性"
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> attribute"
 msgstr "异常的 URL"
@@ -46140,181 +46119,201 @@ msgstr "无法为有抽象类型%qT的对象分配内存"
 msgid "capture by copy of RVV type %qT"
 msgstr "向 void 的类型转换不会访问具有不完全类型%qT的对象"
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr "内建函数%q+D未被声明为函数"
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr "内建函数%q+D未被声明为函数"
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr "内建函数%q+D未被声明为函数"
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr "内建函数%q+D未被声明为函数"
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, fuzzy, gcc-internal-format
 msgid "no matching function call to %qE with empty arguments"
 msgstr "对%<%D(%A)%>的调用没有匹配的函数"
 
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %qs for -mtune"
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "-mtune 参数的值 %qs 未知"
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, fuzzy, gcc-internal-format
 msgid "this operation requires the RVV ISA extension"
 msgstr "不使用位段指令"
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "在 GCC 4.4 中传递带有复数浮点成员结构的 ABI 有了改变"
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr "传递 AltiVec 参数给无原型的函数"
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the V ISA extension"
 msgstr "目标属性或 pragma 改变了 SPE ABI"
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr "目标属性或 pragma 改变了 SPE ABI"
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr "目标属性或 pragma 改变了 SPE ABI"
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr "目标属性或 pragma 改变了 SPE ABI"
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr "目标属性或 pragma 改变了 SPE ABI"
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, fuzzy, gcc-internal-format
 msgid "function attribute %qs requires the V ISA extension"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr ""
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, fuzzy, gcc-internal-format
 msgid "%qs applied to non-RVV type %qT"
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, fuzzy, gcc-internal-format
 #| msgid "case label is not an integer constant expression"
 msgid "%qs requires an integer constant"
 msgstr "case 标号不是一个整数常量表达式"
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support ARM mode"
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr "目标 CPU 不支持 ARM 模式"
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, fuzzy, gcc-internal-format
 msgid "code model %qs with %qs"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr "rv32e 需要 ilp32e ABI"
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, fuzzy, gcc-internal-format
 #| msgid "rv32e requires ilp32e ABI"
 msgid "rv64e requires lp64e ABI"
 msgstr "rv32e 需要 ilp32e ABI"
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr ""
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mfpxx%> requires %<-mlra%>"
 msgid "ABI requires %<-march=rv%d%>"
 msgstr "%<-mfpxx%> 需要 %<-mlra%>"
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, fuzzy, gcc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 的值不在 %d 和 %d 之间"
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs没有指定类名"
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs对%qs而言无效"
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qD不能有默认参数"
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, fuzzy, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr "堆栈限制在此目标机上不受支持"
@@ -46584,33 +46583,33 @@ msgstr "%s 只接受 1 个参数"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s 只接受 1 个参数"
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr "传递%2$qE的第 %1$d 个实参时丢弃了指针目标类型的限定"
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "对 AltiVec 内建函数来说无效的参数组合"
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, fuzzy, gcc-internal-format
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
@@ -46655,30 +46654,22 @@ msgstr "操作数类型%qT和%qT对双目%qO而言无效"
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 传递向量引用：非标准的 ABI 扩展，不保证兼容性"
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, fuzzy, gcc-internal-format
-#| msgid "Use the ELFv2 ABI."
-msgid "%qs requires the ELFv2 ABI"
-msgstr "使用 ELFv2 ABI。"
-
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "栈帧太大"
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported number of nops before function entry (%u)"
 msgstr "提供给函数%qE的实参太多"
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, fuzzy, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "ISO C90 不允许可变数组成员"
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
@@ -46813,111 +46804,122 @@ msgstr "调用篡改寄存器用作全局寄存器变量"
 msgid "unknown option for %<%s=%s%>"
 msgstr "未知的选项：%s %s %s"
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4837
+#, fuzzy, gcc-internal-format
+#| msgid "Use the ELFv2 ABI."
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr "使用 ELFv2 ABI。"
+
+#: config/rs6000/rs6000.cc:4855
 #, fuzzy, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "已弃用。此开关不起作用。"
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "此 ABI 不支持取样 64 位代码"
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "您无法需地址的嵌套的函数如果您使用 -mno-pointers-to-nested-functions 选项。"
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用%<long double%>无效"
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用布尔类型无效"
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用%<complex%>无效"
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, fuzzy, gcc-internal-format
 #| msgid "use of decimal floating point types in AltiVec types is invalid"
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用十进制浮点类型无效"
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<long%>对 64 位代码无效"
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "已弃用在 AltiVec 类型中使用%<long%>；请改用%<int%>"
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<long long%>无效"
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<double%>无效"
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "%s：无效的目的：%s\n"
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s：不允许空权字符串"
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s 无效"
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-march=%s%>与所选 ABI 不兼容"
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "联合成员函数%qD被声明为虚函数"
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr "内建函数%q+D未被声明为函数"
@@ -46963,7 +46965,7 @@ msgstr "RX FPU  指令不支持 NaN 和无限"
 msgid "builtin %qs can only be used on vector types"
 msgstr "只能为函数指定%qs"
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, fuzzy, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "%<__builtin_frame_address%>的实参无效"
@@ -47035,242 +47037,242 @@ msgstr "已弃用%qE"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "常量实参超过%qs的范围"
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr "常量实参超过%qs的范围"
 
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr "常量实参超过%qs的范围"
 
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr "常量实参超过%qs的范围"
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, fuzzy, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, fuzzy, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "unresolved overloaded builtin"
 msgstr "<未解决的重载函数类型>"
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, fuzzy, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "错误的内建 fcode"
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "invalid argument %d for builtin %qF"
 msgstr "内建函数实参无效"
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, fuzzy, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "局部变量大小总和超过架构极限"
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, fuzzy, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr "影格大小的函数 %qs 是 %wd 字节超出用户提供的堆叠限制的 %d 字节。 unconditional 陷阱被已加入。"
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, fuzzy, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr "影格大小的函数 %qs 是 %wd 字节该项是超过半堆叠大小。动态检查会无法是 reliable。没有检查发出用于这个函数。"
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "栈帧大小不是 8 字节的倍数：%wd"
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs使用动态栈分配"
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr ""
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "嵌套函数%qs被声明为%<extern%>"
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "hardware vector support not available on %s"
 msgstr "硬件十进制浮点指令在 %s 上不可用"
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, fuzzy, gcc-internal-format
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr "硬件十进制浮点指令在 %s 上不可用"
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr "硬件十进制浮点指令在 %s 上不可用"
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, fuzzy, gcc-internal-format
 #| msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr "硬件十进制浮点指令在 ESA/390 模式下不可用"
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, fuzzy, gcc-internal-format
 #| msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float 一起使用不受支持"
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "栈大小必须大于栈防护值"
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "栈大小不能大于 64K"
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard 意味着使用 -mstack-size"
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is supported only for SH2A"
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%qE属性只为 SH2A 所支持"
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "“%s”的实参应该是一个非负整数"
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%qE属性的实参大于 %d"
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, fuzzy, gcc-internal-format
 msgid "invalid cc output constraint: %qs"
 msgstr "%<#pragma pack%>中有无效常量 - 已忽略"
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, fuzzy, gcc-internal-format
 #| msgid "-mhard-float not supported"
 msgid "multiple cc output constraints not supported"
 msgstr "不支持 -mhard-float"
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, fuzzy, gcc-internal-format
 #| msgid "asm-specifier for variable %qE conflicts with asm clobber list"
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr "变量%qE的 asm 指定与 asm 篡改列表冲突"
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, fuzzy, gcc-internal-format
 msgid "invalid type for cc output constraint"
 msgstr "向函数类型%qT的转换无效"
@@ -47727,8 +47729,8 @@ msgstr "语句不起作用"
 msgid "attribute %qs applies to array types only"
 msgstr "%qs属性只能为数组类型使用"
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void 值未如预期地被忽略"
@@ -47805,7 +47807,7 @@ msgstr "数组%q+D类型与隐式初始化不兼容"
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr "%qD已在此作用域中声明过"
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "原先在这里定义"
@@ -48049,7 +48051,7 @@ msgstr "%q+D的声明隐藏了先前的一个非变量声明"
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D的声明隐藏了一个形参"
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%qD的声明隐藏了一个全局声明"
@@ -48059,7 +48061,7 @@ msgstr "%qD的声明隐藏了一个全局声明"
 msgid "declaration of %qD shadows a previous local"
 msgstr "%qD的声明隐藏了先前的一个局部变量"
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "被隐藏的声明在这里"
@@ -48127,7 +48129,7 @@ msgstr "%qE未声明(在此函数内第一次使用)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "每个未声明的标识符在其出现的函数内只报告一次"
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "标号%qE在所有函数外被引用"
@@ -48162,7 +48164,7 @@ msgstr "跳转至语句表达式中"
 msgid "duplicate label declaration %qE"
 msgstr "重复的标号定义%qE"
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "重复的标号%qD"
@@ -48198,7 +48200,7 @@ msgstr "开关跳转至语句表达式中"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE定义为类型错误的标记"
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "%qE属性在类型上被忽略"
@@ -48347,12 +48349,12 @@ msgstr "ISO C90 不支持%<[*]%>数组声明"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%>不能用于函数原型以外"
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<omp::%s%> not allowed to be specified in this context"
@@ -48363,7 +48365,7 @@ msgstr "%<this%>不能用在此上下文中"
 msgid "%q+D is usually a function"
 msgstr "%q+D通常是一个函数"
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%qD先前没有声明"
@@ -48443,7 +48445,7 @@ msgstr "不能将带有 volatile 字段的对象放入寄存器"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "未初始化的常量%qD在C++中是无效的"
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -48633,7 +48635,7 @@ msgstr "为形参%qE指定了存储类"
 msgid "storage class specified for unnamed parameter"
 msgstr "为无名形参指定了存储类"
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "为类型名指定了存储类"
@@ -48696,7 +48698,7 @@ msgstr "%qE声明为函数的数组"
 msgid "declaration of type name as array of functions"
 msgstr "类型名声明为函数的数组"
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "对包含可变数组成员的结构的无效使用"
@@ -48806,7 +48808,7 @@ msgstr "类型名声明为返回一个数组的函数"
 msgid "function definition has qualified void return type"
 msgstr "函数定义有限定的 void 返回类型"
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "忽略函数返回类型的类型限定"
@@ -48933,7 +48935,7 @@ msgstr "ISO C 不允许使用 const 或 volatile 限定函数类型"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "结构或联合成员不能具有可变类型"
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "变量或字段%qE声明为 void"
@@ -49041,7 +49043,7 @@ msgstr "非嵌套函数有动态可变类型"
 msgid "object with variably modified type must have no linkage"
 msgstr "可变类型对象不能有外部链接"
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "函数声明不是一个原型"
@@ -49131,18 +49133,18 @@ msgstr "嵌套的%<union %E%>重定义"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "嵌套的%<struct %E%>重定义"
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "C++ 不允许在%qs表达式中定义类型"
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, fuzzy, gcc-internal-format
 #| msgid "unknown field %qE specified in initializer"
 msgid "%qT defined in underspecified object initializer"
 msgstr "初始值设定项里有未知的字段%qE"
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "没有声明任何东西"
@@ -49172,614 +49174,614 @@ msgstr ""
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "联合包含无名成员"
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "联合体没有成员"
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "结构不包含任何有名成员"
 
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "结构体没有成员"
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "联合和可变数组成员"
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in union"
 msgid "flexible array member in a struct with no named members"
 msgstr "联合和可变数组成员"
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "类型 %qT 过大"
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, fuzzy, gcc-internal-format
 msgid "type punning toggles scalar storage order"
 msgstr "无效的 --param 值%qs"
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "联合不能成为透明的"
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, fuzzy, gcc-internal-format
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr "typedef%q+D重定义时具有不同类型"
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %<struct %E%>"
 msgid "redefinition of struct or union %qT"
 msgstr "%<struct %E%>重定义"
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "嵌套的%<enum %E%>重定义"
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%>重声明"
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
 msgstr "指定的模式对枚举值来说太小"
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "枚举值超过了最大整数类型可表示的范围"
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration values exceed range of largest integer"
 msgid "enumeration values exceed range of %qs"
 msgstr "枚举值超过了最大整数类型可表示的范围"
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of %<enum %E%>"
 msgid "conflicting redefinition of enum %qT"
 msgstr "嵌套的%<enum %E%>重定义"
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "%qE的枚举值不是一个整数常量"
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "%qE的枚举值不是一个整数常量"
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "枚举值溢出"
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, fuzzy, gcc-internal-format
 msgid "enumerator value outside the range of underlying type"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, fuzzy, gcc-internal-format
 msgid "enumerator value outside the range of %qs"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr "ISO C 将枚举值限制在%<int%>范围内"
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %qD given attribute noinline"
 msgid "inline function %qD given attribute %qs"
 msgstr "内联函数%qD给定了非内联属性"
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "返回不完全的类型"
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "返回类型默认为%<int%>"
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, fuzzy, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "嵌套函数%q+D声明过但从未定义"
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "%qD先前没有原型"
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "使用%qD时先前既没有原型也没有定义"
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "使用%qD时先前既没有声明也没有定义"
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "%qD的返回类型不是%<int%>"
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "调用了有限定 void 返回类型的函数"
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD通常不是一个静态函数"
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "原型函数定义中使用了旧式参数声明"
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "传统 C 不接受 ISO C 风格的函数定义"
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C99 does not support %<_Static_assert%>"
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr "ISO C90 不支持%<_Static_assert%>"
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "旧式的函数定义"
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "形参列表中缺少形参名"
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD没有声明为一个参数"
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "多个名为%qD的形参"
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "形参%qD被声明为有 void 类型"
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "%qD的类型默认为%<int%>"
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "形参%qD类型不完全"
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "声明的形参%qD不存在"
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "实参个数与内建原型不符"
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "实参数目与原型不符"
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "原型声明"
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "提升后的实参%qD与内建原型不符"
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "提升后的实参%qD与原型不符"
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "实参%qD与内建原型不符"
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "实参%qD与原型不符"
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "在有返回值的函数中未发现 return 语句"
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "形参%qD被设定但未被使用"
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "只允许在 C99 模式下使用%<for%>循环初始化声明"
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, fuzzy, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "使用 -std=c99 或 -std=gnu99 来编译您的代码"
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 不支持%<[*]%>数组声明"
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "在%<for%>循环初始声明中声明了静态变量%qD"
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "在%<for%>循环初始声明中声明了%<extern%>变量%qD"
 
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%>声明于%<for%>循环初始声明中"
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%>声明于%<for%>循环初始声明中"
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%>声明于%<for%>循环初始声明中"
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "在%<for%>循环初始声明中声明了非变量%qD"
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "不兼容的地址空间限定符%qs和%qs"
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "需要指定声明"
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "声明指定了多个存储类"
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %<auto%>"
 msgstr "%qE不能用作函数"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> used with %<constexpr%>"
 msgstr "无效的协寄存器%qE"
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "声明指定了两个以上的数据类型"
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%>对 GCC 来说太长了"
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 不支持%<long long%>"
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 不支持复数类型"
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C 不支持饱和类型"
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "重复的%qE"
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C 不支持 %<__int%d%> 类型"
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 不支持布尔类型"
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support %<__int%d%> types"
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr "ISO C 不支持 %<__int%d%> 类型"
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support decimal floating point"
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr "ISO C 不支持十进制浮点数"
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "定点类型在此目标机上不受支持"
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C 不支持定点类型"
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, fuzzy, gcc-internal-format
 #| msgid "case label is not an integer constant expression"
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr "case 标号不是一个整数常量表达式"
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant expression"
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr "%qE的枚举值不是一个整数常量"
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr ""
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "%qD的 C++ 查询会返回一个字段而非类型"
 
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE不是一个 typedef 类型，也不是一个内建类型"
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE没有出现在声明的开头"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE不能用作函数"
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "无效的协寄存器%qE"
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE不是一个 typedef 类型，也不是一个内建类型"
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<constexpr%>"
 msgstr "无效的协寄存器%qE"
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 不支持 %qE"
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 不支持 %qE"
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%>出现在%<extern%>之前"
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%>出现在%<static%>之前"
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> used with %<auto%>"
 msgstr "%qE不能用作函数"
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<extern%>"
 msgstr "无效的协寄存器%qE"
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %qs"
 msgstr "%qE可被预先确定为%qs，为%qs"
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "线程局部的 COMMON 数据没有实现"
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qE可被预先确定为%qs，为%qs"
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> used with %qE"
 msgstr "%qE可被预先确定为%qs，为%qs"
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%>使用时缺少%<_Fract%>或%<_Accum%>"
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支持单独用%<complex%>表示%<double complex%>"
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr "ISO C90 不支持%<[*]%>数组声明"
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C 不支持复整数"
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, fuzzy, gcc-internal-format
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr "固定格式的行长至少为七。"
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr "ISO C++ 对 %2$qs 不支持 %<__int%1$d%>"
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "左移次数为负"
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "左移次数为负"
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "右移次数为负"
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "左移次数大于或等于类型宽度"
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "右移次数大于或等于类型宽度"
@@ -49811,7 +49813,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "没有匹配"
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "需要行尾"
@@ -49821,8 +49823,8 @@ msgstr "需要行尾"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C 不允许翻译单元为空"
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr ""
@@ -49864,9 +49866,9 @@ msgstr "%qT没有名为%qE的成员"
 msgid "unknown type name %qE"
 msgstr "未知的类型名%qE"
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "需要指定声明"
@@ -49899,7 +49901,7 @@ msgstr "%q+D不能有 section 属性"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "需要标识符或%<(%>"
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "属性在未初始化类型上被忽略"
@@ -49920,7 +49922,7 @@ msgstr "非预期的属性"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "%q+D不能有 section 属性"
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<assume%> attribute not followed by %<;%>"
@@ -50013,7 +50015,7 @@ msgstr "静态断言中出现非常量条件"
 msgid "static assertion failed: %E"
 msgstr "静态断言错误：%E"
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
@@ -50089,10 +50091,10 @@ msgstr "模板第 %d 个参数无效"
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "需要标识符"
@@ -50250,7 +50252,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr ""
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr ""
@@ -50260,8 +50262,8 @@ msgstr ""
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr "%qE属性需要带有名实参的原型"
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized address"
 msgid "unknown OpenMP directive name in %qs attribute argument"
@@ -50439,12 +50441,12 @@ msgstr "ISO C 不允许省略 ?: 表达式中的第二项"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was declared here"
 msgid "first %<sizeof%> operand was declared here"
@@ -50600,7 +50602,7 @@ msgstr "ISO C90 不支持 %<__func__%> 预定义标识符"
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, gcc-internal-format
 msgid "expected expression"
 msgstr "需要表达式"
@@ -50933,12 +50935,12 @@ msgstr "%C处数组声明需要另外一维"
 msgid "no type or storage class may be specified here,"
 msgstr "为%qs指定了存储类"
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, fuzzy, gcc-internal-format
 msgid "empty property attribute list"
 msgstr "不能设置只读属性"
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, fuzzy, gcc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing property attribute"
@@ -50949,61 +50951,61 @@ msgstr "缺少 Code 属性"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "不能设置只读属性"
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不能设置只读属性"
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected %qE selector name"
 msgstr "需要选择语句"
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, fuzzy, gcc-internal-format
 #| msgid "setter name must terminate with %<:%>"
 msgid "setter method names must terminate with %<:%>"
 msgstr "setter 的名字必须以%<:%>结尾"
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr ""
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%>只能用在复合语句中"
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "Objective-C 声明只能出现在全局作用域中"
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<#pragma omp section%>只能用在%<#pragma omp sections%>结构中"
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%>只能用在%<#pragma omp sections%>结构中"
@@ -51014,25 +51016,25 @@ msgstr "%<#pragma omp section%>只能用在%<#pragma omp sections%>结构中"
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr "%<#pragma omp barrier%>只能用在复合语句中"
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "需要语句"
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%>必须是第一个"
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "太多的%qs子句"
@@ -51048,70 +51050,70 @@ msgstr "调度块大小表达式必须为整型"
 msgid "expected %<)%> or %<,%>"
 msgstr "需要 %<,%> 或 %<)%>"
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD不是一个变量"
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD不是一个变量"
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "折叠参数需要正整常量表达式"
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "需要%<none%>或%<shared%>"
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected constant logical expression"
 msgstr "需要表达式"
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "需要%<catch%>"
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -51134,23 +51136,23 @@ msgstr "%<num_threads%>值必须为正"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "需要整数表达式"
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, fuzzy, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "启用最小/最大值指令"
@@ -51161,102 +51163,102 @@ msgstr "启用最小/最大值指令"
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "太多 %<static%> 参数"
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "非预期的参数"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE属性需要一个整常量作为实参"
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<self%> clauses"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr "需要%<none%>或%<shared%>"
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<new%>"
 msgid "expected %<concurrent%>"
 msgstr "需要%<new%>"
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "折叠参数需要正整常量表达式"
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "需要标识符或%<(%>"
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "调度%<runtime%>不接受一个%<chunk_size%>参数"
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "调度%<auto%>不接受一个%<chunk_size%>参数"
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "无效的调度类型"
@@ -51266,22 +51268,22 @@ msgstr "无效的调度类型"
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr ""
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<allocator%> or %<align%>"
@@ -51293,22 +51295,22 @@ msgstr "需要 %<,%> 或 %<)%>"
 msgid "duplicate %qs modifier"
 msgstr "重复的%qs"
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, fuzzy, gcc-internal-format
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, fuzzy, gcc-internal-format
 msgid "multiple linear modifiers"
 msgstr "%q+D的类型限定冲突"
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "multiple %<step%> modifiers"
@@ -51329,66 +51331,66 @@ msgstr "%H折叠变量需要正整常数表达式"
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, fuzzy, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "%qs必须与%qs一起使用"
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "无效的调度类型"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, fuzzy, gcc-internal-format
 msgid "invalid doacross kind"
 msgstr "无效的实型种别 %d，在%C处"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<always%> modifiers"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<close%> modifiers"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<present%> modifiers"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, fuzzy, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "无效的实型种别 %d，在%C处"
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr ""
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr "需要%<none%>或%<shared%>"
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, fuzzy, gcc-internal-format
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr "调度块大小表达式必须为整型"
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "无效的调度类型"
@@ -51404,92 +51406,92 @@ msgstr "无效的调度类型"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected an OpenACC clause"
 msgstr "需要指针"
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs对%qs而言无效"
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected an OpenMP clause"
 msgstr "需要指针"
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "%qD的声明隐藏了一个全局声明"
 
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "指定链接时使用%qD无效"
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified field at file scope"
 msgid "invalid OpenACC clause at file scope"
 msgstr "文件域中的动态可变字段"
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "在%<for%>循环初始声明中声明了%<extern%>变量%qD"
 
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "指定链接时使用%qD无效"
 
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "指定链接时使用%qD无效"
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<#pragma message%>后需要一个字符串"
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr ""
@@ -51505,7 +51507,7 @@ msgstr "%qE未声明"
 msgid "expected function name"
 msgstr "需要函数"
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a function"
@@ -51516,22 +51518,22 @@ msgstr "%qD不是一个成员模板函数"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
@@ -51559,7 +51561,7 @@ msgstr ""
 msgid "modified here"
 msgstr "联合在此定义"
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, fuzzy, gcc-internal-format
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
@@ -51602,117 +51604,117 @@ msgstr ""
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr "#pragma vtable 不再受支持"
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "需要标识符或%<(%>"
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many atomic clauses"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many memory order clauses"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, fuzzy, gcc-internal-format
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs clause requires %qs clause"
 msgstr "%qT作为%qs被引用"
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after union definition"
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr "联合定义后需要%<;%>"
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, gcc-internal-format
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr ""
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr "%<#pragma omp atomic%>运算符无效"
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<delete%>"
 msgid "unexpected %<else%>"
 msgstr "需要%<delete%>"
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr "%<#pragma omp atomic%>运算符无效"
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%>运算符无效"
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%>运算符无效"
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr ""
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用两不同的变量用于内存"
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "整型表达式%qE不是常量"
@@ -51722,30 +51724,30 @@ msgstr "整型表达式%qE不是常量"
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr "整型表达式%qE不是常量"
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr ""
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -51755,171 +51757,171 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "需要%<(%>或行尾"
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr "%<#pragma omp flush%>只能用在复合语句中"
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "需要%<none%>或%<shared%>"
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma omp scan%>"
 msgstr "需要%<#pragma omp%>子句"
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr "%<#pragma omp flush%>只能用在复合语句中"
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "需要迭代声明或初始化"
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, fuzzy, gcc-internal-format
 #| msgid "not enough perfectly nested loops"
 msgid "not enough nested loops"
 msgstr "不够完美的嵌套循环"
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "需要 for 语句"
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "迭代变量%qD不应当是 firstprivate"
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "{ 预期于运算式中 ? 之后"
 
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected trait selector name"
 msgstr "需要选择语句"
 
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, fuzzy, gcc-internal-format
 msgid "unknown selector %qs for context selector set %qs"
 msgstr "%3$L处哑过程‘%1$s’不能出现在基本过程‘%2$s’中"
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, fuzzy, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "%s 只接受 2 个参数"
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr "%<friend%>只能在类中指定"
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "%<score%> argument must be constant integer expression"
 msgstr "折叠参数需要正整常量表达式"
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, fuzzy, gcc-internal-format
 msgid "%<score%> argument must be non-negative"
 msgstr "%qs必须与%qs一起使用"
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "需要字面字符串"
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "property must be constant integer expression"
 msgstr "需要整数表达式"
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, fuzzy, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "内容 %qs 已经指定的在中 %<@synthesize%>"
@@ -51927,301 +51929,301 @@ msgstr "内容 %qs 已经指定的在中 %<@synthesize%>"
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> selector is not supported yet"
 msgstr "尚未支持代码模式 %<large%>"
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, fuzzy, gcc-internal-format
 #| msgid "expected selection-statement"
 msgid "expected context selector set name"
 msgstr "需要选择语句"
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<match%>"
 msgstr "需要%<catch%>"
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, fuzzy, gcc-internal-format
 msgid "variant %qD is not a function"
 msgstr "在函数%qs中"
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, fuzzy, gcc-internal-format
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "-f%s 和 -msdata=%s 互不兼容"
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, fuzzy, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, fuzzy, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr "使用了变长数组"
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, gcc-internal-format
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr "需要%<none%>或%<shared%>"
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr "%<#pragma GCC pop_options%>缺少相应的%<#pragma GCC push_options%>"
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr ""
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute with %s attribute at %L"
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr "%s 属性与 %s 属性共存在 %L"
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%> or %<assumes%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr "Objective-C 声明只能出现在全局作用域中"
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr "上一个声明"
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, fuzzy, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "上一个声明"
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, fuzzy, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr "需要%<(%>或行尾"
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, fuzzy, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "需要函数"
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "需要%<#pragma omp section%>或%<}%>"
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, fuzzy, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, fuzzy, gcc-internal-format
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr "使用了变长数组"
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, fuzzy, gcc-internal-format
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "使用了变长数组"
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %qs or %qs"
 msgstr "需要 %<,%> 或 %<)%>"
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%>只能用在复合语句中"
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr ""
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr ""
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, fuzzy, gcc-internal-format
 msgid "expected at least one assumption clause"
 msgstr "%L处过程指针赋值中接口不匹配：%s"
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, fuzzy, gcc-internal-format
 #| msgid "expected function"
 msgid "expected directive name"
 msgstr "需要函数"
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr ""
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, fuzzy, gcc-internal-format
 msgid "unknown assumption clause %qs"
 msgstr "不能设置只读属性"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected assumption clause"
 msgstr "需要指针"
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE在其首次使用后被声明为%<threadprivate%>"
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自动变量%qE不能是%<threadprivate%>"
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%>%qE的类型不完全"
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%>而无需 transactional 内存支持已启用"
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%>在之内 %<__transaction_relaxed%>"
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "%<transaction_may_cancel_outer%> 函数调用无法在之内外异动作业或 %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%>无法在之内 %<__transaction_atomic%>"
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, fuzzy, gcc-internal-format
 msgid "no closing brace"
 msgstr "括入并行"
@@ -52370,7 +52372,7 @@ msgstr "提领%<void *%>指针"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "下标运算的左操作数既非数组也非指针"
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "数组下标不是一个整数"
@@ -52401,7 +52403,7 @@ msgstr "%qD声明为引用却未被初始化"
 msgid "enum constant defined here"
 msgstr "枚举常量在此定义"
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -52516,18 +52518,18 @@ msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "提供给函数%qE的实参太少"
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "与字面字符串比较的结构是不可预测的"
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "比较指针和整数"
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -52553,7 +52555,7 @@ msgstr "函数指针不能相减"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "在指向不完全类型的指针上执行算术运算"
 
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "在指向不完全类型的指针上执行算术运算"
@@ -52865,7 +52867,7 @@ msgstr "将一个指针转换为大小不同的整数"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "从类型为%qT的函数调用转换到不匹配的类型%qT"
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "将一个整数转换为大小不同的指针"
@@ -53052,7 +53054,7 @@ msgstr "赋值的左手边可能是 format 属性的备选时"
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "初始化的左手边可能是 format 属性的备选时"
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "返回类型可能是 format 属性的备选"
@@ -53269,12 +53271,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "对可变数组成员的初始化"
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -53284,7 +53286,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr "用字符串常量初始化的数组类型不合适"
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "对非左值数组的使用无效"
@@ -53315,7 +53317,7 @@ msgstr "初始值设定中元素不是常量表达式"
 msgid "initializer element is not computable at load time"
 msgstr "初始值设定中的元素在载入时无法被计算出"
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "不透明的向量类型不能被初始化"
@@ -53330,7 +53332,7 @@ msgstr "初始值设定项末尾有多余的花括号组"
 msgid "braces around scalar initializer"
 msgstr "标量初始化带花括号"
 
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "在嵌套的上下文中初始化可变数组成员"
@@ -53421,7 +53423,7 @@ msgstr "结构初始值设定项中有多余元素"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "对可变数组成员非静态地初始化"
@@ -53461,7 +53463,7 @@ msgstr "ISO C++ 不允许%<goto *expr;%>"
 msgid "computed goto must be pointer type"
 msgstr "%2$qE的实参 %1$d 必须是地址"
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "被声明为%<noreturn%>的函数却有%<return%>语句"
@@ -53516,7 +53518,7 @@ msgstr "%<default%>标号未出现在 switch 语句内"
 msgid "break statement not within loop or switch"
 msgstr "break 语句不在循环或开关语句内"
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -53562,27 +53564,27 @@ msgstr "比较将一律评估作为 %<false%> 用于地址的 %qD 将永不是
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr "比较将一律评估作为 %<true%> 用于地址的 %qD 将永不是空值"
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "对不同枚举类型之间的比较给出警告"
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "形参数量不同"
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "在类型%qT和%qT间比较"
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "找不到类%qE的接口"
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
@@ -53655,29 +53657,29 @@ msgstr "需要标量时使用了联合类型"
 msgid "used vector type where scalar is required"
 msgstr "需要标量时使用了联合类型"
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, fuzzy, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "{ 预期于运算式中 ? 之后"
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE在子句%qs中不是一个变量"
@@ -53688,85 +53690,85 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "字段%qE的类型不完全"
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, fuzzy, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, fuzzy, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "%L处过程指针赋值中接口不匹配：%s"
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, fuzzy, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, fuzzy, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr "for 循环増量表达式不起作用"
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "for 循环増量表达式不起作用"
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, fuzzy, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "在过程入口处将数组段复制到一个连续的块中"
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE不是一个类"
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, fuzzy, gcc-internal-format
 #| msgid "throwing NULL, which has integral, not pointer type"
 msgid "iterator %qD has neither integral nor pointer type"
@@ -53777,19 +53779,19 @@ msgstr "抛出 NULL，它的类型是整数而不是指针"
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr "%<#pragma omp atomic%>表达式类型无效"
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD has incomplete type"
 msgid "iterator %qD has const qualified type"
 msgstr "形参%qD类型不完全"
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qD with non-integral type"
 msgid "iterator step with non-integral type"
 msgstr "位段%qD非整型"
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
@@ -53799,36 +53801,36 @@ msgstr ""
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "begin expression refers to outer iterator %qD"
 msgstr "迭代变量%qE类型无效"
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "end expression refers to outer iterator %qD"
 msgstr "迭代变量%qE类型无效"
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "step expression refers to outer iterator %qD"
 msgstr "迭代变量%qE类型无效"
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected pointer in %qs clause"
 msgstr "需要指针"
 
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, fuzzy, gcc-internal-format
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "尚未支持代码模式 %<large%>"
 
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, fuzzy, gcc-internal-format
 msgid "%<inscan%> %<reduction%> clause with array section"
 msgstr "尚未支持代码模式 %<large%>"
@@ -53858,7 +53860,7 @@ msgstr "字段%qE的类型不完全"
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE的类型对%<reduction(%s)%>无效"
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "用户定义的%qD总是计算所有两个参数"
@@ -53868,17 +53870,17 @@ msgstr "用户定义的%qD总是计算所有两个参数"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE必须是%<threadprivate%>方可%<copyin%>"
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
 msgstr ""
@@ -53893,24 +53895,24 @@ msgstr ""
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, fuzzy, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD在数据子句中多次出现"
@@ -53922,32 +53924,32 @@ msgstr "%qE在数据子句中多次出现"
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD在数据子句中多次出现"
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, fuzzy, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE在子句%<firstprivate%>中不是一个变量"
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE在子句%<firstprivate%>中不是一个变量"
@@ -53967,7 +53969,7 @@ msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
@@ -53977,7 +53979,7 @@ msgstr "%qE在子句%<lastprivate%>中不是一个变量"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qE在子句%<firstprivate%>中不是一个变量"
@@ -53987,77 +53989,77 @@ msgstr "%qE在子句%<firstprivate%>中不是一个变量"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr ""
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, fuzzy, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, fuzzy, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "在 %L 处的推迟数组“%1$s”在初始化表达式中不被允许"
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, fuzzy, gcc-internal-format
 msgid "unsupported map expression %qE"
 msgstr "整点转换中类型无效"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
@@ -54073,24 +54075,24 @@ msgstr "源不是一个指针"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, fuzzy, gcc-internal-format
 #| msgid "-frepo must be used with -c"
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "-frepo 必须与 -c 一起使用"
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %qs clauses on a task construct"
 msgstr "太多的%qs子句"
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE可被预先确定为%qs，为%qs"
@@ -54100,38 +54102,38 @@ msgstr "%qE可被预先确定为%qs，为%qs"
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, fuzzy, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, gcc-internal-format
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
@@ -54431,13 +54433,13 @@ msgstr "以从%qT转换为%qT"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "以从%qT转换为%qT"
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] " 备选需要 %d 实参，但提供了 %d 个"
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -54771,605 +54773,605 @@ msgstr "不同的指针类型%qT和%qT组成的条件表达式中需要一个类
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "枚举和非枚举类型一起出现在条件表达式中"
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "%<%D(int)%>没有出现在后缀%qs中，尝试使用前缀运算符"
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "没有为后缀%2$qs声明%<%1$D(int)%>"
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %qD is not %<int%>"
 msgid "return type of %qD is not %qs"
 msgstr "%qD的返回类型不是%<int%>"
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "在%q#T和%q#T间比较"
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to %<(%T) (%A)%>"
 msgid "no match for call to %<%T::operator[] (%A)%>"
 msgstr "对%<(%T) (%A)%>的调用没有匹配"
 
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, fuzzy, gcc-internal-format
 #| msgid "call of %<(%T) (%A)%> is ambiguous"
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr "对%<(%T) (%A)%>的调用有歧义"
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, fuzzy, gcc-internal-format
 #| msgid "non-placement deallocation function %q+D"
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "非预定位的释放函数%q+D"
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, fuzzy, gcc-internal-format
 #| msgid "non-placement deallocation function %q+D"
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "非预定位的释放函数%q+D"
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "%qD没有相应的释放函数"
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr ""
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "没有合适的%<operator %s%>给%qT"
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "在此上下文中"
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared private here"
 msgstr "在此声明"
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "在此上下文中"
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared protected here"
 msgstr "在此声明"
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D无法访问"
 
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "将 NULL 作为非指针实参 %P 传递给%qD"
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "  declared here"
 msgstr "在此声明"
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "将 NULL 转换到非指针类型%qT"
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "将%<false%>转换为指向%2$qD的实参 %1$P 的指针类型"
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "将%<false%>转换为指向%2$qD的实参 %1$P 的指针类型"
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  初始化%2$qD的实参 %1$P"
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, fuzzy, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "显式转换运算符只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "%qT的初始值设定周围花括号太多"
 
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 #, fuzzy
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "不能在初始化时将%qT转换为%qT"
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 #, fuzzy
 #| msgid "conversion to void will never use a type conversion operator"
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr "向 void 的转换永远不会用到类型转换运算符"
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 #, fuzzy
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr "不能在初始化时将%qT转换为%qT"
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "到类型%qT的转换无效，从类型%qT"
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "从类型%qT到类型%qT的转换无效"
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "从初始化列表转换为%qT将使用显式构造函数%qD"
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr ""
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 #, fuzzy
 #| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "将类型为%2$qT的右值转换为%1$qT的 volatile 引用"
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr "用类型为%2$qT的右值初始化类型为%1$qT的非常量引用无效"
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "用类型为%2$qT的右值初始化类型为%1$qT的非常量引用无效"
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 #, fuzzy
 #| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "将类型为%2$qT的右值转换为%1$qT的 volatile 引用"
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 #, fuzzy
 #| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "将类型为%2$qT的右值转换为%1$qT的 volatile 引用"
 
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 #, fuzzy
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "将%qT作为%q#D的%<this%>实参时丢弃了类型限定"
 
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "无法将位段%qE绑定到%qT"
 
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "不能将紧实的字段%qE绑定到%qT"
 
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "无法将右值%qE绑定到%qT"
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, fuzzy, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "不能通过%<...%>传递有不能平凡复制的类型%q#T"
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, fuzzy, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "不能通过%<...%>接受不能平凡复制的类型%q#T；"
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "递归计算%q#D的默认参数"
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "%2$qD的第 %1$d 个形参的默认实参尚未被解析到"
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "函数的实参可能是 format 属性的备选"
 
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, fuzzy, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "已弃用为非函数指定默认参数"
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr ""
 
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "从%qT到%qT的转换丢失了限定信息"
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "在调用%qD时"
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT是%qT的一个不可访问的基类"
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "向 void 的转换不会访问具有不能平凡复制类型%qT的对象"
 
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "赋值(不是初始化)出现在声明中"
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "改用 #include"
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "赋值(不是初始化)出现在声明中"
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "改用 #include"
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, fuzzy, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "(在%qs的初始化附近)"
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will not access object of non-trivially-copyable type %qT"
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "向 void 的转换不会访问具有不能平凡复制类型%qT的对象"
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, fuzzy, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "不能通过%<...%>接受不能平凡复制的类型%q#T；"
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "在此声明"
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, fuzzy, gcc-internal-format
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "inlined_to pointer 指向自身"
 
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 #, fuzzy
 #| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI"
 msgstr "不能将%qT转换为%qT"
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "对%<%T::%s(%A)%#V%>的调用没有匹配的函数"
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "对%<%T::%s(%A)%#V%>的调用没有匹配的函数"
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "调用非函数的%qD"
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "不能直接调用构造函数%<%T::%D%>"
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, fuzzy, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "对于函数类型的类型转换，移除冗余的%<::%D%>"
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "对%<%D(%A)%>的调用没有匹配的函数"
 
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "对重载的%<%s(%A)%>的调用有歧义"
 
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "没有对象无法调用成员函数%qD"
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "传递%qT时选择%qT而不是%qT"
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr "ISO C++ 认为有歧义，尽管第一个备选的最差类型转换要好于第二个备选的最差类型转换"
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "try making the operator a %<const%> member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "选择%qD而不是%qD"
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "以从%qT转换为%qT"
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "因为前者的实参类型转换序列更好"
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "重载解决时默认参数不匹配"
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr "备选 1: %q+#F"
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr "备选 2: %q+#F"
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ 认为有歧义，尽管第一个备选的最差类型转换要好于第二个备选的最差类型转换："
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, fuzzy, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "暂时的约束到 %qD 只有持续直到建构子离开"
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 #, fuzzy
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "用类型为%2$qT的右值初始化类型为%1$qT的非常量引用无效"
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "将类型为%qT的引用初始化为类型为%qT的表达式无效"
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "possibly dangling reference to a temporary"
 msgstr "返回临时变量的引用"
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr ""
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, gcc-internal-format
 msgid "explicit conversion function was not considered"
 msgstr ""
@@ -55417,7 +55419,7 @@ msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D无法被重载"
 
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "先前的声明%q+D"
@@ -55863,7 +55865,7 @@ msgstr "可变数组是结构中的唯一成员"
 msgid "next member %q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T重定义"
@@ -56000,7 +56002,7 @@ msgstr "函数%q+#D的抽象返回类型无效"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
@@ -56042,7 +56044,7 @@ msgstr "返回语句转换无效"
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%qD不是一个广义常函数"
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr ""
@@ -56060,7 +56062,7 @@ msgstr "调用这些函数时给出警告"
 msgid "%q+E is not a constant expression"
 msgstr "%q+E不是一个常量表达式"
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
@@ -56084,7 +56086,7 @@ msgstr "用户定义的%qD总是计算所有两个参数"
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
@@ -56134,7 +56136,7 @@ msgstr "%qT是%qT的有歧义的基类"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -56266,19 +56268,19 @@ msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "提领%<void *%>指针"
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -56286,485 +56288,485 @@ msgstr "提领%<void *%>指针"
 msgid "%qE is not a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, fuzzy, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "初始值设定中数组索引不是整型常量表达式"
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr ""
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, fuzzy, gcc-internal-format
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr ""
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "%qE的枚举值不是一个整数常量"
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "常量表达式中的 Lambda 表达式"
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "allocated here"
 msgstr "在此声明"
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
 msgstr ""
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD用在其自身的初始值设定中"
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D不是 const"
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D是 volatile"
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD在其类外被声明为%<constexpr%>"
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr "常量表达式中的 Lambda 表达式"
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, fuzzy, gcc-internal-format
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr "扩展：从 %s 到 %s，位于 %L"
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr ""
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr ""
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "扩展：从 %s 到 %s，位于 %L"
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "inline assembly is not a constant expression"
 msgstr "初始值设定中元素不是常量表达式"
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "use of %qD"
 msgstr "错误地使用了%qD"
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr ""
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr ""
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr ""
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr ""
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, fuzzy, gcc-internal-format
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "截取的变量 %qD 与 non-automatic 贮藏体持续时间"
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "枚举和非枚举类型一起出现在条件表达式中"
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "表达式%qE具有抽象类类型%qT，不能用于 throw 表达式中"
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, fuzzy, gcc-internal-format
 msgid "pointed-to object declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, fuzzy, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-id"
 msgid "unexpected template-id %qE"
 msgstr "需要模板 ID"
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD takes one argument only"
 msgid "function concept must be called"
 msgstr "内建函数%qD只需要一个实参"
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "数组%qD的大小不是一个整数常表达式"
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "KIND 参数 %s 在%L处必须是初始化表达式"
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr "取析构函数%qE的地址"
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "从具有类型%qT的右值表达式到类型%qT中的转换无效"
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "赋值时将整数赋给指针，未作类型转换"
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, fuzzy, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of 对象 %qE 与线程本地或自动贮藏体并非常数运算式"
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "常量表达式中的 Lambda 表达式"
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "new-expression is not a constant expression before C++20"
 msgstr "常量表达式中的 Lambda 表达式"
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "虚函数不能是友元"
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "常量表达式中类型错误"
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "%L处被零除"
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, fuzzy, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "%L处非常量初始化表达式"
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, fuzzy, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "%2$L处 %1$s 种别无效"
@@ -57540,7 +57542,7 @@ msgstr "%<__builtin_prefetch%>的第三个实参必须是一个常量"
 msgid "no suspend point info for %qD"
 msgstr "%qD先前没有原型"
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -57563,23 +57565,23 @@ msgstr "指针不能用作 case 常量"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr "使用了变长数组"
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
@@ -57601,75 +57603,75 @@ msgstr ""
 msgid "%qD was promoted to an immediate function"
 msgstr "%qD不是一个模板函数"
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of an immediate function %qD"
 msgstr "取析构函数%qE的地址"
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "call to consteval function %qE is not a constant expression"
 msgstr "数组%qD的大小不是一个整数常表达式"
 
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "%qD的地址总是等价为%<true%>"
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qE attribute"
 msgid "pack expansion of %qE attribute"
 msgstr "属性%qE的参数无效"
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in template argument list"
 msgid "use fold expression in the attribute argument instead"
 msgstr "模板实参表语法错误"
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD不是一个类型"
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class type"
 msgid "%qD is not a class type"
 msgstr "%qT不是一个类"
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qE不是一个类"
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
@@ -57718,7 +57720,7 @@ msgstr "将类型为%2$qT的右值转换为非常量引用类型%1$q#T"
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "从%qT到%qT的转换丢失了限定信息"
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "从%qT转换到%qT并未提领指针"
@@ -58119,7 +58121,7 @@ msgstr "从先前的声明%q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "先前的声明%q+D"
@@ -58267,8 +58269,8 @@ msgstr "先前对于%q+#D的非函数声明"
 msgid "%q#D previously defined here"
 msgstr "%q+#D已在此定义过"
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, fuzzy, gcc-internal-format
 msgid "%q#D previously declared here"
 msgstr "%q+#D已在此定义过"
@@ -58346,58 +58348,42 @@ msgstr "为%2$q#D的第 %1$d 个形参指定了默认实参"
 msgid "previous specification in %q#D here"
 msgstr "%q+D的上一个定义在此"
 
-#: cp/decl.cc:2285
-#, fuzzy, gcc-internal-format
-msgid "declaration %qD conflicts with builtin"
-msgstr "%q+D的节与早先的声明冲突"
-
-#: cp/decl.cc:2288
-#, fuzzy, gcc-internal-format
-msgid "declaration %qD conflicts with import"
-msgstr "%q+D的节与早先的声明冲突"
-
-#: cp/decl.cc:2289
-#, fuzzy, gcc-internal-format
-#| msgid "declared here"
-msgid "import declared %q#D here"
-msgstr "在此声明"
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting exporting for declaration %qD"
 msgstr "相互冲突的声明%q#D"
 
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "previously declared here without exporting"
 msgstr "以前在此声明过"
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD here"
 msgstr "%q+D的上一个定义在此"
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD here"
 msgstr "%q+D的上一个声明在此"
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "联合成员函数%qD被声明为虚函数"
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "同一作用域中%qD冗余的重声明"
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, fuzzy, gcc-internal-format
 #| msgid "deleted definition of %qD"
 msgid "deleted definition of %qD is not first declaration"
@@ -58411,44 +58397,44 @@ msgstr "删除了%qD的定义"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "在初次使用后显式特例化%qD"
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "%q+D的数据区域与先前的声明冲突"
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "%q#D 重定义"
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD与已用的函数冲突"
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D未在类中声明"
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D重声明内联并有%<gnu_inline%>属性"
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D重声明为内联而没有%<gnu_inline%>属性"
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -58456,2618 +58442,2618 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "友元%q#D的重声明不能有默认模板参数"
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "%q#D的线程局部声明出现在其非线程局部声明之后"
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "%q#D的非线程局部声明出现在其线程局部声明之后"
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "%q#D重声明"
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "同一作用域中%qD冗余的重声明"
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration"
 msgid "previous label"
 msgstr "上一个声明"
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, gcc-internal-format
 msgid "jump to label %qD"
 msgstr "跳转至标号%qD"
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr "跳转至 case 标号"
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr ""
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  从这里"
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  退出了 OpenMP 结构块"
 
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, gcc-internal-format
 msgid "  crosses initialization of %q#D"
 msgstr "  跳过了%q+#D的初始化"
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, gcc-internal-format
 msgid "  enters %<try%> block"
 msgstr "  进入了 try 块"
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, gcc-internal-format
 msgid "  enters %<catch%> block"
 msgstr "  进入了 catch 块"
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  进入了 OpenMP 结构块"
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr "  进入了同步化或原子化语句"
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, fuzzy, gcc-internal-format
 #| msgid "jump into statement expression"
 msgid "  enters statement expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, gcc-internal-format
 msgid "  enters %<constexpr if%> statement"
 msgstr "  需要语句"
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, gcc-internal-format
 msgid "  enters %<consteval if%> statement"
 msgstr "  需要语句"
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C99 does not support %qE"
 msgid "  does not destroy %qD"
 msgstr "ISO C99 不支持 %qE"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, fuzzy, gcc-internal-format
 msgid "  does not clean up handled exception"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, gcc-internal-format
 msgid "  skips initialization of %q#D"
 msgstr "  跳过了%q+#D的初始化"
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "%qD使用时未带模板参数"
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is a function, not a type"
 msgstr "%qD不是一个函数模板"
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T不是一个类"
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "没有名为%q#T的类模板，在%q#T中 "
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, fuzzy, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "没有名为%q#T的类模板，在%q#T中 "
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "在%2$qT中查询%1$qT有歧义"
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%>指定了%q#T，但后者不是一个类模板"
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, fuzzy, gcc-internal-format
 #| msgid "%<typename %T::%D%> names %q#T, which is not a type"
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%>指定了%q#T，但后者不是一个类型"
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, fuzzy, gcc-internal-format
 msgid "template parameters do not match template %qD"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, fuzzy, gcc-internal-format
 #| msgid "-falign-labels=%d is not supported"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "不支持 -falign-labels=%d"
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D无效；匿名联合只能有非静态的数据成员"
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous struct not inside named type"
 msgid "anonymous struct with base classes"
 msgstr "匿名结构不在有名类型内"
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "有构造函数的成员%q+#D不允许在匿名聚合中出现"
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "有构构函数的成员%q+#D不允许在匿名聚合中出现"
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "有拷贝赋值运算符的成员%q+#D不能用在联合中"
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "%q+#T的属性必须跟在%qs关键字后面"
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "一个声明指定了多个类型"
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "对 C++ 内建类型%qT的重声明"
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "只能为函数指定%qs"
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typedef 声明中缺少类型名"
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ 不允许匿名结构"
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "只能为函数指定%qs"
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "只能为函数指定%qs"
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%>只能在类中指定"
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "只能为构造函数指定%<explicit%>"
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "只能为对象和函数指定存储类"
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定类型限定"
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定类型限定"
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定类型限定"
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "只能为对象和函数指定存储类"
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "此声明中的%<typedef%>被忽略"
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot be used for type declarations"
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%>不能被用作类型声明"
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "对%q#T重复的显式实例化"
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "只能为类定义应用%qE属性"
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "忽略在定义之外为类类型%qT应用的属性"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "忽略在关联定义之外为依赖类类型%qT应用的属性"
 
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %qD is initialized (use decltype instead)"
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef%qD被初始化(改用 decltype)"
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "%q#D声明有%<extern%>并被初始化"
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "%q#D的定义被标记为 %<dllimport%>"
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, fuzzy, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D不是%qT的非静态数据成员"
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, fuzzy, gcc-internal-format
 msgid "non-member-template declaration of %qD"
 msgstr "无效的成员模板声明%qD"
 
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, fuzzy, gcc-internal-format
 msgid "does not match member template declaration here"
 msgstr "无效的成员模板声明%qD"
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ 不允许将%<%T::%D%>定义为%<%T::%D%>"
 
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "ISO C++ 不允许成员%qD的初始化"
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "出现在类外的%q#D的声明不是定义"
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr ""
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "变量%q#D有初始值设定，但是类型不完全"
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "数组%q#D的元素类型不完全"
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "聚合%q#D类型不完全，无法被定义"
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD声明为引用却未被初始化"
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "名字被用在 GNU 风格的数组指定元素初始值设定中"
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "名字%qD用在 GNU 风格的数组指定元素初始值设定中"
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "不平凡的代理初始值设定不受支持"
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "初始值设定无法决定%qD的大小"
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD缺少数组大小"
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "大小为 0 的数组%qD"
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "%qD的存储大小未知"
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "%qD的存储大小不是常量"
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "对不起：内联函数中静态数据%q+#D的语义是错的(您会得到此变量的多份复制)"
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "对不起：内联函数中静态数据%q+#D的语义是错的(您会得到此变量的多份复制)"
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr " 变通的作法是删除初始值设定"
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "未初始化的常量%qD"
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "对广义常变量%qD的声明不同时是定义"
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "对广义常变量%qD的声明不同时是定义"
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T没有用户提供的默认构造函数"
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, fuzzy, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "建构子未被 user-provided 因为它是明确的缺席在中类别本体"
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, fuzzy, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "和 implicitly-defined 建构子不初始化 %q+#D"
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "无效类型%qT被用作类型为%qT的向量的初始值设定"
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "%qT的初始值设定必须在花括号内"
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, fuzzy, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "名字%qD用在 GNU 风格的数组指定元素初始值设定中"
 
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "对成员%qD的请求有歧义"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT没有名为%qD的非静态数据成员"
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD不是%qT的成员"
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "初始值设定无法决定%q+D的大小"
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 指示项 %qE 外侧汇总初始设置式"
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT的初始值设定项太多"
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "类型%qT的标量初始化带花括号"
 
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "类型%qT的标量初始化带花括号"
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "%qT的初始值设定周围缺少花括号"
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "数组%q#T的元素类型不完全"
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "变长复合字面量"
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q+D类型不完全"
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "标量对象%qD在初始值设定中需要一个元素"
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "在 C++98 中%qD必须由构造函数而不是%<{...}%>初始化"
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "数组%qD被有括号的字面字符串%qE所初始化"
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "构造函数中对静态成员的初始化无效"
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(需要一个类外的初始化)"
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qD声明为引用却未被初始化"
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "could not find variant declaration"
 msgstr "%<[*]%>不在声明中"
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "给 %qE 的实递参数太少"
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "%<declare variant%> on destructor %qD"
 msgstr "取析构函数%qE的地址"
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "赋值(不是初始化)出现在声明中"
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "为%qs指定了存储类"
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D声明有缺少初始值设定"
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "对成员的使用无效(您是否遗忘了%<&%>？)"
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "返回值类型%q#T不完全"
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "可变大小的对象不能被初始化"
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "隐藏了早先的类型声明%q#D"
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables and functions"
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qE属性只能为变量或函数所使用"
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "函数%q#D像变量一样被初始化"
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "不能在%q+D使用过时的绑定，因为它有析构函数"
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT是%qT不可访问的基类"
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 不允许变长数组%qE"
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "为结构字段指定了%qs"
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "无法声明指向%q#T的指针"
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "数组大小不是一个整数常表达式"
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "in initialization of structured binding variable %qD"
 msgstr "迭代变量%qE类型无效"
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "无法分解地址"
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, fuzzy, gcc-internal-format
 #| msgid "source is of incomplete class type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "源有不完全的类类型"
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "不能对静态数据成员%qD取%<offsetof%>"
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T 有 non-trivial 解构式"
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初始值设定无法决定%qD的大小"
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "%qD缺少数组大小"
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "大小为 0 的数组%qD"
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "其他类%qT的析构函数不能用作成员"
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "其他类%qT的构造函数不能用作成员"
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD声明为%<virtual%>变量"
 
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD声明为%<virtual%>参数"
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD声明为%<inline%>参数"
 
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD声明为%<virtual%>类型"
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD声明为%<inline%>类型"
 
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD声明为%<virtual%>字段"
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD声明为%<inline%>字段"
 
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D声明为友元"
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D声明时带有异常规范"
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD的定义不在包含%qT的命名空间中"
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "静态成员函数%q#D的声明带有类型限定符"
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD没有声明为一个参数"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "形参%qD被声明为有 void 类型"
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java 方法%qD返回非 Java 类型%qT"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "-fmit-class-file 的别名"
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, fuzzy, gcc-internal-format
 msgid "a function concept cannot be constrained"
 msgstr "不能内联%<main%>函数"
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD不是一个模板函数"
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "constrained non-template friend declaration must be a definition"
 msgstr "友元声明不在类定义内"
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "在友元声明中定义显式特例化%qD"
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "在基本模板的声明中对模板标识符%qD的使用无效"
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "友元模板特例化%qD中不允许出现默认参数"
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%>不允许用于友元模板特例化%qD的声明"
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "出现在类外的%q#D的声明不是定义"
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "不能将%<::main%>声明为一个模板"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "不能将%<::main%>声明为 inline"
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "不能将%<::main%>声明为 static"
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "不能将%<::main%>声明为 static"
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "非成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr "成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "非成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, fuzzy, gcc-internal-format
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr "成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "explicit object parameter declared here"
 msgstr "模板形参类型%qT声明为%<friend%>"
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "%qD的特例化必须出现在命名空间内"
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "%qD的特例化必须出现在命名空间内"
 
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qD没有声明为一个函数"
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "特例化模板有 C 链接"
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD 带有无效参数列表"
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, fuzzy, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "整数字尾 %<%s%>带阴影由实现"
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, fuzzy, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "浮点数字尾 %<%s%>带阴影由实现"
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, fuzzy, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "实字运算符后缀无法前继的由 %<_%>被保留的用于未来标准化"
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD必须是一个非静态的成员函数"
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%>必须返回%<int%>"
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "隐式声明的%qD的定义"
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "默认化声明%q+D"
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "默认化声明%q+D"
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "成员函数%q#D未在类%qT中声明"
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "不能将%<::main%>声明为一个模板"
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "自动变量%qE不能是%<threadprivate%>"
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "concept must be defined at namespace scope"
 msgstr "%qD的特例化必须出现在命名空间内"
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "可变大小的对象不能被初始化"
 
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ 不允许在类内初始化非常量静态成员%qD"
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ 不允许初始化成员常量%qD，因为它有非整数的类型%qT"
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "数组%qD的大小具有非整数类型%qT"
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "数组%qT的大小的类型不是整数"
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "数组%qD的大小不是一个整数常表达式"
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "数组大小不是一个整数常表达式"
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C 不允许大小为 0 的数组%qD"
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ 不允许大小为 0 的数组"
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ 不允许变长数组%qD"
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ 不允许变长数组"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "使用了变长数组%qD"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "使用了变长数组"
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "数组维数溢出"
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "成员函数%qD未在%qT中声明"
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "creating array of template placeholder type %qT"
 msgstr "生成引用类型%qT的成员指针"
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "%qD声明为 void 的数组"
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "创建 void 数组"
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "%qD声明为函数的数组"
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "创建函数的数组"
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "%qD声明为引用的数组"
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "创建引用的数组"
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "%qD声明为函数成员的数组"
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "创建函数成员的组织"
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "多维数组%qD的声明必须至少指定除第一维以外所有维的大小"
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "声明多维数组必须至少指定除第一维以外所有维的大小"
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable-length array of %<auto%>"
 msgstr "使用了变长数组"
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "为构造函数指定返回值无效"
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "指定析构函数的返回类型无效"
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "为%<operator %T%>指定了返回值"
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "指定析构函数的返回类型无效"
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD声明时模板参数表太多"
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "%qs的声明中有相互冲突的限定符"
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "无名变量或字段声明为 void"
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "变量或字段声明为 void"
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "在全局作用域外为函数%qs指定%<inline%>无效"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "对限定名%<::%D%>的使用无效"
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "对限定名%<%T::%D%>的使用无效"
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "对限定名%<%D::%D%>的使用无效"
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT既不是类也不是命名空间"
 
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "%qD没有声明为一个函数"
 
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "%qD未声明为成员"
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "缺少声明标识符：使用了保留字%qD"
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "函数定义未声明形参"
 
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD没有声明为一个函数"
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "形参声明中出现的 typedef 声明无效"
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "声明的形参%qD不存在"
 
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, gcc-internal-format
 msgid "both %qs and %qs specified"
 msgstr ""
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%<constexpr%>不能被用于 typedef 声明"
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "%qs的声明指定了两个以上的数据类型"
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C++ 不支持单独以 %<complex%> 表示 %<double complex%>"
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ 不允许声明无类型的%qs"
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ 对 %2$qs 不支持 %<__int%1$d%>"
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, fuzzy, gcc-internal-format
 #| msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "为%qs同时给定了%<signed%>和%<unsigned%>"
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> and %<short%> specified together for %qs"
 msgid "%<long%> and %<short%> specified together"
 msgstr "为%qs同时给定了%<long%>和%<short%>"
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %qT"
 msgstr "%qE可被预先确定为%qs，为%qs"
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with typedef-name %qD"
 msgstr "%qE不是一个 typedef 类型，也不是一个内建类型"
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "%qE不是一个 typedef 类型，也不是一个内建类型"
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<typeof%>"
 msgstr "%qE不是一个 typedef 类型，也不是一个内建类型"
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "对%qs而言无效的复数"
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "成员%qD不能既被声明为虚函数，又被声明为静态函数"
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "成员%qD不能既被声明为虚函数，又被声明为静态函数"
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "形参声明中出现的 typedef 声明无效"
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "为模板参数%qs指定了存储类"
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "为形参%qs指定了存储类"
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %qs"
 msgstr "形参不能被声明为%<constexpr%>"
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%>用在类声明以外"
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "无效的函数声明"
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs的声明指定了多个存储类"
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "为%qs指定了存储类"
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "嵌套函数%qs被声明为%<extern%>"
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "在文件层将%qs声明为%<auto%>"
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "函数作用域的%qs隐式为 auto，却被声明为%<__thread%>"
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "为友元函数声明指定了无效的存储类"
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored"
 msgstr "忽略%qs属性"
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, fuzzy, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "类型在非前向声明的详尽类型限定符中被忽略"
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs的声明指定了多个存储类"
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "需要左圆括号"
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, fuzzy, gcc-internal-format
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, fuzzy, gcc-internal-format
 msgid "a function type cannot have an explicit object parameter"
 msgstr "函数‘%s’在%L处不能有初始值设定"
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, fuzzy, gcc-internal-format
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, fuzzy, gcc-internal-format
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr "%qE不是类型%qT的有效模板实参，因为它的类型是%qT"
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr ""
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "the type of an explicit object member function is a regular function type"
 msgstr "类型不能定义在条件表达式中"
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "valid explicit object parameter declared here"
 msgstr "模板形参类型%qT声明为%<friend%>"
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "%qE属性在类型上被忽略"
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, fuzzy, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs函数使用了%<auto%>类型限定却没有迟返回类型"
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs函数使用迟返回类型%qT作为它的类型，而不是%<auto%>"
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "%qs函数使用迟返回类型%qT作为它的类型，而不是%<auto%>"
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "错误地使用了%<auto%>"
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "忽略函数返回类型的类型限定"
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, fuzzy, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs函数使用了迟返回类型却未用%<auto%>类型限定声明"
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr "调用了有限定 void 返回类型的函数"
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs声明为返回一个函数的函数"
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs声明为返回一个数组的函数"
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%L处 CASE 语句中的逻辑范围是不被允许的"
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "构造函数不能被声明为虚函数"
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "友元声明不在类定义内"
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "局部类定义中不能定义友元函数%qs"
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr "非成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, fuzzy, gcc-internal-format
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr "模板不能是%<virtual%>的"
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, fuzzy, gcc-internal-format
 #| msgid "In static member function %qs"
 msgid "%qD cannot be an explicit object member function"
 msgstr "在静态成员函数%qs中"
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "析构函数不能有参数"
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "无法声明指向%q#T的指针"
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "无法声明对%q#T的引用"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "无法声明指向%q#T成员的指针"
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "无法声明对%q#T的引用，因为它不是 typedef 或者模板类型实参"
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "模板标识符%qD用作声明"
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "成员函数隐式地成为所属类的友元"
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "有多余的限定%<%T::%>在成员%qs上"
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "无法定义成员函数%<%T::%s%>，在%<%T%>中"
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "无法声明成员%<%T::%s%>，在%qT中"
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "无法声明成员%<%T::%s%>，在%qT中"
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "非形参%qs不能是一个参数包"
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "数据成员不能具有可变类型%qT"
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "参数不能具有可变类型%qT"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%>用在类声明以外"
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%>用于空声明中"
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, fuzzy, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "只有构造函数才能被声明为%<explicit%>"
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非成员%qs不能被声明为%<mutable%>"
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非对象成员%qs不能被声明为%<mutable%>"
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "函数%qs不能被声明为%<mutable%>"
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "静态%qs不能被声明为%<mutable%>"
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "常量%qs不能被声明为%<mutable%>"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "常量%qs不能被声明为%<mutable%>"
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a function definition"
 msgstr "类型不能定义在条件表达式中"
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in conditions"
 msgid "typedef may not be a member function definition"
 msgstr "类型不能定义在条件表达式中"
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%>不在声明中"
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef%q+D声明为%<inline%>"
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef 名不能是嵌套名指定"
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ 不允许嵌类的类型%qD与其所属的类重名"
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "友元函数声明中出现了%<inline%>"
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "模板参数不能是友元"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "友元声明需要 class，即%<friend class %T::%D%>"
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "友元声明需要 class，即%<friend %#T%>"
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "试图让%qT成为全局域的友元"
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非成员函数类型上的限定符无效"
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "抽象声明%qT被用作声明"
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "不能在参数声明中使用%<::%>"
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, fuzzy, gcc-internal-format
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "不能将形参%q+D声明为具有抽象类型%qT"
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr "%qD不是一个函数模板"
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "形参声明为%<auto%>"
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "形参声明为%<auto%>"
 
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "使用模板名%qE时不带实参表无效"
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C 不允许大小为 0 的数组%qD"
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 不允许可变数组成员"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "错误地使用了%<::%>"
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "%qD模板声明无效"
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "联合成员函数%qD被声明为虚函数"
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD不能声明为虚函数，因为它总是静态的"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "在析构函数%qD中的友元声明需要限定名"
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD声明为%qT的一个成员"
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %qs"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "在构造函数%qD中的友元声明需要限定名"
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a constructor cannot be %<concept%>"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "不能打开 %s"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "模板声明%q#D"
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "%qD类型不完全"
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "名字%qT类型不完全"
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE既不是函数也不是成员函数；不能声明为友元"
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE既不是函数也不是成员函数；不能声明为友元"
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, fuzzy, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr "类型在非前向声明的详尽类型限定符中被忽略"
 
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "static data member %qE declared %qs"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %qs"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "函数%qs的存储类%<auto%>无效"
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "函数%qs的存储类%<register%>无效"
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr "不能为%q+D指定对齐"
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "函数定义中不允许出现 asm 指定"
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全局作用域外为函数%qs指定%<static%>无效"
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全局作用域外为函数%qs指定%<inline%>无效"
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "虚函数%qs不是类成员"
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs定义在在非类作用域中"
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs定义在在非类作用域中"
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "不能将成员函数%qD声明为有静态链接"
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "不能在另一个函数中声明一个静态函数"
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "与声明不同，定义静态数据成员时不能使用%<static%>"
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "静态成员%qD声明为%<register%>"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "不能显式地将成员%q#D声明为有外部链接"
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of constexpr variable %qD is not a definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "对广义常变量%qD的声明不同时是定义"
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "形参不能被声明为%<constexpr%>"
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs已初始化，却又被声明为%<extern%>"
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs既有%<extern%>又有初始值设定"
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "默认实参%qE使用了局部变量%qD"
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "默认实参%qE使用了局部变量%qD"
 
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ISO C 不允许前向参数声明"
 
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "不能将形参%q+D声明为具有抽象类型%qT"
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "形参%qD被无效地被声明为具有方法类型"
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "形参%qD包含了指向具有未知边界数组%qT的指针"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "形参%qD包含了指向具有未知边界数组%qT的引用"
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "无效的构造函数：您要的可能是%<%T (const %T&)%>"
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD不能在命名空间声明"
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD不能被声明为静态的"
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD必须是一个非静态的成员函数"
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "%qD必须是一个非静态的成员函数"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, fuzzy, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD必须是一个非静态成员函数或非成员函数"
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD的实参必须有类或枚举类型"
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ 不允许重载 ?: 运算符"
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD不能带可变数量的实参"
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD必须带 0 或 1 个实参"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD必须带 1 或 2 个实参"
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "后缀%qD必须使用%<int%>作为它的参数"
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "后缀%qD必须使用%<int%>作为它的第二个参数"
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD带且仅带 2 个实参"
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD带且仅带 1 个实参"
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD带且仅带 2 个实参"
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD不能有默认参数"
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to void will never use a type conversion operator"
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "向 void 的转换永远不会用到类型转换运算符"
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "向具有相同类型的引用的转换永远不会用到类型转换运算符"
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to the same type will never use a type conversion operator"
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "向相同类型的转换永远不会用到类型转换运算符"
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "向指向基类的引用的转换永远不会用到类型转换运算符"
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to a base class will never use a type conversion operator"
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "向基类的转换永远不会用到类型转换运算符"
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "用户定义的%qD总是计算所有两个参数"
 
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "前缀%qD应当返回%qT"
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "后缀%qD应当返回%qT"
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD应当返回值而非引用"
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "使用模板类型形参%qT，在%qs后"
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "使用模板类型形参%qT，在%qs后"
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "使用 typedef 名%qD，在%qs后"
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT作为%qs被引用"
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT作为枚举被引用"
@@ -61079,119 +61065,102 @@ msgstr "%qT作为枚举被引用"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%>需要模板参数"
 
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "对%qD的引用有歧义"
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, fuzzy, gcc-internal-format
 #| msgid "function template %qD redeclared as a class template"
 msgid "class template %qD redeclared as non-template"
 msgstr "函数模板%qD重声明为类模板"
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD与其声明所在的类重名"
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT不是一个模板"
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "使用枚举%q#D前没有给出声明"
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "%qT重声明为非模板"
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare %qD to be a bit-field type"
-msgid "cannot declare %qD in a different module"
-msgstr "不能将%qD声明为位段类型"
-
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, gcc-internal-format
-msgid "previously declared here"
-msgstr "以前在此声明过"
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "派生联合%qT无效"
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "此函数中的%qD在使用前未初始化"
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "类型%qT不是%qT的直接或虚基类"
 
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "基类型%qT不是结构或类"
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "递归的类型%qT未定义"
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重复的基类型%qT无效"
 
-#: cp/decl.cc:16984
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare %qD to be a bit-field type"
-msgid "cannot declare %qD in different module"
-msgstr "不能将%qD声明为位段类型"
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, fuzzy, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "范围/unscoped 不匹配在中 enum %q#T"
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "先前的定义在这里"
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, fuzzy, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "条件表达式中类型不匹配"
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, fuzzy, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "不同的下层的输入 enum %q#T"
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -61201,84 +61170,84 @@ msgstr "%<%2$T%>的内在类型%<%1$T%>必须是整型"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "没有一个整数类型可以表示%qT的所有枚举值"
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "对%<unsigned long%>类型而言整数常量太大"
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "对%<unsigned long%>类型而言整数常量太大"
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD处枚举值溢出"
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T多次定义"
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "返回值类型%q#T不完全"
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%>应当返回一个对%<*this%>的引用"
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "由于%<volatile%>，函数返回类型不兼容"
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "在有返回值的函数中未发现 return 语句"
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD已在类%qT中定义过"
 
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, fuzzy, gcc-internal-format
 msgid "using %qs"
 msgstr "括入并行"
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "%qD的类型默认为%<int%>"
@@ -61333,7 +61302,7 @@ msgstr "不能 delete 一个函数。只有指向对象的指针才是%<delete%>
 msgid "deleting %qT is undefined"
 msgstr "删除%qT未定义"
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D声明为模板"
@@ -61343,7 +61312,7 @@ msgstr "%q#D声明为模板"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "提供的模板参数列表与 %qD 的模板不符"
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "析构函数%qD被声明为一个成员模板"
@@ -61537,72 +61506,72 @@ msgstr "析构函数不能是静态成员函数"
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%>的第一个形参类型为%qT"
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr "%qT有一个字段%qD使用匿名命名空间"
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT有一个字段%qD使用匿名命名空间"
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr "%qT有一个字段%qD使用匿名命名空间"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr "%qT有一个字段%qD使用匿名命名空间"
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT被声明为比其字段%qD的类型有更高的可见性"
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT which has no linkage"
 msgstr "%qT有一个基类%qT使用匿名命名空间"
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr "%qT有一个基类%qT使用匿名命名空间"
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT which has internal linkage"
 msgstr "%qT有一个基类%qT使用匿名命名空间"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr "%qT有一个基类%qT使用匿名命名空间"
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT被声明为比其基类%qT有更高的可见性"
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr "%q+#D声明为具有匿名类型，在使用前未被定义"
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but not defined"
 msgstr "%q+#D声明为具有匿名类型，在使用前未被定义"
@@ -61611,118 +61580,117 @@ msgstr "%q+#D声明为具有匿名类型，在使用前未被定义"
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "匿名类型不具任何链结用来声明变量 %q#D 与链结"
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "匿名类型不具任何链结用来声明函数 %q#D 与链结"
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, fuzzy, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D未指明非限定类型，所以它不被用作外部链接"
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+#D声明为具有局部类型%qT，在使用前未被定义"
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr "%q+#D声明为具有局部类型%qT，在使用前未被定义"
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "constexpr 变量%2$qD的类型%1$qT不是字面常量"
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "%q+#D的早先声明有%qL链接"
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q+D的节与早先的声明冲突"
 
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, fuzzy, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "先前的声明%q+D"
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, fuzzy, gcc-internal-format
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr "-fabi-version=4 (or =0) 可以改变向量修饰来避免这个错误"
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "使用了内联函数%q+D但从未定义过"
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, fuzzy, gcc-internal-format
 #| msgid "default argument missing for parameter %P of %q+#D"
 msgid "default argument missing for parameter %P of %q#D"
 msgstr "%2$q+#D的第 %1$P 个形参缺少默认实参"
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, fuzzy, gcc-internal-format
 msgid "...following parameter %P which has a default argument"
 msgstr "模板参数包不能有默认参数"
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, fuzzy, gcc-internal-format
 #| msgid "class %qE is deprecated"
 msgid "implicitly-declared %qD is deprecated"
 msgstr "已弃用类%qE"
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, fuzzy, gcc-internal-format
 #| msgid "converting lambda which uses %<...%> to function pointer"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "将使用了%<...%>的 Lambda 转换为函数指针"
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "使用了被删除的函数%qD"
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
 
 #: cp/error.cc:4115
-#, fuzzy, gcc-internal-format
-#| msgid "no arguments"
+#, gcc-internal-format
 msgid "(no argument)"
-msgstr "没有参数"
+msgstr "（没有参数）"
 
 #: cp/error.cc:4207
 #, gcc-internal-format
@@ -61750,9 +61718,9 @@ msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>
 msgstr "Lambda 表达式只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
 #: cp/error.cc:4574
-#, fuzzy, gcc-internal-format
+#, gcc-internal-format
 msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
-msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
+msgstr "C++11 auto 只在 %<-std=c++11%> 或 %<-std=gnu++11%> 下可用"
 
 #: cp/error.cc:4579
 #, fuzzy, gcc-internal-format
@@ -61820,7 +61788,7 @@ msgstr "对%<%T::%D%>的引用有歧义"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD不是%qT的成员"
@@ -61831,7 +61799,7 @@ msgstr "%qD不是%qT的成员"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD不是%qD的成员"
@@ -61858,49 +61826,49 @@ msgstr "异常处理已被禁用，使用 -fexceptions 启用"
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr "抛出 NULL，它的类型是整数而不是指针"
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, gcc-internal-format
 msgid "  in thrown expression"
 msgstr "  在抛出的表达式中"
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr "不能将形参%q+D声明为具有抽象类型%qT"
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, fuzzy, gcc-internal-format
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr "无法为类型%qT创建类型信息，因为它的大小是可变的"
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, fuzzy, gcc-internal-format
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr "无法为类型%qT创建类型信息，因为它的大小是可变的"
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, fuzzy, gcc-internal-format
 #| msgid "exception of type %qT will be caught"
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr "类型为%qT的异常将会"
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, fuzzy, gcc-internal-format
 #| msgid "for %qD"
 msgid "for type %qT"
 msgstr "为 %qD"
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, gcc-internal-format
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr "%<...%>处理者必须是其 try 块中的最后一个处理者"
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, fuzzy, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr "noexcept-expression 评估到 %<false%> 因为调用到 %qD"
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, fuzzy, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
 msgstr "但是 %q+D 不丢掷；也许它应该被声明 %<noexcept%>"
@@ -62028,10 +61996,9 @@ msgid "default member initializer for %qD required before the end of its enclosi
 msgstr ""
 
 #: cp/init.cc:664
-#, fuzzy, gcc-internal-format
-#| msgid "union defined here"
+#, gcc-internal-format
 msgid "defined here"
-msgstr "联合在此定义"
+msgstr "在此定义"
 
 #: cp/init.cc:732
 #, fuzzy, gcc-internal-format
@@ -62172,12 +62139,12 @@ msgstr "类型%qT不是%qT的直接或虚基类"
 msgid "type %qT is not a direct base of %qT"
 msgstr "类型%qT不是%qT的直接基类"
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "数组必须为一个由花括号包围的初始值设定所初始化"
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT不是一个类"
@@ -62192,12 +62159,12 @@ msgstr "不完全类型%qT没有成员%qD"
 msgid "invalid pointer to bit-field %qD"
 msgstr "指向位段%qD指针无效"
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "对非静态成员函数%qD的使用无效"
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "对非静态数据成员%qD的无效使用"
@@ -62400,52 +62367,52 @@ msgstr "删除对象的抽象类别类型 %qT 该项有 non-virtual 解构式将
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "删除对象的 polymorphic 类别类型 %qT 该项有 non-virtual 解构式也许造成未定义的行为"
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, fuzzy, gcc-internal-format
 msgid "because the array element type %qT has variable size"
 msgstr "复合字面量有可变的大小"
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "无法通过引用捕获%qE"
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "向 void 的类型转换不会访问具有不完全类型%qT的对象"
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "lambda 函数中无法捕获%<this%>"
@@ -62831,237 +62798,286 @@ msgstr "需要模板 ID"
 msgid "encapsulation is malformed"
 msgstr ""
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting global module declaration %#qD"
 msgstr "相互冲突的声明%q#D"
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration %q+D"
 msgid "existing declaration %#qD"
 msgstr "在声明%q+D中"
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match"
 msgstr "%q#D的外部声明不匹配"
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, fuzzy, gcc-internal-format
 #| msgid "missing definition"
 msgid "existing definition %qD"
 msgstr "定义缺失"
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "... this enumerator %qD"
 msgstr "枚举%q+D重声明"
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, fuzzy, gcc-internal-format
 msgid "enumerator %qD does not match ..."
 msgstr "%q#D的外部声明不匹配"
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr ""
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr ""
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr ""
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, gcc-internal-format
 msgid "recursive lazy load"
 msgstr ""
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr ""
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "module %qs declared here"
 msgstr "%qD在此声明"
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, gcc-internal-format
 msgid "indirect import %qs is not already loaded"
 msgstr ""
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr ""
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr ""
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "macro definitions of %qE corrupted"
 msgstr "%q+D的上一个定义在此"
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, fuzzy, gcc-internal-format
 msgid "inconsistent imported macro definition %qE"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr ""
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr ""
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, fuzzy, gcc-internal-format
 msgid "compiled module file is %qs"
 msgstr "%s：无法找到模块文件 %s\n"
 
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Display the compiler's version"
 msgid "compiled module is %sversion %s"
 msgstr "显示编译器版本"
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collect2 version %s\n"
 msgid "compiler is %sversion %s%s%s"
 msgstr "collect2 版本 %s\n"
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, fuzzy, gcc-internal-format
 #| msgid "no %qs getter found"
 msgid "module %qs found"
 msgstr "找不到 %qs 的取值器"
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr ""
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr ""
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr ""
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr ""
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, fuzzy, gcc-internal-format
 #| msgid "exception handling disabled, use -fexceptions to enable"
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr "异常处理已被禁用，使用 -fexceptions 启用"
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, fuzzy, gcc-internal-format
 #| msgid "function attribute mismatch"
 msgid "fixed tree mismatch"
 msgstr "函数属性不匹配"
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "interface partition is not exported"
 msgstr "不支持堆栈限制表达式"
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module cluster %u: %s"
 msgstr ""
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "failed to read compiled module: %s"
 msgstr "找不到类‘%s’"
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr ""
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr ""
 
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr ""
 
-#: cp/module.cc:19283
+#: cp/module.cc:19117
+#, fuzzy, gcc-internal-format
+msgid "declaration %qD conflicts with builtin"
+msgstr "%q+D的节与早先的声明冲突"
+
+#: cp/module.cc:19122
+#, fuzzy, gcc-internal-format
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr "%q+D的节与早先的声明冲突"
+
+#: cp/module.cc:19125
+#, fuzzy, gcc-internal-format
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr "%q+D的节与早先的声明冲突"
+
+#: cp/module.cc:19130
+#, fuzzy, gcc-internal-format
+#| msgid "declared here"
+msgid "import declared attached to module %qs"
+msgstr "在此声明"
+
+#: cp/module.cc:19134
+#, fuzzy, gcc-internal-format
+#| msgid "using-declaration for non-member at class scope"
+msgid "import declared in global module"
+msgstr "在类作用域使用非成员的 using 声明"
+
+#: cp/module.cc:19140
+#, fuzzy, gcc-internal-format
+msgid "conflicting declaration of %qD in module %qs"
+msgstr "相互冲突的声明%q#D"
+
+#: cp/module.cc:19143
+#, fuzzy, gcc-internal-format
+msgid "conflicting declaration of %qD in global module"
+msgstr "%q+D声明为没有外部链接的，之前却有外部声明"
+
+#: cp/module.cc:19148
+#, fuzzy, gcc-internal-format
+#| msgid "previously declared here"
+msgid "previously declared in module %qs"
+msgstr "以前在此声明过"
+
+#: cp/module.cc:19152
+#, fuzzy, gcc-internal-format
+#| msgid "previously declared here"
+msgid "previously declared in global module"
+msgstr "以前在此声明过"
+
+#: cp/module.cc:19404
 #, fuzzy, gcc-internal-format
 #| msgid "Creating '%s'\n"
 msgid "reading CMI %qs"
 msgstr "正在创建 '%s'\n"
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, gcc-internal-format
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, fuzzy, gcc-internal-format
 msgid "during load of pendings for %<%E%s%E%>"
 msgstr "未知的选项：%s %s %s"
@@ -63073,420 +63089,420 @@ msgstr "未知的选项：%s %s %s"
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr ""
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, fuzzy, gcc-internal-format
 msgid "module already declared"
 msgstr "`%.*s' 已被定义为对照符号"
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, fuzzy, gcc-internal-format
 #| msgid "module procedure"
 msgid "module already imported"
 msgstr "模块过程"
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, fuzzy, gcc-internal-format
 #| msgid "module procedure"
 msgid "module %qs imported here"
 msgstr "模块过程"
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown Compiled Module Interface: %s"
 msgstr "PRINT_OPERAND：未知的标点‘%c’"
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr ""
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr ""
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr ""
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, gcc-internal-format
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr ""
 
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, fuzzy, gcc-internal-format
 #| msgid "Enable traditional preprocessing."
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr "启用传统预处理。"
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr ""
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr ""
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, gcc-internal-format
 msgid "you should use the %<-%s%> option"
 msgstr ""
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid header name %qs"
 msgstr "无效的 --param 值%qs"
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid module name %qs"
 msgstr "无效的 --param 值%qs"
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr ""
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, fuzzy, gcc-internal-format
 #| msgid "error writing %qs"
 msgid "writing CMI %qs"
 msgstr "写入%qs时错误"
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing modules file: %s"
 msgid "not writing module %qs due to errors"
 msgstr "写入模块文件时出错：%s"
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "failed to write compiled module: %s"
 msgstr "找不到类‘%s’"
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, fuzzy, gcc-internal-format
 msgid "unknown header kind %qs"
 msgstr "spec 函数名格式错误"
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, fuzzy, gcc-internal-format
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "%q+D的声明隐藏了一个形参"
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q+D的节与早先的声明冲突"
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D隐藏了%q#T的构造函数"
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "相互冲突的声明%q#D"
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "因为异常规范不一致"
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "形参%qD被无效地被声明为具有方法类型"
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "%q#D的声明隐藏了一个形参"
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "%qD声明为%qT的一个成员"
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration %qD in local class without prior declaration"
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "本地类中的友元声明%qD没有先前声明"
 
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, fuzzy, gcc-internal-format
 msgid "exporting %q#D that does not have external linkage"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here with no linkage"
 msgstr "%q+D已在此声明过"
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here with internal linkage"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here with module linkage"
 msgstr "%q+D已在此声明过"
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names destructor"
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T::%D%>指定了析构函数"
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "在类作用域使用非成员的 using 声明"
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, fuzzy, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a class, namespace, or enumeration"
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qE不是一个类、命名空间或枚举"
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, fuzzy, gcc-internal-format
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "无效的成员模板声明%qD"
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "在类作用域使用非成员的 using 声明"
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "%qT is not a direct base of %qT"
 msgstr "类型%qT不是%qT的直接基类"
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared in %qD"
 msgstr "%qE未声明"
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, fuzzy, gcc-internal-format
 msgid "using-declaration may not name namespace %qD"
 msgstr "不允许在 using 声明中使用命名空间%qD"
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%>在%qT内指定了构造函数"
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD的声明不在包含%qD的命名空间中"
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD的声明中有显式的限定"
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD应当先在%qD内声明"
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared within %qD"
 msgstr "%qE未声明"
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D声明为友元"
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD属性需要一个 NTBS 作为实参"
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD属性无意义，因为匿名命名空间的成员拥有局部符号"
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "%qs(有%qT)的实参类型无效"
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "%qs(有%qT)的实参类型无效"
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "指定%qD属性被忽略"
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, fuzzy, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "最大值限制的 %d 命名空间搜索的用于 %qE"
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "建议的替代："
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr ""
 
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "静态成员函数中不能使用%<this%>"
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "聚合%q#D类型不完全，无法被定义"
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, fuzzy, gcc-internal-format
 #| msgid "struct defined here"
 msgid "it was later defined here"
 msgstr "结构在此定义"
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "开关%qs不再被支持"
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr "%<this%>不能用在此上下文中"
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD不能在命名空间声明"
 
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "‘%s’(位于 %L)有歧义"
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "这里不允许命名空间别名%qD，假定为%qD"
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "方法属性必须被指定的于结束只有"
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "标号%qD在此定义"
 
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, fuzzy, gcc-internal-format
 #| msgid "%qD conflicts with used function"
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%qD与已用的函数冲突"
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous definition here"
 msgid "reachable %s definition here"
 msgstr "先前的定义在这里"
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX 进入 pop_everything ()\n"
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -63512,7 +63528,7 @@ msgstr "标识符%qE与 C++ 关键字冲突"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
@@ -63761,7 +63777,7 @@ msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
@@ -63946,7 +63962,7 @@ msgstr "语句表达式只能用于函数或模板实参列表内"
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "Lambda 表达式只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "需要元表达式"
@@ -64003,7 +64019,7 @@ msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 msgid "template-id not allowed for destructor in C++20"
 msgstr "关键字%<typename%>不能在模板以外使用"
 
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove the %qs"
@@ -64024,7 +64040,7 @@ msgstr "typedef 名%qD用于析构函数声明"
 msgid "expected unqualified-id"
 msgstr "需要模板 ID"
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD不是一个模板"
@@ -64074,7 +64090,7 @@ msgstr "类型不能定义在%<typeid%>表达式中"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
@@ -64110,7 +64126,7 @@ msgstr "类型不能定义在条件表达式中"
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr ""
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "错误地使用了%qD"
@@ -64135,7 +64151,7 @@ msgstr "ISO C++ 不允许对非类型使用%<alignof%>"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "类型不能定义在%<decltype%>中"
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "不能在返回类型中定义新类型"
@@ -64290,8 +64306,8 @@ msgstr ""
 msgid "capture of non-variable %qE"
 msgstr "%qD不是一个变量"
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q+D已在此声明过"
@@ -64332,7 +64348,7 @@ msgstr "为 lambda 形参指定了默认参数"
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr ""
@@ -64461,7 +64477,7 @@ msgstr "asm 语句中需要左值"
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "需要选择语句"
@@ -64525,7 +64541,7 @@ msgstr "表达式语句类型不完全"
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "需要循环语句"
@@ -64551,7 +64567,7 @@ msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ 不允许计算转移"
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "需要跳转语句"
@@ -64845,12 +64861,12 @@ msgstr "只有构造函数才能有基类初始值设定"
 msgid "cannot expand initializer for member %qD"
 msgstr "无法从成员%<%D%>中扩展初始值"
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "对%qD的静态声明出现在非静态声明之后"
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, fuzzy, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "建构子 delegation 追随 mem-initializer 用于 %qD"
@@ -65516,7 +65532,7 @@ msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 msgid "%qT not permitted in template argument"
 msgstr "参数不匹配"
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, gcc-internal-format
 msgid "invalid use of %qT"
@@ -65702,12 +65718,12 @@ msgstr "%q+#T的前一个定义"
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, gcc-internal-format
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr ""
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "需要%<class%>"
@@ -65921,38 +65937,38 @@ msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 msgid "expression must be enclosed in parentheses"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr ""
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "要求的位置不是一个整数常量"
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, fuzzy, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "要求的位置不是一个整数常量"
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "特例化成员%<%T::%E%>需要%<template<>%>语法"
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "%<%T::%E%>声明无效"
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "模板参数表太少"
@@ -65961,448 +65977,448 @@ msgstr "模板参数表太少"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "模板参数表太多"
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "template-id not allowed for constructor in C++20"
 msgstr "关键字%<typename%>不能在模板以外使用"
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "有名返回值不再被支持"
 
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "实字运算符模板 %qD 有无效的参数清单。 预期 non-type 模板参数包装 <char...>"
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "实字运算符模板 %qD 有无效的参数清单。 预期 non-type 模板参数包装 <char...>"
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "没有找到与%qD匹配的模板"
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "局部类中对成员模板的声明无效"
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "模板有 C 链接"
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "显式特例化前必须有%<template <>%>"
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "%<typedef%>的模板声明"
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "没有声明任何东西"
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "显式特例化不能有存储类型"
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "在嵌套模板实参列表中应当使用%<> >%>而非%<>>%>"
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "可疑的%<>>%>，使用%<>%>来结束模板实参列表"
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, fuzzy, gcc-internal-format
 #| msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr "可疑的%<>>%>，使用%<>%>来结束模板实参列表"
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "指定链接时使用%qD无效"
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD specifier"
 msgstr "%C处重复访问限定符"
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, fuzzy, gcc-internal-format
 msgid "%qD specifier conflicts with %qs"
 msgstr "%+D 导致一个节类型冲突"
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%>出现在%qD之前"
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, fuzzy, gcc-internal-format
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr "%qE不是一个 typedef 类型，也不是一个内建类型"
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 不支持%<long long%>"
 
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "线程局部的 COMMON 数据没有实现"
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "重复的标号%qD"
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "重复的%qs"
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "需要%<new%>"
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "需要%<delete%>"
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "需要%<return%>"
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "需要%<extern%>"
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "需要%<static_assert%>"
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "需要%<decltype%>"
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "需要%<operator%>"
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "需要%<class%>"
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "需要%<template%>"
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "需要%<namespace%>"
 
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "需要%<using%>"
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "需要%<asm%>"
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "需要%<try%>"
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "需要%<catch%>"
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "需要%<throw%>"
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<auto%>"
 msgstr "需要%<catch%>"
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "需要%<__label__%>"
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "需要%<@try%>"
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "需要%<@synchronized%>"
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "需要%<@throw%>"
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "对 rpmtxn 数据库异动作业进行除错"
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "于 %s 等待异动作业锁定\n"
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "expected %<co_yield%>"
 msgstr "需要 %<@end%>"
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "需要%<::%>"
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "需要%<...%>"
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "需要%<*%>"
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "需要%<~%>"
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "需要%<:%>或%<::%>"
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "使用了%qs标记，在命名%q#T时"
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "以前在此声明过"
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "无法声明对%q#T的引用"
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, fuzzy, gcc-internal-format
 #| msgid "%qT declared with greater visibility than its base %qT"
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT被声明为比其基类%qT有更高的可见性"
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "需要%<class%>"
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qT defined as %qs here"
 msgstr "标号%qD在此定义"
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, fuzzy, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "在此声明"
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD重声明时有不同的可访问性"
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "用作消歧义的%<template%>只能用于模板内"
 
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "文件在默认参数处结束"
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "需要指定声明"
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++ 消息参数被预期"
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%>必须指定一个类型作为实参"
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "无效的 Objective-C++ 选择子名"
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "%C处数组声明需要另外一维"
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "不能为局部变量指定节属性"
 
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, fuzzy, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "零星的 %qs 介于 Objective-C++ 方法"
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "不一致的实例变量指定"
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%>需要标识符"
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, fuzzy, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "属性可能无法被指定的之前 %<@%D%>Objective-C++ 关键字"
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE属性为%qE所忽略"
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "不能设置只读属性"
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr "不能设置只读属性"
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression list"
 msgstr "需要整数表达式"
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "无效还原标识符"
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in parameter types"
 msgid "types may not be defined in iterator type"
@@ -66412,13 +66428,13 @@ msgstr "类型不能定义在参数类型中"
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma vtable no longer supported"
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "#pragma vtable 不再受支持"
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "括起的初始化不允许使用在 OpenMP %<for%>循环中"
@@ -66429,138 +66445,138 @@ msgstr "括起的初始化不允许使用在 OpenMP %<for%>循环中"
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr "%<void%>作为仅有的参数时不能被限定"
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "迭代变量%qD不应当是 reduction"
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<#pragma GCC pop_options%>缺少相应的%<#pragma GCC push_options%>"
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr ""
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "无效的初始值设定"
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "? 预期于运算式中"
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "不能在返回类型中定义新类型"
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, fuzzy, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "上一个声明"
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%>而无需 transactional 内存支持已启用"
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%>而无需 transactional 内存支持已启用"
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "外 %<__transaction_cancel%>无法在之内外 %<__transaction_atomic%>"
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, fuzzy, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  或 %<transaction_may_cancel_outer%> 函数"
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma GCC coprocessor"
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "#pragma GCC coprocessor 格式错误"
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%>只能用在复合语句中"
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp barrier%>只能用在复合语句中"
 
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr "#pragma GCC memregs 必须出现在所有函数声明之前"
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "multi-source compilation not implemented for C++"
 msgstr "模块间优化未为 C++ 实现"
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "此上下文中不允许标准转换"
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, fuzzy, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "模板不能是%<virtual%>的"
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -66590,7 +66606,7 @@ msgstr "所包含的类模板并未被显式特例化"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "%qD的特例化必须出现在命名空间内"
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "在不同命名空间内对%qD的特例化"
@@ -66606,27 +66622,27 @@ msgstr "  从%q+#D的定义"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "%qD的显式实例化出现在命名空间%qD中，而后者并不包含命名空间%qD"
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "类名隐藏了模板的模板形参%qD"
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "显式特例化非模板%qT"
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "%qT的实例化在特例化之后"
 
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "from definition of %q#D"
@@ -66634,148 +66650,148 @@ msgstr "  从%q+#D的定义"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "%qT的实例化在%qT的特例化之后"
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "友元模板特例化%qD中不允许出现默认参数"
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "%qD的特例化在实例化之后"
 
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, fuzzy, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s%#D"
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD不是一个函数模板"
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD不是一个模板"
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "%2$q+D的模板标识符%1$qD不匹配任何模板声明"
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "发现 %d 个%<template<>%>，需要 %d 来特例化一个成员函数模板"
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, fuzzy, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, fuzzy, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "在初次使用后显式特例化%qD"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "%qD的显式实例化出现在命名空间%qD中，而后者并不包含命名空间%qD"
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "在初次使用后显式特例化%qD"
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "以前在此声明过"
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "以前在此声明过"
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD in declaration of primary template"
 msgid "template-id %qE in declaration of primary template"
 msgstr "模板标识符%qD出现在基本模板的声明中"
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "显式初始化中出现了模板参数列表"
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "为显式实例化提供的定义"
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "%qD声明时模板参数表太多"
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "%qD声明时模板参数表太少"
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "%qD的显式特例化必须由%<template <>%>引入"
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "显式特例化非模板%qT"
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, fuzzy, gcc-internal-format
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "函数模板部分特例化%qD是不允许的"
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, fuzzy, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "函数模板部分特例化%qD是不允许的"
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "显式特例化时指定了默认参数"
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD不是一个模板函数"
@@ -66788,163 +66804,163 @@ msgstr "%qD不是一个模板函数"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "特例化了隐式声明的特殊成员函数"
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "成员函数%qD未在%qT中声明"
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "友元%q#D的重声明不能有默认模板参数"
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "显式特例化非模板%qT"
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "%L处 ACOS 的参数必须在 -1 和 1 之间"
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, fuzzy, gcc-internal-format
 #| msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "基类初始值设定展开%<%T%>不包括参数包"
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%T%> contains no argument packs"
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "展开样式%<%T%>不包括参数包"
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%E%> contains no argument packs"
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "展开样式%<%E%>不包括参数包"
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "参数包未能在%<...%>中被展开："
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "       %qD"
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "          %s"
 msgid "        %s"
 msgstr "          %s"
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%q+D的声明隐藏了一个形参"
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "%q+D的声明隐藏了一个形参"
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "模板形参类型%qT声明为%<friend%>"
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "部分特例化中未用到模板参数："
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "部分特例化%qT并未特例化任何模板参数"
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "部分特例化%qT并未特例化任何模板参数"
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "以前在此声明过"
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "提供给函数%qE的实参太多"
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "部分特例化%qT并未特例化任何模板参数"
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "以前在此声明过"
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "参数包实参%qE必须出现在模板实参表末尾"
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "参数包实参%qT必须出现在模板实参表末尾"
 
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "模板实参%2$qE的类型%1$qT取决于模板参数"
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "%qD的特例化在实例化之后"
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD没有默认参数"
@@ -66953,49 +66969,49 @@ msgstr "%qD没有默认参数"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "参数包实参%qE必须出现在模板实参表末尾"
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "默认参数不能用在函数模板友元重声明中"
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, fuzzy, gcc-internal-format
 #| msgid "default template arguments may not be used in function template friend declarations"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "默认参数不能用在函数模板友元重声明中"
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "只有指定了 -std=c++0x 或 -std=gnu++0x 时才能在函数模板中使用默认参数"
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "默认参数不能用在部分特例化中"
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "形参%qD被声明为 void"
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "模板类没有名字"
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "非成员函数%qD不能拥有 cv 限定符"
@@ -67005,70 +67021,70 @@ msgstr "非成员函数%qD不能拥有 cv 限定符"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD模板声明无效"
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "对非模板%q#D的模板定义"
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "需要 %d 级的%q#D模板参数，却给出了 %d 级"
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "得到 %d 个模板参数，为%q#D"
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "%2$q#T得到了 %1$d 个模板参数"
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "但实际需要 %d 个"
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, fuzzy, gcc-internal-format
 #| msgid "use template<> for an explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "使用 template<> 来显式特例化"
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "redeclaration of %qD with different constraints"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT不是一个模板类型"
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qD的声明中没有 template 限定"
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "重声明为具有 %d 个模板参数"
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D used %d template parameter"
 #| msgid_plural "previous declaration %q+D used %d template parameters"
@@ -67076,456 +67092,456 @@ msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "先前的声明%q+D使用了 %d 个模板参数"
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "模板形参%q+#D"
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "在这里又被声明为%q#D"
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "redeclared here"
 msgstr "在此声明"
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, fuzzy, gcc-internal-format
 #| msgid "original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "原始定义在此"
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "redeclaration of %q#D with different constraints"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE不是类型%qT的有效模板参数"
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "它必须是一个具有外部链接函数的地址"
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, fuzzy, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "它必须是一个具有外部链接函数的地址"
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, fuzzy, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "它必须是格式为‘&X::Y’的成员指针"
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD不是%qT的成员"
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "%qD声明时模板参数表太多"
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, fuzzy, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  类型 %qT 和 %qT 有不兼容的 cv-qualifiers"
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, fuzzy, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "在类型%qT和%qT间比较"
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "模板参数包%qD不能有默认参数"
 
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qE属性为%qE所忽略"
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, fuzzy, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "Lambda 返回类型演绎得到不一致的类型%qT和%qT"
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  deduced 冲突值用于 non-type 参数 %qE (%qE 和 %qE)"
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为它的类型是%qT"
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "无法将%qE从类型%qT转换到类型%qT"
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT是%qT的有歧义的基类"
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "派生联合%qT无效"
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, fuzzy, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  模板参数的模板模板参数是不一致与其他 deduced 模板参数"
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD不是一个有效模板实参，因为%qD是一个变量，而非变量的地址"
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE不是类型%qT的有效模板实参，因为字面字符串不能用在此上下文中"
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE不是类型%qT的有效模板实参，因为 cv 限定冲突"
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE不是类型%qT的有效模板实参，因为它不是一个左值"
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D不是类型%qT的有效模板参数，因为一个引用变量没有常量地址"
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE不是类型%qT的有效模板实参，因为它是一个指针"
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "尝试使用%qE代替"
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE不是类型%qT的有效模板实参，因为它的类型是%qT"
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "注入的类名%qD被用作模板的模板参数"
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "将析构函数%qD用作类型无效"
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "需要使用某个模板参数的类型成员时，请使用%<typename %E%>"
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "实参 %d 的类型/值不匹配，在%qD的模板参数列表中"
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "需要一个%qT类型的常量，却给出了%qT"
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "需要一个类模板，却给出了%qE"
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "需要一个类型，却给出了%qE"
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "需要一个类型，却给出了%qT"
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "需要一个类模板，却给出了%qT"
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "需要有%qD类型的模板，却得到了%qT"
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "实参 %d 的类型/值不匹配，在%qD的模板参数列表中"
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "需要一个类型，却给出了%qE"
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "不能将模板参数从%qE转换到%qT"
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "提供给%q+D"
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D声明为模板"
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "非模板类型%qT用作模板"
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "对于模板声明%q+D"
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure for %qD"
 msgstr "内部一致性错误"
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qD不是一个模板"
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, fuzzy, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "score argument must be constant integer expression"
 msgstr "折叠参数需要正整常量表达式"
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, fuzzy, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "%qs必须与%qs一起使用"
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "联合和可变数组成员"
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE没有出现在声明的开头"
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "展开%<%T%>时参数包长度不匹配"
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "展开%<%E%>时参数包长度不匹配"
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "重定义%q#D的默认参数"
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths (%d vs %d)"
@@ -67544,307 +67560,307 @@ msgstr "展开%<%T%>时参数包长度不匹配"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "变量%qD有函数类型"
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "无效的参数类型%qT"
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "在声明%q+D中"
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "函数返回了一个数组"
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "函数返回了一个函数"
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "形成对 void 的引用"
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "生成指向引用类型%qT的指针"
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "生成指向引用类型%qT的引用"
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "生成引用类型%qT的成员指针"
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "创建指向 void 类型的成员指针"
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "生成%qT的数组"
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT不是类、结构或联合类型"
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT被解析到非枚举类型%qT"
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT被解析到非类类型%qT"
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "在模板中使用%qs"
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "限定类型%qT不匹配析构函数名 ~%qT"
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "依赖名%qE被解析为非类型，但实例化却产生了一个类型"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "如果您想指定类型，请使用%<typename %E%>"
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "初始值设定中元素不是常量表达式"
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "对集展开表达式的无效使用"
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "使用%<...%>来展开实参集"
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD 未被声明在中这个范围，而找不到任何声明是由 argument-dependent 查找于点的实体化"
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, fuzzy, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "声明在中附属基底 %qT 找不到由资格不符的查找"
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qE未声明(不在函数内)"
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qE attribute"
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "为%qE属性给定的实参数目错误"
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT既不是类也不是命名空间"
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD既不是类也不是命名空间"
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "使用无效字段%qD"
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT是/使用了匿名类型"
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "%qD的模板实参使用了局部类型%qT"
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT是一个可变类型"
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  试图实例化%qD"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T的显式实例化出现在模板定义之前"
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 #, fuzzy
 msgid "%s %#qS"
 msgstr "张贴被搁置的文章 [%%s]？(%s/%s/%s/%s/%s)："
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "对非模板%q#D的显式实例化"
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "显式特例化非模板%qT"
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD不是类模板的非静态数据成员"
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "没有找到与%qD匹配的模板"
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "类型%qT用于显式实例化%qD时不匹配声明的类型%qT"
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "对%q#D的显式实例化"
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "对%q#D重复的显式实例化"
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 不允许在显式实例化时使用%<extern%>"
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "为模板实例化化应用了存储类型%qD"
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "显式实例化非模板类型%qT"
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "显式实例化非模板类型%qT"
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%q#T的显式实例化出现在模板定义之前"
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ 不允许在显式实例化时使用%qE"
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "对%q#T重复的显式实例化"
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -67857,174 +67873,174 @@ msgstr "在初次使用后显式特例化%qD"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "显式实例化%qD时没有可用的定义"
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "在实例化%2$q+D时模板实例化深度超过了最大值 %1$d，可能是由于生成虚函数表所致(使用 -ftemplate-depth= 来增大最大值)"
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T不是一个有效的模板常量参数类型"
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T不是一个有效的模板常量参数类型"
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "关键字%<typename%>不能在模板以外使用"
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be constrained"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, fuzzy, gcc-internal-format
 msgid "concept %qE not in namespace scope"
 msgstr "%qT作为枚举被引用"
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#T inside template parameter list"
 msgid "concept %qE has multiple template parameter lists"
 msgstr "在模板参数列表中定义了%q#T"
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "非模板%qD用作模板"
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "use %qD directly instead"
 msgstr "改用 #include"
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "不考虑内联函数"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, fuzzy, gcc-internal-format
 #| msgid "indirect function %q+D cannot be declared weakref"
 msgid "explicit deduction guide declared here"
 msgstr "内联函数%q+D不能声明为有弱链接"
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, fuzzy, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "无法从%2$qE推导出%1$qT"
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "无法从%2$qE推导出%1$qT"
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "模板第 %d 个参数无效"
@@ -68250,644 +68266,644 @@ msgstr "无法确定 asm 操作数%qE的类型"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "__label__ 声明只能出现在函数作用域中"
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "对非静态成员函数%qD的使用无效"
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr "对非静态成员函数%qD的使用无效"
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr "对非静态成员函数%qD的使用无效"
 
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "%qE missing template arguments"
 msgstr "参数不匹配"
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "cannot call a concept as a function"
 msgstr "%qE不能用作函数"
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "析构函数不能有参数"
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr "静态成员函数中不能使用%<this%>"
 
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, gcc-internal-format
 msgid "use explicit object parameter %qs instead"
 msgstr ""
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, fuzzy, gcc-internal-format
 msgid "name the explicit object parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "静态成员函数中不能使用%<this%>"
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<this%> before it is valid"
 msgstr "在文件作用域使用%<this%>无效"
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<this%> after it is valid"
 msgstr "在文件作用域使用%<this%>无效"
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "在非成员函数中使用%<this%>无效"
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "在文件作用域使用%<this%>无效"
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "伪析构函数名的限定作用域无效"
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "限定的类型%qT不匹配析构函数名 ~%qT"
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE的类型不是%qT"
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "非对象类型%qT的复合字面常量"
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, fuzzy, gcc-internal-format
 msgid "%<auto{x}%> cannot be constrained"
 msgstr "不能内联%<main%>函数"
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, fuzzy, gcc-internal-format
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "模板形参必须使用%<class%>或%<typename%>关键字"
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "将类型%qT用作模板的模板参数的默认值无效"
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "模板的模板形参的默认实参无效"
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "在模板参数列表中定义了%q#T"
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "对限定类型%qT的定义无效"
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "无效的基类"
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, fuzzy, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "匿名联合中出现保护成员%q+#D"
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD未被捕获"
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, fuzzy, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "为 lambda 形参指定了默认参数"
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, fuzzy, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "在包含函数中使用%<auto%>变量"
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, fuzzy, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "已弃用为非函数指定默认参数"
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, fuzzy, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "已弃用为非函数指定默认参数"
 
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing template arguments"
 msgstr "参数不匹配"
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "模板参数%qD(类型为%qT)不允许出现在整数表达式中，因为它的类型不是整数或枚举"
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "将类模板%qT用作表达式"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "在多继承网格中对%qD的访问有歧义"
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE的类型未知"
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qD不是一个枚举名"
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, fuzzy, gcc-internal-format
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr "要求的位置不是一个整数常量"
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr ""
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, fuzzy, gcc-internal-format
 msgid "%<__type_pack_element%> index is out of range"
 msgstr "类型索引编号 %d 超出范围\n"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "为形参声明指定了无效的存储类"
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "不能为析构函数%<~%T%>使用%<offsetof%>"
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "不能为成员函数%qD应用%<offsetof%>"
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "不能为成员函数%qD应用%<offsetof%>"
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "不能为成员函数%qD应用%<offsetof%>"
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, fuzzy, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr "不能通过%<...%>接受不能平凡复制的类型%q#T；"
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, fuzzy, gcc-internal-format
 #| msgid "constructor priorities are not supported"
 msgid "pointer-to-member mapping %qE not supported"
 msgstr "不支持构造函数优先级"
 
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "对%qD的引用有歧义"
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, fuzzy, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE的类型对%<reduction%>无效"
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, gcc-internal-format
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr ""
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, fuzzy, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD在%<firstprivate%>子句中不是一个变量"
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, fuzzy, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, fuzzy, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, fuzzy, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%qE在子句%<firstprivate%>中不是一个变量"
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, fuzzy, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "太多的%qs子句"
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, fuzzy, gcc-internal-format
 msgid "%<filter%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%>%qD不是一个文件、命名空间或块作用域变量"
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%>%qE指示不在%qT定义中"
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "%qE和%qD之间的差不具有整数类型"
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<# pragma omp 基元的 update%>使用两不同的变量用于内存"
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 update%>使用两不同的变量用于内存"
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr ""
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr ""
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr ""
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr ""
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, fuzzy, gcc-internal-format
 msgid "static assertion failed: %.*s"
 msgstr "静态断言错误：%E"
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "静态断言中出现非常量条件"
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, fuzzy, gcc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "argument to %<decltype%> must be an expression"
 msgstr "decltype 的实参必须是一个表达式"
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, fuzzy, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr ""
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr ""
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr "调用%<__builtin_next_arg%>时没有给定实参"
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "需要一个类模板，却给出了%qE"
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "模板实参%qE混杂了模板形参"
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
@@ -68895,1234 +68911,1234 @@ msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV限定符不能应用到%qT上"
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "statement-expression in a constant expression"
 msgstr "常量表达式中的 Lambda 表达式"
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid " declared here"
 msgstr "在此声明"
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, fuzzy, gcc-internal-format
 msgid "base class %qT is not public"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not captured"
 msgid "%qD is not public"
 msgstr "%qD未被捕获"
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is mutable"
 msgstr "%qD不是一个变量"
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD has a non-structural type"
 msgstr "%qD不是一个类型"
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr "只能为类定义应用%qE属性"
 
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not a string constant"
 msgid "%qE attribute argument must be a string constant"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "只能为类定义应用%qE属性"
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "只能为类定义应用%qE属性"
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "只能为类定义应用%qE属性"
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "%qE属性需要带有名实参的原型"
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "不能向类型添加属性%qE"
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "请求的 init_priority 不是一个整数常数"
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "只能将%qE属性用于某个类的对象的文件作用域定义"
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is out of range"
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "请求的 init_priority 越界"
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is reserved for internal use"
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "请求的 init_priority 保留为内部使用"
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "%qD声明为%qT的一个成员"
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%qE属性需要带有名实参的原型"
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%>不是一个有效的声明"
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "请输入有效字符"
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE属性只能用于函数"
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%qE属性只能用于函数"
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not a string constant"
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "PRINT_OPERAND 空指针"
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, fuzzy, gcc-internal-format
 #| msgid "lang_* check: failed in %s, at %s:%d"
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "lang_* check：在 %s 中失败，于 %s:%d"
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "在不同的指针类型%qT和%qT之间的比较需要一个类型转换"
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "在不同的指针类型%qT和%qT之间的转换要一个类型转换"
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "不同的指针类型%qT和%qT组成的条件表达式中需要一个类型转换"
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ 不允许在%<void *%>和函数指针间比较"
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ 不允许在%<void *%>和函数指针间转换"
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++ 不允许%<void *%>和函数指针组成的条件表达式"
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "在不同的成员指针类型%qT和%qT之间的比较需要一个类型转换"
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "在不同的成员指针类型%qT和%qT之间的转换需要一个类型转换"
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "不同的成员指针类型%qT和%qT组成的条件表达式中需要一个类型转换"
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, fuzzy, gcc-internal-format
 #| msgid "canonical types differ for identical types %T and %T"
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "相同类型 %T 和 %T 的正规类型不同"
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, fuzzy, gcc-internal-format
 #| msgid "same canonical type node for different types %T and %T"
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "不同类型 %T 和 %T 有相同的正规类型节点"
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "%qs用于成员函数无效"
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "对位段使用%<sizeof%>无效"
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++ 不允许将%<sizeof%>应用到函数类型的表达式上"
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "对位段使用%<__alignof%>无效"
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++ 不允许将%<__alignof%>应用到函数类型的表达式上"
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "数组%qT的大小的类型不是整数"
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "对非静态成员函数%qD的使用无效"
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "已弃用从字符串常量到%qT的转换"
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "已弃用从字符串常量到%qT的转换"
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "对成员%qD的请求出现在%qE中，而后者具有非类类型%qT"
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "对成员%qD的请求出现在%qE中，而后者具有非类类型%qT"
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of nonstatic data member %qE"
 msgid "invalid use of non-static data member %qE"
 msgstr "对非静态数据成员%qE的使用无效"
 
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "对 NULL 对象非静态数据成员%qD的访问无效"
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "对象类型%qT的析构函数名~%qT不匹配"
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "被析构的类型是%qT，但析构函数却使用了%qT"
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT没有名为%qE的成员"
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%>不是%qT的成员"
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT不是%qT的基类"
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD不是一个成员模板函数"
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT不是一个指向对象的类型"
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "对成员指针数组索引的使用无效"
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "对成员指针使用一元%<*%>非法"
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "隐式转换成员指针用法无效"
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "数组引用缺少下标"
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "按下标访问声明为%<register%>的数组"
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "下标运算的左操作数既非数组也非指针"
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "使用%qE时缺少对象"
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ 不允许在程序里调用%<::main%>"
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "必须用%<.*%>or%<->*%>调用%<%E (...)%>中的成员函数指针，例如%<(... ->* %E) (...)%>"
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE不能用作函数"
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qE不能用作函数"
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "%qE不能用作函数"
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "给 %qE 的实递参数太少"
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "提供给函数%qE的实参太多"
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "提供给函数%qE的实参太少"
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "给予函数的实参太多"
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "给予函数的实参太少"
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "给 %qE 的实递参数太少"
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "给予函数的实参太多"
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "给予函数的实参太少"
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "%2$qD的第 %1$P 个形参的类型%3$qT不完全"
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "形参 %P 的类型%qT不完全"
 
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will never be NULL"
 msgid "the address %qE will never be NULL"
 msgstr "%qD的地址永远不会为 NULL"
 
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "%qD的地址永远不会为 NULL"
 
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr "比较将一律评估作为 %<true%> 用于地址的 %qD 将永不是空值"
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr ""
 
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "比较将一律评估作为 %<true%> 用于地址的 %qD 将永不是空值"
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, fuzzy, gcc-internal-format
 #| msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr "在不同的指针类型%qT和%qT之间的转换要一个类型转换"
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, fuzzy, gcc-internal-format
 #| msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "在不同的指针类型%qT和%qT之间的转换要一个类型转换"
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr "在不同的指针类型%qT和%qT之间的比较需要一个类型转换"
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "在不同的指针类型%qT和%qT之间的比较需要一个类型转换"
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, fuzzy, gcc-internal-format
 #| msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr "不同的指针类型%qT和%qT组成的条件表达式中需要一个类型转换"
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, fuzzy, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr "表达式%qE具有抽象类类型%qT，不能用于 throw 表达式中"
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, fuzzy, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "表达式%qE具有抽象类类型%qT，不能用于 throw 表达式中"
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, fuzzy, gcc-internal-format
 #| msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr "不同的指针类型%qT和%qT组成的条件表达式中需要一个类型转换"
 
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, fuzzy, gcc-internal-format
 #| msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr "不同的指针类型%qT和%qT组成的条件表达式中需要一个类型转换"
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "假定从重载函数转换到类型%qT"
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "算术表达式中使用了 NULL"
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ 不允许比较指针和整数的值"
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "在类型%qT和%qT间比较"
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "指针与整数 0 比较大小"
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "非浮点实参间的无效比较"
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "操作数类型%qT和%qT对双目%qO而言无效"
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ 不允许在减法中使用类型为%<void *%>的指针"
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ 不允许在减法中使用函数指针"
 
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ 不允许在减法中使用指向方法的指针"
 
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "在指针算术中使用指向不完全类型的指针无效"
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of constructor %qE"
 msgid "taking address of constructor %qD"
 msgstr "取构造函数%qE的地址"
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of destructor %qE"
 msgid "taking address of destructor %qD"
 msgstr "取析构函数%qE的地址"
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "用%qE形成成员函数指针的用法无效"
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "需要一个限定的标识符"
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "%qE两边的括号不能用来构造一个成员函数指针"
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允许通过提取一个未限定的或带括号的非静态成员函数的地址来形成一个成员函数指针。请使用%<&%T::%D%>"
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr "ISO C++ 不允许通过提取一个未限定的或带括号的非静态成员函数的地址来形成一个成员函数指针。请使用%<&%T::%D%>"
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允许通过取已绑定的成员函数的地址来构造成员函数指针。请改用%<&%T::%D%>"
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr "ISO C++ 不允许通过取已绑定的成员函数的地址来构造成员函数指针。请改用%<&%T::%D%>"
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr "(成员指针只能用%<&%E%>构成)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "取临时变量的地址"
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ 不允许取函数%<::main%>的地址"
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "不能创建指向引用成员%qD的指针"
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "无法取得位段%qD的地址"
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of expression of type %<void%>"
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "取一个类型为%<void%>的表达式的地址"
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++ 不允许枚举自增"
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++ 不允许枚举自减"
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自增"
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++ 不允许对类型为%qT的指针自增"
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++ 不允许对类型为%qT的指针自减"
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "无法取右值表达式%<this%>的地址"
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "要求显式寄存器变量%qD的地址。"
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "请求声明为%<register%>的%qD的地址"
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "%qT的初始值设定必须在花括号内"
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s 表达式列表被看作复合表达式"
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "缺少用以解析%qE类型的上下文"
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "从类型%qT到类型%qT的类型转换丢失了限定符"
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, fuzzy, gcc-internal-format
 #| msgid "static_cast from type %qT to type %qT casts away qualifiers"
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "从类型%qT到类型%qT的 static_cast 丢失了限定符"
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "从类型%qT到类型%qT的 reinterpret_cast 丢失了限定符"
 
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "向函数类型%qT的转换无效"
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "忽略函数返回类型的类型限定"
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "从类型%qT到类型%qT中的 static_cast 无效"
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "源有不完全的类类型"
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "从%qT转换到%qT"
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "从具有类型%qT的右值表达式到类型%qT中的转换无效"
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "从%qT到%qT的转换损失精度"
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 #, fuzzy
 #| msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "在不同的成员指针类型%qT和%qT之间的比较需要一个类型转换"
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "从%qT到%qT的转换增大了目标类型的对齐需求"
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, fuzzy, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ 不允许在函数指针和对象指针间进行转换"
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "从类型%qT到类型%qT的转换无效"
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "在类型%qT上使用 const_cast 无效，因为它既不是指针，也不是引用，也不是数据成员指针"
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "在类型%qT上使用 const_cast 无效，因为它是一个指针函数类型的指针或引用"
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "从类型%qT到类型%qT中的 const_cast 无效"
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "从类型%qT到类型%qT中的 const_cast 无效"
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ 不允许转换为数组类型%qT"
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "向函数类型%qT的转换无效"
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qE from type %qT to type %qT"
 msgid "moving %qE of type %qT to itself"
 msgstr "无法将%qE从类型%qT转换到类型%qT"
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "在求%<%Q(%#T, %#T)%>值时"
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, fuzzy, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "初始值设定中数组索引不是常数"
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "将%qT赋值给%qT时类型不兼容"
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, gcc-internal-format
 msgid "array used as initializer"
 msgstr "数组被用作初始值设定"
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "无效的数组赋值"
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "在成员函数指针转换中"
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "成员指针转换经由虚基类%qT"
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "在成员指针转换中"
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "到类型%qT的转换无效，从类型%qT"
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in default argument"
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "不能在参数默认时将%qT转换为%qT"
 
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in argument passing"
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "不能在传参时将%qT转换为%qT"
 
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in initialization"
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "不能在初始化时将%qT转换为%qT"
 
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in return"
 msgid "cannot convert %qH to %qI in return"
 msgstr "不能在返回时将%qT转换为%qT"
 
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 #, fuzzy
 #| msgid "cannot convert %qT to %qT in assignment"
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "不能在赋值时将%qT转换为%qT"
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "%2$qE的第 %1$d 个实参可能是 format 属性的备选"
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "返回类型可能是 format 属性的备选"
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "函数的实参可能是 format 属性的备选"
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "初始化的左手边可能是 format 属性的备选时"
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "赋值的左手边可能是 format 属性的备选时"
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "在传递%2$q+D的第 %1$P 个实参时"
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "返回临时变量的引用"
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "returning pointer to temporary"
 msgstr "返回临时变量的引用"
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "返回了对局部变量的%q+D的引用"
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, fuzzy, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "返回了局部变量的%q+D的地址"
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "返回了局部变量的%q+D的地址"
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, fuzzy, gcc-internal-format
 #| msgid "too many values in return statement"
 msgid "redundant move in return statement"
 msgstr "返回语句中值太多"
 
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, fuzzy, gcc-internal-format
 #| msgid "too many values in return statement"
 msgid "redundant move in initialization"
 msgstr "返回语句中值太多"
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "析构函数返回值"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "不能从构造函数的异常处理中返回"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "构造函数返回值"
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "<花括号内的初始值列表>"
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "Lambda 返回类型演绎得到不一致的类型%qT和%qT"
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, fuzzy, gcc-internal-format
 #| msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%>不能返回 NULL，除非它被声明为%<throw()%>(或 -fcheck-new 起作用)"
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, fuzzy, gcc-internal-format
 msgid "not eliding copy on return from %qD"
 msgstr "%q+#D的协变返回类型无效"
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr ""
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, fuzzy, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "右值的引用用作左值"
@@ -70347,161 +70363,161 @@ msgstr "被重载的函数缺少上下文信息"
 msgid "insufficient contextual information to determine type"
 msgstr "上下文信息不足以确定类型"
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "使用了构造函数的语法，但没有为类型%qT声明构造函数"
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "在 {} 内将%qE从%qT转换为较窄的类型%qT"
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 #, fuzzy
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "在 {} 内将%qE从%qT转换为较窄的类型%qT"
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, fuzzy, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "位段%qs的宽度不是一个整数常量表达式"
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, fuzzy, gcc-internal-format
 #| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "用以初始化字符数组的字符串太长"
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "标量初始化带花括号"
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "无法用复合字面常量初始化类型为%qT的聚集"
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "成员%qD缺少初始值设定"
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "类型%qD不匹配原先的声明"
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "在初始化的联合中找不到字段%qD"
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "在联合初始值设定中出现了索引值而不是字段名"
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "检测到循环指针代理"
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%>的基操作数具有非指针类型%qT"
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%>的结果给出了非指针的结果"
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%>的左操作数不是一个指针"
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE不能用作成员指针，因为它的类型为%qT"
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "无法将成员指针%qE应用到%qE上，因为后者的类型%qT不是一个类"
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "成员指针类型%qT与对象类型%qT不兼容"
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "从类型%qT到类型%qT的转换无效"
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, fuzzy, gcc-internal-format
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "不能内联%<main%>函数"
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, fuzzy, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "引用类型的非法值初始化"
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "调用的函数%qD会抛出不完全的类型%q#T"
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "调用的函数会抛出不完全的类型%q#T"
@@ -71534,7 +71550,7 @@ msgstr "名字列表 %s 不能为对 %s 的 USE 关联来更名"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "‘我’于 %L 和‘J’于 %L 无法两者是 BOZ 实字常数"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "%2$C处 DATA 语句初始值设定 %1$s 无效"
@@ -72882,7 +72898,7 @@ msgstr "%C处错误的 INTENT 规格"
 msgid "deferred type parameter at %C"
 msgstr "%C处重复的 DEFERRED 语句"
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -73107,7 +73123,7 @@ msgstr "%2$L处具有 CLASS 的组件‘%1$s’必须是可分配的或指针"
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "%C处结构的数组组件必须有显式或延迟的外形"
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already declared at %L"
@@ -73926,7 +73942,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr "函数定义在%C处需要形参列表"
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "%L处的 BIND(C) 属性只能用于变量或公共块"
@@ -74750,12 +74766,12 @@ msgstr ""
 msgid "are_identical_variables: Bad type"
 msgstr "试图合并相同的常量和常变量"
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr "INTENT(%s) %L处的实参可能干涉%L处的实参。"
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr ""
@@ -75005,276 +75021,276 @@ msgstr "参数’%s在%L处尚未声明或者是一个不能被归约为常量
 msgid "check_init_expr(): Unknown expression type"
 msgstr "需要表达式类型"
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, fuzzy, gcc-internal-format
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr "%2$L处规格函数‘%1$s’不能是一个语句函数"
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, fuzzy, gcc-internal-format
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr "%2$L处规格函数‘%1$s’不能是一个内部函数"
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, fuzzy, gcc-internal-format
 msgid "Specification function %qs at %L must be PURE"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, fuzzy, gcc-internal-format
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr "%2$L处规格函数‘%1$s’不能是 RECURSIVE"
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr "虚参‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr "%L处运算符接口的第一个参数不能是可选的"
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, fuzzy, gcc-internal-format
 msgid "check_restricted(): Unknown expression type"
 msgstr "需要表达式类型"
 
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr "%L处的表达式必须具有 INTEGER 类型而不是 %s"
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L must be PURE"
 msgstr "%L处内建运算符接口必须是一个 FUNCTION"
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr "%L处的表达式必须具有标量类型"
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr ""
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr "%4$L%1$s 中秩(%2$d 和 %3$d)不兼容"
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, gcc-internal-format, gfc-internal-format
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "%2$L处 %1$s 在第 %3$d 维上外形不同(%4$d 和 %5$d)"
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr "不能在%2$C处的 PURE 过程中读取变量‘%1$s’"
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr "%2$L 处的 %1$qs 不是一个 VALUE"
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal stride of zero at %L"
 msgid "Illegal assignment to external procedure at %L"
 msgstr "%L 零间隔非法"
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "赋值中有不兼容的秩 %d 和 %d，位于 %L"
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "%L处赋值中的变量类型是 UNKNOWN"
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "%L处赋值右手边出现 NULL"
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "%L处赋值右手边出现值为 POINTER 的函数"
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr ""
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr "%L处指针赋值时参数种别类型不同"
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "%L处 DATA 语句中类型不兼容；试图从 %s 转换到 %s"
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "%L处指针赋值的目标不是一个 POINTER"
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, fuzzy, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "%2$L处指针赋值中的‘%1$s’不能是一个左值，因为它是一个过程"
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "%2$L处‘%1$s’需要边界规格"
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, fuzzy, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Fortran 2003：%2$L处指针赋值语句中‘%1$s’的边界规格"
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "%L 零间隔非法"
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "外部对象‘%s’在%L处不能有初始值设定"
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "%L处过程指针赋值非法"
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "语句函数‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, fuzzy, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "抽象接口‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "语句函数‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "内部过程‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "%L处过程指针赋值非法"
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, fuzzy, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "内部过程‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "%L处过程指针赋值不匹配：调用约定不匹配"
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "%L处过程指针赋值中接口不匹配：%s"
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "%C处需要 NOPASS 或显式接口"
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "%C处需要 NOPASS 或显式接口"
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "%L处过程指针赋值中接口不匹配：%s"
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr "%L处指针赋值的目标不是一个 POINTER"
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "%L处指针赋值时类型不同；试图将 %s 赋值给 %s"
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "%L处指针赋值时参数种别类型不同"
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "%L处指针赋值时秩不同"
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "分级重新映射目标是小于大小的指标 (%ld<%ld) 于 %L"
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "分级重新映射目标必须是分级 1 或仅需 contiguous 于 %L"
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "Fortran 2008：%L处格式中的‘G0’"
@@ -75282,192 +75298,192 @@ msgstr "Fortran 2008：%L处格式中的‘G0’"
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "%L处计算转移 GOTO 语句的选择表达式必须是一个标量整数表达式"
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr ""
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "%L 处指针赋值目标对象有 PROTECTED 属性"
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr "必须为%L处的 ASYNCHRONOUS= 指定一个初始化表达式"
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr ""
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "%L处指针赋值的目标既不是 TARGET 也不是 POINTER"
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "%L处 PURE 过程中指针赋值目标错误"
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "%L处指针赋值的右手边带有向量下标"
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "%L处指针赋值目标对象有 PROTECTED 属性"
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "%L处指针赋值的目标既不是 TARGET 也不是 POINTER"
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "%L 处指针赋值目标对象有 PROTECTED 属性"
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "%2$L 处的对象“%1$s”对于成分的默认初始化必须有 SAVE 属性，"
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "%L处 PURE 过程中指针赋值目标错误"
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "内部过程‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "内部过程‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2003：%L处初始化表达式中非整数指数"
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Non-variable 运算式在中变量定义语境 (%s) 于 %L"
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Non-POINTER 在中指标关联语境 (%s) 于 %L"
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, fuzzy, gcc-internal-format
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "虚参‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "虚参‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "Associate-name‘%s’无法出现在中变量定义语境 (%s) 于 %L 因为它的目标于 %L 无法，还是"
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "‘%s’于 %L 关联的到运算式无法已用于变量定义语境 (%s)"
@@ -75490,8 +75506,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "在%L处建立临时数组"
@@ -75573,7 +75589,7 @@ msgstr "变量‘%s’(位于 %C)不能在从 %L 开始的循环的内部重定
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "变量‘%s’(位于 %C)不能在从 %L 开始的循环的内部重定义"
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -75709,12 +75725,12 @@ msgstr "%L处定义赋值的第一个参数必须是 INTENT(OUT) 或 INTENT(INOU
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L处定义赋值的第二个参数必须是 INTENT(IN)"
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L处运算符接口的第一个参数必须是 INTENT(IN)"
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L处运算符接口的第二个参数必须是 INTENT(IN)"
@@ -76593,7 +76609,7 @@ msgstr "从 %s 转换到 %s，位于 %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
@@ -77175,7 +77191,7 @@ msgstr "名称表列‘%s’在中读取叙述于 %L 含有符号‘%s’该项
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’不能有 POINTER 组件"
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有 ALLOCATABLE 组件"
@@ -77349,6 +77365,11 @@ msgstr "整数溢出"
 msgid "check_charlen_present(): length not set"
 msgstr ""
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr ""
+
 #: fortran/match.cc:118
 #, fuzzy, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
@@ -77759,7 +77780,7 @@ msgstr "停止编码于 %L 必须是缺省字符 KIND=%d"
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "%C处 Cray 指针必须是一个整数"
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
@@ -78296,85 +78317,85 @@ msgstr "%C处 PROTECTED 语句语法错误"
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "%C处 SELECT TYPE 中的选择子不是一个有名变量；请使用 associate-name=>"
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr "%C处的语句标号为零"
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, gcc-internal-format, gfc-internal-format
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr ""
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "%C处 PROTECTED 语句语法错误"
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "%C处非预期的 CASE 语句"
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "%C处 CASE 规格语法错误"
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "%C处非预期的 TYPE IS 语句"
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "%C处 TYPE IS 规格语法错误"
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "%C处 CLASS IS 规格语法错误"
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected RANK statement at %C"
 msgstr "%C处非预期的 END 语句"
 
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL stride expression at %L must be a scalar %s"
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "%L处 FORALL 间隔表达式必须是一个标量 %s"
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE specification at %C"
 msgid "Syntax error in RANK specification at %C"
 msgstr "%C处 CASE 规格语法错误"
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "%C处的 ELSEWHERE 语句不在 WHERE 块中"
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, fuzzy, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "%2$C处的标号‘%1$s’不匹配 WHERE 标号‘%3$s’"
@@ -79829,8 +79850,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr ""
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "%L处的 IF 分句需要一个标量 LOGICAL 表达式"
@@ -82241,12 +82262,12 @@ msgstr "在%2$L处由内建函数‘%1$s’声明的 INTRINSIC 在当前的标
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "%2$L处非 RECURSIVE 过程‘%1$s’可能递归地调用它自己。请将它声明为 RECURSIVE 或使用 -frecursive"
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, fuzzy, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "%2$L处非 RECURSIVE 过程‘%1$s’可能递归地调用它自己。请将它声明为 RECURSIVE 或使用 -frecursive"
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "标号 %d(引用自 %L)从未被定义"
@@ -82366,7 +82387,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "%2$L处的函数‘%1$s’没有隐式类型"
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "%2$L处的函数‘%1$s’没有隐式类型"
@@ -82770,280 +82791,286 @@ msgstr "数组‘%s’在%L处不能有延迟的外形"
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_variable_attr(): Bad array reference"
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr "gfc_variable_attr()︰不当的数组引用"
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "用在一个规格说明表达式中的变量‘%s’在%L处的引用出现在该变量是其参数的 ENTRY 语句之前"
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "变量‘%s’在%L处的使用出现在该变量是其参数的 ENTRY 语句之前"
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "%2$L处非多态的传递对象哑元实参‘%1$s’"
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Coindexed 对象与 polymorphic allocatable subcomponent 于 %L"
 
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, fuzzy, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "已弃用%qE"
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Bad array reference at %L"
+msgid "Invalid array reference at %L"
+msgstr "%L处数组引用错误"
+
+#: fortran/resolve.cc:6433
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "%C处类型指定无效"
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "%L处传递的对象必须是标量"
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, fuzzy, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "%L处类型限定过程调用的基类型是 ABSTRACT 类型‘%s’"
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, fuzzy, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "%L处 NOPASS 类型限定过程调用的基对象必须是标量"
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "%L处 NOPASS 类型限定过程调用的基对象必须是标量"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, fuzzy, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "%2$L处对 GENERIC‘%1$s’的调用没有找到匹配特别的限定"
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%L处的运算符接口必须是一个 SUBROUTINE"
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "在函数%qs中"
 
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "需要表达式类型"
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s (%L处)必须是一个标量"
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s (%L处)必须是 INTEGER"
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s (%L处)必须是 INTEGER"
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "%L处的 DO 循环中的步进表达式不能为零"
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "%L处的 DO 循环中的步进表达式不能为零"
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 索引名必须是一个标量整数"
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 起始表达式必须是一个标量整数"
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 结束表达式必须是一个标量整数"
 
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L处 FORALL 间隔表达式必须是一个标量 %s"
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L处 FORALL 间隔表达式不能是零"
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL 索引‘%s’不能出现在%L处的三元组规格说明中"
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "%L处的源表达式必须是标量或者与%L处的分配对象有相同的秩"
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "%L处的源表达式和%L处的分配对象必须有相同的外形"
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "%L处实体的类型与%L处的源表达式类型不兼容"
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "%L处的分配对象和%L处的源表达式应该有相同的种别类型参数"
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 于 %L 应该 neither 是的类型 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 于 %L 是 coarray"
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 于 %L 应该 neither 是的类型 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 于 %L 是 coarray"
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "%2$L处分配具有 ABSTRACT 基类型的 %1$s 需要一个类型指定或 SOURCE="
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "配置 %s 于 %L 与 type-spec 需求相同 character-length 参数作为在中声明"
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中有错误的数组规格"
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中有错误的数组规格"
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, fuzzy, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "‘%s’不能出现在%L处其自身被分配的 ALLOCATE 语句的数组规格说明中"
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, fuzzy, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "%1$L处的统计变量不能在同一个 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "%L处的 ERRMSG 没有 STAT 标记所以不起作用"
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "%L处错误信息变量必须是一个标量 CHARACTER 变量"
 
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "%1$L处的错误信息变量不能在同一 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "%L处分配的对象也出现在%L处"
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
@@ -83052,285 +83079,285 @@ msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "%L处的 CASE 标号与%L处的 CASE 标号重叠"
 
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L处 CASE 语句中的表达式必须具有 %s 类型"
 
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "%L 处 CASE 语句中的表达式种别必须为 %d"
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L处 CASE 语句中的表达式必须为标量"
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "%L处计算转移 GOTO 语句的选择表达式必须是一个标量整数表达式"
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L处 SELECT 语句的实参不能是 %s"
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "%L处 CASE 语句中的表达式必须具有 %s 类型"
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "%L处的 DEFAULT CASE 为%L处的第二个 DEFAULT CASE 所跟随"
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "%L处 CASE 语句中的逻辑范围是不被允许的"
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "%L 处 CASE 语句中的常量逻辑值被重复了"
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "%L处范围规格无法匹配"
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "%L处逻辑 SELECT CASE 块有多于两个的情况"
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "%L处过程指针赋值非法"
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "名字‘%s’在%C处不能用作已定义的运算符"
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "%2$L 处的名字“%1$s”已经在 %4$L 处被用作 %3$s"
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "选择子必须是立即数"
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "选择子必须是立即数"
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "%2$L 处的名字“%1$s”已经在 %4$L 处被用作 %3$s"
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "%C处 SELECT TYPE 语句中的选择子应该是多态的"
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "选择子必须是立即数"
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "%L处的 CASE 标号与%L处的 CASE 标号重叠"
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "%2$L处派生类型‘%1$s’必须是可扩展的"
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "%2$L处派生类型‘%1$s’必须是‘%3$s’的一个扩展"
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "对子进程名‘%s’非预期的使用，在%C处"
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "%L处 SELECT TYPE 语句中有双重的 CLASS IS 块"
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "%%L处 NULL() 指针上下文无效"
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "%L处的表达式必须具有标量类型"
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "数据转移组件于 %L 无法 polymorphic 除非它被处理由定义的输入/输出进程"
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 ALLOCATABLE 组件"
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "%L处数据传输元素不能是对一个假定大小数组的全引用"
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "%L处 !$OMP ATOMIC 语句必须设定一个内建类型的标量值"
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "%L处 !$OMP ATOMIC 语句必须设定一个内建类型的标量值"
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "%L处错误信息变量必须是一个标量 CHARACTER 变量"
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%L处 ACOS 的参数必须在 -1 和 1 之间"
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "%L处的语句对%L处的分支语句而言不是一个有效的分支目标语句"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "%L处的分支可能导致无穷循环"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "前往叙述于 %L 树叶重要建构用于标贴于 %L"
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "%s 语句在%C处离开 OpenMP 结构块"
@@ -83338,220 +83365,220 @@ msgstr "%s 语句在%C处离开 OpenMP 结构块"
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "%L处的标号与%L处 GOTO 语句不在相同的块中"
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "%L处的 WHERE 掩码外形不一致"
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "%L处 WHERE 赋值目标外形不一致"
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "%L处 WHERE 中用户定义的非 ELEMENTAL 用户赋值"
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L处在 WHERE 内不支持的语句"
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L处向 FORALL 索引变量赋值"
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, fuzzy, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "%2$L处带索引‘%1$s’的 FORALL 没有被用在赋值的左侧，所以可能导致对这个对象的多个赋值"
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "%L处 FORALL 索引名必须是一个标量整数"
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "%L处外部 FORALL 构造已经有一个同名的索引"
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L处的 WHERE/ELSEWHERE 子句需要一个 LOGICAL 数组"
 
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr "CHARACTER 表达式在%3$L处赋值时将被截断(%1$d/%2$d)"
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "%L处一个非纯变量在 PURE 过程中被赋值给带有 POINTER 组件派生类型变量(12.6)"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%L处 PURE 过程中指针赋值目标错误"
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L处赋值中的变量类型是 UNKNOWN"
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, fuzzy, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "%L处向 FORALL 索引变量赋值"
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, fuzzy, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr "变量必须不是 polymorphic 在中 intrinsic 指派于 %L - 检查该有匹配特定的副常式用于‘=’运算符"
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "%L处赋值中的变量类型不能是多态的"
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "%L处过程指针赋值非法"
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "%L处计算转移 GOTO 语句的选择表达式必须是一个标量整数表达式"
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "ASSIGNED GOTO 语句在%L处需要一个 INTEGER 变量"
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "变量‘%s’在 %L 尚未指派目标标号"
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "%L处的替代 RETURN 语句需要一个 SCALAR-INTEGER 返回限定符"
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected initialization expression in CASE at %C"
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "%C处 CASE 中需要初始化表达式"
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "%L处的 ASSIGN 语句需要一个默认标量 INTEGER 变量"
 
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "%2$L处 %1$s 种别无效"
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "%L处的算术 IF 语句要求一个数字表达式"
 
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "%L处 DO WHILE 循环的退出条件必须是一个标量 LOGICAL 表达式"
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "%L处的 IF 分句需要一个标量 LOGICAL 表达式"
 
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code()：错误的语句代码"
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "%2$L处声明了未使用的参数‘%1$s’"
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
@@ -83559,1012 +83586,1012 @@ msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "%L处字符串太长"
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "可分配的数组‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "%2$L处标量对象‘%1$s’不能为 ALLOCATABLE"
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "数组指针‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, fuzzy, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "%2$L处的 CLASS 变量‘%1$s’必须是哑元、可分配的或者指针"
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "‘%s’在%L处不能是主机相关的，因为它被在%L处声明的一个不兼容的同名对象所阻碍"
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008：%2$L处模块变量‘%1$s’隐含使用了 SAVE，因为默认初始化有此需求"
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "%2$L处的模块或主程序数组‘%1$s’必须有常量外形"
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "%L处假定字符长度的实体必须是个虚参或是个 PARAMETER"
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "可分配的‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "外部‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "哑元‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "内建函数‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "自动数组‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "在 %s 中，于 %s:%d"
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "%2$L处有字符值的语句函数‘%1$s’必须有常量长度"
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, fuzzy, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003：%3$L处‘%1$s’是 PRIVATE 类型因而不能是 PUBLIC 类型‘%2$s’的虚参"
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: %3$L处 PUBLIC 接口‘%2$s’中的过程‘%1$s’有 PRIVATE 的虚参‘%4$s’"
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "函数‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "外部对象‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "%2$L处 ELEMENTAL 函数‘%1$s’必须有一个标量返回值"
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能为数组值"
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "指定CHARACTER(*) 函数‘%s’在%L处不能为指针值"
 
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能为纯函数"
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能是递归的"
 
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "在函数%qs中"
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "%2$L处的具有 PASS 的过程指针组件‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "哑过程‘%s’在%C处不能有泛型接口"
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, fuzzy, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "%L处 PURE 过程不能指定 SAVE 属性"
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE 属性与%2$L处‘%1$s’中的 INTENT 属性冲突"
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE 属性与在%2$L处‘%1$s’中的 RESULT 属性冲突"
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL 属性与在%2$L处‘%1$s’中的 FUNCTION 属性冲突"
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "%2$L处过程指针结果‘%1$s’缺少指针属性"
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, fuzzy, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr "%L处的运算符接口必须是一个 SUBROUTINE"
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "%L处的 FINAL 过程有且只有一个参数"
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "%L处 FINAL 过程的参数必须不是 POINTER"
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "%L处 FINAL 过程的参数必须不是 ALLOCATABLE"
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "%L处 FINAL 过程的参数必须不是 INTENT(OUT)"
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "%L处的非标量 FINAL 过程应当有假定外形的参数"
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "%2$L处声明的 FINAL 过程‘%1$s’有与‘%4$s’相同的秩(%3$d)"
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, fuzzy, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr "仅为定义在%2$L处的派生类型‘%1$s’声明了数组 FINAL 过程，建议也定义一个标量过程"
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%4$L处‘%1$s’和‘%2$s’对 GENERIC‘%3$s’不能是混合的 FUNCTION/SUBROUTINE"
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "引用%qs有歧义：出现在接口%qs和接口%qs中"
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, fuzzy, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "未定义的指定绑定‘%1$s’用作%3$L处的 GENERIC‘%2$s’的目标"
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "%2$L处 GENERIC‘%1$s’必须定位一个特定的绑定，‘%3$s’也是 GENERIC"
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "%2$L处 GENERIC‘%1$s’无法覆盖同名的特定绑定"
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-bound operator at %L can't be NOPASS"
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "%L处类型限定的操作数不能是 NOPASS"
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%2$L处的‘%1$s’必须是一个模块过程或带有显式接口的外部过程"
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "%3$L处有 PASS(%2$s)的过程‘%1$s’没有参数‘%4$s’"
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "%2$L处有 PASS 的过程‘%1$s’必须至少带一个参数"
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "%2$L处非多态的传递对象虚参‘%1$s’"
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr " %4$L处的具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须具有派生类型‘%5$s’"
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr " %4$L处的具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须具有派生类型‘%5$s’"
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr ""
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "%2$L处‘%1$s’的传递对象虚参必须是标量"
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "%2$L处‘%1$s’的传递对象虚参不能是 ALLOCATABLE"
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "%2$L处‘%1$s’的传递对象虚参不能是 POINTER"
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "%2$L处过程‘%1$s’和‘%3$s’的组件重名"
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "%2$L处过程‘%1$s’和‘%3$s’的继承组件重名"
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "%2$L处声明的派生类型‘%1$s’必须是 ABSTRACT，因为‘%3$s’是 DEFERRED 且没有被覆盖"
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "数组指针‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "成分‘%s’于 %L 的类型 (C_PTR) 或类型 (C_FUNPTR) 不应该是 coarray"
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "成分‘%s’于 %L 与 coarray 成分应该是 nonpointer，nonallocatable 纯量"
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "%L处 ICHAR 的参数长度必须为 1"
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "%3$L处带有 PASS(%2$s)的过程指针组件‘%1$s’没有参数‘%4$s’"
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "%2$L处的具有 PASS 的过程指针组件‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "%4$L处具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须有派生类型‘%5$s’"
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "%4$L 处的具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须是标量"
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "%4$L处带 PASS(%3$s) 的‘%2$s’的参数‘%1$s’不能有 POINTER 属性"
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "%4$L处带 PASS(%3$s) 的‘%2$s’的参数‘%1$s’不能是 ALLOCATABLE"
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "%3$L处‘%2$s’的组件‘%1$s’与一个继承的类型限定过程同名"
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, fuzzy, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "%2$L处组件‘%1$s’的字符长度必须是一个常量规格表达式"
 
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be of INTEGER type, found %s"
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "%L处的表达式必须具有 INTEGER 类型而不是 %s"
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, fuzzy, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "字符成分‘%s’的‘%s’于 %L 与已推迟长度必须是指标或 ALLOCATABLE"
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, fuzzy, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003：%3$L处组合‘%1$s’是一个 PRIVATE 类型，因此不能是 PUBLIC‘%2$s’的组合"
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphic 成分 %s 于 %L 在中串行或绑定©类型 %s"
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "%2$L处声明的有 SEQUENCE 类型的组件 %1$s 没有 SEQUENCE 属性"
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "non-constant initialization expression at %L"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "%L处非常量初始化表达式"
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, fuzzy, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "作为延伸类型‘%s’于 %L 有 coarray 成分，亲代类型‘%s’应该也有一个"
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "%2$L处不能扩展的派生类型‘%1$s’不能是 ABSTRACT"
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, fuzzy, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "%3$L处‘%2$s’的组件‘%1$s’与一个继承的类型限定过程同名"
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "%2$L处派生类型‘%1$s’必须是可扩展的"
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "不允许 %3$L 处 %2$s 名字列表中假定大小的数组“%1$s”"
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’不能有假定外形"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有常外形"
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有常外形"
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’声明为 PRIVATE 因此不能是 PUBLIC 名字列表‘%2$s’的成员"
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’有使用相关的 PRIVATE 组件因此不能是 NAMELIST‘%2$s’的成员"
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’有 PRIVATE 组件因此不能是 PUBLIC 名字列表‘%2$s’的成员"
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE 属性与%2$L处‘%1$s’中的 NAMELIST 属性冲突"
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "%2$L处的参数数组‘%1$s’不能是自动的或有延迟的外形"
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, fuzzy, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "%2$L处隐式类型的 PARAMETER‘%1$s’与随后的 IMPLICIT 类型不匹配"
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%L处 PARAMETER 中派生类型不兼容"
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "%C处假定大小数组的规格说明错误"
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%L处假定大小的数组必须是一个虚参"
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "%L处假定大小的数组必须是一个虚参"
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L处的符号不是一个 DUMMY 变量"
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "%2$L处带 VALUE 属性的字符哑元‘%1$s’必须具有常数长度"
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "%2$L处带 VALUE 属性与 C 可互操作的字符哑元‘%1$s’长度必须为 1"
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "%2$L处派生类型‘%1$s’的类型‘%3$s’尚未定义"
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "%2$L处假定外形数组‘%1$s’不能用在初始化表达式中"
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "%C处的循环变量不能是一个子组件"
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "%2$L处变量‘%1$s’不能是 BIND(C) 因为它既不是一个 COMMON 块也不是于模块级作用域声明的"
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, fuzzy, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003：%3$L处 PUBLIC %1$s‘%2$s’具有 PRIVATE 派生类型‘%4$s’"
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "变量 %s 于 %L 的类型 LOCK_TYPE 或与 subcomponent 的类型 LOCK_TYPE 必须是 coarray"
 
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "变量 %s 于 %L 的类型 LOCK_TYPE 或与 subcomponent 的类型 LOCK_TYPE 必须是 coarray"
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "%2$L处INTENT(OUT) 虚参‘%1$s’是 ASSUMED SIZE，所以不能有一个默认初始值设定"
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "变量‘%s’于 %L 的类型 (C_PTR) 或类型 (C_FUNPTR) 不应该是 coarray"
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "变量‘%s’于 %L 与 coarray 成分应该是 nonpointer，nonallocatable 纯量"
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "变量‘%s’于 %L 是 coarray 和不是 ALLOCATABLE，保存 nor 虚参数"
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "%C处可分配的组件必须有延迟的外形"
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "名字列表 %s 不能为对 %s 的 USE 关联来更名"
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "%L处的线程私有变量未被保存"
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting list of named entities at %C"
 msgid "Expecting definable entity near %L"
 msgstr "%C处需要有名实体列表"
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "%2$L处 BLOCK DATA 元素‘%1$s’必须在 COMMON 中"
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "%2$L处 BLOCK DATA 元素‘%1$s’必在前一个声明中指定"
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "%2$L处的 DATA 元素‘%1$s’是一个指针所以必须是一个完全的数组"
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "在 %2$L 处基本过程的参数“%1$s”不能有 POINTER 属性"
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "%L处 DATA 语句中有非常量数组段"
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "%L处的 DATA 语名中变量比值多"
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Nonconstant array section at %L in DATA statement"
 msgid "Non-constant character length at %L in DATA statement"
 msgstr "%L处 DATA 语句中有非常量数组段"
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "开始的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "结束的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "步骤的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "步骤的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "%L处的 DATA 语句中值比变量多"
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "标号 %d 于 %L 经定义但未被使用"
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "标号 %d 于 %L 经定义但无法被使用"
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "%2$L处的派生类型变量‘%1$s’必须有 SEQUENCE 属性方能成为 EQUIVALENCE 对象"
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "%2$L处的派生类型变量‘%1$s’必须没有 ALLOCATABLE 组件方能成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "%2$L处的默认初始化的派生类型变量‘%1$s’不能成为 EQUIVALENCE 对象，因为它在 COMMON 中有变量"
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "%2$L处的带指针组件的派生类型变量‘%1$s’不能成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L处 EQUIVALENCE 语句语法错误"
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "%L处 EQUIVALENCE 集中的对象必须都带有或者都不带有 PROTECTED 属性"
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, fuzzy, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "%2$L处的公共块成员‘%1$s’不能在纯过程‘%3$s’中成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%2$L处的有名常量‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "%2$L处有非常量界限的数组‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%2$L处结构组件‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L 的子字符串长度为零"
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, fuzzy, gcc-internal-format
 #| msgid "Syntax error in character length specification at %C"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "%C处字符长度规格语法错误"
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fortran 2003：%2$L处 PRIVATE 类型‘%3$s’的 PUBLIC 函数‘%1$s’"
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "%2$L处的 ENTRY‘%1$s’没有隐式类型"
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "%2$L处的用户运算符‘%1$s’必须是一个 FUNCTION"
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "%2$L处用户运算符过程‘%1$s’不能有假定字符长度"
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "%2$L处的用户运算符‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "%L处运算符接口的第一个参数不能是可选的"
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "%L处运算符接口的第二个参数不能是可选的"
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "%L处的运算符接口必须有至多两个实参"
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "%2$L处 PURE 过程中包含的过程‘%1$s’必须也是 PURE"
@@ -85118,336 +85145,336 @@ msgstr "%2$L处隐式声明的变量‘%1$s’不能与 C 互操作，但它是%
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr "%2$L处的函数返回值‘%1$s’处没有隐式类型"
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr "%s 属性与 %s 属性在%L处冲突"
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, fuzzy, gcc-internal-format
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr "%s 属性与 %s 属性在%L处冲突"
+
+#: fortran/symbol.cc:508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr "%s 属性在%L处不允许出现在 BLOCAK DATA 程序单元中"
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "%2$L 处的对象“%1$s”对于成分的默认初始化必须有 SAVE 属性，"
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, fuzzy, gcc-internal-format
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr "内部过程‘%s’在%L处不允许用作实参"
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "Fortran 2003：%C处的过程指针"
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "%1$s 属性应用于%4$L处的 %2$s %3$s"
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) 应用于%3$L处的 %1$s %2$s"
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, gcc-internal-format, gfc-internal-format
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr "%s 属性与 %s 属性在%L处冲突"
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, fuzzy, gcc-internal-format
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr "%s 属性与 %s 属性在%L处冲突"
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "不能改变%L处 USE 关联的符号的属性"
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "不能改变%2$L处 USE 关联的符号‘%1$s’的属性"
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "重复的 %s 属性在%L处被指定"
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr "%L 处 ALLOCATABLE 指定在 INTERFACE 体之外"
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate VOLATILE attribute specified at %L"
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr "%L处指定了重复的 VOLATILE 属性"
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, fuzzy, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "为“%s”规定的 DIMENSION 在 %L 处它的 INTERFACE 主体外面"
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, fuzzy, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "%2$L处为‘%1$s’的 DIMENSION 指定在其 INTERFACE 体之外"
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "%L处 Cray 指针指向的对象出现在多个 pointer() 语句中"
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "%L处指定了重复的 PROTECTED 属性"
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "%L处 PURE 过程不能指定 SAVE 属性"
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "%L 指定了重复的 SAVE 属性"
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "%L处指定了重复的 VALUE 属性"
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "%L处指定了重复的 VOLATILE 属性"
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr "%L处 PURE 过程不能指定 SAVE 属性"
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "%L处指定了重复的 ASYNCHRONOUS 属性"
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "%2$L处的 %1$s 过程已经被声明为 %3$s 过程"
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) 与 INTENT(%s) 在 %L 冲突"
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "%L处的 ACCESS 规格已经被指定"
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "%L处指定了重复的 BIND 属性"
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "%L处指定了重复的 BIND 属性"
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "%L处指定了重复的 EXTENDS 属性"
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "Fortran 2003：%L处的 EXTENDS"
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "符号‘%s’在%L处已经有了显式接口"
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "%2$L处的‘%1$s’有在其 INTERFACE 体外指定的属性"
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "符号‘%s’于 %L 冲突与符号从模块‘%s’，use-associated 于 %L"
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "符号‘%s’在%L处已经有了基本类型 %s"
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "%2$L处过程‘%1$s’不能有基本类型 %3$s"
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "%2$L处的符号‘%1$s’不能有类型"
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already in the parent type at %L"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "%2$C处的组件‘%1$s’已在%3$L处的父类中"
 
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "%C处 TYPE 定义中的歧义符号"
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "%2$C处的派生类型‘%1$s’在定义前使用"
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "组件‘%s’在%C处是‘%s’的 PRIVATE 组件"
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "为结构字段%2$qE指定了%1$qs"
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "为结构字段%2$qE指定了%1$qs"
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "重复的语句标号 %d 出现在 %L 和%L处"
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "%2$C处的标号 %1$d 已作为分支目标引用"
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "%2$C处的标号 %1$d 已作为格式标号引用"
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "%2$C处的标号 %1$d 先前用作 FORMAT 标号"
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "%2$C处的标号 %1$d 先前用作分支目标"
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "%C处需要结束名"
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr "%C处的语句标号为零"
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "%2$C处的名字‘%1$s’是从模块‘%4$s’对‘%3$s’有歧义的引用"
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "%2$C处的名字‘%1$s’是从当前程序单元对‘%3$s’有歧义的引用"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "%2$C处符号‘%1$s’已经与主机相关联"
 
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "%2$L处声明的派生类型‘%1$s’必须使用 BIND 属性方可与 C 互操作"
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "衍生类型‘%s’与绑定©属性于 %L 是空的，而也许会是不可访问由 C companion 处理器"
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "%2$L处的组件‘%1$s’不能有 POINTER 属性，因为它是%4$L处派生类型 BIND(C)‘%3$s’的成员"
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "%2$L 处的过程指针组件‘%1$s’不能是%4$L处 BIND(C) 派生类型‘%3$s’的成员"
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "%2$L处的组件‘%1$s’不能有 ALLOCATABLE 属性，因为它是%4$L处派生类型 BIND(C)‘%3$s’的成员"
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "%3$L处的派生类型‘%2$s’的组件‘%1$s’不能与 C 互操作，即使派生类型‘%4$s’是 BIND(C)"
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "%3$L处派生类型‘%2$s’中的组件‘%1$s’不能与 C 互操作"
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "%2$L处派生类型‘%1$s’不能有 SEQUENCE 属性，因为它是 BIND(C)"
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "%2$L处符号‘%1$s’在指定类型之前被使用"
@@ -85478,24 +85505,24 @@ msgstr "%L 处  EQUIVALENCE 中不等的初始值设定重叠"
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "%L 处  EQUIVALENCE 中不等的初始值设定重叠"
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, fuzzy, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "%L处数组构造函数中的元素数超过容许的上限 %d。请参见 -fmax-array-constructor 选项"
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "在%L处建立临时数组"
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "走过错误的表达式类型(%d)"
@@ -85683,37 +85710,37 @@ msgstr "%3$L处声明的的函数‘%2$s’的返回值‘%1$s’没有设置"
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr "不能在%2$C处的 PURE 过程中读取变量‘%1$s’"
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "不能在%2$C处的 PURE 过程中读取变量‘%1$s’"
 
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "未知的内建操作"
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "%L处参数列表函数未知"
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -85724,17 +85751,17 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "内部函数 %s(%d) 无法识别"
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, fuzzy, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "%2$L处‘%1$s’内建函数的‘dim’实参不是一个有效的维数索引"
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "%L处指针赋值时参数种别类型不同"
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "外部对象‘%s’在%L处不能有初始值设定"
@@ -85880,7 +85907,7 @@ msgstr "%L处指针赋值时参数种别类型不同"
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr "抱歉，只有支持用于整数 kind %d 实现的用于 image-set 于 %L"
 
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, fuzzy, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr "gfc_trans_code()：错误的语句代码"
@@ -86260,6 +86287,11 @@ msgstr "变量%qD重声明为函数"
 msgid "function %qD redeclared as variable"
 msgstr "函数%qD重声明为变量"
 
+#: lto/lto-symtab.cc:865
+#, gcc-internal-format
+msgid "previously declared here"
+msgstr "以前在此声明过"
+
 #: lto/lto.cc:174
 #, fuzzy, gcc-internal-format
 #| msgid "lto_obj_file_open() failed"
@@ -87536,7 +87568,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr "%<-fobjc-sjlj-exceptions%>为%<-fgnu-runtime%>所忽略"
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, fuzzy, gcc-internal-format
 #| msgid "non-objective-c type '%T' cannot be caught"
 msgid "non-objective-c type %qT cannot be caught"
@@ -87547,7 +87579,7 @@ msgstr "非 Objective-C 类型‘%T’不能被捕获"
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr "%<-fobjc-sjlj-exceptions%> 是只有支持的异常系统用于 %<-fnext-runtime%> 与 %<-fobjc-abi-version%><2"
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> >= 2"
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
@@ -87640,6 +87672,16 @@ msgstr ""
 #~ msgid "invalid key type for %<-mbranch-protection=%>"
 #~ msgstr "内建函数实参无效"
 
+#, fuzzy, gcc-internal-format
+#~| msgid "cannot declare %qD to be a bit-field type"
+#~ msgid "cannot declare %qD in a different module"
+#~ msgstr "不能将%qD声明为位段类型"
+
+#, fuzzy, gcc-internal-format
+#~| msgid "cannot declare %qD to be a bit-field type"
+#~ msgid "cannot declare %qD in different module"
+#~ msgstr "不能将%qD声明为位段类型"
+
 #, fuzzy, gcc-internal-format
 #~ msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 #~ msgstr "语句函数‘%s’在%L处不允许用作实参"
@@ -90974,10 +91016,6 @@ msgstr ""
 #~ msgid "Builtin function %s requires the -maltivec option"
 #~ msgstr "内建函数%q+D未被声明为函数"
 
-#, fuzzy
-#~ msgid "Builtin function %s requires the -mpaired option"
-#~ msgstr "内建函数%q+D未被声明为函数"
-
 #, fuzzy
 #~ msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 #~ msgstr "内建函数%q+D未被声明为函数"
diff --git a/gcc/po/zh_TW.po b/gcc/po/zh_TW.po
index cf1decb9c38..a77ffc2af07 100644
--- a/gcc/po/zh_TW.po
+++ b/gcc/po/zh_TW.po
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: gcc 10.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2024-05-02 19:44+0000\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
 "PO-Revision-Date: 2020-11-19 00:56+0800\n"
 "Last-Translator: Yi-Jyun Pan <pan93412@gmail.com>\n"
 "Language-Team: Chinese (traditional) <zh-l10n@lists.linux.org.tw>\n"
@@ -445,7 +445,7 @@ msgid "do not specify both -march=... and -mcpu=..."
 msgstr "不指定兩者 -march=...和 -mcpu=…"
 
 #: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
-#: config/i386/mingw-w64.h:123 config/i386/mingw32.h:167
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
 msgid "shared and mdll are not compatible"
 msgstr "shared 和 mdll 互不相容"
 
@@ -20389,18 +20389,18 @@ msgstr "無法辨識的指令："
 msgid "insn does not satisfy its constraints:"
 msgstr "指令不滿足其約束："
 
-#: targhooks.cc:2374
+#: targhooks.cc:2382
 #, c-format
 msgid "created and used with differing settings of '%s'"
 msgstr "建立和使用時使用了不同的「%s」設定"
 
-#: targhooks.cc:2389
+#: targhooks.cc:2397
 #, fuzzy
 #| msgid "created and used with different settings of -fpic"
 msgid "created and used with different settings of %<-fpic%>"
 msgstr "建立和使用時使用了不同的 -fpic 設定"
 
-#: targhooks.cc:2391
+#: targhooks.cc:2399
 #, fuzzy
 #| msgid "created and used with different settings of -fpie"
 msgid "created and used with different settings of %<-fpie%>"
@@ -20723,7 +20723,7 @@ msgstr "strfmon 格式的長度修飾符"
 msgid "<command-line>"
 msgstr "<命令列>"
 
-#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6148
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "「%c」代碼不支援的運算元"
@@ -20742,9 +20742,9 @@ msgstr "「%%%c」的運算元無效"
 
 #: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
 #: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
-#: config/riscv/riscv.cc:6158 config/riscv/riscv.cc:6166
-#: config/riscv/riscv.cc:6173 config/riscv/riscv.cc:6177
-#: config/riscv/riscv.cc:6219 config/riscv/riscv.cc:6237
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "無效指令："
@@ -20765,7 +20765,7 @@ msgstr "「%%%c」的寄存器運算元不相容"
 msgid "incompatible register operand for '%%%c'"
 msgstr "「%%%c」的寄存器運算元不相容"
 
-#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24867
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
 #, c-format
 msgid "missing operand"
 msgstr "缺少運算元"
@@ -20795,93 +20795,93 @@ msgstr "無效的定址模式"
 msgid "cannot combine GNU and SVE vectors in a binary operation"
 msgstr "無效的運算元在中二進運算"
 
-#: config/alpha/alpha.cc:5082 config/i386/i386.cc:14193
-#: config/rs6000/rs6000.cc:14616 config/sparc/sparc.cc:9384
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
 #, fuzzy, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "『%%&』使用的而無需任何本地動態 TLS 參考"
 
-#: config/alpha/alpha.cc:5140 config/bfin/bfin.cc:1428
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
 #, c-format
 msgid "invalid %%J value"
 msgstr "無效 %%J 值"
 
-#: config/alpha/alpha.cc:5170 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
 #, c-format
 msgid "invalid %%r value"
 msgstr "無效 %%r 值"
 
-#: config/alpha/alpha.cc:5180 config/ia64/ia64.cc:5542
-#: config/rs6000/rs6000.cc:14311 config/xtensa/xtensa.cc:3066
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
 #, c-format
 msgid "invalid %%R value"
 msgstr "無效 %%R 值"
 
-#: config/alpha/alpha.cc:5186 config/rs6000/rs6000.cc:14231
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
 #: config/xtensa/xtensa.cc:3039
 #, c-format
 msgid "invalid %%N value"
 msgstr "無效 %%N 值"
 
-#: config/alpha/alpha.cc:5194 config/rs6000/rs6000.cc:14259
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
 #, c-format
 msgid "invalid %%P value"
 msgstr "無效 %%P 值"
 
-#: config/alpha/alpha.cc:5202
+#: config/alpha/alpha.cc:5214
 #, c-format
 msgid "invalid %%h value"
 msgstr "無效 %%h 值"
 
-#: config/alpha/alpha.cc:5210 config/xtensa/xtensa.cc:3059
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
 #, c-format
 msgid "invalid %%L value"
 msgstr "無效 %%L 值"
 
-#: config/alpha/alpha.cc:5229
+#: config/alpha/alpha.cc:5241
 #, c-format
 msgid "invalid %%m value"
 msgstr "無效 %%m 值"
 
-#: config/alpha/alpha.cc:5235
+#: config/alpha/alpha.cc:5247
 #, c-format
 msgid "invalid %%M value"
 msgstr "無效 %%M 值"
 
-#: config/alpha/alpha.cc:5272
+#: config/alpha/alpha.cc:5284
 #, c-format
 msgid "invalid %%U value"
 msgstr "無效 %%U 值"
 
-#: config/alpha/alpha.cc:5280 config/rs6000/rs6000.cc:14319
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
 #, c-format
 msgid "invalid %%s value"
 msgstr "無效 %%s 值"
 
-#: config/alpha/alpha.cc:5291
+#: config/alpha/alpha.cc:5303
 #, c-format
 msgid "invalid %%C value"
 msgstr "無效 %%C 值"
 
-#: config/alpha/alpha.cc:5328 config/rs6000/rs6000.cc:14095
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
 #, c-format
 msgid "invalid %%E value"
 msgstr "無效 %%E 值"
 
-#: config/alpha/alpha.cc:5353 config/alpha/alpha.cc:5403
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
 #, c-format
 msgid "unknown relocation unspec"
 msgstr "不明的不可預期重定位"
 
-#: config/alpha/alpha.cc:5362 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
 #: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
 #: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
-#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14621
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
 #, c-format
 msgid "invalid %%xn code"
 msgstr "無效的 %%xn 程式碼"
 
-#: config/alpha/alpha.cc:5468
+#: config/alpha/alpha.cc:5480
 #, fuzzy, c-format
 msgid "invalid operand address"
 msgstr "無效的 %%d 運算元"
@@ -20983,35 +20983,35 @@ msgstr "無效的 UNSPEC 做為運算元"
 msgid "unrecognized supposed constant"
 msgstr "預期的常數無法識別"
 
-#: config/arm/arm.cc:21110 config/arm/arm.cc:21135 config/arm/arm.cc:21145
-#: config/arm/arm.cc:21154 config/arm/arm.cc:21163
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
 #, fuzzy, c-format
 msgid "invalid shift operand"
 msgstr "無效的 Shift 運算元"
 
-#: config/arm/arm.cc:24117 config/arm/arm.cc:24135
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "預測到的 Thumb 指令"
 
-#: config/arm/arm.cc:24123
+#: config/arm/arm.cc:24132
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "在條件序列中預測到的指令"
 
-#: config/arm/arm.cc:24244 config/arm/arm.cc:24257 config/arm/arm.cc:24282
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
 #: config/nios2/nios2.cc:3085
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "不受支援的運算元用於編碼『%c』"
 
-#: config/arm/arm.cc:24359 config/arm/arm.cc:24381 config/arm/arm.cc:24391
-#: config/arm/arm.cc:24401 config/arm/arm.cc:24411 config/arm/arm.cc:24450
-#: config/arm/arm.cc:24468 config/arm/arm.cc:24486 config/arm/arm.cc:24513
-#: config/arm/arm.cc:24528 config/arm/arm.cc:24555 config/arm/arm.cc:24562
-#: config/arm/arm.cc:24580 config/arm/arm.cc:24587 config/arm/arm.cc:24595
-#: config/arm/arm.cc:24616 config/arm/arm.cc:24623 config/arm/arm.cc:24814
-#: config/arm/arm.cc:24821 config/arm/arm.cc:24848 config/arm/arm.cc:24855
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
 #: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
 #: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
 #: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
@@ -21019,119 +21019,119 @@ msgstr "不受支援的運算元用於編碼『%c』"
 msgid "invalid operand for code '%c'"
 msgstr "程式碼「%c」的運算元無效"
 
-#: config/arm/arm.cc:24463
+#: config/arm/arm.cc:24472
 #, fuzzy, c-format
 msgid "instruction never executed"
 msgstr "指令永不執行"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.cc:24504
+#: config/arm/arm.cc:24513
 #, fuzzy, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "不受支援的運算元用於編碼『%c』"
 
-#: config/arm/arm.cc:34475
+#: config/arm/arm.cc:34536
 #, fuzzy
 msgid "invalid conversion from type %<bfloat16_t%>"
 msgstr "從 %<bfloat16_t%> 類型轉換無效"
 
-#: config/arm/arm.cc:34477
+#: config/arm/arm.cc:34538
 #, fuzzy
 msgid "invalid conversion to type %<bfloat16_t%>"
 msgstr "轉換至 %<bfloat16_t%> 類型無效"
 
-#: config/arm/arm.cc:34492 config/arm/arm.cc:34508
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
 msgid "operation not permitted on type %<bfloat16_t%>"
 msgstr ""
 
-#: config/avr/avr.cc:3610
+#: config/avr/avr.cc:3616
 #, fuzzy, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "位址運算元需求條件約束用於 X,- Y, 或 Z 暫存器"
 
-#: config/avr/avr.cc:3793
+#: config/avr/avr.cc:3799
 #, fuzzy
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "運算元到 %T/%t 必須是 reg+constint(_I)："
 
-#: config/avr/avr.cc:3843 config/avr/avr.cc:3910
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
 #, fuzzy
 msgid "bad address, not an I/O address:"
 msgstr "不當的位址，不是 I/O 位址："
 
-#: config/avr/avr.cc:3852
+#: config/avr/avr.cc:3858
 #, fuzzy
 msgid "bad address, not a constant:"
 msgstr "不當的位址，不是常數："
 
-#: config/avr/avr.cc:3870 config/avr/avr.cc:3877
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
 msgid "bad address, not (reg+disp):"
 msgstr "位址錯誤，不是(reg+disp)："
 
-#: config/avr/avr.cc:3884
+#: config/avr/avr.cc:3890
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "錯誤的位址，不是 post_inc 或 pre_dec:"
 
-#: config/avr/avr.cc:3896
+#: config/avr/avr.cc:3902
 msgid "internal compiler error.  Bad address:"
 msgstr "編譯器內部錯誤。錯誤的位址："
 
-#: config/avr/avr.cc:3929
+#: config/avr/avr.cc:3935
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.cc:3948
+#: config/avr/avr.cc:3954
 msgid "internal compiler error.  Unknown mode:"
 msgstr "編譯器內部錯誤。不明的模式："
 
-#: config/avr/avr.cc:4815 config/avr/avr.cc:5758 config/avr/avr.cc:6205
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
 msgid "invalid insn:"
 msgstr "無效指令："
 
-#: config/avr/avr.cc:4869 config/avr/avr.cc:4980 config/avr/avr.cc:5038
-#: config/avr/avr.cc:5090 config/avr/avr.cc:5109 config/avr/avr.cc:5301
-#: config/avr/avr.cc:5609 config/avr/avr.cc:5894 config/avr/avr.cc:6098
-#: config/avr/avr.cc:6262 config/avr/avr.cc:6355 config/avr/avr.cc:6553
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
 msgid "incorrect insn:"
 msgstr "錯誤指令："
 
-#: config/avr/avr.cc:5125 config/avr/avr.cc:5400 config/avr/avr.cc:5680
-#: config/avr/avr.cc:5966 config/avr/avr.cc:6144 config/avr/avr.cc:6411
-#: config/avr/avr.cc:6611
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
 msgid "unknown move insn:"
 msgstr "無效的 move 指令："
 
-#: config/avr/avr.cc:7378
+#: config/avr/avr.cc:7407
 msgid "bad shift insn:"
 msgstr "錯誤的 shift 指令："
 
-#: config/avr/avr.cc:7486 config/avr/avr.cc:7969 config/avr/avr.cc:8386
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "編譯器內部錯誤。不正確的移位量："
 
-#: config/avr/avr.cc:10210
+#: config/avr/avr.cc:10239
 #, fuzzy
 msgid "unsupported fixed-point conversion"
 msgstr "無效的類型在中定點轉換"
 
-#: config/avr/avr.cc:11585
+#: config/avr/avr.cc:11614
 msgid "variable"
 msgstr "變數"
 
-#: config/avr/avr.cc:11590
+#: config/avr/avr.cc:11619
 msgid "function parameter"
 msgstr "函式參數"
 
-#: config/avr/avr.cc:11595
+#: config/avr/avr.cc:11624
 msgid "structure field"
 msgstr "結構體欄位"
 
-#: config/avr/avr.cc:11601
+#: config/avr/avr.cc:11630
 msgid "return type of function"
 msgstr "函式的回傳類型"
 
-#: config/avr/avr.cc:11606
+#: config/avr/avr.cc:11635
 msgid "pointer"
 msgstr "指針"
 
@@ -21168,7 +21168,7 @@ msgstr "非預期的運算元"
 #: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
 #: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
 #: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
-#: cp/typeck.cc:7752 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
 #: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
 #: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
 #: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
@@ -21491,50 +21491,50 @@ msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.cc:14279
+#: config/i386/i386.cc:14268
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "無效的運算元程式碼「%c」"
 
-#: config/i386/i386.cc:14341 config/i386/i386.cc:14730
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "運算元的約束無效"
 
-#: config/i386/i386.cc:14442
+#: config/i386/i386.cc:14431
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "無效的控制述詞"
 
-#: config/i386/i386.cc:17562
+#: config/i386/i386.cc:17551
 msgid "unknown insn mode"
 msgstr "不明的指令模式"
 
-#: config/i386/i386.cc:23599
+#: config/i386/i386.cc:23777
 #, fuzzy
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
 msgstr "從 %<bfloat16_t%> 類型轉換無效"
 
-#: config/i386/i386.cc:23602
+#: config/i386/i386.cc:23780
 #, fuzzy
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
 msgstr "從 %<bfloat16_t%> 類型轉換無效"
 
-#: config/i386/i386.cc:23605
+#: config/i386/i386.cc:23783
 #, fuzzy
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
 msgstr "轉換至 %<bfloat16_t%> 類型無效"
 
-#: config/i386/i386.cc:23608
+#: config/i386/i386.cc:23786
 #, fuzzy
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
 msgstr "轉換至 %<bfloat16_t%> 類型無效"
 
-#: config/i386/i386.cc:23646 config/i386/i386.cc:23671
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
 msgstr ""
 
-#: config/i386/i386.cc:23649 config/i386/i386.cc:23675
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
 msgstr ""
 
@@ -21565,7 +21565,7 @@ msgstr "對 %<__fpreg%> 的作業無效"
 msgid "invalid %%P operand"
 msgstr "無效的 %%P 運算元"
 
-#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14249
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
 #, c-format
 msgid "invalid %%p value"
 msgstr "無效的 %%p 值"
@@ -21595,29 +21595,29 @@ msgstr "無法使用非 gp 相對的絕對位址"
 msgid "invalid addressing mode"
 msgstr "無效的定址模式"
 
-#: config/loongarch/loongarch.cc:5880 config/loongarch/loongarch.cc:5902
-#: config/loongarch/loongarch.cc:6303 config/mips/mips.cc:9239
-#: config/mips/mips.cc:9266 config/mips/mips.cc:9449
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
 #, fuzzy, c-format
 msgid "'%%%c' is not a valid operand prefix"
 msgstr "『%%%c』並非有效運算元前綴"
 
-#: config/loongarch/loongarch.cc:6140 config/loongarch/loongarch.cc:6160
-#: config/loongarch/loongarch.cc:6206 config/loongarch/loongarch.cc:6213
-#: config/loongarch/loongarch.cc:6260 config/loongarch/loongarch.cc:6263
-#: config/loongarch/loongarch.cc:6275 config/loongarch/loongarch.cc:6282
-#: config/loongarch/loongarch.cc:6292 config/loongarch/loongarch.cc:6295
-#: config/loongarch/loongarch.cc:6316 config/loongarch/loongarch.cc:6323
-#: config/loongarch/loongarch.cc:6350 config/loongarch/loongarch.cc:6361
-#: config/loongarch/loongarch.cc:6376 config/loongarch/loongarch.cc:6385
-#: config/mips/mips.cc:9338 config/mips/mips.cc:9345 config/mips/mips.cc:9352
-#: config/mips/mips.cc:9359 config/mips/mips.cc:9372 config/mips/mips.cc:9379
-#: config/mips/mips.cc:9389 config/mips/mips.cc:9392 config/mips/mips.cc:9404
-#: config/mips/mips.cc:9407 config/mips/mips.cc:9467 config/mips/mips.cc:9474
-#: config/mips/mips.cc:9495 config/mips/mips.cc:9510 config/mips/mips.cc:9529
-#: config/mips/mips.cc:9538 config/riscv/riscv.cc:5962
-#: config/riscv/riscv.cc:6337 config/riscv/riscv.cc:6343
-#: config/riscv/riscv.cc:6359 config/riscv/riscv.cc:6370
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
 #, fuzzy, c-format
 msgid "invalid use of '%%%c'"
 msgstr "無效的使用的『%%%c』"
@@ -21649,7 +21649,7 @@ msgid "post-increment address is not a register"
 msgstr "後自增位址不是一個暫存器"
 
 #: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
-#: config/rs6000/rs6000.cc:20974
+#: config/rs6000/rs6000.cc:20989
 msgid "bad address"
 msgstr "錯誤位址"
 
@@ -21812,7 +21812,7 @@ msgstr "不支援的組合：%s"
 msgid "unsupported memory expression:"
 msgstr "無效的類型在中定點轉換"
 
-#: config/riscv/riscv.cc:6139
+#: config/riscv/riscv.cc:6151
 #, fuzzy, c-format
 msgid "invalid vector operand"
 msgstr "無效的 %%r 運算元"
@@ -21864,263 +21864,263 @@ msgstr "%<-mquad-memory-atomic%> 需要 64 位元模式"
 msgid "%<-mquad-memory%> is not available in little endian mode"
 msgstr "%<-mquad-memory%> 無法在低位位元組在前模式中使用"
 
-#: config/rs6000/rs6000.cc:11339
+#: config/rs6000/rs6000.cc:11354
 #, fuzzy
 msgid "bad move"
 msgstr "不當的移動"
 
-#: config/rs6000/rs6000.cc:13879
+#: config/rs6000/rs6000.cc:13894
 msgid "Bad 128-bit move"
 msgstr "錯誤 128 位元移動"
 
-#: config/rs6000/rs6000.cc:14059
+#: config/rs6000/rs6000.cc:14074
 #, fuzzy, c-format
 #| msgid "invalid %%J value"
 msgid "invalid %%A value"
 msgstr "無效 %%J 值"
 
-#: config/rs6000/rs6000.cc:14068 config/xtensa/xtensa.cc:3015
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
 #, c-format
 msgid "invalid %%D value"
 msgstr "無效的 %%D 值"
 
-#: config/rs6000/rs6000.cc:14083
+#: config/rs6000/rs6000.cc:14098
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "無效 %%H 值"
 
-#: config/rs6000/rs6000.cc:14104
+#: config/rs6000/rs6000.cc:14119
 #, c-format
 msgid "invalid %%f value"
 msgstr "無效 %%f 值"
 
-#: config/rs6000/rs6000.cc:14113
+#: config/rs6000/rs6000.cc:14128
 #, c-format
 msgid "invalid %%F value"
 msgstr "無效 %%F 值"
 
-#: config/rs6000/rs6000.cc:14122
+#: config/rs6000/rs6000.cc:14137
 #, c-format
 msgid "invalid %%G value"
 msgstr "無效 %%G 值"
 
-#: config/rs6000/rs6000.cc:14157
+#: config/rs6000/rs6000.cc:14172
 #, c-format
 msgid "invalid %%j code"
 msgstr "無效 %%j 程式碼"
 
-#: config/rs6000/rs6000.cc:14167
+#: config/rs6000/rs6000.cc:14182
 #, c-format
 msgid "invalid %%J code"
 msgstr "無效 %%J 程式碼"
 
-#: config/rs6000/rs6000.cc:14177
+#: config/rs6000/rs6000.cc:14192
 #, c-format
 msgid "invalid %%k value"
 msgstr "無效 %%k 值"
 
-#: config/rs6000/rs6000.cc:14192 config/xtensa/xtensa.cc:3052
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
 #, c-format
 msgid "invalid %%K value"
 msgstr "無效 %%K 值"
 
-#: config/rs6000/rs6000.cc:14239
+#: config/rs6000/rs6000.cc:14254
 #, c-format
 msgid "invalid %%O value"
 msgstr "無效 %%O 值"
 
-#: config/rs6000/rs6000.cc:14286
+#: config/rs6000/rs6000.cc:14301
 #, c-format
 msgid "invalid %%q value"
 msgstr "無效 %%q 值"
 
-#: config/rs6000/rs6000.cc:14328
+#: config/rs6000/rs6000.cc:14343
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%t value"
 msgstr "無效 %%H 值"
 
-#: config/rs6000/rs6000.cc:14345
+#: config/rs6000/rs6000.cc:14360
 #, c-format
 msgid "invalid %%T value"
 msgstr "無效 %%T 值"
 
-#: config/rs6000/rs6000.cc:14357
+#: config/rs6000/rs6000.cc:14372
 #, c-format
 msgid "invalid %%u value"
 msgstr "無效 %%u 值"
 
-#: config/rs6000/rs6000.cc:14371 config/xtensa/xtensa.cc:3027
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
 #, c-format
 msgid "invalid %%v value"
 msgstr "無效 %%v 值"
 
-#: config/rs6000/rs6000.cc:14421
+#: config/rs6000/rs6000.cc:14436
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%V value"
 msgstr "無效 %%H 值"
 
-#: config/rs6000/rs6000.cc:14437 config/xtensa/xtensa.cc:3073
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
 #, c-format
 msgid "invalid %%x value"
 msgstr "無效的 %%x 值"
 
-#: config/rs6000/rs6000.cc:14494
+#: config/rs6000/rs6000.cc:14509
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%z value"
 msgstr "無效 %%H 值"
 
-#: config/rs6000/rs6000.cc:14563
+#: config/rs6000/rs6000.cc:14578
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "無效的 %%y 值，嘗試使用『Z』條件約束"
 
-#: config/rs6000/rs6000.cc:15505
+#: config/rs6000/rs6000.cc:15520
 #, fuzzy
 msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
 msgstr "啟用 32-bit multiply 指令"
 
-#: config/rs6000/rs6000.cc:24375
+#: config/rs6000/rs6000.cc:24390
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "傳遞 AltiVec 引數給無原型的函式"
 
-#: config/rs6000/rs6000.cc:27990
+#: config/rs6000/rs6000.cc:28005
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "不為每個函式產生單一的離開點"
 
-#: config/rs6000/rs6000.cc:28059
+#: config/rs6000/rs6000.cc:28074
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "無法產生重新載入，為："
 
-#: config/rs6000/rs6000.cc:28135
+#: config/rs6000/rs6000.cc:28150
 msgid "Bad GPR fusion"
 msgstr "錯誤 GPR 融合"
 
-#: config/rs6000/rs6000.cc:28737
+#: config/rs6000/rs6000.cc:28752
 #, fuzzy
 msgid "invalid conversion from type %<__vector_quad%>"
 msgstr "從 %<bfloat16_t%> 類型轉換無效"
 
-#: config/rs6000/rs6000.cc:28739
+#: config/rs6000/rs6000.cc:28754
 #, fuzzy
 msgid "invalid conversion to type %<__vector_quad%>"
 msgstr "轉換至 %<bfloat16_t%> 類型無效"
 
-#: config/rs6000/rs6000.cc:28741
+#: config/rs6000/rs6000.cc:28756
 #, fuzzy
 #| msgid "invalid conversion from %<__fpreg%>"
 msgid "invalid conversion from type %<__vector_pair%>"
 msgstr "從 %<__fpreg%> 的轉換無效"
 
-#: config/rs6000/rs6000.cc:28743
+#: config/rs6000/rs6000.cc:28758
 #, fuzzy
 #| msgid "invalid conversion to %<__fpreg%>"
 msgid "invalid conversion to type %<__vector_pair%>"
 msgstr "向 %<__fpreg%> 的轉換無效"
 
-#: config/s390/s390.cc:8415
+#: config/s390/s390.cc:8416
 #, fuzzy, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "符號記憶體參考是只有支援的於 z10 或稍後"
 
-#: config/s390/s390.cc:8426
+#: config/s390/s390.cc:8427
 #, c-format
 msgid "cannot decompose address"
 msgstr "無法分解位址"
 
-#: config/s390/s390.cc:8508
+#: config/s390/s390.cc:8509
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "無效的比較運算子用於『E』輸出修飾鍵"
 
-#: config/s390/s390.cc:8531
+#: config/s390/s390.cc:8532
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "無效的參考用於『J』輸出修飾鍵"
 
-#: config/s390/s390.cc:8549
+#: config/s390/s390.cc:8550
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "無效的位址用於『O』輸出修飾鍵"
 
-#: config/s390/s390.cc:8571
+#: config/s390/s390.cc:8572
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "無效的位址用於『R』輸出修飾鍵"
 
-#: config/s390/s390.cc:8589
+#: config/s390/s390.cc:8590
 #, fuzzy, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "記憶體參考預期的用於『S』輸出修飾鍵"
 
-#: config/s390/s390.cc:8599
+#: config/s390/s390.cc:8600
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "無效的位址用於『S』輸出修飾鍵"
 
-#: config/s390/s390.cc:8620
+#: config/s390/s390.cc:8621
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "暫存器或記憶體運算式預期的用於『N』輸出修飾鍵"
 
-#: config/s390/s390.cc:8631
+#: config/s390/s390.cc:8632
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "暫存器或記憶體運算式預期的用於『公尺』輸出修飾鍵"
 
-#: config/s390/s390.cc:8740 config/s390/s390.cc:8761
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "無效的常數用於輸出修飾鍵『%c』"
 
-#: config/s390/s390.cc:8758
+#: config/s390/s390.cc:8759
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "無效的常數 - 嘗試使用輸出修飾鍵"
 
-#: config/s390/s390.cc:8795
+#: config/s390/s390.cc:8796
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "無效的常數用於輸出修飾鍵『%c』"
 
-#: config/s390/s390.cc:8802
+#: config/s390/s390.cc:8803
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "無效的運算式 - 嘗試使用輸出修飾鍵"
 
-#: config/s390/s390.cc:8805
+#: config/s390/s390.cc:8806
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "無效的運算式用於輸出修飾鍵『%c』"
 
-#: config/s390/s390.cc:12664
+#: config/s390/s390.cc:12665
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "傳遞 AltiVec 引數給無原型的函式"
 
-#: config/s390/s390.cc:17110
+#: config/s390/s390.cc:17111
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "回傳指標時目的與指標有/無號不一致"
 
-#: config/s390/s390.cc:17120
+#: config/s390/s390.cc:17121
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.cc:17123
+#: config/s390/s390.cc:17124
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.cc:17131
+#: config/s390/s390.cc:17132
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -22323,12 +22323,12 @@ msgstr "({匿名})"
 #: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
 #: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
 #: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
-#: c/c-parser.cc:22363 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
 #: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
 #: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
 #: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
 #: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
-#: cp/parser.cc:33810 cp/parser.cc:34449
+#: cp/parser.cc:33812 cp/parser.cc:34451
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "需要 %<;%>"
@@ -22341,7 +22341,7 @@ msgstr "需要 %<;%>"
 #: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
 #: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
 #: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
-#: c/c-parser.cc:22327 c/c-parser.cc:25651 c/c-parser.cc:25733
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
 #: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
 #: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
 #: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
@@ -22350,7 +22350,7 @@ msgstr "需要 %<;%>"
 #: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
 #: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
 #: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
-#: cp/parser.cc:34497
+#: cp/parser.cc:34499
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "預期 %<)%>"
@@ -22358,7 +22358,7 @@ msgstr "預期 %<)%>"
 #: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
 #: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
 #: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
-#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34461
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "預期 %<]%>"
@@ -22370,29 +22370,29 @@ msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
 #. Look for the two `(' tokens.
 #: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
-#: c/c-parser.cc:17005 c/c-parser.cc:24795 c/c-parser.cc:25459
-#: c/c-parser.cc:25676 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
 #: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
 #: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
 #: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
 #: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
 #: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
-#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34452
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "預期 %<(%>"
 
-#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34464
-#: cp/parser.cc:38333 go/gofrontend/embed.cc:440
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "預期 %<[%>"
 
 #: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
-#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23107
-#: c/c-parser.cc:26919 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
 #: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
-#: cp/parser.cc:34458 go/gofrontend/embed.cc:371
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "需要 %<{%>"
@@ -22402,17 +22402,17 @@ msgstr "需要 %<{%>"
 #: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
 #: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
 #: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
-#: c/c-parser.cc:18731 c/c-parser.cc:24662 c/c-parser.cc:25516
-#: c/c-parser.cc:25575 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
 #: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
-#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34491
-#: cp/parser.cc:36194 cp/parser.cc:39264 cp/parser.cc:40157
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
 #: go/gofrontend/embed.cc:404
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "預期 %<:%>"
 
-#: c/c-parser.cc:8199 cp/parser.cc:34378
+#: c/c-parser.cc:8199 cp/parser.cc:34380
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "預期 %<while%>"
@@ -22421,8 +22421,8 @@ msgstr "預期 %<while%>"
 #: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
 #: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
 #: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
-#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33808
-#: cp/parser.cc:34467
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "預期 %<,%>"
@@ -22433,17 +22433,17 @@ msgid "expected %<.%>"
 msgstr "預期 %<.%>"
 
 #: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
-#: cp/parser.cc:36768 cp/parser.cc:36789
+#: cp/parser.cc:36770 cp/parser.cc:36791
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "預期 %<@end%>"
 
-#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34476
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "預期 %<>%>"
 
-#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34500
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "預期 %<,%>或 %<)%>"
@@ -22451,32 +22451,32 @@ msgstr "預期 %<,%>或 %<)%>"
 #. All following cases are statements with LHS.
 #: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
 #: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
-#: c/c-parser.cc:24843 c/c-parser.cc:25717 c/gimple-parser.cc:745
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
 #: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
-#: cp/parser.cc:34479 cp/parser.cc:43147 cp/parser.cc:43320
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "需要 %<=%>"
 
 #: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
 #: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
-#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34455
-#: cp/parser.cc:36978
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "預期 %<}%>"
 
-#: c/c-parser.cc:21421 cp/parser.cc:43245
+#: c/c-parser.cc:21421 cp/parser.cc:43247
 #, fuzzy, gcc-internal-format
 msgid "expected %<else%>"
 msgstr "預期 %<delete%>"
 
-#: c/c-parser.cc:23154 c/c-parser.cc:23143 cp/parser.cc:45944
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "預期 %<# pragma omp section%>或 %<}%>"
 
-#: c/c-parser.cc:26283 cp/parser.cc:49921
+#: c/c-parser.cc:26281 cp/parser.cc:49919
 msgid "<message unknown at compile time>"
 msgstr ""
 
@@ -22485,7 +22485,7 @@ msgstr ""
 msgid "(anonymous)"
 msgstr "(匿名)"
 
-#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34473
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "預期 %<<%>"
@@ -22502,22 +22502,22 @@ msgstr "預期的頻道"
 msgid "candidate:"
 msgstr "備選 1："
 
-#: cp/call.cc:8332
+#: cp/call.cc:8333
 #, fuzzy
 msgid "  after user-defined conversion:"
 msgstr "啟用使用者定義的指令"
 
-#: cp/call.cc:8498 cp/pt.cc:2043 cp/pt.cc:26344
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "candidate 是："
 
-#: cp/call.cc:13020 cp/call.cc:13446
+#: cp/call.cc:13021 cp/call.cc:13447
 msgid "candidate 1:"
 msgstr "備選 1："
 
-#: cp/call.cc:13022 cp/call.cc:13447
+#: cp/call.cc:13023 cp/call.cc:13448
 msgid "candidate 2:"
 msgstr "備選 2："
 
@@ -22797,7 +22797,7 @@ msgstr "%s:%d:%d：  在中 constexpr 擴展的 %qs"
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%s:%d：  在中 constexpr 擴展的 %qs"
 
-#: cp/pt.cc:2041 cp/semantics.cc:6310
+#: cp/pt.cc:2042 cp/semantics.cc:6308
 msgid "candidates are:"
 msgstr "備選為："
 
@@ -22851,52 +22851,52 @@ msgstr "轉換演員陣容暫離 constness"
 msgid "source type is not polymorphic"
 msgstr "來源型態不是 polymorphic"
 
-#: cp/typeck.cc:7443 c/c-typeck.cc:4685
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "單位元減的運算元類型錯誤"
 
-#: cp/typeck.cc:7444 c/c-typeck.cc:4671
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "單位元加的運算元類型錯誤"
 
-#: cp/typeck.cc:7471 c/c-typeck.cc:4730
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "按位取反的引數類型錯誤"
 
-#: cp/typeck.cc:7488 c/c-typeck.cc:4738
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "不能對該類型的引數求絕對值"
 
-#: cp/typeck.cc:7500 c/c-typeck.cc:4760
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "不能對該類型的引數求共軛"
 
-#: cp/typeck.cc:7524
+#: cp/typeck.cc:7520
 #, fuzzy
 msgid "in argument to unary !"
 msgstr "在中引數到一元！"
 
-#: cp/typeck.cc:7573
+#: cp/typeck.cc:7569
 #, fuzzy
 msgid "no pre-increment operator for type"
 msgstr "沒有 pre-increment 運算子用於型態"
 
-#: cp/typeck.cc:7575
+#: cp/typeck.cc:7571
 #, fuzzy
 msgid "no post-increment operator for type"
 msgstr "沒有 post-increment 運算子用於型態"
 
-#: cp/typeck.cc:7577
+#: cp/typeck.cc:7573
 #, fuzzy
 msgid "no pre-decrement operator for type"
 msgstr "沒有 pre-decrement 運算子用於型態"
 
-#: cp/typeck.cc:7579
+#: cp/typeck.cc:7575
 #, fuzzy
 msgid "no post-decrement operator for type"
 msgstr "沒有 post-decrement 運算子用於型態"
@@ -22983,7 +22983,7 @@ msgstr "Obsolescent 特徵：計算的前往於 %C"
 msgid "Deleted feature:"
 msgstr "預期的運算子"
 
-#: fortran/expr.cc:3809
+#: fortran/expr.cc:3814
 #, fuzzy
 msgid "array assignment"
 msgstr "陣列指派"
@@ -23192,11 +23192,11 @@ msgstr "區塊 IF"
 msgid "implied END DO"
 msgstr "暗示的 END DO"
 
-#: fortran/parse.cc:2432 fortran/resolve.cc:12765
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
 msgid "assignment"
 msgstr "賦值"
 
-#: fortran/parse.cc:2435 fortran/resolve.cc:12831 fortran/resolve.cc:12834
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
 msgid "pointer assignment"
 msgstr "指標賦值"
 
@@ -23382,57 +23382,57 @@ msgstr "使用者運算子「%s」(位於 %%L)的運算元為 %s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "使用者運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.cc:7659
+#: fortran/resolve.cc:7668
 #, fuzzy
 msgid "Loop variable"
 msgstr "迴圈變數"
 
-#: fortran/resolve.cc:7663
+#: fortran/resolve.cc:7672
 #, fuzzy
 msgid "iterator variable"
 msgstr "迭代器變數"
 
-#: fortran/resolve.cc:7667
+#: fortran/resolve.cc:7676
 #, fuzzy
 msgid "Start expression in DO loop"
 msgstr "開始運算式在中做迴圈"
 
-#: fortran/resolve.cc:7671
+#: fortran/resolve.cc:7680
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "結束運算式在中做迴圈"
 
-#: fortran/resolve.cc:7675
+#: fortran/resolve.cc:7684
 #, fuzzy
 msgid "Step expression in DO loop"
 msgstr "步驟運算式在中做迴圈"
 
-#: fortran/resolve.cc:7962 fortran/resolve.cc:7965
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "取消配置物件"
 
-#: fortran/resolve.cc:8353 fortran/resolve.cc:8356
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "配置物件"
 
-#: fortran/resolve.cc:8593 fortran/resolve.cc:10670 fortran/resolve.cc:10791
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
 #, fuzzy
 msgid "STAT variable"
 msgstr "STAT 變數"
 
-#: fortran/resolve.cc:8644 fortran/resolve.cc:10682 fortran/resolve.cc:10803
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "ERRMSG 變數"
 
-#: fortran/resolve.cc:10472
+#: fortran/resolve.cc:10481
 #, fuzzy
 msgid "item in READ"
 msgstr "項目在中讀取"
 
-#: fortran/resolve.cc:10694
+#: fortran/resolve.cc:10703
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK 變數"
@@ -23442,12 +23442,12 @@ msgstr "ACQUIRED_LOCK 變數"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgstr "不同的字元長度 (%ld/%ld) 在中陣列建構子"
 
-#: fortran/trans-array.cc:6401
+#: fortran/trans-array.cc:6413
 #, fuzzy
 msgid "Integer overflow when calculating the amount of memory to allocate"
 msgstr "整數溢位時計算數目的記憶體到配置"
 
-#: fortran/trans-array.cc:10501
+#: fortran/trans-array.cc:10525
 #, c-format
 msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
 msgstr ""
@@ -23462,12 +23462,12 @@ msgstr "實際的字串長度不匹配宣告的一個用於虛引數『%s』(%ld
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "實際的字串長度是短於宣告的一個用於虛引數『%s』(%ld/%ld)"
 
-#: fortran/trans-expr.cc:10754
+#: fortran/trans-expr.cc:10759
 #, fuzzy, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "目標的分級重新映射太小 (%ld<%ld)"
 
-#: fortran/trans-expr.cc:12351
+#: fortran/trans-expr.cc:12385
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -23476,82 +23476,82 @@ msgstr ""
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Unequal 字元長度 (%ld/%ld) 在中 %s"
 
-#: fortran/trans-intrinsic.cc:6518
+#: fortran/trans-intrinsic.cc:6521
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6613
+#: fortran/trans-intrinsic.cc:6616
 #, fuzzy, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "引數『a%d』和『a%d』用於 intrinsic『%s』"
 
-#: fortran/trans-intrinsic.cc:6661
+#: fortran/trans-intrinsic.cc:6664
 #, c-format
 msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6671
+#: fortran/trans-intrinsic.cc:6674
 #, c-format
 msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6678
+#: fortran/trans-intrinsic.cc:6681
 #, c-format
 msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6760
+#: fortran/trans-intrinsic.cc:6763
 #, fuzzy, c-format
 msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
 msgstr "引數『a%d』和『a%d』用於 intrinsic『%s』"
 
-#: fortran/trans-intrinsic.cc:6828
+#: fortran/trans-intrinsic.cc:6831
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6908
+#: fortran/trans-intrinsic.cc:6911
 #, c-format
 msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:6916 fortran/trans-intrinsic.cc:6961
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
 #, c-format
 msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:9312
+#: fortran/trans-intrinsic.cc:9359
 #, fuzzy, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "引數 NCOPIES 的重複 intrinsic 是負 (它的值是 %ld)"
 
-#: fortran/trans-intrinsic.cc:9344
+#: fortran/trans-intrinsic.cc:9391
 #, fuzzy
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "引數 NCOPIES 的重複 intrinsic 太大"
 
-#: fortran/trans-intrinsic.cc:12509
+#: fortran/trans-intrinsic.cc:12556
 #, fuzzy, c-format
 msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "引數『a%d』和『a%d』用於 intrinsic『%s』"
 
-#: fortran/trans-intrinsic.cc:12521
+#: fortran/trans-intrinsic.cc:12568
 #, fuzzy, c-format
 msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "引數『a%d』和『a%d』用於 intrinsic『%s』"
 
-#: fortran/trans-intrinsic.cc:12533
+#: fortran/trans-intrinsic.cc:12580
 #, fuzzy, c-format
 msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
 msgstr "引數『a%d』和『a%d』用於 intrinsic『%s』"
 
-#: fortran/trans-intrinsic.cc:12545
+#: fortran/trans-intrinsic.cc:12592
 #, c-format
 msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
 
-#: fortran/trans-intrinsic.cc:12553
+#: fortran/trans-intrinsic.cc:12600
 #, c-format
 msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
 msgstr ""
@@ -23575,16 +23575,16 @@ msgstr "賦值標籤不是目的標籤"
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "無效的影像號碼 %d 在中同步影像"
 
-#: fortran/trans-stmt.cc:2517
+#: fortran/trans-stmt.cc:2527
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.cc:2537 fortran/trans-stmt.cc:2793
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
 #, fuzzy
 msgid "Loop variable has been modified"
 msgstr "迴圈變數已被已修改"
 
-#: fortran/trans-stmt.cc:2646
+#: fortran/trans-stmt.cc:2656
 #, fuzzy
 msgid "DO step value is zero"
 msgstr "做步驟值是零"
@@ -23671,7 +23671,7 @@ msgid "expected boolean type"
 msgstr "預期的布林值型態"
 
 #: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
-#: cp/parser.cc:40917 cp/parser.cc:40924
+#: cp/parser.cc:40919 cp/parser.cc:40926
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -23745,7 +23745,7 @@ msgstr "不足引數"
 #: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
 #: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
 #: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
-#: cp/pt.cc:9370
+#: cp/pt.cc:9381
 #, fuzzy, gcc-internal-format
 msgid "too many arguments"
 msgstr "太多引數"
@@ -24456,7 +24456,7 @@ msgid "%<-mrelax%> is only supported for RTP PIC"
 msgstr "-mrelax 是只有支援的用於 RTP PIC"
 
 #. A general purpose syntax error.
-#: fortran/gfortran.h:3412 fortran/io.cc:3727 fortran/io.cc:4413
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s 敘述在 %C 處語法錯誤"
@@ -24910,8 +24910,8 @@ msgstr "%qE 屬性衝突與屬性 %s"
 
 #: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
 #: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
-#: c-family/c-attribs.cc:5147 cp/decl.cc:16434 cp/decl.cc:16484
-#: cp/friend.cc:318 cp/tree.cc:5259
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "與此處早先的宣告 %q+#D 衝突"
@@ -24928,7 +24928,7 @@ msgstr "%qE 屬性指令忽略"
 msgid "%<%E::%E%> scoped attribute directive ignored"
 msgstr "%qE 屬性指令忽略"
 
-#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3667
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments specified for %qE attribute"
 msgstr "錯誤的引數數量指定的用於 %qE 屬性"
@@ -24938,7 +24938,7 @@ msgstr "錯誤的引數數量指定的用於 %qE 屬性"
 msgid "expected %i or more, found %i"
 msgstr "預期 %<(%>或列尾"
 
-#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3669
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "expected %i, found %i"
 msgstr "預期 %<(%>或列尾"
@@ -25005,12 +25005,12 @@ msgstr "型態屬性忽略的之後型態已經定義"
 #: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
 #: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
 #: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
-#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11226
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
 #: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
-#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3756
-#: config/i386/i386-options.cc:3914 config/i386/i386-options.cc:4146
-#: config/i386/i386-options.cc:4176 config/ia64/ia64.cc:795
-#: config/loongarch/loongarch.cc:7999 config/rs6000/rs6000.cc:20738
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
 #: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
 #: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
 #: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
@@ -25019,7 +25019,7 @@ msgstr "型態屬性忽略的之後型態已經定義"
 #: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
 #: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
 #: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
-#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5013 cp/tree.cc:5424
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
 #: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
 #: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
 #: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
@@ -25041,8 +25041,8 @@ msgstr "%qE 屬性被忽略"
 msgid "missing %<target%> attribute for multi-versioned %qD"
 msgstr ""
 
-#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2351 cp/decl.cc:2399
-#: cp/decl.cc:2415 cp/decl.cc:3095 cp/decl.cc:3533
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %qD"
@@ -25152,7 +25152,7 @@ msgstr "無法讀取 LTO decls 從 %s"
 msgid "offset %qwi outside bounds of constant string"
 msgstr "偏移量超過字串常數界"
 
-#: builtins.cc:707 cp/name-lookup.cc:6773
+#: builtins.cc:707 cp/name-lookup.cc:6830
 #, fuzzy, gcc-internal-format
 msgid "%qE declared here"
 msgstr "%qD 宣告的在此"
@@ -25262,7 +25262,7 @@ msgstr "缺少引數到 %qs"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.cc:8018 expr.cc:12318
+#: builtins.cc:8018 expr.cc:12326
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kinvalid 使用的 %<__builtin_va_arg_pack()%>"
@@ -25284,43 +25284,43 @@ msgstr "%<__builtin_longjmp%> 的第二個引數必須是 1"
 msgid "target format does not support infinity"
 msgstr "目的格式不支援無限大浮點數"
 
-#: builtins.cc:11227
+#: builtins.cc:11247
 #, fuzzy, gcc-internal-format
 #| msgid "%<va_start%> used in function with fixed args"
 msgid "%<va_start%> used in function with fixed arguments"
 msgstr "在定參數的函式中使用了 %<va_start%>"
 
-#: builtins.cc:11235
+#: builtins.cc:11255
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "錯誤的引數數量到函式 %<va_start%>"
 
-#: builtins.cc:11250
+#: builtins.cc:11270
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "呼叫 %<__builtin_next_arg%> 時沒有給定引數"
 
-#: builtins.cc:11255
+#: builtins.cc:11275
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "錯誤的引數數量到函式 %<__builtin_next_arg%>"
 
-#: builtins.cc:11288
+#: builtins.cc:11308
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%> 的第二個參數不是最後一個具名參數"
 
-#: builtins.cc:11301
+#: builtins.cc:11321
 #, fuzzy, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "未定義的行為時秒參數的 %<va_start%> 被宣告與 %<register%>貯藏體"
 
-#: builtins.cc:11330
+#: builtins.cc:11350
 #, fuzzy, gcc-internal-format
 msgid "first argument of %qD must be a pointer, second integer constant"
 msgstr "%Kfirst 引數的 %D 必須是指標，秒整數常數"
 
-#: builtins.cc:11343
+#: builtins.cc:11363
 #, fuzzy, gcc-internal-format
 msgid "last argument of %qD is not integer constant between 0 and 3"
 msgstr "%Klast 引數的 %D 不是整數常數介於 0 和 3"
@@ -26390,12 +26390,12 @@ msgstr "%<weakref%> 屬性忽略的因為變數被初始化的"
 
 #. include_self=
 #. TODO: Add OPT_Wundefined-inline.
-#: cgraphunit.cc:1098 c/c-decl.cc:13338
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F 使用過但從未定義"
 
-#: cgraphunit.cc:1100 c/c-decl.cc:13348
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F 宣告為 %<static%> 卻從未定義過"
@@ -26960,7 +26960,7 @@ msgstr "region_array 不匹配 region_tree"
 msgid "%<lp_array%> does not match %<region_tree%>"
 msgstr "lp_array 不匹配 region_tree"
 
-#: except.cc:3541 tree.cc:14395 value-prof.cc:529
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
 #, fuzzy, gcc-internal-format
 msgid "%qs failed"
 msgstr "開啟 %s 失敗：%s"
@@ -26990,17 +26990,17 @@ msgstr ""
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.cc:12330
+#: expr.cc:12338
 #, fuzzy, gcc-internal-format
 msgid "call to %qs declared with attribute error: %s"
 msgstr "%Kcall 到 %qs 宣告的與屬性錯誤：%s"
 
-#: expr.cc:12344
+#: expr.cc:12352
 #, fuzzy, gcc-internal-format
 msgid "call to %qs declared with attribute warning: %s"
 msgstr "%Kcall 到 %qs 宣告的與屬性警告：%s"
 
-#: expr.cc:13391
+#: expr.cc:13399
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
 msgstr "假設帶正負號溢位不發生時簡化 %<abs (X)%> 到 %<X%>或 %<-X%>"
@@ -27035,7 +27035,7 @@ msgstr "大定點常數隱含地截短至定點型態"
 msgid "comparison is always %d due to width of bit-field"
 msgstr "由於位元段寬度所限，比較結果永遠為 %d"
 
-#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3969
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "假設帶正負號溢位不發生時簡化範圍測試"
@@ -27210,7 +27210,7 @@ msgstr "提取處理次時失敗：%m"
 msgid "%s signal terminated program %s"
 msgstr "使用另一套暫存器名"
 
-#: gcc.cc:3956 opts-common.cc:1597 opts-common.cc:1629
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
 #, fuzzy, gcc-internal-format
 msgid "unrecognized command-line option %qs"
 msgstr "無法辨識的命令列選項 %qs"
@@ -27477,7 +27477,7 @@ msgstr "multilib spec %qs 無效"
 msgid "multilib exclusions %qs is invalid"
 msgstr "multilib 互斥 %qs 無效"
 
-#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2242
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
 #, fuzzy, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "multilib 選取 %qs 無效"
@@ -27782,22 +27782,22 @@ msgstr "大小的陣列 %qE 是負"
 msgid "%qD specified bound %E equals source length"
 msgstr ""
 
-#: gimple-fold.cc:4550 gimple-fold.cc:4777
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD does not have well defined padding bits for %qs"
 msgstr "flexible 陣列成員無法於結束的結構"
 
-#: gimple-fold.cc:4726 cp/constexpr.cc:4901
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
 #, gcc-internal-format
 msgid "PDP11 bit-field handling unsupported in %qs"
 msgstr ""
 
-#: gimple-fold.cc:5007
+#: gimple-fold.cc:5009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s not supported for variable length aggregates"
 msgstr "ISO C 不支援飽和類型"
 
-#: gimple-fold.cc:5013
+#: gimple-fold.cc:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s not supported on this target"
 msgstr "巢狀的函式不支援於這個目標"
@@ -27839,16 +27839,16 @@ msgid "function returns address of local variable"
 msgstr "函式回傳局部變數的位址"
 
 #: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
-#: gimple-ssa-warn-access.cc:3713 tree.cc:12442 tree.cc:12479 tree.cc:12520
-#: tree.cc:12553 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
 #: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
 #: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
-#: cp/call.cc:8203 cp/call.cc:10398 cp/class.cc:9399 cp/constexpr.cc:889
-#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5996
-#: cp/constexpr.cc:6367 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9104
-#: cp/decl2.cc:5889 cp/decl2.cc:5944 cp/method.cc:1234 cp/parser.cc:22475
-#: cp/pt.cc:9178 cp/semantics.cc:2378 cp/semantics.cc:3782 cp/semantics.cc:4900
-#: cp/typeck.cc:2143 cp/typeck.cc:2363 cp/typeck.cc:4509 cp/typeck.cc:10694
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
 #: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
 #: rust/backend/rust-tree.cc:3813
 #, fuzzy, gcc-internal-format
@@ -27860,355 +27860,355 @@ msgstr "宣告的在此"
 msgid "%<nonnull%> argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2836 gimple-ssa-sprintf.cc:2956
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2841 gimple-ssa-sprintf.cc:2961
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2853
+#: gimple-ssa-sprintf.cc:2855
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2860
+#: gimple-ssa-sprintf.cc:2862
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2867
+#: gimple-ssa-sprintf.cc:2869
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2878
+#: gimple-ssa-sprintf.cc:2880
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2881
+#: gimple-ssa-sprintf.cc:2883
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2883
+#: gimple-ssa-sprintf.cc:2885
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2895
+#: gimple-ssa-sprintf.cc:2897
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2898
+#: gimple-ssa-sprintf.cc:2900
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2901
+#: gimple-ssa-sprintf.cc:2903
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2910
+#: gimple-ssa-sprintf.cc:2912
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2913
+#: gimple-ssa-sprintf.cc:2915
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2916
+#: gimple-ssa-sprintf.cc:2918
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2925
+#: gimple-ssa-sprintf.cc:2927
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2928
+#: gimple-ssa-sprintf.cc:2930
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2930
+#: gimple-ssa-sprintf.cc:2932
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:2972
+#: gimple-ssa-sprintf.cc:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2979
+#: gimple-ssa-sprintf.cc:2981
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2987
+#: gimple-ssa-sprintf.cc:2989
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:2999
+#: gimple-ssa-sprintf.cc:3001
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3002
+#: gimple-ssa-sprintf.cc:3004
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3005
+#: gimple-ssa-sprintf.cc:3007
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3018
+#: gimple-ssa-sprintf.cc:3020
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3021
+#: gimple-ssa-sprintf.cc:3023
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3024
+#: gimple-ssa-sprintf.cc:3026
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3034
+#: gimple-ssa-sprintf.cc:3036
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3037
+#: gimple-ssa-sprintf.cc:3039
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3040
+#: gimple-ssa-sprintf.cc:3042
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3049
+#: gimple-ssa-sprintf.cc:3051
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3052
+#: gimple-ssa-sprintf.cc:3054
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3055
+#: gimple-ssa-sprintf.cc:3057
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3177
+#: gimple-ssa-sprintf.cc:3179
 #, fuzzy, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr "延伸：負引數 N 於 %L"
 
-#: gimple-ssa-sprintf.cc:3255
+#: gimple-ssa-sprintf.cc:3257
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3261
+#: gimple-ssa-sprintf.cc:3263
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3268
+#: gimple-ssa-sprintf.cc:3270
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3298
+#: gimple-ssa-sprintf.cc:3300
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3304
+#: gimple-ssa-sprintf.cc:3306
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3315
+#: gimple-ssa-sprintf.cc:3317
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3321
+#: gimple-ssa-sprintf.cc:3323
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3332
+#: gimple-ssa-sprintf.cc:3334
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3342
+#: gimple-ssa-sprintf.cc:3344
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3348 gimple-ssa-warn-access.cc:234
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
 #, fuzzy, gcc-internal-format
 msgid "referenced argument declared here"
 msgstr "參考 %qs 無法宣告 %<mutable%>"
 
-#: gimple-ssa-sprintf.cc:3355
+#: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:3362
+#: gimple-ssa-sprintf.cc:3364
 #, fuzzy, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "延伸：負引數 N 於 %L"
 
-#: gimple-ssa-sprintf.cc:3364
+#: gimple-ssa-sprintf.cc:3366
 #, fuzzy, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr "停用回合 %s 用於函式在中範圍的 [%u，%u]"
 
-#: gimple-ssa-sprintf.cc:3368
+#: gimple-ssa-sprintf.cc:3370
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3388
+#: gimple-ssa-sprintf.cc:3390
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgid_plural "%qE output %wu bytes into a destination of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:3393
+#: gimple-ssa-sprintf.cc:3395
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3398
+#: gimple-ssa-sprintf.cc:3400
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3403
+#: gimple-ssa-sprintf.cc:3405
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3414
+#: gimple-ssa-sprintf.cc:3416
 #, gcc-internal-format
 msgid "%qE output %wu byte"
 msgid_plural "%qE output %wu bytes"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:3418
+#: gimple-ssa-sprintf.cc:3420
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3422
+#: gimple-ssa-sprintf.cc:3424
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu)"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3426
+#: gimple-ssa-sprintf.cc:3428
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3810
+#: gimple-ssa-sprintf.cc:3812
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3844
+#: gimple-ssa-sprintf.cc:3846
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3977
+#: gimple-ssa-sprintf.cc:3979
 msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:3989
+#: gimple-ssa-sprintf.cc:3991
 msgid "%qE argument %Z overlaps destination object %qE"
 msgid_plural "%qE arguments %Z overlap destination object %qE"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:4000
+#: gimple-ssa-sprintf.cc:4002
 msgid "%qE argument %Z may overlap destination object %qE"
 msgid_plural "%qE arguments %Z may overlap destination object %qE"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.cc:4020
+#: gimple-ssa-sprintf.cc:4022
 #, gcc-internal-format
 msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4607
+#: gimple-ssa-sprintf.cc:4609
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4618
+#: gimple-ssa-sprintf.cc:4620
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4644
+#: gimple-ssa-sprintf.cc:4646
 #, gcc-internal-format
 msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4688
+#: gimple-ssa-sprintf.cc:4690
 #, fuzzy, gcc-internal-format
 msgid "null destination pointer"
 msgstr "空指標"
 
-#: gimple-ssa-sprintf.cc:4705
+#: gimple-ssa-sprintf.cc:4707
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.cc:4717
+#: gimple-ssa-sprintf.cc:4719
 #, fuzzy, gcc-internal-format
 msgid "null format string"
 msgstr "%s 在中格式字串於 %L"
@@ -28953,12 +28953,12 @@ msgstr "無效的指標模式 %qs"
 #: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
 #: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
 #: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
-#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8578
-#: cp/call.cc:8589 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
-#: cp/decl.cc:4631 cp/decl.cc:12893 cp/decl.cc:13481 cp/decl.cc:13490
-#: cp/decl.cc:14491 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
 #: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
-#: cp/parser.cc:25045 cp/typeck.cc:5002
+#: cp/parser.cc:25045 cp/typeck.cc:4998
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD 宣告的在此"
@@ -29734,7 +29734,7 @@ msgstr ""
 msgid "token %u has %<y-location == %u%>"
 msgstr ""
 
-#: internal-fn.cc:841
+#: internal-fn.cc:843
 #, fuzzy, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
 msgstr "無效的使用的 %<auto%>"
@@ -30079,17 +30079,17 @@ msgstr "%q+D 宣告的在此，稍後在中轉譯單位"
 msgid "mismatching definition"
 msgstr "定義缺失"
 
-#: ipa-fnsummary.cc:4656
+#: ipa-fnsummary.cc:4658
 #, fuzzy, gcc-internal-format
 msgid "invalid fnsummary in LTO stream"
 msgstr "無效的函式在中 gimple 呼叫"
 
-#: ipa-fnsummary.cc:4757
+#: ipa-fnsummary.cc:4759
 #, fuzzy, gcc-internal-format
 msgid "ipa inline summary is missing in input file"
 msgstr "ipa 內聯概要缺少在中輸入檔案"
 
-#: ipa-modref.cc:4017
+#: ipa-modref.cc:4022
 #, fuzzy, gcc-internal-format
 msgid "IPA modref summary is missing in input file"
 msgstr "ipa 內聯概要缺少在中輸入檔案"
@@ -31180,73 +31180,73 @@ msgstr "寫入 %s 時發生錯誤：%m"
 msgid "error closing optimization records %qs"
 msgstr "進行跨跳轉最佳化"
 
-#: opts-common.cc:1432
+#: opts-common.cc:1447
 #, fuzzy, gcc-internal-format
 #| msgid "command line option %qs is not supported by this configuration"
 msgid "command-line option %qs is not supported by this configuration"
 msgstr "此配置不支援命令列選項 %qs"
 
-#: opts-common.cc:1442 opts.cc:2576
+#: opts-common.cc:1457 opts.cc:2576
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "缺少引數到 %qs"
 
-#: opts-common.cc:1449
+#: opts-common.cc:1464
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
 msgstr "引數到 %qs 應該是 non-negative 整數"
 
-#: opts-common.cc:1453
+#: opts-common.cc:1468
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs should be a non-negative integer"
 msgstr "引數到 %qs 應該是 non-negative 整數"
 
-#: opts-common.cc:1460
+#: opts-common.cc:1475
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is not between %d and %d"
 msgstr "-malign-functions=%d 未被介於 0 和 %d"
 
-#: opts-common.cc:1524
+#: opts-common.cc:1539
 #, fuzzy, gcc-internal-format
 msgid "invalid argument in option %qs"
 msgstr "有效引數到 %qs 是：%s"
 
-#: opts-common.cc:1526
+#: opts-common.cc:1541
 #, gcc-internal-format
 msgid "%qs specified multiple times in the same option"
 msgstr ""
 
-#: opts-common.cc:1529
+#: opts-common.cc:1544
 #, fuzzy, gcc-internal-format
 msgid "%qs is mutually exclusive with %qs and cannot be specified together"
 msgstr "-mcorea 和 -mcoreb can%'t 一起使用"
 
-#: opts-common.cc:1551
+#: opts-common.cc:1566
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument in option %qs"
 msgstr "無法辨識的引數在中選項 %qs"
 
-#: opts-common.cc:1562 config/i386/i386-options.cc:1703
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
-#: opts-common.cc:1565 config/i386/i386-options.cc:1706
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: opts-common.cc:1608 c-family/c-opts.cc:471
+#: opts-common.cc:1623 c-family/c-opts.cc:471
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "開關 %qs 不再被支援"
 
-#: opts-common.cc:1668
+#: opts-common.cc:1683
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is bigger than %d"
 msgstr "引數到 %qE 屬性大於 %d"
 
-#: opts-common.cc:2015
+#: opts-common.cc:2030
 #, fuzzy, gcc-internal-format
 msgid "malformed %<COLLECT_GCC_OPTIONS%>"
 msgstr "異常的 COLLECT_GCC_OPTIONS"
@@ -31321,8 +31321,8 @@ msgstr "引數到 %qs 應該是 non-negative 整數"
 
 #: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
 #: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
-#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20411
-#: config/mips/mips.cc:20413 config/mips/mips.cc:20426
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with %qs"
 msgstr "%qs 是不相容的與 %qs"
@@ -32058,7 +32058,7 @@ msgstr "全域暫存器變數出現在函式定義後"
 msgid "register of %qD used for multiple global register variables"
 msgstr "暫存器的 %qD 用於多重全域暫存器變數"
 
-#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5579
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "衝突與 %qD"
@@ -32517,42 +32517,42 @@ msgstr ""
 msgid "%<__builtin_saveregs%> not supported by this target"
 msgstr "__builtin_saveregs 不為此目的所支援"
 
-#: targhooks.cc:1215
+#: targhooks.cc:1223
 #, fuzzy, gcc-internal-format
 msgid "argument %qs is not supported for %qs on this target"
 msgstr "巢狀的函式不支援於這個目標"
 
-#: targhooks.cc:1257
+#: targhooks.cc:1265
 #, fuzzy, gcc-internal-format
 msgid "nested functions not supported on this target"
 msgstr "巢狀的函式不支援於這個目標"
 
-#: targhooks.cc:1270
+#: targhooks.cc:1278
 #, fuzzy, gcc-internal-format
 msgid "nested function trampolines not supported on this target"
 msgstr "巢狀的函式 trampolines 不支援於這個目標"
 
-#: targhooks.cc:1433
+#: targhooks.cc:1441
 #, gcc-internal-format
 msgid "global constructors not supported on this target"
 msgstr "全域建構式在此目標平臺上不受支援"
 
-#: targhooks.cc:1442
+#: targhooks.cc:1450
 #, gcc-internal-format
 msgid "global destructors not supported on this target"
 msgstr "全域解構函式在此目標平臺上不受支援"
 
-#: targhooks.cc:1802
+#: targhooks.cc:1810
 #, fuzzy, gcc-internal-format
 msgid "%<target%> attribute is not supported on this machine"
 msgstr "目標屬性未被支援於這個機器"
 
-#: targhooks.cc:1814
+#: targhooks.cc:1822
 #, fuzzy, gcc-internal-format
 msgid "%<target_version%> attribute is not supported on this machine"
 msgstr "目標屬性未被支援於這個機器"
 
-#: targhooks.cc:1828
+#: targhooks.cc:1836
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC target%> is not supported for this machine"
 msgstr "# pragma GCC 目標未被支援用於這個機器"
@@ -33700,86 +33700,86 @@ msgstr "BB %i 有不正確邊緣"
 msgid "BB %i has incorrect fallthru edge"
 msgstr "BB %i 有不正確 fallthru 邊緣"
 
-#: tree-inline.cc:3925
+#: tree-inline.cc:3939
 #, fuzzy, gcc-internal-format
 msgid "function %q+F can never be copied because it receives a non-local goto"
 msgstr "函式 %q+F 可以永不被複製因為它接收 non-local 前往"
 
-#: tree-inline.cc:3932
+#: tree-inline.cc:3946
 #, fuzzy, gcc-internal-format
 msgid "function %q+F can never be copied because it saves address of local label in a static variable"
 msgstr "函式 %q+F 可以永不被複製因為它儲存位址的本地標貼在中靜態變數"
 
-#: tree-inline.cc:3972
+#: tree-inline.cc:3986
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
 msgstr "函式 %q+F 無法被內聯，因為它使用了 alloca (使用 always_inline 屬性強制內聯)"
 
-#: tree-inline.cc:3986
+#: tree-inline.cc:4000
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp"
 msgstr "函式 %q+F 無法被內聯，因為它使用了 setjmp"
 
-#: tree-inline.cc:4000
+#: tree-inline.cc:4014
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgstr "函式 %q+F 無法被內聯，因為它使用了變長引數表"
 
-#: tree-inline.cc:4012
+#: tree-inline.cc:4026
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
 msgstr "函式 %q+F 無法被內聯，因為它使用了 setjmp-longjmp 異常處理"
 
-#: tree-inline.cc:4020
+#: tree-inline.cc:4034
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses non-local goto"
 msgstr "函式 %q+F 無法被內聯，因為使用了非區域性的 goto"
 
-#: tree-inline.cc:4032
+#: tree-inline.cc:4046
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses __builtin_return or __builtin_apply_args"
 msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
 msgstr "函式 %q+F 無法被內聯，因為使用了 __builtin_return 或 __builtin_apply_args"
 
-#: tree-inline.cc:4052
+#: tree-inline.cc:4066
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it contains a computed goto"
 msgstr "函式 %q+F 無法被內聯，因為包含一個執行時 goto"
 
-#: tree-inline.cc:4098
+#: tree-inline.cc:4112
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it uses variable argument lists"
 msgid "function %q+F can never be inlined because it has a VLA argument"
 msgstr "函式 %q+F 無法被內聯，因為它使用了變長引數表"
 
-#: tree-inline.cc:4165
+#: tree-inline.cc:4179
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+F can never be inlined because it is suppressed using -fno-inline"
 msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
 msgstr "函式 %q+F 無法被內聯，因為使用了 -fno-inline"
 
-#: tree-inline.cc:4173
+#: tree-inline.cc:4187
 #, gcc-internal-format
 msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
 msgstr "函式 %q+F 無法被內聯，因為它使用了與內聯衝突的屬性"
 
-#: tree-inline.cc:4854
+#: tree-inline.cc:4868
 #, fuzzy, gcc-internal-format
 msgid "inlining failed in call to %<always_inline%> %q+F: %s"
 msgstr "內聯失敗的在中呼叫到 alwaysinline %q+F(_I)：%s"
 
-#: tree-inline.cc:4857 tree-inline.cc:4878
+#: tree-inline.cc:4871 tree-inline.cc:4892
 #, gcc-internal-format
 msgid "called from here"
 msgstr "從此處呼叫"
 
-#: tree-inline.cc:4860 tree-inline.cc:4881
+#: tree-inline.cc:4874 tree-inline.cc:4895
 #, fuzzy, gcc-internal-format
 #| msgid "from this location"
 msgid "called from this function"
 msgstr "從這個地方"
 
-#: tree-inline.cc:4874
+#: tree-inline.cc:4888
 #, gcc-internal-format
 msgid "inlining failed in call to %q+F: %s"
 msgstr "呼叫 %q+F 時內聯失敗：%s"
@@ -33835,28 +33835,28 @@ msgstr "無效的元件類型用於屬性 %qs"
 msgid "invalid fn spec attribute \"%s\" arg %i"
 msgstr "無效的使用的 %<auto%>"
 
-#: tree-ssa-ccp.cc:4681 c-family/c-common.cc:5912
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
 #, gcc-internal-format
 msgid "%qs pointer is null"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4684 c-family/c-common.cc:5915
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "in a call to non-static member function %qD"
 msgstr "對非靜態成員函式 %qD 的使用無效"
 
-#: tree-ssa-ccp.cc:4690 c-family/c-common.cc:5921
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.cc:4696
+#: tree-ssa-ccp.cc:4700
 #, fuzzy, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "無效的引數到內建函式"
 
-#: tree-ssa-ccp.cc:4700 c-family/c-common.cc:5925
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
 #, fuzzy, gcc-internal-format
 msgid "in a call to function %qD declared %qs"
 msgstr "內聯函式 %q+D 宣告的 weak"
@@ -34056,7 +34056,7 @@ msgstr "%qE 未被初始化的"
 msgid "%qs may be used uninitialized"
 msgstr "%qD 也許會被使用 uninitialized 在中這個函式"
 
-#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8019
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
 #, fuzzy, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD 被宣告在此"
@@ -34286,7 +34286,7 @@ msgstr "向量作業將被展開 piecewise"
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "向量隨機播放作業將被展開 piecewise"
 
-#: tree-vect-loop.cc:5065
+#: tree-vect-loop.cc:5069
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
@@ -34301,122 +34301,122 @@ msgstr ""
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.cc:7341 m2/gm2-gcc/m2type.cc:215
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "函式陣列是沒有意義的"
 
-#: tree.cc:7496
+#: tree.cc:7513
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "函式不能回傳函式"
 
-#: tree.cc:8956 tree.cc:9041 tree.cc:9104
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "樹檢查：%s，得到 %s 在 %s，於 %s:%d"
 
-#: tree.cc:8993
+#: tree.cc:9032
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "樹檢查：不需要 %s，得到 %s 在 %s，於 %s:%d"
 
-#: tree.cc:9006
+#: tree.cc:9045
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "樹檢查：需要類別 %qs，得到 %qs(%s) 在 %s，於 %s:%d"
 
-#: tree.cc:9055
+#: tree.cc:9094
 #, fuzzy, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "樹檢查：並未預期類別 %qs，有 %qs (%s) 在中 %s，於 %s:%d"
 
-#: tree.cc:9068
+#: tree.cc:9107
 #, fuzzy, gcc-internal-format
 msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
 msgstr "樹檢查：預期的 ompclause %s(_C)，有 %s 在中 %s，於 %s:%d"
 
-#: tree.cc:9130
+#: tree.cc:9169
 #, fuzzy, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "樹檢查：預期的樹該含有 %qs 結構，有 %qs 在中 %s，於 %s:%d"
 
-#: tree.cc:9144
+#: tree.cc:9183
 #, fuzzy, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
 msgstr "樹檢查：存取的 elt %d 的 treevec 與 %d elts 在中 %s(_V)，於 %s:%d"
 
-#: tree.cc:9157
+#: tree.cc:9196
 #, fuzzy, gcc-internal-format
 msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
 msgstr "樹檢查：存取的 elt %d 的 treevec 與 %d elts 在中 %s(_V)，於 %s:%d"
 
-#: tree.cc:9170
+#: tree.cc:9209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "樹檢查：存取的運算元 %d 的 %s 與 %d 運算元在中 %s，於 %s:%d"
 
-#: tree.cc:9183
+#: tree.cc:9222
 #, fuzzy, gcc-internal-format
 msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
 msgstr "樹檢查：存取的運算元 %d 的 ompclause %s 與 %d 運算元在中 %s(_C)，於 %s:%d"
 
-#: tree.cc:12437
+#: tree.cc:12476
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qE 被不宜用：%s"
 
-#: tree.cc:12440
+#: tree.cc:12479
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qE 被不宜用"
 
-#: tree.cc:12463
+#: tree.cc:12502
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE 被不宜用：%s"
 
-#: tree.cc:12466
+#: tree.cc:12505
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE 被不宜用"
 
-#: tree.cc:12472
+#: tree.cc:12511
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "型態被不宜用：%s"
 
-#: tree.cc:12475
+#: tree.cc:12514
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "類型已過時"
 
-#: tree.cc:12517
+#: tree.cc:12556
 #, fuzzy, gcc-internal-format
 msgid "%qD is unavailable: %s"
 msgstr "%qD 並非變數"
 
-#: tree.cc:12519
+#: tree.cc:12558
 #, fuzzy, gcc-internal-format
 msgid "%qD is unavailable"
 msgstr "%qD 並非變數"
 
-#: tree.cc:12540
+#: tree.cc:12579
 #, fuzzy, gcc-internal-format
 msgid "%qE is unavailable: %s"
 msgstr "%qD 並非變數"
 
-#: tree.cc:12542
+#: tree.cc:12581
 #, fuzzy, gcc-internal-format
 msgid "%qE is unavailable"
 msgstr "%qD 並非變數"
 
-#: tree.cc:12547
+#: tree.cc:12586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type is unavailable: %s"
 msgstr "開啟 %s 失敗：%s"
 
-#: tree.cc:12549
+#: tree.cc:12588
 #, fuzzy, gcc-internal-format
 msgid "type is unavailable"
 msgstr "%qD 並非變數"
@@ -34441,264 +34441,264 @@ msgstr "%qD 並非變數"
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.cc:13477
+#: tree.cc:13516
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.cc:13522
+#: tree.cc:13561
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13524
+#: tree.cc:13563
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13526
+#: tree.cc:13565
 #, gcc-internal-format
 msgid "type%'s %<TYPE_SIZE_UNIT%>"
 msgstr ""
 
-#: tree.cc:13551
+#: tree.cc:13590
 #, gcc-internal-format
 msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
 msgstr ""
 
-#: tree.cc:13564
+#: tree.cc:13603
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_VFIELD%>"
 msgstr ""
 
-#: tree.cc:13601
+#: tree.cc:13640
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13603
+#: tree.cc:13642
 #, gcc-internal-format
 msgid "type variant%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13605
+#: tree.cc:13644
 #, gcc-internal-format
 msgid "type%'s %<TYPE_BINFO%>"
 msgstr ""
 
-#: tree.cc:13644
+#: tree.cc:13683
 #, gcc-internal-format
 msgid "type variant has different %<TYPE_FIELDS%>"
 msgstr ""
 
-#: tree.cc:13646
+#: tree.cc:13685
 #, fuzzy, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "%s：時間戳記與圖檔案不匹配\n"
 
-#: tree.cc:13648
+#: tree.cc:13687
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.cc:13665
+#: tree.cc:13704
 #, gcc-internal-format
 msgid "type variant has different %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13667 tree.cc:13678
+#: tree.cc:13706 tree.cc:13717
 #, gcc-internal-format
 msgid "type variant%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13669 tree.cc:13680
+#: tree.cc:13708 tree.cc:13719
 #, gcc-internal-format
 msgid "type%'s %<TREE_TYPE%>"
 msgstr ""
 
-#: tree.cc:13676
+#: tree.cc:13715
 #, fuzzy, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "%qD 不是相容與 %qD"
 
-#: tree.cc:14001
+#: tree.cc:14040
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qT is not a template type"
 msgid "type %s is not an opaque type"
 msgstr "%qT 不是一個範本類型"
 
-#: tree.cc:14007
+#: tree.cc:14046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "type %s is not with opaque mode"
 msgstr "類型 %qT 不是 %qT 的直接基礎類別"
 
-#: tree.cc:14013
+#: tree.cc:14052
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_MODE%>"
 msgstr ""
 
-#: tree.cc:14021
+#: tree.cc:14060
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_SIZE%>"
 msgstr ""
 
-#: tree.cc:14027
+#: tree.cc:14066
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14033
+#: tree.cc:14072
 #, gcc-internal-format
 msgid "type %s differs by %<TYPE_USER_ALIGN%>"
 msgstr ""
 
-#: tree.cc:14063
+#: tree.cc:14102
 #, fuzzy, gcc-internal-format
 msgid "main variant is not defined"
 msgstr "環境變數 %qs 無法定義"
 
-#: tree.cc:14068
+#: tree.cc:14107
 #, gcc-internal-format
 msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14079
+#: tree.cc:14118
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
 msgstr ""
 
-#: tree.cc:14098
+#: tree.cc:14137
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14106
+#: tree.cc:14145
 #, gcc-internal-format
 msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
 msgstr ""
 
-#: tree.cc:14112
+#: tree.cc:14151
 #, gcc-internal-format
 msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
 msgstr ""
 
-#: tree.cc:14128
+#: tree.cc:14167
 #, gcc-internal-format
 msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
 msgstr ""
 
-#: tree.cc:14138
+#: tree.cc:14177
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
 msgstr ""
 
-#: tree.cc:14148
+#: tree.cc:14187
 #, gcc-internal-format
 msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
 msgstr ""
 
-#: tree.cc:14169
+#: tree.cc:14208
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
 msgstr ""
 
-#: tree.cc:14175
+#: tree.cc:14214
 #, gcc-internal-format
 msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
 msgstr ""
 
-#: tree.cc:14186
+#: tree.cc:14225
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14197
+#: tree.cc:14236
 #, gcc-internal-format
 msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
 msgstr ""
 
-#: tree.cc:14215
+#: tree.cc:14254
 #, gcc-internal-format
 msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14222
+#: tree.cc:14261
 #, gcc-internal-format
 msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
 msgstr ""
 
-#: tree.cc:14229
+#: tree.cc:14268
 #, gcc-internal-format
 msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14245
+#: tree.cc:14284
 #, gcc-internal-format
 msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
 msgstr ""
 
-#: tree.cc:14254
+#: tree.cc:14293
 #, gcc-internal-format
 msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
 msgstr ""
 
-#: tree.cc:14262
+#: tree.cc:14301
 #, gcc-internal-format
 msgid "enum value name is not %<IDENTIFIER_NODE%>"
 msgstr ""
 
-#: tree.cc:14272
+#: tree.cc:14311
 #, fuzzy, gcc-internal-format
 msgid "array %<TYPE_DOMAIN%> is not integer type"
 msgstr "大小的陣列 %qE 有 non-integer 型態"
 
-#: tree.cc:14281
+#: tree.cc:14320
 #, fuzzy, gcc-internal-format
 msgid "%<TYPE_FIELDS%> defined in incomplete type"
 msgstr "欄位 %qE 有不完整型態"
 
-#: tree.cc:14303
+#: tree.cc:14342
 #, gcc-internal-format
 msgid "wrong tree in %<TYPE_FIELDS%> list"
 msgstr ""
 
-#: tree.cc:14319
+#: tree.cc:14358
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
 msgstr ""
 
-#: tree.cc:14326
+#: tree.cc:14365
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
 msgstr ""
 
-#: tree.cc:14339
+#: tree.cc:14378
 #, gcc-internal-format
 msgid "wrong %<TYPE_CACHED_VALUES%> entry"
 msgstr ""
 
-#: tree.cc:14352
+#: tree.cc:14391
 #, gcc-internal-format
 msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14358
+#: tree.cc:14397
 #, gcc-internal-format
 msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
 msgstr ""
 
-#: tree.cc:14365
+#: tree.cc:14404
 #, gcc-internal-format
 msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
 msgstr ""
 
-#: tree.cc:14378
+#: tree.cc:14417
 #, gcc-internal-format
 msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
 msgstr ""
 
-#: tree.cc:14388
+#: tree.cc:14427
 #, gcc-internal-format
 msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
 msgstr ""
@@ -34925,7 +34925,7 @@ msgstr "別名定義不支援在中這個組態"
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "可見性屬性在此配置下不受支援；已忽略"
 
-#: varasm.cc:8015
+#: varasm.cc:8017
 #, gcc-internal-format
 msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
 msgstr ""
@@ -35142,7 +35142,7 @@ msgstr "%qE 屬性忽略的因為 %qT 已經定義"
 msgid "%qE attribute ignored because %qD is not a local variable"
 msgstr "%qE 屬性忽略的因為 %qT 已經定義"
 
-#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4170
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE 屬性只能套用到公共物件上"
@@ -35330,7 +35330,7 @@ msgid "ignoring %qE attribute not set on a variable"
 msgstr "%qE 屬性沒有任何效果於單位本地函式"
 
 #: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
-#: config/loongarch/loongarch.cc:7956
+#: config/loongarch/loongarch.cc:7963
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be specified for local variables"
 msgstr "%qE 屬性無法指定的用於區域變數"
@@ -35658,7 +35658,7 @@ msgstr "%qD 不是相容與 %qD"
 msgid "%qE argument is not a function"
 msgstr "cleanup 引數不是一個函式"
 
-#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6411
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
 #, fuzzy, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "不宜用訊息並非字串"
@@ -36181,7 +36181,7 @@ msgstr "ISO C++不允許 %<alignof%> 套用到函數型式"
 msgid "ISO C does not permit %<_Alignof%> applied to a function type"
 msgstr "ISO C 不允許 %<Alignof%(_A)>套用到函數型式"
 
-#: c-family/c-common.cc:3965 cp/typeck.cc:2057
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
 #, gcc-internal-format
 msgid "invalid application of %qs to a void type"
 msgstr "%qs 不能用於 void 類型"
@@ -36313,17 +36313,17 @@ msgstr "只能為類別定義套用 %qE 屬性"
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "預設引數指定的用於 lambda 參數"
 
-#: c-family/c-common.cc:6307 c-family/c-common.cc:7229
-#: c-family/c-common.cc:7276 c-family/c-common.cc:7355
-#: c-family/c-common.cc:7438 c-family/c-common.cc:8081
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
 #: config/aarch64/aarch64-sve-builtins.cc:3026
 #: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "提供給函式 %qE 的引數太少"
 
-#: c-family/c-common.cc:6312 c-family/c-common.cc:7282
-#: c-family/c-common.cc:7464 c-family/c-common.cc:8083
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
 #: config/aarch64/aarch64-sve-builtins.cc:3028
 #: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
 #, gcc-internal-format
@@ -36448,171 +36448,171 @@ msgstr "試圖取位元段結構成員 %qD 的位址"
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "索引 %E 指出偏移大於大小的 %qT"
 
-#: c-family/c-common.cc:7145
+#: c-family/c-common.cc:7150
 #, fuzzy, gcc-internal-format
 msgid "size of array is too large"
 msgstr "大小的陣列太大"
 
-#: c-family/c-common.cc:7259 c-family/c-common.cc:7397
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "引數 %d(屬於 %qE)類型不相容"
 
-#: c-family/c-common.cc:7293
+#: c-family/c-common.cc:7298
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgid "expecting argument of type pointer or of type integer for argument 1"
 msgstr "傳遞參數 %d (屬於 %qE)時將整數賦給指標，未作類型轉換"
 
-#: c-family/c-common.cc:7309
+#: c-family/c-common.cc:7314
 #, fuzzy, gcc-internal-format
 msgid "both arguments must be compatible"
 msgstr "左引數必須是切片"
 
-#: c-family/c-common.cc:7539
+#: c-family/c-common.cc:7544
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "不正確引數數量到函式 %qE"
 
-#: c-family/c-common.cc:7553
+#: c-family/c-common.cc:7558
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "引數 1 的 %qE 必須是 non-void 指標類型"
 
-#: c-family/c-common.cc:7560
+#: c-family/c-common.cc:7565
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a complete type"
 msgstr "引數 1 的 %qE 必須是指標到常數大小型態"
 
-#: c-family/c-common.cc:7569
+#: c-family/c-common.cc:7574
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "引數 1 的 %qE 必須是指標到常數大小型態"
 
-#: c-family/c-common.cc:7580
+#: c-family/c-common.cc:7585
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "引數 1 的 %qE 必須是指標到非零值大小物件"
 
-#: c-family/c-common.cc:7601
+#: c-family/c-common.cc:7606
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "引數 %d 的 %qE 必須是指標類型"
 
-#: c-family/c-common.cc:7609
+#: c-family/c-common.cc:7614
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "引數 1 的 %qE 必須是指標到常數大小型態"
 
-#: c-family/c-common.cc:7615
+#: c-family/c-common.cc:7620
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "引數 %d 的 %qE 必須是指標類型"
 
-#: c-family/c-common.cc:7623
+#: c-family/c-common.cc:7628
 #, fuzzy, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "大小不匹配在中引數 %d 的 %qE"
 
-#: c-family/c-common.cc:7636
+#: c-family/c-common.cc:7641
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<const%> type"
 msgstr "引數 1 的 %qE 必須是指標到常數大小型態"
 
-#: c-family/c-common.cc:7641
+#: c-family/c-common.cc:7646
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE discards %<const%> qualifier"
 msgstr "傳遞引數 %d 的 %qE 捨棄 %qv 限定元從指標目標類型"
 
-#: c-family/c-common.cc:7650
+#: c-family/c-common.cc:7655
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
 msgstr "引數 1 的 %qE 必須是指標到常數大小型態"
 
-#: c-family/c-common.cc:7655
+#: c-family/c-common.cc:7660
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE discards %<volatile%> qualifier"
 msgstr "傳遞引數 %d 的 %qE 捨棄 %qv 限定元從指標目標類型"
 
-#: c-family/c-common.cc:7668
+#: c-family/c-common.cc:7673
 #, fuzzy, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "non-integer 記憶體式樣引數 %d 的 %qE"
 
-#: c-family/c-common.cc:7681
+#: c-family/c-common.cc:7686
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "無效的記憶體式樣引數 %d 的 %qE"
 
-#: c-family/c-common.cc:8315
+#: c-family/c-common.cc:8320
 #, gcc-internal-format
 msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
 msgstr ""
 
-#: c-family/c-common.cc:8969
+#: c-family/c-common.cc:8975
 #, fuzzy, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "索引值是超出約束"
 
-#: c-family/c-common.cc:9011 c-family/c-common.cc:9060
-#: c-family/c-common.cc:9076
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
 #, fuzzy, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "轉換的純量到向量牽連出截斷"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.cc:9164 d/intrinsics.cc:1459
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
 #: rust/backend/rust-tree.cc:3497
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "內建函式 %qD 需一個引數只有"
 
-#: c-family/c-common.cc:9184
+#: c-family/c-common.cc:9194
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "size of array %qE is not a constant expression"
 msgstr "陣列 %qD 的大小不是一個整數常運算式"
 
-#: c-family/c-common.cc:9187
+#: c-family/c-common.cc:9197
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "size of array is not a constant expression"
 msgstr "陣列大小不是一個整數常運算式"
 
-#: c-family/c-common.cc:9191
+#: c-family/c-common.cc:9201
 #, fuzzy, gcc-internal-format
 msgid "size %qE of array %qE is negative"
 msgstr "大小的陣列 %qE 是負"
 
-#: c-family/c-common.cc:9194
+#: c-family/c-common.cc:9204
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size %qE of array is negative"
 msgstr "陣列大小為負數"
 
-#: c-family/c-common.cc:9199
+#: c-family/c-common.cc:9209
 #, gcc-internal-format
 msgid "size %qE of array %qE exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9202
+#: c-family/c-common.cc:9212
 #, gcc-internal-format
 msgid "size %qE of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9207
+#: c-family/c-common.cc:9217
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE exceeds maximum object size %qE"
 msgstr "大小的陣列 %qE 是負"
 
-#: c-family/c-common.cc:9210
+#: c-family/c-common.cc:9220
 #, gcc-internal-format
 msgid "size of array exceeds maximum object size %qE"
 msgstr ""
 
-#: c-family/c-common.cc:9281
+#: c-family/c-common.cc:9291
 #, gcc-internal-format
 msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -37265,7 +37265,7 @@ msgstr "整數常數太大用於 %<unsigned long%> 型態"
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
 msgstr "整數常數太大用於 %<unsigned long%> 型態"
 
-#: c-family/c-lex.cc:1045 c/c-decl.cc:12698
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
 #, fuzzy, gcc-internal-format
 msgid "%<_BitInt(%d)%> is not supported on this target"
 msgstr "%<__int128%>未被支援用於這個目標"
@@ -37345,7 +37345,7 @@ msgstr "不受支援的 non-standard 串接的字串實字"
 msgid "traditional C rejects string constant concatenation"
 msgstr "傳統 C 不接受字串常數粘貼"
 
-#: c-family/c-omp.cc:131 cp/pt.cc:19155
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
 #, gcc-internal-format
 msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
 msgstr ""
@@ -37400,7 +37400,7 @@ msgstr ""
 msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
 msgstr ""
 
-#: c-family/c-omp.cc:969 cp/semantics.cc:10925
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
 #, fuzzy, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "無效的型態用於迭代變數 %qE"
@@ -37415,17 +37415,17 @@ msgstr "無效的型態用於迭代變數 %qE"
 msgid "%qE is not initialized"
 msgstr "%qE 未被初始化的"
 
-#: c-family/c-omp.cc:1011 cp/semantics.cc:10817
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "缺少控制述詞"
 
-#: c-family/c-omp.cc:1117 cp/semantics.cc:10413
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "無效的控制述詞"
 
-#: c-family/c-omp.cc:1124 cp/semantics.cc:10823
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "缺少遞增運算式"
@@ -37435,7 +37435,7 @@ msgstr "缺少遞增運算式"
 msgid "increment is not constant 1 or -1 for %<!=%> condition"
 msgstr ""
 
-#: c-family/c-omp.cc:1255 cp/semantics.cc:10530
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "無效的遞增運算式"
@@ -37523,7 +37523,7 @@ msgstr ""
 msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
 msgstr ""
 
-#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9517
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
 #, gcc-internal-format
 msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
 msgstr ""
@@ -37534,7 +37534,7 @@ msgstr ""
 msgid "%qD is not a function argument"
 msgstr "%qD 不是一個函式範本"
 
-#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8256
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
@@ -38155,7 +38155,7 @@ msgid "wrong type argument to %s"
 msgstr "錯誤的型態引數到 %s"
 
 #: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
-#: cp/constexpr.cc:7370 m2/gm2-gcc/m2expr.cc:964
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
 #: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
 #, gcc-internal-format
 msgid "overflow in constant expression"
@@ -39101,35 +39101,35 @@ msgstr "比較介於 %qT 和 %qT"
 
 #: c-family/c-warn.cc:3832
 #, gcc-internal-format
-msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3836
+#: c-family/c-warn.cc:3839
 #, gcc-internal-format
-msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
 msgstr ""
 
-#: c-family/c-warn.cc:3896
+#: c-family/c-warn.cc:3901
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
 msgstr ""
 
-#: c-family/c-warn.cc:3906
+#: c-family/c-warn.cc:3911
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3913
+#: c-family/c-warn.cc:3918
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
 msgstr ""
 
-#: c-family/c-warn.cc:3924
+#: c-family/c-warn.cc:3929
 #, gcc-internal-format
 msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
 msgstr ""
 
-#: c-family/c-warn.cc:3941
+#: c-family/c-warn.cc:3946
 #, gcc-internal-format
 msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
 msgstr ""
@@ -39353,118 +39353,118 @@ msgstr "-mregparm=%d 不在 0 和 %d 之間"
 msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:765
+#: common/config/riscv/riscv-common.cc:674
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:774
+#: common/config/riscv/riscv-common.cc:683
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:782
+#: common/config/riscv/riscv-common.cc:691
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:790
+#: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:798
+#: common/config/riscv/riscv-common.cc:707
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1045
+#: common/config/riscv/riscv-common.cc:955
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: expect number after %<%dp%>"
 msgstr "%<-mips3d%> 需求 %<-mpaired-single%>"
 
-#: common/config/riscv/riscv-common.cc:1051
+#: common/config/riscv/riscv-common.cc:961
 #, gcc-internal-format
 msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1109
+#: common/config/riscv/riscv-common.cc:1019
 #, gcc-internal-format
 msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1133
+#: common/config/riscv/riscv-common.cc:1043
 #, gcc-internal-format
 msgid "%<-march=%s%>: rv%de is not a valid base ISA"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1145
+#: common/config/riscv/riscv-common.cc:1055
 #, gcc-internal-format
 msgid "version of %<g%> will be omitted, please specify version for individual extension"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1164
+#: common/config/riscv/riscv-common.cc:1074
 #, gcc-internal-format
 msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1187
+#: common/config/riscv/riscv-common.cc:1097
 #, gcc-internal-format
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1318
+#: common/config/riscv/riscv-common.cc:1228
 #, gcc-internal-format
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1323
+#: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
 msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1329
+#: common/config/riscv/riscv-common.cc:1239
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: h extension requires i extension"
 msgstr "不使用 SPE ABI 延伸"
 
-#: common/config/riscv/riscv-common.cc:1334
+#: common/config/riscv/riscv-common.cc:1244
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
 msgstr "-mcpu=%s 衝突與 -march=%s"
 
-#: common/config/riscv/riscv-common.cc:1336
+#: common/config/riscv/riscv-common.cc:1246
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
 msgstr "-mcpu=%s 衝突與 -march=%s"
 
-#: common/config/riscv/riscv-common.cc:1345
+#: common/config/riscv/riscv-common.cc:1255
 #, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
 msgstr ""
 
-#: common/config/riscv/riscv-common.cc:1442
+#: common/config/riscv/riscv-common.cc:1352
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: name of %s must be more than 1 letter"
 msgstr "%<-march=%s%>不是相容與已選 ABI"
 
-#: common/config/riscv/riscv-common.cc:1454
+#: common/config/riscv/riscv-common.cc:1364
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr "%<-march=%s%>不是相容與已選 ABI"
 
-#: common/config/riscv/riscv-common.cc:1516
+#: common/config/riscv/riscv-common.cc:1426
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%>: i, e or g must be the first extension"
 msgstr "%<-march=%s%>不是相容與已選 ABI"
 
-#: common/config/riscv/riscv-common.cc:1871
+#: common/config/riscv/riscv-common.cc:1759
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qE is unknown"
 msgid "%<-mcpu=%s%>: unknown CPU"
 msgstr "%qE 的類型不明"
 
-#: common/config/riscv/riscv-common.cc:1950
+#: common/config/riscv/riscv-common.cc:1838
 #, gcc-internal-format
 msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
 msgstr ""
@@ -39874,12 +39874,12 @@ msgstr "預期 %qT 但是引數是的型態 %qT"
 msgid "expected 64-bit address but argument 2 is %d-bit"
 msgstr "預期 %qT 但是引數是的型態 %qT"
 
-#: config/aarch64/aarch64-c.cc:341
+#: config/aarch64/aarch64-c.cc:347
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC aarch64%> requires a string parameter"
 msgstr "%<# pragma GCC optimize%>並非字串或數字"
 
-#: config/aarch64/aarch64-c.cc:357
+#: config/aarch64/aarch64-c.cc:363
 #, fuzzy, gcc-internal-format
 msgid "unknown %<#pragma GCC aarch64%> option %qs"
 msgstr "不明 # pragma GCC 輔助處理器 %E"
@@ -40490,7 +40490,7 @@ msgstr ""
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
-#: config/arm/arm.cc:7372 config/arm/arm.cc:29487
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 9.1"
 msgstr ""
@@ -40569,12 +40569,12 @@ msgid "unknown tuning option (%s)"
 msgstr "不明 spec 函式 %qs"
 
 #: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
-#: config/riscv/riscv.cc:9411
+#: config/riscv/riscv.cc:9369
 #, gcc-internal-format
 msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9420
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
 #, gcc-internal-format
 msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
 msgstr ""
@@ -40586,7 +40586,7 @@ msgid "specify a system register with a small string length"
 msgstr "指定指派暫存器的順序"
 
 #: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
-#: config/riscv/riscv.cc:9449 config/rs6000/rs6000.cc:4497
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs 無效用於 %qs"
@@ -40768,9 +40768,9 @@ msgstr ""
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "屬性 (目標 (「%s」)) 為未知"
 
-#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33744
-#: config/riscv/riscv-target-attr.cc:325 config/rs6000/rs6000.cc:24684
-#: config/s390/s390.cc:16421
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "屬性 %qE 引數不是字串"
@@ -40822,18 +40822,18 @@ msgid "virtual function multiversioning not supported"
 msgstr "不支援堆疊限制運算式"
 
 #: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
-#: config/rs6000/rs6000.cc:25374
+#: config/rs6000/rs6000.cc:25389
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs %<ifunc%> which is not supported on this target"
 msgstr "ifunc 未被支援在中這個組態"
 
 #: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
-#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12778
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
 msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
 msgstr ""
 
 #: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
-#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12773
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
 msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
 msgstr ""
 
@@ -40846,8 +40846,8 @@ msgstr ""
 msgid "lane %wd out of range %wd - %wd"
 msgstr "運算元號超出範圍"
 
-#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25115
-#: config/i386/i386.cc:25246
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %wd"
@@ -40858,7 +40858,7 @@ msgstr "不支援的組合：%s"
 msgid "GCC does not currently support return type %qT for simd"
 msgstr "不受支援的引數類型到內建函式"
 
-#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25137
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
@@ -40868,7 +40868,7 @@ msgstr ""
 msgid "GCC does not currently support argument type %qT for simd"
 msgstr "不受支援的引數類型到內建函式"
 
-#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25168
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "不受支援的引數類型到內建函式"
@@ -40966,8 +40966,8 @@ msgstr "L%d 快取延遲不明，對 %s 來說"
 msgid "bad value %qs for %<-mmemory-latency%>"
 msgstr "-mmemory-latency 開關的值 %qs 錯誤"
 
-#: config/alpha/alpha.cc:6659 config/alpha/alpha.cc:6662 config/arc/arc.cc:6981
-#: config/arc/arc.cc:7255 config/s390/s390.cc:959
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
 #, gcc-internal-format
 msgid "bad builtin fcode"
 msgstr "錯誤的內建 fcode"
@@ -41092,18 +41092,18 @@ msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
 msgstr "%qs 屬性的引數不是「ilink1」或「ilink2」"
 
 #: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
-#: config/arm/arm.cc:7680 config/avr/avr.cc:11244 config/avr/avr.cc:11258
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
 #: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
 #: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
 #: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
-#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3711
-#: config/i386/i386-options.cc:3888 config/i386/i386-options.cc:3944
-#: config/i386/i386-options.cc:3995 config/i386/i386-options.cc:4032
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
 #: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
-#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5772
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
 #: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
-#: config/rs6000/rs6000.cc:20635 config/rx/rx.cc:2728 config/rx/rx.cc:2754
-#: config/s390/s390.cc:1174 config/s390/s390.cc:1261 config/sh/sh.cc:8429
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
 #: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
 #: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
 #: config/v850/v850.cc:2010 config/visium/visium.cc:724
@@ -41222,7 +41222,7 @@ msgid "argument of %qE attribute is missing"
 msgstr "引數的 %qE 屬性並非字串常數"
 
 #: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
-#: config/avr/avr.cc:11318
+#: config/avr/avr.cc:11347
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qE 屬性允許只有整數常數引數"
@@ -41243,23 +41243,23 @@ msgstr "%qE 屬性只有套用到函數型式"
 msgid "argument of %qE attribute ignored"
 msgstr "%qE 屬性被忽略"
 
-#: config/arc/arc.cc:11012 config/avr/avr.cc:11305 config/bfin/bfin.cc:4818
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
 #: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "%qE 屬性只有套用到變數"
 
-#: config/arm/aarch-common.cc:553 config/i386/i386.cc:23866
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
 #, fuzzy, gcc-internal-format
 msgid "alternatives not allowed in %<asm%> flag output"
 msgstr "By-value 引數於 %L 未被允許在中這個語境"
 
-#: config/arm/aarch-common.cc:614 config/i386/i386.cc:23930
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
 #, fuzzy, gcc-internal-format
 msgid "unknown %<asm%> flag output %qs"
 msgstr "不明 IRA 演算法 %qs"
 
-#: config/arm/aarch-common.cc:624 config/i386/i386.cc:23959
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
 #, fuzzy, gcc-internal-format
 msgid "invalid type for %<asm%> flag output"
 msgstr "無效的型態用於製作函式"
@@ -41510,7 +41510,7 @@ msgstr "目的 CPU 不支援 THUMB 指令"
 msgid "target CPU does not support unaligned accesses"
 msgstr "目標 CPU 不支援 unaligned 存取"
 
-#: config/arm/arm.cc:3247 config/arm/arm.cc:33417
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
 #, fuzzy, gcc-internal-format
 msgid "This architecture does not support branch protection instructions"
 msgstr "%qs 架構不支援 branch-likely 指令"
@@ -41563,7 +41563,7 @@ msgstr "結構大小邊界只能是設定為 8 或 32"
 msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
 msgstr "RTP PIC 是不相容的與 -msingle-pic-base"
 
-#: config/arm/arm.cc:3725 config/arm/arm.cc:33758
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
 #, fuzzy, gcc-internal-format
 msgid "FDPIC mode is not supported in Thumb-1 mode"
 msgstr "編碼式樣 %qs 不支援在中 x32 模式"
@@ -41675,7 +41675,7 @@ msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
 msgstr ""
 
 #: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
-#: config/arm/arm.cc:29480
+#: config/arm/arm.cc:29541
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
@@ -41716,43 +41716,43 @@ msgstr "%qE 屬性沒有任何效果於單位本地函式"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qE 屬性只有套用到函數型式"
 
-#: config/arm/arm.cc:9737
+#: config/arm/arm.cc:9739
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
 msgstr ""
 
-#: config/arm/arm.cc:13588 config/arm/arm.cc:13590
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.cc:26067
+#: config/arm/arm.cc:26076
 #, fuzzy, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "無法計算真實位置的重疊參數"
 
-#: config/arm/arm.cc:26730
+#: config/arm/arm.cc:26739
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "非預期的模組結束"
 
-#: config/arm/arm.cc:26989
+#: config/arm/arm.cc:26998
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "高暫存器彈堆疊時沒有可用的低暫存器"
 
-#: config/arm/arm.cc:27242
+#: config/arm/arm.cc:27251
 #, fuzzy, gcc-internal-format
 msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
 msgstr "插斷服務常式無法編碼的在中姆指模式"
 
-#: config/arm/arm.cc:27488
+#: config/arm/arm.cc:27549
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.cc:33773
+#: config/arm/arm.cc:33834
 #, fuzzy, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
 msgstr "無效的向量型態用於屬性 %qs"
@@ -41760,22 +41760,22 @@ msgstr "無效的向量型態用於屬性 %qs"
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.cc:33781
+#: config/arm/arm.cc:33842
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.cc:33794
+#: config/arm/arm.cc:33855
 #, fuzzy, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
 msgstr "無效的向量型態用於屬性 %qs"
 
-#: config/arm/arm.cc:33808
+#: config/arm/arm.cc:33869
 #, fuzzy, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
 msgstr "目標屬性或 pragma 變更 SPE ABI"
 
-#: config/arm/arm.cc:34771
+#: config/arm/arm.cc:34832
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> flags not supported in thumb1 mode"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
@@ -41830,161 +41830,161 @@ msgstr ""
 msgid "unknown core architecture %qs specified with %qs"
 msgstr "%qs 沒有指定類別名"
 
-#: config/avr/avr.cc:1144 config/pru/pru.cc:601 config/visium/visium.cc:422
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
 #, fuzzy, gcc-internal-format
 msgid "%<-fpic%> is not supported"
 msgstr "-fpic 未被支援"
 
-#: config/avr/avr.cc:1146 config/pru/pru.cc:603 config/visium/visium.cc:424
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
 #, fuzzy, gcc-internal-format
 msgid "%<-fPIC%> is not supported"
 msgstr "-fPIC 未被支援"
 
-#: config/avr/avr.cc:1148 config/pru/pru.cc:605
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
 #, fuzzy, gcc-internal-format
 msgid "%<-fpie%> is not supported"
 msgstr "-fpic 未被支援"
 
-#: config/avr/avr.cc:1150 config/pru/pru.cc:607
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
 #, fuzzy, gcc-internal-format
 msgid "%<-fPIE%> is not supported"
 msgstr "-fPIC 未被支援"
 
-#: config/avr/avr.cc:1446 config/avr/avr.cc:1451 config/riscv/riscv.cc:9772
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
 #, fuzzy, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
 msgstr "函式屬性 %qs，%qs 和 %qs 彼此互斥"
 
-#: config/avr/avr.cc:1472 config/riscv/riscv.cc:9784
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs 函式無法有引數"
 
-#: config/avr/avr.cc:1475 config/riscv/riscv.cc:9781
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "%qs 函式無法回傳值"
 
-#: config/avr/avr.cc:1489
+#: config/avr/avr.cc:1495
 #, fuzzy, gcc-internal-format
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs 似乎是 misspelled %s 處理常式"
 
-#: config/avr/avr.cc:1500
+#: config/avr/avr.cc:1506
 #, gcc-internal-format
 msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1507
+#: config/avr/avr.cc:1513
 #, gcc-internal-format
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
 msgstr ""
 
-#: config/avr/avr.cc:1728
+#: config/avr/avr.cc:1734
 #, fuzzy, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr "『builtin_return_address』含有只有 2 位元組的位址"
 
-#: config/avr/avr.cc:3716
+#: config/avr/avr.cc:3722
 #, fuzzy, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr "指標偏移從符號也許不正確"
 
-#: config/avr/avr.cc:3855
+#: config/avr/avr.cc:3861
 #, fuzzy, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr "存取資料記憶體與程式記憶體位址"
 
-#: config/avr/avr.cc:3916
+#: config/avr/avr.cc:3922
 #, fuzzy, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr "存取程式記憶體與資料記憶體位址"
 
-#: config/avr/avr.cc:4258
+#: config/avr/avr.cc:4264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr "固定的暫存器 %s 用來回合參數到函式"
 
-#: config/avr/avr.cc:4518
+#: config/avr/avr.cc:4524
 #, fuzzy, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "寫入位址空間 %qs 不支援"
 
-#: config/avr/avr.cc:11277
+#: config/avr/avr.cc:11306
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "%qE 屬性只有套用到變數和函式"
 
-#: config/avr/avr.cc:11284
+#: config/avr/avr.cc:11313
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "%qE 屬性未被支援用於 R8C 目標"
 
-#: config/avr/avr.cc:11326
+#: config/avr/avr.cc:11355
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute address out of range 0x%x%s0x%x"
 msgstr "%qE 屬性沒有任何效果"
 
-#: config/avr/avr.cc:11340
+#: config/avr/avr.cc:11369
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.cc:11350
+#: config/avr/avr.cc:11379
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "%qE 屬性只有套用到變數"
 
-#: config/avr/avr.cc:11426
+#: config/avr/avr.cc:11455
 #, fuzzy, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
 
-#: config/avr/avr.cc:11433
+#: config/avr/avr.cc:11462
 #, fuzzy, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
 
-#: config/avr/avr.cc:11613
+#: config/avr/avr.cc:11642
 #, fuzzy, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr "指標目標位址空間 %qs 必須是常數在中 %qT"
 
-#: config/avr/avr.cc:11616
+#: config/avr/avr.cc:11645
 #, fuzzy, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr "指標目標位址空間 %qs 必須是常數在中 %s %q+D"
 
-#: config/avr/avr.cc:11637
+#: config/avr/avr.cc:11666
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object %qD may not be initialized"
 msgid "variable %q+D with attribute %qs must be located in static storage"
 msgstr "可變大小的物件 %qD 不能被初始化"
 
-#: config/avr/avr.cc:11688
+#: config/avr/avr.cc:11717
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr "變數 %q+D 必須是常數以便是置放進入唯讀區段依靠 %qs"
 
-#: config/avr/avr.cc:11849
+#: config/avr/avr.cc:11878
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "static attribute %qs declaration for %q+D needs an address"
 msgstr "%q+D 的宣告隱藏了一個參數"
 
-#: config/avr/avr.cc:11938
+#: config/avr/avr.cc:11967
 #, fuzzy, gcc-internal-format
 #| msgid "only uninitialized variables can be placed in the .noinit section"
 msgid "only uninitialized variables can be placed in the %<.noinit%> section"
 msgstr "只有未初始化的變數才能放在 .noinit 區段中"
 
 #. This might happen with C++ if stuff needs constructing.
-#: config/avr/avr.cc:12015
+#: config/avr/avr.cc:12044
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D with dynamic initialization put into program memory area"
 msgstr "uninitialized 變數 %q+D 置放進入程式記憶儲存區"
 
-#: config/avr/avr.cc:12026
+#: config/avr/avr.cc:12055
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "uninitialized 變數 %q+D 置放進入程式記憶儲存區"
@@ -41993,44 +41993,44 @@ msgstr "uninitialized 變數 %q+D 置放進入程式記憶儲存區"
 #. hence deny initializers now.  The values of symbols with an
 #. address attribute are determined by the attribute, not by
 #. some initializer.
-#: config/avr/avr.cc:12091
+#: config/avr/avr.cc:12120
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object %qD may not be initialized"
 msgid "variable %q+D with attribute %qs must not have an initializer"
 msgstr "可變大小的物件 %qD 不能被初始化"
 
-#: config/avr/avr.cc:12144
+#: config/avr/avr.cc:12173
 #, fuzzy, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%qE 不相容的屬性忽略"
 
-#: config/avr/avr.cc:12207
+#: config/avr/avr.cc:12236
 #, fuzzy, gcc-internal-format
 #| msgid "MCU %qs supported for assembler only"
 msgid "architecture %qs supported for assembler only"
 msgstr "MCU %qs 只支援組譯器"
 
-#: config/avr/avr.cc:14767
+#: config/avr/avr.cc:14796
 #, fuzzy, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "從 %s 轉換到 %s，位於 %L"
 
-#: config/avr/avr.cc:15848 config/avr/avr.cc:15861
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "%s 預期編譯時期整數常數"
 
-#: config/avr/avr.cc:15875
+#: config/avr/avr.cc:15904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%s 預期編譯時期長整數常數做為先引數"
 
-#: config/avr/avr.cc:15903
+#: config/avr/avr.cc:15932
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.cc:15912
+#: config/avr/avr.cc:15941
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -42172,7 +42172,7 @@ msgid "indirect call in function, which are not supported by eBPF"
 msgstr "%<__int128%>未被支援由這個目標"
 
 #: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
-#: config/mips/mips.cc:17394 config/nios2/nios2.cc:3602
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
 #: config/riscv/riscv-builtins.cc:344
 #: config/riscv/riscv-vector-builtins.cc:4226
 #, fuzzy, gcc-internal-format
@@ -42817,8 +42817,8 @@ msgstr "下一個到最後一筆引數必須是 8-bit 即時"
 msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2251
-#: config/i386/i386-options.cc:2260
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "編碼式樣 %s 不支援 PIC 模式"
@@ -42886,261 +42886,261 @@ msgstr "%qs 沒有指定類別名"
 msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
 msgstr ""
 
-#: config/i386/i386-options.cc:2047
+#: config/i386/i386-options.cc:2069
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支援"
 
-#: config/i386/i386-options.cc:2101
+#: config/i386/i386-options.cc:2123
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%stune =x86-64%s 被不宜用；使用 %stune=k8%s 或 %stune=generic%s 做為替代做為適當"
 
-#: config/i386/i386-options.cc:2103
+#: config/i386/i386-options.cc:2125
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%stune =x86-64%s 被不宜用；使用 %stune=k8%s 或 %stune=generic%s 做為替代做為適當"
 
-#: config/i386/i386-options.cc:2109
+#: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2110
+#: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2115
+#: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2116
+#: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386-options.cc:2143
+#: config/i386/i386-options.cc:2165
 #, fuzzy, gcc-internal-format
 msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8 位元組不支援用於 32-bit 編碼"
 
-#: config/i386/i386-options.cc:2148
+#: config/i386/i386-options.cc:2170
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "%<-mapxf%> is not supported for 32-bit code"
 msgstr "32 位元系統不支援 -mcmodel="
 
-#: config/i386/i386-options.cc:2150
+#: config/i386/i386-options.cc:2172
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
 msgstr "32 位元系統不支援 -mcmodel="
 
-#: config/i386/i386-options.cc:2153
+#: config/i386/i386-options.cc:2175
 #, fuzzy, gcc-internal-format
 msgid "%<-muintr%> not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8 位元組不支援用於 32-bit 編碼"
 
-#: config/i386/i386-options.cc:2156
+#: config/i386/i386-options.cc:2178
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
 msgstr "32 位元系統不支援 -mcmodel="
 
-#: config/i386/i386-options.cc:2171
+#: config/i386/i386-options.cc:2193
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
 
-#: config/i386/i386-options.cc:2182
+#: config/i386/i386-options.cc:2204
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=ms%> not supported with X32 ABI"
 msgstr "-f%s 不受支援：已忽略"
 
-#: config/i386/i386-options.cc:2188
+#: config/i386/i386-options.cc:2210
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
 msgstr "transactional 記憶體未被支援與 non-call 異常"
 
-#: config/i386/i386-options.cc:2191
+#: config/i386/i386-options.cc:2213
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
 msgstr "transactional 記憶體未被支援與 non-call 異常"
 
-#: config/i386/i386-options.cc:2195
+#: config/i386/i386-options.cc:2217
 #, fuzzy, gcc-internal-format
 msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
 msgstr "-fdirectives-only 是不相容的與 -traditional"
 
-#: config/i386/i386-options.cc:2201
+#: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2221 config/i386/i386-options.cc:2230
-#: config/i386/i386-options.cc:2242 config/i386/i386-options.cc:2253
-#: config/i386/i386-options.cc:2264
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
 
-#: config/i386/i386-options.cc:2233 config/i386/i386-options.cc:2245
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "編碼式樣 %qs 不支援在中 x32 模式"
 
-#: config/i386/i386-options.cc:2288
+#: config/i386/i386-options.cc:2310
 #, fuzzy, gcc-internal-format
 msgid "%<-masm=intel%> not supported in this configuration"
 msgstr "-masm=intel 不支援在中這個組態"
 
-#: config/i386/i386-options.cc:2293
+#: config/i386/i386-options.cc:2315
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "未編譯入對 %i 位模式的支援"
 
-#: config/i386/i386-options.cc:2305
+#: config/i386/i386-options.cc:2327
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386-options.cc:2307
+#: config/i386/i386-options.cc:2329
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386-options.cc:2314
+#: config/i386/i386-options.cc:2336
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386-options.cc:2316
+#: config/i386/i386-options.cc:2338
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386-options.cc:2324 config/i386/i386-options.cc:2477
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "您選擇的 CPU 不支援 x86-64 指令集"
 
-#: config/i386/i386-options.cc:2332
+#: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2333
+#: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2338
+#: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2339
+#: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
 msgstr ""
 
-#: config/i386/i386-options.cc:2416
+#: config/i386/i386-options.cc:2438
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value %qs for %<-march=%> switch"
 msgstr "-march= 所帶參數(%s)不正確"
 
-#: config/i386/i386-options.cc:2417
+#: config/i386/i386-options.cc:2439
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"arch=\")%> attribute"
 msgstr "不當的值 (%s) 用於 %sarch=%s %s"
 
-#: config/i386/i386-options.cc:2439
+#: config/i386/i386-options.cc:2461
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386-options.cc:2441
+#: config/i386/i386-options.cc:2463
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2446
+#: config/i386/i386-options.cc:2468
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386-options.cc:2447
+#: config/i386/i386-options.cc:2469
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386-options.cc:2496
+#: config/i386/i386-options.cc:2518
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<-mtune=%> switch"
 msgstr "不當的值 %qs 用於 -mtune 切換"
 
-#: config/i386/i386-options.cc:2497
+#: config/i386/i386-options.cc:2519
 #, fuzzy, gcc-internal-format
 msgid "bad value %qs for %<target(\"tune=\")%> attribute"
 msgstr "不當的值 (%s) 用於 %stune=%s %s"
 
-#: config/i386/i386-options.cc:2518
+#: config/i386/i386-options.cc:2540
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386-options.cc:2520
+#: config/i386/i386-options.cc:2542
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386-options.cc:2525
+#: config/i386/i386-options.cc:2547
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386-options.cc:2526
+#: config/i386/i386-options.cc:2548
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386-options.cc:2554
+#: config/i386/i386-options.cc:2578
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored in 64-bit mode"
 msgstr "-mregparm 被忽略在中 64-bit 模式"
 
-#: config/i386/i386-options.cc:2556
+#: config/i386/i386-options.cc:2580
 #, fuzzy, gcc-internal-format
 msgid "%<-mregparm%> is ignored for Intel MCU psABI"
 msgstr "-mregparm 被忽略在中 64-bit 模式"
 
-#: config/i386/i386-options.cc:2559
+#: config/i386/i386-options.cc:2583
 #, fuzzy, gcc-internal-format
 #| msgid "-mregparm=%d is not between 0 and %d"
 msgid "%<-mregparm=%d%> is not between 0 and %d"
 msgstr "-mregparm=%d 不在 0 和 %d 之間"
 
-#: config/i386/i386-options.cc:2582
+#: config/i386/i386-options.cc:2609
 #, fuzzy, gcc-internal-format
 msgid "%<-m96bit-long-double%> is not compatible with this target"
 msgstr "%<-march=%s%>不是相容與已選 ABI"
 
-#: config/i386/i386-options.cc:2587
+#: config/i386/i386-options.cc:2614
 #, fuzzy, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s 被忽略在中 64 位元模式"
 
-#: config/i386/i386-options.cc:2588
+#: config/i386/i386-options.cc:2615
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s 被忽略在中 64 位元模式"
 
-#: config/i386/i386-options.cc:2681
+#: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
 msgstr ""
@@ -43148,295 +43148,295 @@ msgstr ""
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
 #. Disable EVEX512 bit for this.
-#: config/i386/i386-options.cc:2695
+#: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2702 config/i386/i386-options.cc:2708
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
 msgstr ""
 
-#: config/i386/i386-options.cc:2716
+#: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
 msgstr ""
 
-#: config/i386/i386-options.cc:2726
+#: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:2781
+#: config/i386/i386-options.cc:2802
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
 msgstr "-mpreferred-stack-boundary 未被支援用於這個目標"
 
-#: config/i386/i386-options.cc:2784
+#: config/i386/i386-options.cc:2805
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 未被介於 %d 和 %d"
 
-#: config/i386/i386-options.cc:2807
+#: config/i386/i386-options.cc:2828
 #, fuzzy, gcc-internal-format
 msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d 未被介於 %d 和 12"
 
-#: config/i386/i386-options.cc:2820
+#: config/i386/i386-options.cc:2841
 #, fuzzy, gcc-internal-format
 msgid "%<-mnop-mcount%> is not compatible with this target"
 msgstr "%<-march=%s%>不是相容與已選 ABI"
 
-#: config/i386/i386-options.cc:2823
+#: config/i386/i386-options.cc:2844
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
 msgstr "模組間最佳化淍未為 C++ 實作"
 
-#: config/i386/i386-options.cc:2829
+#: config/i386/i386-options.cc:2850
 #, fuzzy, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparm%s 使用的而無需 SSE 已啟用"
 
-#: config/i386/i386-options.cc:2830
+#: config/i386/i386-options.cc:2851
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparm%s 使用的而無需 SSE 已啟用"
 
-#: config/i386/i386-options.cc:2840
+#: config/i386/i386-options.cc:2861
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 指令集已停用，使用 387 指令"
 
-#: config/i386/i386-options.cc:2847
+#: config/i386/i386-options.cc:2868
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 指令集已停用，使用 SSE 指令"
 
-#: config/i386/i386-options.cc:2897
+#: config/i386/i386-options.cc:2918
 #, fuzzy, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386-options.cc:2899
+#: config/i386/i386-options.cc:2920
 #, fuzzy, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386-options.cc:2913
+#: config/i386/i386-options.cc:2934
 #, fuzzy, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386-options.cc:2915
+#: config/i386/i386-options.cc:2936
 #, fuzzy, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386-options.cc:2975
+#: config/i386/i386-options.cc:2996
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
 msgstr "-mfentry isn%'t 支援的用於 32-bit 在中組合與 -fpic"
 
-#: config/i386/i386-options.cc:2978
+#: config/i386/i386-options.cc:2999
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-fentry%> isn%'t compatible with SEH"
 msgstr "-mno-fentry isn%'t 相容與 SEH"
 
-#: config/i386/i386-options.cc:2982
+#: config/i386/i386-options.cc:3003
 #, gcc-internal-format
 msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386-options.cc:3104 config/loongarch/loongarch-opts.cc:898
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<-mrecip=%s%>"
 msgstr "不明選項用於 -mrecip=%s"
 
-#: config/i386/i386-options.cc:3163
+#: config/i386/i386-options.cc:3184
 #, gcc-internal-format
 msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3168
+#: config/i386/i386-options.cc:3189
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3196
+#: config/i386/i386-options.cc:3217
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
 msgstr ""
 
-#: config/i386/i386-options.cc:3250
+#: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
 msgstr ""
 
-#: config/i386/i386-options.cc:3259
+#: config/i386/i386-options.cc:3280
 #, fuzzy, gcc-internal-format
 msgid "%<-fcf-protection%> is not compatible with this target"
 msgstr "%<-march=%s%>不是相容與已選 ABI"
 
-#: config/i386/i386-options.cc:3426
+#: config/i386/i386-options.cc:3447
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386-options.cc:3430 config/i386/i386-options.cc:3462
-#: config/i386/i386-options.cc:4006 config/i386/i386-options.cc:4016
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs attributes are not compatible"
 msgstr "ms_abi 和 sysv_abi 屬性不是相容"
 
-#: config/i386/i386-options.cc:3447
+#: config/i386/i386-options.cc:3468
 #, gcc-internal-format
 msgid "only DWARF debug format is supported for interrupt service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3508
+#: config/i386/i386-options.cc:3529
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 與 -mcall-%s 互不相容"
 
-#: config/i386/i386-options.cc:3518
+#: config/i386/i386-options.cc:3539
 #, gcc-internal-format
 msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3553
+#: config/i386/i386-options.cc:3574
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 與 -mcall-%s 互不相容"
 
-#: config/i386/i386-options.cc:3563
+#: config/i386/i386-options.cc:3584
 #, gcc-internal-format
 msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
 msgstr ""
 
-#: config/i386/i386-options.cc:3671
+#: config/i386/i386-options.cc:3692
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an exception service routine"
 msgstr ""
 
-#: config/i386/i386-options.cc:3673
+#: config/i386/i386-options.cc:3694
 #, fuzzy, gcc-internal-format
 msgid "%s instructions aren%'t allowed in an interrupt service routine"
 msgstr "2 位元組 cop 指令未被允許在中 64-bit VLIW 模式"
 
-#: config/i386/i386-options.cc:3677
+#: config/i386/i386-options.cc:3698
 #, gcc-internal-format
 msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
 msgstr ""
 
-#: config/i386/i386-options.cc:3724 config/i386/i386-options.cc:3775
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall 和 regparm 屬性互不相容"
 
-#: config/i386/i386-options.cc:3729
+#: config/i386/i386-options.cc:3750
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam 和 thiscall 屬性不是相容"
 
-#: config/i386/i386-options.cc:3736 config/i386/i386-options.cc:3964
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE 屬性需求整數常數引數"
 
-#: config/i386/i386-options.cc:3742
+#: config/i386/i386-options.cc:3763
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "引數到 %qE 屬性大於 %d"
 
-#: config/i386/i386-options.cc:3767 config/i386/i386-options.cc:3810
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386-options.cc:3771
+#: config/i386/i386-options.cc:3792
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall 和 stdcall 屬性互不相容"
 
-#: config/i386/i386-options.cc:3779 config/i386/i386-options.cc:3828
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 屬性不是相容"
 
-#: config/i386/i386-options.cc:3789 config/i386/i386-options.cc:3806
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386-options.cc:3793
+#: config/i386/i386-options.cc:3814
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall 和 fastcall 屬性互不相容"
 
-#: config/i386/i386-options.cc:3797 config/i386/i386-options.cc:3824
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall 和 thiscall 屬性不是相容"
 
-#: config/i386/i386-options.cc:3814 config/i386/i386-options.cc:3832
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl 和 thiscall 屬性不是相容"
 
-#: config/i386/i386-options.cc:3820
+#: config/i386/i386-options.cc:3841
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE 屬性被用於無 class-method"
 
-#: config/i386/i386-options.cc:3924 config/rs6000/rs6000.cc:20747
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE 不相容的屬性忽略"
 
-#: config/i386/i386-options.cc:3951
+#: config/i386/i386-options.cc:3972
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE 屬性只有可見於 32-bit"
 
-#: config/i386/i386-options.cc:3972
+#: config/i386/i386-options.cc:3993
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "引數到 %qE 屬性是 neither 零，nor 一個"
 
-#: config/i386/i386-options.cc:4043 config/i386/i386-options.cc:4065
-#: config/ia64/ia64.cc:822 config/s390/s390.cc:1271
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE 屬性需要字串常數引數"
 
-#: config/i386/i386-options.cc:4053 config/i386/i386-options.cc:4075
-#: config/s390/s390.cc:1300
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: config/i386/i386-options.cc:4107
+#: config/i386/i386-options.cc:4128
 #, fuzzy, gcc-internal-format
 #| msgid "dereferenced pointers should have a name or a type tag"
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "提領的指標應具有一個名稱或類型標記"
 
-#: config/i386/i386-options.cc:4114
+#: config/i386/i386-options.cc:4135
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine should have %qs as the second argument"
 msgstr "插斷函式必須沒有任何引數"
 
-#: config/i386/i386-options.cc:4125
+#: config/i386/i386-options.cc:4146
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386-options.cc:4128
+#: config/i386/i386-options.cc:4149
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine must return %<void%>"
 msgstr "插斷服務常式無法編碼的在中姆指模式"
@@ -43634,49 +43634,49 @@ msgstr "擴充的暫存器不支援的運算元大小"
 msgid "non-integer operand used with operand code %<z%>"
 msgstr "non-integer 運算元使用的與運算元編碼『%c』"
 
-#: config/i386/i386.cc:17996
+#: config/i386/i386.cc:17985
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.cc:22734
+#: config/i386/i386.cc:22766
 #, fuzzy
 msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr "mangling 的 %<va_list%> 已變更在中 GCC 4.4"
 
-#: config/i386/i386.cc:22815
+#: config/i386/i386.cc:22847
 #, fuzzy, gcc-internal-format
 #| msgid "no low registers available for popping high registers"
 msgid "no register available for profiling %<-mcmodel=large%s%>"
 msgstr "高暫存器彈堆疊時沒有可用的低暫存器"
 
-#: config/i386/i386.cc:22911
+#: config/i386/i386.cc:22943
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel= is not supported on 32 bit systems"
 msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "32 位元系統不支援 -mcmodel="
 
-#: config/i386/i386.cc:23624
+#: config/i386/i386.cc:23802
 #, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
 msgstr ""
 
-#: config/i386/i386.cc:25074
+#: config/i386/i386.cc:25252
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "不明 TLS 式樣 %qs"
 
-#: config/i386/i386.cc:25081
+#: config/i386/i386.cc:25259
 #, gcc-internal-format
 msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25088
+#: config/i386/i386.cc:25266
 #, gcc-internal-format
 msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.cc:25775
+#: config/i386/i386.cc:25953
 #, fuzzy, gcc-internal-format
 msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
 msgstr "-fdirectives-only 是不相容的與 -traditional"
@@ -43697,8 +43697,8 @@ msgstr "定義的靜態資料成員 %q+D 的 dllimport%'d 類別"
 msgid "malformed %<#pragma builtin%>"
 msgstr "#pragma builtin 格式錯誤"
 
-#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7974
-#: config/loongarch/loongarch.cc:7984
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
 #, fuzzy, gcc-internal-format
 msgid "invalid argument of %qE attribute"
 msgstr "無效的引數的 %qE 屬性"
@@ -43757,12 +43757,12 @@ msgstr "PRINT_OPERAND：不明的標點「%c」"
 msgid "%<PRINT_OPERAND%> null pointer"
 msgstr "PRINT_OPERAND 空指標"
 
-#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17388
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d to the built-in must be a constant in range %d to %d"
 msgstr "引數 %d 的 %qE 必須是在中範圍 %d...%d"
 
-#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17508
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
 #, fuzzy, gcc-internal-format
 #| msgid "failed to reclaim unneeded function"
 msgid "failed to expand built-in function"
@@ -43891,17 +43891,17 @@ msgstr "%qD 不是相容與 %qD"
 msgid "%qs cannot be used for compiling a shared library"
 msgstr "%<constexpr%> 無法用於類型宣告"
 
-#: config/loongarch/loongarch.cc:7946
+#: config/loongarch/loongarch.cc:7953
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be specified for thread-local variables"
 msgstr "%qE 屬性無法指定的用於區域變數"
 
-#: config/loongarch/loongarch.cc:7964
+#: config/loongarch/loongarch.cc:7971
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute cannot be specified for register variables"
 msgstr "%qE 屬性無法指定的用於區域變數"
 
-#: config/loongarch/loongarch.cc:7992
+#: config/loongarch/loongarch.cc:7999
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "multiple %qE attribute"
@@ -44007,12 +44007,12 @@ msgstr "多重插斷屬性不允許"
 msgid "%<interrupt_thread%> is available only on fido"
 msgstr "interruptthread 是可用只有於 fido(_T)"
 
-#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1749
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "不支援堆疊限制運算式"
 
-#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17177
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
 #, fuzzy, gcc-internal-format
 #| msgid "-fstack-protector not supported for this target"
 msgid "%<-fexcess-precision=16%> is not supported on this target"
@@ -44054,7 +44054,7 @@ msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
 msgstr "-mxl-multiply-high 需求 -mno-xl-soft-mul"
 
 #: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
-#: config/riscv/riscv.cc:5800
+#: config/riscv/riscv.cc:5812
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string argument"
 msgstr "%qE 屬性需要字串常數引數"
@@ -44094,132 +44094,132 @@ msgstr ""
 msgid "argument to %qE attribute is not intstack"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: config/mips/mips.cc:6223
+#: config/mips/mips.cc:6232
 msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6668
+#: config/mips/mips.cc:6677
 msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:6692
+#: config/mips/mips.cc:6701
 msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
 msgstr ""
 
-#: config/mips/mips.cc:8039
+#: config/mips/mips.cc:8048
 #, gcc-internal-format
 msgid "cannot handle inconsistent calls to %qs"
 msgstr "無法處理對 %qs 不一致的呼叫"
 
-#: config/mips/mips.cc:11295
+#: config/mips/mips.cc:11304
 #, fuzzy, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
 msgstr "%<interrupt%> 屬性需要 MIPS32r2 處理器"
 
-#: config/mips/mips.cc:11297
+#: config/mips/mips.cc:11306
 #, fuzzy, gcc-internal-format
 msgid "interrupt handlers cannot be MIPS16 functions"
 msgstr "中斷處理程式無法 MIPS16 函式"
 
-#: config/mips/mips.cc:12301
+#: config/mips/mips.cc:12310
 #, gcc-internal-format
 msgid "%<-fstack-check=specific%> not implemented for MIPS16"
 msgstr ""
 
-#: config/mips/mips.cc:17640
+#: config/mips/mips.cc:17649
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE not supported for MIPS16"
 msgstr "內建函式 %qE 不支援用於 MIPS16"
 
-#: config/mips/mips.cc:18248
+#: config/mips/mips.cc:18257
 #, fuzzy, gcc-internal-format
 msgid "%qs does not support MIPS16 code"
 msgstr "%qs 不支援 MIPS16 編碼"
 
-#: config/mips/mips.cc:20061
+#: config/mips/mips.cc:20070
 #, fuzzy, gcc-internal-format
 msgid "MIPS16 PIC for ABIs other than o32 and o64"
 msgstr "MIPS16 PIC 用於 ABIs 不同於 o32 和 o64"
 
-#: config/mips/mips.cc:20064
+#: config/mips/mips.cc:20073
 #, fuzzy, gcc-internal-format
 msgid "MIPS16 %<-mxgot%> code"
 msgstr "MIPS16 -mxgot 編碼"
 
-#: config/mips/mips.cc:20067
+#: config/mips/mips.cc:20076
 #, fuzzy, gcc-internal-format
 msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
 msgstr "hard-float MIPS16 編碼用於 ABIs 不同於 o32 和 o64"
 
-#: config/mips/mips.cc:20070
+#: config/mips/mips.cc:20079
 #, fuzzy, gcc-internal-format
 msgid "MSA MIPS16 code"
 msgstr "產生 MIPS16 編碼"
 
-#: config/mips/mips.cc:20073
+#: config/mips/mips.cc:20082
 #, fuzzy, gcc-internal-format
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
 msgstr "%<-mno-gpopt%> 需要 %<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20264 config/mips/mips.cc:20269
-#: config/mips/mips.cc:20359 config/mips/mips.cc:20361
-#: config/mips/mips.cc:20391 config/mips/mips.cc:20401
-#: config/mips/mips.cc:20507 config/mips/mips.cc:20531
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported combination: %s"
 msgstr "不支援的組合：%s"
 
-#: config/mips/mips.cc:20304
+#: config/mips/mips.cc:20313
 #, fuzzy, gcc-internal-format
 msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
 msgstr "%<-%s%> 衝突與其他架構選項，該項指定 %s 處理器"
 
-#: config/mips/mips.cc:20314
+#: config/mips/mips.cc:20323
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgstr "%<-march=%s%>不是相容與已選 ABI"
 
-#: config/mips/mips.cc:20329
+#: config/mips/mips.cc:20338
 #, fuzzy, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit processor"
 msgstr "%<-mgp64%> 使用的與 32-bit 處理器"
 
-#: config/mips/mips.cc:20331
+#: config/mips/mips.cc:20340
 #, fuzzy, gcc-internal-format
 msgid "%<-mgp32%> used with a 64-bit ABI"
 msgstr "%<-mgp32%> 使用的與 64-bit ABI"
 
-#: config/mips/mips.cc:20333
+#: config/mips/mips.cc:20342
 #, fuzzy, gcc-internal-format
 msgid "%<-mgp64%> used with a 32-bit ABI"
 msgstr "%<-mgp64%> 使用的與 32-bit ABI"
 
-#: config/mips/mips.cc:20356
+#: config/mips/mips.cc:20365
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support %<-mfp32%>"
 msgstr "%qs 架構不支援同步指令"
 
-#: config/mips/mips.cc:20365
+#: config/mips/mips.cc:20374
 #, fuzzy, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
 msgstr "%<-mgp32%> 和 %<-mfp64%> 只能被合併如果目標支援 mfhc1 和 mthc1 指令"
 
-#: config/mips/mips.cc:20368
+#: config/mips/mips.cc:20377
 #, fuzzy, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
 msgstr "%<-mgp32%> 和 %<-mfp64%> 只能被合併時使用 o32 ABI"
 
-#: config/mips/mips.cc:20389
+#: config/mips/mips.cc:20398
 #, fuzzy, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
 msgstr "%<-mgp32%> 和 %<-mfp64%> 只能被合併時使用 o32 ABI"
 
-#: config/mips/mips.cc:20393
+#: config/mips/mips.cc:20402
 #, fuzzy, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
 msgstr "%<-mips3d%> 需求 %<-mpaired-single%>"
 
-#: config/mips/mips.cc:20395
+#: config/mips/mips.cc:20404
 #, fuzzy, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
 msgstr "%<-mips3d%> 需求 %<-mpaired-single%>"
@@ -44229,121 +44229,121 @@ msgstr "%<-mips3d%> 需求 %<-mpaired-single%>"
 #. effort to support the combination of 32-bit GOT entries
 #. and 64-bit pointers, so we treat the abicalls case as
 #. an error.
-#: config/mips/mips.cc:20420
+#: config/mips/mips.cc:20429
 #, fuzzy, gcc-internal-format
 msgid "the combination of %qs and %qs is incompatible with %qs"
 msgstr "組合的 %qs 和 %qs 是不相容的與 %qs"
 
-#: config/mips/mips.cc:20473
+#: config/mips/mips.cc:20482
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support branch-likely instructions"
 msgstr "%qs 架構不支援 branch-likely 指令"
 
-#: config/mips/mips.cc:20488
+#: config/mips/mips.cc:20497
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support madd or msub instructions"
 msgstr "%qs 架構不支援同步指令"
 
-#: config/mips/mips.cc:20502
+#: config/mips/mips.cc:20511
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
 msgstr "%qs 架構不支援 paired-single 指令"
 
-#: config/mips/mips.cc:20515
+#: config/mips/mips.cc:20524
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported combination: %qs%s %s"
 msgstr "不支援的組合：%s"
 
-#: config/mips/mips.cc:20524
+#: config/mips/mips.cc:20533
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported combination: %qs %s"
 msgstr "不支援的組合：%s"
 
-#: config/mips/mips.cc:20539
+#: config/mips/mips.cc:20548
 #, fuzzy, gcc-internal-format
 msgid "cannot generate position-independent code for %qs"
 msgstr "盡可能產生與位置無關的程式碼(大模式)"
 
-#: config/mips/mips.cc:20542
+#: config/mips/mips.cc:20551
 #, fuzzy, gcc-internal-format
 msgid "position-independent code requires %qs"
 msgstr "停用 position-independent 編碼 (PIC) 用於使用在中作業系統內核編碼"
 
-#: config/mips/mips.cc:20575
+#: config/mips/mips.cc:20584
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
 msgstr "%<-mno-gpopt%> 需要 %<-mexplicit-relocs%>"
 
-#: config/mips/mips.cc:20583 config/mips/mips.cc:20586
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
 #, fuzzy, gcc-internal-format
 msgid "cannot use small-data accesses for %qs"
 msgstr "無法使用 small-data 存取用於 %qs"
 
-#: config/mips/mips.cc:20603
+#: config/mips/mips.cc:20612
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
 msgstr "%qs 架構不支援 paired-single 指令"
 
-#: config/mips/mips.cc:20610
+#: config/mips/mips.cc:20619
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=2008%>"
 msgstr "%qs 架構不支援同步指令"
 
-#: config/mips/mips.cc:20628
+#: config/mips/mips.cc:20637
 #, fuzzy, gcc-internal-format
 msgid "%<-mips3d%> requires %<-mpaired-single%>"
 msgstr "%<-mips3d%> 需求 %<-mpaired-single%>"
 
-#: config/mips/mips.cc:20638
+#: config/mips/mips.cc:20647
 #, fuzzy, gcc-internal-format
 msgid "%qs must be used with %qs"
 msgstr "%qs 必須被使用與 %qs"
 
-#: config/mips/mips.cc:20648
+#: config/mips/mips.cc:20657
 #, fuzzy, gcc-internal-format
 #| msgid "-mips3d/-mpaired-single must be used with -mfp64 -mhard-float"
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
 msgstr "-mips3d/-mpaired-single 必須與 -mfp64 -mhard-float 一起使用"
 
-#: config/mips/mips.cc:20655
+#: config/mips/mips.cc:20664
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support paired-single instructions"
 msgstr "%qs 架構不支援 paired-single 指令"
 
-#: config/mips/mips.cc:20664
+#: config/mips/mips.cc:20673
 #, fuzzy, gcc-internal-format
 msgid "%qs requires a target that provides the %qs instruction"
 msgstr "%qs 需要目標該提供 %qs 指令"
 
-#: config/mips/mips.cc:20675
+#: config/mips/mips.cc:20684
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support DSP instructions"
 msgstr "%qs 架構不支援同步指令"
 
-#: config/mips/mips.cc:20685
+#: config/mips/mips.cc:20694
 #, fuzzy, gcc-internal-format
 #| msgid "-mips3d/-mpaired-single must be used with -mfp64 -mhard-float"
 msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
 msgstr "-mips3d/-mpaired-single 必須與 -mfp64 -mhard-float 一起使用"
 
-#: config/mips/mips.cc:20695
+#: config/mips/mips.cc:20704
 #, gcc-internal-format
 msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
 msgstr ""
 
-#: config/mips/mips.cc:20790
+#: config/mips/mips.cc:20799
 #, fuzzy, gcc-internal-format
 msgid "%qs requires branch-likely instructions"
 msgstr "%qs 需求 branch-likely 指令"
 
-#: config/mips/mips.cc:20794
+#: config/mips/mips.cc:20803
 #, fuzzy, gcc-internal-format
 msgid "the %qs architecture does not support the synci instruction"
 msgstr "%qs 架構不支援同步指令"
 
-#: config/mips/mips.cc:21630
+#: config/mips/mips.cc:21639
 #, gcc-internal-format
 msgid "mips16 function profiling"
 msgstr "mips16 函式取樣"
@@ -45248,58 +45248,58 @@ msgstr "%<# pragma GCC optimize%>並非字串或數字"
 msgid "unknown %<#pragma riscv intrinsic%> option %qs"
 msgstr "不明 # pragma GCC 輔助處理器 %E"
 
-#: config/riscv/riscv-target-attr.cc:124
+#: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:136
+#: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:162
+#: config/riscv/riscv-target-attr.cc:159
 #, gcc-internal-format
 msgid "%<target()%> attribute: arch appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:173
+#: config/riscv/riscv-target-attr.cc:170
 #, gcc-internal-format
 msgid "%<target()%> attribute: cpu appears more than once"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:180
+#: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:201
+#: config/riscv/riscv-target-attr.cc:198
 #, fuzzy, gcc-internal-format
 msgid "%<target()%> attribute: tune appears more than once"
 msgstr "目標屬性未被支援於這個機器"
 
-#: config/riscv/riscv-target-attr.cc:207
+#: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
 msgstr ""
 
-#: config/riscv/riscv-target-attr.cc:246
+#: config/riscv/riscv-target-attr.cc:253
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> attribute"
 msgstr "%<#pragma init%> 格式錯誤"
 
-#: config/riscv/riscv-target-attr.cc:260
+#: config/riscv/riscv-target-attr.cc:267
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%qE 屬性需要字串常數引數"
 
-#: config/riscv/riscv-target-attr.cc:277
+#: config/riscv/riscv-target-attr.cc:285
 #, fuzzy, gcc-internal-format
 msgid "Got unknown attribute %<target(\"%s\")%>"
 msgstr "預期的繫結屬性於 %C"
 
-#: config/riscv/riscv-target-attr.cc:359
+#: config/riscv/riscv-target-attr.cc:368
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target(\"%s\")%> attribute"
@@ -45365,175 +45365,195 @@ msgstr "無法為有抽象類型 %qT 的物件指派記憶體"
 msgid "capture by copy of RVV type %qT"
 msgstr "無效的使用的不完整型態 %q#T"
 
-#: config/riscv/riscv-vector-builtins.cc:4646
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr "內建函式 %s 需求 -maltivec 選項"
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr "內建函式 %s 需求 -maltivec 選項"
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr "內建函式 %s 需求 -maltivec 選項"
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, fuzzy, gcc-internal-format
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr "內建函式 %s 需求 -maltivec 選項"
+
+#: config/riscv/riscv-vector-builtins.cc:4694
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE requires the %qs ISA extension"
 msgstr "內建函式 %s 需求 -mvsx 選項"
 
-#: config/riscv/riscv-vector-builtins.cc:4696
+#: config/riscv/riscv-vector-builtins.cc:4747
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function call to %qE with empty arguments"
 msgstr "對 %<%D(%A)%> 的呼叫沒有匹配的函式"
 
-#: config/riscv/riscv.cc:714
+#: config/riscv/riscv.cc:723
 #, fuzzy, gcc-internal-format
 msgid "unknown cpu %qs for %<-mtune%>"
 msgstr "不當的值 %qs 用於 -mtune 切換"
 
-#: config/riscv/riscv.cc:2537
+#: config/riscv/riscv.cc:2548
 #, fuzzy, gcc-internal-format
 msgid "this operation requires the RVV ISA extension"
 msgstr "不使用 SPE ABI 延伸"
 
-#: config/riscv/riscv.cc:2538
+#: config/riscv/riscv.cc:2549
 #, gcc-internal-format
 msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
 msgstr ""
 
-#: config/riscv/riscv.cc:4969 config/riscv/riscv.cc:5011
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
 #, fuzzy, gcc-internal-format
 msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI 的傳遞結構與複雜浮點數成員已變更在中 GCC 4.4"
 
-#: config/riscv/riscv.cc:5358
+#: config/riscv/riscv.cc:5370
 #, fuzzy, gcc-internal-format
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "RVV type %qT cannot be passed to an unprototyped function"
 msgstr "傳遞 AltiVec 引數給無原型的函式"
 
-#: config/riscv/riscv.cc:5611
+#: config/riscv/riscv.cc:5623
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the V ISA extension"
 msgstr "使用 SPE ABI 延伸"
 
-#: config/riscv/riscv.cc:5623
+#: config/riscv/riscv.cc:5635
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
 msgstr "使用 SPE ABI 延伸"
 
-#: config/riscv/riscv.cc:5634
+#: config/riscv/riscv.cc:5646
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
 msgstr "使用 SPE ABI 延伸"
 
-#: config/riscv/riscv.cc:5643
+#: config/riscv/riscv.cc:5655
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
 msgstr "使用 SPE ABI 延伸"
 
-#: config/riscv/riscv.cc:5652
+#: config/riscv/riscv.cc:5664
 #, fuzzy, gcc-internal-format
 msgid "%s %qT requires the zve64d or v ISA extension"
 msgstr "使用 SPE ABI 延伸"
 
-#: config/riscv/riscv.cc:5662
+#: config/riscv/riscv.cc:5674
 #, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
 msgstr ""
 
-#: config/riscv/riscv.cc:5717
+#: config/riscv/riscv.cc:5729
 #, fuzzy, gcc-internal-format
 msgid "function attribute %qs requires the V ISA extension"
 msgstr "內建函式 %s 需求 -mvsx 選項"
 
-#: config/riscv/riscv.cc:5811
+#: config/riscv/riscv.cc:5823
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
 msgstr "引數到 %qE 屬性是 neither 零，nor 一個"
 
-#: config/riscv/riscv.cc:5834
+#: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
 msgstr ""
 
-#: config/riscv/riscv.cc:5843
+#: config/riscv/riscv.cc:5855
 #, fuzzy, gcc-internal-format
 msgid "%qs applied to non-RVV type %qT"
 msgstr "%qE 屬性在不是類別的類型上被忽略"
 
-#: config/riscv/riscv.cc:5851
+#: config/riscv/riscv.cc:5863
 #, fuzzy, gcc-internal-format
 msgid "%qs requires an integer constant"
 msgstr "%qE 屬性需求整數常數引數"
 
-#: config/riscv/riscv.cc:5861
+#: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
 msgstr ""
 
-#: config/riscv/riscv.cc:9255
+#: config/riscv/riscv.cc:9213
 #, gcc-internal-format
 msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9297
+#: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9303
+#: config/riscv/riscv.cc:9261
 #, fuzzy, gcc-internal-format
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
 msgstr "目標 CPU 不支援手臂模式"
 
-#: config/riscv/riscv.cc:9329 config/riscv/riscv.cc:9332
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs with %qs"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
 
-#: config/riscv/riscv.cc:9361
+#: config/riscv/riscv.cc:9319
 #, gcc-internal-format
 msgid "requested ABI requires %<-march%> to subsume the %qc extension"
 msgstr ""
 
-#: config/riscv/riscv.cc:9368
+#: config/riscv/riscv.cc:9326
 #, gcc-internal-format
 msgid "rv32e requires ilp32e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9370
+#: config/riscv/riscv.cc:9328
 #, gcc-internal-format
 msgid "rv64e requires lp64e ABI"
 msgstr ""
 
-#: config/riscv/riscv.cc:9377
+#: config/riscv/riscv.cc:9335
 #, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
 msgstr ""
 
-#: config/riscv/riscv.cc:9381
+#: config/riscv/riscv.cc:9339
 #, gcc-internal-format
 msgid "ABI requires %<-march=rv%d%>"
 msgstr ""
 
-#: config/riscv/riscv.cc:9391
+#: config/riscv/riscv.cc:9349
 #, fuzzy, gcc-internal-format
 msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 未被介於 %d 和 %d"
 
-#: config/riscv/riscv.cc:9404
+#: config/riscv/riscv.cc:9362
 #, gcc-internal-format
 msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
 msgstr ""
 
-#: config/riscv/riscv.cc:9431 config/rs6000/rs6000.cc:4509
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs 並非有效類別名稱"
 
-#: config/riscv/riscv.cc:9445 config/rs6000/rs6000.cc:4492
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs 無效用於 %qs"
 
-#: config/riscv/riscv.cc:9843
+#: config/riscv/riscv.cc:9801
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have different interrupt type"
 msgstr "%qs 函式無法有引數"
 
-#: config/riscv/riscv.cc:10369
+#: config/riscv/riscv.cc:10327
 #, gcc-internal-format
 msgid "cannot allocate vl register for %qs on this target"
 msgstr ""
@@ -45798,33 +45818,33 @@ msgstr "%s 只有接受 2 引數"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s 只有接受 2 引數"
 
-#: config/rs6000/rs6000-c.cc:1734
+#: config/rs6000/rs6000-c.cc:1737
 #, gcc-internal-format
 msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1738
+#: config/rs6000/rs6000-c.cc:1741
 #, gcc-internal-format
 msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:1824
+#: config/rs6000/rs6000-c.cc:1827
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
 msgstr "傳遞引數 %d 的 %qE 捨棄 %qv 限定元從指標目標類型"
 
-#: config/rs6000/rs6000-c.cc:1880 config/rs6000/rs6000-c.cc:2063
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "對 AltiVec 內建函式來說無效的參陣列合"
 
-#: config/rs6000/rs6000-c.cc:2052
+#: config/rs6000/rs6000-c.cc:2056
 #, gcc-internal-format
 msgid "overloaded builtin %qs is implemented by builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.cc:2056
+#: config/rs6000/rs6000-c.cc:2060
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "%qs is not supported in this compiler configuration"
@@ -45869,31 +45889,23 @@ msgstr "運算元類型 %qT 和 %qT 對二進位 %qO 而言無效"
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 傳遞向量參照：非標準的 ABI 擴充，不保證相容性"
 
-#. We can't check this in rs6000_option_override_internal since
-#. DEFAULT_ABI isn't established yet.
-#: config/rs6000/rs6000-logue.cc:728
-#, fuzzy, gcc-internal-format
-#| msgid "Use EABI"
-msgid "%qs requires the ELFv2 ABI"
-msgstr "使用 EABI"
-
-#: config/rs6000/rs6000-logue.cc:1712
+#: config/rs6000/rs6000-logue.cc:1705
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "堆疊框架太大"
 
-#: config/rs6000/rs6000-logue.cc:4029
+#: config/rs6000/rs6000-logue.cc:4021
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported number of nops before function entry (%u)"
 msgstr "不正確引數數量到函式 %qE"
 
-#: config/rs6000/rs6000-logue.cc:5577
+#: config/rs6000/rs6000-logue.cc:5565
 #, fuzzy, gcc-internal-format
 #| msgid "Use registers r2 and r5"
 msgid "%qs uses register r29"
 msgstr "使用暫存器 r2 和 r5"
 
-#: config/rs6000/rs6000-logue.cc:5585
+#: config/rs6000/rs6000-logue.cc:5573
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
 msgstr ""
@@ -46023,107 +46035,117 @@ msgstr "需要 call-clobbered 目標暫存器"
 msgid "unknown option for %<%s=%s%>"
 msgstr "不明選項用於 -mrecip=%s"
 
-#: config/rs6000/rs6000.cc:4843
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4837
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4855
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:11169
+#: config/rs6000/rs6000.cc:11184
 #, gcc-internal-format
 msgid "%qs is an opaque type, and you cannot set it to other values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:18014
+#: config/rs6000/rs6000.cc:18029
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "此 ABI 不支援取樣 64 位元程式碼"
 
-#: config/rs6000/rs6000.cc:20410
+#: config/rs6000/rs6000.cc:20425
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "您無法需位址的巢狀的函式如果您使用 -mno-pointers-to-nested-functions 選項。"
 
-#: config/rs6000/rs6000.cc:20492
+#: config/rs6000/rs6000.cc:20507
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用 %<long double%> 無效"
 
-#: config/rs6000/rs6000.cc:20494
+#: config/rs6000/rs6000.cc:20509
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用布林類型無效"
 
-#: config/rs6000/rs6000.cc:20496
+#: config/rs6000/rs6000.cc:20511
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用 %<complex%> 無效"
 
-#: config/rs6000/rs6000.cc:20498
+#: config/rs6000/rs6000.cc:20513
 #, fuzzy, gcc-internal-format
 msgid "use of decimal floating-point types in AltiVec types is invalid"
 msgstr "使用的十進位浮點數類型在中 AltiVec 類型無效"
 
-#: config/rs6000/rs6000.cc:20504
+#: config/rs6000/rs6000.cc:20519
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "使用的 %<long%> 在中 AltiVec 類型無效用於 64-bit 編碼而無需 -mvsx"
 
-#: config/rs6000/rs6000.cc:20507
+#: config/rs6000/rs6000.cc:20522
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "在 AltiVec 類型中使用 %<long%> 已過時；請改用 %<int%>"
 
-#: config/rs6000/rs6000.cc:20512
+#: config/rs6000/rs6000.cc:20527
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "使用的 %<long long%> 在中 AltiVec 類型無效而無需 -mvsx"
 
-#: config/rs6000/rs6000.cc:20515
+#: config/rs6000/rs6000.cc:20530
 #, fuzzy, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "使用的 %<double%> 在中 AltiVec 類型無效而無需 -mvsx"
 
-#: config/rs6000/rs6000.cc:24656
+#: config/rs6000/rs6000.cc:24671
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "無效的 cpu「%s」用於 %s「%s」%s"
 
-#: config/rs6000/rs6000.cc:24659
+#: config/rs6000/rs6000.cc:24674
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s「%s」%s 未被允許"
 
-#: config/rs6000/rs6000.cc:24661
+#: config/rs6000/rs6000.cc:24676
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s「%s」%s 無效"
 
-#: config/rs6000/rs6000.cc:25182
+#: config/rs6000/rs6000.cc:25197
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25341
+#: config/rs6000/rs6000.cc:25356
 #, gcc-internal-format
 msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:25630
+#: config/rs6000/rs6000.cc:25645
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "不支援堆疊限制運算式"
 
-#: config/rs6000/rs6000.cc:28768
+#: config/rs6000/rs6000.cc:28783
 #, gcc-internal-format
 msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
 msgstr ""
 
-#: config/rs6000/rs6000.cc:29246
+#: config/rs6000/rs6000.cc:29261
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_quad%> requires the %qs option"
 msgstr "內建函式 %s 需求 -mvsx 選項"
 
-#: config/rs6000/rs6000.cc:29251
+#: config/rs6000/rs6000.cc:29266
 #, fuzzy, gcc-internal-format
 msgid "type %<__vector_pair%> requires the %qs option"
 msgstr "內建函式 %s 需求 -mvsx 選項"
@@ -46169,7 +46191,7 @@ msgstr "RX FPU 指令不支援 NaNs 和 infinities"
 msgid "builtin %qs can only be used on vector types"
 msgstr "只能為函式指定 %qs"
 
-#: config/s390/s390-c.cc:720 config/s390/s390.cc:999
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -46241,232 +46263,232 @@ msgstr "%qE 被不宜用"
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "常數引數超過 %qs 的範圍"
 
-#: config/s390/s390.cc:848
+#: config/s390/s390.cc:849
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is invalid (%s)"
 msgstr "常數引數超過 %qs 的範圍"
 
-#: config/s390/s390.cc:852
+#: config/s390/s390.cc:853
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
 msgstr "常數引數超過 %qs 的範圍"
 
-#: config/s390/s390.cc:868
+#: config/s390/s390.cc:869
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
 msgstr "常數引數超過 %qs 的範圍"
 
-#: config/s390/s390.cc:917
+#: config/s390/s390.cc:918
 #, gcc-internal-format
 msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:923
+#: config/s390/s390.cc:924
 #, gcc-internal-format
 msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
 msgstr ""
 
-#: config/s390/s390.cc:930
+#: config/s390/s390.cc:931
 #, fuzzy, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher"
 msgstr "%qE 被 predetermined %qs 用於 %qs"
 
-#: config/s390/s390.cc:936
+#: config/s390/s390.cc:937
 #, fuzzy, gcc-internal-format
 msgid "Builtin %qF requires z15 or higher"
 msgstr "%qE 被 predetermined %qs 用於 %qs"
 
-#: config/s390/s390.cc:955
+#: config/s390/s390.cc:956
 #, fuzzy, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "<unresolved overloaded function type>"
 
-#: config/s390/s390.cc:962
+#: config/s390/s390.cc:963
 #, fuzzy, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "不當的內建 icode"
 
-#: config/s390/s390.cc:1096
+#: config/s390/s390.cc:1097
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "無效的引數到內建函式"
 
-#: config/s390/s390.cc:1197
+#: config/s390/s390.cc:1198
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.cc:1287
+#: config/s390/s390.cc:1288
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
 msgstr "引數到 %qE 屬性是 neither 零，nor 一個"
 
-#: config/s390/s390.cc:10593
+#: config/s390/s390.cc:10594
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "局部變數大小總和超過架構極值。"
 
-#: config/s390/s390.cc:12000
+#: config/s390/s390.cc:12001
 #, fuzzy, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
 msgstr "影格大小的函式 %qs 是 %wd 位元組超出使用者提供的堆疊限制的 %d 位元組。 unconditional 陷阱被已加入。"
 
-#: config/s390/s390.cc:12016
+#: config/s390/s390.cc:12017
 #, fuzzy, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
 msgstr "影格大小的函式 %qs 是 %wd 位元組該項是超過半堆疊大小。動態檢查會無法是 reliable。沒有檢查發出用於這個函式。"
 
-#: config/s390/s390.cc:12044
+#: config/s390/s390.cc:12045
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "影格大小的 %qs 是 %wd 位元組"
 
-#: config/s390/s390.cc:12048
+#: config/s390/s390.cc:12049
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs 使用動態堆疊指派"
 
-#: config/s390/s390.cc:12795
+#: config/s390/s390.cc:12796
 #, fuzzy, gcc-internal-format
 msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
 msgstr "ABI 的傳遞結構與複雜浮點數成員已變更在中 GCC 4.4"
 
-#: config/s390/s390.cc:13754
+#: config/s390/s390.cc:13755
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
 msgstr "巢狀函式 %qs 被宣告為 %<extern%>"
 
-#: config/s390/s390.cc:16056
+#: config/s390/s390.cc:16057
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支援"
 
-#: config/s390/s390.cc:16063
+#: config/s390/s390.cc:16064
 #, gcc-internal-format
 msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
 msgstr ""
 
-#: config/s390/s390.cc:16098
+#: config/s390/s390.cc:16099
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "硬體十進位浮點數指令無法使用於 %s"
 
-#: config/s390/s390.cc:16101
+#: config/s390/s390.cc:16102
 #, gcc-internal-format
 msgid "hardware vector support not available with %<-msoft-float%>"
 msgstr ""
 
-#: config/s390/s390.cc:16130
+#: config/s390/s390.cc:16131
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating-point instructions not available on %s"
 msgstr "硬體十進位浮點數指令無法使用於 %s"
 
-#: config/s390/s390.cc:16134
+#: config/s390/s390.cc:16135
 #, fuzzy, gcc-internal-format
 msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
 msgstr "硬體十進位浮點數指令無法使用在中 ESA/390 模式"
 
-#: config/s390/s390.cc:16146
+#: config/s390/s390.cc:16147
 #, fuzzy, gcc-internal-format
 msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
 msgstr "-mhard-dfp can%'t 被已用於接合與 -msoft-float"
 
-#: config/s390/s390.cc:16155
+#: config/s390/s390.cc:16156
 #, fuzzy, gcc-internal-format
 #| msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float 一起使用不受支援"
 
-#: config/s390/s390.cc:16161
+#: config/s390/s390.cc:16162
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "堆疊大小必須大於堆疊防護值"
 
-#: config/s390/s390.cc:16163
+#: config/s390/s390.cc:16164
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "堆疊大小不能大於 64K"
 
-#: config/s390/s390.cc:16166
+#: config/s390/s390.cc:16167
 #, fuzzy, gcc-internal-format
 #| msgid "-mstack-guard implies use of -mstack-size"
 msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
 msgstr "-mstack-guard 意味著使用 -mstack-size"
 
-#: config/s390/s390.cc:16179
+#: config/s390/s390.cc:16180
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16182
+#: config/s390/s390.cc:16183
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16185
+#: config/s390/s390.cc:16186
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16188
+#: config/s390/s390.cc:16189
 #, gcc-internal-format
 msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
 msgstr ""
 
-#: config/s390/s390.cc:16252
+#: config/s390/s390.cc:16253
 #, fuzzy, gcc-internal-format
 msgid "%<-mfentry%> is supported only for 64-bit CPUs"
 msgstr "%qE 屬性被支援只有用於 SH2A"
 
 #. argument is not a plain number
-#: config/s390/s390.cc:16288
+#: config/s390/s390.cc:16289
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "引數到 %qs 應該是 non-negative 整數"
 
-#: config/s390/s390.cc:16295
+#: config/s390/s390.cc:16296
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "引數到 %qE 屬性大於 %d"
 
-#: config/s390/s390.cc:16326
+#: config/s390/s390.cc:16327
 #, gcc-internal-format
 msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
 msgstr ""
 
-#: config/s390/s390.cc:16487 config/s390/s390.cc:16537
-#: config/s390/s390.cc:16554
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument %qs is unknown"
 msgstr "屬性 (目標 (「%s」)) 為未知"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.cc:16493
+#: config/s390/s390.cc:16494
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "%<__int128%>未被支援由這個目標"
 
-#: config/s390/s390.cc:17552
+#: config/s390/s390.cc:17553
 #, fuzzy, gcc-internal-format
 msgid "invalid cc output constraint: %qs"
 msgstr "無效指令："
 
-#: config/s390/s390.cc:17557
+#: config/s390/s390.cc:17558
 #, fuzzy, gcc-internal-format
 #| msgid "-mhard-float not supported"
 msgid "multiple cc output constraints not supported"
 msgstr "不支援 -mhard-float"
 
-#: config/s390/s390.cc:17562
+#: config/s390/s390.cc:17563
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
 msgstr "asm-specifier 用於變數 %qE 衝突與 asm clobber 清單"
 
-#: config/s390/s390.cc:17568
+#: config/s390/s390.cc:17569
 #, fuzzy, gcc-internal-format
 msgid "invalid type for cc output constraint"
 msgstr "無效的型態用於製作函式"
@@ -46920,8 +46942,8 @@ msgstr "%qE 屬性沒有任何效果"
 msgid "attribute %qs applies to array types only"
 msgstr "屬性 %qs 套用到陣列類型只有"
 
-#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2498
-#: cp/typeck.cc:9512 cp/typeck.cc:10300 d/d-convert.cc:262
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
 msgstr "void 值未如預期地被忽略"
@@ -46998,7 +47020,7 @@ msgstr "陣列 %q+D 類型與隱含初始化不相容"
 msgid "underspecified declaration of %qE, which is already declared in this scope"
 msgstr "%qD 已在此作用欄位中宣告過"
 
-#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9946
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
 #, fuzzy, gcc-internal-format
 msgid "originally defined here"
 msgstr "原本地定義的在此"
@@ -47241,7 +47263,7 @@ msgstr "%q+D 的宣告隱藏了先前的一個非變數宣告"
 msgid "declaration of %qD shadows a parameter"
 msgstr "%q+D 的宣告隱藏了一個參數"
 
-#: c/c-decl.cc:3266 cp/name-lookup.cc:3547
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
 #, gcc-internal-format
 msgid "declaration of %qD shadows a global declaration"
 msgstr "%qD 的宣告隱藏了一個全域宣告"
@@ -47251,7 +47273,7 @@ msgstr "%qD 的宣告隱藏了一個全域宣告"
 msgid "declaration of %qD shadows a previous local"
 msgstr "%qD 的宣告隱藏了先前的一個局部變數"
 
-#: c/c-decl.cc:3298 cp/name-lookup.cc:3264
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
 #, fuzzy, gcc-internal-format
 msgid "shadowed declaration is here"
 msgstr "帶陰影宣告是在此"
@@ -47319,7 +47341,7 @@ msgstr "%qE undeclared (先使用在中這個函式)"
 msgid "each undeclared identifier is reported only once for each function it appears in"
 msgstr "每個 undeclared 識別碼被報告只一次用於每個函式看來在中"
 
-#: c/c-decl.cc:4053 cp/decl.cc:3579
+#: c/c-decl.cc:4053 cp/decl.cc:3588
 #, gcc-internal-format
 msgid "label %qE referenced outside of any function"
 msgstr "標籤 %qE 在所有函式外被參照"
@@ -47354,7 +47376,7 @@ msgstr "跳轉至敘述運算式中"
 msgid "duplicate label declaration %qE"
 msgstr "重複的標籤定義 %qE"
 
-#: c/c-decl.cc:4276 cp/decl.cc:4080
+#: c/c-decl.cc:4276 cp/decl.cc:4089
 #, gcc-internal-format
 msgid "duplicate label %qD"
 msgstr "重複的標籤 %qD"
@@ -47389,7 +47411,7 @@ msgstr "切換跳躍進入敘述運算式"
 msgid "%qE defined as wrong kind of tag"
 msgstr "%qE 定義為錯誤的 kind 的標籤"
 
-#: c/c-decl.cc:4669 cp/tree.cc:5036
+#: c/c-decl.cc:4669 cp/tree.cc:5039
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "忽略屬性套用到 %qT 之後定義"
@@ -47538,12 +47560,12 @@ msgstr "ISO C90 不支援 %<[*]%> 陣列宣告"
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10791
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
 #, fuzzy, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%>不允許在中不同於函式原型範圍"
 
-#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8804
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<omp::%s%> not allowed to be specified in this context"
@@ -47554,7 +47576,7 @@ msgstr "%<this%> 不能用在此上下文中"
 msgid "%q+D is usually a function"
 msgstr "%q+D 一般是一個函式"
 
-#: c/c-decl.cc:5562 c/c-decl.cc:10622 cp/decl.cc:17941
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "沒有前一個宣告用於 %qD"
@@ -47633,7 +47655,7 @@ msgstr "不能將帶有 volatile 欄位的物件放入暫存器"
 msgid "uninitialized %<const %D%> is invalid in C++"
 msgstr "uninitialized 常數 %qD 無效在中 C++"
 
-#: c/c-decl.cc:6110 cp/decl.cc:9043
+#: c/c-decl.cc:6110 cp/decl.cc:9052
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -47822,7 +47844,7 @@ msgstr "貯藏類別指定的用於參數 %qE"
 msgid "storage class specified for unnamed parameter"
 msgstr "貯藏類別指定的用於未命名參數"
 
-#: c/c-decl.cc:7068 cp/decl.cc:13134
+#: c/c-decl.cc:7068 cp/decl.cc:13150
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "為類型名指定了存儲類別"
@@ -47885,7 +47907,7 @@ msgstr "宣告的 %qE 做為陣列的函式"
 msgid "declaration of type name as array of functions"
 msgstr "宣告的型態名稱做為陣列的函式"
 
-#: c/c-decl.cc:7237 c/c-decl.cc:9542
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "對包含彈性陣列成員的結構的無效使用"
@@ -47994,7 +48016,7 @@ msgstr "型態名稱宣告的做為函式回傳陣列"
 msgid "function definition has qualified void return type"
 msgstr "函式定義有限定的 void 回傳類型"
 
-#: c/c-decl.cc:7647 cp/decl.cc:13543
+#: c/c-decl.cc:7647 cp/decl.cc:13559
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "忽略函式回傳類型的類型限定"
@@ -48124,7 +48146,7 @@ msgstr "ISO C 不允許使用 const 或 volatile 限定函式類型"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "成員的結構或聯合無法有 variably 已修改型態"
 
-#: c/c-decl.cc:7944 cp/decl.cc:12014
+#: c/c-decl.cc:7944 cp/decl.cc:12030
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "變數或欄位 %qE 宣告為 void"
@@ -48232,7 +48254,7 @@ msgstr "non-nested 函式與 variably 已修改型態"
 msgid "object with variably modified type must have no linkage"
 msgstr "物件與 variably 已修改型態必須沒有任何鏈結"
 
-#: c/c-decl.cc:8419 c/c-decl.cc:10596
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "函式宣告不是一個原型"
@@ -48322,18 +48344,18 @@ msgstr "巢狀的 %<union %E%> 重定義"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "巢狀的 %<struct %E%> 重定義"
 
-#: c/c-decl.cc:8935 c/c-decl.cc:9974
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
 #, fuzzy, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "定義輸入 %qs 運算式無效在中 C++"
 
-#: c/c-decl.cc:8941 c/c-decl.cc:9980
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
 #, fuzzy, gcc-internal-format
 #| msgid "unknown field %qE specified in initializer"
 msgid "%qT defined in underspecified object initializer"
 msgstr "初始值設定項裡有不明的欄位 %qE"
 
-#: c/c-decl.cc:9005 cp/decl.cc:5661
+#: c/c-decl.cc:9005 cp/decl.cc:5670
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "沒有宣告任何東西"
@@ -48363,355 +48385,355 @@ msgstr ""
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.cc:9434
+#: c/c-decl.cc:9469
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "聯合包含無名成員"
 
-#: c/c-decl.cc:9436
+#: c/c-decl.cc:9471
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "聯合體沒有成員"
 
-#: c/c-decl.cc:9441
+#: c/c-decl.cc:9476
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "結構不包含任何具名成員"
 
-#: c/c-decl.cc:9443
+#: c/c-decl.cc:9478
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "結構體沒有成員"
 
-#: c/c-decl.cc:9521 cp/decl.cc:14576
+#: c/c-decl.cc:9556 cp/decl.cc:14592
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexible 陣列成員在中聯合"
 
-#: c/c-decl.cc:9527
+#: c/c-decl.cc:9562
 #, fuzzy, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "flexible 陣列成員無法於結束的結構"
 
-#: c/c-decl.cc:9533
+#: c/c-decl.cc:9568
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "flexible 陣列成員在中聯合"
 
-#: c/c-decl.cc:9564
+#: c/c-decl.cc:9599
 #, fuzzy, gcc-internal-format
 msgid "structure containing a flexible array member is not at the end of another structure"
 msgstr "flexible 陣列成員無法於結束的結構"
 
-#: c/c-decl.cc:9587
+#: c/c-decl.cc:9622
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "值傳遞在中 %qs 太大"
 
-#: c/c-decl.cc:9651
+#: c/c-decl.cc:9686
 #, fuzzy, gcc-internal-format
 msgid "type punning toggles scalar storage order"
 msgstr "無法辨識的暫存器名稱 %qs"
 
-#: c/c-decl.cc:9718
+#: c/c-decl.cc:9753
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "聯合不能成為透明的"
 
-#: c/c-decl.cc:9731
+#: c/c-decl.cc:9766
 #, fuzzy, gcc-internal-format
 msgid "redefinition of struct or union %qT with variably modified type"
 msgstr "重複定義的 typedef %q+D 與 variably 已修改型態"
 
-#: c/c-decl.cc:9734
+#: c/c-decl.cc:9769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %<struct %E%>"
 msgid "redefinition of struct or union %qT"
 msgstr "%<struct %E%> 重定義"
 
-#: c/c-decl.cc:9899
+#: c/c-decl.cc:9938
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "巢狀的 %<enum %E%> 重定義"
 
-#: c/c-decl.cc:9944
+#: c/c-decl.cc:9983
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%> 重宣告"
 
-#: c/c-decl.cc:9956
+#: c/c-decl.cc:9995
 #, gcc-internal-format
 msgid "%<enum%> declared with but defined without fixed underlying type"
 msgstr ""
 
-#: c/c-decl.cc:10043 cp/decl.cc:17215 m2/gm2-gcc/m2type.cc:2073
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
 #, fuzzy, gcc-internal-format
 #| msgid "specified mode too small for enumeral values"
 msgid "specified mode too small for enumerated values"
 msgstr "指定的模式對列舉值來說太小"
 
-#: c/c-decl.cc:10062
+#: c/c-decl.cc:10101
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "列舉值超過了最大整數類型可表示的範圍"
 
-#: c/c-decl.cc:10071
+#: c/c-decl.cc:10110
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration values exceed range of largest integer"
 msgid "enumeration values exceed range of %qs"
 msgstr "列舉值超過了最大整數類型可表示的範圍"
 
-#: c/c-decl.cc:10180
+#: c/c-decl.cc:10219
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of %<enum %E%>"
 msgid "conflicting redefinition of enum %qT"
 msgstr "巢狀的 %<enum %E%> 重定義"
 
-#: c/c-decl.cc:10212 c/c-decl.cc:10228
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "%qE 的列舉值不是一個整數常數"
 
-#: c/c-decl.cc:10223
+#: c/c-decl.cc:10262
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "列舉值值用於 %qE 不是整數常數運算式"
 
-#: c/c-decl.cc:10247
+#: c/c-decl.cc:10286
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "列舉值溢出"
 
-#: c/c-decl.cc:10254
+#: c/c-decl.cc:10293
 #, fuzzy, gcc-internal-format
 msgid "enumerator value outside the range of underlying type"
 msgstr "列舉值值 %E 太大用於下層的型態 %<%T%>"
 
-#: c/c-decl.cc:10282
+#: c/c-decl.cc:10321
 #, fuzzy, gcc-internal-format
 msgid "enumerator value outside the range of %qs"
 msgstr "列舉值值 %E 太大用於下層的型態 %<%T%>"
 
-#: c/c-decl.cc:10288
+#: c/c-decl.cc:10327
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
 msgstr "ISO C 將列舉值限制在 %<int%> 範圍內"
 
-#: c/c-decl.cc:10489 cp/decl.cc:5981 cp/decl.cc:17800
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute %qs"
 msgstr "內聯函式 %qD 給定的屬性 noinline"
 
-#: c/c-decl.cc:10507
+#: c/c-decl.cc:10546
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "回傳不完全的類型"
 
-#: c/c-decl.cc:10519
+#: c/c-decl.cc:10558
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "回傳類型預設為 %<int%>"
 
-#: c/c-decl.cc:10547
+#: c/c-decl.cc:10586
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about global functions without prototypes"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "全域函式沒有原型時給出警告"
 
-#: c/c-decl.cc:10605
+#: c/c-decl.cc:10644
 #, fuzzy, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "沒有前一個原型用於 %qD"
 
-#: c/c-decl.cc:10614
+#: c/c-decl.cc:10653
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD 被使用不具任何原型之前它的定義"
 
-#: c/c-decl.cc:10632
+#: c/c-decl.cc:10671
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD 被使用不具任何宣告之前它的定義"
 
-#: c/c-decl.cc:10651
+#: c/c-decl.cc:10690
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "傳回類型的 %qD 不是 %<int%>"
 
-#: c/c-decl.cc:10653
+#: c/c-decl.cc:10692
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.cc:10660
+#: c/c-decl.cc:10699
 #, fuzzy, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD 是正常非靜態函式"
 
-#: c/c-decl.cc:10711
+#: c/c-decl.cc:10750
 #, fuzzy, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "舊式參數宣告在中原型的函式定義"
 
-#: c/c-decl.cc:10726
+#: c/c-decl.cc:10765
 #, fuzzy, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "傳統 C 拒絕 ISO C 樣式函式定義"
 
-#: c/c-decl.cc:10743
+#: c/c-decl.cc:10782
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
 msgstr "ISO C 不支援十進位浮點數"
 
-#: c/c-decl.cc:10783 c/c-decl.cc:10787
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, fuzzy, gcc-internal-format
 msgid "old-style function definition"
 msgstr "舊式函式定義"
 
-#: c/c-decl.cc:10800
+#: c/c-decl.cc:10839
 #, fuzzy, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "參數名稱缺少的從參數清單"
 
-#: c/c-decl.cc:10816
+#: c/c-decl.cc:10855
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD 宣告的做為 non-parameter"
 
-#: c/c-decl.cc:10824
+#: c/c-decl.cc:10863
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "多重參數具名的 %qD"
 
-#: c/c-decl.cc:10833
+#: c/c-decl.cc:10872
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "參數 %qD 宣告的與虛值型態"
 
-#: c/c-decl.cc:10862 c/c-decl.cc:10867
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
 #, fuzzy, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "型態的 %qD 預設值到 %<int%>"
 
-#: c/c-decl.cc:10887
+#: c/c-decl.cc:10926
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "參數 %qD 有不完整型態"
 
-#: c/c-decl.cc:10894
+#: c/c-decl.cc:10933
 #, fuzzy, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "宣告用於參數 %qD 但是沒有此類參數"
 
-#: c/c-decl.cc:10947
+#: c/c-decl.cc:10986
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "引數個數與內建原型不符"
 
-#: c/c-decl.cc:10958
+#: c/c-decl.cc:10997
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "引數數目與原型不符"
 
-#: c/c-decl.cc:10961 c/c-decl.cc:11008 c/c-decl.cc:11022
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
 #, fuzzy, gcc-internal-format
 msgid "prototype declaration"
 msgstr "原型宣告"
 
-#: c/c-decl.cc:11000
+#: c/c-decl.cc:11039
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "提升後的引數 %qD 與內建原型不符"
 
-#: c/c-decl.cc:11005
+#: c/c-decl.cc:11044
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "提升後的引數 %qD 與原型不符"
 
-#: c/c-decl.cc:11015
+#: c/c-decl.cc:11054
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "引數 %qD 與內建原型不符"
 
-#: c/c-decl.cc:11020
+#: c/c-decl.cc:11059
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "引數 %qD 與原型不符"
 
-#: c/c-decl.cc:11278 cp/decl.cc:18737
+#: c/c-decl.cc:11317 cp/decl.cc:18743
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "在有回傳值的函式中未發現 return 敘述"
 
-#: c/c-decl.cc:11297 cp/decl.cc:18808
+#: c/c-decl.cc:11336 cp/decl.cc:18814
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "參數 %qD 設定並不是使用"
 
-#: c/c-decl.cc:11394
+#: c/c-decl.cc:11433
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> 迴圈初始宣告是只有允許的在中 C99 模式"
 
-#: c/c-decl.cc:11399
+#: c/c-decl.cc:11438
 #, fuzzy, gcc-internal-format
 msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
 msgstr "使用選項 -std=c99 或 -std=gnu99 到編譯您的編碼"
 
-#: c/c-decl.cc:11406
+#: c/c-decl.cc:11445
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C90 does not support %<for%> loop initial declarations"
 msgstr "ISO C90 不支援 %<[*]%> 陣列宣告"
 
-#: c/c-decl.cc:11440
+#: c/c-decl.cc:11479
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "宣告的靜態變數 %qD 在中 %<for%> 迴圈初始宣告"
 
-#: c/c-decl.cc:11444
+#: c/c-decl.cc:11483
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "宣告的 %<extern%> 變數 %qD 在中 %<for%>迴圈初始宣告"
 
-#: c/c-decl.cc:11451
+#: c/c-decl.cc:11490
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> 宣告於 %<for%> 循環初始宣告中"
 
-#: c/c-decl.cc:11456
+#: c/c-decl.cc:11495
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> 宣告於 %<for%> 循環初始宣告中"
 
-#: c/c-decl.cc:11462
+#: c/c-decl.cc:11501
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> 宣告於 %<for%> 循環初始宣告中"
 
-#: c/c-decl.cc:11466
+#: c/c-decl.cc:11505
 #, fuzzy, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "宣告的 non-variable %qD 在中 %<for%> 迴圈初始宣告"
 
-#: c/c-decl.cc:11753
+#: c/c-decl.cc:11792
 #, fuzzy, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "不相容的位址空間限定元 %qs 和 %qs"
 
-#: c/c-decl.cc:11812 c/c-decl.cc:11819
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "需要指定宣告"
 
-#: c/c-decl.cc:11847 c/c-decl.cc:12925
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "宣告指定了多個存儲類別"
 
-#: c/c-decl.cc:11849
+#: c/c-decl.cc:11888
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qs used with %<auto%>"
@@ -48719,261 +48741,261 @@ msgstr "%<__thread%> 與 %<auto%> 一起使用"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:11854
+#: c/c-decl.cc:11893
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%<auto%> used with %<constexpr%>"
 msgstr "%<__thread%> 與 %<register%> 一起使用"
 
-#: c/c-decl.cc:11867 c/c-decl.cc:12267 c/c-decl.cc:12720
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "宣告指定了兩個以上的資料類型"
 
-#: c/c-decl.cc:11879 cp/parser.cc:34266
+#: c/c-decl.cc:11918 cp/parser.cc:34268
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> 對 GCC 來說太長了"
 
-#: c/c-decl.cc:11892
+#: c/c-decl.cc:11931
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 不支援 %<long long%>"
 
-#: c/c-decl.cc:12129 c/c-parser.cc:11619
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 不支援複數類型"
 
-#: c/c-decl.cc:12179
+#: c/c-decl.cc:12218
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C 不支援飽和類型"
 
-#: c/c-decl.cc:12254 c/c-decl.cc:12860 c/c-decl.cc:12919
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "重複的 %qE"
 
-#: c/c-decl.cc:12314
+#: c/c-decl.cc:12353
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C 不支援 %<__int128%>型態"
 
-#: c/c-decl.cc:12336
+#: c/c-decl.cc:12375
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int128%>未被支援用於這個目標"
 
-#: c/c-decl.cc:12379
+#: c/c-decl.cc:12418
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 不支援複數類型"
 
-#: c/c-decl.cc:12498
+#: c/c-decl.cc:12537
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
 msgstr "ISO C 不支援 %<__int128%>型態"
 
-#: c/c-decl.cc:12549 cp/parser.cc:20288
+#: c/c-decl.cc:12588 cp/parser.cc:20288
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<__int128%>未被支援用於這個目標"
 
-#: c/c-decl.cc:12620
+#: c/c-decl.cc:12659
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C23"
 msgstr "ISO C 不支援十進位浮點數"
 
-#: c/c-decl.cc:12644 c/c-decl.cc:13021 c/c-parser.cc:10626
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "定點類型不支援用於這個目標"
 
-#: c/c-decl.cc:12646
+#: c/c-decl.cc:12685
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C 不支援定點類型"
 
-#: c/c-decl.cc:12675
+#: c/c-decl.cc:12714
 #, fuzzy, gcc-internal-format
 msgid "%<_BitInt%> argument is not an integer constant expression"
 msgstr "大小寫標貼不是整數常數運算式"
 
-#: c/c-decl.cc:12681
+#: c/c-decl.cc:12720
 #, fuzzy, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
 msgstr "列舉值值用於 %qE 不是整數常數運算式"
 
-#: c/c-decl.cc:12688
+#: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
 msgstr ""
 
-#: c/c-decl.cc:12736
+#: c/c-decl.cc:12775
 #, fuzzy, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "C++查找的 %qD 會回傳欄位，不是型態"
 
-#: c/c-decl.cc:12749
+#: c/c-decl.cc:12788
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE 不是一個 typedef 類型，也不是一個內建類型"
 
-#: c/c-decl.cc:12804
+#: c/c-decl.cc:12843
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE 沒有出現在宣告的開頭"
 
 #. auto may only be used with another storage class specifier,
 #. such as constexpr, if the type is inferred.
-#: c/c-decl.cc:12825 c/c-decl.cc:12902
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> 與 %<auto%> 一起使用"
 
-#: c/c-decl.cc:12827
+#: c/c-decl.cc:12866
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> 與 %<register%> 一起使用"
 
-#: c/c-decl.cc:12829 c/c-decl.cc:12898
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> 與 %<typedef%> 一起使用"
 
-#: c/c-decl.cc:12831 c/c-decl.cc:12868
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<constexpr%>"
 msgstr "%<__thread%> 與 %<register%> 一起使用"
 
-#: c/c-decl.cc:12845 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 不支援 %qE"
 
-#: c/c-decl.cc:12848 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 不支援 %qE"
 
-#: c/c-decl.cc:12874
+#: c/c-decl.cc:12913
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> 出現在 %<extern%> 之前"
 
-#: c/c-decl.cc:12883
+#: c/c-decl.cc:12922
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> 出現在 %<static%> 之前"
 
-#: c/c-decl.cc:12889
+#: c/c-decl.cc:12928
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%<typedef%> used with %<auto%>"
 msgstr "%<__thread%> 與 %<auto%> 一起使用"
 
-#: c/c-decl.cc:12896
+#: c/c-decl.cc:12935
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<extern%>"
 msgstr "%<__thread%> 與 %<register%> 一起使用"
 
-#: c/c-decl.cc:12904
+#: c/c-decl.cc:12943
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %qs"
 msgstr "%qs 必須被使用與 %qs"
 
-#: c/c-decl.cc:12917
+#: c/c-decl.cc:12956
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.cc:12933
+#: c/c-decl.cc:12972
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs 必須被使用與 %qs"
 
-#: c/c-decl.cc:12941
+#: c/c-decl.cc:12980
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%<constexpr%> used with %qE"
 msgstr "%<__thread%> 與 %qE 一起使用"
 
-#: c/c-decl.cc:13018
+#: c/c-decl.cc:13057
 #, fuzzy, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%>被使用而無需 %<_Fract%>或 %<_Accum%>"
 
-#: c/c-decl.cc:13033
+#: c/c-decl.cc:13072
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支援單獨用 %<complex%> 表示 %<double complex%>"
 
-#: c/c-decl.cc:13044
+#: c/c-decl.cc:13083
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<[*]%> array declarators"
 msgid "ISO C does not support %<auto%> type deduction before C23"
 msgstr "ISO C90 不支援 %<[*]%> 陣列宣告"
 
-#: c/c-decl.cc:13073
+#: c/c-decl.cc:13112
 #, gcc-internal-format
 msgid "%<__auto_type%> followed by %<[[]]%> attributes"
 msgstr ""
 
-#: c/c-decl.cc:13099 c/c-decl.cc:13115 c/c-decl.cc:13141
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C 不支援複整數"
 
-#: c/c-decl.cc:13284
+#: c/c-decl.cc:13323
 #, fuzzy, gcc-internal-format
 #| msgid "Fixed line length must be at least seven."
 msgid "%<signed _BitInt%> argument must be at least 2"
 msgstr "固定格式的列長至少為七。"
 
-#: c/c-decl.cc:13293
+#: c/c-decl.cc:13332
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
 msgstr "ISO C++不支援 %<__int128%>用於 %qs"
 
-#: c/c-decl.cc:13592 cp/semantics.cc:6389
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.cc:13596 cp/semantics.cc:6393
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5736
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "左移次數為負"
 
-#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5744
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "左移次數為負"
 
-#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5683
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "右移次數為負"
 
-#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5752
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "左移次數大於或等於類型寬度"
 
-#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5694
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "右移次數大於或等於類型寬度"
@@ -49005,7 +49027,7 @@ msgstr ""
 msgid "to match this %qs"
 msgstr "沒有匹配用於 %qs 在中 %<%s %E%>"
 
-#: c/c-parser.cc:1409 cp/parser.cc:34503
+#: c/c-parser.cc:1409 cp/parser.cc:34505
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "預期的列尾"
@@ -49015,8 +49037,8 @@ msgstr "預期的列尾"
 msgid "ISO C forbids an empty translation unit"
 msgstr "ISO C 禁止清空轉譯單位"
 
-#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25405 cp/parser.cc:49093
-#: cp/semantics.cc:3633 cp/semantics.cc:3642
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
 #, gcc-internal-format
 msgid "%qs without corresponding %qs"
 msgstr ""
@@ -49057,9 +49079,9 @@ msgstr "不明型態名稱 %qE"
 msgid "unknown type name %qE"
 msgstr "不明型態名稱 %qE"
 
-#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23035
-#: c/c-parser.cc:23634 c/c-parser.cc:24220 cp/parser.cc:46431
-#: cp/parser.cc:51179
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "需要指定宣告"
@@ -49092,7 +49114,7 @@ msgstr "%q+D 不能有 section 屬性"
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "預期 %<;%>，識別碼或 %<(%>"
 
-#: c/c-parser.cc:2439 cp/parser.cc:36757 cp/parser.cc:36829
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "前綴屬性被忽略用於方法"
@@ -49113,7 +49135,7 @@ msgstr "未預期的屬性"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "%q+D 不能有 section 屬性"
 
-#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3647
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<assume%> attribute not followed by %<;%>"
@@ -49209,7 +49231,7 @@ msgstr "運算式在中靜態假設不是常數"
 msgid "static assertion failed: %E"
 msgstr "靜態假設失敗：%E"
 
-#: c/c-parser.cc:3164 cp/semantics.cc:11751
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
 #, fuzzy, gcc-internal-format
 msgid "static assertion failed"
 msgstr "靜態假設失敗：%E"
@@ -49284,10 +49306,10 @@ msgstr "範本參數 %d 無效"
 #: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
 #: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
 #: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
-#: c/c-parser.cc:21828 c/c-parser.cc:24698 c/c-parser.cc:24887
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
 #: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
-#: cp/parser.cc:34506 cp/parser.cc:37734 cp/parser.cc:40861 cp/parser.cc:41053
-#: cp/parser.cc:48026 cp/parser.cc:50445
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "需要識別碼"
@@ -49442,7 +49464,7 @@ msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause
 msgstr ""
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
-#: cp/parser.cc:48622
+#: cp/parser.cc:48620
 #, gcc-internal-format
 msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
 msgstr ""
@@ -49452,8 +49474,8 @@ msgstr ""
 msgid "OpenMP %<omp::decl%> attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25088 cp/parser.cc:12272
-#: cp/parser.cc:48602 cp/parser.cc:48742
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs attribute argument"
 msgstr ""
@@ -49630,12 +49652,12 @@ msgstr "ISO C 不允許省略 ?: 運算式中的第二項"
 
 #. Location of the binary operator.
 #. Quiet warning.
-#: c/c-parser.cc:9399 cp/typeck.cc:5515
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
 #, gcc-internal-format
 msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
 msgstr ""
 
-#: c/c-parser.cc:9405 cp/typeck.cc:5520
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
 #, fuzzy, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
 msgstr "型態的欄位宣告的在此"
@@ -49792,7 +49814,7 @@ msgstr "ISO C 不支援 %<__int128%>型態"
 
 #: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
 #: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
-#: cp/parser.cc:43085
+#: cp/parser.cc:43087
 #, gcc-internal-format
 msgid "expected expression"
 msgstr "需要運算式"
@@ -50119,12 +50141,12 @@ msgstr "objective-c 方法宣告被預期"
 msgid "no type or storage class may be specified here,"
 msgstr "沒有型態或貯藏類別也許會被指定的在此，"
 
-#: c/c-parser.cc:14137 cp/parser.cc:37591
+#: c/c-parser.cc:14137 cp/parser.cc:37593
 #, fuzzy, gcc-internal-format
 msgid "empty property attribute list"
 msgstr "不明內容屬性"
 
-#: c/c-parser.cc:14151 cp/parser.cc:37604
+#: c/c-parser.cc:14151 cp/parser.cc:37606
 #, fuzzy, gcc-internal-format
 #| msgid "missing Code attribute"
 msgid "missing property attribute"
@@ -50135,57 +50157,57 @@ msgstr "缺少 Code 屬性"
 msgid "unknown property attribute %<%s%s%>"
 msgstr "不明內容屬性"
 
-#: c/c-parser.cc:14193 cp/parser.cc:37641
+#: c/c-parser.cc:14193 cp/parser.cc:37643
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不明內容屬性"
 
-#: c/c-parser.cc:14202 cp/parser.cc:37650
+#: c/c-parser.cc:14202 cp/parser.cc:37652
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%> after Objective-C %qE"
 msgstr "重複 %<@%>之前 Objective-C 字串"
 
-#: c/c-parser.cc:14213 cp/parser.cc:37664
+#: c/c-parser.cc:14213 cp/parser.cc:37666
 #, fuzzy, gcc-internal-format
 msgid "expected %qE selector name"
 msgstr "預期 selection-statement"
 
-#: c/c-parser.cc:14229 cp/parser.cc:37683
+#: c/c-parser.cc:14229 cp/parser.cc:37685
 #, fuzzy, gcc-internal-format
 msgid "setter method names must terminate with %<:%>"
 msgstr "setter 名稱必須終止與 %<:%>"
 
-#: c/c-parser.cc:14453 cp/semantics.cc:13238
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
-#: c/c-parser.cc:14489 cp/parser.cc:50800
+#: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
 msgstr ""
 
-#: c/c-parser.cc:14509 c/c-parser.cc:23631 c/c-parser.cc:23940
-#: c/c-parser.cc:24003 c/c-parser.cc:24113 cp/parser.cc:46428
-#: cp/parser.cc:46776 cp/parser.cc:46891 cp/parser.cc:46990 cp/parser.cc:50821
-#: cp/parser.cc:50837 cp/parser.cc:50853 cp/parser.cc:50870 cp/parser.cc:50887
-#: cp/parser.cc:50904 cp/parser.cc:50931 cp/parser.cc:50945 cp/parser.cc:50970
-#: cp/parser.cc:50984
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<# pragma omp flush%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.cc:14532 cp/parser.cc:50959
+#: c/c-parser.cc:14532 cp/parser.cc:50957
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<# pragma GCC pchpreprocess%(_P)>必須是先"
 
-#: c/c-parser.cc:14622 cp/parser.cc:51083
+#: c/c-parser.cc:14622 cp/parser.cc:51081
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
 msgstr "%<# pragma omp section%>也許會只有被已用於 %<# pragma omp sections%>建構"
 
-#: c/c-parser.cc:14629 cp/parser.cc:51089
+#: c/c-parser.cc:14629 cp/parser.cc:51087
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<# pragma omp section%>也許會只有被已用於 %<# pragma omp sections%>建構"
@@ -50195,25 +50217,25 @@ msgstr "%<# pragma omp section%>也許會只有被已用於 %<# pragma omp secti
 msgid "%<#pragma %s%> may only be used at file scope"
 msgstr "%<# pragma GCC pchpreprocess%(_P)>必須是先"
 
-#: c/c-parser.cc:14724 cp/parser.cc:51166
+#: c/c-parser.cc:14724 cp/parser.cc:51164
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "用於敘述預期"
 
-#: c/c-parser.cc:14737 cp/parser.cc:50811
+#: c/c-parser.cc:14737 cp/parser.cc:50809
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<# pragma GCC pchpreprocess%(_P)>必須是先"
 
 #: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
 #: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
-#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25954
-#: c/c-parser.cc:25962 c/c-parser.cc:26232 c/c-parser.cc:26242
-#: c/c-parser.cc:26336 c/c-parser.cc:26343 c/c-parser.cc:26350
-#: cp/parser.cc:38114 cp/parser.cc:41693 cp/parser.cc:42611 cp/parser.cc:42648
-#: cp/parser.cc:42837 cp/parser.cc:42900 cp/parser.cc:42907 cp/parser.cc:42914
-#: cp/parser.cc:48245 cp/parser.cc:48252 cp/parser.cc:48259 cp/parser.cc:49706
-#: cp/parser.cc:49714 cp/parser.cc:49866 cp/parser.cc:49876
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "太多 %qs 子句"
@@ -50228,63 +50250,63 @@ msgstr "numthreads 運算式必須是積分(_T)"
 msgid "expected %<)%> or %<,%>"
 msgstr "預期 %<,%>或 %<)%>"
 
-#: c/c-parser.cc:15746 c/c-parser.cc:26638
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable"
 msgstr "%qD 並非變數"
 
-#: c/c-parser.cc:15750 cp/semantics.cc:8614
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD 並非變數"
 
-#: c/c-parser.cc:15792 cp/parser.cc:38995
+#: c/c-parser.cc:15792 cp/parser.cc:38997
 #, fuzzy, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.cc:15887 cp/parser.cc:39073
+#: c/c-parser.cc:15887 cp/parser.cc:39075
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "預期 %<none%> 或 %<shared%>"
 
-#: c/c-parser.cc:15889 cp/parser.cc:39075
+#: c/c-parser.cc:15889 cp/parser.cc:39077
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr "預期 %<# pragma omp section%>或 %<}%>"
 
-#: c/c-parser.cc:15974 cp/parser.cc:39145
+#: c/c-parser.cc:15974 cp/parser.cc:39147
 #, fuzzy, gcc-internal-format
 msgid "expected constant logical expression"
 msgstr "預期的整數運算式"
 
-#: c/c-parser.cc:16051 cp/parser.cc:39227
+#: c/c-parser.cc:16051 cp/parser.cc:39229
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
-#: c/c-parser.cc:16071 c/c-parser.cc:23996 c/c-parser.cc:24106
-#: cp/parser.cc:39245 cp/parser.cc:46768 cp/parser.cc:46883
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "預期 %<catch%>"
 
-#: c/c-parser.cc:16124 cp/parser.cc:39300
+#: c/c-parser.cc:16124 cp/parser.cc:39302
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.cc:16131 cp/parser.cc:39307
+#: c/c-parser.cc:16131 cp/parser.cc:39309
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.cc:16133 cp/parser.cc:39309
+#: c/c-parser.cc:16133 cp/parser.cc:39311
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.cc:16139 cp/parser.cc:39315
+#: c/c-parser.cc:16139 cp/parser.cc:39317
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -50307,22 +50329,22 @@ msgstr "%<num_threads%> 值必須是正值"
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.cc:16378 cp/semantics.cc:8828
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.cc:16427 cp/semantics.cc:8858
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "『%s』於 %L 必須是 nonnegative"
 
-#: c/c-parser.cc:16461 cp/parser.cc:39541
+#: c/c-parser.cc:16461 cp/parser.cc:39543
 #, fuzzy, gcc-internal-format
 msgid "expected constant integer expression with valid sync-hint value"
 msgstr "預期的整數運算式"
 
-#: c/c-parser.cc:16533 cp/parser.cc:39611
+#: c/c-parser.cc:16533 cp/parser.cc:39613
 #, fuzzy, gcc-internal-format
 msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
 msgstr "預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>"
@@ -50332,95 +50354,95 @@ msgstr "預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: c/c-parser.cc:16678 cp/parser.cc:39763
+#: c/c-parser.cc:16678 cp/parser.cc:39765
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with %qs category"
 msgstr ""
 
-#: c/c-parser.cc:16681 cp/parser.cc:39766
+#: c/c-parser.cc:16681 cp/parser.cc:39768
 #, gcc-internal-format
 msgid "too many %<defaultmap%> clauses with unspecified category"
 msgstr ""
 
-#: c/c-parser.cc:16765 cp/semantics.cc:7685 cp/semantics.cc:7740
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7719
-#: cp/semantics.cc:7754
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.cc:16839 cp/parser.cc:38767
+#: c/c-parser.cc:16839 cp/parser.cc:38769
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "太多引數"
 
-#: c/c-parser.cc:16873 cp/parser.cc:38800
+#: c/c-parser.cc:16873 cp/parser.cc:38802
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "未預期的屬性"
 
-#: c/c-parser.cc:17040 cp/semantics.cc:9045
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE 屬性引數不是整數常數"
 
-#: c/c-parser.cc:17108 cp/parser.cc:41874
+#: c/c-parser.cc:17108 cp/parser.cc:41876
 #, fuzzy, gcc-internal-format
 msgid "too many %<self%> clauses"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.cc:17150 cp/parser.cc:39816
+#: c/c-parser.cc:17150 cp/parser.cc:39818
 #, fuzzy, gcc-internal-format
 msgid "expected %<reproducible%> or %<unconstrained%>"
 msgstr "預期 %<none%> 或 %<shared%>"
 
-#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39825
-#: cp/parser.cc:39835
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
 #, fuzzy, gcc-internal-format
 msgid "expected %<concurrent%>"
 msgstr "預期 %<using%>"
 
-#: c/c-parser.cc:17201 cp/parser.cc:39875
+#: c/c-parser.cc:17201 cp/parser.cc:39877
 #, fuzzy, gcc-internal-format
 msgid "expected %<teams%>, %<parallel%> or %<thread%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: c/c-parser.cc:17254 cp/parser.cc:39943
+#: c/c-parser.cc:17254 cp/parser.cc:39945
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.cc:17379 c/c-parser.cc:25505 cp/parser.cc:49347
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>"
 
-#: c/c-parser.cc:17501 cp/parser.cc:40201
+#: c/c-parser.cc:17501 cp/parser.cc:40203
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "宣告中同時使用了 %<long%> 和 %<void%>"
 
-#: c/c-parser.cc:17555 cp/parser.cc:40217
+#: c/c-parser.cc:17555 cp/parser.cc:40219
 #, fuzzy, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "排程 %<runtime%> 不需 %<chunksize%(_S)>參數"
 
-#: c/c-parser.cc:17559 cp/parser.cc:40220
+#: c/c-parser.cc:17559 cp/parser.cc:40222
 #, fuzzy, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "排程 %<auto%> 不需 %<chunksize%(_S)>參數"
 
-#: c/c-parser.cc:17572 cp/semantics.cc:7801
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.cc:17595 cp/parser.cc:40240
+#: c/c-parser.cc:17595 cp/parser.cc:40242
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "無效的排程 kind"
@@ -50430,22 +50452,22 @@ msgstr "無效的排程 kind"
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.cc:17753 cp/semantics.cc:7768
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
 #, gcc-internal-format
 msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
 msgstr ""
 
-#: c/c-parser.cc:17802 cp/semantics.cc:7897
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.cc:17847 cp/semantics.cc:8025
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42603
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
 #, fuzzy, gcc-internal-format
 msgid "expected %<allocator%> or %<align%>"
 msgstr "預期 %<,%>或 %<)%>"
@@ -50456,23 +50478,23 @@ msgstr "預期 %<,%>或 %<)%>"
 msgid "duplicate %qs modifier"
 msgstr "重複的 %qs"
 
-#: c/c-parser.cc:18014 cp/semantics.cc:8160
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
 #, gcc-internal-format
 msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:18025 cp/semantics.cc:8115 cp/semantics.cc:8131
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
 #, fuzzy, gcc-internal-format
 msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.cc:18144 cp/parser.cc:40687
+#: c/c-parser.cc:18144 cp/parser.cc:40689
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple linear modifiers"
 msgstr "重複的 cv 限定"
 
-#: c/c-parser.cc:18156 cp/parser.cc:40700
+#: c/c-parser.cc:18156 cp/parser.cc:40702
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple %<step%> modifiers"
@@ -50493,64 +50515,64 @@ msgstr "崩潰引數需要正面的常數整數運算式"
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.cc:18643 cp/parser.cc:41247
+#: c/c-parser.cc:18643 cp/parser.cc:41249
 #, fuzzy, gcc-internal-format
 msgid "%<iterator%> modifier incompatible with %qs"
 msgstr "%qs 是不相容的與 %qs"
 
-#: c/c-parser.cc:18691 cp/parser.cc:41302 cp/parser.cc:41754 cp/parser.cc:41804
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "無效的排程 kind"
 
-#: c/c-parser.cc:18752 cp/parser.cc:41332
+#: c/c-parser.cc:18752 cp/parser.cc:41334
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid doacross kind"
 msgstr "無效遮罩"
 
-#: c/c-parser.cc:18821 cp/parser.cc:41475
+#: c/c-parser.cc:18821 cp/parser.cc:41477
 #, fuzzy, gcc-internal-format
 msgid "too many %<always%> modifiers"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.cc:18831 cp/parser.cc:41488
+#: c/c-parser.cc:18831 cp/parser.cc:41490
 #, fuzzy, gcc-internal-format
 msgid "too many %<close%> modifiers"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.cc:18841 cp/parser.cc:41501
+#: c/c-parser.cc:18841 cp/parser.cc:41503
 #, fuzzy, gcc-internal-format
 msgid "too many %<present%> modifiers"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.cc:18849 cp/parser.cc:41512
+#: c/c-parser.cc:18849 cp/parser.cc:41514
 #, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.cc:18887 cp/parser.cc:41552
+#: c/c-parser.cc:18887 cp/parser.cc:41554
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "無效遮罩"
 
-#: c/c-parser.cc:18939 cp/parser.cc:41616
+#: c/c-parser.cc:18939 cp/parser.cc:41618
 #, gcc-internal-format
 msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
 msgstr ""
 
-#: c/c-parser.cc:18951 cp/parser.cc:41627
+#: c/c-parser.cc:18951 cp/parser.cc:41629
 #, fuzzy, gcc-internal-format
 msgid "expected %<ancestor%> or %<device_num%>"
 msgstr "預期 %<none%> 或 %<shared%>"
 
-#: c/c-parser.cc:18974 cp/semantics.cc:7922
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
 #, fuzzy, gcc-internal-format
 msgid "the %<device%> clause expression must evaluate to %<1%>"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: c/c-parser.cc:19007 cp/parser.cc:41698
+#: c/c-parser.cc:19007 cp/parser.cc:41700
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "無效的排程 kind"
@@ -50565,90 +50587,90 @@ msgstr "無效的排程 kind"
 msgid "expected %<host%>, %<nohost%> or %<any%>"
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
-#: c/c-parser.cc:19228 cp/semantics.cc:8341
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
 #, gcc-internal-format
 msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
 msgstr ""
 
-#: c/c-parser.cc:19440 cp/parser.cc:42090
+#: c/c-parser.cc:19440 cp/parser.cc:42092
 #, fuzzy, gcc-internal-format
 msgid "expected an OpenACC clause"
 msgstr "預期的指標"
 
-#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42101
-#: cp/parser.cc:42509
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs 無效用於 %qs"
 
-#: c/c-parser.cc:19496 cp/parser.cc:42149
+#: c/c-parser.cc:19496 cp/parser.cc:42151
 #, gcc-internal-format
 msgid "clauses in %<simd%> trait should be separated by %<,%>"
 msgstr ""
 
-#: c/c-parser.cc:19649 cp/parser.cc:42342
+#: c/c-parser.cc:19649 cp/parser.cc:42344
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs 必須被使用與 %qs"
 
-#: c/c-parser.cc:19805 cp/parser.cc:42498
+#: c/c-parser.cc:19805 cp/parser.cc:42500
 #, fuzzy, gcc-internal-format
 msgid "expected an OpenMP clause"
 msgstr "預期的指標"
 
-#: c/c-parser.cc:19964 cp/parser.cc:47351
+#: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:19974 cp/parser.cc:47361
+#: c/c-parser.cc:19974 cp/parser.cc:47359
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "陣列區段在中『%s』呼叫於 %L"
 
-#: c/c-parser.cc:19994 cp/parser.cc:47381
+#: c/c-parser.cc:19994 cp/parser.cc:47379
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.cc:20005 cp/parser.cc:47392
+#: c/c-parser.cc:20005 cp/parser.cc:47390
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "無效的輸入宣告"
 
-#: c/c-parser.cc:20012 cp/parser.cc:47399
+#: c/c-parser.cc:20012 cp/parser.cc:47397
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "宣告的 %<extern%> 變數 %qD 在中 %<for%>迴圈初始宣告"
 
-#: c/c-parser.cc:20020 cp/parser.cc:47407
+#: c/c-parser.cc:20020 cp/parser.cc:47405
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "對於 bool 變數 %qD 使用 %<--%> 無效"
 
-#: c/c-parser.cc:20031 cp/parser.cc:47429
+#: c/c-parser.cc:20031 cp/parser.cc:47427
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
 msgstr "對於 bool 變數 %qD 使用 %<--%> 無效"
 
-#: c/c-parser.cc:20041 cp/parser.cc:47452
+#: c/c-parser.cc:20041 cp/parser.cc:47450
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.cc:20134 cp/parser.cc:47536
+#: c/c-parser.cc:20134 cp/parser.cc:47534
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "預期的字串之後 %<# pragma message%>"
 
-#: c/c-parser.cc:20150 cp/parser.cc:47553
+#: c/c-parser.cc:20150 cp/parser.cc:47551
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
 
-#: c/c-parser.cc:20182 cp/parser.cc:47311
+#: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
 msgstr ""
@@ -50663,7 +50685,7 @@ msgstr "%qE 未被宣告"
 msgid "expected function name"
 msgstr "預期的函式"
 
-#: c/c-parser.cc:20433 cp/parser.cc:50133
+#: c/c-parser.cc:20433 cp/parser.cc:50131
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a function"
@@ -50674,22 +50696,22 @@ msgstr "%qD 不是一個成員範本函式"
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:20496 cp/parser.cc:50184 cp/parser.cc:50231
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.cc:20527 cp/parser.cc:50259
+#: c/c-parser.cc:20527 cp/parser.cc:50257
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.cc:20528 cp/parser.cc:50261
+#: c/c-parser.cc:20528 cp/parser.cc:50259
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 
-#: c/c-parser.cc:20573 cp/parser.cc:47769
+#: c/c-parser.cc:20573 cp/parser.cc:47767
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
@@ -50715,7 +50737,7 @@ msgstr ""
 msgid "modified here"
 msgstr "聯合定義的在此"
 
-#: c/c-parser.cc:20724 cp/parser.cc:42623 cp/parser.cc:42638
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, fuzzy, gcc-internal-format
 msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
@@ -50755,111 +50777,111 @@ msgstr ""
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
 msgstr ""
 
-#: c/c-parser.cc:20949 cp/parser.cc:42803
+#: c/c-parser.cc:20949 cp/parser.cc:42805
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
-#: c/c-parser.cc:20988 cp/parser.cc:42842
+#: c/c-parser.cc:20988 cp/parser.cc:42844
 #, fuzzy, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: c/c-parser.cc:21012 cp/parser.cc:42871
+#: c/c-parser.cc:21012 cp/parser.cc:42873
 #, fuzzy, gcc-internal-format
 msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
 msgstr "預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>"
 
-#: c/c-parser.cc:21027 cp/parser.cc:42886
+#: c/c-parser.cc:21027 cp/parser.cc:42888
 #, fuzzy, gcc-internal-format
 msgid "too many atomic clauses"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.cc:21034 cp/parser.cc:42893
+#: c/c-parser.cc:21034 cp/parser.cc:42895
 #, fuzzy, gcc-internal-format
 msgid "too many memory order clauses"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42931
-#: cp/parser.cc:42938
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
 #, fuzzy, gcc-internal-format
 msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
 msgstr "%qE 有無效的型態用於 %<reduction%>"
 
-#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42944
-#: cp/parser.cc:42949
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs clause requires %qs clause"
 msgstr "%qT 做為 %qs 被參照"
 
-#: c/c-parser.cc:21113 cp/parser.cc:42972
+#: c/c-parser.cc:21113 cp/parser.cc:42974
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21124 cp/parser.cc:42983
+#: c/c-parser.cc:21124 cp/parser.cc:42985
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
 msgstr ""
 
-#: c/c-parser.cc:21156 cp/parser.cc:43015
+#: c/c-parser.cc:21156 cp/parser.cc:43017
 #, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21166 cp/parser.cc:43025
+#: c/c-parser.cc:21166 cp/parser.cc:43027
 #, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
 msgstr ""
 
-#: c/c-parser.cc:21289 cp/parser.cc:43125
+#: c/c-parser.cc:21289 cp/parser.cc:43127
 #, fuzzy, gcc-internal-format
 msgid "expected %<==%> comparison in %<if%> condition"
 msgstr "預期 %<;%>之後聯合定義"
 
-#: c/c-parser.cc:21296 cp/parser.cc:43132
+#: c/c-parser.cc:21296 cp/parser.cc:43134
 #, gcc-internal-format
 msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
 msgstr ""
 
-#: c/c-parser.cc:21369 cp/parser.cc:43197 cp/parser.cc:43480 cp/parser.cc:43574
-#: cp/parser.cc:43592
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic compare%>"
 msgstr "無效的表單的 %<# pragma omp atomic%>"
 
-#: c/c-parser.cc:21380 cp/parser.cc:43208
+#: c/c-parser.cc:21380 cp/parser.cc:43210
 #, fuzzy, gcc-internal-format
 msgid "unexpected %<else%>"
 msgstr "預期 %<delete%>"
 
-#: c/c-parser.cc:21440 cp/parser.cc:43647
+#: c/c-parser.cc:21440 cp/parser.cc:43649
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<pragma omp atomic compare%>"
 msgstr "無效的表單的 %<# pragma omp atomic%>"
 
-#: c/c-parser.cc:21711 cp/parser.cc:43501 cp/parser.cc:43527
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "無效的表單的 %<# pragma omp atomic%>"
 
-#: c/c-parser.cc:21715 cp/parser.cc:43567 cp/parser.cc:43601
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "無效的運算子用於 %<# pragma omp atomic%>"
 
-#: c/c-parser.cc:21766 cp/parser.cc:43636
+#: c/c-parser.cc:21766 cp/parser.cc:43638
 #, gcc-internal-format
 msgid "%<weak%> clause requires atomic equality comparison"
 msgstr ""
 
-#: c/c-parser.cc:21772 cp/semantics.cc:11233 cp/semantics.cc:11243
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用兩不同的變數用於記憶體"
 
-#: c/c-parser.cc:21875 cp/semantics.cc:11320
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
 #, fuzzy, gcc-internal-format
 msgid "%<depobj%> expression is not lvalue expression"
 msgstr "運算式 %qE 並非 constant-expression"
@@ -50869,28 +50891,28 @@ msgstr "運算式 %qE 並非 constant-expression"
 msgid "%<destroy%> expression is not lvalue expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: c/c-parser.cc:21924 cp/parser.cc:43789
+#: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
 msgstr ""
 
-#: c/c-parser.cc:21955 cp/parser.cc:43825
+#: c/c-parser.cc:21955 cp/parser.cc:43827
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>, %<,%>, %<;%>, %<}%> or %<__attribute__%>"
 msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
 msgstr "需要 %<:%>，%<,%>，%<;%>，%<}%> 或 %<__attribute__%>"
 
-#: c/c-parser.cc:21967 cp/parser.cc:43841
+#: c/c-parser.cc:21967 cp/parser.cc:43843
 #, fuzzy, gcc-internal-format
 msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
-#: c/c-parser.cc:22008 cp/parser.cc:43879
+#: c/c-parser.cc:22008 cp/parser.cc:43881
 #, fuzzy, gcc-internal-format
 msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: c/c-parser.cc:22016 cp/parser.cc:43887
+#: c/c-parser.cc:22016 cp/parser.cc:43889
 #, gcc-internal-format
 msgid "%<flush%> list specified together with memory order clause"
 msgstr ""
@@ -50900,165 +50922,165 @@ msgstr ""
 msgid "expected %<(%> or end of line"
 msgstr "預期 %<(%>或列尾"
 
-#: c/c-parser.cc:22092 cp/parser.cc:44593
+#: c/c-parser.cc:22092 cp/parser.cc:44595
 #, gcc-internal-format
 msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
 msgstr ""
 
-#: c/c-parser.cc:22159 cp/parser.cc:44662
+#: c/c-parser.cc:22159 cp/parser.cc:44664
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
 msgstr "%<# pragma omp taskwait%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.cc:22193 cp/parser.cc:44695
+#: c/c-parser.cc:22193 cp/parser.cc:44697
 #, fuzzy, gcc-internal-format
 msgid "expected %<inclusive%> or %<exclusive%> clause"
 msgstr "預期 %<none%> 或 %<shared%>"
 
-#: c/c-parser.cc:22198 cp/parser.cc:44701
+#: c/c-parser.cc:22198 cp/parser.cc:44703
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp scan%>"
 msgstr "預期 %<# pragma omp%>子句"
 
-#: c/c-parser.cc:22207 cp/parser.cc:44710
+#: c/c-parser.cc:22207 cp/parser.cc:44712
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
 msgstr "%<# pragma omp taskwait%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.cc:22325 cp/semantics.cc:10807 cp/semantics.cc:10892
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "預期的迭代宣告或初始化"
 
-#: c/c-parser.cc:22413 c/c-parser.cc:22428 cp/parser.cc:45057
-#: cp/parser.cc:45072
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
 #, fuzzy, gcc-internal-format
 msgid "not enough nested loops"
 msgstr "不足 perfectly 巢狀的迴圈"
 
-#: c/c-parser.cc:22528 cp/parser.cc:45344
+#: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.cc:22539 cp/parser.cc:45355
+#: c/c-parser.cc:22537 cp/parser.cc:45353
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "用於敘述預期"
 
-#: c/c-parser.cc:22651 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18143
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "迭代變數 %qD 不應為 firstprivate"
 
-#: c/c-parser.cc:23059 cp/parser.cc:45866
+#: c/c-parser.cc:23057 cp/parser.cc:45864
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
 msgstr "%<# pragma omp barrier%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.cc:23275 cp/parser.cc:46072
+#: c/c-parser.cc:23273 cp/parser.cc:46070
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "預期 %<operator%>"
 
-#: c/c-parser.cc:23622 cp/parser.cc:46419
+#: c/c-parser.cc:23620 cp/parser.cc:46417
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "預期 %<using%>"
 
-#: c/c-parser.cc:23889 cp/parser.cc:46706
+#: c/c-parser.cc:23887 cp/parser.cc:46704
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23905 cp/parser.cc:46722
+#: c/c-parser.cc:23903 cp/parser.cc:46720
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
 msgstr ""
 
-#: c/c-parser.cc:23953 cp/parser.cc:47003
+#: c/c-parser.cc:23951 cp/parser.cc:47001
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:24055 cp/parser.cc:46829
+#: c/c-parser.cc:24053 cp/parser.cc:46827
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24067 cp/parser.cc:46841
+#: c/c-parser.cc:24065 cp/parser.cc:46839
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24166 cp/parser.cc:46946
+#: c/c-parser.cc:24164 cp/parser.cc:46944
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24179 cp/parser.cc:46959
+#: c/c-parser.cc:24177 cp/parser.cc:46957
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24424 cp/semantics.cc:10315
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.cc:24481
+#: c/c-parser.cc:24479
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 
-#: c/c-parser.cc:24532 c/c-parser.cc:24570
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 
-#: c/c-parser.cc:24603 cp/parser.cc:47913
+#: c/c-parser.cc:24601 cp/parser.cc:47911
 #, fuzzy, gcc-internal-format
 msgid "expected trait selector name"
 msgstr "預期 selection-statement"
 
-#: c/c-parser.cc:24615 cp/parser.cc:47927
+#: c/c-parser.cc:24613 cp/parser.cc:47925
 #, fuzzy, gcc-internal-format
 msgid "unknown selector %qs for context selector set %qs"
 msgstr "不明運算子 %qs 在中 %%:version-compare"
 
-#: c/c-parser.cc:24643 cp/parser.cc:47956
+#: c/c-parser.cc:24641 cp/parser.cc:47954
 #, fuzzy, gcc-internal-format
 msgid "selector %qs does not accept any properties"
 msgstr "%s 只有接受 2 引數"
 
-#: c/c-parser.cc:24665 cp/parser.cc:47988
+#: c/c-parser.cc:24663 cp/parser.cc:47986
 #, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
 msgstr "%<friend%> 只能在類別中指定"
 
-#: c/c-parser.cc:24674 cp/parser.cc:47998
+#: c/c-parser.cc:24672 cp/parser.cc:47996
 #, fuzzy, gcc-internal-format
 msgid "%<score%> argument must be constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.cc:24677 cp/parser.cc:48001
+#: c/c-parser.cc:24675 cp/parser.cc:47999
 #, fuzzy, gcc-internal-format
 msgid "%<score%> argument must be non-negative"
 msgstr "『%s』於 %L 必須是 nonnegative"
 
-#: c/c-parser.cc:24718 cp/parser.cc:48047
+#: c/c-parser.cc:24716 cp/parser.cc:48045
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected identifier or string literal"
 msgstr "需要字面字串"
 
-#: c/c-parser.cc:24743 cp/parser.cc:48072 cp/pt.cc:12036
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression"
 msgstr "預期的整數運算式"
 
-#: c/c-parser.cc:24757 cp/parser.cc:48086
+#: c/c-parser.cc:24755 cp/parser.cc:48084
 #, fuzzy, gcc-internal-format
 msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
 msgstr "內容 %qs 已經指定的在中 %<@synthesize%>"
@@ -51066,292 +51088,292 @@ msgstr "內容 %qs 已經指定的在中 %<@synthesize%>"
 #. FIXME: The "requires" selector was added in OpenMP 5.1.
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
-#: c/c-parser.cc:24778 cp/parser.cc:48102 fortran/openmp.cc:5921
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%<requires%> selector is not supported yet"
 msgstr "尚未支援程式碼模式 %<large%>"
 
-#: c/c-parser.cc:24837 cp/parser.cc:48165
+#: c/c-parser.cc:24835 cp/parser.cc:48163
 #, fuzzy, gcc-internal-format
 msgid "expected context selector set name"
 msgstr "預期 selection-statement"
 
-#: c/c-parser.cc:24914 cp/parser.cc:48480
+#: c/c-parser.cc:24912 cp/parser.cc:48478
 #, fuzzy, gcc-internal-format
 msgid "expected %<match%>"
 msgstr "預期 %<catch%>"
 
-#: c/c-parser.cc:24934
+#: c/c-parser.cc:24932
 #, fuzzy, gcc-internal-format
 msgid "variant %qD is not a function"
 msgstr "『%s』於 %L 並非函式"
 
-#: c/c-parser.cc:24941 cp/decl.cc:8314
+#: c/c-parser.cc:24939 cp/decl.cc:8323
 #, fuzzy, gcc-internal-format
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "variant %qD and base %qD have incompatible types"
 msgstr "-f%s 和 -msdata=%s 互不相容"
 
-#: c/c-parser.cc:24953 cp/decl.cc:8323
+#: c/c-parser.cc:24951 cp/decl.cc:8332
 #, gcc-internal-format
 msgid "variant %qD is a built-in"
 msgstr ""
 
-#: c/c-parser.cc:24999
+#: c/c-parser.cc:24997
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 
-#: c/c-parser.cc:25007 cp/parser.cc:48525
+#: c/c-parser.cc:25005 cp/parser.cc:48523
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 
-#: c/c-parser.cc:25208 cp/parser.cc:48815
+#: c/c-parser.cc:25206 cp/parser.cc:48813
 #, fuzzy, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %qs clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-parser.cc:25212 cp/parser.cc:48819
+#: c/c-parser.cc:25210 cp/parser.cc:48817
 #, fuzzy, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
 msgstr "%qE 有無效的型態用於 %<reduction%>"
 
-#: c/c-parser.cc:25272 cp/parser.cc:48949
+#: c/c-parser.cc:25270 cp/parser.cc:48947
 #, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:25275 cp/parser.cc:48952
+#: c/c-parser.cc:25273 cp/parser.cc:48950
 #, gcc-internal-format
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25324 c/c-parser.cc:25366 cp/parser.cc:49007
-#: cp/parser.cc:49054
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "預期 %<try%>"
 
-#: c/c-parser.cc:25338 cp/parser.cc:49020
+#: c/c-parser.cc:25336 cp/parser.cc:49018
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare target%> or %<assumes%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: c/c-parser.cc:25373 cp/parser.cc:49061
+#: c/c-parser.cc:25371 cp/parser.cc:49059
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
 msgstr "%<# pragma GCC pop_options%>而無需相應 %<# pragma GCC push_options%>"
 
-#: c/c-parser.cc:25384 c/c-parser.cc:25415 cp/parser.cc:49072
-#: cp/parser.cc:49103
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
 #, gcc-internal-format
 msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
 msgstr ""
 
-#: c/c-parser.cc:25391 c/c-parser.cc:25420 cp/parser.cc:49079
-#: cp/parser.cc:49108
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
 #, fuzzy, gcc-internal-format
 msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
 msgstr "%s 屬性與 %s 屬性在 %L 處衝突"
 
-#: c/c-parser.cc:25428 cp/parser.cc:49116
+#: c/c-parser.cc:25426 cp/parser.cc:49114
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%> or %<assumes%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: c/c-parser.cc:25455
+#: c/c-parser.cc:25453
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
 msgstr "模板宣告無法出現於區塊範圍"
 
-#: c/c-parser.cc:25532
+#: c/c-parser.cc:25530
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25536
+#: c/c-parser.cc:25534
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25539
+#: c/c-parser.cc:25537
 #, gcc-internal-format
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25542
+#: c/c-parser.cc:25540
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: c/c-parser.cc:25550
+#: c/c-parser.cc:25548
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
 msgstr ""
 
-#: c/c-parser.cc:25559
+#: c/c-parser.cc:25557
 #, fuzzy, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
 msgstr "前一個宣告"
 
-#: c/c-parser.cc:25680
+#: c/c-parser.cc:25678
 #, fuzzy, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
 msgstr "預期 %<(%>或列尾"
 
-#: c/c-parser.cc:25691
+#: c/c-parser.cc:25689
 #, fuzzy, gcc-internal-format
 msgid "expected function-name %<(%>"
 msgstr "預期的函式"
 
-#: c/c-parser.cc:25710
+#: c/c-parser.cc:25708
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.cc:25841 cp/parser.cc:49589
+#: c/c-parser.cc:25839 cp/parser.cc:49587
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "預期 %<# pragma omp section%>或 %<}%>"
 
-#: c/c-parser.cc:25910 cp/parser.cc:49656
+#: c/c-parser.cc:25908 cp/parser.cc:49654
 #, fuzzy, gcc-internal-format
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: c/c-parser.cc:25939 cp/parser.cc:49691
+#: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
 msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
 msgstr ""
 
-#: c/c-parser.cc:25957 cp/parser.cc:49709
+#: c/c-parser.cc:25955 cp/parser.cc:49707
 #, gcc-internal-format
 msgid "%qs clause used lexically after first target construct or offloading API"
 msgstr ""
 
-#: c/c-parser.cc:25969 cp/parser.cc:49721
+#: c/c-parser.cc:25967 cp/parser.cc:49719
 #, gcc-internal-format
 msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
 msgstr ""
 
-#: c/c-parser.cc:25978 cp/parser.cc:49730
+#: c/c-parser.cc:25976 cp/parser.cc:49728
 #, gcc-internal-format
 msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
 msgstr ""
 
-#: c/c-parser.cc:25992 cp/parser.cc:49744
+#: c/c-parser.cc:25990 cp/parser.cc:49742
 #, gcc-internal-format
 msgid "%<pragma omp requires%> requires at least one clause"
 msgstr ""
 
-#: c/c-parser.cc:26011
+#: c/c-parser.cc:26009
 #, gcc-internal-format
 msgid "zero sized type %qT in %<reduction%> clause"
 msgstr ""
 
-#: c/c-parser.cc:26017
+#: c/c-parser.cc:26015
 #, fuzzy, gcc-internal-format
 msgid "variable sized type %qT in %<reduction%> clause"
 msgstr "%qE 有無效的型態用於 %<reduction%>"
 
-#: c/c-parser.cc:26174 cp/parser.cc:49801
+#: c/c-parser.cc:26172 cp/parser.cc:49799
 #, fuzzy, gcc-internal-format
 msgid "expected %<at%>, %<severity%> or %<message%> clause"
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
-#: c/c-parser.cc:26207 cp/parser.cc:49836
+#: c/c-parser.cc:26205 cp/parser.cc:49834
 #, fuzzy, gcc-internal-format
 msgid "expected %qs or %qs"
 msgstr "預期 %<,%>或 %<)%>"
 
-#: c/c-parser.cc:26264 cp/parser.cc:49898
+#: c/c-parser.cc:26262 cp/parser.cc:49896
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
 msgstr "%<# pragma omp barrier%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.cc:26287 cp/parser.cc:49925
+#: c/c-parser.cc:26285 cp/parser.cc:49923
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered: %s"
 msgstr ""
 
-#: c/c-parser.cc:26290 cp/parser.cc:49928
+#: c/c-parser.cc:26288 cp/parser.cc:49926
 #, gcc-internal-format
 msgid "%<pragma omp error%> encountered"
 msgstr ""
 
-#: c/c-parser.cc:26317 cp/parser.cc:48226
+#: c/c-parser.cc:26315 cp/parser.cc:48224
 #, fuzzy, gcc-internal-format
 msgid "expected at least one assumption clause"
 msgstr "Cray 指標『%s』在中 %s 子句於 %L"
 
-#: c/c-parser.cc:26403 cp/parser.cc:48312
+#: c/c-parser.cc:26401 cp/parser.cc:48310
 #, fuzzy, gcc-internal-format
 msgid "expected directive name"
 msgstr "預期的函式"
 
-#: c/c-parser.cc:26416 cp/parser.cc:48325
+#: c/c-parser.cc:26414 cp/parser.cc:48323
 #, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs clause argument"
 msgstr ""
 
-#: c/c-parser.cc:26423 cp/parser.cc:48332
+#: c/c-parser.cc:26421 cp/parser.cc:48330
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
 msgstr ""
 
-#: c/c-parser.cc:26434 cp/parser.cc:48343
+#: c/c-parser.cc:26432 cp/parser.cc:48341
 #, gcc-internal-format
 msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
 msgstr ""
 
-#: c/c-parser.cc:26457 cp/parser.cc:48370
+#: c/c-parser.cc:26455 cp/parser.cc:48368
 #, fuzzy, gcc-internal-format
 msgid "unknown assumption clause %qs"
 msgstr "不明 spec 函式 %qs"
 
-#: c/c-parser.cc:26470 cp/parser.cc:48380
+#: c/c-parser.cc:26468 cp/parser.cc:48378
 #, fuzzy, gcc-internal-format
 msgid "expected assumption clause"
 msgstr "預期的指標"
 
-#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
 #, fuzzy, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE 宣告 %<threadprivate%> 之後先使用"
 
-#: c/c-parser.cc:26642 cp/semantics.cc:9683
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
 #, fuzzy, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自動變數 %qE 無法 %<threadprivate%>"
 
-#: c/c-parser.cc:26646 cp/semantics.cc:9685
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE 有不完整型態"
 
-#: c/c-parser.cc:26826 cp/parser.cc:50667
+#: c/c-parser.cc:26824 cp/parser.cc:50665
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%>而無需 transactional 記憶體支援已啟用"
 
-#: c/c-parser.cc:26832 cp/parser.cc:50673
+#: c/c-parser.cc:26830 cp/parser.cc:50671
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%>在之內 %<__transaction_relaxed%>"
 
-#: c/c-parser.cc:26841
+#: c/c-parser.cc:26839
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
 msgstr "%<transaction_may_cancel_outer%> 函式呼叫無法在之內外異動作業或 %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.cc:26849 cp/parser.cc:50691
+#: c/c-parser.cc:26847 cp/parser.cc:50689
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%>無法在之內 %<__transaction_atomic%>"
 
-#: c/c-parser.cc:26942
+#: c/c-parser.cc:26940
 #, fuzzy, gcc-internal-format
 msgid "no closing brace"
 msgstr "封閉平行"
@@ -51496,7 +51518,7 @@ msgstr "提領 %<void *%> 指標"
 msgid "subscripted value is neither array nor pointer nor vector"
 msgstr "註標的值是 neither 陣列 nor 指標 nor 向量"
 
-#: c/c-typeck.cc:2810 cp/typeck.cc:4005 cp/typeck.cc:4099
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
 #, gcc-internal-format
 msgid "array subscript is not an integer"
 msgstr "陣列下標不是一個整數"
@@ -51527,7 +51549,7 @@ msgstr "%qD 宣告為參照卻未被初始化"
 msgid "enum constant defined here"
 msgstr "enum 常數定義的在此"
 
-#: c/c-typeck.cc:3156 cp/typeck.cc:2141
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
 msgstr ""
@@ -51642,18 +51664,18 @@ msgstr "隱含轉換從 %qT 到 %qT 時傳遞引數到函式"
 msgid "too few arguments to built-in function %qE expecting %u"
 msgstr "提供給函式 %qE 的引數太少"
 
-#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5782 cp/typeck.cc:6065
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
 #, fuzzy, gcc-internal-format
 msgid "comparison with string literal results in unspecified behavior"
 msgstr "比較與字串實字結果於未規定行為"
 
-#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5814 cp/typeck.cc:5838
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between pointer and integer"
 msgid "comparison between pointer and zero character constant"
 msgstr "比較指標和整數"
 
-#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5817 cp/typeck.cc:5841
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
 #, fuzzy, gcc-internal-format
 #| msgid "casting %qT to %qT does not dereference pointer"
 msgid "did you mean to dereference the pointer?"
@@ -51679,7 +51701,7 @@ msgstr "函式指標不能相減"
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "在參照不完全類型的指標上執行算術運算"
 
-#: c/c-typeck.cc:4264 cp/typeck.cc:6860
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
@@ -51985,7 +52007,7 @@ msgstr "當將一個指標轉換為大小不同的整數時給出警告"
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "從類型為 %qT 的函式呼叫轉換到不匹配的類型 %qT"
 
-#: c/c-typeck.cc:6336 cp/typeck.cc:9296
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "當將一個指標轉換為大小不同的整數時給出警告"
@@ -52167,7 +52189,7 @@ msgstr "賦值的左手邊可能是 format 屬性的備選時"
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "初始化的左手邊可能是 format 屬性的備選時"
 
-#: c/c-typeck.cc:7635 cp/typeck.cc:10459
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "回傳類型可能是 format 屬性的備選"
@@ -52382,12 +52404,12 @@ msgstr ""
 msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
 msgstr ""
 
-#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1218
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "對彈性陣列成員的初始化"
 
-#: c/c-typeck.cc:8562 cp/typeck2.cc:1235
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
 #, gcc-internal-format
 msgid "cannot initialize array of %qT from a string literal with type array of %qT"
 msgstr ""
@@ -52397,7 +52419,7 @@ msgstr ""
 msgid "array of inappropriate type initialized from string constant"
 msgstr "用字串常數初始化的陣列類型不合適"
 
-#: c/c-typeck.cc:8689 cp/typeck.cc:2534
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "對非左值陣列的無效使用"
@@ -52428,7 +52450,7 @@ msgstr "初始設定式元件並非常數運算式"
 msgid "initializer element is not computable at load time"
 msgstr "初始值設定中的元素在載入時無法被計算出"
 
-#: c/c-typeck.cc:9107 cp/decl.cc:7691
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "不透明的向量類型不能被初始化"
@@ -52443,7 +52465,7 @@ msgstr "初始值設定項末尾有多餘的大括號組"
 msgid "braces around scalar initializer"
 msgstr "標量初始化帶大括號"
 
-#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1245 cp/typeck2.cc:1580
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "在巢狀的上下文中初始化彈性陣列成員"
@@ -52534,7 +52556,7 @@ msgstr "結構初始值設定項中有多餘元素"
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.cc:10940 cp/typeck2.cc:1222
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "對彈性陣列成員非靜態地初始化"
@@ -52574,7 +52596,7 @@ msgstr "ISO C++ 不允許 %<goto *expr;%>"
 msgid "computed goto must be pointer type"
 msgstr "引數 %d 的 %qE 必須是指標類型"
 
-#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11060
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "被宣告為 %<noreturn%> 的函式卻有 %<return%> 敘述"
@@ -52630,7 +52652,7 @@ msgstr "%<default%> 標籤未出現在 switch 敘述內"
 msgid "break statement not within loop or switch"
 msgstr "break 敘述不在循環或開關敘述內"
 
-#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4052 cp/parser.cc:14829
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
 #: cp/parser.cc:14850
 #, fuzzy, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
@@ -52676,27 +52698,27 @@ msgstr "比較將一律評估做為 %<false%> 用於位址的 %qD 將永不是
 msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
 msgstr "比較將一律評估做為 %<true%> 用於位址的 %qD 將永不是空值"
 
-#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6087
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "比較向量與不同的元件類型"
 
-#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6100
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "比較向量與不同的元件號碼的"
 
-#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6118
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
 #, fuzzy, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "比較介於類型 %qT 和 %qT"
 
-#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6135
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "找不到介面用於類別 %qE"
 
-#: c/c-typeck.cc:12929 cp/typeck.cc:5771
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
 #, fuzzy, gcc-internal-format
 #| msgid "comparing floating point with == or != is unsafe"
 msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
@@ -52769,29 +52791,29 @@ msgstr "需要標量時使用了聯合類型"
 msgid "used vector type where scalar is required"
 msgstr "使用的向量型態位置純量被必要項"
 
-#: c/c-typeck.cc:13773 cp/semantics.cc:11393
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11404
-#: cp/semantics.cc:11414
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
 #, fuzzy, gcc-internal-format
 msgid "expected %<cancel%> %<if%> clause modifier"
 msgstr "預期 %<;%>之後類別定義"
 
-#: c/c-typeck.cc:13829 cp/semantics.cc:11449
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:13897 cp/semantics.cc:5554 cp/semantics.cc:8562
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5558
-#: cp/semantics.cc:8566
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE 並非變數在中子句 %qs"
@@ -52802,87 +52824,87 @@ msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "太多 %qs 子句"
 
 #: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
-#: cp/semantics.cc:5567 cp/semantics.cc:8573 cp/semantics.cc:8761
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.cc:13956 cp/semantics.cc:5601
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "陣列 new 的大小必須有整數類型"
 
-#: c/c-typeck.cc:13963 cp/semantics.cc:5608
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "陣列 new 的大小必須有整數類型"
 
-#: c/c-typeck.cc:13986 cp/semantics.cc:5641
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
 #, fuzzy, gcc-internal-format
 msgid "expected single pointer in %qs clause"
 msgstr "Cray 指標『%s』在中 %s 子句於 %L"
 
 #: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
-#: cp/semantics.cc:5659 cp/semantics.cc:5726
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "陣列區段在中『%s』呼叫於 %L"
 
-#: c/c-typeck.cc:14023 cp/semantics.cc:5678
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.cc:14031 cp/semantics.cc:5686
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5695
-#: cp/semantics.cc:5819
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
 #, fuzzy, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "變數長度陣列被使用"
 
-#: c/c-typeck.cc:14057 cp/semantics.cc:5712
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14100 cp/semantics.cc:5755
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14115 cp/semantics.cc:5770
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.cc:14152 cp/semantics.cc:5807
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
 #, fuzzy, gcc-internal-format
 msgid "for array function parameter length expression must be specified"
 msgstr "用於遞增運算式沒有任何效果"
 
-#: c/c-typeck.cc:14156 cp/semantics.cc:5811
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "用於遞增運算式沒有任何效果"
 
-#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5838
-#: cp/semantics.cc:5974
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
 #, fuzzy, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "複製陣列區段進入 contiguous 區塊於程序條目"
 
-#: c/c-typeck.cc:14194 cp/semantics.cc:5848
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: c/c-typeck.cc:14570 cp/semantics.cc:6910
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
 #, fuzzy, gcc-internal-format
 #| msgid "throwing NULL, which has integral, not pointer type"
 msgid "iterator %qD has neither integral nor pointer type"
@@ -52893,17 +52915,17 @@ msgstr "拋出 NULL，它的類型是整數而不是指標"
 msgid "iterator %qD has %<_Atomic%> qualified type"
 msgstr ""
 
-#: c/c-typeck.cc:14583 cp/semantics.cc:6917
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
 #, fuzzy, gcc-internal-format
 msgid "iterator %qD has const qualified type"
 msgstr "參數 %qD 有不完整型態"
 
-#: c/c-typeck.cc:14596 cp/semantics.cc:6933
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
 #, fuzzy, gcc-internal-format
 msgid "iterator step with non-integral type"
 msgstr "bit-field %qD 與 non-integral 型態"
 
-#: c/c-typeck.cc:14616 cp/semantics.cc:6969
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
 #, gcc-internal-format
 msgid "iterator %qD has zero step"
 msgstr ""
@@ -52913,33 +52935,33 @@ msgstr ""
 msgid "type of iterator %qD refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14650 cp/semantics.cc:7003
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
 #, gcc-internal-format
 msgid "begin expression refers to outer iterator %qD"
 msgstr ""
 
-#: c/c-typeck.cc:14656 cp/semantics.cc:7009
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
 #, fuzzy, gcc-internal-format
 msgid "end expression refers to outer iterator %qD"
 msgstr "無效的運算式用於輸出修飾鍵『%c』"
 
-#: c/c-typeck.cc:14662 cp/semantics.cc:7015
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
 #, fuzzy, gcc-internal-format
 msgid "step expression refers to outer iterator %qD"
 msgstr "%L 處運算式參照類型錯誤"
 
-#: c/c-typeck.cc:14699 cp/semantics.cc:7063
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
 #, fuzzy, gcc-internal-format
 msgid "expected pointer in %qs clause"
 msgstr "預期的指標"
 
-#: c/c-typeck.cc:14794 cp/semantics.cc:7152
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
 msgstr "尚未支援程式碼模式 %<large%>"
 
-#: c/c-typeck.cc:14816 cp/semantics.cc:7172
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "%<inscan%> %<reduction%> clause with array section"
@@ -52970,7 +52992,7 @@ msgstr "變數長度陣列 %qE 被使用"
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE 有無效的型態用於 %<reduction(%s)%>"
 
-#: c/c-typeck.cc:14945 cp/semantics.cc:6802
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -52980,17 +53002,17 @@ msgstr ""
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "變數長度陣列被使用"
 
-#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9298
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.cc:15063 cp/semantics.cc:9366
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
 #, fuzzy, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE 必須是 %<threadprivate%> 用於 %<copyin%>"
 
-#: c/c-typeck.cc:15078 cp/semantics.cc:7215
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
 msgstr ""
@@ -53005,23 +53027,23 @@ msgstr ""
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:15114 cp/semantics.cc:7299
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
 #: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
-#: cp/semantics.cc:7386 cp/semantics.cc:8755 cp/semantics.cc:9106
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.cc:15161 cp/semantics.cc:7404
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in data-sharing clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.cc:15172 cp/semantics.cc:7415
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD 出現一次以上在中資料子句"
@@ -53033,32 +53055,32 @@ msgstr "%qE 出現一次以上在中資料子句"
 
 #: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
 #: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
-#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7429
-#: cp/semantics.cc:7439 cp/semantics.cc:7532 cp/semantics.cc:7540
-#: cp/semantics.cc:7587 cp/semantics.cc:8444 cp/semantics.cc:8633
-#: cp/semantics.cc:8641 cp/semantics.cc:8661 cp/semantics.cc:8670
-#: cp/semantics.cc:8678
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
 #: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
-#: cp/semantics.cc:7442 cp/semantics.cc:7546 cp/semantics.cc:8681
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
 #, fuzzy, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.cc:15244 cp/semantics.cc:7519
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE 並非變數在中子句 %<firstprivate%>"
 
-#: c/c-typeck.cc:15284 cp/semantics.cc:7579
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE 並非變數在中子句 %<lastprivate%>"
 
-#: c/c-typeck.cc:15303 cp/semantics.cc:7977
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
@@ -53079,7 +53101,7 @@ msgstr ""
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.cc:15337 cp/semantics.cc:8048
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<nontemporal%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
@@ -53089,7 +53111,7 @@ msgstr "%qE 並非變數在中子句 %qs"
 msgid "%qE appears more than once in %<nontemporal%> clauses"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.cc:15356 cp/semantics.cc:8087
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<allocate%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
@@ -53099,76 +53121,76 @@ msgstr "%qE 並非變數在中子句 %qs"
 msgid "%qE appears more than once in %<allocate%> clauses"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.cc:15432 cp/semantics.cc:8213
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
 #, gcc-internal-format
 msgid "%<depend%> clause with %<depobj%> dependence type on array section"
 msgstr ""
 
-#: c/c-typeck.cc:15447 cp/semantics.cc:8228
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
 #, gcc-internal-format
 msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
 msgstr ""
 
-#: c/c-typeck.cc:15455 cp/semantics.cc:8246
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
 #, fuzzy, gcc-internal-format
 msgid "%qE is not lvalue expression nor array section in %qs clause"
 msgstr "變數長度陣列被使用"
 
-#: c/c-typeck.cc:15476 cp/semantics.cc:8268
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
 #, gcc-internal-format
 msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
 msgstr ""
 
-#: c/c-typeck.cc:15486 cp/semantics.cc:8280
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
 #, gcc-internal-format
 msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
 msgstr ""
 
-#: c/c-typeck.cc:15547 cp/semantics.cc:8379
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
 #, fuzzy, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "陣列區段無法允許的在中『%s』呼叫於 %L"
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
-#: cp/semantics.cc:8399 cp/semantics.cc:8478 cp/semantics.cc:8514
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
 #, fuzzy, gcc-internal-format
 msgid "unsupported map expression %qE"
 msgstr "無效的類型在中定點轉換"
 
-#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8440
-#: cp/semantics.cc:8658
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8448
-#: cp/semantics.cc:8664
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8601
-#: cp/semantics.cc:8768
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.cc:15859 cp/semantics.cc:8750
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.cc:15885 cp/semantics.cc:8780
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.cc:15899 cp/semantics.cc:8796
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.cc:15902 cp/semantics.cc:8799
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
@@ -53184,23 +53206,23 @@ msgstr "來源並非指標"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "向量 delete 的引數類型既非指標也非陣列"
 
-#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9260
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
 #, fuzzy, gcc-internal-format
 #| msgid "-frepo must be used with -c"
 msgid "%<order%> clause must not be used together with %<ordered%>"
 msgstr "-frepo 必須與 -c 一起使用"
 
-#: c/c-typeck.cc:15996 cp/semantics.cc:8320
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses on a task construct"
 msgstr "太多 %qs 子句"
 
-#: c/c-typeck.cc:16093 cp/semantics.cc:9074
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.cc:16160 cp/semantics.cc:9437
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE 被 predetermined %qs 用於 %qs"
@@ -53210,39 +53232,39 @@ msgstr "%qE 被 predetermined %qs 用於 %qs"
 msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: c/c-typeck.cc:16201 cp/semantics.cc:9212
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.cc:16213 cp/semantics.cc:9225
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9234
-#: cp/semantics.cc:9252
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
 #, fuzzy, gcc-internal-format
 msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
 msgstr "%qE 有無效的型態用於 %<reduction%>"
 
-#: c/c-typeck.cc:16280 cp/semantics.cc:9192
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16331 cp/semantics.cc:9242
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
 #, gcc-internal-format
 msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.cc:16341 cp/semantics.cc:9271
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
 #, fuzzy, gcc-internal-format
 #| msgid "-frepo must be used with -c"
 msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
 msgstr "-frepo 必須與 -c 一起使用"
 
-#: c/c-typeck.cc:16359 cp/semantics.cc:9462
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
 #, gcc-internal-format
 msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
 msgstr ""
@@ -53534,13 +53556,13 @@ msgstr "  當從 %qT 轉換為 %qT 時"
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  沒有已知轉換用於引數 %d 從 %qT 到 %qT"
 
-#: cp/call.cc:3927 cp/pt.cc:7112
+#: cp/call.cc:3927 cp/pt.cc:7123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  candidate 預期 %d 引數，%d 提供"
 
-#: cp/call.cc:3932 cp/pt.cc:7117
+#: cp/call.cc:3932 cp/pt.cc:7128
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -53859,594 +53881,594 @@ msgstr "條件運算式介於明確的指標類型 %qT 和 %qT lacks 演員陣
 msgid "enumerated and non-enumerated type in conditional expression"
 msgstr "列舉和非列舉類型一起出現在條件運算式中"
 
-#: cp/call.cc:7207
+#: cp/call.cc:7208
 #, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
 msgstr "%<%D(int)%> 沒有出現在字尾 %qs 中，嘗試使用字首運算子"
 
-#: cp/call.cc:7209
+#: cp/call.cc:7210
 #, fuzzy, gcc-internal-format
 msgid "no %<%D(int)%> declared for postfix %qs"
 msgstr "沒有 %<%D(整數)%>宣告的用於後綴 %qs"
 
-#: cp/call.cc:7289
+#: cp/call.cc:7290
 #, gcc-internal-format
 msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
 msgstr ""
 
-#: cp/call.cc:7342
+#: cp/call.cc:7343
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %qs"
 msgstr "傳回類型的 %qD 不是 %<int%>"
 
-#: cp/call.cc:7344
+#: cp/call.cc:7345
 #, gcc-internal-format
 msgid "used as rewritten candidate for comparison of %qT and %qT"
 msgstr ""
 
-#: cp/call.cc:7427
+#: cp/call.cc:7428
 #, gcc-internal-format
 msgid "comparison between %q#T and %q#T"
 msgstr "在 %q#T 和 %q#T 間比較"
 
-#: cp/call.cc:7614
+#: cp/call.cc:7615
 #, fuzzy, gcc-internal-format
 #| msgid "no match for call to %<(%T) (%A)%>"
 msgid "no match for call to %<%T::operator[] (%A)%>"
 msgstr "對 %<(%T) (%A)%> 的呼叫沒有匹配"
 
-#: cp/call.cc:7628
+#: cp/call.cc:7629
 #, fuzzy, gcc-internal-format
 #| msgid "call of %<(%T) (%A)%> is ambiguous"
 msgid "call of %<%T::operator[] (%A)%> is ambiguous"
 msgstr "對 %<(%T) (%A)%> 的呼叫有歧義"
 
-#: cp/call.cc:7906
+#: cp/call.cc:7907
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
 msgstr ""
 
-#: cp/call.cc:7909
+#: cp/call.cc:7910
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
 msgstr "non-placement deallocation 函式 %q+D"
 
-#: cp/call.cc:7946
+#: cp/call.cc:7947
 #, fuzzy, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
 msgstr "non-placement deallocation 函式 %q+D"
 
-#: cp/call.cc:8140
+#: cp/call.cc:8141
 #, fuzzy, gcc-internal-format
 msgid "no corresponding deallocation function for %qD"
 msgstr "沒有相應 deallocation 函式用於 %qD"
 
-#: cp/call.cc:8143
+#: cp/call.cc:8144
 #, gcc-internal-format
 msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
 msgstr ""
 
-#: cp/call.cc:8152
+#: cp/call.cc:8153
 #, gcc-internal-format
 msgid "no suitable %<operator %s%> for %qT"
 msgstr "沒有合適的 %<operator %s%> 給 %qT"
 
-#: cp/call.cc:8188
+#: cp/call.cc:8189
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is private within this context"
 msgstr "在此上下文中"
 
-#: cp/call.cc:8189 cp/decl.cc:9113
+#: cp/call.cc:8190 cp/decl.cc:9122
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "宣告的在此"
 
-#: cp/call.cc:8194
+#: cp/call.cc:8195
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "%q#D is protected within this context"
 msgstr "在此上下文中"
 
-#: cp/call.cc:8195 cp/decl.cc:9114
+#: cp/call.cc:8196 cp/decl.cc:9123
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "宣告的在此"
 
-#: cp/call.cc:8202
+#: cp/call.cc:8203
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is inaccessible"
 msgid "%q#D is inaccessible within this context"
 msgstr "%q+#D 無法存取"
 
-#: cp/call.cc:8283
+#: cp/call.cc:8284
 #, gcc-internal-format
 msgid "passing NULL to non-pointer argument %P of %qD"
 msgstr "將 NULL 做為非指標引數 %P 傳遞給 %qD"
 
-#: cp/call.cc:8286 cp/call.cc:8305 cp/decl.cc:10850 cp/decl.cc:10858
-#: cp/typeck.cc:4606
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
 #, fuzzy, gcc-internal-format
 msgid "  declared here"
 msgstr "宣告的在此"
 
-#: cp/call.cc:8290
+#: cp/call.cc:8291
 #, gcc-internal-format
 msgid "converting to non-pointer type %qT from NULL"
 msgstr "將 NULL 轉換到非指標類型 %qT"
 
-#: cp/call.cc:8302
+#: cp/call.cc:8303
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type for argument %P of %qD"
 msgstr "轉換 %<false%> 到指標類型用於引數 %P 的 %qD"
 
-#: cp/call.cc:8309
+#: cp/call.cc:8310
 #, fuzzy, gcc-internal-format
 msgid "converting %<false%> to pointer type %qT"
 msgstr "轉換 %<false%> 到指標類型 %qT"
 
-#: cp/call.cc:8376
+#: cp/call.cc:8377
 #, gcc-internal-format
 msgid "  initializing argument %P of %qD"
 msgstr "  初始化引數 %P，屬於 %qD"
 
-#: cp/call.cc:8397
+#: cp/call.cc:8398
 #, fuzzy, gcc-internal-format
 msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/call.cc:8447
+#: cp/call.cc:8448
 #, fuzzy, gcc-internal-format
 msgid "too many braces around initializer for %qT"
 msgstr "太多大括號周圍初始設定式用於 %qT"
 
-#: cp/call.cc:8458
+#: cp/call.cc:8459
 #, fuzzy
 msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "無法轉換 %qT 到 %qT 在中初始化"
 
-#: cp/call.cc:8470
+#: cp/call.cc:8471
 #, fuzzy
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
 msgstr "ISO C++不允許 %<alignof%> 與 non-type"
 
-#: cp/call.cc:8478
+#: cp/call.cc:8479
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
 msgstr ""
 
-#: cp/call.cc:8494
+#: cp/call.cc:8495
 #, fuzzy
 msgid "invalid user-defined conversion from %qH to %qI"
 msgstr "無效的使用者定義的轉換從 %qT 到 %qT"
 
-#: cp/call.cc:8527 cp/cvt.cc:227
+#: cp/call.cc:8528 cp/cvt.cc:227
 #, fuzzy
 #| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
 msgstr "從類型 %qT 到類型 %qT 的轉換無效"
 
-#: cp/call.cc:8574 cp/call.cc:8587
+#: cp/call.cc:8575 cp/call.cc:8588
 #, fuzzy, gcc-internal-format
 msgid "converting to %qT from initializer list would use explicit constructor %qD"
 msgstr "轉換到 %qT 從初始設定式清單會使用明確的建構子 %qD"
 
-#: cp/call.cc:8580
+#: cp/call.cc:8581
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "in C++11 and above a default constructor can be explicit"
 msgstr "只有建構式才能被宣告為 %<explicit%>"
 
-#: cp/call.cc:8860
+#: cp/call.cc:8861
 #, fuzzy
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
 msgstr "轉換到易變的參考類型 %q#T 從 rvalue 的型態 %qT"
 
-#: cp/call.cc:8869
+#: cp/call.cc:8870
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
 msgstr "無效的初始化的 non-const 參考的型態 %qT 從 rvalue 的型態 %qT"
 
-#: cp/call.cc:8874
+#: cp/call.cc:8875
 #, fuzzy
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "無效的初始化的 non-const 參考的型態 %qT 從 rvalue 的型態 %qT"
 
 #. extype is volatile
-#: cp/call.cc:8877
+#: cp/call.cc:8878
 #, fuzzy
 msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
 msgstr "轉換到易變的參考類型 %q#T 從 rvalue 的型態 %qT"
 
-#: cp/call.cc:8890
+#: cp/call.cc:8891
 #, fuzzy
 msgid "cannot bind reference of type %qH to %qI due to different array bounds"
 msgstr "轉換到易變的參考類型 %q#T 從 rvalue 的型態 %qT"
 
-#: cp/call.cc:8893
+#: cp/call.cc:8894
 #, fuzzy
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
 msgstr "從 %qT 到 %qT 的轉換丟失了限定資訊"
 
-#: cp/call.cc:8932
+#: cp/call.cc:8933
 #, fuzzy, gcc-internal-format
 #| msgid "cannot bind bitfield %qE to %qT"
 msgid "cannot bind bit-field %qE to %qT"
 msgstr "無法將位元段 %qE 繫結到 %qT"
 
-#: cp/call.cc:8935 cp/call.cc:8953
+#: cp/call.cc:8936 cp/call.cc:8954
 #, gcc-internal-format
 msgid "cannot bind packed field %qE to %qT"
 msgstr "不能將緊實的欄位 %qE 繫結到 %qT"
 
-#: cp/call.cc:8938
+#: cp/call.cc:8939
 #, gcc-internal-format
 msgid "cannot bind rvalue %qE to %qT"
 msgstr "無法將右值 %qE 繫結到 %qT"
 
-#: cp/call.cc:9139
+#: cp/call.cc:9140
 #, fuzzy
 msgid "implicit conversion from %qH to %qI when passing argument to function"
 msgstr "隱含轉換從 %qT 到 %qT 時傳遞引數到函式"
 
-#: cp/call.cc:9168 cp/cvt.cc:2011
+#: cp/call.cc:9169 cp/cvt.cc:2011
 #, gcc-internal-format
 msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
 msgstr ""
 
-#: cp/call.cc:9212
+#: cp/call.cc:9213
 #, fuzzy, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
 msgstr "無法回合物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>"
 
-#: cp/call.cc:9248
+#: cp/call.cc:9249
 #, fuzzy, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
 msgstr "無法接收物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>；"
 
-#: cp/call.cc:9258
+#: cp/call.cc:9259
 #, fuzzy, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
 msgstr "無法接收物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>；"
 
-#: cp/call.cc:9326
+#: cp/call.cc:9327
 #, fuzzy, gcc-internal-format
 msgid "recursive evaluation of default argument for %q#D"
 msgstr "遞迴求值的預設引數用於 %q#D"
 
-#: cp/call.cc:9335
+#: cp/call.cc:9336
 #, fuzzy, gcc-internal-format
 msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
 msgstr "呼叫到 %qD 使用預設引數用於參數 %P, 該項不是未定義"
 
-#: cp/call.cc:9435
+#: cp/call.cc:9436
 #, gcc-internal-format
 msgid "argument of function call might be a candidate for a format attribute"
 msgstr "函式的引數可能是 format 屬性的備選"
 
-#: cp/call.cc:9515
+#: cp/call.cc:9516
 #, fuzzy, gcc-internal-format
 msgid "use of multiversioned function without a default"
 msgstr "缺席函式 %q+D 與預設引數"
 
-#: cp/call.cc:10020
+#: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
 msgstr ""
 
-#: cp/call.cc:10143
+#: cp/call.cc:10144
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "將 %qT 做為 %q#D 的 %<this%> 引數時丟棄了類型限定"
 
-#: cp/call.cc:10146 cp/call.cc:12992
+#: cp/call.cc:10147 cp/call.cc:12993
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  在呼叫 %qD 時"
 
-#: cp/call.cc:10171
+#: cp/call.cc:10172
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT 是 %qT 的一個不可存取的基礎類別"
 
-#: cp/call.cc:10396
+#: cp/call.cc:10397
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "太多引數到建構子 %q#D"
 
-#: cp/call.cc:10533
+#: cp/call.cc:10534
 #, gcc-internal-format
 msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/call.cc:10900
+#: cp/call.cc:10901
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
 msgstr ""
 
-#: cp/call.cc:10903
+#: cp/call.cc:10904
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-POD type %qT"
 msgid "%qD writing to an object of non-trivial type %#qT%s"
 msgstr "%qD 無法 thread-local 因為它有 non-trivial 型態 %qT"
 
-#: cp/call.cc:10908
+#: cp/call.cc:10909
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with %qs member %qD"
 msgstr ""
 
-#: cp/call.cc:10913
+#: cp/call.cc:10914
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
 msgstr ""
 
-#: cp/call.cc:10928
+#: cp/call.cc:10929
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use assignment or value-initialization instead"
 msgstr "賦值(不是初始化)出現在宣告中"
 
-#: cp/call.cc:10930
+#: cp/call.cc:10931
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use assignment instead"
 msgstr "改用 #include"
 
-#: cp/call.cc:10932
+#: cp/call.cc:10933
 #, fuzzy, gcc-internal-format
 msgid "; use value-initialization instead"
 msgstr "value-initialization 的函數型式 %qT"
 
-#: cp/call.cc:10935
+#: cp/call.cc:10936
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10938
+#: cp/call.cc:10939
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-POD type %qT"
 msgid "%qD clearing an object of non-trivial type %#qT%s"
 msgstr "%qD 無法 thread-local 因為它有 non-trivial 型態 %qT"
 
-#: cp/call.cc:10940
+#: cp/call.cc:10941
 #, gcc-internal-format
 msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
 msgstr ""
 
-#: cp/call.cc:10961
+#: cp/call.cc:10962
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "; use copy-assignment or copy-initialization instead"
 msgstr "賦值(不是初始化)出現在宣告中"
 
-#: cp/call.cc:10963
+#: cp/call.cc:10964
 #, fuzzy, gcc-internal-format
 #| msgid "use #include instead"
 msgid "; use copy-assignment instead"
 msgstr "改用 #include"
 
-#: cp/call.cc:10965
+#: cp/call.cc:10966
 #, fuzzy, gcc-internal-format
 msgid "; use copy-initialization instead"
 msgstr "擴充：%C 處舊式的初始化"
 
-#: cp/call.cc:10968
+#: cp/call.cc:10969
 #, gcc-internal-format
 msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
 msgstr ""
 
-#: cp/call.cc:10971
+#: cp/call.cc:10972
 #, fuzzy, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
 msgstr "轉換到虛值將無法存取物件的 non-trivially-copyable 型態 %qT"
 
-#: cp/call.cc:10974
+#: cp/call.cc:10975
 #, gcc-internal-format
 msgid "%qD writing to an object with a deleted copy constructor"
 msgstr ""
 
-#: cp/call.cc:10985
+#: cp/call.cc:10986
 #, gcc-internal-format
 msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
 msgstr ""
 
-#: cp/call.cc:10997
+#: cp/call.cc:10998
 #, gcc-internal-format
 msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
 msgstr ""
 
-#: cp/call.cc:11016
+#: cp/call.cc:11017
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
 msgstr ""
 
-#: cp/call.cc:11019
+#: cp/call.cc:11020
 #, gcc-internal-format
 msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
 msgstr ""
 
-#: cp/call.cc:11029
+#: cp/call.cc:11030
 #, fuzzy, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
 msgstr "無法回合物件的 non-trivially-copyable 型態 %q#T 透過 %<...%>"
 
-#: cp/call.cc:11032
+#: cp/call.cc:11033
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
 msgstr ""
 
-#: cp/call.cc:11035
+#: cp/call.cc:11036
 #, gcc-internal-format
 msgid "%qD moving an object of type %#qT with deleted destructor"
 msgstr ""
 
-#: cp/call.cc:11044
+#: cp/call.cc:11045
 #, gcc-internal-format
 msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
 msgstr ""
 
-#: cp/call.cc:11066
+#: cp/call.cc:11067
 #, fuzzy, gcc-internal-format
 msgid "%#qT declared here"
 msgstr "%qD 宣告的在此"
 
-#: cp/call.cc:11120
+#: cp/call.cc:11121
 #, fuzzy, gcc-internal-format
 msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
 msgstr "non-integer 引數 3 在中呼叫到函式 %qE"
 
-#: cp/call.cc:11187
+#: cp/call.cc:11188
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "常數參考它自己"
 
-#: cp/call.cc:11462 cp/typeck.cc:10390
+#: cp/call.cc:11463 cp/typeck.cc:10386
 #, fuzzy
 msgid "cannot convert %qH to %qI"
 msgstr "無法轉換 %qT 到 %qT"
 
-#: cp/call.cc:11484
+#: cp/call.cc:11485
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "沒有匹配函式用於呼叫到 %<%T::運算子 %T(%A)%#V%>"
 
-#: cp/call.cc:11516
+#: cp/call.cc:11517
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
 msgstr "對 %<%T::%s(%A)%#V%> 的呼叫沒有匹配的函式"
 
-#: cp/call.cc:11564
+#: cp/call.cc:11565
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "呼叫非函式的 %qD"
 
-#: cp/call.cc:11602 cp/pt.cc:17172 cp/typeck.cc:3483
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
 #, fuzzy, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "無法呼叫建構子 %<%T::%D%>直接"
 
-#: cp/call.cc:11604
+#: cp/call.cc:11605
 #, fuzzy, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "  用於 function-style 演員陣容，移除冗餘 %<::%D%>"
 
-#: cp/call.cc:11786
+#: cp/call.cc:11787
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "對 %<%D(%A)%> 的呼叫沒有匹配的函式"
 
-#: cp/call.cc:11789
+#: cp/call.cc:11790
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "對多載的 %<%s(%A)%> 的呼叫有歧義"
 
-#: cp/call.cc:11812
+#: cp/call.cc:11813
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT 沒具名為 %qD 的非靜態資料成員"
 
-#: cp/call.cc:11817
+#: cp/call.cc:11818
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "建構式回傳值"
 
-#: cp/call.cc:11818
+#: cp/call.cc:11819
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "解構函式回傳值"
 
-#: cp/call.cc:11841
+#: cp/call.cc:11842
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "沒有物件無法呼叫成員函式 %qD"
 
-#: cp/call.cc:12990
+#: cp/call.cc:12991
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "傳遞 %qT 時選擇 %qT 而不是 %qT"
 
-#: cp/call.cc:13016
+#: cp/call.cc:13017
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgid "C++20 says that these are ambiguous, even though the second is reversed:"
 msgstr "ISO C++ 認為有歧義，盡管第一個備選的最差類型轉換要好於第二個備選的最差類型轉換"
 
-#: cp/call.cc:13039
+#: cp/call.cc:13040
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "try making the operator a %<const%> member function"
 msgstr "解構函式不能是靜態成員函式"
 
-#: cp/call.cc:13102
+#: cp/call.cc:13103
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "選擇 %qD 而不是 %qD"
 
-#: cp/call.cc:13103
+#: cp/call.cc:13104
 #, fuzzy
 #| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
 msgstr "  當從 %qT 轉換為 %qT 時"
 
-#: cp/call.cc:13106
+#: cp/call.cc:13107
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  因為前者的引數類型轉換序列更好"
 
-#: cp/call.cc:13390
+#: cp/call.cc:13391
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "預設引數不匹配在中過載解析度"
 
-#: cp/call.cc:13394
+#: cp/call.cc:13395
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " candidate 1:%q+#F"
 
-#: cp/call.cc:13396
+#: cp/call.cc:13397
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " candidate 2:%q+#F"
 
-#: cp/call.cc:13442
+#: cp/call.cc:13443
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ 認為有歧義，盡管第一個備選的最差類型轉換要好於第二個備選的最差類型轉換"
 
-#: cp/call.cc:13850
+#: cp/call.cc:13855
 #, fuzzy, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "暫時的約束到 %qD 只有持續直到建構子離開"
 
-#: cp/call.cc:14003
+#: cp/call.cc:14008
 #, fuzzy
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
 msgstr "無效的初始化的 non-const 參考的型態 %qT 從 rvalue 的型態 %qT"
 
-#: cp/call.cc:14007
+#: cp/call.cc:14012
 #, fuzzy
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
 msgstr "將類型為 %qT 的參照初始化為類型為 %qT 的運算式無效"
 
-#: cp/call.cc:14325
+#: cp/call.cc:14330
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "possibly dangling reference to a temporary"
 msgstr "回傳臨時變數的參照"
 
-#: cp/call.cc:14326
+#: cp/call.cc:14331
 #, gcc-internal-format
 msgid "the temporary was destroyed at the end of the full expression %qE"
 msgstr ""
 
-#: cp/call.cc:14594
+#: cp/call.cc:14599
 #, fuzzy, gcc-internal-format
 #| msgid "%s: definition of function '%s' not converted\n"
 msgid "explicit conversion function was not considered"
@@ -54498,7 +54520,7 @@ msgid "%q#D cannot be overloaded with %q#D"
 msgstr "%q+#D 無法被多載"
 
 #: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
-#: cp/decl.cc:1988 cp/name-lookup.cc:2895 cp/name-lookup.cc:3213
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %q#D"
 msgstr "前一個宣告 %q+#D"
@@ -54950,7 +54972,7 @@ msgstr "flexible 陣列成員在中否則清空結構"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.cc:7785 cp/decl.cc:17643 cp/parser.cc:27638
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T 重定義"
@@ -55086,7 +55108,7 @@ msgstr "無效的型態用於參數 %d 的 constexpr 函式 %q+#D"
 msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
 msgstr ""
 
-#: cp/constexpr.cc:270 cp/decl.cc:14678
+#: cp/constexpr.cc:270 cp/decl.cc:14694
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
@@ -55127,7 +55149,7 @@ msgstr "內文的 constexpr 函式 %qD 不是 return-statement"
 msgid "%qD is not usable as a %<constexpr%> function because:"
 msgstr "%q+D 不是可用做為 constexpr 函式因為："
 
-#: cp/constexpr.cc:1315 cp/constexpr.cc:6363
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
 msgstr ""
@@ -55145,7 +55167,7 @@ msgstr "%<constexpr%> 無法用於類型宣告"
 msgid "%q+E is not a constant expression"
 msgstr "%q+E並非常數運算式"
 
-#: cp/constexpr.cc:1898 cp/constexpr.cc:5929 cp/constexpr.cc:8238
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
 #: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
@@ -55168,7 +55190,7 @@ msgstr "使用者定義的 %qD 總是計算所有兩個參數"
 msgid "failed %<assume%> attribute assumption"
 msgstr ""
 
-#: cp/constexpr.cc:2203 cp/constexpr.cc:9688
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
 #: rust/backend/rust-constexpr.cc:5758
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
@@ -55217,7 +55239,7 @@ msgstr "  %qT 是模稜兩可的基礎類別的 %qT"
 msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
 msgstr ""
 
-#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9724
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
 #: rust/backend/rust-constexpr.cc:5789
 #, fuzzy, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
@@ -55351,20 +55373,20 @@ msgstr "陣列下標超出陣列邊界"
 msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
 msgstr "陣列下標超出陣列邊界"
 
-#: cp/constexpr.cc:4514 rust/backend/rust-constexpr.cc:1667
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/constexpr.cc:4576 rust/backend/rust-constexpr.cc:1724
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "提領 %<void *%> 指標"
 
-#: cp/constexpr.cc:4595 cp/constexpr.cc:4711 cp/constexpr.cc:4723
-#: cp/constexpr.cc:7422 cp/constexpr.cc:7552 cp/constexpr.cc:9638
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
 #: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
 #: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
 #: rust/backend/rust-constexpr.cc:5712
@@ -55372,477 +55394,477 @@ msgstr "提領 %<void *%> 指標"
 msgid "%qE is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.cc:4603 rust/backend/rust-constexpr.cc:1744
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "可變的 %qD 不是可用在中常數運算式"
 
-#: cp/constexpr.cc:4635 cp/constexpr.cc:4671 cp/constexpr.cc:6527
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
 #: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/constexpr.cc:4637 cp/constexpr.cc:4650 cp/constexpr.cc:6522
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
 #: rust/backend/rust-constexpr.cc:1776
 #, fuzzy, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "存取 %qD 成員以代替初始化的 %qD 成員在中常數運算式"
 
-#: cp/constexpr.cc:4789
+#: cp/constexpr.cc:4790
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a union type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.cc:4792
+#: cp/constexpr.cc:4793
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a union type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.cc:4803
+#: cp/constexpr.cc:4804
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.cc:4806
+#: cp/constexpr.cc:4807
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.cc:4817
+#: cp/constexpr.cc:4818
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a reference type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.cc:4820
+#: cp/constexpr.cc:4821
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a reference type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.cc:4831
+#: cp/constexpr.cc:4832
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is a pointer to member type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.cc:4835
+#: cp/constexpr.cc:4836
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a pointer to member type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.cc:4846
+#: cp/constexpr.cc:4847
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT is volatile"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.cc:4849
+#: cp/constexpr.cc:4850
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a constant expression because %qT contains a volatile subobject"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.cc:5004
+#: cp/constexpr.cc:5005
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be constant evaluated on the target"
 msgstr "巢狀的函式不支援於這個目標"
 
-#: cp/constexpr.cc:5013 cp/constexpr.cc:5023
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
 #, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the type is too large"
 msgstr ""
 
-#: cp/constexpr.cc:5043
+#: cp/constexpr.cc:5044
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.cc:5089
+#: cp/constexpr.cc:5090
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "%qs accessing uninitialized byte at offset %d"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/constexpr.cc:5101
+#: cp/constexpr.cc:5102
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.cc:5949 rust/backend/rust-constexpr.cc:895
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "存取值的 %qE 透過 %qT glvalue 在中常數運算式"
 
 #. Provide a more accurate message for deleted variables.
-#: cp/constexpr.cc:5989 cp/constexpr.cc:6022
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
 #, fuzzy, gcc-internal-format
 msgid "use of allocated storage after deallocation in a constant expression"
 msgstr "使用的值的物件被建構在中常數運算式"
 
-#: cp/constexpr.cc:5991 cp/constexpr.cc:6017 cp/constexpr.cc:6024
-#: cp/constexpr.cc:6358
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
 #, fuzzy, gcc-internal-format
 msgid "allocated here"
 msgstr "宣告的在此"
 
-#: cp/constexpr.cc:5995
+#: cp/constexpr.cc:5996
 #, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
 msgstr ""
 
-#: cp/constexpr.cc:6015
+#: cp/constexpr.cc:6016
 #, fuzzy, gcc-internal-format
 msgid "the content of uninitialized storage is not usable in a constant expression"
 msgstr "值的 %qD 不是可用在中常數運算式"
 
-#: cp/constexpr.cc:6027 rust/backend/rust-constexpr.cc:4041
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "值的 %qD 不是可用在中常數運算式"
 
-#: cp/constexpr.cc:6035
+#: cp/constexpr.cc:6036
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD 已用於它的本身初始設定式"
 
-#: cp/constexpr.cc:6040
+#: cp/constexpr.cc:6041
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D 不是常數"
 
-#: cp/constexpr.cc:6043
+#: cp/constexpr.cc:6044
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D 是易變的"
 
-#: cp/constexpr.cc:6048 cp/constexpr.cc:6055
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD 未被初始化的與常數運算式"
 
-#: cp/constexpr.cc:6061
+#: cp/constexpr.cc:6062
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD 未被宣告 %<constexpr%>"
 
-#: cp/constexpr.cc:6064
+#: cp/constexpr.cc:6065
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/constexpr.cc:6356
+#: cp/constexpr.cc:6357
 #, fuzzy, gcc-internal-format
 msgid "modification of allocated storage after deallocation is not a constant expression"
 msgstr "使用的值的物件被建構在中常數運算式"
 
-#: cp/constexpr.cc:6365
+#: cp/constexpr.cc:6366
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE outside its lifetime is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.cc:6372
+#: cp/constexpr.cc:6373
 #, fuzzy, gcc-internal-format
 msgid "destroying %qE from outside current evaluation is not a constant expression"
 msgstr "差異的兩指標運算式並非常數運算式"
 
-#: cp/constexpr.cc:6375
+#: cp/constexpr.cc:6376
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE from outside current evaluation is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.cc:6502
+#: cp/constexpr.cc:6503
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
 msgstr "無法轉換 %qT 到 %qT 在中初始化"
 
-#: cp/constexpr.cc:6531
+#: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
 msgstr ""
 
-#: cp/constexpr.cc:6538
+#: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
 msgstr ""
 
-#: cp/constexpr.cc:6550 rust/backend/rust-constexpr.cc:2822
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, fuzzy, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD during initialization"
 msgstr "無法轉換 %qT 到 %qT 在中初始化"
 
-#: cp/constexpr.cc:6998 cp/constexpr.cc:8587 cp/constexpr.cc:8599
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
 #: rust/backend/rust-constexpr.cc:4668
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/constexpr.cc:7094 rust/backend/rust-constexpr.cc:4933
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
 msgstr "constexpr 求值深度超出最大值的 %d (使用 -fconstexpr-depth=到增加最大值)"
 
-#: cp/constexpr.cc:7201 rust/backend/rust-constexpr.cc:999
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
 #, fuzzy, gcc-internal-format
 msgid "inline assembly is not a constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/constexpr.cc:7203 rust/backend/rust-constexpr.cc:1000
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
 #, gcc-internal-format
 msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
 msgstr ""
 
-#: cp/constexpr.cc:7221
+#: cp/constexpr.cc:7222
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "use of %qD"
 msgstr "錯誤地使用了 %qD"
 
-#: cp/constexpr.cc:7225
+#: cp/constexpr.cc:7226
 #, gcc-internal-format
 msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
 msgstr ""
 
-#: cp/constexpr.cc:7227
+#: cp/constexpr.cc:7228
 #, gcc-internal-format
 msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
 msgstr ""
 
-#: cp/constexpr.cc:7229
+#: cp/constexpr.cc:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "the default value for the current CPU tuning is %d bytes"
 msgstr ""
 
-#: cp/constexpr.cc:7231
+#: cp/constexpr.cc:7232
 #, gcc-internal-format
 msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
 msgstr ""
 
-#: cp/constexpr.cc:7384
+#: cp/constexpr.cc:7385
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.cc:7397
+#: cp/constexpr.cc:7398
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
 msgstr "constexpr 求值深度超出最大值的 %d (使用 -fconstexpr-depth=到增加最大值)"
 
-#: cp/constexpr.cc:7582
+#: cp/constexpr.cc:7583
 #, gcc-internal-format
 msgid "control passes through definition of %qD with thread storage duration"
 msgstr ""
 
-#: cp/constexpr.cc:7585
+#: cp/constexpr.cc:7586
 #, fuzzy, gcc-internal-format
 msgid "control passes through definition of %qD with static storage duration"
 msgstr "擷取的變數 %qD 與 non-automatic 貯藏體持續時間"
 
-#: cp/constexpr.cc:7650 cp/constexpr.cc:10332
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
 #: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "暫時的的 non-literal 型態 %qT 在中常數運算式"
 
-#: cp/constexpr.cc:8099 cp/constexpr.cc:9839
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> is not a constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/constexpr.cc:8127 rust/backend/rust-constexpr.cc:2461
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "轉換從指標類型 %qT 到算術型式 %qT 在中 constant-expression"
 
-#: cp/constexpr.cc:8177
+#: cp/constexpr.cc:8181
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.cc:8184
+#: cp/constexpr.cc:8188
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "pointed-to object declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/constexpr.cc:8189
+#: cp/constexpr.cc:8193
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
 msgstr "範本參數 %qD(類型為 %qT)不允許出現在整數運算式中，因為它的類型不是整數或列舉"
 
-#: cp/constexpr.cc:8201
+#: cp/constexpr.cc:8205
 #, fuzzy, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression before C++26"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.cc:8215
+#: cp/constexpr.cc:8219
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression when the class %qT is still incomplete"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.cc:8249 rust/backend/rust-constexpr.cc:2506
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.cc:8387 cp/constexpr.cc:10150 cp/constexpr.cc:10555
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
 #: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.cc:8432 cp/constexpr.cc:10596
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.cc:8490
+#: cp/constexpr.cc:8494
 #, fuzzy, gcc-internal-format
 msgid "contract predicate is false in constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/constexpr.cc:8506
+#: cp/constexpr.cc:8510
 #, fuzzy, gcc-internal-format
 msgid "unexpected template-id %qE"
 msgstr "預期 template-id"
 
-#: cp/constexpr.cc:8512 cp/constraint.cc:178 cp/constraint.cc:755
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
 #, fuzzy, gcc-internal-format
 msgid "function concept must be called"
 msgstr "內建函式 %qD 需一個引數只有"
 
-#: cp/constexpr.cc:8537
+#: cp/constexpr.cc:8541
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "address of a call to %qs is not a constant expression"
 msgstr "陣列 %qD 的大小不是一個整數常運算式"
 
-#: cp/constexpr.cc:8602
+#: cp/constexpr.cc:8606
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "未預期的運算式 %qE 的 kind %s"
 
-#: cp/constexpr.cc:8878 rust/backend/rust-constexpr.cc:5158
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.cc:8886 rust/backend/rust-constexpr.cc:5167
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.cc:8902 rust/backend/rust-constexpr.cc:5183
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.cc:8913 rust/backend/rust-constexpr.cc:5195
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because allocated storage has not been deallocated"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.cc:8933 rust/backend/rust-constexpr.cc:5213
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
 #, gcc-internal-format
 msgid "immediate evaluation returns address of immediate function %qD"
 msgstr ""
 
-#: cp/constexpr.cc:8937
+#: cp/constexpr.cc:8941
 #, fuzzy, gcc-internal-format
 msgid "constant evaluation returns address of immediate function %qD"
 msgstr "需位址的解構式 %qE"
 
-#: cp/constexpr.cc:9575 rust/backend/rust-constexpr.cc:5667
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
 msgstr "從具有類型 %qT 的右值運算式到類型 %qT 中的轉換無效"
 
-#: cp/constexpr.cc:9804
+#: cp/constexpr.cc:9808
 #, fuzzy, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.cc:9807
+#: cp/constexpr.cc:9811
 #, gcc-internal-format
 msgid "because it is used as a glvalue"
 msgstr ""
 
-#: cp/constexpr.cc:9863 rust/backend/rust-constexpr.cc:5893
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from integer to pointer"
 msgstr "reinterpretcast 從型態 %qT 輸入 %qT 演員陣容暫離限定元(_C)"
 
-#: cp/constexpr.cc:9897 rust/backend/rust-constexpr.cc:5921
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
 #, fuzzy, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of 物件 %qE 與執行緒本地或自動貯藏體並非常數運算式"
 
-#: cp/constexpr.cc:9936
+#: cp/constexpr.cc:9940
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.cc:10085
+#: cp/constexpr.cc:10089
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.cc:10097
+#: cp/constexpr.cc:10101
 #, fuzzy, gcc-internal-format
 msgid "new-expression is not a constant expression before C++20"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.cc:10164
+#: cp/constexpr.cc:10168
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual functions cannot be %<constexpr%> before C++20"
 msgstr "虛函式不能是夥伴"
 
-#: cp/constexpr.cc:10180
+#: cp/constexpr.cc:10184
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.cc:10243
+#: cp/constexpr.cc:10247
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "暫時的的 non-literal 型態 %qT 在中常數運算式"
 
-#: cp/constexpr.cc:10296
+#: cp/constexpr.cc:10300
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %<constexpr%> context"
 msgstr "%qD 宣告 %<constexpr%> 外側它的類別"
 
-#: cp/constexpr.cc:10304
+#: cp/constexpr.cc:10308
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<static%> in %<constexpr%> context"
 msgstr "%qD 宣告 %<constexpr%> 外側它的類別"
 
-#: cp/constexpr.cc:10382 rust/backend/rust-constexpr.cc:6251
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "除法由零並非 constant-expression"
 
-#: cp/constexpr.cc:10483 rust/backend/rust-constexpr.cc:6349
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.cc:10552
+#: cp/constexpr.cc:10556
 #, fuzzy, gcc-internal-format
 msgid "neither branch of %<if%> is a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.cc:10565
+#: cp/constexpr.cc:10569
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "non-constant 陣列初始化"
 
-#: cp/constexpr.cc:10613 rust/backend/rust-constexpr.cc:6427
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
 #, fuzzy, gcc-internal-format
 msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/constexpr.cc:10644 rust/backend/rust-constexpr.cc:6438
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "未預期的 AST 的 kind %s"
@@ -56600,7 +56622,7 @@ msgstr "%<__builtin_prefetch%> 的第三個引數必須是一個常數"
 msgid "no suspend point info for %qD"
 msgstr "沒有前一個原型用於 %qD"
 
-#: cp/coroutines.cc:2102 cp/coroutines.cc:4657
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
 #, gcc-internal-format
 msgid "%qE is provided by %qT but is not usable with the function signature %qD"
 msgstr ""
@@ -56622,23 +56644,23 @@ msgstr "指標不能做為 case 常數"
 msgid "variable length arrays are not yet supported in coroutines"
 msgstr ""
 
-#: cp/coroutines.cc:4662
+#: cp/coroutines.cc:4657
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
 msgstr ""
 
-#: cp/coroutines.cc:4665
+#: cp/coroutines.cc:4660
 #, gcc-internal-format
 msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
 msgstr ""
 
-#: cp/coroutines.cc:4694
+#: cp/coroutines.cc:4689
 #, gcc-internal-format
 msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
 msgstr ""
 
 #. We can't initialize a non-class return value from void.
-#: cp/coroutines.cc:5076
+#: cp/coroutines.cc:5064
 #, fuzzy, gcc-internal-format
 msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
 msgstr "無效的初始化的 non-const 參考的型態 %qT 從 rvalue 的型態 %qT"
@@ -56659,69 +56681,69 @@ msgstr ""
 msgid "%qD was promoted to an immediate function"
 msgstr "%qD 不是一個範本函式"
 
-#: cp/cp-gimplify.cc:1164
+#: cp/cp-gimplify.cc:1174
 #, fuzzy, gcc-internal-format
 msgid "taking address of an immediate function %qD"
 msgstr "需位址的解構式 %qE"
 
-#: cp/cp-gimplify.cc:1263
+#: cp/cp-gimplify.cc:1273
 #, fuzzy, gcc-internal-format
 msgid "call to consteval function %qE is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/cp-gimplify.cc:2002
+#: cp/cp-gimplify.cc:2012
 #, fuzzy, gcc-internal-format
 msgid "%<throw%> will always call %<terminate%>"
 msgstr "位址的 %qD 將一律評估做為 %<true%>"
 
-#: cp/cp-gimplify.cc:2005
+#: cp/cp-gimplify.cc:2015
 #, fuzzy, gcc-internal-format
 msgid "in C++11 destructors default to %<noexcept%>"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/cp-gimplify.cc:2017
+#: cp/cp-gimplify.cc:2027
 #, gcc-internal-format
 msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
 msgstr ""
 
-#: cp/cp-gimplify.cc:3614
+#: cp/cp-gimplify.cc:3624
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %qE after earlier %qE"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/cp-gimplify.cc:3656
+#: cp/cp-gimplify.cc:3666
 #, fuzzy, gcc-internal-format
 msgid "pack expansion of %qE attribute"
 msgstr "無效的引數的 %qE 屬性"
 
-#: cp/cp-gimplify.cc:3659
+#: cp/cp-gimplify.cc:3669
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in template argument list"
 msgid "use fold expression in the attribute argument instead"
 msgstr "範本引數表語法錯誤"
 
-#: cp/cp-gimplify.cc:3698 cp/cp-gimplify.cc:3710 cp/decl.cc:4456
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
 #: cp/method.cc:984
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a type"
 msgstr "%qD 並非型態"
 
-#: cp/cp-gimplify.cc:3716
+#: cp/cp-gimplify.cc:3726
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class type"
 msgstr "%qT 並非類別型態"
 
-#: cp/cp-gimplify.cc:3733
+#: cp/cp-gimplify.cc:3743
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have %<const char *%> type"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/cp-gimplify.cc:3743
+#: cp/cp-gimplify.cc:3753
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral type"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/cp-gimplify.cc:3755
+#: cp/cp-gimplify.cc:3765
 #, gcc-internal-format
 msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
 msgstr ""
@@ -56769,7 +56791,7 @@ msgstr "轉換到 non-const 參考類型 %q#T 從 rvalue 的型態 %qT"
 msgid "conversion from %qH to %qI discards qualifiers"
 msgstr "從 %qT 到 %qT 的轉換丟失了限定資訊"
 
-#: cp/cvt.cc:498 cp/typeck.cc:8827
+#: cp/cvt.cc:498 cp/typeck.cc:8823
 #, gcc-internal-format
 msgid "casting %qT to %qT does not dereference pointer"
 msgstr "從 %qT 轉換到 %qT 並未提領指標"
@@ -57161,7 +57183,7 @@ msgstr "從先前的宣告 %q+F"
 msgid "redeclaration %qD differs in %qs from previous declaration"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/decl.cc:1446 cp/decl.cc:16620
+#: cp/decl.cc:1446 cp/decl.cc:16636
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -57318,8 +57340,8 @@ msgstr "先前對於 %q+#D 的非函式宣告"
 msgid "%q#D previously defined here"
 msgstr "%q+#D 已在此定義過"
 
-#: cp/decl.cc:2089 cp/name-lookup.cc:3366 cp/name-lookup.cc:3404
-#: cp/name-lookup.cc:3430
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#D previously declared here"
@@ -57402,58 +57424,41 @@ msgstr "為參數 %d (屬於 %q#D)指定了預設引數"
 msgid "previous specification in %q#D here"
 msgstr "但先前在 %q+#D 中已有指定"
 
-#: cp/decl.cc:2285
-#, fuzzy, gcc-internal-format
-#| msgid "conflicts with built-in declaration %q#D"
-msgid "declaration %qD conflicts with builtin"
-msgstr "與內建宣告 %q#D 衝突"
-
-#: cp/decl.cc:2288
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of namespace %qD conflicts with"
-msgid "declaration %qD conflicts with import"
-msgstr "命名空間 %qD 的宣告存在衝突，與"
-
-#: cp/decl.cc:2289
-#, fuzzy, gcc-internal-format
-msgid "import declared %q#D here"
-msgstr "%qD 宣告的在此"
-
-#: cp/decl.cc:2306 cp/decl.cc:16643
+#: cp/decl.cc:2300 cp/decl.cc:16654
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting exporting for declaration %qD"
 msgstr "相互衝突的宣告 %q#D"
 
-#: cp/decl.cc:2308 cp/decl.cc:16645
+#: cp/decl.cc:2302 cp/decl.cc:16656
 #, fuzzy, gcc-internal-format
 msgid "previously declared here without exporting"
 msgstr "在之前宣告的在此"
 
-#: cp/decl.cc:2335
+#: cp/decl.cc:2330
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "previous definition of %qD here"
 msgstr "%q+D 的上一個定義在此"
 
-#: cp/decl.cc:2336
+#: cp/decl.cc:2331
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D was here"
 msgid "previous declaration of %qD here"
 msgstr "%q+D 的上一個宣告在此"
 
-#: cp/decl.cc:2349
+#: cp/decl.cc:2344
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
 msgstr "聯合成員函式 %qD 被宣告為虛函式"
 
-#: cp/decl.cc:2396
+#: cp/decl.cc:2391
 #, gcc-internal-format
 msgid "redundant redeclaration of %qD in same scope"
 msgstr "同一作用欄位中 %qD 冗餘的重宣告"
 
-#: cp/decl.cc:2412
+#: cp/decl.cc:2407
 #, fuzzy, gcc-internal-format
 msgid "deleted definition of %qD is not first declaration"
 msgstr "刪除的定義的 %qD"
@@ -57466,44 +57471,44 @@ msgstr "刪除的定義的 %qD"
 #. that specialization that would cause an implicit
 #. instantiation to take place, in every translation unit in
 #. which such a use occurs.
-#: cp/decl.cc:2910
+#: cp/decl.cc:2905
 #, gcc-internal-format
 msgid "explicit specialization of %qD after first use"
 msgstr "在初次使用後明確特例化 %qD"
 
-#: cp/decl.cc:3092
+#: cp/decl.cc:3087
 #, fuzzy, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
 msgstr "『setter』屬性的內容 %qD 衝突與前一個宣告"
 
 #. Reject two definitions.
-#: cp/decl.cc:3356 cp/decl.cc:3385 cp/decl.cc:3423 cp/decl.cc:3440
-#: cp/decl.cc:3539
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#D"
 msgstr "重複定義的 %q#D"
 
-#: cp/decl.cc:3372
+#: cp/decl.cc:3381
 #, fuzzy, gcc-internal-format
 msgid "%qD conflicts with used function"
 msgstr "%qD 衝突與使用的函式"
 
-#: cp/decl.cc:3382
+#: cp/decl.cc:3391
 #, fuzzy, gcc-internal-format
 msgid "%q#D not declared in class"
 msgstr "%q#D 無法宣告的在中類別"
 
-#: cp/decl.cc:3396 cp/decl.cc:3450
+#: cp/decl.cc:3405 cp/decl.cc:3459
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
 msgstr "%q+D redeclared 內聯與 %<gnu_inline%> 屬性"
 
-#: cp/decl.cc:3399 cp/decl.cc:3453
+#: cp/decl.cc:3408 cp/decl.cc:3462
 #, fuzzy, gcc-internal-format
 msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
 msgstr "%q+D redeclared 內聯而無需 %<gnu_inline%> 屬性"
 
-#: cp/decl.cc:3409
+#: cp/decl.cc:3418
 #, gcc-internal-format
 msgid "comparison operator %q+D defaulted after its first declaration"
 msgstr ""
@@ -57511,2605 +57516,2605 @@ msgstr ""
 #. is_primary=
 #. is_partial=
 #. is_friend_decl=
-#: cp/decl.cc:3470
+#: cp/decl.cc:3479
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of friend %q#D may not have default template arguments"
 msgstr "重新宣告的朋友 %q#D 可能無法有預設模板引數"
 
-#: cp/decl.cc:3485
+#: cp/decl.cc:3494
 #, fuzzy, gcc-internal-format
 msgid "thread-local declaration of %q#D follows non-thread-local declaration"
 msgstr "thread-local 宣告的 %q#D 追隨 non-thread-local 宣告"
 
-#: cp/decl.cc:3488
+#: cp/decl.cc:3497
 #, fuzzy, gcc-internal-format
 msgid "non-thread-local declaration of %q#D follows thread-local declaration"
 msgstr "non-thread-local 宣告的 %q#D 追隨 thread-local 宣告"
 
-#: cp/decl.cc:3503 cp/decl.cc:3547 cp/name-lookup.cc:2890
-#: cp/name-lookup.cc:3398 cp/name-lookup.cc:3401 cp/name-lookup.cc:3424
-#: cp/name-lookup.cc:3427
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D"
 msgstr "重新宣告的 %q#D"
 
-#: cp/decl.cc:3530
+#: cp/decl.cc:3539
 #, fuzzy, gcc-internal-format
 #| msgid "redundant redeclaration of %qD in same scope"
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
 msgstr "同一作用欄位中 %qD 冗餘的重宣告"
 
-#: cp/decl.cc:3598
+#: cp/decl.cc:3607
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
 msgstr ""
 
-#: cp/decl.cc:3599
+#: cp/decl.cc:3608
 #, fuzzy, gcc-internal-format
 msgid "previous label"
 msgstr "前一個宣告"
 
-#: cp/decl.cc:3689
+#: cp/decl.cc:3698
 #, gcc-internal-format
 msgid "jump to label %qD"
 msgstr "跳轉至標籤 %qD"
 
-#: cp/decl.cc:3690
+#: cp/decl.cc:3699
 #, gcc-internal-format
 msgid "jump to case label"
 msgstr "跳轉至 case 標籤"
 
-#: cp/decl.cc:3694
+#: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
 msgstr ""
 
-#: cp/decl.cc:3696
+#: cp/decl.cc:3705
 #, gcc-internal-format
 msgid "  from here"
 msgstr "  從這裡"
 
-#: cp/decl.cc:3724 cp/decl.cc:3962
+#: cp/decl.cc:3733 cp/decl.cc:3971
 #, fuzzy, gcc-internal-format
 msgid "  exits OpenMP structured block"
 msgstr "  離開 OpenMP 結構化訊息塊"
 
-#: cp/decl.cc:3749
+#: cp/decl.cc:3758
 #, fuzzy, gcc-internal-format
 #| msgid "  crosses initialization of %q+#D"
 msgid "  crosses initialization of %q#D"
 msgstr "  略過 %q+#D 的初始化"
 
-#: cp/decl.cc:3761 cp/decl.cc:3928
+#: cp/decl.cc:3770 cp/decl.cc:3937
 #, fuzzy, gcc-internal-format
 #| msgid "  enters try block"
 msgid "  enters %<try%> block"
 msgstr "  進入 try 區塊"
 
-#: cp/decl.cc:3767 cp/decl.cc:3917 cp/decl.cc:3930
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
 #, fuzzy, gcc-internal-format
 #| msgid "  enters catch block"
 msgid "  enters %<catch%> block"
 msgstr "  進入 catch 區塊"
 
-#: cp/decl.cc:3773 cp/decl.cc:3944
+#: cp/decl.cc:3782 cp/decl.cc:3953
 #, fuzzy, gcc-internal-format
 msgid "  enters OpenMP structured block"
 msgstr "  輸入 OpenMP 結構化訊息塊"
 
-#: cp/decl.cc:3779 cp/decl.cc:3932
+#: cp/decl.cc:3788 cp/decl.cc:3941
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
 msgstr ""
 
-#: cp/decl.cc:3785 cp/decl.cc:3938
+#: cp/decl.cc:3794 cp/decl.cc:3947
 #, fuzzy, gcc-internal-format
 #| msgid "jump into statement expression"
 msgid "  enters statement expression"
 msgstr "跳轉至敘述運算式中"
 
-#: cp/decl.cc:3792 cp/decl.cc:3934
+#: cp/decl.cc:3801 cp/decl.cc:3943
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "  enters %<constexpr if%> statement"
 msgstr "需要敘述"
 
-#: cp/decl.cc:3798 cp/decl.cc:3936
+#: cp/decl.cc:3807 cp/decl.cc:3945
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "  enters %<consteval if%> statement"
 msgstr "需要敘述"
 
-#: cp/decl.cc:3829 cp/decl.cc:4003
+#: cp/decl.cc:3838 cp/decl.cc:4012
 #, fuzzy, gcc-internal-format
 msgid "  does not destroy %qD"
 msgstr "ISO C99 不支援 %qE"
 
-#: cp/decl.cc:3831 cp/decl.cc:3986
+#: cp/decl.cc:3840 cp/decl.cc:3995
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not declare a template type"
 msgid "  does not clean up handled exception"
 msgstr "%qD 沒有宣告一個範本類型"
 
-#: cp/decl.cc:3922
+#: cp/decl.cc:3931
 #, fuzzy, gcc-internal-format
 #| msgid "  skips initialization of %q+#D"
 msgid "  skips initialization of %q#D"
 msgstr "  略過 %q+#D 的初始化"
 
-#: cp/decl.cc:4463 cp/parser.cc:7205
+#: cp/decl.cc:4472 cp/parser.cc:7205
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "%qD used without template arguments"
 msgstr "%qD 使用時未帶範本參數"
 
-#: cp/decl.cc:4469
+#: cp/decl.cc:4478
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is a function, not a type"
 msgstr "%qD 不是一個函式範本"
 
-#: cp/decl.cc:4480
+#: cp/decl.cc:4489
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class"
 msgstr "%q#T 並非類別"
 
-#: cp/decl.cc:4519 cp/decl.cc:4620
+#: cp/decl.cc:4528 cp/decl.cc:4629
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
 msgstr "沒具名為 %q#T 的類別範本，在%q#T 中 "
 
-#: cp/decl.cc:4520
+#: cp/decl.cc:4529
 #, gcc-internal-format
 msgid "no type named %q#T in %q#T"
 msgstr "沒具名為 %q#T 的類型，在%q#T 中 "
 
-#: cp/decl.cc:4533
+#: cp/decl.cc:4542
 #, fuzzy, gcc-internal-format
 msgid "lookup of %qT in %qT is ambiguous"
 msgstr "查找的 %qT 在中 %qT 是模稜兩可的"
 
-#: cp/decl.cc:4542
+#: cp/decl.cc:4551
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#T, which is not a class template"
 msgstr "%<typename %T::%D%> 名稱 %q#T, 該項並非類別模板"
 
-#: cp/decl.cc:4555
+#: cp/decl.cc:4564
 #, fuzzy, gcc-internal-format
 msgid "%<typename %T::%D%> names %q#D, which is not a type"
 msgstr "%<typename %T::%D%> 名稱 %q#T, 該項並非型態"
 
-#: cp/decl.cc:4629
+#: cp/decl.cc:4638
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template parameters do not match template %qD"
 msgstr "範本參數與範本不符"
 
-#: cp/decl.cc:4986
+#: cp/decl.cc:4995
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "%<-faligned-new=%d%> is not a power of two"
 msgstr "要求的對齊邊界不是 2 的某次方"
 
-#: cp/decl.cc:5160
+#: cp/decl.cc:5169
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5164
+#: cp/decl.cc:5173
 #, gcc-internal-format
 msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5177
+#: cp/decl.cc:5186
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is less than %d"
 msgstr ""
 
-#: cp/decl.cc:5182
+#: cp/decl.cc:5191
 #, gcc-internal-format
 msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
 msgstr ""
 
-#: cp/decl.cc:5509
+#: cp/decl.cc:5518
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D 無效；匿名聯合只能有非靜態的資料成員"
 
-#: cp/decl.cc:5519 cp/parser.cc:23596
+#: cp/decl.cc:5528 cp/parser.cc:23596
 #, fuzzy, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "%<mwords-little-endian%> 被不宜用而將被  移除的在中未來釋出"
 
-#: cp/decl.cc:5548
+#: cp/decl.cc:5557
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous struct not inside named type"
 msgid "anonymous struct with base classes"
 msgstr "匿名結構不在具名類型內"
 
-#: cp/decl.cc:5560
+#: cp/decl.cc:5569
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in anonymous aggregate"
 msgstr "有建構式的成員 %q+#D 不允許在匿名聚合中出現"
 
-#: cp/decl.cc:5563
+#: cp/decl.cc:5572
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in anonymous aggregate"
 msgstr "有構構函式的成員 %q+#D 不允許在匿名聚合中出現"
 
-#: cp/decl.cc:5566
+#: cp/decl.cc:5575
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
 msgstr "有複製賦值運算子的成員 %q+#D 不能用在聯合中"
 
-#: cp/decl.cc:5585
+#: cp/decl.cc:5594
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in declaration of %q#T"
 msgstr "屬性忽略的在中宣告的 %q#T"
 
-#: cp/decl.cc:5588
+#: cp/decl.cc:5597
 #, fuzzy, gcc-internal-format
 msgid "attribute for %q#T must follow the %qs keyword"
 msgstr "屬性用於 %q#T 必須追隨 %qs 關鍵字"
 
-#: cp/decl.cc:5630
+#: cp/decl.cc:5639
 #, gcc-internal-format
 msgid "multiple types in one declaration"
 msgstr "一個宣告指定了多個類型"
 
-#: cp/decl.cc:5635
+#: cp/decl.cc:5644
 #, gcc-internal-format
 msgid "redeclaration of C++ built-in type %qT"
 msgstr "對 C++ 內建類型 %qT 的重宣告"
 
-#: cp/decl.cc:5652
+#: cp/decl.cc:5661
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> can only be specified for variables or function declarations"
 msgstr "%<auto%> 只能被指定的用於變數或函式宣告"
 
-#: cp/decl.cc:5685
+#: cp/decl.cc:5694
 #, gcc-internal-format
 msgid "missing type-name in typedef-declaration"
 msgstr "typedef 宣告中缺少類型名"
 
-#: cp/decl.cc:5693
+#: cp/decl.cc:5702
 #, gcc-internal-format
 msgid "ISO C++ prohibits anonymous structs"
 msgstr "ISO C++ 不允許匿名結構"
 
-#: cp/decl.cc:5700
+#: cp/decl.cc:5709
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<inline%> can only be specified for functions"
 msgstr "只能為函式指定 %qs"
 
-#: cp/decl.cc:5703
+#: cp/decl.cc:5712
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<virtual%> can only be specified for functions"
 msgstr "只能為函式指定 %qs"
 
-#: cp/decl.cc:5708
+#: cp/decl.cc:5717
 #, gcc-internal-format
 msgid "%<friend%> can only be specified inside a class"
 msgstr "%<friend%> 只能在類別中指定"
 
-#: cp/decl.cc:5711
+#: cp/decl.cc:5720
 #, gcc-internal-format
 msgid "%<explicit%> can only be specified for constructors"
 msgstr "只能為建構式指定 %<explicit%>"
 
-#: cp/decl.cc:5714
+#: cp/decl.cc:5723
 #, gcc-internal-format
 msgid "a storage class can only be specified for objects and functions"
 msgstr "只能為物件和函式指定存儲類別"
 
-#: cp/decl.cc:5718
+#: cp/decl.cc:5727
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<const%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定類型限定"
 
-#: cp/decl.cc:5722
+#: cp/decl.cc:5731
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<volatile%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定類型限定"
 
-#: cp/decl.cc:5726
+#: cp/decl.cc:5735
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers can only be specified for objects and functions"
 msgid "%<__restrict%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定類型限定"
 
-#: cp/decl.cc:5730
+#: cp/decl.cc:5739
 #, fuzzy, gcc-internal-format
 #| msgid "a storage class can only be specified for objects and functions"
 msgid "%<__thread%> can only be specified for objects and functions"
 msgstr "只能為物件和函式指定存儲類別"
 
-#: cp/decl.cc:5734
+#: cp/decl.cc:5743
 #, fuzzy, gcc-internal-format
 msgid "%<typedef%> was ignored in this declaration"
 msgstr "%<typedef%> 被忽略在中這個宣告"
 
-#: cp/decl.cc:5737 cp/decl.cc:5740 cp/decl.cc:5743
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be used for type declarations"
 msgstr "%<constexpr%> 無法用於類型宣告"
 
-#: cp/decl.cc:5765
+#: cp/decl.cc:5774
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
 msgstr "屬性忽略的於模板具現化"
 
-#: cp/decl.cc:5768
+#: cp/decl.cc:5777
 #, fuzzy, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
 msgstr "只能為類別定義套用 %qE 屬性"
 
-#: cp/decl.cc:5847
+#: cp/decl.cc:5856
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to class type %qT outside of definition"
 msgstr "忽略屬性套用到類別型態 %qT 外側的定義"
 
 #. A template type parameter or other dependent type.
-#: cp/decl.cc:5851
+#: cp/decl.cc:5860
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
 msgstr "忽略屬性套用到附屬型態 %qT 而無需關聯的宣告"
 
-#: cp/decl.cc:5917 cp/decl2.cc:1064
+#: cp/decl.cc:5926 cp/decl2.cc:1064
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD is initialized (use %qs instead)"
 msgstr "typedef %qD 被初始化的 (使用 decltype 做為替代)"
 
-#: cp/decl.cc:5930
+#: cp/decl.cc:5939
 #, gcc-internal-format
 msgid "declaration of %q#D has %<extern%> and is initialized"
 msgstr "%q#D 宣告有 %<extern%> 並被初始化"
 
-#: cp/decl.cc:5968
+#: cp/decl.cc:5977
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#D is marked %<dllimport%>"
 msgstr "定義的 %q#D 被標記 %<dllimport%>"
 
-#: cp/decl.cc:5992
+#: cp/decl.cc:6001
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%q+#D is not a static data member of %q#T"
 msgstr "%q#D 不是 %qT 的非靜態資料成員"
 
-#: cp/decl.cc:6000
+#: cp/decl.cc:6009
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member-template declaration of %qD"
 msgstr "%q#D 宣告為範本"
 
-#: cp/decl.cc:6001
+#: cp/decl.cc:6010
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration %qD"
 msgid "does not match member template declaration here"
 msgstr "無效的成員範本宣告 %qD"
 
-#: cp/decl.cc:6013
+#: cp/decl.cc:6022
 #, gcc-internal-format
 msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
 msgstr "ISO C++ 不允許將 %<%T::%D%> 定義為 %<%T::%D%>"
 
-#: cp/decl.cc:6025
+#: cp/decl.cc:6034
 #, gcc-internal-format
 msgid "duplicate initialization of %qD"
 msgstr "ISO C++ 不允許成員 %qD 的初始化"
 
-#: cp/decl.cc:6075 cp/decl.cc:6079
+#: cp/decl.cc:6084 cp/decl.cc:6088
 #, gcc-internal-format
 msgid "declaration of %q#D outside of class is not definition"
 msgstr "出現在類別外的 %q#D 的宣告不是定義"
 
-#: cp/decl.cc:6097
+#: cp/decl.cc:6106
 #, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
 msgstr ""
 
-#: cp/decl.cc:6133
+#: cp/decl.cc:6142
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.cc:6139
+#: cp/decl.cc:6148
 #, fuzzy, gcc-internal-format
 msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.cc:6205
+#: cp/decl.cc:6214
 #, gcc-internal-format
 msgid "variable %q#D has initializer but incomplete type"
 msgstr "變數 %q#D 有初始值設定，但是類型不完全"
 
-#: cp/decl.cc:6214 cp/decl.cc:7548
+#: cp/decl.cc:6223 cp/decl.cc:7557
 #, gcc-internal-format
 msgid "elements of array %q#D have incomplete type"
 msgstr "陣列 %q#D 的元素類型不完全"
 
-#: cp/decl.cc:6225
+#: cp/decl.cc:6234
 #, gcc-internal-format
 msgid "aggregate %q#D has incomplete type and cannot be defined"
 msgstr "聚合 %q#D 類型不完全，無法被定義"
 
-#: cp/decl.cc:6295
+#: cp/decl.cc:6304
 #, gcc-internal-format
 msgid "%qD declared as reference but not initialized"
 msgstr "%qD 宣告為參照卻未被初始化"
 
-#: cp/decl.cc:6378
+#: cp/decl.cc:6387
 #, fuzzy, gcc-internal-format
 msgid "name used in a GNU-style designated initializer for an array"
 msgstr "名稱已用於 GNU-style 指定的初始設定式用於陣列"
 
-#: cp/decl.cc:6384
+#: cp/decl.cc:6393
 #, gcc-internal-format
 msgid "name %qD used in a GNU-style designated initializer for an array"
 msgstr "名稱 %qD 用在 GNU 風格的陣列指定元素初始值設定中"
 
-#: cp/decl.cc:6403
+#: cp/decl.cc:6412
 #, gcc-internal-format
 msgid "non-trivial designated initializers not supported"
 msgstr "不平凡的代理初始值設定不受支援"
 
-#: cp/decl.cc:6407
+#: cp/decl.cc:6416
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "C99 designator %qE is not an integral constant-expression"
 msgstr "陣列 %qD 的大小不是一個整數常運算式"
 
-#: cp/decl.cc:6468
+#: cp/decl.cc:6477
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qD"
 msgstr "初始值設定無法決定 %qD 的大小"
 
-#: cp/decl.cc:6475
+#: cp/decl.cc:6484
 #, gcc-internal-format
 msgid "array size missing in %qD"
 msgstr "%qD 缺少陣列大小"
 
-#: cp/decl.cc:6487
+#: cp/decl.cc:6496
 #, gcc-internal-format
 msgid "zero-size array %qD"
 msgstr "大小為 0 的陣列 %qD"
 
-#: cp/decl.cc:6527
+#: cp/decl.cc:6536
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t known"
 msgstr "貯藏大小的 %qD isn%'t 已知"
 
-#: cp/decl.cc:6552
+#: cp/decl.cc:6561
 #, fuzzy, gcc-internal-format
 msgid "storage size of %qD isn%'t constant"
 msgstr "貯藏大小的 %qD isn%'t 常數"
 
-#: cp/decl.cc:6636
+#: cp/decl.cc:6645
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "抱歉：語意的內聯函式靜態資料 %q+#D 是錯誤的 (you%'ll 旋緊向上與多重份數)"
 
-#: cp/decl.cc:6640
+#: cp/decl.cc:6649
 #, fuzzy, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
 msgstr "抱歉：語意的內聯函式靜態資料 %q+#D 是錯誤的 (you%'ll 旋緊向上與多重份數)"
 
-#: cp/decl.cc:6646
+#: cp/decl.cc:6655
 #, fuzzy, gcc-internal-format
 msgid "you can work around this by removing the initializer"
 msgstr "  您可以解決方法這個由移除初始設定式"
 
-#: cp/decl.cc:6688 rust/backend/rust-tree.cc:3278
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD"
 msgid "uninitialized %<const %D%>"
 msgstr "未初始化的常數 %qD"
 
-#: cp/decl.cc:6695 rust/backend/rust-tree.cc:3285
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "uninitialized 成員 %qD 在中 %<constexpr%> 建構子"
 
-#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3294
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
 msgstr "uninitialized 成員 %qD 在中 %<constexpr%> 建構子"
 
-#: cp/decl.cc:6712
+#: cp/decl.cc:6721
 #, fuzzy, gcc-internal-format
 msgid "%q#T has no user-provided default constructor"
 msgstr "%q#T 沒有任何 user-provided 預設建構函式"
 
-#: cp/decl.cc:6716
+#: cp/decl.cc:6725
 #, fuzzy, gcc-internal-format
 msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
 msgstr "建構子未被 user-provided 因為它是明確的缺席在中類別本體"
 
-#: cp/decl.cc:6719
+#: cp/decl.cc:6728
 #, fuzzy, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
 msgstr "和 implicitly-defined 建構子不初始化 %q+#D"
 
-#: cp/decl.cc:6912
+#: cp/decl.cc:6921
 #, gcc-internal-format
 msgid "invalid type %qT as initializer for a vector of type %qT"
 msgstr "無效類型 %qT 做為類型為 %qT 的向量的初始化設定"
 
-#: cp/decl.cc:6984
+#: cp/decl.cc:6993
 #, gcc-internal-format
 msgid "initializer for %qT must be brace-enclosed"
 msgstr "%qT 的初始化設定必須在大括號內"
 
-#: cp/decl.cc:7028
+#: cp/decl.cc:7037
 #, fuzzy, gcc-internal-format
 msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
 msgstr "%<[%E]=%>已用於 GNU-style 指定的初始設定式用於類別 %qT"
 
-#: cp/decl.cc:7044 cp/init.cc:3407 cp/search.cc:1230
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "對成員 %qD 的請求有歧義"
 
-#: cp/decl.cc:7049
+#: cp/decl.cc:7058
 #, gcc-internal-format
 msgid "%qT has no non-static data member named %qD"
 msgstr "%qT 沒具名為 %qD 的非靜態資料成員"
 
-#: cp/decl.cc:7074
+#: cp/decl.cc:7083
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD is not a direct member of %qT"
 msgstr "%qD 不是 %qT 的成員"
 
-#: cp/decl.cc:7129
+#: cp/decl.cc:7138
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for %q#D"
 msgstr "無效的初始設定式用於陣列成員 %q#D"
 
-#: cp/decl.cc:7179
+#: cp/decl.cc:7188
 #, fuzzy, gcc-internal-format
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 指示項 %qE 外側彙總初始設定式"
 
-#: cp/decl.cc:7218 cp/decl.cc:7506 cp/typeck2.cc:1593 cp/typeck2.cc:1923
-#: cp/typeck2.cc:1971 cp/typeck2.cc:2018
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT 的初始值設定項太多"
 
-#: cp/decl.cc:7260
+#: cp/decl.cc:7269
 #, gcc-internal-format
 msgid "braces around scalar initializer for type %qT"
 msgstr "類型 %qT 的標量初始化帶大括號"
 
-#: cp/decl.cc:7270
+#: cp/decl.cc:7279
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer for type %qT"
 msgid "too many braces around scalar initializer for type %qT"
 msgstr "類型 %qT 的標量初始化帶大括號"
 
-#: cp/decl.cc:7403
+#: cp/decl.cc:7412
 #, gcc-internal-format
 msgid "missing braces around initializer for %qT"
 msgstr "%qT 的初始值設定周圍缺少大括號"
 
-#: cp/decl.cc:7536
+#: cp/decl.cc:7545
 #, fuzzy, gcc-internal-format
 msgid "structured binding has incomplete type %qT"
 msgstr "來源是指標到不完整型態"
 
-#: cp/decl.cc:7550
+#: cp/decl.cc:7559
 #, fuzzy, gcc-internal-format
 msgid "elements of array %q#T have incomplete type"
 msgstr "元件的陣列 %q#T 有不完整型態"
 
-#: cp/decl.cc:7563
+#: cp/decl.cc:7572
 #, fuzzy, gcc-internal-format
 msgid "variable-sized compound literal"
 msgstr "variable-sized 複合實字"
 
-#: cp/decl.cc:7619
+#: cp/decl.cc:7628
 #, fuzzy, gcc-internal-format
 msgid "%q#D has incomplete type"
 msgstr "%q#D 有不完整型態"
 
-#: cp/decl.cc:7640
+#: cp/decl.cc:7649
 #, fuzzy, gcc-internal-format
 msgid "scalar object %qD requires one element in initializer"
 msgstr "純量物件 %qD 需求一個元件在中初始設定式"
 
-#: cp/decl.cc:7685
+#: cp/decl.cc:7694
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
 msgstr "在中 C++98 %qD 必須被初始化的由建構子，無法由 %<{...}%>"
 
-#: cp/decl.cc:7828
+#: cp/decl.cc:7837
 #, gcc-internal-format
 msgid "array %qD initialized by parenthesized string literal %qE"
 msgstr "陣列 %qD 被有括號的字面字串 %qE 所初始化"
 
-#: cp/decl.cc:7867
+#: cp/decl.cc:7876
 #, gcc-internal-format
 msgid "initializer invalid for static member with constructor"
 msgstr "建構式中對靜態成員的初始化無效"
 
-#: cp/decl.cc:7869
+#: cp/decl.cc:7878
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for static member %qD"
 msgstr "non-constant in-class 初始化無效的用於靜態成員 %qD"
 
-#: cp/decl.cc:7872
+#: cp/decl.cc:7881
 #, fuzzy, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
 msgstr "non-constant in-class 初始化無效的用於靜態成員 %qD"
 
-#: cp/decl.cc:7877
+#: cp/decl.cc:7886
 #, gcc-internal-format
 msgid "(an out of class initialization is required)"
 msgstr "(需要一個類別外的初始化)"
 
-#: cp/decl.cc:8079
+#: cp/decl.cc:8088
 #, fuzzy, gcc-internal-format
 msgid "reference %qD is initialized with itself"
 msgstr "%qD 被初始化的以其本身"
 
-#: cp/decl.cc:8338
+#: cp/decl.cc:8347
 #, fuzzy, gcc-internal-format
 msgid "could not find variant declaration"
 msgstr "%<[*]%>無法在中宣告"
 
-#: cp/decl.cc:8362
+#: cp/decl.cc:8371
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on constructor %qD"
 msgstr "太少引數到建構子 %q#D"
 
-#: cp/decl.cc:8367
+#: cp/decl.cc:8376
 #, fuzzy, gcc-internal-format
 msgid "%<declare variant%> on destructor %qD"
 msgstr "需位址的解構式 %qE"
 
-#: cp/decl.cc:8372
+#: cp/decl.cc:8381
 #, gcc-internal-format
 msgid "%<declare variant%> on defaulted %qD"
 msgstr ""
 
-#: cp/decl.cc:8377
+#: cp/decl.cc:8386
 #, gcc-internal-format
 msgid "%<declare variant%> on deleted %qD"
 msgstr ""
 
-#: cp/decl.cc:8382
+#: cp/decl.cc:8391
 #, gcc-internal-format
 msgid "%<declare variant%> on virtual %qD"
 msgstr ""
 
-#: cp/decl.cc:8436
+#: cp/decl.cc:8445
 #, gcc-internal-format
 msgid "assignment (not initialization) in declaration"
 msgstr "賦值(不是初始化)出現在宣告中"
 
-#: cp/decl.cc:8457 cp/decl.cc:15234
+#: cp/decl.cc:8466 cp/decl.cc:15250
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ 不允許指定元素初始值設定"
 
-#: cp/decl.cc:8461 cp/decl.cc:15238
+#: cp/decl.cc:8470 cp/decl.cc:15254
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
 msgstr "為 %qs 指定了存儲類別"
 
-#: cp/decl.cc:8506 cp/decl.cc:15201
+#: cp/decl.cc:8515 cp/decl.cc:15217
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "宣告的 %q#D 沒有任何初始設定式"
 
-#: cp/decl.cc:8542
+#: cp/decl.cc:8551
 #, fuzzy, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
 msgstr "無效的使用的成員函式 (did 您忘記%<()%>?)"
 
-#: cp/decl.cc:8553
+#: cp/decl.cc:8562
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "deduced type %qT for %qD is incomplete"
 msgstr "回傳值類型 %q#T 為不完全"
 
-#: cp/decl.cc:8691
+#: cp/decl.cc:8700
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "variable concept has no initializer"
 msgstr "可變大小的物件不能被初始化"
 
-#: cp/decl.cc:8750
+#: cp/decl.cc:8759
 #, gcc-internal-format
 msgid "shadowing previous type declaration of %q#D"
 msgstr "隱藏了早先的類型宣告 %q#D"
 
-#: cp/decl.cc:8793
+#: cp/decl.cc:8802
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
 msgstr "%qE 屬性只有套用到變數和函式"
 
-#: cp/decl.cc:8988
+#: cp/decl.cc:8997
 #, gcc-internal-format
 msgid "function %q#D is initialized like a variable"
 msgstr "函式 %q#D 像變數一樣被初始化"
 
-#: cp/decl.cc:9099
+#: cp/decl.cc:9108
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  不能在 %q+D 使用過時的繫結，因為它有解構函式"
 
-#: cp/decl.cc:9102
+#: cp/decl.cc:9111
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.cc:9109
+#: cp/decl.cc:9118
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT 是 %qT 不可存取的基礎類別"
 
-#: cp/decl.cc:9135
+#: cp/decl.cc:9144
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9144
+#: cp/decl.cc:9153
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.cc:9381
+#: cp/decl.cc:9390
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "來源是指標到不完整型態"
 
-#: cp/decl.cc:9397
+#: cp/decl.cc:9406
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 禁止變數長度陣列 %qE"
 
-#: cp/decl.cc:9406 cp/decl.cc:9485
+#: cp/decl.cc:9415 cp/decl.cc:9494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs 指定的用於結構欄位"
 
-#: cp/decl.cc:9410
+#: cp/decl.cc:9419
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.cc:9413
+#: cp/decl.cc:9422
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.cc:9454
+#: cp/decl.cc:9463
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "無法宣告參照 %q#T 的指標"
 
-#: cp/decl.cc:9478
+#: cp/decl.cc:9487
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "陣列大小不是一個整數常運算式"
 
-#: cp/decl.cc:9487
+#: cp/decl.cc:9496
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.cc:9508
+#: cp/decl.cc:9517
 #, gcc-internal-format
 msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
 msgstr ""
 
-#: cp/decl.cc:9514
+#: cp/decl.cc:9523
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "value-initialization 的函數型式 %qT"
 
-#: cp/decl.cc:9543
+#: cp/decl.cc:9552
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/decl.cc:9548
+#: cp/decl.cc:9557
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員指標"
 
-#: cp/decl.cc:9553
+#: cp/decl.cc:9562
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "無法分解位址"
 
-#: cp/decl.cc:9559
+#: cp/decl.cc:9568
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "來源是的不完整類別型態"
 
-#: cp/decl.cc:9568
+#: cp/decl.cc:9577
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "無法套用 %<offsetof%> 到靜態資料成員 %qD"
 
-#: cp/decl.cc:10046
+#: cp/decl.cc:10062
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.cc:10049
+#: cp/decl.cc:10065
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T 有 non-trivial 解構式"
 
-#: cp/decl.cc:10054
+#: cp/decl.cc:10070
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.cc:10273
+#: cp/decl.cc:10289
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初始設定式失敗到決定大小的 %qT"
 
-#: cp/decl.cc:10277
+#: cp/decl.cc:10293
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "陣列大小缺少的在中 %qT"
 
-#: cp/decl.cc:10280
+#: cp/decl.cc:10296
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "zero-size 陣列 %qT"
 
-#: cp/decl.cc:10296
+#: cp/decl.cc:10312
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "其它類別 %qT 的解構函式不能做為成員"
 
-#: cp/decl.cc:10298
+#: cp/decl.cc:10314
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "其它類別 %qT 的建構式不能做為成員"
 
-#: cp/decl.cc:10324
+#: cp/decl.cc:10340
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD 宣告的做為 %<virtual%> 變數"
 
-#: cp/decl.cc:10326
+#: cp/decl.cc:10342
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中變數宣告"
 
-#: cp/decl.cc:10332
+#: cp/decl.cc:10348
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD 宣告的做為 %<virtual%> 參數"
 
-#: cp/decl.cc:10335
+#: cp/decl.cc:10351
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD 宣告的做為 %<inline%> 參數"
 
-#: cp/decl.cc:10337
+#: cp/decl.cc:10353
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中參數宣告"
 
-#: cp/decl.cc:10343
+#: cp/decl.cc:10359
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD 宣告的做為 %<virtual%> 型態"
 
-#: cp/decl.cc:10346
+#: cp/decl.cc:10362
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD 宣告的做為 %<inline%> 型態"
 
-#: cp/decl.cc:10348
+#: cp/decl.cc:10364
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中類型宣告"
 
-#: cp/decl.cc:10354
+#: cp/decl.cc:10370
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD 宣告的做為 %<virtual%> 欄位"
 
-#: cp/decl.cc:10357
+#: cp/decl.cc:10373
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD 宣告的做為 %<inline%> 欄位"
 
-#: cp/decl.cc:10359
+#: cp/decl.cc:10375
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中欄位宣告"
 
-#: cp/decl.cc:10366
+#: cp/decl.cc:10382
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/decl.cc:10373
+#: cp/decl.cc:10389
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D 宣告時有異常指定"
 
-#: cp/decl.cc:10405
+#: cp/decl.cc:10421
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD 的定義不在包含 %qT 的命名空間中"
 
-#: cp/decl.cc:10445
+#: cp/decl.cc:10461
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "靜態成員函式 %q#D 的宣告帶有類型限定符"
 
-#: cp/decl.cc:10456
+#: cp/decl.cc:10472
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD 宣告的做為 non-parameter"
 
-#: cp/decl.cc:10463
+#: cp/decl.cc:10479
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "使舊的宣告 %q+#D 出現歧義"
 
-#: cp/decl.cc:10466
+#: cp/decl.cc:10482
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java 方法 %qD 回傳非 Java 類型 %qT"
 
-#: cp/decl.cc:10542
+#: cp/decl.cc:10558
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "預期 %<;%>之後聯合定義"
 
-#: cp/decl.cc:10571
+#: cp/decl.cc:10587
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a function concept cannot be constrained"
 msgstr "虛函式不能是夥伴"
 
-#: cp/decl.cc:10586
+#: cp/decl.cc:10602
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template function"
 msgid "constraints on a non-templated function"
 msgstr "%qD 不是一個範本函式"
 
-#: cp/decl.cc:10588
+#: cp/decl.cc:10604
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration not in class definition"
 msgid "constrained non-template friend declaration must be a definition"
 msgstr "夥伴宣告不在類別定義內"
 
-#: cp/decl.cc:10595
+#: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
 msgstr ""
 
-#: cp/decl.cc:10644
+#: cp/decl.cc:10660
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "在夥伴宣告中定義明確特例化 %qD"
 
-#: cp/decl.cc:10655
+#: cp/decl.cc:10671
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "在基本範本的宣告中對範本識別碼 %qD 的使用無效"
 
-#: cp/decl.cc:10673
+#: cp/decl.cc:10689
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "夥伴範本特例化 %qD 中不允許出現預設參數"
 
-#: cp/decl.cc:10682
+#: cp/decl.cc:10698
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> 不允許用於夥伴範本特例化 %qD 的宣告"
 
-#: cp/decl.cc:10699
+#: cp/decl.cc:10715
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
 msgstr "出現在類別外的 %q#D 的宣告不是定義"
 
-#: cp/decl.cc:10741
+#: cp/decl.cc:10757
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "不能將 %<::main%> 宣告為一個範本"
 
-#: cp/decl.cc:10744
+#: cp/decl.cc:10760
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "不能將 %<::main%> 宣告為 inline"
 
-#: cp/decl.cc:10747 cp/decl.cc:10750
+#: cp/decl.cc:10763 cp/decl.cc:10766
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be static"
 msgid "cannot declare %<::main%> to be %qs"
 msgstr "不能將 %<::main%> 宣告為 static"
 
-#: cp/decl.cc:10752
+#: cp/decl.cc:10768
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "不能將 %<::main%> 宣告為 static"
 
-#: cp/decl.cc:10819
+#: cp/decl.cc:10835
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.cc:10821
+#: cp/decl.cc:10837
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "靜態成員函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.cc:10822
+#: cp/decl.cc:10838
 #, fuzzy, gcc-internal-format
 msgid "explicit object member function %qD cannot have cv-qualifier"
 msgstr "靜態成員函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.cc:10827
+#: cp/decl.cc:10843
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.cc:10829
+#: cp/decl.cc:10845
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "靜態成員函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.cc:10830
+#: cp/decl.cc:10846
 #, fuzzy, gcc-internal-format
 msgid "explicit object member function %qD cannot have ref-qualifier"
 msgstr "靜態成員函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.cc:10836 cp/decl.cc:13719 cp/decl.cc:13729 cp/parser.cc:11972
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "explicit object parameter declared here"
 msgstr "範本參數類型 %qT 宣告為 %<friend%>"
 
-#: cp/decl.cc:10848
+#: cp/decl.cc:10864
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must be declared in the same scope as %qT"
 msgstr "特殊化的 %qD 必須出現於命名空間範圍"
 
-#: cp/decl.cc:10856
+#: cp/decl.cc:10872
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must have the same access as %qT"
 msgstr "特殊化的 %qD 必須出現於命名空間範圍"
 
-#: cp/decl.cc:10862
+#: cp/decl.cc:10878
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qD 沒有宣告為一個函式"
 
-#: cp/decl.cc:10875
+#: cp/decl.cc:10891
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "實字運算子與 C 鏈結"
 
-#: cp/decl.cc:10885
+#: cp/decl.cc:10901
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD 有無效的引數清單"
 
-#: cp/decl.cc:10893
+#: cp/decl.cc:10909
 #, fuzzy, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "整數字尾 %<%s%>帶陰影由實作"
 
-#: cp/decl.cc:10899
+#: cp/decl.cc:10915
 #, fuzzy, gcc-internal-format
 msgid "floating-point suffix %qs shadowed by implementation"
 msgstr "浮點數字尾 %<%s%>帶陰影由實作"
 
-#: cp/decl.cc:10906
+#: cp/decl.cc:10922
 #, fuzzy, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "實字運算子字尾無法前繼的由 %<_%>被保留的用於未來標準化"
 
-#: cp/decl.cc:10911
+#: cp/decl.cc:10927
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD 必須是 non-member 函式"
 
-#: cp/decl.cc:10997
+#: cp/decl.cc:11013
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> 必須回傳 %<int%>"
 
-#: cp/decl.cc:11037
+#: cp/decl.cc:11053
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "隱含宣告的 %qD 的定義"
 
-#: cp/decl.cc:11042
+#: cp/decl.cc:11058
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "定義的 explicitly-defaulted %q+D"
 
-#: cp/decl.cc:11044
+#: cp/decl.cc:11060
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D 明確的缺席在此"
 
-#: cp/decl.cc:11061
+#: cp/decl.cc:11077
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "成員函式 %q#D 未在類別 %qT 中宣告"
 
-#: cp/decl.cc:11255
+#: cp/decl.cc:11271
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "不能將 %<::main%> 宣告為一個範本"
 
-#: cp/decl.cc:11264
+#: cp/decl.cc:11280
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "自動變數 %qE 無法 %<threadprivate%>"
 
-#: cp/decl.cc:11270
+#: cp/decl.cc:11286
 #, fuzzy, gcc-internal-format
 msgid "concept must be defined at namespace scope"
 msgstr "特殊化的 %qD 必須出現於命名空間範圍"
 
-#: cp/decl.cc:11277
+#: cp/decl.cc:11293
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.cc:11280
+#: cp/decl.cc:11296
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object may not be initialized"
 msgid "a variable concept cannot be constrained"
 msgstr "可變大小的物件不能被初始化"
 
-#: cp/decl.cc:11402
+#: cp/decl.cc:11418
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "in-class 初始化的靜態資料成員 %q#D 的不完整型態"
 
-#: cp/decl.cc:11406
+#: cp/decl.cc:11422
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> 所需自 in-class 初始化的靜態資料成員 %q#D 的 non-integral 型態"
 
-#: cp/decl.cc:11410
+#: cp/decl.cc:11426
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "in-class 初始化的靜態資料成員 %q#D 的 non-literal 型態"
 
-#: cp/decl.cc:11421
+#: cp/decl.cc:11437
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "類別中對具有非整數類型 %qT 的靜態資料成員的初始化無效"
 
-#: cp/decl.cc:11426
+#: cp/decl.cc:11442
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ 不允許在類別內初始化非常數靜態成員 %qD"
 
-#: cp/decl.cc:11431
+#: cp/decl.cc:11447
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ 不允許初始化成員常數 %qD，因為它有非整數的類型 %qT"
 
-#: cp/decl.cc:11542
+#: cp/decl.cc:11558
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "陣列 %qD 的大小具有非整數類型 %qT"
 
-#: cp/decl.cc:11545
+#: cp/decl.cc:11561
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "陣列 %qT 的大小的類型不是整數"
 
-#: cp/decl.cc:11576 cp/decl.cc:11648
+#: cp/decl.cc:11592 cp/decl.cc:11664
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "陣列 %qD 的大小不是一個整數常運算式"
 
-#: cp/decl.cc:11580 cp/decl.cc:11651
+#: cp/decl.cc:11596 cp/decl.cc:11667
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "陣列大小不是一個整數常運算式"
 
-#: cp/decl.cc:11631
+#: cp/decl.cc:11647
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C 不允許大小為 0 的陣列 %qD"
 
-#: cp/decl.cc:11634
+#: cp/decl.cc:11650
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ 不允許大小為 0 的陣列"
 
-#: cp/decl.cc:11658
+#: cp/decl.cc:11674
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++禁止變數長度陣列 %qD"
 
-#: cp/decl.cc:11661
+#: cp/decl.cc:11677
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++禁止變數長度陣列"
 
-#: cp/decl.cc:11667
+#: cp/decl.cc:11683
 #, fuzzy, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "變數長度陣列 %qD 被使用"
 
-#: cp/decl.cc:11670
+#: cp/decl.cc:11686
 #, fuzzy, gcc-internal-format
 msgid "variable length array is used"
 msgstr "變數長度陣列被使用"
 
-#: cp/decl.cc:11722
+#: cp/decl.cc:11738
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "陣列維數溢出"
 
-#: cp/decl.cc:11782
+#: cp/decl.cc:11798
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of template placeholder type %qT"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/decl.cc:11785
+#: cp/decl.cc:11801
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "creating array of template placeholder type %qT"
 msgstr "產生參照類型 %qT 的成員指標"
 
-#: cp/decl.cc:11795
+#: cp/decl.cc:11811
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "宣告的 %qD 做為陣列的虛值"
 
-#: cp/decl.cc:11797
+#: cp/decl.cc:11813
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "建立陣列的虛值"
 
-#: cp/decl.cc:11802
+#: cp/decl.cc:11818
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "宣告的 %qD 做為陣列的函式"
 
-#: cp/decl.cc:11804
+#: cp/decl.cc:11820
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "建立陣列的函式"
 
-#: cp/decl.cc:11809
+#: cp/decl.cc:11825
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "宣告的 %qD 做為陣列的參考"
 
-#: cp/decl.cc:11811
+#: cp/decl.cc:11827
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "建立陣列的參考"
 
-#: cp/decl.cc:11816
+#: cp/decl.cc:11832
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "宣告的 %qD 做為陣列的函式成員"
 
-#: cp/decl.cc:11819
+#: cp/decl.cc:11835
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "建立陣列的函式成員"
 
-#: cp/decl.cc:11837
+#: cp/decl.cc:11853
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "多維陣列 %qD 的宣告必須至少指定除第一維以外所有維的大小"
 
-#: cp/decl.cc:11841
+#: cp/decl.cc:11857
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "宣告多維陣列必須至少指定除第一維以外所有維的大小"
 
-#: cp/decl.cc:11855
+#: cp/decl.cc:11871
 #, fuzzy, gcc-internal-format
 msgid "variable-length array of %<auto%>"
 msgstr "變數長度陣列被使用"
 
-#: cp/decl.cc:11931
+#: cp/decl.cc:11947
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "為建構式指定回傳值無效"
 
-#: cp/decl.cc:11934
+#: cp/decl.cc:11950
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.cc:11945
+#: cp/decl.cc:11961
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "指定解構函式的回傳類型無效"
 
-#: cp/decl.cc:11948
+#: cp/decl.cc:11964
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.cc:11961
+#: cp/decl.cc:11977
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "為 %<operator %T%> 指定了回傳值"
 
-#: cp/decl.cc:11964
+#: cp/decl.cc:11980
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.cc:11973
+#: cp/decl.cc:11989
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "指定解構函式的回傳類型無效"
 
-#: cp/decl.cc:11976
+#: cp/decl.cc:11992
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.cc:11980
+#: cp/decl.cc:11996
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD 宣告時範本參數表太多"
 
-#: cp/decl.cc:11989
+#: cp/decl.cc:12005
 #, fuzzy, gcc-internal-format
 msgid "%<decl-specifier%> in declaration of deduction guide"
 msgstr "衝突說明符在中宣告的 %qs"
 
-#: cp/decl.cc:12010
+#: cp/decl.cc:12026
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "無名變數或欄位宣告為 void"
 
-#: cp/decl.cc:12018
+#: cp/decl.cc:12034
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "變數或欄位宣告為 void"
 
-#: cp/decl.cc:12033
+#: cp/decl.cc:12049
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<inline%> 無效"
 
-#: cp/decl.cc:12038
+#: cp/decl.cc:12054
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.cc:12094
+#: cp/decl.cc:12110
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/decl.cc:12100
+#: cp/decl.cc:12116
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "%<decltype(auto)%> cannot be cv-qualified"
 msgstr "解構函式不能被 cv 限定"
 
-#: cp/decl.cc:12316
+#: cp/decl.cc:12332
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "無效的使用的限定名稱 %<::%D%>"
 
-#: cp/decl.cc:12319 cp/decl.cc:12341
+#: cp/decl.cc:12335 cp/decl.cc:12357
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "無效的使用的限定名稱 %<%T::%D%>"
 
-#: cp/decl.cc:12322
+#: cp/decl.cc:12338
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "無效的使用的限定名稱 %<%D::%D%>"
 
-#: cp/decl.cc:12332
+#: cp/decl.cc:12348
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or namespace"
 msgstr "%qT 既不是類別也不是命名空間"
 
-#: cp/decl.cc:12356
+#: cp/decl.cc:12372
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "declaration of %qE as non-function"
 msgstr "%qD 沒有宣告為一個函式"
 
-#: cp/decl.cc:12363
+#: cp/decl.cc:12379
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-member"
 msgid "declaration of %qE as non-member"
 msgstr "%qD 未宣告為成員"
 
-#: cp/decl.cc:12391
+#: cp/decl.cc:12407
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "缺少宣告識別碼：使用了保留字 %qD"
 
-#: cp/decl.cc:12442
+#: cp/decl.cc:12458
 #, fuzzy, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "函式定義不宣告參數"
 
-#: cp/decl.cc:12450 cp/decl.cc:12459 cp/decl.cc:14444
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD 沒有宣告為一個函式"
 
-#: cp/decl.cc:12467
+#: cp/decl.cc:12483
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "宣告的 %qD 做為 %<typedef%>"
 
-#: cp/decl.cc:12472
+#: cp/decl.cc:12488
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "宣告的 %qD 做為參數"
 
-#: cp/decl.cc:12507
+#: cp/decl.cc:12523
 #, fuzzy, gcc-internal-format
 #| msgid "no classes specified"
 msgid "both %qs and %qs specified"
 msgstr "未指定類別"
 
-#: cp/decl.cc:12514 cp/decl.cc:12521 cp/decl.cc:12528 cp/decl.cc:12535
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a typedef declaration"
 msgstr "%<constexpr%> 無法出現在中 typedef 宣告"
 
-#: cp/decl.cc:12546
+#: cp/decl.cc:12562
 #, gcc-internal-format
 msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
 msgstr ""
 
-#: cp/decl.cc:12556
+#: cp/decl.cc:12572
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "%qs 的宣告指定了兩個以上的資料類型"
 
-#: cp/decl.cc:12610
+#: cp/decl.cc:12626
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支援單獨用 %<complex%> 表示 %<double complex%>"
 
-#: cp/decl.cc:12659 cp/decl.cc:12663 cp/decl.cc:12666
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ 不允許宣告無類型的 %qs"
 
-#: cp/decl.cc:12683
+#: cp/decl.cc:12699
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int128%>未被支援由這個目標"
 
-#: cp/decl.cc:12691
+#: cp/decl.cc:12707
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++不支援 %<__int128%>用於 %qs"
 
-#: cp/decl.cc:12745
+#: cp/decl.cc:12761
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together"
 msgstr "%<signed%> 和 %<unsigned%>指定的一起用於 %qs"
 
-#: cp/decl.cc:12751
+#: cp/decl.cc:12767
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together"
 msgstr "%<long%> 和 %<short%>指定的一起用於 %qs"
 
-#: cp/decl.cc:12759
+#: cp/decl.cc:12775
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "%qs specified with %qT"
 msgstr "%qs 沒有指定類別名"
 
-#: cp/decl.cc:12766
+#: cp/decl.cc:12782
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qs specified with typedef-name %qD"
 msgstr "%<__thread%> 與 %<typedef%> 一起使用"
 
-#: cp/decl.cc:12775
+#: cp/decl.cc:12791
 #, fuzzy, gcc-internal-format
 msgid "%qs specified with %<decltype%>"
 msgstr "預期 %<decltype%>"
 
-#: cp/decl.cc:12777
+#: cp/decl.cc:12793
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qs specified with %<typeof%>"
 msgstr "%<__thread%> 與 %<typedef%> 一起使用"
 
-#: cp/decl.cc:12846
+#: cp/decl.cc:12862
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "對 %qs 而言無效的複數"
 
-#: cp/decl.cc:12890
+#: cp/decl.cc:12906
 #, gcc-internal-format
 msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.cc:12916
+#: cp/decl.cc:12932
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "成員 %qD 不能既被宣告為虛函式，又被宣告為靜態函式"
 
-#: cp/decl.cc:12925
+#: cp/decl.cc:12941
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "成員 %qD 不能既被宣告為虛函式，又被宣告為靜態函式"
 
-#: cp/decl.cc:12938
+#: cp/decl.cc:12954
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "參數宣告中出現的 typedef 宣告無效"
 
-#: cp/decl.cc:12945
+#: cp/decl.cc:12961
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "貯藏類別指定的用於模板參數 %qs"
 
-#: cp/decl.cc:12955 cp/decl.cc:13132
+#: cp/decl.cc:12971 cp/decl.cc:13148
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "為參數 %qs 指定了存儲類別"
 
-#: cp/decl.cc:12963 cp/decl.cc:12972 cp/decl.cc:12978 cp/decl.cc:12984
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %qs"
 msgstr "參數無法宣告 %<constexpr%>"
 
-#: cp/decl.cc:12994
+#: cp/decl.cc:13010
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> 外側類別宣告"
 
-#: cp/decl.cc:13004 cp/decl.cc:13007 cp/decl.cc:13009 cp/decl.cc:13012
-#: cp/decl.cc:13022 cp/decl.cc:13032 cp/decl.cc:13042 cp/decl.cc:13046
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "屬性忽略的在中宣告的 %q#T"
 
-#: cp/decl.cc:13016 cp/decl.cc:13038
+#: cp/decl.cc:13032 cp/decl.cc:13054
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "無限制的聯合只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.cc:13026
+#: cp/decl.cc:13042
 #, fuzzy, gcc-internal-format
 msgid "%<volatile%>-qualified structured binding is deprecated"
 msgstr "無效的輸入宣告"
 
-#: cp/decl.cc:13050
+#: cp/decl.cc:13066
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13062
+#: cp/decl.cc:13078
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "屬性忽略的在中宣告的 %q#T"
 
-#: cp/decl.cc:13065
+#: cp/decl.cc:13081
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.cc:13073
+#: cp/decl.cc:13089
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
 msgstr "屬性忽略的在中宣告的 %q#T"
 
-#: cp/decl.cc:13104
+#: cp/decl.cc:13120
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs 的宣告指定了多個存儲類別"
 
-#: cp/decl.cc:13130
+#: cp/decl.cc:13146
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "為 %qs 指定了存儲類別"
 
-#: cp/decl.cc:13144
+#: cp/decl.cc:13160
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "巢狀函式 %qs 被宣告為 %<extern%>"
 
-#: cp/decl.cc:13149
+#: cp/decl.cc:13165
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "在頂層將 %qs 宣告為 %<auto%>"
 
-#: cp/decl.cc:13157
+#: cp/decl.cc:13173
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "函式作用欄位的 %qs 隱含為 auto，卻被宣告為 %<__thread%>"
 
-#: cp/decl.cc:13171
+#: cp/decl.cc:13187
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "為夥伴函式宣告指定了無效的存儲類別"
 
-#: cp/decl.cc:13204 cp/decl.cc:14834 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
 #: cp/parser.cc:28063
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored"
 msgstr "%qE 屬性被忽略"
 
-#: cp/decl.cc:13205
+#: cp/decl.cc:13221
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: cp/decl.cc:13275
+#: cp/decl.cc:13291
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs 的宣告指定了多個存儲類別"
 
-#: cp/decl.cc:13281
+#: cp/decl.cc:13297
 #, fuzzy, gcc-internal-format
 #| msgid "Expected left parenthesis"
 msgid "remove parentheses"
 msgstr "需要左圓括號"
 
-#: cp/decl.cc:13349
+#: cp/decl.cc:13365
 #, fuzzy, gcc-internal-format
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.cc:13363
+#: cp/decl.cc:13379
 #, fuzzy, gcc-internal-format
 msgid "a function type cannot have an explicit object parameter"
 msgstr "函式『%s』於 %L 無法有初始設定式"
 
-#: cp/decl.cc:13369
+#: cp/decl.cc:13385
 #, fuzzy, gcc-internal-format
 msgid "a pointer to function type cannot have an explicit object parameter"
 msgstr "%qs 函式無法有引數"
 
-#: cp/decl.cc:13373
+#: cp/decl.cc:13389
 #, fuzzy, gcc-internal-format
 msgid "a pointer to member function type cannot have an explicit object parameter"
 msgstr "  成員函數型式 %qT 並非有效模板引數"
 
-#: cp/decl.cc:13381
+#: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
 msgstr ""
 
-#: cp/decl.cc:13385
+#: cp/decl.cc:13401
 #, fuzzy, gcc-internal-format
 msgid "the type of an explicit object member function is a regular function type"
 msgstr "類型可能無法被定義在中條件"
 
-#: cp/decl.cc:13406
+#: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
 msgstr ""
 
-#: cp/decl.cc:13411
+#: cp/decl.cc:13427
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "valid explicit object parameter declared here"
 msgstr "範本參數類型 %qT 宣告為 %<friend%>"
 
-#: cp/decl.cc:13415
+#: cp/decl.cc:13431
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.cc:13435
+#: cp/decl.cc:13451
 #, fuzzy, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs 函式使用 %<auto%> 型態說明符而無需尾隨傳回類型"
 
-#: cp/decl.cc:13439
+#: cp/decl.cc:13455
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.cc:13444
+#: cp/decl.cc:13460
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "虛函式不能是夥伴"
 
-#: cp/decl.cc:13451
+#: cp/decl.cc:13467
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs 函式與尾隨傳回類型有 %qT 做為它的型態而非普通 %<auto%>"
 
-#: cp/decl.cc:13460
+#: cp/decl.cc:13476
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
 msgstr "%qs 函式與尾隨傳回類型有 %qT 做為它的型態而非普通 %<auto%>"
 
-#: cp/decl.cc:13465
+#: cp/decl.cc:13481
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<decltype(auto)%>"
 msgstr "無效的使用的 %<auto%>"
 
-#: cp/decl.cc:13477
+#: cp/decl.cc:13493
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "忽略函式回傳類型的類型限定"
 
-#: cp/decl.cc:13486
+#: cp/decl.cc:13502
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.cc:13499
+#: cp/decl.cc:13515
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
 
-#: cp/decl.cc:13513
+#: cp/decl.cc:13529
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.cc:13516
+#: cp/decl.cc:13532
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs 函式與尾隨傳回類型無法宣告的與 %<auto%> 型態說明符"
 
-#: cp/decl.cc:13523
+#: cp/decl.cc:13539
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "%qs 函式無法有引數"
 
-#: cp/decl.cc:13549
+#: cp/decl.cc:13565
 #, gcc-internal-format
 msgid "%<volatile%>-qualified return type is deprecated"
 msgstr ""
 
-#: cp/decl.cc:13561
+#: cp/decl.cc:13577
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs 宣告為回傳一個函式的函式"
 
-#: cp/decl.cc:13567
+#: cp/decl.cc:13583
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs 宣告為回傳一個陣列的函式"
 
-#: cp/decl.cc:13574
+#: cp/decl.cc:13590
 #, fuzzy, gcc-internal-format
 #| msgid "%<noreturn%> function returns non-void value"
 msgid "%<constinit%> on function return type is not allowed"
 msgstr "%<noreturn%> 函式回傳了一個非 void 的回傳值"
 
-#: cp/decl.cc:13607
+#: cp/decl.cc:13623
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "解構函式不能是靜態成員函式"
 
-#: cp/decl.cc:13609
+#: cp/decl.cc:13625
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/decl.cc:13614
+#: cp/decl.cc:13630
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "解構函式不能被 cv 限定"
 
-#: cp/decl.cc:13615
+#: cp/decl.cc:13631
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "建構式不能帶 cv 限定"
 
-#: cp/decl.cc:13623
+#: cp/decl.cc:13639
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "解構函式不能被 cv 限定"
 
-#: cp/decl.cc:13624
+#: cp/decl.cc:13640
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "建構式不能帶 cv 限定"
 
-#: cp/decl.cc:13642
+#: cp/decl.cc:13658
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "建構式不能被宣告為虛函式"
 
-#: cp/decl.cc:13659
+#: cp/decl.cc:13675
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "虛函式不能是夥伴"
 
-#: cp/decl.cc:13664
+#: cp/decl.cc:13680
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "夥伴宣告不在類別定義內"
 
-#: cp/decl.cc:13668
+#: cp/decl.cc:13684
 #, fuzzy, gcc-internal-format
 msgid "cannot define friend function %qs in a local class definition"
 msgstr "can%'t 定義朋友函式 %qs 在中區域類別定義"
 
-#: cp/decl.cc:13678
+#: cp/decl.cc:13694
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<::%>"
 msgstr ""
 
-#: cp/decl.cc:13682
+#: cp/decl.cc:13698
 #, gcc-internal-format
 msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
 msgstr ""
 
-#: cp/decl.cc:13708
+#: cp/decl.cc:13724
 #, fuzzy, gcc-internal-format
 msgid "a non-member function cannot have an explicit object parameter"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.cc:13716
+#: cp/decl.cc:13732
 #, fuzzy, gcc-internal-format
 msgid "an explicit object member function cannot be %<virtual%>"
 msgstr "模板可能無法是 %<virtual%>"
 
-#: cp/decl.cc:13726
+#: cp/decl.cc:13742
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.cc:13735
+#: cp/decl.cc:13751
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD cannot be an explicit object member function"
 msgstr "%qD 必須是一個非靜態的成員函式"
 
-#: cp/decl.cc:13758
+#: cp/decl.cc:13774
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "解構函式不能有參數"
 
-#: cp/decl.cc:13816
+#: cp/decl.cc:13832
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "無法宣告參照 %q#T 的指標"
 
-#: cp/decl.cc:13829 cp/decl.cc:13836
+#: cp/decl.cc:13845 cp/decl.cc:13852
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "無法宣告對 %q#T 的參照"
 
-#: cp/decl.cc:13838
+#: cp/decl.cc:13854
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "無法宣告參照 %q#T 成員的指標"
 
-#: cp/decl.cc:13867
+#: cp/decl.cc:13883
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "無法宣告參考到經資格修飾函數型式 %qT"
 
-#: cp/decl.cc:13868
+#: cp/decl.cc:13884
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/decl.cc:13941
+#: cp/decl.cc:13957
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "無法宣告參考到 %q#T, 該項並非 typedef 或模板型態引數"
 
-#: cp/decl.cc:14021
+#: cp/decl.cc:14037
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "範本識別碼 %qD 做為宣告"
 
-#: cp/decl.cc:14047
+#: cp/decl.cc:14063
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "成員函式隱含地成為所屬類別的夥伴"
 
-#: cp/decl.cc:14052
+#: cp/decl.cc:14068
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "有多餘的限定 %<%T::%> 於成員 %qs 上"
 
-#: cp/decl.cc:14082
+#: cp/decl.cc:14098
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "無法定義成員函式 %<%T::%s%> 於 %<%T%> 之內"
 
-#: cp/decl.cc:14084
+#: cp/decl.cc:14100
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "無法宣告成員函式 %<%T::%s%> 於 %<%T%> 之內"
 
-#: cp/decl.cc:14092
+#: cp/decl.cc:14108
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "無法宣告成員 %<%T::%s%> 於 %qT 之內"
 
-#: cp/decl.cc:14132
+#: cp/decl.cc:14148
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "non-parameter %qs 無法參數包裝"
 
-#: cp/decl.cc:14141
+#: cp/decl.cc:14157
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "資料成員不能具有可變類型 %qT"
 
-#: cp/decl.cc:14144
+#: cp/decl.cc:14160
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "參數不能具有可變類型 %qT"
 
-#: cp/decl.cc:14155
+#: cp/decl.cc:14171
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> 外側類別宣告"
 
-#: cp/decl.cc:14158
+#: cp/decl.cc:14174
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> 用於空宣告中"
 
-#: cp/decl.cc:14161
+#: cp/decl.cc:14177
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "只有建構式才能被宣告為 %<explicit%>"
 
-#: cp/decl.cc:14171
+#: cp/decl.cc:14187
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.cc:14178
+#: cp/decl.cc:14194
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非物件成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.cc:14184
+#: cp/decl.cc:14200
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "函式 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.cc:14190
+#: cp/decl.cc:14206
 #, fuzzy, gcc-internal-format
 #| msgid "static %qs cannot be declared %<mutable%>"
 msgid "%<static%> %qs cannot be declared %<mutable%>"
 msgstr "靜態 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.cc:14196
+#: cp/decl.cc:14212
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "%<const%> %qs cannot be declared %<mutable%>"
 msgstr "常數 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.cc:14202
+#: cp/decl.cc:14218
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "參考 %qs 無法宣告 %<mutable%>"
 
-#: cp/decl.cc:14218
+#: cp/decl.cc:14234
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a function definition"
 msgstr "類型可能無法被定義在中條件"
 
-#: cp/decl.cc:14221
+#: cp/decl.cc:14237
 #, fuzzy, gcc-internal-format
 msgid "typedef may not be a member function definition"
 msgstr "類型可能無法被定義在中條件"
 
-#: cp/decl.cc:14247
+#: cp/decl.cc:14263
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> not allowed in alias declaration"
 msgstr "%<[*]%>無法在中宣告"
 
-#: cp/decl.cc:14250
+#: cp/decl.cc:14266
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef 宣告 %<auto%>"
 
-#: cp/decl.cc:14255
+#: cp/decl.cc:14271
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.cc:14259
+#: cp/decl.cc:14275
 #, fuzzy, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef 名稱可能無法是 nested-name-specifier"
 
-#: cp/decl.cc:14285
+#: cp/decl.cc:14301
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ 不允許嵌類別的類型 %qD 與其所屬的類別同名"
 
-#: cp/decl.cc:14374
+#: cp/decl.cc:14390
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "夥伴函式宣告中出現了 %<inline%>"
 
-#: cp/decl.cc:14382
+#: cp/decl.cc:14398
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "範本參數不能是夥伴"
 
-#: cp/decl.cc:14384
+#: cp/decl.cc:14400
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "夥伴宣告需要 class，即 %<friend class %T::%D%>"
 
-#: cp/decl.cc:14388
+#: cp/decl.cc:14404
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "夥伴宣告需要 class，即 %<friend %#T%>"
 
-#: cp/decl.cc:14401
+#: cp/decl.cc:14417
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "試圖讓 %qT 成為全域欄位的夥伴"
 
-#: cp/decl.cc:14421
+#: cp/decl.cc:14437
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非成員函式類型上的限定符無效"
 
-#: cp/decl.cc:14425
+#: cp/decl.cc:14441
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.cc:14435
+#: cp/decl.cc:14451
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "抽象宣告 %qT 做為宣告"
 
-#: cp/decl.cc:14450
+#: cp/decl.cc:14466
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "value-initialization 的函數型式 %qT"
 
-#: cp/decl.cc:14469
+#: cp/decl.cc:14485
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "不能在參數宣告中使用 %<::%>"
 
-#: cp/decl.cc:14479 cp/parser.cc:20813
+#: cp/decl.cc:14495 cp/parser.cc:20813
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare parameter %q+D to be of abstract type %qT"
 msgid "cannot declare a parameter with %<decltype(auto)%>"
 msgstr "不能將參數 %q+D 宣告為具有抽象類型 %qT"
 
-#: cp/decl.cc:14486
+#: cp/decl.cc:14502
 #, gcc-internal-format
 msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
 msgstr ""
 
-#: cp/decl.cc:14489
+#: cp/decl.cc:14505
 #, gcc-internal-format
 msgid "or use %<auto%> for an abbreviated function template"
 msgstr ""
 
-#: cp/decl.cc:14495 cp/parser.cc:25355
+#: cp/decl.cc:14511 cp/parser.cc:25355
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<this%> 不能用在此上下文中"
 
-#: cp/decl.cc:14505
+#: cp/decl.cc:14521
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "參數宣告 %<auto%>"
 
-#: cp/decl.cc:14559 cp/parser.cc:3687
+#: cp/decl.cc:14575 cp/parser.cc:3687
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "使用範本名 %qE 時不帶引數表無效"
 
-#: cp/decl.cc:14563
+#: cp/decl.cc:14579
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "非靜態資料成員宣告 %<auto%>"
 
-#: cp/decl.cc:14584
+#: cp/decl.cc:14600
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C 不允許大小為 0 的陣列 %qD"
 
-#: cp/decl.cc:14587
+#: cp/decl.cc:14603
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C90 不允許彈性陣列成員"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.cc:14603
+#: cp/decl.cc:14619
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "錯誤地使用了 %<::%>"
 
-#: cp/decl.cc:14624
+#: cp/decl.cc:14640
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "宣告的函式 %qD 在中無效的語境"
 
-#: cp/decl.cc:14634
+#: cp/decl.cc:14650
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "聯合成員函式 %qD 被宣告為虛函式"
 
-#: cp/decl.cc:14644
+#: cp/decl.cc:14660
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD 不能宣告為虛函式，因為它總是靜態的"
 
-#: cp/decl.cc:14658
+#: cp/decl.cc:14674
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "在解構函式 %qD 中的夥伴宣告需要限定名"
 
-#: cp/decl.cc:14665
+#: cp/decl.cc:14681
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD 宣告為 %qT 的一個成員"
 
-#: cp/decl.cc:14672 cp/decl.cc:14685
+#: cp/decl.cc:14688 cp/decl.cc:14701
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %qs"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.cc:14691
+#: cp/decl.cc:14707
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "預期的限定名稱在中朋友宣告用於建構子 %qD"
 
-#: cp/decl.cc:14700
+#: cp/decl.cc:14716
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.cc:14706
+#: cp/decl.cc:14722
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/decl.cc:14714 cp/decl.cc:15069
+#: cp/decl.cc:14730 cp/decl.cc:15085
 #, fuzzy, gcc-internal-format
 #| msgid "cannot open %s"
 msgid "%qD cannot be %qs"
 msgstr "無法開啟 %s"
 
-#: cp/decl.cc:14723
+#: cp/decl.cc:14739
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "局部特化的別名模板 %qD"
 
-#: cp/decl.cc:14726
+#: cp/decl.cc:14742
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "原來的型態宣告的在此"
 
-#: cp/decl.cc:14789
+#: cp/decl.cc:14805
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "欄位 %qD 類型不完全"
 
-#: cp/decl.cc:14794
+#: cp/decl.cc:14810
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "名稱 %qT 類型不完全"
 
-#: cp/decl.cc:14814
+#: cp/decl.cc:14830
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE 既不是函式也不是成員函式；不能宣告為夥伴"
 
-#: cp/decl.cc:14817
+#: cp/decl.cc:14833
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is neither function nor member function; cannot be declared friend"
 msgid "unnamed field is neither function nor member function; cannot be declared friend"
 msgstr "%qE 既不是函式也不是成員函式；不能宣告為夥伴"
 
-#: cp/decl.cc:14835 cp/parser.cc:21380 cp/parser.cc:28064
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
 #, gcc-internal-format
 msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
 msgstr ""
 
-#: cp/decl.cc:14885 cp/decl.cc:14896
+#: cp/decl.cc:14901 cp/decl.cc:14912
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %qs"
 msgstr "非靜態資料成員 %qE 宣告 %<constexpr%>"
 
-#: cp/decl.cc:14890
+#: cp/decl.cc:14906
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "constexpr 靜態資料成員 %qD 必須有初始設定式"
 
-#: cp/decl.cc:14933 cp/decl.cc:14941 cp/decl.cc:14948 cp/decl.cc:14955
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %qs"
 msgstr "非靜態資料成員 %qE 宣告 %<constexpr%>"
 
-#: cp/decl.cc:15007
+#: cp/decl.cc:15023
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<auto%> 無效"
 
-#: cp/decl.cc:15010
+#: cp/decl.cc:15026
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<register%> 無效"
 
-#: cp/decl.cc:15016
+#: cp/decl.cc:15032
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/decl.cc:15020
+#: cp/decl.cc:15036
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/decl.cc:15025
+#: cp/decl.cc:15041
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> specifier invalid for function %qs"
 msgstr "對齊指定的用於函式 %qE"
 
-#: cp/decl.cc:15028
+#: cp/decl.cc:15044
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-specifiers 在中 %qs 不允許外側類別定義"
 
-#: cp/decl.cc:15040
+#: cp/decl.cc:15056
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<static%> 無效"
 
-#: cp/decl.cc:15044
+#: cp/decl.cc:15060
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<inline%> 無效"
 
-#: cp/decl.cc:15052
+#: cp/decl.cc:15068
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "虛函式 %qs 不是類別成員"
 
-#: cp/decl.cc:15059
+#: cp/decl.cc:15075
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs 定義的在中 non-class 範圍"
 
-#: cp/decl.cc:15060
+#: cp/decl.cc:15076
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs 宣告的在中 non-class 範圍"
 
-#: cp/decl.cc:15103
+#: cp/decl.cc:15119
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "不能將成員函式 %qD 宣告為有靜態連結"
 
-#: cp/decl.cc:15112
+#: cp/decl.cc:15128
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "不能在另一個函式中宣告一個靜態函式"
 
-#: cp/decl.cc:15153
+#: cp/decl.cc:15169
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "與宣告不同，定義靜態資料成員時不能使用 %<static%>"
 
-#: cp/decl.cc:15160
+#: cp/decl.cc:15176
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "靜態成員 %qD 宣告為 %<register%>"
 
-#: cp/decl.cc:15166
+#: cp/decl.cc:15182
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "不能明確地將成員 %q#D 宣告為有外部連結"
 
-#: cp/decl.cc:15174
+#: cp/decl.cc:15190
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "宣告的 constexpr 變數 %qD 並非定義"
 
-#: cp/decl.cc:15181
+#: cp/decl.cc:15197
 #, fuzzy, gcc-internal-format
 msgid "a variable cannot be declared %<consteval%>"
 msgstr "參數無法宣告 %<constexpr%>"
 
-#: cp/decl.cc:15213
+#: cp/decl.cc:15229
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs 已初始化，卻又被宣告為 %<extern%>"
 
-#: cp/decl.cc:15218
+#: cp/decl.cc:15234
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs 既有 %<extern%> 又有初始值設定"
 
-#: cp/decl.cc:15420
+#: cp/decl.cc:15436
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "預設引數 %qE 使用 %qD"
 
-#: cp/decl.cc:15423
+#: cp/decl.cc:15439
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "預設引數 %qE 使用了局部變數 %qD"
 
-#: cp/decl.cc:15550
+#: cp/decl.cc:15566
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "在 %q#D 的範本宣告中使用 %<virtual%> 無效"
 
-#: cp/decl.cc:15554
+#: cp/decl.cc:15570
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "在 %q#D 的範本宣告中使用 %<virtual%> 無效"
 
-#: cp/decl.cc:15583
+#: cp/decl.cc:15599
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type %qT"
 msgid "%<volatile%>-qualified parameter is deprecated"
 msgstr "無效的參數類型 %qT"
 
-#: cp/decl.cc:15591
+#: cp/decl.cc:15607
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "參數 %qD 被無效地被宣告為具有方法類型"
 
-#: cp/decl.cc:15616
+#: cp/decl.cc:15632
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "參數 %qD 包含指標到陣列的不明約束 %qT"
 
-#: cp/decl.cc:15618
+#: cp/decl.cc:15634
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "參數 %qD 包含參考到陣列的不明約束 %qT"
 
-#: cp/decl.cc:15901
+#: cp/decl.cc:15917
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "無效的建構式：您要的可能是 %<%T (const %T&)%>"
 
-#: cp/decl.cc:15980
+#: cp/decl.cc:15996
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD 不能在命名空間宣告"
 
-#: cp/decl.cc:15987
+#: cp/decl.cc:16003
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD 不能被宣告為靜態的"
 
-#: cp/decl.cc:16015
+#: cp/decl.cc:16031
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-static member function"
 msgstr "%qD 必須是一個非靜態的成員函式"
 
-#: cp/decl.cc:16023
+#: cp/decl.cc:16039
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a member function"
 msgstr "%qD 必須是 non-member 函式"
 
-#: cp/decl.cc:16031
+#: cp/decl.cc:16047
 #, fuzzy, gcc-internal-format
 msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.cc:16041
+#: cp/decl.cc:16057
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD 必須是一個非靜態成員函式或非成員函式"
 
-#: cp/decl.cc:16051
+#: cp/decl.cc:16067
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD 的引數必須有類別或列舉類型"
 
 #. 13.4.0.3
-#: cp/decl.cc:16082
+#: cp/decl.cc:16098
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ prohibits overloading operator ?:"
 msgid "ISO C++ prohibits overloading %<operator ?:%>"
 msgstr "ISO C++ 不允許多載 ?: 運算子"
 
-#: cp/decl.cc:16092
+#: cp/decl.cc:16108
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD 必須不有可變個數引數數量"
 
-#: cp/decl.cc:16118
+#: cp/decl.cc:16134
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD 必須帶 0 或 1 個引數"
 
-#: cp/decl.cc:16119
+#: cp/decl.cc:16135
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD 必須帶 1 或 2 個引數"
 
-#: cp/decl.cc:16131
+#: cp/decl.cc:16147
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "字尾 %qD 必須使用 %<int%> 做為它的參數"
 
-#: cp/decl.cc:16132
+#: cp/decl.cc:16148
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "字尾 %qD 必須使用 %<int%> 做為它的第二個參數"
 
-#: cp/decl.cc:16143
+#: cp/decl.cc:16159
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD 帶且僅帶 2 個引數"
 
-#: cp/decl.cc:16144 cp/decl.cc:16154
+#: cp/decl.cc:16160 cp/decl.cc:16170
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD 帶且僅帶 1 個引數"
 
-#: cp/decl.cc:16155
+#: cp/decl.cc:16171
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD 帶且僅帶 2 個引數"
 
-#: cp/decl.cc:16170
+#: cp/decl.cc:16186
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD 不能有預設參數"
 
-#: cp/decl.cc:16194
+#: cp/decl.cc:16210
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to %<void%> will never use a type conversion operator"
 msgstr "轉換到虛值將永不使用類型轉換運算子"
 
-#: cp/decl.cc:16201
+#: cp/decl.cc:16217
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to the same type will never use a type conversion operator"
 msgstr "轉換到參考到相同型態將永不使用類型轉換運算子"
 
-#: cp/decl.cc:16203
+#: cp/decl.cc:16219
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to the same type will never use a type conversion operator"
 msgstr "轉換到相同型態將永不使用類型轉換運算子"
 
-#: cp/decl.cc:16212
+#: cp/decl.cc:16228
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
 msgstr "轉換到參考到基礎類別將永不使用類型轉換運算子"
 
-#: cp/decl.cc:16214
+#: cp/decl.cc:16230
 #, fuzzy, gcc-internal-format
 msgid "converting %qT to a base class %qT will never use a type conversion operator"
 msgstr "轉換到基礎類別將永不使用類型轉換運算子"
 
-#: cp/decl.cc:16230
+#: cp/decl.cc:16246
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "使用者定義的 %qD 總是計算所有兩個參數"
 
-#: cp/decl.cc:16249
+#: cp/decl.cc:16265
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "字首 %qD 應當回傳 %qT"
 
-#: cp/decl.cc:16256
+#: cp/decl.cc:16272
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "字尾 %qD 應當回傳 %qT"
 
-#: cp/decl.cc:16268
+#: cp/decl.cc:16284
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD 應當回傳值而非參照"
 
-#: cp/decl.cc:16323
+#: cp/decl.cc:16339
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "使用範本類型參數 %qT，在 %qs 後"
 
-#: cp/decl.cc:16346
+#: cp/decl.cc:16362
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "使用別名模板特殊化 %qT 之後 %qs"
 
-#: cp/decl.cc:16349
+#: cp/decl.cc:16365
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "使用 typedef 名 %qD，在 %qs 後"
 
-#: cp/decl.cc:16351
+#: cp/decl.cc:16367
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD 有前一個宣告在此"
 
-#: cp/decl.cc:16359
+#: cp/decl.cc:16375
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT 做為 %qs 被參照"
 
-#: cp/decl.cc:16360 cp/decl.cc:16367
+#: cp/decl.cc:16376 cp/decl.cc:16383
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T 先前在此處有過宣告"
 
-#: cp/decl.cc:16366
+#: cp/decl.cc:16382
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT 做為列舉被參照"
@@ -60121,117 +60126,101 @@ msgstr "%qT 做為列舉被參照"
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.cc:16381
+#: cp/decl.cc:16397
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%> 需要範本參數"
 
-#: cp/decl.cc:16424 cp/name-lookup.cc:6074 cp/name-lookup.cc:6206
-#: cp/parser.cc:7215 cp/parser.cc:32114
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "對 %qD 的參照有歧義"
 
-#: cp/decl.cc:16433
+#: cp/decl.cc:16449
 #, fuzzy, gcc-internal-format
 msgid "class template %qD redeclared as non-template"
 msgstr "函式模板 %qD redeclared 做為類別模板"
 
-#: cp/decl.cc:16455 cp/name-lookup.cc:5764
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD 與其宣告所在的類別同名"
 
-#: cp/decl.cc:16483 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
-#: cp/pt.cc:9992
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT 不是一個範本"
 
-#: cp/decl.cc:16488
+#: cp/decl.cc:16504
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.cc:16593
+#: cp/decl.cc:16609
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "使用列舉 %q#D 前沒有給出宣告"
 
-#: cp/decl.cc:16619
+#: cp/decl.cc:16635
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "%qT 重宣告為非範本"
 
-#: cp/decl.cc:16631 cp/semantics.cc:3781
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare %qD to be a bit-field type"
-msgid "cannot declare %qD in a different module"
-msgstr "不能將 %qD 宣告為位元段類型"
-
-#: cp/decl.cc:16632 cp/decl.cc:16985 lto/lto-symtab.cc:865
-#, fuzzy, gcc-internal-format
-msgid "previously declared here"
-msgstr "在之前宣告的在此"
-
-#: cp/decl.cc:16759
+#: cp/decl.cc:16770
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "衍生聯合 %qT 無效"
 
-#: cp/decl.cc:16766
+#: cp/decl.cc:16777
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.cc:16777
+#: cp/decl.cc:16788
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "類型 %qT 不是 %qT 的直接或虛基礎類別"
 
-#: cp/decl.cc:16802
+#: cp/decl.cc:16813
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "基礎類別型 %qT 不是結構或類別"
 
-#: cp/decl.cc:16832
+#: cp/decl.cc:16843
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "遞迴的類型 %qT 未定義"
 
-#: cp/decl.cc:16834
+#: cp/decl.cc:16845
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重複的基礎類別型 %qT 無效"
 
-#: cp/decl.cc:16984
-#, fuzzy, gcc-internal-format
-msgid "cannot declare %qD in different module"
-msgstr "無法擷取 %qE 由參考"
-
-#: cp/decl.cc:16997
+#: cp/decl.cc:17003
 #, fuzzy, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "範圍/unscoped 不匹配在中 enum %q#T"
 
-#: cp/decl.cc:17000 cp/decl.cc:17009 cp/decl.cc:17020 cp/decl.cc:17612
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
 #: cp/parser.cc:21734
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "前一個定義在此"
 
-#: cp/decl.cc:17006
+#: cp/decl.cc:17012
 #, fuzzy, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "下層的型態不匹配在中 enum %q#T"
 
-#: cp/decl.cc:17017
+#: cp/decl.cc:17023
 #, fuzzy, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "不同的下層的輸入 enum %q#T"
 
-#: cp/decl.cc:17090
+#: cp/decl.cc:17096
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "下層的型態 %<%T%>的 %<%T%>必須是整數類資料類型"
@@ -60240,83 +60229,83 @@ msgstr "下層的型態 %<%T%>的 %<%T%>必須是整數類資料類型"
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.cc:17239
+#: cp/decl.cc:17245
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "沒有一個整數類型可以表示 %qT 的所有列舉值"
 
-#: cp/decl.cc:17420
+#: cp/decl.cc:17426
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "列舉值值用於 %qD 不是整數常數"
 
-#: cp/decl.cc:17430
+#: cp/decl.cc:17436
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "列舉值值用於 %qD 不是整數常數"
 
-#: cp/decl.cc:17479
+#: cp/decl.cc:17485
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "遞增的列舉值值太大用於 %<unsigned long%>"
 
-#: cp/decl.cc:17480
+#: cp/decl.cc:17486
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "遞增的列舉值值太大用於 %<unsigned long%>"
 
-#: cp/decl.cc:17491
+#: cp/decl.cc:17497
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD 處列舉值溢出"
 
-#: cp/decl.cc:17511
+#: cp/decl.cc:17517
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "列舉值值 %E 太大用於下層的型態 %<%T%>"
 
-#: cp/decl.cc:17610 cp/parser.cc:21732
+#: cp/decl.cc:17616 cp/parser.cc:21732
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T 多次定義"
 
-#: cp/decl.cc:17684
+#: cp/decl.cc:17690
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "回傳值類型 %q#T 為不完全"
 
-#: cp/decl.cc:17842 cp/typeck.cc:11242
+#: cp/decl.cc:17848 cp/typeck.cc:11238
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> 應當回傳一個對 %<*this%> 的參照"
 
-#: cp/decl.cc:18672
+#: cp/decl.cc:18678
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "在有回傳值的函式中未發現 return 敘述"
 
-#: cp/decl.cc:18674 cp/typeck.cc:11122
+#: cp/decl.cc:18680 cp/typeck.cc:11118
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "由於 %<volatile%>，函式回傳類型不相容"
 
-#: cp/decl.cc:18734
+#: cp/decl.cc:18740
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statement in %<constexpr%> function returning non-void"
 msgstr "在有回傳值的函式中未發現 return 敘述"
 
-#: cp/decl.cc:18914
+#: cp/decl.cc:18920
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD 已在類別 %qT 中定義過"
 
-#: cp/decl.cc:19304
+#: cp/decl.cc:19310
 #, fuzzy, gcc-internal-format
 msgid "using %qs"
 msgstr "封閉任務"
 
-#: cp/decl.cc:19316
+#: cp/decl.cc:19322
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "型態的 %qD 預設值到 %<int%>"
@@ -60371,7 +60360,7 @@ msgstr "不能 delete 一個函式。只有參照物件的指標才是 %<delete%
 msgid "deleting %qT is undefined"
 msgstr "刪除 %qT 未定義"
 
-#: cp/decl2.cc:768 cp/pt.cc:5961
+#: cp/decl2.cc:768 cp/pt.cc:5962
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D 宣告為範本"
@@ -60381,7 +60370,7 @@ msgstr "%q#D 宣告為範本"
 msgid "template parameter lists provided don%'t match the template parameters of %qD"
 msgstr "模板參數清單提供 don%'t 匹配模板參數的 %qD"
 
-#: cp/decl2.cc:823 cp/pt.cc:5929
+#: cp/decl2.cc:823 cp/pt.cc:5930
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "解構函式 %qD 被宣告為一個成員範本"
@@ -60574,64 +60563,64 @@ msgstr "解構函式不能是靜態成員函式"
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> 的第一個參數類型為 %qT"
 
-#: cp/decl2.cc:3159
+#: cp/decl2.cc:3160
 #, fuzzy, gcc-internal-format
 msgid "%qT has a field %q#D whose type has no linkage"
 msgstr "%qT 有欄位 %qD 其型態使用匿名命名空間"
 
-#: cp/decl2.cc:3163
+#: cp/decl2.cc:3164
 #, fuzzy, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT 有欄位 %qD 其型態使用匿名命名空間"
 
-#: cp/decl2.cc:3169
+#: cp/decl2.cc:3170
 #, fuzzy, gcc-internal-format
 msgid "%qT has a field %q#D whose type has internal linkage"
 msgstr "%qT 有欄位 %qD 其型態使用匿名命名空間"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3173
+#: cp/decl2.cc:3174
 #, fuzzy, gcc-internal-format
 msgid "%qT has a field %q#D whose type uses the anonymous namespace"
 msgstr "%qT 有欄位 %qD 其型態使用匿名命名空間"
 
-#: cp/decl2.cc:3181
+#: cp/decl2.cc:3182
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT 宣告的與更大可視性比型態的它的欄位 %qD"
 
-#: cp/decl2.cc:3200
+#: cp/decl2.cc:3201
 #, fuzzy, gcc-internal-format
 msgid "%qT has a base %qT which has no linkage"
 msgstr "%qT 有基底 %qT 其型態使用匿名命名空間"
 
-#: cp/decl2.cc:3204
+#: cp/decl2.cc:3205
 #, fuzzy, gcc-internal-format
 msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
 msgstr "%qT 有基底 %qT 其型態使用匿名命名空間"
 
-#: cp/decl2.cc:3210
+#: cp/decl2.cc:3211
 #, fuzzy, gcc-internal-format
 msgid "%qT has a base %qT which has internal linkage"
 msgstr "%qT 有基底 %qT 其型態使用匿名命名空間"
 
 #. In C++98 this can only happen with unnamed namespaces.
-#: cp/decl2.cc:3214
+#: cp/decl2.cc:3215
 #, fuzzy, gcc-internal-format
 msgid "%qT has a base %qT which uses the anonymous namespace"
 msgstr "%qT 有基底 %qT 其型態使用匿名命名空間"
 
-#: cp/decl2.cc:3221
+#: cp/decl2.cc:3222
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT 宣告的與更大可視性比它的基底 %qT"
 
-#: cp/decl2.cc:4713
+#: cp/decl2.cc:4714
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but never defined"
 msgstr "%q+#D, 宣告的使用匿名型態，被使用但是永不定義"
 
-#: cp/decl2.cc:4717
+#: cp/decl2.cc:4718
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but not defined"
 msgstr "%q+#D, 宣告的使用匿名型態，被使用但是永不定義"
@@ -60640,107 +60629,107 @@ msgstr "%q+#D, 宣告的使用匿名型態，被使用但是永不定義"
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.cc:4727
+#: cp/decl2.cc:4728
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "匿名型態不具任何鏈結用來宣告變數 %q#D 與鏈結"
 
-#: cp/decl2.cc:4731
+#: cp/decl2.cc:4732
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "匿名型態不具任何鏈結用來宣告函式 %q#D 與鏈結"
 
-#: cp/decl2.cc:4735
+#: cp/decl2.cc:4736
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D 未指明非限定類型，所以它不做為外部連結"
 
-#: cp/decl2.cc:4753
+#: cp/decl2.cc:4754
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+#D, 宣告的使用本地型態 %qT，被使用但是永不定義"
 
-#: cp/decl2.cc:4757
+#: cp/decl2.cc:4758
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but not defined here"
 msgstr "%q+#D, 宣告的使用本地型態 %qT，被使用但是永不定義"
 
-#: cp/decl2.cc:4765
+#: cp/decl2.cc:4766
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "型態 %qT 不具任何鏈結用來宣告變數 %q#D 與鏈結"
 
-#: cp/decl2.cc:4768
+#: cp/decl2.cc:4769
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "型態 %qT 不具任何鏈結用來宣告函式 %q#D 與鏈結"
 
-#: cp/decl2.cc:4965
+#: cp/decl2.cc:4966
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q#D 衝突與前一個宣告"
 
-#: cp/decl2.cc:4968
+#: cp/decl2.cc:4969
 #, fuzzy, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "前一個宣告 %q+#D"
 
-#: cp/decl2.cc:4970
+#: cp/decl2.cc:4971
 #, fuzzy, gcc-internal-format
 msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
 msgstr "-fabi-version=6 (或=0) 避免這個錯誤與變更在中 mangling"
 
-#: cp/decl2.cc:5042 cp/decl2.cc:5045
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.cc:5384
+#: cp/decl2.cc:5385
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "使用了內聯函式 %q+D 但從未定義過"
 
-#: cp/decl2.cc:5610
+#: cp/decl2.cc:5611
 #, fuzzy, gcc-internal-format
 #| msgid "default argument missing for parameter %P of %q+#D"
 msgid "default argument missing for parameter %P of %q#D"
 msgstr "參數 %P (屬於 %q+#D)缺少預設引數"
 
-#: cp/decl2.cc:5615
+#: cp/decl2.cc:5616
 #, fuzzy, gcc-internal-format
 msgid "...following parameter %P which has a default argument"
 msgstr "參數包裝無法有預設引數"
 
-#: cp/decl2.cc:5739
+#: cp/decl2.cc:5740
 #, fuzzy, gcc-internal-format
 msgid "implicitly-declared %qD is deprecated"
 msgstr "類別 %qE 被不宜用"
 
-#: cp/decl2.cc:5743
+#: cp/decl2.cc:5744
 #, gcc-internal-format
 msgid "because %qT has user-provided %qD"
 msgstr ""
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.cc:5884
+#: cp/decl2.cc:5885
 #, fuzzy, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "轉換 lambda 該項使用 %<...%>到函式指標"
 
-#: cp/decl2.cc:5887
+#: cp/decl2.cc:5888
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "使用的刪除的函式 %qD"
 
-#: cp/decl2.cc:5941
+#: cp/decl2.cc:5942
 #, fuzzy, gcc-internal-format
 msgid "use of function %qD with unsatisfied constraints"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/decl2.cc:5971
+#: cp/decl2.cc:5974
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -60848,7 +60837,7 @@ msgstr "對 %<%T::%D%> 的參照有歧義"
 msgid "%qD is not a member of %qT; did you mean %qs?"
 msgstr "%qD 不是類型 %qT 的成員"
 
-#: cp/error.cc:4697 cp/typeck.cc:2875
+#: cp/error.cc:4697 cp/typeck.cc:2871
 #, gcc-internal-format
 msgid "%qD is not a member of %qT"
 msgstr "%qD 不是 %qT 的成員"
@@ -60859,7 +60848,7 @@ msgstr "%qD 不是 %qT 的成員"
 msgid "%qD is not a member of %qD; did you mean %qs?"
 msgstr "%qD 不是類型 %qT 的成員"
 
-#: cp/error.cc:4723 cp/typeck.cc:3467
+#: cp/error.cc:4723 cp/typeck.cc:3463
 #, gcc-internal-format
 msgid "%qD is not a member of %qD"
 msgstr "%qD 不是 %qD 的成員"
@@ -60885,47 +60874,47 @@ msgstr "異常處理已停用，使用 -fexceptions 以啟用"
 msgid "throwing NULL, which has integral, not pointer type"
 msgstr "拋出 NULL，它的類型是整數而不是指標"
 
-#: cp/except.cc:735
+#: cp/except.cc:731
 #, gcc-internal-format
 msgid "  in thrown expression"
 msgstr "  在拋出的運算式中"
 
-#: cp/except.cc:882
+#: cp/except.cc:878
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
 msgstr "不能將參數 %q+D 宣告為具有抽象類型 %qT"
 
-#: cp/except.cc:892
+#: cp/except.cc:888
 #, fuzzy, gcc-internal-format
 msgid "cannot throw expression of type %qT because it involves types of variable size"
 msgstr "無法建立類型資訊用於型態 %qT 因為它牽連出類型的變數大小"
 
-#: cp/except.cc:895
+#: cp/except.cc:891
 #, fuzzy, gcc-internal-format
 msgid "cannot catch type %qT because it involves types of variable size"
 msgstr "無法建立類型資訊用於型態 %qT 因為它牽連出類型的變數大小"
 
-#: cp/except.cc:996
+#: cp/except.cc:992
 #, fuzzy, gcc-internal-format
 msgid "exception of type %qT will be caught by earlier handler"
 msgstr "異常的型態 %qT 將是擷取到"
 
-#: cp/except.cc:998
+#: cp/except.cc:994
 #, fuzzy, gcc-internal-format
 msgid "for type %qT"
 msgstr "錯誤的型態引數到 %s"
 
-#: cp/except.cc:1027
+#: cp/except.cc:1023
 #, fuzzy, gcc-internal-format
 msgid "%<...%> handler must be the last handler for its try block"
 msgstr "%<...%>處理常式必須是最後一筆處理常式用於它的嘗試區塊"
 
-#: cp/except.cc:1123
+#: cp/except.cc:1119
 #, fuzzy, gcc-internal-format
 msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
 msgstr "noexcept-expression 評估到 %<false%> 因為呼叫到 %qD"
 
-#: cp/except.cc:1126
+#: cp/except.cc:1122
 #, fuzzy, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
 msgstr "但是 %q+D 不丟擲；也許它應該被宣告 %<noexcept%>"
@@ -61196,12 +61185,12 @@ msgstr "類型 %qT 不是 %qT 的直接或虛基礎類別"
 msgid "type %qT is not a direct base of %qT"
 msgstr "類型 %qT 不是 %qT 的直接基礎類別"
 
-#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1378
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
 #, fuzzy, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "陣列必須被初始化的與 brace-enclosed 初始設定式"
 
-#: cp/init.cc:2366 cp/semantics.cc:4058 rust/backend/rust-tree.cc:4168
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT 並非類別型態"
@@ -61216,12 +61205,12 @@ msgstr "不完全類型 %qT 沒有成員 %qD"
 msgid "invalid pointer to bit-field %qD"
 msgstr "參照位元段 %qD 指標無效"
 
-#: cp/init.cc:2524 cp/typeck.cc:2361 rust/backend/rust-tree.cc:3811
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "對非靜態成員函式 %qD 的使用無效"
 
-#: cp/init.cc:2531 cp/semantics.cc:2377
+#: cp/init.cc:2531 cp/semantics.cc:2379
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "對非靜態資料成員 %qD 的無效使用"
@@ -61422,53 +61411,53 @@ msgstr "刪除物件的抽象類別型態 %qT 該項有 non-virtual 解構式將
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "刪除物件的 polymorphic 類別型態 %qT 該項有 non-virtual 解構式也許造成未定義的行為"
 
-#: cp/init.cc:5510
+#: cp/init.cc:5517
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "向量 delete 的引數類型既非指標也非陣列"
 
-#: cp/lambda.cc:549
+#: cp/lambda.cc:550
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
 msgstr ""
 
-#: cp/lambda.cc:564
+#: cp/lambda.cc:565
 #, gcc-internal-format
 msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
 msgstr ""
 
-#: cp/lambda.cc:568
+#: cp/lambda.cc:569
 #, fuzzy, gcc-internal-format
 #| msgid "compound literal has variable size"
 msgid "because the array element type %qT has variable size"
 msgstr "複合字面值有可變的大小"
 
-#: cp/lambda.cc:592
+#: cp/lambda.cc:593
 #, fuzzy, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "無法擷取 %qE 由參考"
 
-#: cp/lambda.cc:602
+#: cp/lambda.cc:603
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "無效的使用的不完整型態 %q#T"
 
-#: cp/lambda.cc:674
+#: cp/lambda.cc:675
 #, gcc-internal-format
 msgid "trying to capture %qD in instantiation of generic lambda"
 msgstr ""
 
-#: cp/lambda.cc:750
+#: cp/lambda.cc:751
 #, gcc-internal-format
 msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
 msgstr ""
 
-#: cp/lambda.cc:752
+#: cp/lambda.cc:753
 #, gcc-internal-format
 msgid "add explicit %<this%> or %<*this%> capture"
 msgstr ""
 
-#: cp/lambda.cc:873
+#: cp/lambda.cc:874
 #, fuzzy, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> 未被擷取用於這個 lambda 函式"
@@ -61849,232 +61838,281 @@ msgstr "預期 template-id 用於型態"
 msgid "encapsulation is malformed"
 msgstr ""
 
-#: cp/module.cc:11577
+#: cp/module.cc:11604
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting global module declaration %#qD"
 msgstr "相互衝突的宣告 %q#D"
 
-#: cp/module.cc:11579
+#: cp/module.cc:11606
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration %q+D"
 msgid "existing declaration %#qD"
 msgstr "在宣告 %q+D 中"
 
-#: cp/module.cc:12626
+#: cp/module.cc:12655
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match"
 msgstr "extern 宣告的 %q#D doesn%'t 匹配"
 
-#: cp/module.cc:12628
+#: cp/module.cc:12657
 #, fuzzy, gcc-internal-format
 #| msgid "missing definition"
 msgid "existing definition %qD"
 msgstr "定義缺失"
 
-#: cp/module.cc:12640
+#: cp/module.cc:12669
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of enumerator %q+D"
 msgid "... this enumerator %qD"
 msgstr "列舉 %q+D 重宣告"
 
-#: cp/module.cc:12642
+#: cp/module.cc:12671
 #, fuzzy, gcc-internal-format
 msgid "enumerator %qD does not match ..."
 msgstr "extern 宣告的 %q#D doesn%'t 匹配"
 
-#: cp/module.cc:12648
+#: cp/module.cc:12677
 #, gcc-internal-format
 msgid "additional enumerators beginning with %qD"
 msgstr ""
 
-#: cp/module.cc:12652
+#: cp/module.cc:12681
 #, gcc-internal-format
 msgid "enumeration range differs"
 msgstr ""
 
-#: cp/module.cc:13747
+#: cp/module.cc:13782
 #, gcc-internal-format
 msgid "%q#D references internal linkage entity %q#D"
 msgstr ""
 
-#: cp/module.cc:14330
+#: cp/module.cc:14365
 #, gcc-internal-format
 msgid "recursive lazy load"
 msgstr ""
 
 #. Cannot import the current module.
-#: cp/module.cc:14349
+#: cp/module.cc:14384
 #, gcc-internal-format
 msgid "cannot import module in its own purview"
 msgstr ""
 
-#: cp/module.cc:14350 cp/module.cc:19589
+#: cp/module.cc:14385 cp/module.cc:19710
 #, fuzzy, gcc-internal-format
 msgid "module %qs declared here"
 msgstr "%qD 宣告的在此"
 
-#: cp/module.cc:14694
+#: cp/module.cc:14729
 #, gcc-internal-format
 msgid "indirect import %qs is not already loaded"
 msgstr ""
 
-#: cp/module.cc:14700
+#: cp/module.cc:14735
 #, gcc-internal-format
 msgid "import %qs has CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:16528
+#: cp/module.cc:16563
 #, gcc-internal-format
 msgid "unable to represent further imported source locations"
 msgstr ""
 
-#: cp/module.cc:17403
+#: cp/module.cc:17438
 #, gcc-internal-format
 msgid "not exporting %<#define %E%> as it is a keyword"
 msgstr ""
 
-#: cp/module.cc:17643
+#: cp/module.cc:17678
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "macro definitions of %qE corrupted"
 msgstr "%q+D 的上一個定義在此"
 
-#: cp/module.cc:17667 cp/module.cc:17670
+#: cp/module.cc:17702 cp/module.cc:17705
 #, fuzzy, gcc-internal-format
 msgid "inconsistent imported macro definition %qE"
 msgstr "  不一致參數包裝推導與 %qT 和 %qT"
 
-#: cp/module.cc:17676
+#: cp/module.cc:17711
 #, gcc-internal-format
 msgid "%<#undef %E%>"
 msgstr ""
 
-#: cp/module.cc:17678
+#: cp/module.cc:17713
 #, gcc-internal-format
 msgid "%<#define %s%>"
 msgstr ""
 
-#: cp/module.cc:17911
+#: cp/module.cc:17946
 #, fuzzy, gcc-internal-format
 msgid "compiled module file is %qs"
 msgstr "無法刪除模組檔案『%s』：%s"
 
-#: cp/module.cc:17948 cp/module.cc:17953
+#: cp/module.cc:17983 cp/module.cc:17988
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collect2 version %s\n"
 msgid "compiled module is %sversion %s"
 msgstr "collect2 版本 %s\n"
 
-#: cp/module.cc:17959
+#: cp/module.cc:17994
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collect2 version %s\n"
 msgid "compiler is %sversion %s%s%s"
 msgstr "collect2 版本 %s\n"
 
-#: cp/module.cc:17989
+#: cp/module.cc:18024
 #, fuzzy, gcc-internal-format
 msgid "module %qs found"
 msgstr "找不到任何 %qs getter"
 
-#: cp/module.cc:17991
+#: cp/module.cc:18026
 #, gcc-internal-format
 msgid "header module expected, module %qs found"
 msgstr ""
 
-#: cp/module.cc:17992
+#: cp/module.cc:18027
 #, gcc-internal-format
 msgid "module %qs expected, header module found"
 msgstr ""
 
-#: cp/module.cc:18007
+#: cp/module.cc:18042
 #, gcc-internal-format
 msgid "module %qs CRC mismatch"
 msgstr ""
 
-#: cp/module.cc:18021
+#: cp/module.cc:18056
 #, gcc-internal-format
 msgid "target & host is %qs:%qs, expected %qs:%qs"
 msgstr ""
 
-#: cp/module.cc:18033
+#: cp/module.cc:18068
 #, gcc-internal-format
 msgid "language dialect differs %qs, expected %qs"
 msgstr ""
 
-#: cp/module.cc:18049
+#: cp/module.cc:18084
 #, fuzzy, gcc-internal-format
 msgid "module contains OpenMP, use %<-fopenmp%> to enable"
 msgstr "異常處理已停用，使用 -fexceptions 以啟用"
 
-#: cp/module.cc:18066
+#: cp/module.cc:18101
 #, fuzzy, gcc-internal-format
 msgid "fixed tree mismatch"
 msgstr "最佳化等級屬性不匹配"
 
-#: cp/module.cc:18157
+#: cp/module.cc:18192
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "interface partition is not exported"
 msgstr "不支援堆疊限制運算式"
 
-#: cp/module.cc:18714
+#: cp/module.cc:18749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module cluster %u: %s"
 msgstr "重新命名 %s 到狀態檔案 %s 時失敗 [%s]"
 
-#: cp/module.cc:18752
+#: cp/module.cc:18787
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to read compiled module: %s"
 msgstr "開啟 %s 時失敗"
 
-#: cp/module.cc:18762
+#: cp/module.cc:18797
 #, gcc-internal-format
 msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
 msgstr ""
 
-#: cp/module.cc:18767
+#: cp/module.cc:18802
 #, gcc-internal-format
 msgid "imports must be built before being imported"
 msgstr ""
 
-#: cp/module.cc:18770
+#: cp/module.cc:18805
 #, gcc-internal-format
 msgid "returning to the gate for a mechanical issue"
 msgstr ""
 
-#: cp/module.cc:19283
+#: cp/module.cc:19117
+#, fuzzy, gcc-internal-format
+#| msgid "conflicts with built-in declaration %q#D"
+msgid "declaration %qD conflicts with builtin"
+msgstr "與內建宣告 %q#D 衝突"
+
+#: cp/module.cc:19122
+#, fuzzy, gcc-internal-format
+#| msgid "declaration of namespace %qD conflicts with"
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr "命名空間 %qD 的宣告存在衝突，與"
+
+#: cp/module.cc:19125
+#, gcc-internal-format
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr ""
+
+#: cp/module.cc:19130
+#, gcc-internal-format
+msgid "import declared attached to module %qs"
+msgstr ""
+
+#: cp/module.cc:19134
+#, gcc-internal-format
+msgid "import declared in global module"
+msgstr ""
+
+#: cp/module.cc:19140
+#, fuzzy, gcc-internal-format
+#| msgid "declaration of template %q#D"
+msgid "conflicting declaration of %qD in module %qs"
+msgstr "範本宣告 %q#D"
+
+#: cp/module.cc:19143
+#, fuzzy, gcc-internal-format
+#| msgid "conflicts with new declaration with %qL linkage"
+msgid "conflicting declaration of %qD in global module"
+msgstr "與帶有 %qL 連結的新宣告衝突"
+
+#: cp/module.cc:19148
+#, fuzzy, gcc-internal-format
+msgid "previously declared in module %qs"
+msgstr "在之前宣告的在此"
+
+#: cp/module.cc:19152
+#, fuzzy, gcc-internal-format
+msgid "previously declared in global module"
+msgstr "在之前宣告的在此"
+
+#: cp/module.cc:19404
 #, fuzzy, gcc-internal-format
 #| msgid "creating %s"
 msgid "reading CMI %qs"
 msgstr "建立 %s"
 
-#: cp/module.cc:19434
+#: cp/module.cc:19555
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19435
+#: cp/module.cc:19556
 #, gcc-internal-format
 msgid "failed to load binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19442
+#: cp/module.cc:19563
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19443
+#: cp/module.cc:19564
 #, gcc-internal-format
 msgid "during load of binding %<%E%s%E@%s%>"
 msgstr ""
 
-#: cp/module.cc:19505
+#: cp/module.cc:19626
 #, gcc-internal-format
 msgid "failed to load pendings for %<%E%s%E%>"
 msgstr ""
 
-#: cp/module.cc:19509
+#: cp/module.cc:19630
 #, fuzzy, gcc-internal-format
 msgid "during load of pendings for %<%E%s%E%>"
 msgstr "不明選項用於 -mrecip=%s"
@@ -62086,412 +62124,412 @@ msgstr "不明選項用於 -mrecip=%s"
 #. module, so we don't want to confuse things by having to think
 #. about whether 'extern "C++" { import foo; }' puts foo's
 #. contents into the global module all of a sudden.
-#: cp/module.cc:19554
+#: cp/module.cc:19675
 #, gcc-internal-format
 msgid "import of named module %qs inside language-linkage block"
 msgstr ""
 
-#: cp/module.cc:19584
+#: cp/module.cc:19705
 #, fuzzy, gcc-internal-format
 msgid "module already declared"
 msgstr "符號『%s』已經宣告"
 
-#: cp/module.cc:19585
+#: cp/module.cc:19706
 #, fuzzy, gcc-internal-format
 msgid "module already imported"
 msgstr "符號『%s』已經宣告"
 
-#: cp/module.cc:19590
+#: cp/module.cc:19711
 #, fuzzy, gcc-internal-format
 msgid "module %qs imported here"
 msgstr "%qD 宣告的在此"
 
-#: cp/module.cc:19797
+#: cp/module.cc:19918
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown Compiled Module Interface: %s"
 msgstr "不明標點符號『%c』"
 
-#: cp/module.cc:19840
+#: cp/module.cc:19961
 #, gcc-internal-format
 msgid "cannot determine %<#include%> translation of %s: %s"
 msgstr ""
 
-#: cp/module.cc:19858
+#: cp/module.cc:19979
 #, gcc-internal-format
 msgid "include %qs translated to import"
 msgstr ""
 
-#: cp/module.cc:19859
+#: cp/module.cc:19980
 #, gcc-internal-format
 msgid "include %qs processed textually"
 msgstr ""
 
-#: cp/module.cc:20218
+#: cp/module.cc:20339
 #, gcc-internal-format
 msgid "C++ modules are incompatible with precompiled headers"
 msgstr ""
 
-#: cp/module.cc:20222
+#: cp/module.cc:20343
 #, fuzzy, gcc-internal-format
 #| msgid "Enable traditional preprocessing"
 msgid "C++ modules are incompatible with traditional preprocessing"
 msgstr "啟用傳統預先處理"
 
-#: cp/module.cc:20232
+#: cp/module.cc:20353
 #, gcc-internal-format
 msgid "macro debug output may be incomplete with modules"
 msgstr ""
 
-#: cp/module.cc:20233
+#: cp/module.cc:20354
 #, gcc-internal-format
 msgid "module dependencies require preprocessing"
 msgstr ""
 
-#: cp/module.cc:20235
+#: cp/module.cc:20356
 #, fuzzy, gcc-internal-format
 msgid "you should use the %<-%s%> option"
 msgstr "內建函式 %s 需求 -mvsx 選項"
 
-#: cp/module.cc:20270 cp/module.cc:20299
+#: cp/module.cc:20391 cp/module.cc:20420
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid header name %qs"
 msgstr "無效的 --param 值 %qs"
 
-#: cp/module.cc:20309
+#: cp/module.cc:20430
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid module name %qs"
 msgstr "無效的 --param 值 %qs"
 
-#: cp/module.cc:20507
+#: cp/module.cc:20630
 #, gcc-internal-format
 msgid "%<-fmodule-only%> used for non-interface"
 msgstr ""
 
-#: cp/module.cc:20547
+#: cp/module.cc:20670
 #, fuzzy, gcc-internal-format
 #| msgid "error writing %qs"
 msgid "writing CMI %qs"
 msgstr "寫入 %qs 時錯誤"
 
-#: cp/module.cc:20554
+#: cp/module.cc:20677
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing modules file: %s"
 msgid "not writing module %qs due to errors"
 msgstr "寫入模組檔案時發生錯誤：%s"
 
-#: cp/module.cc:20619
+#: cp/module.cc:20742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to write compiled module: %s"
 msgstr "寫入狀態結尾時失敗 [%s]"
 
-#: cp/module.cc:20716
+#: cp/module.cc:20839
 #, fuzzy, gcc-internal-format
 msgid "unknown header kind %qs"
 msgstr "不明 spec 函式 %qs"
 
-#: cp/name-lookup.cc:2856 cp/name-lookup.cc:3932 cp/name-lookup.cc:4029
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
 #, fuzzy, gcc-internal-format
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/name-lookup.cc:2887
+#: cp/name-lookup.cc:2891
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "redeclaration of %q#D with different template parameters"
 msgstr "%q+D 的宣告隱藏了一個參數"
 
-#: cp/name-lookup.cc:2893
+#: cp/name-lookup.cc:2897
 #, fuzzy, gcc-internal-format
 msgid "%q#D conflicts with a previous declaration"
 msgstr "%q#D 衝突與前一個宣告"
 
-#: cp/name-lookup.cc:3060
+#: cp/name-lookup.cc:3064
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D hides constructor for %q#T"
 msgid "%q#D hides constructor for %q#D"
 msgstr "%q#D 隱藏了 %q#T 的建構式"
 
-#: cp/name-lookup.cc:3211
+#: cp/name-lookup.cc:3215
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting C language linkage declaration %q#D"
 msgstr "相互衝突的宣告 %q#D"
 
-#: cp/name-lookup.cc:3216
+#: cp/name-lookup.cc:3220
 #, fuzzy, gcc-internal-format
 msgid "due to different exception specifications"
 msgstr "由於不同的異常規格"
 
-#: cp/name-lookup.cc:3326
+#: cp/name-lookup.cc:3330
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD invalidly declared method type"
 msgid "lambda parameter %qD previously declared as a capture"
 msgstr "參數 %qD 被無效地被宣告為具有方法類型"
 
-#: cp/name-lookup.cc:3359 cp/name-lookup.cc:3363
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
 #, gcc-internal-format
 msgid "declaration of %q#D shadows a parameter"
 msgstr "%q#D 的宣告隱藏了一個參數"
 
-#: cp/name-lookup.cc:3522
+#: cp/name-lookup.cc:3526
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "declaration of %qD shadows a member of %qT"
 msgstr "%qD 宣告為 %qT 的一個成員"
 
-#: cp/name-lookup.cc:4014
+#: cp/name-lookup.cc:4018
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
 msgstr "朋友宣告 %qD 在中區域類別而無需事前宣告"
 
-#: cp/name-lookup.cc:4512
+#: cp/name-lookup.cc:4569
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s(%E) %p %d\n"
 msgid "%s %<%s(%E)%> %p %d"
 msgstr "%s %s(%E) %p %d\n"
 
-#: cp/name-lookup.cc:4515
+#: cp/name-lookup.cc:4572
 #, fuzzy, gcc-internal-format
 #| msgid "%s %s %p %d\n"
 msgid "%s %s %p %d"
 msgstr "%s %s %p %d\n"
 
-#: cp/name-lookup.cc:5101
+#: cp/name-lookup.cc:5158
 #, fuzzy, gcc-internal-format
 msgid "exporting %q#D that does not have external linkage"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/name-lookup.cc:5106
+#: cp/name-lookup.cc:5163
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here with no linkage"
 msgstr "%q+#D 宣告的在此"
 
-#: cp/name-lookup.cc:5109
+#: cp/name-lookup.cc:5166
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here with internal linkage"
 msgstr "%q+D 宣告的在此，稍後在中轉譯單位"
 
-#: cp/name-lookup.cc:5112
+#: cp/name-lookup.cc:5169
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here with module linkage"
 msgstr "%q+#D 宣告的在此"
 
-#: cp/name-lookup.cc:5911
+#: cp/name-lookup.cc:5968
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names destructor"
 msgid "%<%T%s%D%> names destructor"
 msgstr "%<%T::%D%> 指定了解構函式"
 
-#: cp/name-lookup.cc:5927
+#: cp/name-lookup.cc:5984
 #, gcc-internal-format
 msgid "using-declaration for non-member at class scope"
 msgstr "在類別作用欄位使用非成員的 using 宣告"
 
-#: cp/name-lookup.cc:5935
+#: cp/name-lookup.cc:5992
 #, fuzzy, gcc-internal-format
 msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/name-lookup.cc:5951 cp/pt.cc:18490
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, namespace, or enumeration"
 msgstr "%qE 並非類別、命名空間，或列舉類型"
 
-#: cp/name-lookup.cc:5961
+#: cp/name-lookup.cc:6018
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "non-member using-declaration names constructor of %qT"
 msgstr "%q#D 宣告為範本"
 
-#: cp/name-lookup.cc:5972 cp/name-lookup.cc:6045
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "using-declaration for member at non-class scope"
 msgstr "在類別作用欄位使用非成員的 using 宣告"
 
-#: cp/name-lookup.cc:5995
+#: cp/name-lookup.cc:6052
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct base of %qT"
 msgid "%qT is not a direct base of %qT"
 msgstr "類型 %qT 不是 %qT 的直接基礎類別"
 
-#: cp/name-lookup.cc:6055
+#: cp/name-lookup.cc:6112
 #, gcc-internal-format
 msgid "did you mean %<using enum %T::%D%>?"
 msgstr ""
 
-#: cp/name-lookup.cc:6067
+#: cp/name-lookup.cc:6124
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared in %qD"
 msgstr "%qD 未被宣告在中 %qD"
 
-#: cp/name-lookup.cc:6081
+#: cp/name-lookup.cc:6138
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD not in a namespace surrounding %qD"
 msgid "using-declaration may not name namespace %qD"
 msgstr "%qD 的宣告不在包含 %qD 的命名空間中"
 
-#: cp/name-lookup.cc:6092
+#: cp/name-lookup.cc:6149
 #, gcc-internal-format
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> 在 %qT 內指定了建構式"
 
-#: cp/name-lookup.cc:6185
+#: cp/name-lookup.cc:6242
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD 的宣告不在包含 %qD 的命名空間中"
 
-#: cp/name-lookup.cc:6226
+#: cp/name-lookup.cc:6283
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD 的宣告中有明確的限定"
 
-#: cp/name-lookup.cc:6236
+#: cp/name-lookup.cc:6293
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD 應當已在 %qD 內部宣告過"
 
-#: cp/name-lookup.cc:6305
+#: cp/name-lookup.cc:6362
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %qD"
 msgstr "%qD 未被宣告在中 %qD"
 
-#: cp/name-lookup.cc:6307
+#: cp/name-lookup.cc:6364
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a %<friend%>"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/name-lookup.cc:6361
+#: cp/name-lookup.cc:6418
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD 屬性需要單一 NTBS 引數"
 
-#: cp/name-lookup.cc:6368
+#: cp/name-lookup.cc:6425
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD 屬性是無意義的自從成員的匿名命名空間提取本機符號"
 
-#: cp/name-lookup.cc:6378 cp/name-lookup.cc:6405
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/name-lookup.cc:6384
+#: cp/name-lookup.cc:6441
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/name-lookup.cc:6421 cp/name-lookup.cc:8815
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "指定 %qD 屬性被忽略"
 
-#: cp/name-lookup.cc:6747
+#: cp/name-lookup.cc:6804
 #, fuzzy, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "最大值限制的 %d 命名空間搜尋的用於 %qE"
 
-#: cp/name-lookup.cc:6799
+#: cp/name-lookup.cc:6856
 #, fuzzy, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "建議的替代方案："
 
-#: cp/name-lookup.cc:6805
+#: cp/name-lookup.cc:6862
 #, fuzzy, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.cc:7119
+#: cp/name-lookup.cc:7176
 #, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
 msgstr ""
 
-#: cp/name-lookup.cc:7125
+#: cp/name-lookup.cc:7182
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<std::%s%> is only available from %s onwards"
 msgstr "靜態成員函式中不能使用 %<this%>"
 
-#: cp/name-lookup.cc:7561
+#: cp/name-lookup.cc:7618
 #, fuzzy, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
 msgstr "weak %q+D 無法定義 %qE"
 
-#: cp/name-lookup.cc:7564
+#: cp/name-lookup.cc:7621
 #, fuzzy, gcc-internal-format
 msgid "it was later defined here"
 msgstr "結構定義的在此"
 
-#: cp/name-lookup.cc:8359
+#: cp/name-lookup.cc:8416
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
 msgstr ""
 
-#: cp/name-lookup.cc:8787
+#: cp/name-lookup.cc:8844
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "%<strong%> using directive no longer supported"
 msgstr "開關 %qs 不再被支援"
 
-#: cp/name-lookup.cc:8790
+#: cp/name-lookup.cc:8847
 #, gcc-internal-format
 msgid "you can use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.cc:8809
+#: cp/name-lookup.cc:8866
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<omp::%E%> not allowed to be specified in this context"
 msgstr "%<this%> 不能用在此上下文中"
 
 #. We only allow depth 255.
-#: cp/name-lookup.cc:8901
+#: cp/name-lookup.cc:8958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD 不能在命名空間宣告"
 
-#: cp/name-lookup.cc:8998
+#: cp/name-lookup.cc:9055
 #, fuzzy, gcc-internal-format
 msgid "%<namespace %E%> is ambiguous"
 msgstr "『%s』於 %L 是模稜兩可的"
 
-#: cp/name-lookup.cc:9014
+#: cp/name-lookup.cc:9071
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "這裡不允許命名空間別名 %qD，假定為 %qD"
 
-#: cp/name-lookup.cc:9101
+#: cp/name-lookup.cc:9158
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "方法屬性必須被指定的於結束只有"
 
-#: cp/name-lookup.cc:9102
+#: cp/name-lookup.cc:9159
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "標貼 %qD 定義的在此"
 
-#: cp/name-lookup.cc:9150
+#: cp/name-lookup.cc:9207
 #, fuzzy, gcc-internal-format
 msgid "%s namespace %qD conflicts with reachable definition"
 msgstr "%qD 衝突與使用的函式"
 
-#: cp/name-lookup.cc:9152
+#: cp/name-lookup.cc:9209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "reachable %s definition here"
 msgstr "前一個定義在此"
 
-#: cp/name-lookup.cc:9195
+#: cp/name-lookup.cc:9252
 #, fuzzy, gcc-internal-format
 #| msgid "XXX entering pop_everything ()\n"
 msgid "XXX entering %<pop_everything ()%>"
 msgstr "XXX 進入 pop_everything ()\n"
 
-#: cp/name-lookup.cc:9204
+#: cp/name-lookup.cc:9261
 #, fuzzy, gcc-internal-format
 #| msgid "XXX leaving pop_everything ()\n"
 msgid "XXX leaving %<pop_everything ()%>"
@@ -62517,7 +62555,7 @@ msgstr "識別碼 %qE 是關鍵字在中 C++11"
 msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
 msgstr ""
 
-#: cp/parser.cc:1607 cp/parser.cc:47881
+#: cp/parser.cc:1607 cp/parser.cc:47879
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
@@ -62765,7 +62803,7 @@ msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.cc:3754 cp/parser.cc:31351
+#: cp/parser.cc:3754 cp/parser.cc:31353
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
 msgstr "使用者定義的實字只有可用與 -std=c++11 或 -std=gnu++11"
@@ -62949,7 +62987,7 @@ msgstr "statement-expressions 未被允許外側函式 nor 在中 template-argum
 msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "lambda 運算式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4405
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
 #, fuzzy, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "預期 primary-expression"
@@ -63007,7 +63045,7 @@ msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
 msgid "template-id not allowed for destructor in C++20"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/parser.cc:6735 cp/parser.cc:32584
+#: cp/parser.cc:6735 cp/parser.cc:32586
 #, gcc-internal-format
 msgid "remove the %qs"
 msgstr ""
@@ -63027,7 +63065,7 @@ msgstr "typedef 名 %qD 用於解構函式宣告"
 msgid "expected unqualified-id"
 msgstr "預期 unqualified-id"
 
-#: cp/parser.cc:6921 cp/typeck.cc:3165 cp/typeck.cc:3168 cp/typeck.cc:3185
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD 不是一個範本"
@@ -63079,7 +63117,7 @@ msgstr "類型可能無法被定義在中 %<typeid%> 運算式"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "錯誤的引數數量到 %<__builtin_shuffle%>"
 
-#: cp/parser.cc:7734 cp/pt.cc:20997
+#: cp/parser.cc:7734 cp/pt.cc:21039
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "錯誤的引數數量到 %<__builtin_complex%>"
@@ -63114,7 +63152,7 @@ msgstr "類型可能無法被定義在中條件"
 msgid "cannot use multidimensional subscript in OpenMP array section"
 msgstr ""
 
-#: cp/parser.cc:8687 cp/typeck.cc:3053
+#: cp/parser.cc:8687 cp/typeck.cc:3049
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "錯誤地使用了 %qD"
@@ -63139,7 +63177,7 @@ msgstr "ISO C++不允許 %<alignof%> 與 non-type"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "類型可能無法被定義在中 %<noexcept%> 運算式"
 
-#: cp/parser.cc:9444 cp/parser.cc:33997
+#: cp/parser.cc:9444 cp/parser.cc:33999
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %qs expressions"
 msgstr "類型可能無法被定義在中 new-expression"
@@ -63291,8 +63329,8 @@ msgstr ""
 msgid "capture of non-variable %qE"
 msgstr "擷取的 non-variable %qD "
 
-#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4247
-#: cp/semantics.cc:4262
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q+#D 宣告的在此"
@@ -63332,7 +63370,7 @@ msgstr "預設引數指定的用於 lambda 參數"
 msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "無限制的聯合只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.cc:11932 cp/pt.cc:14742
+#: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
 msgstr ""
@@ -63460,7 +63498,7 @@ msgstr ""
 msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
 msgstr "委派建構子只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.cc:13819 cp/parser.cc:34509
+#: cp/parser.cc:13819 cp/parser.cc:34511
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "預期 selection-statement"
@@ -63524,7 +63562,7 @@ msgstr "range-based %<for%> 運算式的型態 %qT 有不完整型態"
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "不一致開始/結束類型在中 range-based %<for%> 敘述：%qT 和 %qT"
 
-#: cp/parser.cc:14700 cp/parser.cc:34512
+#: cp/parser.cc:14700 cp/parser.cc:34514
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "預期 iteration-statement"
@@ -63550,7 +63588,7 @@ msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ 不允許執行時可知的 goto 目的"
 
-#: cp/parser.cc:14915 cp/parser.cc:34515
+#: cp/parser.cc:14915 cp/parser.cc:34517
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "預期 jump-statement"
@@ -63838,12 +63876,12 @@ msgstr "只有建構子需成員初始設定式"
 msgid "cannot expand initializer for member %qD"
 msgstr "無法展開初始設定式用於成員 %<%D%>"
 
-#: cp/parser.cc:17514 cp/pt.cc:27654
+#: cp/parser.cc:17514 cp/pt.cc:27696
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "mem-initializer 用於 %qD 追隨建構子 delegation"
 
-#: cp/parser.cc:17526 cp/pt.cc:27666
+#: cp/parser.cc:17526 cp/pt.cc:27708
 #, fuzzy, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "建構子 delegation 追隨 mem-initializer 用於 %qD"
@@ -64495,7 +64533,7 @@ msgstr "在中模板引數用於型態 %qT "
 msgid "%qT not permitted in template argument"
 msgstr "不匹配的引數"
 
-#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2473
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
 #: rust/backend/rust-tree.cc:3909
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
@@ -64679,12 +64717,12 @@ msgstr "%q+#T 的上一個定義"
 #. In a lambda this should work, but doesn't currently.
 #. We're in a lambda, but it isn't the innermost class.
 #. This should work, but currently doesn't.
-#: cp/parser.cc:27654 cp/pt.cc:4327
+#: cp/parser.cc:27654 cp/pt.cc:4328
 #, gcc-internal-format
 msgid "unexpanded parameter pack in local class in lambda"
 msgstr ""
 
-#: cp/parser.cc:27760 cp/parser.cc:34518
+#: cp/parser.cc:27760 cp/parser.cc:34520
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "預期 class-key"
@@ -64889,38 +64927,38 @@ msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
 msgid "expression must be enclosed in parentheses"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/parser.cc:31368
+#: cp/parser.cc:31370
 #, gcc-internal-format
 msgid "missing additional %<requires%> to start a requires-expression"
 msgstr ""
 
-#: cp/parser.cc:31611
+#: cp/parser.cc:31613
 #, gcc-internal-format
 msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
 msgstr ""
 
-#: cp/parser.cc:31749
+#: cp/parser.cc:31751
 #, fuzzy, gcc-internal-format
 #| msgid "requested position is not an integer constant"
 msgid "result type is not a plain type-constraint"
 msgstr "要求的位置不是一個整數常數"
 
-#: cp/parser.cc:31757
+#: cp/parser.cc:31759
 #, fuzzy, gcc-internal-format
 msgid "return-type-requirement is not a type-constraint"
 msgstr "要求的對齊不是整數常數"
 
-#: cp/parser.cc:32275
+#: cp/parser.cc:32277
 #, fuzzy, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "專用化成員 %<%T::%E%>需求 %<模板<>%>語法specializing member %<%T::%E%> requires %<template<>%> syntax專用化成員 %<%T::%E%>需求 %<模板<>%>語法"
 
-#: cp/parser.cc:32280
+#: cp/parser.cc:32282
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "無效的宣告的 %<%T::%E%>"
 
-#: cp/parser.cc:32284
+#: cp/parser.cc:32286
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "範本參數表太少"
@@ -64929,444 +64967,444 @@ msgstr "範本參數表太少"
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.cc:32291
+#: cp/parser.cc:32293
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "範本參數表太多"
 
-#: cp/parser.cc:32583
+#: cp/parser.cc:32585
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "template-id not allowed for constructor in C++20"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/parser.cc:32694
+#: cp/parser.cc:32696
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "具名回傳值不再被支援"
 
-#: cp/parser.cc:32867
+#: cp/parser.cc:32869
 #, gcc-internal-format
 msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
 msgstr ""
 
-#: cp/parser.cc:32876
+#: cp/parser.cc:32878
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
 msgstr "實字運算子模板 %qD 有無效的參數清單。 預期 non-type 模板引數包裝 <char...>"
 
-#: cp/parser.cc:32882
+#: cp/parser.cc:32884
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
 msgstr "實字運算子模板 %qD 有無效的參數清單。 預期 non-type 模板引數包裝 <char...>"
 
-#: cp/parser.cc:32989
+#: cp/parser.cc:32991
 #, gcc-internal-format
 msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
 msgstr ""
 
-#: cp/parser.cc:32999
+#: cp/parser.cc:33001
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "沒有找到與 %qD 匹配的範本"
 
-#: cp/parser.cc:33022
+#: cp/parser.cc:33024
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "無效的宣告的成員模板在中區域類別"
 
-#: cp/parser.cc:33031
+#: cp/parser.cc:33033
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "C 連結的範本"
 
-#: cp/parser.cc:33051
+#: cp/parser.cc:33053
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "無效的明確的特殊化"
 
-#: cp/parser.cc:33163
+#: cp/parser.cc:33165
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "模板宣告的 %<typedef%>"
 
-#: cp/parser.cc:33214
+#: cp/parser.cc:33216
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "沒有宣告任何東西"
 
-#: cp/parser.cc:33266
+#: cp/parser.cc:33268
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "明確的模板特殊化無法有貯藏類別"
 
-#: cp/parser.cc:33583
+#: cp/parser.cc:33585
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%>應該是 %<>>%>在之內巢狀的模板引數清單"
 
-#: cp/parser.cc:33596
+#: cp/parser.cc:33598
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "可疑的 %<>>%>，使用 %<>%> 來結束範本引數清單"
 
-#: cp/parser.cc:33627
+#: cp/parser.cc:33629
 #, fuzzy, gcc-internal-format
 #| msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgid "%qs should be %qs to terminate a template argument list"
 msgstr "可疑的 %<>>%>，使用 %<>%> 來結束範本引數清單"
 
-#: cp/parser.cc:33944
+#: cp/parser.cc:33946
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.cc:34121
+#: cp/parser.cc:34123
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "無效的使用的 %qD 在中連繫規格"
 
-#: cp/parser.cc:34132
+#: cp/parser.cc:34134
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD specifier"
 msgstr "重製 virt-specifier"
 
-#: cp/parser.cc:34135
+#: cp/parser.cc:34137
 #, fuzzy, gcc-internal-format
 msgid "%qD specifier conflicts with %qs"
 msgstr "%+D 造成區段型態衝突與 %D"
 
-#: cp/parser.cc:34147
+#: cp/parser.cc:34149
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%>之前 %qD"
 
-#: cp/parser.cc:34163
+#: cp/parser.cc:34165
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qD specifier conflicts with %<typedef%>"
 msgstr "%<__thread%> 與 %<typedef%> 一起使用"
 
-#: cp/parser.cc:34272
+#: cp/parser.cc:34274
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++1998 不支援 %<long long%>"
 
-#: cp/parser.cc:34283
+#: cp/parser.cc:34285
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "宣告中同時使用了 %<short%> 和 %<char%>"
 
-#: cp/parser.cc:34288
+#: cp/parser.cc:34290
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "重複的 %qE"
 
-#: cp/parser.cc:34317
+#: cp/parser.cc:34319
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "重複的 %qs"
 
-#: cp/parser.cc:34369
+#: cp/parser.cc:34371
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "預期 %<new%>"
 
-#: cp/parser.cc:34372
+#: cp/parser.cc:34374
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "預期 %<delete%>"
 
-#: cp/parser.cc:34375
+#: cp/parser.cc:34377
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "預期 %<return%>"
 
-#: cp/parser.cc:34381
+#: cp/parser.cc:34383
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "預期 %<extern%>"
 
-#: cp/parser.cc:34384
+#: cp/parser.cc:34386
 #, fuzzy, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "預期 %<static_assert%>"
 
-#: cp/parser.cc:34387
+#: cp/parser.cc:34389
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "預期 %<decltype%>"
 
-#: cp/parser.cc:34390
+#: cp/parser.cc:34392
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "預期 %<operator%>"
 
-#: cp/parser.cc:34393
+#: cp/parser.cc:34395
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "預期 %<class%>"
 
-#: cp/parser.cc:34396
+#: cp/parser.cc:34398
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "預期 %<template%>"
 
-#: cp/parser.cc:34399
+#: cp/parser.cc:34401
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "預期 %<namespace%>"
 
-#: cp/parser.cc:34402
+#: cp/parser.cc:34404
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "預期 %<using%>"
 
-#: cp/parser.cc:34405
+#: cp/parser.cc:34407
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "預期 %<asm%>"
 
-#: cp/parser.cc:34408
+#: cp/parser.cc:34410
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "預期 %<try%>"
 
-#: cp/parser.cc:34411
+#: cp/parser.cc:34413
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "預期 %<catch%>"
 
-#: cp/parser.cc:34414
+#: cp/parser.cc:34416
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "預期 %<throw%>"
 
-#: cp/parser.cc:34417
+#: cp/parser.cc:34419
 #, fuzzy, gcc-internal-format
 msgid "expected %<auto%>"
 msgstr "預期 %<catch%>"
 
-#: cp/parser.cc:34420
+#: cp/parser.cc:34422
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "預期 %<__label__%>"
 
-#: cp/parser.cc:34423
+#: cp/parser.cc:34425
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "預期 %<@try%>"
 
-#: cp/parser.cc:34426
+#: cp/parser.cc:34428
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "預期 %<@synchronized%>"
 
-#: cp/parser.cc:34429
+#: cp/parser.cc:34431
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "預期 %<@throw%>"
 
-#: cp/parser.cc:34432
+#: cp/parser.cc:34434
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "預期 %<__transaction_atomic%>"
 
-#: cp/parser.cc:34435
+#: cp/parser.cc:34437
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "預期 %<__transaction_relaxed%>"
 
-#: cp/parser.cc:34438
+#: cp/parser.cc:34440
 #, fuzzy, gcc-internal-format
 msgid "expected %<co_yield%>"
 msgstr "預期 %<@end%>"
 
-#: cp/parser.cc:34470
+#: cp/parser.cc:34472
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "預期 %<::%>"
 
-#: cp/parser.cc:34482
+#: cp/parser.cc:34484
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "預期 %<...%>"
 
-#: cp/parser.cc:34485
+#: cp/parser.cc:34487
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "預期 %<*%>"
 
-#: cp/parser.cc:34488
+#: cp/parser.cc:34490
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "預期 %<~%>"
 
-#: cp/parser.cc:34494
+#: cp/parser.cc:34496
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "預期 %<:%>或 %<::%>"
 
-#: cp/parser.cc:34521
+#: cp/parser.cc:34523
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: cp/parser.cc:34856
+#: cp/parser.cc:34858
 #, gcc-internal-format
 msgid "redundant enum-key %<enum%s%> in reference to %q#T"
 msgstr ""
 
-#: cp/parser.cc:35007
+#: cp/parser.cc:35009
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "使用了 %qs 標記，在命名 %q#T 時"
 
-#: cp/parser.cc:35012
+#: cp/parser.cc:35014
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T 是在之前宣告的在此"
 
-#: cp/parser.cc:35133
+#: cp/parser.cc:35135
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "redundant class-key %qs in reference to %q#T"
 msgstr "無法宣告對 %q#T 的參照"
 
-#: cp/parser.cc:35291 cp/parser.cc:35325
+#: cp/parser.cc:35293 cp/parser.cc:35327
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with a mismatched class-key %qs"
 msgstr "%qT 宣告的與更大可視性比它的基底 %qT"
 
-#: cp/parser.cc:35298 cp/parser.cc:35331
+#: cp/parser.cc:35300 cp/parser.cc:35333
 #, gcc-internal-format
 msgid "remove the class-key or replace it with %qs"
 msgstr ""
 
-#: cp/parser.cc:35299 cp/parser.cc:35332
+#: cp/parser.cc:35301 cp/parser.cc:35334
 #, fuzzy, gcc-internal-format
 msgid "replace the class-key with %qs"
 msgstr "預期 class-key"
 
-#: cp/parser.cc:35306
+#: cp/parser.cc:35308
 #, fuzzy, gcc-internal-format
 msgid "%qT defined as %qs here"
 msgstr "標貼 %qD 定義的在此"
 
-#: cp/parser.cc:35307
+#: cp/parser.cc:35309
 #, fuzzy, gcc-internal-format
 msgid "%qT first declared as %qs here"
 msgstr "%qD 宣告的在此"
 
-#: cp/parser.cc:35390
+#: cp/parser.cc:35392
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD 重宣告時有不同的可存取性"
 
-#: cp/parser.cc:35411
+#: cp/parser.cc:35413
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "做為消歧義的 %<template%> 只能用於範本內"
 
-#: cp/parser.cc:35661
+#: cp/parser.cc:35663
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "檔案在預設參數處結束"
 
-#: cp/parser.cc:35902 cp/parser.cc:37210 cp/parser.cc:37399
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "位置錯誤的 %<@%D%> Objective-C++ 建構"
 
-#: cp/parser.cc:35973
+#: cp/parser.cc:35975
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c++ 訊息引數被預期"
 
-#: cp/parser.cc:36043
+#: cp/parser.cc:36045
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++ 訊息引數被預期"
 
-#: cp/parser.cc:36074
+#: cp/parser.cc:36076
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> 必須指定一個類型做為引數"
 
-#: cp/parser.cc:36478
+#: cp/parser.cc:36480
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "無效的 Objective-C++ 選擇子名"
 
-#: cp/parser.cc:36553 cp/parser.cc:36571
+#: cp/parser.cc:36555 cp/parser.cc:36573
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "objective-c++ 方法宣告被預期"
 
-#: cp/parser.cc:36565 cp/parser.cc:36631
+#: cp/parser.cc:36567 cp/parser.cc:36633
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "方法屬性必須被指定的於結束"
 
-#: cp/parser.cc:36674
+#: cp/parser.cc:36676
 #, fuzzy, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "零星的 %qs 介於 Objective-C++ 方法"
 
-#: cp/parser.cc:36871 cp/parser.cc:36878 cp/parser.cc:36885
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "無效的型態舉例來說變數"
 
-#: cp/parser.cc:37002
+#: cp/parser.cc:37004
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%> 需要識別碼"
 
-#: cp/parser.cc:37175
+#: cp/parser.cc:37177
 #, fuzzy, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "屬性可能無法被指定的之前 %<@%D%>Objective-C++ 關鍵字"
 
-#: cp/parser.cc:37182
+#: cp/parser.cc:37184
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "前綴屬性被忽略之前 %<@%D%>"
 
-#: cp/parser.cc:37462 cp/parser.cc:37469 cp/parser.cc:37476
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "無效的型態用於內容"
 
-#: cp/parser.cc:37638
+#: cp/parser.cc:37640
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute %qE"
 msgstr "不明內容屬性"
 
-#: cp/parser.cc:38910
+#: cp/parser.cc:38912
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression list"
 msgstr "預期的整數運算式"
 
-#: cp/parser.cc:38927
+#: cp/parser.cc:38929
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/parser.cc:39683
+#: cp/parser.cc:39685
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: cp/parser.cc:40074
+#: cp/parser.cc:40076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "無效的初始值設定"
 
-#: cp/parser.cc:41043
+#: cp/parser.cc:41045
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in iterator type"
 msgstr "類型可能無法被定義在中參數類型"
@@ -65375,13 +65413,13 @@ msgstr "類型可能無法被定義在中參數類型"
 #. check above and add one in semantics.cc (to properly handle templates).
 #. Base this on the allocator/align modifiers check for the 'allocate' clause
 #. in semantics.cc's finish_omp_clauses.
-#: cp/parser.cc:42671
+#: cp/parser.cc:42673
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma vtable no longer supported"
 msgid "%<#pragma omp allocate%> not yet supported"
 msgstr "#pragma vtable 不再受支援"
 
-#: cp/parser.cc:44122
+#: cp/parser.cc:44124
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "parenthesized 初始化未被允許在中 OpenMP %<for%> 迴圈"
@@ -65391,138 +65429,138 @@ msgstr "parenthesized 初始化未被允許在中 OpenMP %<for%> 迴圈"
 msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.cc:44944 cp/pt.cc:18150
+#: cp/parser.cc:44944 cp/pt.cc:18191
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "迭代變數 %qD 不應為消除"
 
-#: cp/parser.cc:47843
+#: cp/parser.cc:47841
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
 msgstr "%<# pragma GCC pop_options%>而無需相應 %<# pragma GCC push_options%>"
 
-#: cp/parser.cc:48613
+#: cp/parser.cc:48611
 #, gcc-internal-format
 msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
 msgstr ""
 
-#: cp/parser.cc:49220
+#: cp/parser.cc:49218
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "無效的初始值設定"
 
-#: cp/parser.cc:49251
+#: cp/parser.cc:49249
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "預期 id-expression"
 
-#: cp/parser.cc:49263
+#: cp/parser.cc:49261
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.cc:49366
+#: cp/parser.cc:49364
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "不能在回傳類型中定義新類型"
 
-#: cp/parser.cc:49386 cp/semantics.cc:6446
+#: cp/parser.cc:49384 cp/semantics.cc:6444
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49390 cp/semantics.cc:6454
+#: cp/parser.cc:49388 cp/semantics.cc:6452
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49393 cp/pt.cc:14635 cp/semantics.cc:6460
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:49396 cp/semantics.cc:6466
+#: cp/parser.cc:49394 cp/semantics.cc:6464
 #, gcc-internal-format
 msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.cc:50116
+#: cp/parser.cc:50114
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.cc:50126
+#: cp/parser.cc:50124
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD 不是一個成員範本函式"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.cc:50487
+#: cp/parser.cc:50485
 #, gcc-internal-format
 msgid "%<atomic_cancel%>"
 msgstr ""
 
-#: cp/parser.cc:50534 cp/semantics.cc:11478
+#: cp/parser.cc:50532 cp/semantics.cc:11476
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%>而無需 transactional 記憶體支援已啟用"
 
-#: cp/parser.cc:50536 cp/semantics.cc:11480
+#: cp/parser.cc:50534 cp/semantics.cc:11478
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%>而無需 transactional 記憶體支援已啟用"
 
-#: cp/parser.cc:50682
+#: cp/parser.cc:50680
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "外 %<__transaction_cancel%>無法在之內外 %<__transaction_atomic%>"
 
-#: cp/parser.cc:50685
+#: cp/parser.cc:50683
 #, fuzzy, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  或 %<transaction_may_cancel_outer%> 函式"
 
-#: cp/parser.cc:50732
+#: cp/parser.cc:50730
 #, fuzzy, gcc-internal-format
 msgid "malformed %<#pragma GCC pch_preprocess%>"
 msgstr "異常的 # pragma GCC 輔助處理器"
 
-#: cp/parser.cc:51032
+#: cp/parser.cc:51030
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
 msgstr "%<# pragma omp taskyield%>也許會只有被已用於複合陳述"
 
-#: cp/parser.cc:51043
+#: cp/parser.cc:51041
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr "%<# pragma omp taskyield%>也許會只有被已用於複合陳述"
 
-#: cp/parser.cc:51120
+#: cp/parser.cc:51118
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC %s%> must be inside a function"
 msgstr "# pragma GCC 最佳化未被允許內部函式"
 
-#: cp/parser.cc:51262
+#: cp/parser.cc:51260
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "multi-source compilation not implemented for C++"
 msgstr "模組間最佳化淍未為 C++ 實作"
 
-#: cp/parser.cc:51299
+#: cp/parser.cc:51297
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "placeholder type not allowed in this context"
 msgstr "此上下文中不允許標準轉換"
 
-#: cp/parser.cc:51508
+#: cp/parser.cc:51506
 #, fuzzy, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "模板可能無法是 %<virtual%>"
 
-#: cp/parser.cc:51564
+#: cp/parser.cc:51562
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -65552,7 +65590,7 @@ msgstr "所包含的類別範本並未被明確特例化"
 msgid "specialization of %qD must appear at namespace scope"
 msgstr "特殊化的 %qD 必須出現於命名空間範圍"
 
-#: cp/pt.cc:889 cp/pt.cc:1129
+#: cp/pt.cc:889 cp/pt.cc:1130
 #, gcc-internal-format
 msgid "specialization of %qD in different namespace"
 msgstr "在不同命名空間內對 %qD 的特例化"
@@ -65568,27 +65606,27 @@ msgstr "  從 %q+#D 的定義"
 msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgstr "%qD 的明確實體化出現在命名空間 %qD 中，而後者並不包含命名空間 %qD"
 
-#: cp/pt.cc:1041
+#: cp/pt.cc:1042
 #, fuzzy, gcc-internal-format
 msgid "name of class shadows template template parameter %qD"
 msgstr "名稱的類別陰影模板模板參數 %qD"
 
-#: cp/pt.cc:1053
+#: cp/pt.cc:1054
 #, fuzzy, gcc-internal-format
 msgid "specialization of alias template %qD"
 msgstr "局部特化的別名模板 %qD"
 
-#: cp/pt.cc:1056 cp/pt.cc:1195
+#: cp/pt.cc:1057 cp/pt.cc:1196
 #, gcc-internal-format
 msgid "explicit specialization of non-template %qT"
 msgstr "明確特例化非範本 %qT"
 
-#: cp/pt.cc:1088
+#: cp/pt.cc:1089
 #, gcc-internal-format
 msgid "specialization of %qT after instantiation"
 msgstr "%qT 的實體化在特例化之後"
 
-#: cp/pt.cc:1132
+#: cp/pt.cc:1133
 #, fuzzy, gcc-internal-format
 #| msgid "  from definition of %q+#D"
 msgid "from definition of %q#D"
@@ -65596,150 +65634,150 @@ msgstr "  從 %q+#D 的定義"
 
 #. But if we've had an implicit instantiation, that's a
 #. problem ([temp.expl.spec]/6).
-#: cp/pt.cc:1173
+#: cp/pt.cc:1174
 #, gcc-internal-format
 msgid "specialization %qT after instantiation %qT"
 msgstr "%qT 的實體化在 %qT 的特例化之後"
 
-#: cp/pt.cc:1191
+#: cp/pt.cc:1192
 #, fuzzy, gcc-internal-format
 msgid "template specialization of %qD not allowed by ISO C++"
 msgstr "模板特殊化的 %qD 不允許由 ISO C++"
 
-#: cp/pt.cc:1568
+#: cp/pt.cc:1569
 #, gcc-internal-format
 msgid "specialization of %qD after instantiation"
 msgstr "%qD 的特例化在實體化之後"
 
-#: cp/pt.cc:2046 cp/semantics.cc:6316
+#: cp/pt.cc:2047 cp/semantics.cc:6314
 #, fuzzy, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:2182
+#: cp/pt.cc:2183
 #, gcc-internal-format
 msgid "%qD is not a function template"
 msgstr "%qD 不是一個函式範本"
 
-#: cp/pt.cc:2187
+#: cp/pt.cc:2188
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable template"
 msgstr "%qD 並非變數"
 
-#: cp/pt.cc:2470
+#: cp/pt.cc:2471
 #, gcc-internal-format
 msgid "template-id %qD for %q+D does not match any template declaration"
 msgstr "範本識別碼 %qD(屬於 %q+D)不匹配任何範本宣告"
 
-#: cp/pt.cc:2474
+#: cp/pt.cc:2475
 #, fuzzy, gcc-internal-format
 msgid "saw %d %<template<>%>, need %d for specializing a member function template"
 msgstr "發現 %d %<template<>%>，需要 %d 用於專用化成員函式模板"
 
-#: cp/pt.cc:2484
+#: cp/pt.cc:2485
 #, gcc-internal-format
 msgid "ambiguous template specialization %qD for %q+D"
 msgstr "有歧義的範本特例化 %qD (為 %q+D)"
 
-#: cp/pt.cc:2688
+#: cp/pt.cc:2689
 #, fuzzy, gcc-internal-format
 msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.cc:2698
+#: cp/pt.cc:2699
 #, fuzzy, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: cp/pt.cc:2704
+#: cp/pt.cc:2705
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
 msgstr ""
 
-#: cp/pt.cc:2728
+#: cp/pt.cc:2729
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
 msgstr "在初次使用後明確特例化 %qD"
 
 #. This was allowed in C++98, so only pedwarn.
-#: cp/pt.cc:2733
+#: cp/pt.cc:2734
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
 msgstr "%qD 的明確實體化出現在命名空間 %qD 中，而後者並不包含命名空間 %qD"
 
-#: cp/pt.cc:2769
+#: cp/pt.cc:2770
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "explicit specialization %q#D may be missing attributes"
 msgstr "在初次使用後明確特例化 %qD"
 
-#: cp/pt.cc:2773
+#: cp/pt.cc:2774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
 msgstr "在之前宣告的在此"
 
-#: cp/pt.cc:2774
+#: cp/pt.cc:2775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
 msgstr "在之前宣告的在此"
 
-#: cp/pt.cc:2866 cp/pt.cc:2926
+#: cp/pt.cc:2867 cp/pt.cc:2927
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD in declaration of primary template"
 msgid "template-id %qE in declaration of primary template"
 msgstr "範本識別碼 %qD 出現在基本範本的宣告中"
 
-#: cp/pt.cc:2879
+#: cp/pt.cc:2880
 #, gcc-internal-format
 msgid "template parameter list used in explicit instantiation"
 msgstr "明確初始化中出現了範本參數清單"
 
-#: cp/pt.cc:2885
+#: cp/pt.cc:2886
 #, gcc-internal-format
 msgid "definition provided for explicit instantiation"
 msgstr "為明確實體化提供的定義"
 
-#: cp/pt.cc:2893
+#: cp/pt.cc:2894
 #, gcc-internal-format
 msgid "too many template parameter lists in declaration of %qD"
 msgstr "%qD 宣告時範本參數表太多"
 
-#: cp/pt.cc:2896
+#: cp/pt.cc:2897
 #, gcc-internal-format
 msgid "too few template parameter lists in declaration of %qD"
 msgstr "%qD 宣告時範本參數表太少"
 
-#: cp/pt.cc:2898
+#: cp/pt.cc:2899
 #, gcc-internal-format
 msgid "explicit specialization of %qD must be introduced by %<template <>%>"
 msgstr "%qD 的明確特例化必須由 %<template <>%> 引入"
 
-#: cp/pt.cc:2904
+#: cp/pt.cc:2905
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization declared %<concept%>"
 msgstr "明確特例化非範本 %qT"
 
-#: cp/pt.cc:2937
+#: cp/pt.cc:2938
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-type partial specialization %qE is not allowed"
 msgstr "函式範本部分特例化 %qD 是不允許的"
 
-#: cp/pt.cc:2941
+#: cp/pt.cc:2942
 #, fuzzy, gcc-internal-format
 #| msgid "function template partial specialization %qD is not allowed"
 msgid "non-class, non-variable partial specialization %qE is not allowed"
 msgstr "函式範本部分特例化 %qD 是不允許的"
 
-#: cp/pt.cc:2973
+#: cp/pt.cc:2974
 #, gcc-internal-format
 msgid "default argument specified in explicit specialization"
 msgstr "明確特例化時指定了預設參數"
 
-#: cp/pt.cc:3016
+#: cp/pt.cc:3017
 #, gcc-internal-format
 msgid "%qD is not a template function"
 msgstr "%qD 不是一個範本函式"
@@ -65752,163 +65790,163 @@ msgstr "%qD 不是一個範本函式"
 #. program is ill-formed.
 #.
 #. Similar language is found in [temp.explicit].
-#: cp/pt.cc:3078
+#: cp/pt.cc:3079
 #, gcc-internal-format
 msgid "specialization of implicitly-declared special member function"
 msgstr "特例化了隱含宣告的特殊成員函式"
 
-#: cp/pt.cc:3094
+#: cp/pt.cc:3095
 #, gcc-internal-format
 msgid "no member function %qD declared in %qT"
 msgstr "成員函式 %qD 未在 %qT 中宣告"
 
-#: cp/pt.cc:3125
+#: cp/pt.cc:3126
 #, fuzzy, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
 msgstr "朋友宣告 %qD 在中區域類別而無需事前宣告"
 
-#: cp/pt.cc:3128
+#: cp/pt.cc:3129
 #, fuzzy, gcc-internal-format
 msgid "friend declaration here"
 msgstr "與此處早先的宣告 %q+#D 衝突"
 
-#: cp/pt.cc:3239
+#: cp/pt.cc:3240
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "explicit specialization of function concept %qD"
 msgstr "明確特例化非範本 %qT"
 
-#: cp/pt.cc:3817
+#: cp/pt.cc:3818
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "argument to %<__integer_pack%> must be between 0 and %d"
 msgstr "%L 處 ACOS 的參數必須在 -1 和 1 之間"
 
-#: cp/pt.cc:4190
+#: cp/pt.cc:4191
 #, fuzzy, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "基底初始設定式擴展 %<%T%>不含任何參數包裝"
 
-#: cp/pt.cc:4258
+#: cp/pt.cc:4259
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qT contains no parameter packs"
 msgstr "擴展胚騰 %<%T%>不含任何引數包裝"
 
-#: cp/pt.cc:4260
+#: cp/pt.cc:4261
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qE contains no parameter packs"
 msgstr "擴展胚騰 %<%E%>不含任何引數包裝"
 
-#: cp/pt.cc:4344
+#: cp/pt.cc:4345
 #, fuzzy, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "參數包裝無法展開的與 %<...%>："
 
-#: cp/pt.cc:4361 cp/pt.cc:5242
+#: cp/pt.cc:4362 cp/pt.cc:5243
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.cc:4363
+#: cp/pt.cc:4364
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "        %s"
 msgstr "          %s"
 
-#: cp/pt.cc:4489
+#: cp/pt.cc:4490
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%q+D 的宣告隱藏了一個參數"
 
-#: cp/pt.cc:4492
+#: cp/pt.cc:4493
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "%q+D 的宣告隱藏了一個參數"
 
-#: cp/pt.cc:4494
+#: cp/pt.cc:4495
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "範本參數類型 %qT 宣告為 %<friend%>"
 
-#: cp/pt.cc:5178
+#: cp/pt.cc:5179
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "局部特化的別名模板 %qD"
 
-#: cp/pt.cc:5237
+#: cp/pt.cc:5238
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "部分特例化中未用到範本參數："
 
-#: cp/pt.cc:5260
+#: cp/pt.cc:5261
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "部分特例化 %qT 並未特例化任何範本參數"
 
-#: cp/pt.cc:5264
+#: cp/pt.cc:5265
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.cc:5268 cp/pt.cc:5279 cp/pt.cc:5287
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "在之前宣告的在此"
 
-#: cp/pt.cc:5276
+#: cp/pt.cc:5277
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.cc:5286
+#: cp/pt.cc:5287
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qE"
 msgid "too many arguments for partial specialization %qT"
 msgstr "提供給函式 %qE 的引數太多"
 
-#: cp/pt.cc:5301
+#: cp/pt.cc:5302
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "部分特例化 %qT 並未特例化任何範本參數"
 
-#: cp/pt.cc:5303
+#: cp/pt.cc:5304
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "在之前宣告的在此"
 
-#: cp/pt.cc:5345
+#: cp/pt.cc:5346
 #, fuzzy, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "參數包裝引數 %qE 必須是於結束的模板引數清單"
 
-#: cp/pt.cc:5348
+#: cp/pt.cc:5349
 #, fuzzy, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "參數包裝引數 %qT 必須是於結束的模板引數清單"
 
-#: cp/pt.cc:5410
+#: cp/pt.cc:5411
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "型態 %qT 的模板引數 %qE 依存於模板參數"
 
-#: cp/pt.cc:5478
+#: cp/pt.cc:5479
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.cc:5482
+#: cp/pt.cc:5483
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "局部特化的 %qT 之後實體化的 %qT"
 
-#: cp/pt.cc:5665
+#: cp/pt.cc:5666
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD 沒有預設參數"
@@ -65917,48 +65955,48 @@ msgstr "%qD 沒有預設參數"
 #. (DR 2032), or alias template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.cc:5688
+#: cp/pt.cc:5689
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "參數包裝 %qE 必須是於結束的模板參數清單"
 
-#: cp/pt.cc:5724
+#: cp/pt.cc:5725
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "預設模板引數可能無法被已用於函式模板朋友重新宣告"
 
-#: cp/pt.cc:5727
+#: cp/pt.cc:5728
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "預設模板引數可能無法被已用於函式模板朋友宣告"
 
-#: cp/pt.cc:5730
+#: cp/pt.cc:5731
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
 msgstr "預設模板引數可能無法被已用於函式模板而無需 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.cc:5733
+#: cp/pt.cc:5734
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "預設模板引數可能無法被已用於局部特化"
 
-#: cp/pt.cc:5736 cp/pt.cc:5794
+#: cp/pt.cc:5737 cp/pt.cc:5795
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "預設引數用於模板參數用於類別封閉 %qD"
 
-#: cp/pt.cc:5905
+#: cp/pt.cc:5906
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "參數 %qD 被宣告為 void"
 
-#: cp/pt.cc:5913
+#: cp/pt.cc:5914
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "範本類別沒具名字"
 
-#: cp/pt.cc:5921
+#: cp/pt.cc:5922
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
@@ -65968,514 +66006,514 @@ msgstr "non-member 函式 %qD 無法有 cv-qualifier"
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.cc:5944
+#: cp/pt.cc:5945
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD 範本宣告無效"
 
-#: cp/pt.cc:6096
+#: cp/pt.cc:6097
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "對非範本 %q#D 的範本定義"
 
-#: cp/pt.cc:6135
+#: cp/pt.cc:6136
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "需要 %d 級的 %q#D 範本參數，卻給出了 %d 級"
 
-#: cp/pt.cc:6149
+#: cp/pt.cc:6150
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "得到 %d 個範本參數，為 %q#D"
 
-#: cp/pt.cc:6152
+#: cp/pt.cc:6153
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "得到 %d 個範本參數，為 %q#T"
 
-#: cp/pt.cc:6154
+#: cp/pt.cc:6155
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  但實際需要 %d 個"
 
-#: cp/pt.cc:6175
+#: cp/pt.cc:6176
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "模板引數到 %qD 不匹配原來的模板 %qD"
 
-#: cp/pt.cc:6178
+#: cp/pt.cc:6179
 #, fuzzy, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "使用模板<>用於明確的特殊化"
 
-#: cp/pt.cc:6200
+#: cp/pt.cc:6201
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD with different constraints"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/pt.cc:6345
+#: cp/pt.cc:6346
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT 不是一個範本類型"
 
-#: cp/pt.cc:6358
+#: cp/pt.cc:6359
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qD 的宣告中沒有 template 限定"
 
-#: cp/pt.cc:6369
+#: cp/pt.cc:6370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "redeclared 與 %d 模板參數"
 
-#: cp/pt.cc:6373
+#: cp/pt.cc:6374
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "前一個宣告 %q+D 使用 %d 模板參數"
 
-#: cp/pt.cc:6407
+#: cp/pt.cc:6408
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "範本參數 %q+#D"
 
-#: cp/pt.cc:6409
+#: cp/pt.cc:6410
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "在這裡又被宣告為 %q#D"
 
-#: cp/pt.cc:6411
+#: cp/pt.cc:6412
 #, fuzzy, gcc-internal-format
 msgid "redeclared here"
 msgstr "宣告的在此"
 
-#: cp/pt.cc:6422
+#: cp/pt.cc:6423
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+#D with different constraints"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/pt.cc:6425 cp/pt.cc:6453
+#: cp/pt.cc:6426 cp/pt.cc:6454
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "原來的定義出現的在此"
 
-#: cp/pt.cc:6450
+#: cp/pt.cc:6451
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %q#D with different constraints"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/pt.cc:6861 cp/pt.cc:6931
+#: cp/pt.cc:6872 cp/pt.cc:6942
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE 並非有效模板引數用於型態 %qT"
 
-#: cp/pt.cc:6864
+#: cp/pt.cc:6875
 #, fuzzy, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "它必須是位址的函式與外部連結"
 
-#: cp/pt.cc:6867
+#: cp/pt.cc:6878
 #, fuzzy, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "它必須是位址的函式與外部連結"
 
-#: cp/pt.cc:6881
+#: cp/pt.cc:6892
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.cc:6885
+#: cp/pt.cc:6896
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為 %qD 沒有外部連結"
 
-#: cp/pt.cc:6934
+#: cp/pt.cc:6945
 #, fuzzy, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "它必須是成員指標的形式 %<&X::Y%>"
 
-#: cp/pt.cc:6936
+#: cp/pt.cc:6947
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD 不是 %qT 的成員"
 
-#: cp/pt.cc:7005
+#: cp/pt.cc:7016
 #, fuzzy, gcc-internal-format
 msgid "  couldn%'t deduce template parameter %qD"
 msgstr "  無法 deduce 模板參數 %qD"
 
-#: cp/pt.cc:7014
+#: cp/pt.cc:7025
 #, fuzzy, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  類型 %qT 和 %qT 有不相容的 cv-qualifiers"
 
-#: cp/pt.cc:7023
+#: cp/pt.cc:7034
 #, fuzzy, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  不匹配的類型 %qT 和 %qT"
 
-#: cp/pt.cc:7032
+#: cp/pt.cc:7043
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  模板參數 %qD 並非參數包裝，但是引數 %qD 是"
 
-#: cp/pt.cc:7043
+#: cp/pt.cc:7054
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  模板引數 %qE 不匹配成員指標常數 %qE"
 
-#: cp/pt.cc:7053
+#: cp/pt.cc:7064
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE 不是 equivalent 到 %qE"
 
-#: cp/pt.cc:7062
+#: cp/pt.cc:7073
 #, fuzzy, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  不一致參數包裝推導與 %qT 和 %qT"
 
-#: cp/pt.cc:7074
+#: cp/pt.cc:7085
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  deduced 衝突類型用於參數 %qT (%qT 和 %qT)"
 
-#: cp/pt.cc:7078
+#: cp/pt.cc:7089
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  deduced 衝突值用於 non-type 參數 %qE (%qE 和 %qE)"
 
-#: cp/pt.cc:7089
+#: cp/pt.cc:7100
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  variable-sized 陣列類型 %qT 並非有效模板引數"
 
-#: cp/pt.cc:7100
+#: cp/pt.cc:7111
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  成員函數型式 %qT 並非有效模板引數"
 
-#: cp/pt.cc:7143
+#: cp/pt.cc:7154
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  無法轉換 %qE (型態 %qT) 輸入 %qT"
 
-#: cp/pt.cc:7156
+#: cp/pt.cc:7167
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT 是模稜兩可的基礎類別的 %qT"
 
-#: cp/pt.cc:7160
+#: cp/pt.cc:7171
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT 未被衍生自 %qT"
 
-#: cp/pt.cc:7171
+#: cp/pt.cc:7182
 #, fuzzy, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  模板參數的模板模板引數是不一致與其他 deduced 模板引數"
 
-#: cp/pt.cc:7181
+#: cp/pt.cc:7192
 #, fuzzy, gcc-internal-format
 msgid "  cannot deduce a template for %qT from non-template type %qT"
 msgstr "  無法 deduce 模板用於 %qT 從 non-template 型態 %qT"
 
-#: cp/pt.cc:7191
+#: cp/pt.cc:7202
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "  模板引數 %qE 不匹配 %qD"
 
-#: cp/pt.cc:7242
+#: cp/pt.cc:7253
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qE 並非變數"
 
-#: cp/pt.cc:7251
+#: cp/pt.cc:7262
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有外部連結"
 
-#: cp/pt.cc:7261
+#: cp/pt.cc:7272
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.cc:7278
+#: cp/pt.cc:7289
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "  variable-sized 陣列類型 %qT 並非有效模板引數"
 
-#: cp/pt.cc:7288
+#: cp/pt.cc:7299
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "  variable-sized 陣列類型 %qT 並非有效模板引數"
 
-#: cp/pt.cc:7295
+#: cp/pt.cc:7306
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有外部連結"
 
-#: cp/pt.cc:7313
+#: cp/pt.cc:7324
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD 並非有效模板引數因為 %qD 是變數，不是位址的變數"
 
-#: cp/pt.cc:7321
+#: cp/pt.cc:7332
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD 並非有效模板引數因為 %qD 是變數，不是位址的變數"
 
-#: cp/pt.cc:7443
+#: cp/pt.cc:7454
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為字面字串不能用在此上下文中"
 
-#: cp/pt.cc:7608
+#: cp/pt.cc:7619
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/pt.cc:7622
+#: cp/pt.cc:7633
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a compile-time constant"
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/pt.cc:7708
+#: cp/pt.cc:7719
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為 cv 限定衝突"
 
-#: cp/pt.cc:7716
+#: cp/pt.cc:7727
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為它不是 lvalue"
 
-#: cp/pt.cc:7734
+#: cp/pt.cc:7745
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D 並非有效模板引數用於型態 %qT 因為參考變數沒有常數位址"
 
-#: cp/pt.cc:7793
+#: cp/pt.cc:7804
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為它是一個指標"
 
-#: cp/pt.cc:7795
+#: cp/pt.cc:7806
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "嘗試使用 %qE 代替"
 
-#: cp/pt.cc:7849
+#: cp/pt.cc:7860
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為它的類型是 %qT"
 
-#: cp/pt.cc:8441
+#: cp/pt.cc:8452
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/pt.cc:8457
+#: cp/pt.cc:8468
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/pt.cc:8601
+#: cp/pt.cc:8612
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "injected-class-name %qD 使用的做為模板模板引數"
 
-#: cp/pt.cc:8630
+#: cp/pt.cc:8641
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "無效的使用的解構式 %qE 做為型態"
 
-#: cp/pt.cc:8635
+#: cp/pt.cc:8646
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "需要使用某個範本參數的類型成員時，請使用 %<typename %E%>"
 
-#: cp/pt.cc:8651 cp/pt.cc:8685 cp/pt.cc:8735
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "引數 %d 的類型/值不匹配，在 %qD 的範本參數清單中"
 
-#: cp/pt.cc:8659
+#: cp/pt.cc:8670
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  需要一個 %qT 類型的常數，卻給出了 %qT"
 
-#: cp/pt.cc:8667
+#: cp/pt.cc:8678
 #, fuzzy, gcc-internal-format
 msgid "  ambiguous template argument for non-type template parameter is treated as function type"
 msgstr "預設引數用於模板參數用於類別封閉 %qD"
 
-#: cp/pt.cc:8673
+#: cp/pt.cc:8684
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  需要一個類別範本，卻給出了 %qE"
 
-#: cp/pt.cc:8676
+#: cp/pt.cc:8687
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  需要一個類型，卻給出了 %qE"
 
-#: cp/pt.cc:8690
+#: cp/pt.cc:8701
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  需要一個類型，卻給出了 %qT"
 
-#: cp/pt.cc:8693
+#: cp/pt.cc:8704
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  需要一個類別範本，卻給出了 %qT"
 
-#: cp/pt.cc:8739
+#: cp/pt.cc:8750
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  預期的模板的型態 %qD，得到 %qT"
 
-#: cp/pt.cc:8753
+#: cp/pt.cc:8764
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "引數 %d 的類型/值不匹配，在 %qD 的範本參數清單中"
 
-#: cp/pt.cc:8756
+#: cp/pt.cc:8767
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  需要一個類型，卻給出了 %qE"
 
-#: cp/pt.cc:8844
+#: cp/pt.cc:8855
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "不能將範本參數從 %qE 轉換到 %qT"
 
-#: cp/pt.cc:8982 cp/pt.cc:9308
+#: cp/pt.cc:8993 cp/pt.cc:9319
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "範本參數 %d 無效"
 
-#: cp/pt.cc:8997 cp/pt.cc:9142
+#: cp/pt.cc:9008 cp/pt.cc:9153
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: cp/pt.cc:9138
+#: cp/pt.cc:9149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: cp/pt.cc:9147
+#: cp/pt.cc:9158
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "提供給 %q+D"
 
-#: cp/pt.cc:9172
+#: cp/pt.cc:9183
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "預設引數用於模板參數用於類別封閉 %qD"
 
-#: cp/pt.cc:9176
+#: cp/pt.cc:9187
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "為參數 %d (屬於 %q#D)指定了預設引數"
 
-#: cp/pt.cc:9274
+#: cp/pt.cc:9285
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.cc:9841
+#: cp/pt.cc:9852
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D 並非函式模板"
 
-#: cp/pt.cc:10004
+#: cp/pt.cc:10015
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "非範本類型 %qT 做為範本"
 
-#: cp/pt.cc:10006
+#: cp/pt.cc:10017
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "對於範本宣告 %q+D"
 
-#: cp/pt.cc:10175 cp/pt.cc:22257
+#: cp/pt.cc:10186 cp/pt.cc:22299
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure for %qD"
 msgstr "內部一致性錯誤"
 
-#: cp/pt.cc:10528
+#: cp/pt.cc:10539
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "在範本中使用 %qs"
 
-#: cp/pt.cc:11252
+#: cp/pt.cc:11263
 #, fuzzy, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "模板具現化深度超出最大值的 %d (使用 -ftemplate-depth=到增加最大值) 替代 %qS"
 
-#: cp/pt.cc:11996
+#: cp/pt.cc:12037
 #, fuzzy, gcc-internal-format
 msgid "score argument must be constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: cp/pt.cc:12005
+#: cp/pt.cc:12046
 #, fuzzy, gcc-internal-format
 msgid "score argument must be non-negative"
 msgstr "『%s』於 %L 必須是 nonnegative"
 
-#: cp/pt.cc:12032
+#: cp/pt.cc:12073
 #, fuzzy, gcc-internal-format
 msgid "property must be constant integer expression or string literal"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/pt.cc:12581
+#: cp/pt.cc:12622
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "flexible 陣列成員在中聯合"
 
-#: cp/pt.cc:13071
+#: cp/pt.cc:13112
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.cc:13531
+#: cp/pt.cc:13572
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not at beginning of declaration"
 msgid "%qE is not the entire pattern of the pack expansion"
 msgstr "%qE 沒有出現在宣告的開頭"
 
-#: cp/pt.cc:13619
+#: cp/pt.cc:13660
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "不匹配的引數包裝長度當展開 %<%T%>"
 
-#: cp/pt.cc:13622
+#: cp/pt.cc:13663
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "不匹配的引數包裝長度當展開 %<%E%>"
 
-#: cp/pt.cc:14310
+#: cp/pt.cc:14351
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "重定義 %q#D 的預設參數"
 
-#: cp/pt.cc:14406
+#: cp/pt.cc:14447
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員函式指標"
 
-#: cp/pt.cc:15398
+#: cp/pt.cc:15439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "mismatched argument pack lengths (%d vs %d)"
 msgstr "不匹配的引數包裝長度當展開 %<%T%>"
@@ -66493,308 +66531,308 @@ msgstr "不匹配的引數包裝長度當展開 %<%T%>"
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.cc:15587
+#: cp/pt.cc:15628
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "變數 %qD 有函數型式"
 
-#: cp/pt.cc:15788
+#: cp/pt.cc:15829
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "無效的參數類型 %qT"
 
-#: cp/pt.cc:15790
+#: cp/pt.cc:15831
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "在宣告 %q+D 中"
 
-#: cp/pt.cc:15917
+#: cp/pt.cc:15958
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "函式回傳了一個陣列"
 
-#: cp/pt.cc:15919
+#: cp/pt.cc:15960
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "函式回傳了一個函式"
 
-#: cp/pt.cc:16625
+#: cp/pt.cc:16666
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "形成對 void 的參照"
 
-#: cp/pt.cc:16627
+#: cp/pt.cc:16668
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "表單指標到參考類型 %qT"
 
-#: cp/pt.cc:16629
+#: cp/pt.cc:16670
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "表單參考到參考類型 %qT"
 
-#: cp/pt.cc:16642
+#: cp/pt.cc:16683
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/pt.cc:16645
+#: cp/pt.cc:16686
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "無法宣告參考到經資格修飾函數型式 %qT"
 
-#: cp/pt.cc:16693
+#: cp/pt.cc:16734
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員指標"
 
-#: cp/pt.cc:16699
+#: cp/pt.cc:16740
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "產生參照類型 %qT 的成員指標"
 
-#: cp/pt.cc:16705
+#: cp/pt.cc:16746
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "建立參照 void 類型的成員指標"
 
-#: cp/pt.cc:16771
+#: cp/pt.cc:16812
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "產生 %qT 的陣列"
 
-#: cp/pt.cc:16808
+#: cp/pt.cc:16849
 #, gcc-internal-format
 msgid "%qD is instantiated for an empty pack"
 msgstr ""
 
-#: cp/pt.cc:16829
+#: cp/pt.cc:16870
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT 不是類別、結構或聯合類型"
 
-#: cp/pt.cc:16869
+#: cp/pt.cc:16910
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT 被解析到非列舉類型 %qT"
 
-#: cp/pt.cc:16877
+#: cp/pt.cc:16918
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is is not a class type"
 msgid "%qT resolves to %qT, which is not a class type"
 msgstr "%qT 被解析到非類別類型 %qT"
 
-#: cp/pt.cc:16995
+#: cp/pt.cc:17036
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "在範本中使用 %qs"
 
-#: cp/pt.cc:17314
+#: cp/pt.cc:17355
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "限定型態 %qT 不匹配解構式名稱 ~%qT"
 
-#: cp/pt.cc:17329
+#: cp/pt.cc:17370
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "依賴名 %qE 被解析為非類型，但實體化卻產生了一個類型"
 
-#: cp/pt.cc:17331
+#: cp/pt.cc:17372
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "如果您想指定類型，請使用 %<typename %E%>"
 
-#: cp/pt.cc:17424
+#: cp/pt.cc:17465
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D expands to an empty list of expressions"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/pt.cc:19448 cp/pt.cc:21638
+#: cp/pt.cc:19489 cp/pt.cc:21680
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "無效的使用的包裝擴展運算式"
 
-#: cp/pt.cc:19452 cp/pt.cc:21642
+#: cp/pt.cc:19493 cp/pt.cc:21684
 #, fuzzy, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "使用 %<...%>到展開引數包裝"
 
-#: cp/pt.cc:19599
+#: cp/pt.cc:19640
 #, fuzzy, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "ISO C++不允許初始設定式在中 lambda 運算式擷取清單"
 
-#: cp/pt.cc:20912
+#: cp/pt.cc:20954
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD 未被宣告在中這個範圍，而找不到任何宣告是由 argument-dependent 查找於點的實體化"
 
-#: cp/pt.cc:20947
+#: cp/pt.cc:20989
 #, fuzzy, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "宣告在中附屬基底 %qT 找不到由資格不符的查找"
 
-#: cp/pt.cc:20952
+#: cp/pt.cc:20994
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "使用 %<this->%D%>做為替代"
 
-#: cp/pt.cc:20955
+#: cp/pt.cc:20997
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "使用 %<%T::%D%>做為替代"
 
-#: cp/pt.cc:20960
+#: cp/pt.cc:21002
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D 宣告的在此，稍後在中轉譯單位"
 
-#: cp/pt.cc:21011
+#: cp/pt.cc:21053
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_convertvector%>"
 msgstr "錯誤的引數數量到 %<__builtin_choose_expr%>"
 
-#: cp/pt.cc:21038
+#: cp/pt.cc:21080
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<assume%> attribute"
 msgstr "錯誤的引數數量指定的用於 %qE 屬性"
 
-#: cp/pt.cc:21249
+#: cp/pt.cc:21291
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT 既不是類別也不是命名空間"
 
-#: cp/pt.cc:21252
+#: cp/pt.cc:21294
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD 既不是類別也不是命名空間"
 
-#: cp/pt.cc:21570
+#: cp/pt.cc:21612
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "使用無效欄位 %qD"
 
-#: cp/pt.cc:21903
+#: cp/pt.cc:21945
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT 是/使用了匿名類型"
 
-#: cp/pt.cc:21905
+#: cp/pt.cc:21947
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "模板引數用於 %qD 使用本地型態 %qT"
 
-#: cp/pt.cc:21915
+#: cp/pt.cc:21957
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT 是一個可變類型"
 
-#: cp/pt.cc:21930
+#: cp/pt.cc:21972
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "整型運算式 %qE 不是常數"
 
-#: cp/pt.cc:21948
+#: cp/pt.cc:21990
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  試圖實體化 %qD"
 
-#: cp/pt.cc:26341
+#: cp/pt.cc:26383
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.cc:26343
+#: cp/pt.cc:26385
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.cc:26349
+#: cp/pt.cc:26391
 #, fuzzy
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.cc:26376 cp/pt.cc:26471
+#: cp/pt.cc:26418 cp/pt.cc:26513
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "對非範本 %q#D 的明確實體化"
 
-#: cp/pt.cc:26382
+#: cp/pt.cc:26424
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of variable concept %q#D"
 msgstr "對非範本 %q#D 的明確實體化"
 
-#: cp/pt.cc:26384
+#: cp/pt.cc:26426
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of function concept %q#D"
 msgstr "對非範本 %q#D 的明確實體化"
 
-#: cp/pt.cc:26403
+#: cp/pt.cc:26445
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD 並非靜態資料成員的類別模板"
 
-#: cp/pt.cc:26409 cp/pt.cc:26466
+#: cp/pt.cc:26451 cp/pt.cc:26508
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "沒有找到與 %qD 匹配的範本"
 
-#: cp/pt.cc:26414
+#: cp/pt.cc:26456
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "型態 %qT 用於明確的實體化 %qD 不匹配宣告的型態 %qT"
 
-#: cp/pt.cc:26422
+#: cp/pt.cc:26464
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "對 %q#D 的明確實體化"
 
-#: cp/pt.cc:26458
+#: cp/pt.cc:26500
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "對 %q#D 重複的明確實體化"
 
-#: cp/pt.cc:26481 cp/pt.cc:26548
+#: cp/pt.cc:26523 cp/pt.cc:26590
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++1998 禁止使用的 %<extern%> 於明確的實體化"
 
-#: cp/pt.cc:26486 cp/pt.cc:26563
+#: cp/pt.cc:26528 cp/pt.cc:26605
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "為範本實體化化套用了存儲類型 %qD"
 
-#: cp/pt.cc:26520
+#: cp/pt.cc:26562
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "明確的實體化的 non-class 模板 %qD"
 
-#: cp/pt.cc:26523
+#: cp/pt.cc:26565
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "明確實體化非範本類型 %qT"
 
-#: cp/pt.cc:26532
+#: cp/pt.cc:26574
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%q#T 的明確實體化出現在範本定義之前"
 
-#: cp/pt.cc:26553
+#: cp/pt.cc:26595
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ 不允許在明確實體化時使用 %qE"
 
-#: cp/pt.cc:26593
+#: cp/pt.cc:26635
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "對 %q#T 重複的明確實體化"
 
-#: cp/pt.cc:26909
+#: cp/pt.cc:26951
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -66807,173 +66845,173 @@ msgstr "在初次使用後明確特例化 %qD"
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.cc:27382
+#: cp/pt.cc:27424
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "明確實體化 %qD 時沒有可用的定義"
 
-#: cp/pt.cc:27427
+#: cp/pt.cc:27469
 #, fuzzy, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
 msgstr "模板具現化深度超出最大值的 %d 舉例說明 %q+D, 可能會從虛擬表格產生 (使用 -ftemplate-depth=到增加最大值)"
 
-#: cp/pt.cc:27801
+#: cp/pt.cc:27843
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.cc:27831
+#: cp/pt.cc:27873
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
 msgstr "%q#T 並非有效型態用於模板 non-type 參數"
 
-#: cp/pt.cc:27840
+#: cp/pt.cc:27882
 #, fuzzy, gcc-internal-format
 msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.cc:27848
+#: cp/pt.cc:27890
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/pt.cc:27850
+#: cp/pt.cc:27892
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T 並非有效型態用於模板 non-type 參數"
 
-#: cp/pt.cc:29294
+#: cp/pt.cc:29336
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "關鍵字 %<typename%> 不能在範本以外使用"
 
-#: cp/pt.cc:29485
+#: cp/pt.cc:29527
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be constrained"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/pt.cc:29494
+#: cp/pt.cc:29536
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a namespace"
 msgid "concept %qE not in namespace scope"
 msgstr "%qT 不是一個命名空間"
 
-#: cp/pt.cc:29500
+#: cp/pt.cc:29542
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#T inside template parameter list"
 msgid "concept %qE has multiple template parameter lists"
 msgstr "在範本參數清單中定義了 %q#T"
 
-#: cp/pt.cc:29531
+#: cp/pt.cc:29573
 #, fuzzy, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "deducing 從 brace-enclosed 初始設定式清單需求 # 包含 <initializer_list>"
 
-#: cp/pt.cc:30809
+#: cp/pt.cc:30867
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-deducible template %qT used without template arguments"
 msgstr "非範本 %qD 做為範本"
 
-#: cp/pt.cc:30821
+#: cp/pt.cc:30879
 #, fuzzy, gcc-internal-format
 msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.cc:30827
+#: cp/pt.cc:30885
 #, fuzzy, gcc-internal-format
 #| msgid "try using %qE instead"
 msgid "use %qD directly instead"
 msgstr "嘗試使用 %qE 代替"
 
-#: cp/pt.cc:30955
+#: cp/pt.cc:31013
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.cc:30962
+#: cp/pt.cc:31020
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.cc:30974
+#: cp/pt.cc:31032
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "  模板引數推導/替代失敗："
 
-#: cp/pt.cc:30977
+#: cp/pt.cc:31035
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "不考慮內聯函式"
 
 #. TODO: Pass down location from cp_finish_decl.
-#: cp/pt.cc:30991
+#: cp/pt.cc:31049
 #, gcc-internal-format
 msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
 msgstr ""
 
-#: cp/pt.cc:30995
+#: cp/pt.cc:31053
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guide declared here"
 msgstr "間接函式 %q+D 無法宣告的 weakref"
 
-#: cp/pt.cc:31009
+#: cp/pt.cc:31067
 #, fuzzy, gcc-internal-format
 msgid "%qT may not intend to support class template argument deduction"
 msgstr "  模板引數推導/替代失敗："
 
-#: cp/pt.cc:31011
+#: cp/pt.cc:31069
 #, gcc-internal-format
 msgid "add a deduction guide to suppress this warning"
 msgstr ""
 
-#: cp/pt.cc:31133
+#: cp/pt.cc:31191
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.cc:31136
+#: cp/pt.cc:31194
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.cc:31203
+#: cp/pt.cc:31261
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "無法 deduce %qT 從 %qE"
 
-#: cp/pt.cc:31206
+#: cp/pt.cc:31264
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "無法 deduce %qT 從 %qE"
 
-#: cp/pt.cc:31281
+#: cp/pt.cc:31339
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.cc:31285
+#: cp/pt.cc:31343
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.cc:31289
+#: cp/pt.cc:31347
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.cc:31293
+#: cp/pt.cc:31351
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.cc:31448
+#: cp/pt.cc:31506
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "無效的 non-type 模板引數"
@@ -67192,645 +67230,645 @@ msgstr "無法確定 asm 運算元 %qE 的類型"
 msgid "%<__label__%> declarations are only allowed in function scopes"
 msgstr "__label__ 宣告是只有允許的在中函式範圍"
 
-#: cp/semantics.cc:2367
+#: cp/semantics.cc:2369
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "在靜態成員函式中使用成員 %q+D 無效"
 
-#: cp/semantics.cc:2371
+#: cp/semantics.cc:2373
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in constructor %<pre%> contract"
 msgstr "在靜態成員函式中使用成員 %q+D 無效"
 
-#: cp/semantics.cc:2375
+#: cp/semantics.cc:2377
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in destructor %<post%> contract"
 msgstr "在靜態成員函式中使用成員 %q+D 無效"
 
-#: cp/semantics.cc:2638
+#: cp/semantics.cc:2640
 #, fuzzy, gcc-internal-format
 msgid "%qE missing template arguments"
 msgstr "不匹配的引數"
 
-#: cp/semantics.cc:2698
+#: cp/semantics.cc:2700
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.cc:3057
+#: cp/semantics.cc:3059
 #, fuzzy, gcc-internal-format
 #| msgid "%qE cannot be used as a function"
 msgid "cannot call a concept as a function"
 msgstr "%qE 不能做為函式"
 
-#: cp/semantics.cc:3140
+#: cp/semantics.cc:3142
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "解構函式不能有參數"
 
-#: cp/semantics.cc:3244
+#: cp/semantics.cc:3246
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<this%> is unavailable for explicit object member functions"
 msgstr "靜態成員函式中不能使用 %<this%>"
 
-#: cp/semantics.cc:3256
+#: cp/semantics.cc:3258
 #, fuzzy, gcc-internal-format
 #| msgid "used %d template parameter(s) instead of %d"
 msgid "use explicit object parameter %qs instead"
 msgstr "使用了 %d 個範本參數，而不是 %d 個"
 
-#: cp/semantics.cc:3260
+#: cp/semantics.cc:3262
 #, fuzzy, gcc-internal-format
 msgid "name the explicit object parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/semantics.cc:3265
+#: cp/semantics.cc:3267
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "靜態成員函式中不能使用 %<this%>"
 
-#: cp/semantics.cc:3267
+#: cp/semantics.cc:3269
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<this%> before it is valid"
 msgstr "在頂層使用 %<this%> 無效"
 
-#: cp/semantics.cc:3269
+#: cp/semantics.cc:3271
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<this%> after it is valid"
 msgstr "在頂層使用 %<this%> 無效"
 
-#: cp/semantics.cc:3271
+#: cp/semantics.cc:3273
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "在非成員函式中使用 %<this%> 無效"
 
-#: cp/semantics.cc:3273
+#: cp/semantics.cc:3275
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "在頂層使用 %<this%> 無效"
 
-#: cp/semantics.cc:3295
+#: cp/semantics.cc:3297
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "偽解構函式名的限定作用欄位無效"
 
-#: cp/semantics.cc:3303 cp/typeck.cc:3085
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "限定的類型 %qT 不匹配解構函式名 ~%qT"
 
-#: cp/semantics.cc:3325
+#: cp/semantics.cc:3327
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE 的類型不是 %qT"
 
-#: cp/semantics.cc:3439
+#: cp/semantics.cc:3441
 #, fuzzy, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "複合實字的 non-object 型態 %qT"
 
-#: cp/semantics.cc:3459
+#: cp/semantics.cc:3461
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "%<auto{x}%> cannot be constrained"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/semantics.cc:3464
+#: cp/semantics.cc:3466
 #, fuzzy, gcc-internal-format
 msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/semantics.cc:3656
+#: cp/semantics.cc:3658
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "範本參數必須使用 %<class%> 或 %<typename%> 關鍵字"
 
-#: cp/semantics.cc:3709
+#: cp/semantics.cc:3711
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "將類型 %qT 做為範本的範本參數的預設值無效"
 
-#: cp/semantics.cc:3713
+#: cp/semantics.cc:3715
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "範本的範本參數的預設引數無效"
 
-#: cp/semantics.cc:3730
+#: cp/semantics.cc:3732
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "在範本參數清單中定義了 %q#T"
 
-#: cp/semantics.cc:3761
+#: cp/semantics.cc:3763
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "對限定類型 %qT 的定義無效"
 
-#: cp/semantics.cc:4053
+#: cp/semantics.cc:4051
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "無效的基礎類別"
 
-#: cp/semantics.cc:4221
+#: cp/semantics.cc:4219
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "匿名聯合中出現保護成員 %q+#D"
 
-#: cp/semantics.cc:4238
+#: cp/semantics.cc:4236
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD 未被擷取"
 
-#: cp/semantics.cc:4242
+#: cp/semantics.cc:4240
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.cc:4244
+#: cp/semantics.cc:4242
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.cc:4259
+#: cp/semantics.cc:4257
 #, fuzzy, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "在包含函式中使用 %<auto%> 變數"
 
-#: cp/semantics.cc:4261
+#: cp/semantics.cc:4259
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "在包含函式中使用參數"
 
-#: cp/semantics.cc:4389
+#: cp/semantics.cc:4387
 #, fuzzy, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "使用的參數 %qD 外側函式內文"
 
-#: cp/semantics.cc:4399
+#: cp/semantics.cc:4397
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "不匹配的引數"
 
-#: cp/semantics.cc:4435
+#: cp/semantics.cc:4433
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "範本參數 %qD(類型為 %qT)不允許出現在整數運算式中，因為它的類型不是整數或列舉"
 
-#: cp/semantics.cc:4486
+#: cp/semantics.cc:4484
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "將類別範本 %qT 做為運算式"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.cc:4493
+#: cp/semantics.cc:4491
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "在多繼承網格中對 %qD 的存取有歧義"
 
-#: cp/semantics.cc:4521
+#: cp/semantics.cc:4519
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD 不能出現在常數運算式中"
 
-#: cp/semantics.cc:4674
+#: cp/semantics.cc:4672
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE 的類型不明"
 
-#: cp/semantics.cc:4692 rust/backend/rust-tree.cc:5511
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT 不是列舉類型型態"
 
-#: cp/semantics.cc:4719
+#: cp/semantics.cc:4717
 #, fuzzy, gcc-internal-format
 msgid "%<__type_pack_element%> index is not an integral constant"
 msgstr "要求的對齊不是整數常數"
 
-#: cp/semantics.cc:4725
+#: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
 msgstr ""
 
-#: cp/semantics.cc:4731
+#: cp/semantics.cc:4729
 #, fuzzy, gcc-internal-format
 msgid "%<__type_pack_element%> index is out of range"
 msgstr "常數引數超過 %qs 的範圍"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.cc:4854
+#: cp/semantics.cc:4852
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %<__bases%> only valid in template declaration"
 msgstr "參數包裝 __bases 只有有效在中模板宣告"
 
-#: cp/semantics.cc:4886
+#: cp/semantics.cc:4884
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "無法套用 %<offsetof%> 到解構式 %<~%T%>"
 
-#: cp/semantics.cc:4899
+#: cp/semantics.cc:4897
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "無法套用 %<offsetof%> 到成員函式 %qD"
 
-#: cp/semantics.cc:4903
+#: cp/semantics.cc:4901
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "無法套用 %<offsetof%> 到成員函式 %qD"
 
-#: cp/semantics.cc:4908
+#: cp/semantics.cc:4906
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "無法套用 %<offsetof%> 到成員函式 %qD"
 
-#: cp/semantics.cc:4919
+#: cp/semantics.cc:4917
 #, gcc-internal-format
 msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.cc:6119
+#: cp/semantics.cc:6117
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member mapping %qE not supported"
 msgstr "建構子優先等級未被支援"
 
-#: cp/semantics.cc:6313
+#: cp/semantics.cc:6311
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "對 %qD 的參照有歧義"
 
-#: cp/semantics.cc:6586
+#: cp/semantics.cc:6584
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.cc:6632
+#: cp/semantics.cc:6630
 #, fuzzy, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE 有無效的型態用於 %<reduction%>"
 
-#: cp/semantics.cc:6751
+#: cp/semantics.cc:6749
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.cc:7223
+#: cp/semantics.cc:7221
 #, gcc-internal-format
 msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
 msgstr ""
 
-#: cp/semantics.cc:7238
+#: cp/semantics.cc:7236
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7253
+#: cp/semantics.cc:7251
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.cc:7277
+#: cp/semantics.cc:7275
 #, fuzzy, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.cc:7370 cp/semantics.cc:7502 cp/semantics.cc:7562
-#: cp/semantics.cc:7963 cp/semantics.cc:9089
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:7382 cp/semantics.cc:9102
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.cc:7515
+#: cp/semantics.cc:7513
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD 並非變數在中子句 %<firstprivate%>"
 
-#: cp/semantics.cc:7575
+#: cp/semantics.cc:7573
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD 並非變數在中子句 %<lastprivate%>"
 
-#: cp/semantics.cc:7626
+#: cp/semantics.cc:7624
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.cc:7640
+#: cp/semantics.cc:7638
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.cc:7674
+#: cp/semantics.cc:7672
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.cc:7677
+#: cp/semantics.cc:7675
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.cc:7681
+#: cp/semantics.cc:7679
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.cc:7703
+#: cp/semantics.cc:7701
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.cc:7707
+#: cp/semantics.cc:7705
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.cc:7712
+#: cp/semantics.cc:7710
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.cc:7788
+#: cp/semantics.cc:7786
 #, fuzzy, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: cp/semantics.cc:7821
+#: cp/semantics.cc:7819
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.cc:7835
+#: cp/semantics.cc:7833
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: cp/semantics.cc:7855
+#: cp/semantics.cc:7853
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.cc:7884
+#: cp/semantics.cc:7882
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.cc:7914
+#: cp/semantics.cc:7912
 #, fuzzy, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "切片結束必須是整數"
 
-#: cp/semantics.cc:7945
+#: cp/semantics.cc:7943
 #, fuzzy, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: cp/semantics.cc:7974
+#: cp/semantics.cc:7972
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.cc:7989
+#: cp/semantics.cc:7987
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:7996
+#: cp/semantics.cc:7994
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: cp/semantics.cc:8011
+#: cp/semantics.cc:8009
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: cp/semantics.cc:8044
+#: cp/semantics.cc:8042
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<nontemporal%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.cc:8055
+#: cp/semantics.cc:8053
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<nontemporal%> clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: cp/semantics.cc:8072
+#: cp/semantics.cc:8070
 #, fuzzy, gcc-internal-format
 msgid "%<this%> not allowed in %<allocate%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: cp/semantics.cc:8084
+#: cp/semantics.cc:8082
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<allocate%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.cc:8093
+#: cp/semantics.cc:8091
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<allocate%> clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: cp/semantics.cc:8241
+#: cp/semantics.cc:8239
 #, fuzzy, gcc-internal-format
 msgid "%qD is not lvalue expression nor array section in %qs clause"
 msgstr "變數長度陣列被使用"
 
-#: cp/semantics.cc:8743
+#: cp/semantics.cc:8741
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "太多 %qs 子句"
 
-#: cp/semantics.cc:8746
+#: cp/semantics.cc:8744
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.cc:8815
+#: cp/semantics.cc:8813
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.cc:8845
+#: cp/semantics.cc:8843
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.cc:8875
+#: cp/semantics.cc:8873
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.cc:8888
+#: cp/semantics.cc:8886
 #, fuzzy, gcc-internal-format
 msgid "%<hint%> expression must be constant integer expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/semantics.cc:8905
+#: cp/semantics.cc:8903
 #, fuzzy, gcc-internal-format
 msgid "%<filter%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.cc:8936
+#: cp/semantics.cc:8934
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor reference to pointer"
 msgstr "向量 delete 的引數類型既非指標也非陣列"
 
-#: cp/semantics.cc:8946
+#: cp/semantics.cc:8944
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.cc:9030
+#: cp/semantics.cc:9028
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> 未被定義為一個指標類型"
 
-#: cp/semantics.cc:9447
+#: cp/semantics.cc:9445
 #, gcc-internal-format
 msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
 msgstr ""
 
-#: cp/semantics.cc:9674
+#: cp/semantics.cc:9672
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD 不是檔案，命名空間或區塊範圍變數"
 
-#: cp/semantics.cc:9688
+#: cp/semantics.cc:9686
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE 指令無法在中 %qT 定義"
 
-#: cp/semantics.cc:10425
+#: cp/semantics.cc:10423
 #, fuzzy, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "差異介於 %qE 和 %qD 沒有整數類型"
 
-#: cp/semantics.cc:10910
+#: cp/semantics.cc:10908
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<# pragma omp 基元的 update%>使用兩不同的變數用於記憶體"
 
-#: cp/semantics.cc:11230 cp/semantics.cc:11240
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 update%>使用兩不同的變數用於記憶體"
 
-#: cp/semantics.cc:11582
+#: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
 msgstr ""
 
-#: cp/semantics.cc:11598
+#: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
 msgstr ""
 
-#: cp/semantics.cc:11607
+#: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
 msgstr ""
 
-#: cp/semantics.cc:11665
+#: cp/semantics.cc:11663
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/semantics.cc:11673
+#: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
 msgstr ""
 
-#: cp/semantics.cc:11700
+#: cp/semantics.cc:11698
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/semantics.cc:11727
+#: cp/semantics.cc:11725
 #, fuzzy, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/semantics.cc:11753
+#: cp/semantics.cc:11751
 #, fuzzy, gcc-internal-format
 msgid "static assertion failed: %.*s"
 msgstr "靜態假設失敗：%s"
 
-#: cp/semantics.cc:11761
+#: cp/semantics.cc:11759
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "non-constant 條件用於靜態假設"
 
-#: cp/semantics.cc:11790
+#: cp/semantics.cc:11788
 #, fuzzy, gcc-internal-format
 msgid "argument to %<decltype%> must be an expression"
 msgstr "引數到 decltype 必須是運算式"
 
-#: cp/semantics.cc:11836
+#: cp/semantics.cc:11834
 #, fuzzy, gcc-internal-format
 msgid "%<decltype%> cannot resolve address of overloaded function"
 msgstr "decltype 無法解析位址的多載化函式"
 
-#: cp/semantics.cc:12148 rust/backend/rust-tree.cc:5225
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
 msgstr ""
 
-#: cp/semantics.cc:12157 rust/backend/rust-tree.cc:5234
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
 #, gcc-internal-format
 msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12328 rust/backend/rust-tree.cc:5838
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
 msgstr ""
 
-#: cp/semantics.cc:12352 rust/backend/rust-tree.cc:5882
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "%<__builtin_is_corresponding_member%> needs two arguments"
 msgstr "呼叫 %<__builtin_next_arg%> 時沒有給定引數"
 
-#: cp/semantics.cc:12363 rust/backend/rust-tree.cc:5892
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
 #, gcc-internal-format
 msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
 msgstr ""
 
-#: cp/semantics.cc:12847
+#: cp/semantics.cc:12837
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or alias template"
 msgstr "%qE 不是一個範本"
 
-#: cp/semantics.cc:13036
+#: cp/semantics.cc:13026
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "第三運算元的條件運算式沒有任何效果"
 
-#: cp/semantics.cc:13096
+#: cp/semantics.cc:13086
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "範本引數 %qE 混雜了範本參數"
 
-#: cp/semantics.cc:13098
+#: cp/semantics.cc:13088
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.cc:13116
+#: cp/semantics.cc:13106
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -67839,1213 +67877,1213 @@ msgstr "%<__builtin_return_address%> 的引數不受支援"
 #. std::bit_cast for destination ARRAY_TYPE is not possible,
 #. as functions may not return an array, so don't bother trying
 #. to support this (and then deal with VLAs etc.).
-#: cp/semantics.cc:13165
+#: cp/semantics.cc:13155
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
 msgstr ""
 
-#: cp/semantics.cc:13171
+#: cp/semantics.cc:13161
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13198
+#: cp/semantics.cc:13188
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
 msgstr ""
 
-#: cp/semantics.cc:13206
+#: cp/semantics.cc:13196
 #, gcc-internal-format
 msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
 msgstr ""
 
-#: cp/tree.cc:1486 rust/backend/rust-tree.cc:2609
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV 限定符不能套用到 %qT 上"
 
-#: cp/tree.cc:2004
+#: cp/tree.cc:2007
 #, fuzzy, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/tree.cc:4524
+#: cp/tree.cc:4527
 #, gcc-internal-format
 msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.cc:4528
+#: cp/tree.cc:4531
 #, gcc-internal-format
 msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
 msgstr ""
 
-#: cp/tree.cc:4532
+#: cp/tree.cc:4535
 #, fuzzy, gcc-internal-format
 msgid " declared here"
 msgstr "宣告的在此"
 
-#: cp/tree.cc:4537
+#: cp/tree.cc:4540
 #, gcc-internal-format
 msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
 msgstr ""
 
-#: cp/tree.cc:4539
+#: cp/tree.cc:4542
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.cc:4966
+#: cp/tree.cc:4969
 #, fuzzy, gcc-internal-format
 #| msgid "base class %qT has cv qualifiers"
 msgid "base class %qT is not public"
 msgstr "基礎類別 %qT 有 cv 限定"
 
-#: cp/tree.cc:4969
+#: cp/tree.cc:4972
 #, fuzzy, gcc-internal-format
 msgid "%qD is not public"
 msgstr "%qD 未被擷取"
 
-#: cp/tree.cc:4976
+#: cp/tree.cc:4979
 #, fuzzy, gcc-internal-format
 msgid "%qD is mutable"
 msgstr "%qD 並非變數"
 
-#: cp/tree.cc:4984
+#: cp/tree.cc:4987
 #, fuzzy, gcc-internal-format
 msgid "%qD has a non-structural type"
 msgstr "%qD 並非型態"
 
-#: cp/tree.cc:5007
+#: cp/tree.cc:5010
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or parameters"
 msgstr "只能為類別定義套用 %qE 屬性"
 
-#: cp/tree.cc:5028
+#: cp/tree.cc:5031
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument must be a string constant"
 msgstr "%qE 屬性引數不是字串常數"
 
-#: cp/tree.cc:5043
+#: cp/tree.cc:5046
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "只能為類別定義套用 %qE 屬性"
 
-#: cp/tree.cc:5063 cp/tree.cc:5068
+#: cp/tree.cc:5066 cp/tree.cc:5071
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to non-static data members"
 msgstr "只能為類別定義套用 %qE 屬性"
 
-#: cp/tree.cc:5074
+#: cp/tree.cc:5077
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute cannot be applied to a bit-field"
 msgstr "只能為類別定義套用 %qE 屬性"
 
-#: cp/tree.cc:5094
+#: cp/tree.cc:5097
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute takes no arguments"
 msgstr "%qE 屬性沒有任何效果"
 
-#: cp/tree.cc:5098
+#: cp/tree.cc:5101
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
 msgstr "%qE 屬性不套用輸入"
 
-#: cp/tree.cc:5182
+#: cp/tree.cc:5185
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested %<init_priority%> is not an integer constant"
 msgstr "請求的 init_priority 不是一個整數常數"
 
-#: cp/tree.cc:5204
+#: cp/tree.cc:5207
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "只能將 %qE 屬性用於某個類別的物件的檔案作用欄位定義"
 
-#: cp/tree.cc:5212
+#: cp/tree.cc:5215
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is out of range"
 msgid "requested %<init_priority%> %i is out of range [0, %i]"
 msgstr "請求的 init_priority 越界"
 
-#: cp/tree.cc:5223
+#: cp/tree.cc:5226
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is reserved for internal use"
 msgid "requested %<init_priority%> %i is reserved for internal use"
 msgstr "請求的 init_priority 保留為內部使用"
 
-#: cp/tree.cc:5253
+#: cp/tree.cc:5256
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "%qD 宣告為 %qT 的一個成員"
 
-#: cp/tree.cc:5273
+#: cp/tree.cc:5276
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%qD 屬性需要單一 NTBS 引數"
 
-#: cp/tree.cc:5284
+#: cp/tree.cc:5287
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: cp/tree.cc:5297 cp/tree.cc:5310
+#: cp/tree.cc:5300 cp/tree.cc:5313
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: cp/tree.cc:5299
+#: cp/tree.cc:5302
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> 不是一個有效的宣告"
 
-#: cp/tree.cc:5312
+#: cp/tree.cc:5315
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> 不是一個有效的宣告"
 
-#: cp/tree.cc:5336
+#: cp/tree.cc:5339
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE 屬性在不是類別的類型上被忽略"
 
-#: cp/tree.cc:5342
+#: cp/tree.cc:5345
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: cp/tree.cc:5349
+#: cp/tree.cc:5352
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: cp/tree.cc:5356
+#: cp/tree.cc:5359
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: cp/tree.cc:5378
+#: cp/tree.cc:5381
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE 屬性套用只有到函式"
 
-#: cp/tree.cc:5384
+#: cp/tree.cc:5387
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%qE 屬性套用只有到函式"
 
-#: cp/tree.cc:5417
+#: cp/tree.cc:5420
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
 msgstr "%qE 屬性引數不是字串常數"
 
-#: cp/tree.cc:6283
+#: cp/tree.cc:6290
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "零做為空指標常數"
 
-#: cp/tree.cc:6324 rust/backend/rust-tree.cc:3189
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
 #, fuzzy, gcc-internal-format
 #| msgid "lang_* check: failed in %s, at %s:%d"
 msgid "%<lang_*%> check: failed in %s, at %s:%d"
 msgstr "lang_* check：在 %s 中失敗，於 %s:%d"
 
-#: cp/typeck.cc:625
+#: cp/typeck.cc:628
 #, fuzzy, gcc-internal-format
 msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
 msgstr "比較介於明確的指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.cc:631
+#: cp/typeck.cc:634
 #, fuzzy, gcc-internal-format
 msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
 msgstr "轉換介於明確的指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.cc:637
+#: cp/typeck.cc:640
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
 msgstr "條件運算式介於明確的指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.cc:785
+#: cp/typeck.cc:788
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++禁止比較介於指標的型態 %<void *%> 和 pointer-to-function"
 
-#: cp/typeck.cc:790
+#: cp/typeck.cc:793
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++禁止轉換介於指標的型態 %<void *%> 和 pointer-to-function"
 
-#: cp/typeck.cc:795
+#: cp/typeck.cc:798
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
 msgstr "ISO C++禁止條件運算式介於指標的型態 %<void *%> 和 pointer-to-function"
 
-#: cp/typeck.cc:874
+#: cp/typeck.cc:877
 #, fuzzy, gcc-internal-format
 msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "比較介於明確的成員指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.cc:879
+#: cp/typeck.cc:882
 #, fuzzy, gcc-internal-format
 msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "轉換介於明確的成員指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.cc:884
+#: cp/typeck.cc:887
 #, fuzzy, gcc-internal-format
 msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgstr "條件運算式介於明確的成員指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.cc:1710
+#: cp/typeck.cc:1713
 #, fuzzy, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
 msgstr "權威的類型不同用於相等的類型 %T 和 %T"
 
-#: cp/typeck.cc:1717
+#: cp/typeck.cc:1720
 #, fuzzy, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
 msgstr "相同權威的型態節點用於不同的類型 %T 和 %T"
 
-#: cp/typeck.cc:2047
+#: cp/typeck.cc:2050
 #, gcc-internal-format
 msgid "invalid application of %qs to a member function"
 msgstr "%qs 用於成員函式無效"
 
-#: cp/typeck.cc:2152
+#: cp/typeck.cc:2148
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<sizeof%> to a bit-field"
 msgstr "無效的應用程式的 %<sizeof%> 到 bit-field"
 
-#: cp/typeck.cc:2160
+#: cp/typeck.cc:2156
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
 msgstr "ISO C++禁止套用 %<sizeof%> 到運算式的函數型式"
 
-#: cp/typeck.cc:2225
+#: cp/typeck.cc:2221
 #, fuzzy, gcc-internal-format
 msgid "invalid application of %<__alignof%> to a bit-field"
 msgstr "無效的應用程式的 %<__alignof%>到 bit-field"
 
-#: cp/typeck.cc:2236
+#: cp/typeck.cc:2232
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
 msgstr "ISO C++禁止套用 %<__alignof%>到運算式的函數型式"
 
-#: cp/typeck.cc:2320
+#: cp/typeck.cc:2316
 #, fuzzy, gcc-internal-format
 #| msgid "size of array has non-integral type %qT"
 msgid "%<alignas%> argument has non-integral type %qT"
 msgstr "陣列 %qT 的大小的類型不是整數"
 
-#: cp/typeck.cc:2366 rust/backend/rust-tree.cc:3817
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "invalid use of non-static member function of type %qT"
 msgstr "對非靜態成員函式 %qD 的使用無效"
 
-#: cp/typeck.cc:2716
+#: cp/typeck.cc:2712
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
 msgstr "不宜用轉換從字串常數到 %qT"
 
-#: cp/typeck.cc:2720
+#: cp/typeck.cc:2716
 #, fuzzy, gcc-internal-format
 msgid "deprecated conversion from string constant to %qT"
 msgstr "不宜用轉換從字串常數到 %qT"
 
-#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
 msgstr "要求用於成員 %qD 在中 %qE，該項是的指標類型 %qT (也許您 meant 以使用 %<->%> ?)"
 
-#: cp/typeck.cc:2839 cp/typeck.cc:3403
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
 #, gcc-internal-format
 msgid "request for member %qD in %qE, which is of non-class type %qT"
 msgstr "對成員 %qD 的請求出現在 %qE 中，而後者具有非類別類型 %qT"
 
-#: cp/typeck.cc:2873
+#: cp/typeck.cc:2869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of nonstatic data member %qE"
 msgid "invalid use of non-static data member %qE"
 msgstr "對非靜態資料成員 %qE 的使用無效"
 
-#: cp/typeck.cc:2950
+#: cp/typeck.cc:2946
 #, fuzzy, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
 msgstr "無效的存取到非靜態資料成員 %qD  的空值物件"
 
-#: cp/typeck.cc:3100
+#: cp/typeck.cc:3096
 #, fuzzy, gcc-internal-format
 msgid "object type %qT does not match destructor name ~%qT"
 msgstr "物件類型 %qT 不匹配解構式名稱 ~%qT"
 
-#: cp/typeck.cc:3109
+#: cp/typeck.cc:3105
 #, gcc-internal-format
 msgid "the type being destroyed is %qT, but the destructor refers to %qT"
 msgstr "被解構的類型是 %qT，但解構函式卻使用了 %qT"
 
-#: cp/typeck.cc:3251
+#: cp/typeck.cc:3247
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
 msgstr ""
 
 #. No hint.
-#: cp/typeck.cc:3270
+#: cp/typeck.cc:3266
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE"
 msgstr "%qT 沒具名為 %qE 的成員"
 
-#: cp/typeck.cc:3293
+#: cp/typeck.cc:3289
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
 msgstr ""
 
-#: cp/typeck.cc:3304
+#: cp/typeck.cc:3300
 #, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
 msgstr ""
 
-#: cp/typeck.cc:3319
+#: cp/typeck.cc:3315
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%q#T has no member named %qE; did you mean %qE?"
 msgstr "%qT 沒具名為 %qE 的成員"
 
-#: cp/typeck.cc:3433 cp/typeck.cc:3459
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a member of %qT"
 msgstr "%<%D::%D%> 不是 %qT 的成員"
 
-#: cp/typeck.cc:3513
+#: cp/typeck.cc:3509
 #, gcc-internal-format
 msgid "%qT is not a base of %qT"
 msgstr "%qT 不是 %qT 的基礎類別"
 
-#: cp/typeck.cc:3576
+#: cp/typeck.cc:3572
 #, gcc-internal-format
 msgid "%qD is not a member template function"
 msgstr "%qD 不是一個成員範本函式"
 
-#: cp/typeck.cc:3841
+#: cp/typeck.cc:3837
 #, gcc-internal-format
 msgid "%qT is not a pointer-to-object type"
 msgstr "%qT 不是一個參照物件的類型"
 
-#: cp/typeck.cc:3873
+#: cp/typeck.cc:3869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of array indexing on pointer to member"
 msgstr "無效的使用的陣列索引於成員指標"
 
-#: cp/typeck.cc:3876
+#: cp/typeck.cc:3872
 #, fuzzy, gcc-internal-format
 msgid "invalid use of unary %<*%> on pointer to member"
 msgstr "無效的使用的一元 %<*%>於成員指標"
 
-#: cp/typeck.cc:3879
+#: cp/typeck.cc:3875
 #, fuzzy, gcc-internal-format
 msgid "invalid use of implicit conversion on pointer to member"
 msgstr "無效的使用的隱含轉換於成員指標"
 
-#: cp/typeck.cc:3883
+#: cp/typeck.cc:3879
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
 msgstr ""
 
-#: cp/typeck.cc:3949
+#: cp/typeck.cc:3945
 #, gcc-internal-format
 msgid "subscript missing in array reference"
 msgstr "陣列參照缺少下標"
 
-#: cp/typeck.cc:4054
+#: cp/typeck.cc:4050
 #, gcc-internal-format
 msgid "subscripting array declared %<register%>"
 msgstr "按下標存取宣告為 %<register%> 的陣列"
 
-#: cp/typeck.cc:4093
+#: cp/typeck.cc:4089
 #, gcc-internal-format
 msgid "subscripted value is neither array nor pointer"
 msgstr "下標運算的左運算元既非陣列也非指標"
 
-#: cp/typeck.cc:4165
+#: cp/typeck.cc:4161
 #, gcc-internal-format
 msgid "object missing in use of %qE"
 msgstr "使用 %qE 時缺少物件"
 
-#: cp/typeck.cc:4390
+#: cp/typeck.cc:4386
 #, gcc-internal-format
 msgid "ISO C++ forbids calling %<::main%> from within program"
 msgstr "ISO C++ 不允許在程式裡呼叫 %<::main%>"
 
-#: cp/typeck.cc:4411
+#: cp/typeck.cc:4407
 #, fuzzy, gcc-internal-format
 msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
 msgstr "必須使用 %<.*%>或 %<->*%> 到呼叫成員指標函式在中 %<%E (...)%>，例如： %<(...->* %E) (...)%>"
 
-#: cp/typeck.cc:4428
+#: cp/typeck.cc:4424
 #, gcc-internal-format
 msgid "%qE cannot be used as a function"
 msgstr "%qE 不能做為函式"
 
-#: cp/typeck.cc:4431
+#: cp/typeck.cc:4427
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be used as a function"
 msgstr "%qE 不能做為函式"
 
-#: cp/typeck.cc:4434
+#: cp/typeck.cc:4430
 #, fuzzy, gcc-internal-format
 msgid "expression cannot be used as a function"
 msgstr "%qE 不能做為函式"
 
-#: cp/typeck.cc:4492
+#: cp/typeck.cc:4488
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to constructor %q#D"
 msgstr "太多引數到建構子 %q#D"
 
-#: cp/typeck.cc:4493
+#: cp/typeck.cc:4489
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to constructor %q#D"
 msgstr "太少引數到建構子 %q#D"
 
-#: cp/typeck.cc:4498
+#: cp/typeck.cc:4494
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to member function %q#D"
 msgstr "太多引數到成員函式 %q#D"
 
-#: cp/typeck.cc:4499
+#: cp/typeck.cc:4495
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to member function %q#D"
 msgstr "太少引數到成員函式 %q#D"
 
-#: cp/typeck.cc:4505
+#: cp/typeck.cc:4501
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %q#D"
 msgstr "太多引數到函式 %q#D"
 
-#: cp/typeck.cc:4506
+#: cp/typeck.cc:4502
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %q#D"
 msgstr "太少引數到函式 %q#D"
 
-#: cp/typeck.cc:4516
+#: cp/typeck.cc:4512
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to method %q#D"
 msgstr "太多引數到方法 %q#D"
 
-#: cp/typeck.cc:4517
+#: cp/typeck.cc:4513
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to method %q#D"
 msgstr "太少引數到方法 %q#D"
 
-#: cp/typeck.cc:4520
+#: cp/typeck.cc:4516
 #, gcc-internal-format
 msgid "too many arguments to function"
 msgstr "給予函式的引數太多"
 
-#: cp/typeck.cc:4521
+#: cp/typeck.cc:4517
 #, gcc-internal-format
 msgid "too few arguments to function"
 msgstr "給予函式的引數太少"
 
-#: cp/typeck.cc:4603
+#: cp/typeck.cc:4599
 #, gcc-internal-format
 msgid "parameter %P of %qD has incomplete type %qT"
 msgstr "參數 %P (屬於 %qD)的類型 %qT 不完全"
 
-#: cp/typeck.cc:4609
+#: cp/typeck.cc:4605
 #, gcc-internal-format
 msgid "parameter %P has incomplete type %qT"
 msgstr "參數 %P 的類型 %qT 不完全"
 
-#: cp/typeck.cc:4918
+#: cp/typeck.cc:4914
 #, fuzzy, gcc-internal-format
 msgid "the address %qE will never be NULL"
 msgstr "位址的 %qD 將永不是空值"
 
-#: cp/typeck.cc:4964
+#: cp/typeck.cc:4960
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD will never be NULL"
 msgstr "位址的 %qD 將永不是空值"
 
-#: cp/typeck.cc:4979
+#: cp/typeck.cc:4975
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qE will never be NULL"
 msgstr "比較將一律評估做為 %<true%> 用於位址的 %qD 將永不是空值"
 
-#: cp/typeck.cc:4982
+#: cp/typeck.cc:4978
 #, gcc-internal-format
 msgid "comparing the result of pointer addition %qE and NULL"
 msgstr ""
 
-#: cp/typeck.cc:4997
+#: cp/typeck.cc:4993
 #, fuzzy, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "比較將一律評估做為 %<true%> 用於位址的 %qD 將永不是空值"
 
-#: cp/typeck.cc:5056
+#: cp/typeck.cc:5052
 #, fuzzy, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT"
 msgstr "運算元到 ?:有不同的類型 %qT 和 %qT"
 
-#: cp/typeck.cc:5059
+#: cp/typeck.cc:5055
 #, fuzzy, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
 msgstr "轉換介於明確的指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.cc:5065
+#: cp/typeck.cc:5061
 #, fuzzy, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT"
 msgstr "相同權威的型態節點用於不同的類型 %T 和 %T"
 
-#: cp/typeck.cc:5068
+#: cp/typeck.cc:5064
 #, fuzzy, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "比較介於明確的指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.cc:5105
+#: cp/typeck.cc:5101
 #, fuzzy, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT"
 msgstr "複雜引數必須有浮點型態"
 
-#: cp/typeck.cc:5108
+#: cp/typeck.cc:5104
 #, fuzzy, gcc-internal-format
 #| msgid "cast from function call of type %qT to non-matching type %qT"
 msgid "comparison of floating-point type %qT with enumeration type %qT"
 msgstr "從類型為 %qT 的函式呼叫轉換到不匹配的類型 %qT"
 
-#: cp/typeck.cc:5111
+#: cp/typeck.cc:5107
 #, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5115
+#: cp/typeck.cc:5111
 #, fuzzy, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
 msgstr "轉換從指標類型 %qT 到算術型式 %qT 在中 constant-expression"
 
-#: cp/typeck.cc:5124
+#: cp/typeck.cc:5120
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
 msgstr ""
 
-#: cp/typeck.cc:5127
+#: cp/typeck.cc:5123
 #, fuzzy, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
 msgstr "不相容的類型時指派輸入 %qT 從型態 %qT"
 
-#: cp/typeck.cc:5130
+#: cp/typeck.cc:5126
 #, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5134
+#: cp/typeck.cc:5130
 #, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:5269 cp/typeck.cc:5281
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
 #, gcc-internal-format
 msgid "assuming cast to type %qT from overloaded function"
 msgstr "假定從多載函式轉換到類型 %qT"
 
-#: cp/typeck.cc:5395
+#: cp/typeck.cc:5391
 #, gcc-internal-format
 msgid "NULL used in arithmetic"
 msgstr "算術運算式中使用了 NULL"
 
-#: cp/typeck.cc:5857 cp/typeck.cc:5866 cp/typeck.cc:6167 cp/typeck.cc:6176
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
 #, gcc-internal-format
 msgid "ISO C++ forbids comparison between pointer and integer"
 msgstr "ISO C++ 不允許比較指標和整數的值"
 
-#: cp/typeck.cc:6089 cp/typeck.cc:6102
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
 #, fuzzy, gcc-internal-format
 msgid "operand types are %qT and %qT"
 msgstr "沒具名為 %q#T 的類型，在%q#T 中 "
 
-#: cp/typeck.cc:6125
+#: cp/typeck.cc:6121
 #, gcc-internal-format
 msgid "three-way comparison of vectors"
 msgstr ""
 
-#: cp/typeck.cc:6159
+#: cp/typeck.cc:6155
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
 msgstr "指標與整數 0 比較大小"
 
-#: cp/typeck.cc:6206
+#: cp/typeck.cc:6202
 #, fuzzy, gcc-internal-format
 #| msgid "unordered comparison on non-floating point argument"
 msgid "unordered comparison on non-floating-point argument"
 msgstr "非浮點引數間的無效比較"
 
-#: cp/typeck.cc:6272
+#: cp/typeck.cc:6268
 #, fuzzy
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
 msgstr "隱含轉換從 %qT 到 %qT 到匹配其他運算元的二進位運算式"
 
-#: cp/typeck.cc:6381
+#: cp/typeck.cc:6377
 #, gcc-internal-format
 msgid "invalid operands of types %qT and %qT to binary %qO"
 msgstr "運算元類型 %qT 和 %qT 對二進位 %qO 而言無效"
 
-#: cp/typeck.cc:6782
+#: cp/typeck.cc:6778
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
 msgstr "ISO C++ 不允許在減法中使用類型為 %<void *%> 的指標"
 
-#: cp/typeck.cc:6790
+#: cp/typeck.cc:6786
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgstr "ISO C++ 不允許在減法中使用函式指標"
 
-#: cp/typeck.cc:6798
+#: cp/typeck.cc:6794
 #, gcc-internal-format
 msgid "ISO C++ forbids using pointer to a method in subtraction"
 msgstr "ISO C++ 不允許在減法中使用參照方法的指標"
 
-#: cp/typeck.cc:6851
+#: cp/typeck.cc:6847
 #, gcc-internal-format
 msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
 msgstr "在指標算術中使用參照不完全類型的指標無效"
 
-#: cp/typeck.cc:6928
+#: cp/typeck.cc:6924
 #, fuzzy, gcc-internal-format
 msgid "taking address of constructor %qD"
 msgstr "需位址的建構子 %qE"
 
-#: cp/typeck.cc:6929
+#: cp/typeck.cc:6925
 #, fuzzy, gcc-internal-format
 msgid "taking address of destructor %qD"
 msgstr "需位址的解構式 %qE"
 
-#: cp/typeck.cc:6945
+#: cp/typeck.cc:6941
 #, gcc-internal-format
 msgid "invalid use of %qE to form a pointer-to-member-function"
 msgstr "用 %qE 形成成員函式指標的用法無效。"
 
-#: cp/typeck.cc:6948
+#: cp/typeck.cc:6944
 #, gcc-internal-format
 msgid "  a qualified-id is required"
 msgstr "  需要一個限定的識別碼"
 
-#: cp/typeck.cc:6955
+#: cp/typeck.cc:6951
 #, fuzzy, gcc-internal-format
 msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
 msgstr "parentheses 周圍 %qE 無法用來表單成員函式指標"
 
-#: cp/typeck.cc:7150
+#: cp/typeck.cc:7146
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允許透過提取一個未限定的或帶括號的非靜態成員函式的位址來形成一個成員函式指標。請使用 %<&%T::%D%>"
 
-#: cp/typeck.cc:7156
+#: cp/typeck.cc:7152
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
 msgstr "ISO C++ 不允許透過提取一個未限定的或帶括號的非靜態成員函式的位址來形成一個成員函式指標。請使用 %<&%T::%D%>"
 
-#: cp/typeck.cc:7162
+#: cp/typeck.cc:7158
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgstr "ISO C++ 不允許透過取已繫結的成員函式的位址來建構成員函式指標。請改用 %<&%T::%D%>"
 
-#: cp/typeck.cc:7168
+#: cp/typeck.cc:7164
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
 msgstr "ISO C++ 不允許透過取已繫結的成員函式的位址來建構成員函式指標。請改用 %<&%T::%D%>"
 
-#: cp/typeck.cc:7173
+#: cp/typeck.cc:7169
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
 msgstr "(成員指標只能用 %<&%E%> 構成)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.cc:7206
+#: cp/typeck.cc:7202
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of rvalue"
 msgstr "取臨時變數的位址"
 
-#: cp/typeck.cc:7223
+#: cp/typeck.cc:7219
 #, gcc-internal-format
 msgid "ISO C++ forbids taking address of function %<::main%>"
 msgstr "ISO C++ 不允許取函式 %<::main%> 的位址"
 
-#: cp/typeck.cc:7281
+#: cp/typeck.cc:7277
 #, gcc-internal-format
 msgid "cannot create pointer to reference member %qD"
 msgstr "不能建立參照參照成員 %qD 的指標"
 
-#: cp/typeck.cc:7316 cp/typeck.cc:7892 rust/backend/rust-tree.cc:4714
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field %qD"
 msgid "attempt to take address of bit-field"
 msgstr "無法取得位元段 %qD 的位址"
 
-#: cp/typeck.cc:7478
+#: cp/typeck.cc:7474
 #, fuzzy, gcc-internal-format
 msgid "%<~%> on an expression of type %<bool%>"
 msgstr "需位址的運算式的型態 %<void%>"
 
-#: cp/typeck.cc:7479
+#: cp/typeck.cc:7475
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
 msgstr ""
 
-#: cp/typeck.cc:7611
+#: cp/typeck.cc:7607
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing an enum"
 msgstr "ISO C++禁止遞增 enum"
 
-#: cp/typeck.cc:7612
+#: cp/typeck.cc:7608
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing an enum"
 msgstr "ISO C++禁止遞減 enum"
 
-#: cp/typeck.cc:7628
+#: cp/typeck.cc:7624
 #, fuzzy, gcc-internal-format
 msgid "cannot increment a pointer to incomplete type %qT"
 msgstr "無法遞增指標到不完整型態 %qT"
 
-#: cp/typeck.cc:7630
+#: cp/typeck.cc:7626
 #, fuzzy, gcc-internal-format
 msgid "cannot decrement a pointer to incomplete type %qT"
 msgstr "無法遞減指標到不完整型態 %qT"
 
-#: cp/typeck.cc:7642
+#: cp/typeck.cc:7638
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids incrementing a pointer of type %qT"
 msgstr "ISO C++禁止遞增指標的型態 %qT"
 
-#: cp/typeck.cc:7644
+#: cp/typeck.cc:7640
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids decrementing a pointer of type %qT"
 msgstr "ISO C++禁止遞減指標的型態 %qT"
 
-#: cp/typeck.cc:7684
+#: cp/typeck.cc:7680
 #, gcc-internal-format
 msgid "%qs expression of %<volatile%>-qualified type is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7697
+#: cp/typeck.cc:7693
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
 msgstr ""
 
-#: cp/typeck.cc:7707
+#: cp/typeck.cc:7703
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
 msgstr ""
 
-#: cp/typeck.cc:7715
+#: cp/typeck.cc:7711
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
 msgstr ""
 
-#: cp/typeck.cc:7904 rust/backend/rust-tree.cc:4726
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
 #, gcc-internal-format
 msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgstr "無法取右值運算式 %<this%> 的位址"
 
-#: cp/typeck.cc:7926 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
 msgstr "要求明確暫存器變數 %qD 的位址。"
 
-#: cp/typeck.cc:7931 rust/backend/rust-tree.cc:4752
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, gcc-internal-format
 msgid "address requested for %qD, which is declared %<register%>"
 msgstr "請求宣告為 %<register%> 的 %qD 的位址"
 
-#: cp/typeck.cc:8002
+#: cp/typeck.cc:7998
 #, fuzzy, gcc-internal-format
 msgid "list-initializer for non-class type must not be parenthesized"
 msgstr "list-initializer 用於 non-class 型態必須不被 parenthesized"
 
-#: cp/typeck.cc:8014
+#: cp/typeck.cc:8010
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in initializer"
 msgstr "運算式清單視為複合式表示式在中初始設定式"
 
-#: cp/typeck.cc:8018
+#: cp/typeck.cc:8014
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in mem-initializer"
 msgstr "運算式清單視為複合式表示式在中 mem-initializer"
 
-#: cp/typeck.cc:8022
+#: cp/typeck.cc:8018
 #, fuzzy, gcc-internal-format
 msgid "expression list treated as compound expression in functional cast"
 msgstr "運算式清單視為複合式表示式在中 functional 演員陣容"
 
-#: cp/typeck.cc:8060
+#: cp/typeck.cc:8056
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expression list treated as compound expression"
 msgstr "%s 運算式清單被看作複合運算式"
 
-#: cp/typeck.cc:8161
+#: cp/typeck.cc:8157
 #, fuzzy, gcc-internal-format
 msgid "no context to resolve type of %qE"
 msgstr "沒有語境到解析型態的 %qE"
 
-#: cp/typeck.cc:8198
+#: cp/typeck.cc:8194
 #, fuzzy, gcc-internal-format
 msgid "cast from type %qT to type %qT casts away qualifiers"
 msgstr "演員陣容從型態 %qT 輸入 %qT 演員陣容暫離限定元"
 
-#: cp/typeck.cc:8204
+#: cp/typeck.cc:8200
 #, fuzzy, gcc-internal-format
 msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "staticcast 從型態 %qT 輸入 %qT 演員陣容暫離限定元(_C)"
 
-#: cp/typeck.cc:8211
+#: cp/typeck.cc:8207
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
 msgstr "reinterpretcast 從型態 %qT 輸入 %qT 演員陣容暫離限定元(_C)"
 
-#: cp/typeck.cc:8237
+#: cp/typeck.cc:8233
 #, fuzzy, gcc-internal-format
 msgid "useless cast to type %q#T"
 msgstr "%qT 使用了局部類型 %qT"
 
-#: cp/typeck.cc:8251
+#: cp/typeck.cc:8247
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "type qualifiers ignored on cast result type"
 msgstr "忽略函式回傳類型的類型限定"
 
-#: cp/typeck.cc:8699
+#: cp/typeck.cc:8695
 #, fuzzy, gcc-internal-format
 #| msgid "invalid static_cast from type %qT to type %qT"
 msgid "invalid %<static_cast%> from type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 中的 static_cast 無效"
 
-#: cp/typeck.cc:8705 cp/typeck.cc:8711 cp/typeck.cc:10422
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "回傳值類型 %q#T 為不完全"
 
-#: cp/typeck.cc:8739
+#: cp/typeck.cc:8735
 #, fuzzy
 #| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
 msgstr "從 %qT 轉換到 %qT"
 
-#: cp/typeck.cc:8814
+#: cp/typeck.cc:8810
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
 msgid "invalid cast of a prvalue expression of type %qT to type %qT"
 msgstr "從具有類型 %qT 的右值運算式到類型 %qT 中的轉換無效"
 
-#: cp/typeck.cc:8884
+#: cp/typeck.cc:8880
 #, fuzzy
 #| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
 msgstr "從 %qT 到 %qT 的轉換損失精度"
 
-#: cp/typeck.cc:8909
+#: cp/typeck.cc:8905
 msgid "cast between incompatible function types from %qH to %qI"
 msgstr ""
 
-#: cp/typeck.cc:8920
+#: cp/typeck.cc:8916
 #, fuzzy
 msgid "cast between incompatible pointer to member types from %qH to %qI"
 msgstr "比較介於明確的成員指標類型 %qT 和 %qT lacks 演員陣容"
 
-#: cp/typeck.cc:8941 cp/typeck.cc:9131
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
 #, fuzzy
 #| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
 msgstr "從 %qT 到 %qT 的轉換增大了目的類型的對齊需求"
 
-#: cp/typeck.cc:8958
+#: cp/typeck.cc:8954
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
 msgstr "ISO C++ 不允許在函式指標和物件指標間進行轉換"
 
-#: cp/typeck.cc:8972
+#: cp/typeck.cc:8968
 #, gcc-internal-format
 msgid "invalid cast from type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 的轉換無效"
 
-#: cp/typeck.cc:9045
+#: cp/typeck.cc:9041
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
 msgstr "在類型 %qT 上使用 const_cast 無效，因為它既不是指標，也不是參照，也不是資料成員指標"
 
-#: cp/typeck.cc:9054
+#: cp/typeck.cc:9050
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of const_cast with type %qT, which is a pointer or reference to a function type"
 msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
 msgstr "在類型 %qT 上使用 const_cast 無效，因為它是一個指標函式類型的指標或參照"
 
-#: cp/typeck.cc:9096
+#: cp/typeck.cc:9092
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast of an rvalue of type %qT to type %qT"
 msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 中的 const_cast 無效"
 
-#: cp/typeck.cc:9166
+#: cp/typeck.cc:9162
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_cast from type %qT to type %qT"
 msgid "invalid %<const_cast%> from type %qT to type %qT"
 msgstr "從類型 %qT 到類型 %qT 中的 const_cast 無效"
 
-#: cp/typeck.cc:9267 cp/typeck.cc:9276
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
 #, gcc-internal-format
 msgid "ISO C++ forbids casting to an array type %qT"
 msgstr "ISO C++ 不允許轉換為陣列類型 %qT"
 
-#: cp/typeck.cc:9285
+#: cp/typeck.cc:9281
 #, gcc-internal-format
 msgid "invalid cast to function type %qT"
 msgstr "向函式類型 %qT 的轉換無效"
 
-#: cp/typeck.cc:9398
+#: cp/typeck.cc:9394
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qE from type %qT to type %qT"
 msgid "moving %qE of type %qT to itself"
 msgstr "無法將 %qE 從類型 %qT 轉換到類型 %qT"
 
-#: cp/typeck.cc:9399 cp/typeck.cc:10951 cp/typeck.cc:10967 cp/typeck.cc:10992
-#: cp/typeck.cc:11029
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
 #, gcc-internal-format
 msgid "remove %<std::move%> call"
 msgstr ""
 
-#: cp/typeck.cc:9659
+#: cp/typeck.cc:9655
 #, gcc-internal-format
 msgid "  in evaluation of %<%Q(%#T, %#T)%>"
 msgstr "  在求 %<%Q(%#T, %#T)%> 值時"
 
-#: cp/typeck.cc:9719
+#: cp/typeck.cc:9715
 #, fuzzy, gcc-internal-format
 msgid "assigning to an array from an initializer list"
 msgstr "指派到陣列從初始設定式清單"
 
-#: cp/typeck.cc:9746
+#: cp/typeck.cc:9742
 #, gcc-internal-format
 msgid "incompatible types in assignment of %qT to %qT"
 msgstr "將 %qT 賦值給 %qT 時類型不相容"
 
-#: cp/typeck.cc:9762
+#: cp/typeck.cc:9758
 #, fuzzy, gcc-internal-format
 msgid "array used as initializer"
 msgstr "陣列使用的做為初始設定式"
 
-#: cp/typeck.cc:9764
+#: cp/typeck.cc:9760
 #, fuzzy, gcc-internal-format
 msgid "invalid array assignment"
 msgstr "無效的陣列指派"
 
-#: cp/typeck.cc:9900
+#: cp/typeck.cc:9896
 #, gcc-internal-format
 msgid "   in pointer to member function conversion"
 msgstr "  在成員函式指標轉換中"
 
-#: cp/typeck.cc:9914
+#: cp/typeck.cc:9910
 #, gcc-internal-format
 msgid "pointer to member conversion via virtual base %qT"
 msgstr "成員指標轉換經由虛基礎類別 %qT"
 
-#: cp/typeck.cc:9961 cp/typeck.cc:9980
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
 #, gcc-internal-format
 msgid "   in pointer to member conversion"
 msgstr "  在成員指標轉換中"
 
-#: cp/typeck.cc:10061
+#: cp/typeck.cc:10057
 #, gcc-internal-format
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "到類型 %qT 的轉換無效，從類型 %qT"
 
-#: cp/typeck.cc:10381
+#: cp/typeck.cc:10377
 #, fuzzy
 msgid "cannot convert %qH to %qI in default argument"
 msgstr "無法轉換 %qT 到 %qT 在中預設引數"
 
-#: cp/typeck.cc:10386
+#: cp/typeck.cc:10382
 #, fuzzy
 msgid "cannot convert %qH to %qI in argument passing"
 msgstr "無法轉換 %qT 到 %qT 在中引數傳遞"
 
-#: cp/typeck.cc:10395
+#: cp/typeck.cc:10391
 #, fuzzy
 msgid "cannot convert %qH to %qI in initialization"
 msgstr "無法轉換 %qT 到 %qT 在中初始化"
 
-#: cp/typeck.cc:10399
+#: cp/typeck.cc:10395
 #, fuzzy
 msgid "cannot convert %qH to %qI in return"
 msgstr "無法轉換 %qT 到 %qT 在中回傳"
 
-#: cp/typeck.cc:10404
+#: cp/typeck.cc:10400
 #, fuzzy
 msgid "cannot convert %qH to %qI in assignment"
 msgstr "無法轉換 %qT 到 %qT 在中指派"
 
-#: cp/typeck.cc:10440
+#: cp/typeck.cc:10436
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "參數 %qP 的 %qD 也許是 candidate 用於格式屬性"
 
-#: cp/typeck.cc:10444
+#: cp/typeck.cc:10440
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "參數也許是 candidate 用於格式屬性"
 
-#: cp/typeck.cc:10449
+#: cp/typeck.cc:10445
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "目標的轉換也許是 candidate 用於格式屬性"
 
-#: cp/typeck.cc:10454
+#: cp/typeck.cc:10450
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "目標的初始化也許是 candidate 用於格式屬性"
 
-#: cp/typeck.cc:10464
+#: cp/typeck.cc:10460
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "left-hand 側邊的指派也許是 candidate 用於格式屬性"
 
-#: cp/typeck.cc:10550
+#: cp/typeck.cc:10546
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "在傳遞引數 %P (屬於 %q+D)"
 
-#: cp/typeck.cc:10634
+#: cp/typeck.cc:10630
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "回傳臨時變數的參照"
 
-#: cp/typeck.cc:10637
+#: cp/typeck.cc:10633
 #, fuzzy, gcc-internal-format
 #| msgid "returning reference to temporary"
 msgid "returning pointer to temporary"
 msgstr "回傳臨時變數的參照"
 
-#: cp/typeck.cc:10640
+#: cp/typeck.cc:10636
 #, gcc-internal-format
 msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10676
+#: cp/typeck.cc:10672
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "回傳了對局部變數的 %q+D 的參照"
 
-#: cp/typeck.cc:10680
+#: cp/typeck.cc:10676
 #, gcc-internal-format
 msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
 msgstr ""
 
-#: cp/typeck.cc:10686
+#: cp/typeck.cc:10682
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "回傳了局部變數的 %q+D 的位址"
 
-#: cp/typeck.cc:10690
+#: cp/typeck.cc:10686
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "回傳了局部變數的 %q+D 的位址"
 
-#: cp/typeck.cc:10950
+#: cp/typeck.cc:10946
 #, gcc-internal-format
 msgid "moving a temporary object prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10965
+#: cp/typeck.cc:10961
 #, gcc-internal-format
 msgid "moving a local object in a return statement prevents copy elision"
 msgstr ""
 
-#: cp/typeck.cc:10991 cp/typeck.cc:11026
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
 #, fuzzy, gcc-internal-format
 msgid "redundant move in return statement"
 msgstr "太多值在中回傳敘述"
 
-#: cp/typeck.cc:11028
+#: cp/typeck.cc:11024
 #, fuzzy, gcc-internal-format
 msgid "redundant move in initialization"
 msgstr "太多值在中回傳敘述"
 
-#: cp/typeck.cc:11066
+#: cp/typeck.cc:11062
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "解構函式回傳值"
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.cc:11078
+#: cp/typeck.cc:11074
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "不能從建構式的異常處理中回傳"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.cc:11081
+#: cp/typeck.cc:11077
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "建構式回傳值"
 
 #. Give a helpful error message.
-#: cp/typeck.cc:11120 cp/typeck.cc:11166
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "在回傳 %qT 的函式中，回傳敘述不帶回傳值"
 
-#: cp/typeck.cc:11128
+#: cp/typeck.cc:11124
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "<brace-enclosed initializer list>"
 
-#: cp/typeck.cc:11147
+#: cp/typeck.cc:11143
 #, fuzzy, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "不一致類型 %qT 和 %qT deduced 用於 lambda 傳回類型"
 
-#: cp/typeck.cc:11150
+#: cp/typeck.cc:11146
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "不一致推導用於 %qT：%qT 然後 %qT"
 
-#: cp/typeck.cc:11185
+#: cp/typeck.cc:11181
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with no value, in function returning %qT"
 msgid "return-statement with a value, in function returning %qT"
 msgstr "在回傳 %qT 的函式中，回傳敘述不帶回傳值"
 
-#: cp/typeck.cc:11214
+#: cp/typeck.cc:11210
 #, fuzzy, gcc-internal-format
 #| msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
 msgstr "%<operator new%> 不能回傳 NULL，除非它被宣告為 %<throw()%> (或 -fcheck-new 起作用)"
 
-#: cp/typeck.cc:11303
+#: cp/typeck.cc:11299
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q+#D"
 msgid "not eliding copy on return from %qD"
 msgstr "%q+#D 的協變回傳類型無效"
 
-#: cp/typeck.cc:11315
+#: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
 msgstr ""
 
-#: cp/typeck.cc:11902
+#: cp/typeck.cc:11898
 #, fuzzy, gcc-internal-format
 msgid "using rvalue as lvalue"
 msgstr "使用暫時的做為 lvalue"
@@ -69274,164 +69312,164 @@ msgstr "多載化函式不具任何語境的類型資訊"
 msgid "insufficient contextual information to determine type"
 msgstr "不足的語境的資訊到決定型態"
 
-#: cp/typeck2.cc:832
+#: cp/typeck2.cc:838
 #, gcc-internal-format
 msgid "constructor syntax used, but no constructor declared for type %qT"
 msgstr "使用了建構式的語法，但沒有為類型 %qT 宣告建構式"
 
-#: cp/typeck2.cc:883 cp/typeck2.cc:900
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
 #, fuzzy, gcc-internal-format
 msgid "%<constinit%> variable %qD does not have a constant initializer"
 msgstr "constexpr 靜態資料成員 %qD 必須有初始設定式"
 
-#: cp/typeck2.cc:1088
+#: cp/typeck2.cc:1094
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
 msgstr "narrowing 轉換的 %qE 從 %qT 到 %qT 內部 {} 被不當形式的在中 C++11"
 
-#: cp/typeck2.cc:1100 cp/typeck2.cc:1112
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
 #, fuzzy
 msgid "narrowing conversion of %qE from %qH to %qI"
 msgstr "narrowing 轉換的 %qE 從 %qT 到 %qT 內部 {}"
 
-#: cp/typeck2.cc:1103
+#: cp/typeck2.cc:1109
 #, fuzzy, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
 msgstr "運算式在中靜態假設不是整數常數運算式"
 
-#: cp/typeck2.cc:1275
+#: cp/typeck2.cc:1281
 #, fuzzy, gcc-internal-format
 #| msgid "initializer-string for array of chars is too long"
 msgid "initializer-string for %qT is too long"
 msgstr "用以初始化字元陣列的字串太長"
 
-#: cp/typeck2.cc:1338
+#: cp/typeck2.cc:1344
 #, gcc-internal-format
 msgid "initializing a base class of type %qT results in object slicing"
 msgstr ""
 
-#: cp/typeck2.cc:1340
+#: cp/typeck2.cc:1346
 #, fuzzy, gcc-internal-format
 #| msgid "braces around scalar initializer"
 msgid "remove %<{ }%> around initializer"
 msgstr "標量初始化帶大括號"
 
-#: cp/typeck2.cc:1360
+#: cp/typeck2.cc:1366
 #, gcc-internal-format
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "不可使用複合原文初始化類型為 %qT 的聚集"
 
-#: cp/typeck2.cc:1820 cp/typeck2.cc:1851
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/typeck2.cc:1827
+#: cp/typeck2.cc:1833
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "成員 %qD 是未初始化的參照"
 
-#: cp/typeck2.cc:1834
+#: cp/typeck2.cc:1840
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "成員 %qD 是未初始化的參照"
 
-#: cp/typeck2.cc:1920
+#: cp/typeck2.cc:1926
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "型態的 %qD 不匹配原來的宣告"
 
-#: cp/typeck2.cc:1993
+#: cp/typeck2.cc:1999
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "在初始化的聯合中找不到欄位 %qD"
 
-#: cp/typeck2.cc:2004
+#: cp/typeck2.cc:2010
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "在聯合初始值設定中出現了索引值而不是欄位名"
 
-#: cp/typeck2.cc:2219
+#: cp/typeck2.cc:2225
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "偵測到循環指標代理"
 
-#: cp/typeck2.cc:2233
+#: cp/typeck2.cc:2239
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%> 的基運算元具有非指標類型 %qT"
 
-#: cp/typeck2.cc:2263
+#: cp/typeck2.cc:2269
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%> 的結果給出了非指標的結果"
 
-#: cp/typeck2.cc:2265
+#: cp/typeck2.cc:2271
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%> 的左運算元不是一個指標"
 
-#: cp/typeck2.cc:2292
+#: cp/typeck2.cc:2298
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE 不能做為成員指標，因為它的類型為 %qT"
 
-#: cp/typeck2.cc:2301
+#: cp/typeck2.cc:2307
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "無法套用成員指標 %qE 到 %qE，該項是的 non-class 型態 %qT"
 
-#: cp/typeck2.cc:2323
+#: cp/typeck2.cc:2329
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "成員指標類型 %qT 與物件類型 %qT 不相容"
 
-#: cp/typeck2.cc:2385
+#: cp/typeck2.cc:2391
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "在算術運算式中使用了成員指標"
 
-#: cp/typeck2.cc:2396
+#: cp/typeck2.cc:2402
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "在算術運算式中使用了成員指標"
 
-#: cp/typeck2.cc:2404
+#: cp/typeck2.cc:2410
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
 msgstr "在算術運算式中使用了成員指標"
 
-#: cp/typeck2.cc:2445
+#: cp/typeck2.cc:2451
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "functional 演員陣容到陣列類型 %qT"
 
-#: cp/typeck2.cc:2462
+#: cp/typeck2.cc:2468
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "%<auto(x)%> cannot be constrained"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/typeck2.cc:2467
+#: cp/typeck2.cc:2473
 #, fuzzy, gcc-internal-format
 msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
 msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/typeck2.cc:2492
+#: cp/typeck2.cc:2498
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "無效的 value-initialization 的參考類型"
 
-#: cp/typeck2.cc:2733
+#: cp/typeck2.cc:2739
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "呼叫的函式 %qD 會拋出不完全的類型 %q#T"
 
-#: cp/typeck2.cc:2736
+#: cp/typeck2.cc:2742
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "呼叫的函式會拋出不完全的類型 %q#T"
@@ -70456,7 +70494,7 @@ msgstr "non-parameter %qs 無法參數包裝"
 msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
 msgstr "『我』於 %L 和『J』於 %L 無法兩者是 BOZ 實字常數"
 
-#: fortran/check.cc:123 fortran/resolve.cc:11536
+#: fortran/check.cc:123 fortran/resolve.cc:11545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid use of BOZ literal constant at %L"
 msgstr "無效的 exponent-letter『q』在中 real-literal-constant 於 %C"
@@ -71839,7 +71877,7 @@ msgstr "%C 處錯誤地指定 INTENT"
 msgid "deferred type parameter at %C"
 msgstr "Fortran 2003:已推遲型態參數於 %C"
 
-#: fortran/decl.cc:1162 fortran/resolve.cc:13326
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
@@ -72061,7 +72099,7 @@ msgstr "成分『%s』與類別於 %L 必須是 allocatable 或指標"
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "陣列成分的結構於 %C 必須有明確的或已推遲形狀"
 
-#: fortran/decl.cc:2358 fortran/symbol.cc:2283
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already declared at %L"
@@ -72879,7 +72917,7 @@ msgid "Expected formal argument list in function definition at %C"
 msgstr "預期的形式引數清單在中函式定義於 %C"
 
 #: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
-#: fortran/symbol.cc:1923
+#: fortran/symbol.cc:1916
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "繫結©屬性於 %L 只能使用用於變數或共同區塊"
@@ -73710,12 +73748,12 @@ msgstr ""
 msgid "are_identical_variables: Bad type"
 msgstr ""
 
-#: fortran/dependency.cc:989
+#: fortran/dependency.cc:1021
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
 msgstr "含義 (%s) 實際引數於 %L 也許 interfere 與實際引數於 %L。"
 
-#: fortran/dependency.cc:1293
+#: fortran/dependency.cc:1325
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
 msgstr ""
@@ -73970,282 +74008,282 @@ msgstr "參數『%s』於 %L 未被宣告的或是變數，該項不縮小到常
 msgid "check_init_expr(): Unknown expression type"
 msgstr "需要運算式類型"
 
-#: fortran/expr.cc:3324
+#: fortran/expr.cc:3329
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be a statement function"
 msgid "Specification function %qs at %L cannot be a statement function"
 msgstr "指定函式「%s」(位於 %L)不能是一個敘述函式"
 
-#: fortran/expr.cc:3331
+#: fortran/expr.cc:3336
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be an internal function"
 msgid "Specification function %qs at %L cannot be an internal function"
 msgstr "指定函式「%s」(位於 %L)不能是一個內部函式"
 
-#: fortran/expr.cc:3338
+#: fortran/expr.cc:3343
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L must be PURE"
 msgid "Specification function %qs at %L must be PURE"
 msgstr "指定函式「%s」(位於 %L)必須為 PURE"
 
-#: fortran/expr.cc:3346
+#: fortran/expr.cc:3351
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be RECURSIVE"
 msgid "Specification function %qs at %L cannot be RECURSIVE"
 msgstr "指定函式「%s」(位於 %L)不能是 RECURSIVE"
 
-#: fortran/expr.cc:3493
+#: fortran/expr.cc:3498
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs not allowed in expression at %L"
 msgstr "虛引數『%s』不允許在中運算式於 %L"
 
-#: fortran/expr.cc:3501
+#: fortran/expr.cc:3506
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be OPTIONAL"
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
 msgstr "啞元「%s」(位於 %L)不能是 OPTIONAL"
 
-#: fortran/expr.cc:3508
+#: fortran/expr.cc:3513
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
 msgstr "「%s」啞元引數在 %L 處不能是 INTENT(OUT)"
 
-#: fortran/expr.cc:3530
+#: fortran/expr.cc:3535
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs cannot appear in the expression at %L"
 msgstr "變數「%s」不能出現在 %L 處的運算式中"
 
-#: fortran/expr.cc:3561
+#: fortran/expr.cc:3566
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "check_restricted(): Unknown expression type"
 msgstr "需要運算式類型"
 
-#: fortran/expr.cc:3581
+#: fortran/expr.cc:3586
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be of INTEGER type, found %s"
 msgstr "運算式於 %L 必須是的整數類型，找到 %s"
 
-#: fortran/expr.cc:3593
+#: fortran/expr.cc:3598
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L must be PURE"
 msgstr "函式『%s』於 %L 必須是 PURE"
 
-#: fortran/expr.cc:3602
+#: fortran/expr.cc:3607
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L must be scalar"
 msgstr "%L 處的運算式必須具有標量類型"
 
 #. Reject truncation.
-#: fortran/expr.cc:3634
+#: fortran/expr.cc:3639
 #, gcc-internal-format, gfc-internal-format
 msgid "optype_msgid overflow: %d"
 msgstr ""
 
-#: fortran/expr.cc:3638
+#: fortran/expr.cc:3643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgstr "不相容的分級在中 %s (%d 和 %d) 於 %L"
 
-#: fortran/expr.cc:3652
+#: fortran/expr.cc:3657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Different shape for %s at %L on dimension %d (%d and %d)"
 msgstr "不同的形狀用於 %s 於 %L 於尺寸 %d (%d 和 %d)"
 
-#: fortran/expr.cc:3700
+#: fortran/expr.cc:3705
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3756
+#: fortran/expr.cc:3761
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
 msgstr "『%s』於 %L 並非值"
 
-#: fortran/expr.cc:3767
+#: fortran/expr.cc:3772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal stride of zero at %L"
 msgid "Illegal assignment to external procedure at %L"
 msgstr "%L 零間隔無效"
 
-#: fortran/expr.cc:3775
+#: fortran/expr.cc:3780
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible ranks %d and %d in assignment at %L"
 msgstr "賦值中有不相容的秩 %d 和 %d，位於 %L"
 
-#: fortran/expr.cc:3782
+#: fortran/expr.cc:3787
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable type is UNKNOWN in assignment at %L"
 msgstr "%L 處賦值中的變數類型是 UNKNOWN"
 
-#: fortran/expr.cc:3794
+#: fortran/expr.cc:3799
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL appears on right-hand side in assignment at %L"
 msgstr "%L 處賦值右手邊出現 NULL"
 
-#: fortran/expr.cc:3804
+#: fortran/expr.cc:3809
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
 msgstr "%L 處賦值右手邊出現值為 POINTER 的函式"
 
-#: fortran/expr.cc:3847
+#: fortran/expr.cc:3852
 #, gcc-internal-format
 msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
 msgstr ""
 
-#: fortran/expr.cc:3854
+#: fortran/expr.cc:3859
 #, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.cc:3884
+#: fortran/expr.cc:3889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "不相容的類型在中資料敘述於 %L; 試圖的轉換的 %s 到 %s"
 
-#: fortran/expr.cc:3928
+#: fortran/expr.cc:3933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "指標指派目標並非指標於 %L"
 
-#: fortran/expr.cc:3936
+#: fortran/expr.cc:3941
 #, fuzzy, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "『%s』在中指標指派於 %L 無法 l-value 自從它是程序"
 
-#: fortran/expr.cc:3960
+#: fortran/expr.cc:3965
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "預期的邊界規格用於『%s』於 %L"
 
-#: fortran/expr.cc:3965
+#: fortran/expr.cc:3970
 #, fuzzy, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Fortran 2003:邊界規格用於『%s』在中指標指派於 %L"
 
-#: fortran/expr.cc:3994
+#: fortran/expr.cc:3999
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "Stride 必須不都到位於 %L"
 
-#: fortran/expr.cc:4000 fortran/expr.cc:4020
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
 #, gcc-internal-format
 msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4008 fortran/expr.cc:4027
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
 #, gcc-internal-format
 msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
 msgstr ""
 
-#: fortran/expr.cc:4054
+#: fortran/expr.cc:4059
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "指標物件於 %L 不應該有 coindex"
 
-#: fortran/expr.cc:4075
+#: fortran/expr.cc:4080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "無效的程序指標指派於 %L"
 
-#: fortran/expr.cc:4100
+#: fortran/expr.cc:4105
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "敘述函式『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.cc:4109
+#: fortran/expr.cc:4114
 #, fuzzy, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "摘要介面『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.cc:4119
+#: fortran/expr.cc:4124
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "敘述函式『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.cc:4125
+#: fortran/expr.cc:4130
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "內部程序『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.cc:4132
+#: fortran/expr.cc:4137
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "內部程序『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.cc:4140
+#: fortran/expr.cc:4145
 #, fuzzy, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Nonintrinsic elemental 程序『%s』無效在中程序指標 assigment 於 %L"
 
-#: fortran/expr.cc:4163
+#: fortran/expr.cc:4168
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "不匹配在中程序指標指派於 %L:不匹配在中呼叫慣例"
 
-#: fortran/expr.cc:4216
+#: fortran/expr.cc:4221
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "介面不匹配在中程序指標指派於 %L:%s"
 
-#: fortran/expr.cc:4226 fortran/expr.cc:4241
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "關鍵字引數需求明確的介面用於程序指標成分『%s』於 %L"
 
-#: fortran/expr.cc:4232 fortran/expr.cc:4247 fortran/resolve.cc:2742
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "NOPASS 或明確的介面必要項於 %C"
 
-#: fortran/expr.cc:4259
+#: fortran/expr.cc:4264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "介面不匹配在中程序指標指派於 %L:%s"
 
-#: fortran/expr.cc:4268
+#: fortran/expr.cc:4273
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.cc:4281
+#: fortran/expr.cc:4286
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target cannot be a constant at %L"
 msgstr "指標指派目標並非指標於 %L"
 
-#: fortran/expr.cc:4295
+#: fortran/expr.cc:4300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.cc:4300
+#: fortran/expr.cc:4305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "不同的類型在中指標指派於 %L; 試圖的指派的 %s 到 %s"
 
-#: fortran/expr.cc:4308
+#: fortran/expr.cc:4313
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "不同的 kind 型態參數在中指標指派於 %L"
 
-#: fortran/expr.cc:4315
+#: fortran/expr.cc:4320
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "%L 處指標賦值時秩不同"
 
-#: fortran/expr.cc:4334
+#: fortran/expr.cc:4339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "分級重新映射目標是小於大小的指標 (%ld<%ld) 於 %L"
 
-#: fortran/expr.cc:4347
+#: fortran/expr.cc:4352
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "分級重新映射目標必須是分級 1 或僅需 contiguous 於 %L"
 
-#: fortran/expr.cc:4351
+#: fortran/expr.cc:4356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "Fortran 2008:分級重新映射目標不是分級 1 於 %L"
@@ -74253,192 +74291,192 @@ msgstr "Fortran 2008:分級重新映射目標不是分級 1 於 %L"
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.cc:4376 fortran/expr.cc:4502
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "資料目標於 %L 不應該有 coindex"
 
-#: fortran/expr.cc:4379
+#: fortran/expr.cc:4384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "目標運算式在中指標指派於 %L 必須投遞指標結果"
 
-#: fortran/expr.cc:4393
+#: fortran/expr.cc:4398
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
 msgstr ""
 
-#: fortran/expr.cc:4399 fortran/expr.cc:4414
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
 msgstr "指標初始化目標於 %C 必須有目標屬性"
 
-#: fortran/expr.cc:4430
+#: fortran/expr.cc:4435
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Every subscript of target specification at %L must be a constant expression"
 msgstr "非同步=說明符於 %L 必須是初始化運算式"
 
-#: fortran/expr.cc:4441
+#: fortran/expr.cc:4446
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring starting and ending points of target specification at %L must be constant expressions"
 msgstr ""
 
-#: fortran/expr.cc:4457
+#: fortran/expr.cc:4462
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "指標指派目標是 neither 目標 nor 指標於 %L"
 
-#: fortran/expr.cc:4472
+#: fortran/expr.cc:4477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "不當的目標在中指標指派在中 PURE 程序於 %L"
 
-#: fortran/expr.cc:4481
+#: fortran/expr.cc:4486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "指標指派與向量註標於 rhs 於 %L"
 
-#: fortran/expr.cc:4489
+#: fortran/expr.cc:4494
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "指標指派目標有保護的屬性於 %L"
 
-#: fortran/expr.cc:4517 fortran/expr.cc:4522
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.cc:4562
+#: fortran/expr.cc:4567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "目標運算式在中指標指派於 %L 必須投遞指標結果"
 
-#: fortran/expr.cc:4638 fortran/resolve.cc:1565
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "指標初始化目標於 %L 必須不是 ALLOCATABLE "
 
-#: fortran/expr.cc:4644
+#: fortran/expr.cc:4649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "指標初始化目標於 %C 必須有目標屬性"
 
-#: fortran/expr.cc:4659 fortran/resolve.cc:1571
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "指標初始化目標於 %L 必須有儲存屬性"
 
-#: fortran/expr.cc:4671
+#: fortran/expr.cc:4676
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "程序指標初始化目標於 %L 可能無法是程序指標"
 
-#: fortran/expr.cc:4677
+#: fortran/expr.cc:4682
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "內部程序『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.cc:4684
+#: fortran/expr.cc:4689
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
 msgstr "內部程序『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.cc:5152
+#: fortran/expr.cc:5157
 #, gcc-internal-format
 msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
 msgstr ""
 
-#: fortran/expr.cc:6267
+#: fortran/expr.cc:6272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008:指標函式在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.cc:6275
+#: fortran/expr.cc:6280
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Non-variable 運算式在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.cc:6283
+#: fortran/expr.cc:6288
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "具名的常數『%s』在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.cc:6294
+#: fortran/expr.cc:6299
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "『%s』在中變數定義語境 (%s) 於 %L 並非變數"
 
-#: fortran/expr.cc:6305
+#: fortran/expr.cc:6310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Non-POINTER 在中指標關聯語境 (%s) 於 %L"
 
-#: fortran/expr.cc:6314
+#: fortran/expr.cc:6319
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "具名的常數『%s』在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.cc:6327
+#: fortran/expr.cc:6332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE 在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.cc:6340
+#: fortran/expr.cc:6345
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE 在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.cc:6371
+#: fortran/expr.cc:6376
 #, fuzzy, gcc-internal-format
 msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
 msgstr "具名的常數『%s』在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.cc:6388
+#: fortran/expr.cc:6393
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "虛引數『%s』與含義 (在中) 在中指標關聯語境 (%s) 於 %L"
 
-#: fortran/expr.cc:6398
+#: fortran/expr.cc:6403
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "虛引數『%s』與含義 (在中) 在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.cc:6411
+#: fortran/expr.cc:6416
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
 msgstr "變數『%s』是保護的和無法出現在中指標關聯語境 (%s) 於 %L"
 
-#: fortran/expr.cc:6419
+#: fortran/expr.cc:6424
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
 msgstr "變數『%s』是保護的和無法出現在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.cc:6434
+#: fortran/expr.cc:6439
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "變數『%s』無法出現在中變數定義語境 (%s) 於 %L 在中 PURE 程序"
 
-#: fortran/expr.cc:6494 fortran/expr.cc:6515
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
 msgstr "『%s』於 %L 關聯的到 vector-indexed 目標無法已用於變數定義語境 (%s)"
 
-#: fortran/expr.cc:6499
+#: fortran/expr.cc:6504
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
 msgstr "『%s』於 %L 關聯的到運算式無法已用於變數定義語境 (%s)"
 
-#: fortran/expr.cc:6508
+#: fortran/expr.cc:6513
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
 msgstr "『%s』於 %L 關聯的到運算式無法已用於變數定義語境 (%s)"
 
-#: fortran/expr.cc:6527
+#: fortran/expr.cc:6532
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
 msgstr "Associate-name『%s』無法出現在中變數定義語境 (%s) 於 %L 因為它的目標於 %L 無法，還是"
 
-#: fortran/expr.cc:6569
+#: fortran/expr.cc:6574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "『%s』於 %L 關聯的到運算式無法已用於變數定義語境 (%s)"
@@ -74459,8 +74497,8 @@ msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
 #: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
-#: fortran/trans-array.cc:7194 fortran/trans-array.cc:8856
-#: fortran/trans-intrinsic.cc:8475
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Creating array temporary at %L"
 msgstr "建立陣列暫時的於 %L"
@@ -74541,7 +74579,7 @@ msgstr "變數『%s』於 %C 無法重新定義的內部迴圈起始部分於 %L
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "變數『%s』於 %C 無法重新定義的內部迴圈起始部分於 %L"
 
-#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1932
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
@@ -74680,12 +74718,12 @@ msgstr "第一個引數的定義的指派於 %L 必須是含義 (出) 或含義
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L 處定義賦值的第二個參數必須是 INTENT(IN)"
 
-#: fortran/interface.cc:1035 fortran/resolve.cc:18228
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L 處運算子介面的第一個參數必須是 INTENT(IN)"
 
-#: fortran/interface.cc:1042 fortran/resolve.cc:18246
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L 處運算子介面的第二個參數必須是 INTENT(IN)"
@@ -75576,7 +75614,7 @@ msgstr "從 %s 轉換到 %s，位於 %L"
 #. Use of -fdec-char-conversions allows assignment of character data
 #. to non-character variables.  This not permitted for nonconstant
 #. strings.
-#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11511
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cannot convert %s to %s at %L"
@@ -76137,7 +76175,7 @@ msgstr "名稱表列『%s』在中讀取敘述於 %L 含有符號『%s』該項
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "名稱表列物件『%s』在中名稱表列『%s』於 %L 是 polymorphic 和需要定義的輸入/輸出程序"
 
-#: fortran/io.cc:3422 fortran/resolve.cc:16056
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "Fortran 2003:名稱表列物件『%s』在中名稱表列『%s』於 %L 與 ALLOCATABLE 或指標成分"
@@ -76311,6 +76349,11 @@ msgstr "整數溢出"
 msgid "check_charlen_present(): length not set"
 msgstr ""
 
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr ""
+
 #: fortran/match.cc:118
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
@@ -76722,7 +76765,7 @@ msgstr "停止編碼於 %L 必須是預設字元 KIND=%d"
 msgid "STOP code at %L must be default integer KIND=%d"
 msgstr "停止編碼於 %L 必須是預設整數 KIND=%d"
 
-#: fortran/match.cc:3210 fortran/resolve.cc:12650
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "QUIET specifier at %L must be a scalar LOGICAL"
 msgstr "非同步=說明符於 %L 必須是初始化運算式"
@@ -77252,85 +77295,85 @@ msgstr "語法時發生錯誤保護的敘述於 %C"
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "選擇器在中選取型態於 %C 並非具名的變數；使用 associate-name=>"
 
-#: fortran/match.cc:6874
+#: fortran/match.cc:6895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SELECT RANK statement at %C"
 msgstr "Fortran 2008:鎖定敘述於 %C"
 
-#: fortran/match.cc:6915 fortran/match.cc:6969
+#: fortran/match.cc:6936 fortran/match.cc:6990
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "The SELECT RANK selector at %C must be an assumed rank variable"
 msgstr "%C 處的 STAT 運算式必須是一個變數"
 
-#: fortran/match.cc:6979
+#: fortran/match.cc:7000
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT RANK statement at %C"
 msgstr "語法時發生錯誤保護的敘述於 %C"
 
-#: fortran/match.cc:7015
+#: fortran/match.cc:7036
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "%C 處非預期的 CASE 敘述"
 
-#: fortran/match.cc:7067
+#: fortran/match.cc:7088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "語法時發生錯誤大小寫規格於 %C"
 
-#: fortran/match.cc:7085
+#: fortran/match.cc:7106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "未預期的型態是敘述於 %C"
 
-#: fortran/match.cc:7117
+#: fortran/match.cc:7138
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.cc:7128
+#: fortran/match.cc:7149
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.cc:7139
+#: fortran/match.cc:7160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "語法時發生錯誤型態是規格於 %C"
 
-#: fortran/match.cc:7215
+#: fortran/match.cc:7236
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "語法時發生錯誤類別是規格於 %C"
 
-#: fortran/match.cc:7235
+#: fortran/match.cc:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected RANK statement at %C"
 msgstr "%C 處非預期的 END 敘述"
 
-#: fortran/match.cc:7281
+#: fortran/match.cc:7302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
 msgstr "%C 處的 STAT 運算式必須是一個變數"
 
-#: fortran/match.cc:7290
+#: fortran/match.cc:7311
 #, gcc-internal-format, gfc-internal-format
 msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
 msgstr ""
 
-#: fortran/match.cc:7317
+#: fortran/match.cc:7338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in RANK specification at %C"
 msgstr "語法時發生錯誤大小寫規格於 %C"
 
-#: fortran/match.cc:7439
+#: fortran/match.cc:7460
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "其他情況下敘述於 %C 無法夾於位置區塊"
 
-#: fortran/match.cc:7477
+#: fortran/match.cc:7498
 #, fuzzy, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "標貼『%s』於 %C 不匹配位置標貼『%s』"
@@ -78787,8 +78830,8 @@ msgstr ""
 msgid "ORDER clause must not be used together ORDERED at %L"
 msgstr "-frepo 必須與 -c 一起使用"
 
-#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11309
-#: fortran/resolve.cc:12878
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "如果子句於 %L 需要純量邏輯的運算式"
@@ -81184,12 +81227,12 @@ msgstr "intrinsic『%s』宣告的 INTRINSIC 於 %L 不是可用在中目前的
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "非遞迴程序『%s』於 %L 是可能會呼叫它自己遞迴。 宣告它遞迴或使用 -frecursive"
 
-#: fortran/resolve.cc:1976 fortran/resolve.cc:6843
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, fuzzy, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "非遞迴程序『%s』於 %L 是可能會呼叫它自己遞迴。 宣告它遞迴或使用 -frecursive"
 
-#: fortran/resolve.cc:2035 fortran/resolve.cc:10823 fortran/resolve.cc:12805
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "標籤 %d(參照自 %L)從未被定義"
@@ -81314,7 +81357,7 @@ msgstr ""
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "函式「%s」在 %L 處沒有 IMPLICIT 類型"
 
-#: fortran/resolve.cc:3092 fortran/resolve.cc:18158
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -81720,279 +81763,285 @@ msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.cc:5932
+#: fortran/resolve.cc:5935
 #, fuzzy, gcc-internal-format
 msgid "Scalar variable %qs has an array reference at %L"
 msgstr "建立陣列的參考"
 
-#: fortran/resolve.cc:6077
+#: fortran/resolve.cc:6080
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "變數『%s』，已用於規格運算式，被引用於 %L 之前條目敘述在中該項它是參數"
 
-#: fortran/resolve.cc:6082
+#: fortran/resolve.cc:6085
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "變數『%s』被使用於 %L 之前條目敘述在中該項它是參數"
 
-#: fortran/resolve.cc:6152
+#: fortran/resolve.cc:6155
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Polymorphic 子物件的 coindexed 物件於 %L"
 
-#: fortran/resolve.cc:6165
+#: fortran/resolve.cc:6168
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Coindexed 物件與 polymorphic allocatable subcomponent 於 %L"
 
-#: fortran/resolve.cc:6181
+#: fortran/resolve.cc:6184
 #, fuzzy, gcc-internal-format
 msgid "Using variable %qs at %L is deprecated"
 msgstr "%qE 被不宜用"
 
-#: fortran/resolve.cc:6424
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Bad array reference at %L"
+msgid "Invalid array reference at %L"
+msgstr "%L 處陣列參照錯誤"
+
+#: fortran/resolve.cc:6433
 #, gcc-internal-format
 msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
 msgstr ""
 
-#: fortran/resolve.cc:6602 fortran/resolve.cc:6754
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in typebound call at %L"
 msgstr "在中 type-spec 於 %L 時發生錯誤"
 
-#: fortran/resolve.cc:6718
+#: fortran/resolve.cc:6727
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Passed-object 於 %L 必須是純量"
 
-#: fortran/resolve.cc:6725
+#: fortran/resolve.cc:6734
 #, fuzzy, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "基底物件用於 procedure-pointer 成分呼叫於 %L 是的摘要型態『%s』"
 
-#: fortran/resolve.cc:6764
+#: fortran/resolve.cc:6773
 #, fuzzy, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "基底物件用於 type-bound 程序呼叫於 %L 是的摘要型態『%s』"
 
-#: fortran/resolve.cc:6773
+#: fortran/resolve.cc:6782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "基底物件用於 NOPASS type-bound 程序呼叫於 %L 必須是純量"
 
 #. Nothing matching found!
-#: fortran/resolve.cc:6968
+#: fortran/resolve.cc:6977
 #, fuzzy, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "找到沒有匹配特定的繫結用於呼叫到通用『%s』於 %L"
 
-#: fortran/resolve.cc:7002
+#: fortran/resolve.cc:7011
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "『%s』於 %L 應該是副常式"
 
-#: fortran/resolve.cc:7054
+#: fortran/resolve.cc:7063
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "『%s』於 %L 應該是函式"
 
-#: fortran/resolve.cc:7589
+#: fortran/resolve.cc:7598
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "需要運算式類型"
 
-#: fortran/resolve.cc:7622
+#: fortran/resolve.cc:7631
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s (%L 處)必須是一個標量"
 
-#: fortran/resolve.cc:7632
+#: fortran/resolve.cc:7641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "『%s』於 %L 必須是 nonnegative"
 
-#: fortran/resolve.cc:7636 fortran/resolve.cc:7643
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s (%L 處)必須是 INTEGER"
 
-#: fortran/resolve.cc:7698
+#: fortran/resolve.cc:7707
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "步進敘述於 %L 處的 DO 迴圈中不可為零"
 
-#: fortran/resolve.cc:7721
+#: fortran/resolve.cc:7730
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "做迴圈於 %L 將被執行零次"
 
-#: fortran/resolve.cc:7738
+#: fortran/resolve.cc:7747
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.cc:7744
+#: fortran/resolve.cc:7753
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.cc:7805
+#: fortran/resolve.cc:7814
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L 處 FORALL 索引名稱必須是 INTEGER 標量"
 
-#: fortran/resolve.cc:7810
+#: fortran/resolve.cc:7819
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L 處的 FORALL 啟始敘述必須是 INTEGER 標量"
 
-#: fortran/resolve.cc:7817
+#: fortran/resolve.cc:7826
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L 處的 FORALL 結束敘述必須是 INTEGER 標量"
 
-#: fortran/resolve.cc:7825
+#: fortran/resolve.cc:7834
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L 處的 FORALL 步幅敘述必須是 %s 標量"
 
-#: fortran/resolve.cc:7830
+#: fortran/resolve.cc:7839
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L 處的 FORALL 步幅敘述不能為零"
 
-#: fortran/resolve.cc:7843
+#: fortran/resolve.cc:7852
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL 索引『%s』可能無法出現在中 triplet 規格於 %L"
 
-#: fortran/resolve.cc:7948 fortran/resolve.cc:8246
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allocate-object 於 %L 必須是 ALLOCATABLE 或指標"
 
-#: fortran/resolve.cc:7956 fortran/resolve.cc:8209
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Coindexed allocatable 物件於 %L"
 
-#: fortran/resolve.cc:8066
+#: fortran/resolve.cc:8075
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Source-expr 於 %L 必須是純量或有同級做為 allocate-object 於 %L"
 
-#: fortran/resolve.cc:8097
+#: fortran/resolve.cc:8106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Source-expr 於 %L 和 allocate-object 於 %L 必須有相同形狀"
 
-#: fortran/resolve.cc:8257
+#: fortran/resolve.cc:8266
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "型態的實體於 %L 是型態不相容的與 source-expr 於 %L"
 
-#: fortran/resolve.cc:8269
+#: fortran/resolve.cc:8278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "allocate-object 於 %L 和 source-expr 於 %L 應該有相同 kind 型態參數"
 
-#: fortran/resolve.cc:8283
+#: fortran/resolve.cc:8292
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 於 %L 應該 neither 是的型態 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 於 %L 是 coarray"
 
-#: fortran/resolve.cc:8308
+#: fortran/resolve.cc:8317
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 於 %L 應該 neither 是的型態 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 於 %L 是 coarray"
 
-#: fortran/resolve.cc:8321
+#: fortran/resolve.cc:8330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "配置 %s 的摘要基底類型於 %L 需要 type-spec 或 source-expr"
 
-#: fortran/resolve.cc:8339
+#: fortran/resolve.cc:8348
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "配置 %s 於 %L 與 type-spec 需求相同 character-length 參數做為在中宣告"
 
-#: fortran/resolve.cc:8423 fortran/resolve.cc:8438
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "陣列規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.cc:8430
+#: fortran/resolve.cc:8439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "陣列規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.cc:8455
+#: fortran/resolve.cc:8464
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Coarray 規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.cc:8465 fortran/resolve.cc:8567
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "不當的 coarray 規格在中配置敘述於 %L"
 
-#: fortran/resolve.cc:8471
+#: fortran/resolve.cc:8480
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8483
+#: fortran/resolve.cc:8492
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper cobound is less than lower cobound of 1 at %L"
 msgstr ""
 
-#: fortran/resolve.cc:8494 fortran/resolve.cc:8522
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "不當的陣列規格在中配置敘述於 %L"
 
-#: fortran/resolve.cc:8541
+#: fortran/resolve.cc:8550
 #, fuzzy, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "『%s』必須不出現在中陣列規格於 %L 在中相同配置敘述位置它是它自己配置"
 
-#: fortran/resolve.cc:8556
+#: fortran/resolve.cc:8565
 #, fuzzy, gcc-internal-format
 msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
 msgstr "預期『*』在中 coindex 規格在中配置敘述於 %L"
 
-#: fortran/resolve.cc:8598
+#: fortran/resolve.cc:8607
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-variable 於 %L 必須是純量整數變數"
 
-#: fortran/resolve.cc:8627
+#: fortran/resolve.cc:8636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-variable 於 %L 不應該是 %sd 在之內相同 %s 敘述"
 
-#: fortran/resolve.cc:8640
+#: fortran/resolve.cc:8649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG 於 %L 是無用的而無需 STAT 標籤"
 
-#: fortran/resolve.cc:8654
+#: fortran/resolve.cc:8663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "ERRMSG=引數於 %L 必須是純量字元變數"
 
-#: fortran/resolve.cc:8683
+#: fortran/resolve.cc:8692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Errmsg-variable 於 %L 不應該是 %sd 在之內相同 %s 敘述"
 
-#: fortran/resolve.cc:8715
+#: fortran/resolve.cc:8724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allocate-object 於 %L 也出現於 %L"
 
-#: fortran/resolve.cc:8721 fortran/resolve.cc:8727
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allocate-object 於 %L 是子物件的物件於 %L"
@@ -82001,285 +82050,285 @@ msgstr "Allocate-object 於 %L 是子物件的物件於 %L"
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.cc:8955
+#: fortran/resolve.cc:8964
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "大小寫標貼於 %L 重疊與大小寫標貼於 %L"
 
-#: fortran/resolve.cc:9006
+#: fortran/resolve.cc:9015
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L 處 CASE 敘述中的運算式必須具有 %s 類型"
 
-#: fortran/resolve.cc:9017
+#: fortran/resolve.cc:9026
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "運算式在中條件敘述於 %L 必須是的 kind %d"
 
-#: fortran/resolve.cc:9030
+#: fortran/resolve.cc:9039
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L 處 CASE 敘述中的運算式必須為標量"
 
-#: fortran/resolve.cc:9076
+#: fortran/resolve.cc:9085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "選擇運算式在中計算的前往敘述於 %L 必須是純量整數運算式"
 
-#: fortran/resolve.cc:9095
+#: fortran/resolve.cc:9104
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L 處 SELECT 敘述的引數不能是 %s"
 
-#: fortran/resolve.cc:9105
+#: fortran/resolve.cc:9114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L 處 SELECT 敘述的引數不能是 %s"
 
-#: fortran/resolve.cc:9123 fortran/resolve.cc:9131
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "運算式在中條件敘述於 %L 不是在中範圍的 %s"
 
-#: fortran/resolve.cc:9193 fortran/resolve.cc:9957
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "預設大小寫於 %L 無法在之後秒預設大小寫於 %L"
 
-#: fortran/resolve.cc:9219
+#: fortran/resolve.cc:9228
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "邏輯的範圍在中條件敘述於 %L 未被允許"
 
-#: fortran/resolve.cc:9232
+#: fortran/resolve.cc:9241
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "常數邏輯的值在中條件敘述被重複於 %L"
 
-#: fortran/resolve.cc:9247
+#: fortran/resolve.cc:9256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "範圍規格於 %L 可以永不被匹配"
 
-#: fortran/resolve.cc:9350
+#: fortran/resolve.cc:9359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "邏輯的選取大小寫區塊於 %L 有更多該兩大小寫"
 
-#: fortran/resolve.cc:9412
+#: fortran/resolve.cc:9421
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure pointer"
 msgstr "內部程序『%s』無效在中程序指標指派於 %L"
 
-#: fortran/resolve.cc:9421
+#: fortran/resolve.cc:9430
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' cannot be used as a defined operator at %C"
 msgid "Derived type %qs cannot be used as a variable at %L"
 msgstr "名稱「%s」在 %C 處不能做為已定義的運算子"
 
-#: fortran/resolve.cc:9438
+#: fortran/resolve.cc:9447
 #, fuzzy, gcc-internal-format
 msgid "Associating entity %qs at %L is a procedure name"
 msgstr "Associate-name『%s』於 %L 被做為陣列"
 
-#: fortran/resolve.cc:9454
+#: fortran/resolve.cc:9463
 #, gcc-internal-format, gfc-internal-format
 msgid "Associating selector-expression at %L yields a procedure"
 msgstr ""
 
-#: fortran/resolve.cc:9508
+#: fortran/resolve.cc:9517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.cc:9513
+#: fortran/resolve.cc:9522
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.cc:9571
+#: fortran/resolve.cc:9580
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Associate-name『%s』於 %L 被做為陣列"
 
-#: fortran/resolve.cc:9582
+#: fortran/resolve.cc:9591
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.cc:9821
+#: fortran/resolve.cc:9830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "選擇器應該是 polymorphic 在中選取型態敘述於 %L"
 
-#: fortran/resolve.cc:9865 fortran/resolve.cc:9877
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.cc:9906
+#: fortran/resolve.cc:9915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "大小寫標貼於 %L 重疊與大小寫標貼於 %L"
 
-#: fortran/resolve.cc:9919
+#: fortran/resolve.cc:9928
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "衍生類型『%s』於 %L 必須是 extensible"
 
-#: fortran/resolve.cc:9932
+#: fortran/resolve.cc:9941
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "衍生類型『%s』於 %L 必須是延伸的『%s』"
 
-#: fortran/resolve.cc:9935
+#: fortran/resolve.cc:9944
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "未預期的空值() intrinsic 於 %L 到虛設『%s』"
 
-#: fortran/resolve.cc:9945
+#: fortran/resolve.cc:9954
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Type-spec 於 %L 無法包含已推遲型態參數"
 
-#: fortran/resolve.cc:10192
+#: fortran/resolve.cc:10201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "雙倍類別是區塊在中選取型態敘述於 %L"
 
-#: fortran/resolve.cc:10325
+#: fortran/resolve.cc:10334
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK DEFAULT at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10334
+#: fortran/resolve.cc:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10337
+#: fortran/resolve.cc:10346
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (%i) at %L is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10347
+#: fortran/resolve.cc:10356
 #, gcc-internal-format, gfc-internal-format
 msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
 msgstr ""
 
-#: fortran/resolve.cc:10456
+#: fortran/resolve.cc:10465
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "無效的語境用於空值() 指標於 %%L"
 
-#: fortran/resolve.cc:10510
+#: fortran/resolve.cc:10519
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "停止編碼於 %L 必須是純量"
 
-#: fortran/resolve.cc:10520
+#: fortran/resolve.cc:10529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法 polymorphic 除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.cc:10533
+#: fortran/resolve.cc:10542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有指標成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.cc:10542
+#: fortran/resolve.cc:10551
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "資料轉移元件於 %L 無法有程序指標成分"
 
-#: fortran/resolve.cc:10549
+#: fortran/resolve.cc:10558
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有 ALLOCATABLE 成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.cc:10560
+#: fortran/resolve.cc:10569
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "資料轉移元件於 %L 無法有私人的成分"
 
-#: fortran/resolve.cc:10566
+#: fortran/resolve.cc:10575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有指標成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.cc:10584
+#: fortran/resolve.cc:10593
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "資料轉移元件於 %L 無法全部參考到 assumed-size 陣列"
 
-#: fortran/resolve.cc:10641
+#: fortran/resolve.cc:10650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "鎖定變數於 %L 必須是純量的型態 LOCK_TYPE"
 
-#: fortran/resolve.cc:10651
+#: fortran/resolve.cc:10660
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "鎖定變數於 %L 必須是純量的型態 LOCK_TYPE"
 
-#: fortran/resolve.cc:10655
+#: fortran/resolve.cc:10664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "實際引數到『%s』於 %L 必須是 coarray"
 
-#: fortran/resolve.cc:10658
+#: fortran/resolve.cc:10667
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "實際引數到『%s』於 %L 必須是 coarray"
 
-#: fortran/resolve.cc:10665 fortran/resolve.cc:10787
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT=引數於 %L 必須是純量整數變數"
 
-#: fortran/resolve.cc:10677 fortran/resolve.cc:10799
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG=引數於 %L 必須是純量字元變數"
 
-#: fortran/resolve.cc:10689
+#: fortran/resolve.cc:10698
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK=引數於 %L 必須是純量邏輯的變數"
 
-#: fortran/resolve.cc:10702
+#: fortran/resolve.cc:10711
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Imageset 引數於 %L 必須是純量或 rank-1 整數運算式"
 
-#: fortran/resolve.cc:10763
+#: fortran/resolve.cc:10772
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Imageset 引數於 %L 必須是純量或 rank-1 整數運算式"
 
-#: fortran/resolve.cc:10767 fortran/resolve.cc:10777
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Imageset 引數於 %L 必須介於 1 和 numimages()(_I)"
 
-#: fortran/resolve.cc:10830
+#: fortran/resolve.cc:10839
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "敘述於 %L 並非有效分支目標敘述用於分支敘述於 %L"
 
-#: fortran/resolve.cc:10840
+#: fortran/resolve.cc:10849
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "分支於 %L 也許會導致無窮迴圈"
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.cc:10857 fortran/resolve.cc:10880
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "前往敘述於 %L 樹葉重要建構用於標貼於 %L"
 
-#: fortran/resolve.cc:10861 fortran/resolve.cc:10886
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "前往敘述於 %L 樹葉做共時建構用於標貼於 %L"
@@ -82287,218 +82336,218 @@ msgstr "前往敘述於 %L 樹葉做共時建構用於標貼於 %L"
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.cc:10901
+#: fortran/resolve.cc:10910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "標貼於 %L 不是在中相同區塊做為前往敘述於 %L"
 
-#: fortran/resolve.cc:10973
+#: fortran/resolve.cc:10982
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "位置遮罩於 %L 有不一致形狀"
 
-#: fortran/resolve.cc:10989
+#: fortran/resolve.cc:10998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "位置指派目標於 %L 有不一致形狀"
 
-#: fortran/resolve.cc:11002 fortran/resolve.cc:11094
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Non-ELEMENTAL 使用者定義的指派在中位置於 %L"
 
-#: fortran/resolve.cc:11012 fortran/resolve.cc:11104
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L 處在 WHERE 內不支援的敘述"
 
-#: fortran/resolve.cc:11043
+#: fortran/resolve.cc:11052
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L 處向 FORALL 索引變數賦值"
 
-#: fortran/resolve.cc:11052
+#: fortran/resolve.cc:11061
 #, fuzzy, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL 與索引『%s』未被使用左側的側邊的指派於 %L 和因而也許造成多重指派到這個物件"
 
-#: fortran/resolve.cc:11209
+#: fortran/resolve.cc:11218
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL construct at %L"
 msgstr "Fortran 2008:區塊建構於 %C"
 
-#: fortran/resolve.cc:11230
+#: fortran/resolve.cc:11239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "%L 處 FORALL 索引名稱必須是 INTEGER 標量"
 
-#: fortran/resolve.cc:11240
+#: fortran/resolve.cc:11249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "外 FORALL 建構已經有索引與這個名稱 %L"
 
-#: fortran/resolve.cc:11317
+#: fortran/resolve.cc:11326
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L 處的 WHERE/ELSEWHERE 子句需要一個 LOGICAL 陣列"
 
-#: fortran/resolve.cc:11435
+#: fortran/resolve.cc:11444
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.cc:11498
+#: fortran/resolve.cc:11507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
 msgstr "資料轉移元件於 %L 無法有程序指標成分"
 
-#: fortran/resolve.cc:11559
+#: fortran/resolve.cc:11568
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
 msgstr "字元運算式將被截斷在中指派 (%d/%d) 於 %L"
 
-#: fortran/resolve.cc:11591
+#: fortran/resolve.cc:11600
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Coindexed 運算式於 %L 被指派到衍生類型變數與指標成分在中 PURE 程序"
 
 #. F2008, C1283 (4).
-#: fortran/resolve.cc:11597
+#: fortran/resolve.cc:11606
 #, gcc-internal-format, gfc-internal-format
 msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
 msgstr ""
 
-#: fortran/resolve.cc:11609
+#: fortran/resolve.cc:11618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "指派到 coindexed 變數於 %L 在中 PURE 程序"
 
-#: fortran/resolve.cc:11641
+#: fortran/resolve.cc:11650
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.cc:11645
+#: fortran/resolve.cc:11654
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L 處向 FORALL 索引變數賦值"
 
-#: fortran/resolve.cc:11650
+#: fortran/resolve.cc:11659
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.cc:11657
+#: fortran/resolve.cc:11666
 #, fuzzy, gcc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
 msgstr "變數必須不是 polymorphic 在中 intrinsic 指派於 %L - 檢查該有匹配特定的副常式用於『=』運算子"
 
-#: fortran/resolve.cc:11668
+#: fortran/resolve.cc:11677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Coindexed 變數必須不是有 allocatable ultimate 成分在中指派於 %L"
 
-#: fortran/resolve.cc:12091
+#: fortran/resolve.cc:12100
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.cc:12395
+#: fortran/resolve.cc:12404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "無效的程序指標指派於 %L"
 
-#: fortran/resolve.cc:12407
+#: fortran/resolve.cc:12416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "目標運算式在中指標指派於 %L 必須投遞指標結果"
 
-#: fortran/resolve.cc:12492
+#: fortran/resolve.cc:12501
 #, fuzzy, gcc-internal-format
 msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
 msgstr "%L 處 SELECT 敘述的引數不能是 %s"
 
-#: fortran/resolve.cc:12683
+#: fortran/resolve.cc:12692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
 msgstr "STAT=引數於 %L 必須是純量整數變數"
 
-#: fortran/resolve.cc:12719
+#: fortran/resolve.cc:12728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
 msgstr "指派的前往敘述於 %L 需求整數變數"
 
-#: fortran/resolve.cc:12723
+#: fortran/resolve.cc:12732
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "變數「%s」在 %L 尚未指派到目標標籤"
 
-#: fortran/resolve.cc:12734
+#: fortran/resolve.cc:12743
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "交替回傳敘述於 %L 需要 SCALAR-INTEGER 回傳說明符"
 
-#: fortran/resolve.cc:12772
+#: fortran/resolve.cc:12781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected initialization expression in CASE at %C"
 msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
 msgstr "%C 處 CASE 中需要初始化運算式"
 
-#: fortran/resolve.cc:12814
+#: fortran/resolve.cc:12823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "指派敘述於 %L 需要純量預設整數變數"
 
-#: fortran/resolve.cc:12861
+#: fortran/resolve.cc:12870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "%s 種別無效，於 %L 處"
 
-#: fortran/resolve.cc:12865
+#: fortran/resolve.cc:12874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "算術如果敘述於 %L 需要數值運算式"
 
-#: fortran/resolve.cc:12926
+#: fortran/resolve.cc:12935
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.cc:12931
+#: fortran/resolve.cc:12940
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "離開條件的做當迴圈於 %L 必須是純量邏輯的運算式"
 
-#: fortran/resolve.cc:13015
+#: fortran/resolve.cc:13024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL 遮罩子句於 %L 需要純量邏輯的運算式"
 
-#: fortran/resolve.cc:13119
+#: fortran/resolve.cc:13128
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code()：錯誤的敘述程式碼"
 
-#: fortran/resolve.cc:13140
+#: fortran/resolve.cc:13149
 #, fuzzy, gcc-internal-format
 msgid "Using parameter %qs declared at %L is deprecated"
 msgstr "未使用的參數『%s』宣告的於 %L"
 
-#: fortran/resolve.cc:13234
+#: fortran/resolve.cc:13243
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "繫結標貼『%s』於 %L collides 與全域實體『%s』於 %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.cc:13248
+#: fortran/resolve.cc:13257
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -82506,1016 +82555,1016 @@ msgstr ""
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.cc:13267
+#: fortran/resolve.cc:13276
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "繫結標貼『%s』於 %L collides 與全域實體『%s』於 %L"
 
-#: fortran/resolve.cc:13353
+#: fortran/resolve.cc:13362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "字串長度於 %L 太大"
 
-#: fortran/resolve.cc:13591
+#: fortran/resolve.cc:13600
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "可指派的陣列「%s」在 %L 處必須有延遲的外形"
 
-#: fortran/resolve.cc:13595
+#: fortran/resolve.cc:13604
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "純量物件『%s』於 %L 可能無法是 ALLOCATABLE"
 
-#: fortran/resolve.cc:13603
+#: fortran/resolve.cc:13612
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "陣列指標「%s」在 %L 處必須有延遲的外形"
 
-#: fortran/resolve.cc:13614
+#: fortran/resolve.cc:13623
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "陣列「%s」在 %L 處不能有延遲的外形"
 
-#: fortran/resolve.cc:13632
+#: fortran/resolve.cc:13641
 #, fuzzy, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "型態『%s』的類別變數『%s』於 %L 不是 extensible"
 
-#: fortran/resolve.cc:13644
+#: fortran/resolve.cc:13653
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "類別變數『%s』於 %L 必須是虛設，allocatable 或指標"
 
-#: fortran/resolve.cc:13677
+#: fortran/resolve.cc:13686
 #, fuzzy, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "型態『%s』無法主機關聯的於 %L 因為它被阻斷由不相容的物件的同名宣告的於 %L"
 
-#: fortran/resolve.cc:13699
+#: fortran/resolve.cc:13708
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008:意味著的儲存用於模組變數『%s』於 %L, 所需的由於預設初始化"
 
-#: fortran/resolve.cc:13732
+#: fortran/resolve.cc:13741
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "實體『%s』於 %L 有已推遲型態參數和需求還是指標或 allocatable 屬性"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.cc:13768
+#: fortran/resolve.cc:13777
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "模組或主程式陣列「%s」在 %L 處必須有常態的外形"
 
-#: fortran/resolve.cc:13793
+#: fortran/resolve.cc:13802
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "實體與假設的字元長度於 %L 必須是虛引數或參數"
 
-#: fortran/resolve.cc:13814
+#: fortran/resolve.cc:13823
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "『%s』於 %L 必須有常數字元長度在中這個語境"
 
-#: fortran/resolve.cc:13821
+#: fortran/resolve.cc:13830
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "共同變數『%s』於 %L 必須有常數字元長度"
 
-#: fortran/resolve.cc:13869
+#: fortran/resolve.cc:13878
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "可指派的「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.cc:13872
+#: fortran/resolve.cc:13881
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "外部「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.cc:13875
+#: fortran/resolve.cc:13884
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "啞元「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.cc:13878
+#: fortran/resolve.cc:13887
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "內建函式「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.cc:13881
+#: fortran/resolve.cc:13890
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "函式結果「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.cc:13884
+#: fortran/resolve.cc:13893
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "自動陣列「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.cc:13926
+#: fortran/resolve.cc:13935
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "在 %s 中，於 %s:%d"
 
-#: fortran/resolve.cc:13958
+#: fortran/resolve.cc:13967
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Character-valued 敘述函式『%s』於 %L 必須有常數長度"
 
-#: fortran/resolve.cc:13981
+#: fortran/resolve.cc:13990
 #, fuzzy, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003:『%s』是的私人的型態和無法虛引數的『%s』，該項是公用的於 %L"
 
-#: fortran/resolve.cc:14003
+#: fortran/resolve.cc:14012
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003:程序『%s』在中公用的介面『%s』於 %L 需虛引數的『%s』該項是私人的"
 
-#: fortran/resolve.cc:14021
+#: fortran/resolve.cc:14030
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "函式『%s』於 %L 無法有初始設定式"
 
-#: fortran/resolve.cc:14033
+#: fortran/resolve.cc:14042
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "外部物件「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.cc:14043
+#: fortran/resolve.cc:14052
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL 函式『%s』於 %L 必須有純量結果"
 
-#: fortran/resolve.cc:14053
+#: fortran/resolve.cc:14062
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "敘述函式『%s』於 %L 可能無法有指標或 allocatable 屬性"
 
-#: fortran/resolve.cc:14072
+#: fortran/resolve.cc:14081
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能以陣列賦值"
 
-#: fortran/resolve.cc:14076
+#: fortran/resolve.cc:14085
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能以指標賦值"
 
-#: fortran/resolve.cc:14080
+#: fortran/resolve.cc:14089
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能是純量"
 
-#: fortran/resolve.cc:14084
+#: fortran/resolve.cc:14093
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "字元 (*) 函式『%s』於 %L 無法遞迴"
 
-#: fortran/resolve.cc:14097
+#: fortran/resolve.cc:14106
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能是純量"
 
-#: fortran/resolve.cc:14108
+#: fortran/resolve.cc:14117
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "程序『%s』在中 %s 於 %L 沒有任何明確的介面"
 
-#: fortran/resolve.cc:14114
+#: fortran/resolve.cc:14123
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "虛設程序『%s』於 %C 無法有通用介面"
 
-#: fortran/resolve.cc:14134
+#: fortran/resolve.cc:14143
 #, fuzzy, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.cc:14191
+#: fortran/resolve.cc:14200
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "程序屬性衝突與儲存屬性在中『%s』於 %L"
 
-#: fortran/resolve.cc:14197
+#: fortran/resolve.cc:14206
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "程序屬性衝突與含義屬性在中『%s』於 %L"
 
-#: fortran/resolve.cc:14203
+#: fortran/resolve.cc:14212
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "程序屬性衝突與結果屬性在中『%s』於 %L"
 
-#: fortran/resolve.cc:14211
+#: fortran/resolve.cc:14220
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "外部屬性衝突與函式屬性在中『%s』於 %L"
 
-#: fortran/resolve.cc:14217
+#: fortran/resolve.cc:14226
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "程序指標結果『%s』於 %L 缺少指標屬性"
 
-#: fortran/resolve.cc:14260
+#: fortran/resolve.cc:14269
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14268
+#: fortran/resolve.cc:14277
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14276
+#: fortran/resolve.cc:14285
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.cc:14285
+#: fortran/resolve.cc:14294
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.cc:14309
+#: fortran/resolve.cc:14318
 #, fuzzy, gcc-internal-format
 msgid "Interface of %qs at %L must be explicit"
 msgstr "介面『%s』的程序『%s』於 %L 必須是明確的"
 
-#: fortran/resolve.cc:14379
+#: fortran/resolve.cc:14388
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "最後的程序『%s』於 %L 並非副常式"
 
-#: fortran/resolve.cc:14388
+#: fortran/resolve.cc:14397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "最後的程序於 %L 必須有精確的一個引數"
 
-#: fortran/resolve.cc:14396 fortran/resolve.cc:14413
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "引數的最後的程序於 %L 必須是的型態『%s』"
 
-#: fortran/resolve.cc:14404
+#: fortran/resolve.cc:14413
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
 msgstr ""
 
-#: fortran/resolve.cc:14421
+#: fortran/resolve.cc:14430
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "引數的最後的程序於 %L 必須不是指標"
 
-#: fortran/resolve.cc:14427
+#: fortran/resolve.cc:14436
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "引數的最後的程序於 %L 必須不是 ALLOCATABLE"
 
-#: fortran/resolve.cc:14433
+#: fortran/resolve.cc:14442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "引數的最後的程序於 %L 必須不是可選的"
 
-#: fortran/resolve.cc:14441
+#: fortran/resolve.cc:14450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "引數的最後的程序於 %L 必須不是含義 (出)"
 
-#: fortran/resolve.cc:14450
+#: fortran/resolve.cc:14459
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Non-scalar 最後的程序於 %L 應該已假設形狀引數"
 
-#: fortran/resolve.cc:14472
+#: fortran/resolve.cc:14481
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "最後的程序『%s』宣告的於 %L 有同級 (%d) 做為『%s』"
 
-#: fortran/resolve.cc:14509
+#: fortran/resolve.cc:14518
 #, fuzzy, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
 msgstr "只有陣列最後的程序宣告的用於衍生類型『%s』定義的於 %L, 建議也純量一個"
 
-#: fortran/resolve.cc:14550
+#: fortran/resolve.cc:14559
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "『%s』和『%s』無法混合的函式/副常式用於通用『%s』於 %L"
 
-#: fortran/resolve.cc:14586
+#: fortran/resolve.cc:14595
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "『%s』和『%s』用於通用『%s』於 %L 是模稜兩可的"
 
-#: fortran/resolve.cc:14645
+#: fortran/resolve.cc:14654
 #, fuzzy, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "未定義的特定的繫結『%s』做為目標的通用『%s』於 %L"
 
-#: fortran/resolve.cc:14657
+#: fortran/resolve.cc:14666
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "通用『%s』於 %L 必須目標特定的繫結，『%s』是通用，太"
 
-#: fortran/resolve.cc:14685
+#: fortran/resolve.cc:14694
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
 msgstr "通用『%s』於 %L 無法覆寫特定的繫結與同名"
 
-#: fortran/resolve.cc:14741
+#: fortran/resolve.cc:14750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L cannot be NOPASS"
 msgstr "Type-bound 運算子於 %L 無法 NOPASS"
 
-#: fortran/resolve.cc:14953
+#: fortran/resolve.cc:14962
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "『%s』必須是模組程序或外部程序與明確的介面於 %L"
 
-#: fortran/resolve.cc:14996
+#: fortran/resolve.cc:15005
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "程序『%s』與回合 (%s) 於 %L 沒有任何引數『%s』"
 
-#: fortran/resolve.cc:15010
+#: fortran/resolve.cc:15019
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "程序『%s』與回合於 %L 必須至少有一個引數"
 
-#: fortran/resolve.cc:15024 fortran/resolve.cc:15566
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Non-polymorphic passed-object 虛引數的『%s』於 %L"
 
-#: fortran/resolve.cc:15033
+#: fortran/resolve.cc:15042
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是的衍生類型『%s』"
 
-#: fortran/resolve.cc:15043
+#: fortran/resolve.cc:15052
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是的衍生類型『%s』"
 
-#: fortran/resolve.cc:15085
+#: fortran/resolve.cc:15094
 #, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
 msgstr ""
 
-#: fortran/resolve.cc:15095
+#: fortran/resolve.cc:15104
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須是純量"
 
-#: fortran/resolve.cc:15101
+#: fortran/resolve.cc:15110
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須不是 ALLOCATABLE"
 
-#: fortran/resolve.cc:15107
+#: fortran/resolve.cc:15116
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須不是指標"
 
-#: fortran/resolve.cc:15136
+#: fortran/resolve.cc:15145
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "程序『%s』於 %L 有同名做為成分的『%s』"
 
-#: fortran/resolve.cc:15146
+#: fortran/resolve.cc:15155
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "程序『%s』於 %L 有同名做為繼承的成分的『%s』"
 
-#: fortran/resolve.cc:15241
+#: fortran/resolve.cc:15250
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "衍生類型『%s』宣告的於 %L 必須是摘要因為『%s』是已推遲和無法 overridden"
 
-#: fortran/resolve.cc:15346
+#: fortran/resolve.cc:15355
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Coarray 成分『%s』於 %L 必須是 allocatable 與已推遲形狀"
 
-#: fortran/resolve.cc:15355
+#: fortran/resolve.cc:15364
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "成分『%s』於 %L 的型態 (C_PTR) 或型態 (C_FUNPTR) 不應該是 coarray"
 
-#: fortran/resolve.cc:15365
+#: fortran/resolve.cc:15374
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "成分『%s』於 %L 與 coarray 成分應該是 nonpointer，nonallocatable 純量"
 
-#: fortran/resolve.cc:15390
+#: fortran/resolve.cc:15399
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "成分『%s』於 %L 有 CONTIGUOUS 屬性但是不是陣列指標"
 
-#: fortran/resolve.cc:15401
+#: fortran/resolve.cc:15410
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "%L 處 ICHAR 的參數長度必須為 1"
 
-#: fortran/resolve.cc:15499
+#: fortran/resolve.cc:15508
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "程序指標成分『%s』與回合 (%s) 於 %L 沒有任何引數『%s』"
 
-#: fortran/resolve.cc:15513
+#: fortran/resolve.cc:15522
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "程序指標成分『%s』與回合於 %L 必須至少有一個引數"
 
-#: fortran/resolve.cc:15529
+#: fortran/resolve.cc:15538
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是的衍生類型『%s』"
 
-#: fortran/resolve.cc:15539
+#: fortran/resolve.cc:15548
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是純量"
 
-#: fortran/resolve.cc:15548
+#: fortran/resolve.cc:15557
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 可能無法有指標屬性"
 
-#: fortran/resolve.cc:15557
+#: fortran/resolve.cc:15566
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 可能無法是 ALLOCATABLE"
 
-#: fortran/resolve.cc:15599
+#: fortran/resolve.cc:15608
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "成分『%s』的『%s』於 %L 有同名做為繼承 type-bound 程序"
 
-#: fortran/resolve.cc:15612
+#: fortran/resolve.cc:15621
 #, fuzzy, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "字元長度的成分『%s』需要是常數規格運算式於 %L"
 
-#: fortran/resolve.cc:15623
+#: fortran/resolve.cc:15632
 #, fuzzy, gcc-internal-format
 msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
 msgstr "運算式於 %L 必須是的整數類型，找到 %s"
 
-#: fortran/resolve.cc:15636
+#: fortran/resolve.cc:15645
 #, fuzzy, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "字元成分『%s』的『%s』於 %L 與已推遲長度必須是指標或 ALLOCATABLE"
 
-#: fortran/resolve.cc:15669
+#: fortran/resolve.cc:15678
 #, fuzzy, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003:成分『%s』是私人的型態和無法成分的『%s』，該項是公用的於 %L"
 
-#: fortran/resolve.cc:15677
+#: fortran/resolve.cc:15686
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphic 成分 %s 於 %L 在中序列或繫結©型態 %s"
 
-#: fortran/resolve.cc:15686
+#: fortran/resolve.cc:15695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "成分 %s 的序列型態宣告的於 %L 沒有序列屬性"
 
-#: fortran/resolve.cc:15772
+#: fortran/resolve.cc:15781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "衝突在中屬性的函式引數於 %C"
 
-#: fortran/resolve.cc:15817
+#: fortran/resolve.cc:15826
 #, fuzzy, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "做為延伸型態『%s』於 %L 有 coarray 成分，親代型態『%s』應該也有一個"
 
-#: fortran/resolve.cc:15830
+#: fortran/resolve.cc:15839
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Non-extensible 衍生類型『%s』於 %L 必須不是摘要"
 
-#: fortran/resolve.cc:15894
+#: fortran/resolve.cc:15903
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.cc:15927
+#: fortran/resolve.cc:15936
 #, fuzzy, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Fortran 2003:通用名稱『%s』的函式『%s』於 %L 相同名稱做為衍生類型於 %L"
 
-#: fortran/resolve.cc:15941
+#: fortran/resolve.cc:15950
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L has not been declared"
 msgstr "衍生類型『%s』於 %L 必須是 extensible"
 
-#: fortran/resolve.cc:16009
+#: fortran/resolve.cc:16018
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "假設的大小陣列『%s』在中名稱表列『%s』於 %L 未被允許"
 
-#: fortran/resolve.cc:16015
+#: fortran/resolve.cc:16024
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列陣列物件『%s』與假設的形狀在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.cc:16021
+#: fortran/resolve.cc:16030
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列陣列物件『%s』與 nonconstant 形狀在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.cc:16029
+#: fortran/resolve.cc:16038
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列物件『%s』與 nonconstant 字元長度在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.cc:16046
+#: fortran/resolve.cc:16055
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "名稱表列物件『%s』被宣告私人的和無法成員的公用的名稱表列『%s』於 %L"
 
-#: fortran/resolve.cc:16068
+#: fortran/resolve.cc:16077
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "名稱表列物件『%s』已 use-associated 私人的成分和無法成員的名稱表列『%s』於 %L"
 
-#: fortran/resolve.cc:16079
+#: fortran/resolve.cc:16088
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "名稱表列物件『%s』有私人的成分和無法成員的公用的名稱表列『%s』於 %L"
 
-#: fortran/resolve.cc:16106
+#: fortran/resolve.cc:16115
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "程序屬性衝突與名稱表列屬性在中『%s』於 %L"
 
-#: fortran/resolve.cc:16125
+#: fortran/resolve.cc:16134
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "參數陣列『%s』於 %L 無法自動或的已推遲形狀"
 
-#: fortran/resolve.cc:16141
+#: fortran/resolve.cc:16150
 #, fuzzy, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "隱含地型態的參數『%s』於 %L 不匹配稍後隱含的型態"
 
-#: fortran/resolve.cc:16152
+#: fortran/resolve.cc:16161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "不相容的衍生類型在中參數於 %L"
 
-#: fortran/resolve.cc:16160
+#: fortran/resolve.cc:16169
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "共同區塊『%s』於 %L 無法有外部屬性"
 
-#: fortran/resolve.cc:16212
+#: fortran/resolve.cc:16221
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "實體『%s』於 %L 有已推遲型態參數和需求還是指標或 allocatable 屬性"
 
-#: fortran/resolve.cc:16224
+#: fortran/resolve.cc:16233
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.cc:16231
+#: fortran/resolve.cc:16240
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.cc:16290
+#: fortran/resolve.cc:16299
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.cc:16303
+#: fortran/resolve.cc:16312
 #, gcc-internal-format
 msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
 msgstr ""
 
-#: fortran/resolve.cc:16361
+#: fortran/resolve.cc:16370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "保護的屬性衝突與外部屬性於 %L"
 
-#: fortran/resolve.cc:16364
+#: fortran/resolve.cc:16373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "程序屬性衝突與保護的屬性於 %L"
 
-#: fortran/resolve.cc:16461
+#: fortran/resolve.cc:16470
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "『%s』於 %L 有 CONTIGUOUS 屬性但是不是陣列指標或 assumed-shape 陣列"
 
-#: fortran/resolve.cc:16482
+#: fortran/resolve.cc:16491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "不當的規格用於假設的大小陣列於 %C"
 
-#: fortran/resolve.cc:16496
+#: fortran/resolve.cc:16505
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "假定大小的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.cc:16499
+#: fortran/resolve.cc:16508
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.cc:16509
+#: fortran/resolve.cc:16518
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.cc:16516
+#: fortran/resolve.cc:16525
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.cc:16529
+#: fortran/resolve.cc:16538
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L 處的符號不是一個 DUMMY 變數"
 
-#: fortran/resolve.cc:16535
+#: fortran/resolve.cc:16544
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "『%s』於 %L 無法有值屬性因為它並非虛引數"
 
-#: fortran/resolve.cc:16545
+#: fortran/resolve.cc:16554
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "字元虛設變數『%s』於 %L 與值屬性必須有常數長度"
 
-#: fortran/resolve.cc:16554
+#: fortran/resolve.cc:16563
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C 可交流的字元虛設變數『%s』於 %L 與值屬性必須有長度一個"
 
-#: fortran/resolve.cc:16567 fortran/resolve.cc:16744
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "衍生類型『%s』於 %L 是的型態『%s』，該項未被定義"
 
-#: fortran/resolve.cc:16581
+#: fortran/resolve.cc:16590
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.cc:16590
+#: fortran/resolve.cc:16599
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.cc:16599
+#: fortran/resolve.cc:16608
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.cc:16607
+#: fortran/resolve.cc:16616
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/resolve.cc:16614
+#: fortran/resolve.cc:16623
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.cc:16634
+#: fortran/resolve.cc:16643
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "假設的形狀陣列『%s』於 %L 未被允許在中初始化運算式"
 
-#: fortran/resolve.cc:16641
+#: fortran/resolve.cc:16650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.cc:16648
+#: fortran/resolve.cc:16657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/resolve.cc:16655
+#: fortran/resolve.cc:16664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "迴圈變數於 %C 無法 coarray"
 
-#: fortran/resolve.cc:16681
+#: fortran/resolve.cc:16690
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "變數『%s』於 %L 無法繫結©因為它是 neither 共同區塊 nor 宣告的於模組等級範圍"
 
-#: fortran/resolve.cc:16691
+#: fortran/resolve.cc:16700
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "%s 的參數(位於 %L)長度必須為 1"
 
-#: fortran/resolve.cc:16770
+#: fortran/resolve.cc:16779
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003:公用的 %s『%s』於 %L 的私人的衍生類型『%s』"
 
-#: fortran/resolve.cc:16785
+#: fortran/resolve.cc:16794
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "變數 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須是 coarray"
 
-#: fortran/resolve.cc:16798
+#: fortran/resolve.cc:16807
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "變數 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須是 coarray"
 
-#: fortran/resolve.cc:16816
+#: fortran/resolve.cc:16825
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "含義 (出) 虛引數『%s』於 %L 是假設的大小和因而無法有預設初始設定式"
 
-#: fortran/resolve.cc:16828
+#: fortran/resolve.cc:16837
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "虛引數『%s』於 %L 的 LOCK_TYPE 不應該是含義 (出)"
 
-#: fortran/resolve.cc:16837
+#: fortran/resolve.cc:16846
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "虛引數『%s』於 %L 的 LOCK_TYPE 不應該是含義 (出)"
 
-#: fortran/resolve.cc:16850
+#: fortran/resolve.cc:16859
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "函數計算結果『%s』於 %L 不應該是 coarray 或有 coarray 成分"
 
-#: fortran/resolve.cc:16859
+#: fortran/resolve.cc:16868
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "變數『%s』於 %L 的型態 (C_PTR) 或型態 (C_FUNPTR) 不應該是 coarray"
 
-#: fortran/resolve.cc:16872
+#: fortran/resolve.cc:16881
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "變數『%s』於 %L 與 coarray 成分應該是 nonpointer，nonallocatable 純量"
 
-#: fortran/resolve.cc:16888
+#: fortran/resolve.cc:16897
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "變數『%s』於 %L 是 coarray 和不是 ALLOCATABLE，儲存 nor 虛引數"
 
-#: fortran/resolve.cc:16896
+#: fortran/resolve.cc:16905
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.cc:16903
+#: fortran/resolve.cc:16912
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Allocatable coarray 變數『%s』於 %L 必須已已推遲形狀"
 
-#: fortran/resolve.cc:16916
+#: fortran/resolve.cc:16925
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "變數『%s』於 %L 是含義 (出) 和可以因而無法是 allocatable coarray 或有 coarray 成分"
 
-#: fortran/resolve.cc:16925
+#: fortran/resolve.cc:16934
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.cc:16941
+#: fortran/resolve.cc:16950
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.cc:16947
+#: fortran/resolve.cc:16956
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.cc:16972
+#: fortran/resolve.cc:16981
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
 msgstr "名稱表列 %s 無法重新命名的由使用關聯到 %s"
 
-#: fortran/resolve.cc:17032
+#: fortran/resolve.cc:17041
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate 於 %L 不是儲存"
 
-#: fortran/resolve.cc:17044
+#: fortran/resolve.cc:17053
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.cc:17151
+#: fortran/resolve.cc:17160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting definable entity near %L"
 msgstr "預期具名的實體清單的於 %C"
 
-#: fortran/resolve.cc:17159
+#: fortran/resolve.cc:17168
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "區塊資料元素『%s』於 %L 必須是在中共同"
 
-#: fortran/resolve.cc:17166
+#: fortran/resolve.cc:17175
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "資料陣列『%s』於 %L 必須被指定的在中前一個宣告"
 
-#: fortran/resolve.cc:17173
+#: fortran/resolve.cc:17182
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "資料元素『%s』於 %L 無法有 coindex"
 
-#: fortran/resolve.cc:17189
+#: fortran/resolve.cc:17198
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "資料元素『%s』於 %L 是指標和因而必須是全部陣列"
 
-#: fortran/resolve.cc:17196
+#: fortran/resolve.cc:17205
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
 msgstr ""
 
-#: fortran/resolve.cc:17205
+#: fortran/resolve.cc:17214
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
 msgstr "引數『%s』的 elemental 程序於 %L 無法有 ALLOCATABLE 屬性"
 
-#: fortran/resolve.cc:17267
+#: fortran/resolve.cc:17276
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Nonconstant 陣列區段於 %L 在中資料敘述"
 
-#: fortran/resolve.cc:17280
+#: fortran/resolve.cc:17289
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "資料敘述於 %L 有更多變數比值"
 
-#: fortran/resolve.cc:17356
+#: fortran/resolve.cc:17365
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-constant character length at %L in DATA statement"
 msgstr "Nonconstant 陣列區段於 %L 在中資料敘述"
 
-#: fortran/resolve.cc:17384
+#: fortran/resolve.cc:17393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "開始的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.cc:17392
+#: fortran/resolve.cc:17401
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "結束的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.cc:17400
+#: fortran/resolve.cc:17409
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "步驟的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.cc:17407
+#: fortran/resolve.cc:17416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L shall not be zero"
 msgstr "步驟的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.cc:17532
+#: fortran/resolve.cc:17541
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "資料敘述於 %L 有更多值比變數"
 
-#: fortran/resolve.cc:17698
+#: fortran/resolve.cc:17707
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "標籤 %d 於 %L 經定義但未被使用"
 
-#: fortran/resolve.cc:17704
+#: fortran/resolve.cc:17713
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "標籤 %d 於 %L 經定義但無法被使用"
 
-#: fortran/resolve.cc:17788
+#: fortran/resolve.cc:17797
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 必須有序列屬性為等價物件"
 
-#: fortran/resolve.cc:17797
+#: fortran/resolve.cc:17806
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 無法有 ALLOCATABLE 成分為等價物件"
 
-#: fortran/resolve.cc:17805
+#: fortran/resolve.cc:17814
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "衍生類型變數『%s』於 %L 與預設初始化無法在中等價與變數在中共同"
 
-#: fortran/resolve.cc:17821
+#: fortran/resolve.cc:17830
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 與指標成分無法等價物件"
 
-#: fortran/resolve.cc:17924
+#: fortran/resolve.cc:17933
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L 處 EQUIVALENCE 敘述語法錯誤"
 
-#: fortran/resolve.cc:17939
+#: fortran/resolve.cc:17948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "還是所有或沒有任何物件在中等價設定於 %L 應該有保護的屬性"
 
-#: fortran/resolve.cc:17964
+#: fortran/resolve.cc:17973
 #, fuzzy, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "共同區塊成員『%s』於 %L 無法等價物件在中 pure 程序『%s』"
 
-#: fortran/resolve.cc:17973
+#: fortran/resolve.cc:17982
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "具名的常數『%s』於 %L 無法等價物件"
 
-#: fortran/resolve.cc:18048
+#: fortran/resolve.cc:18057
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "陣列『%s』於 %L 與 non-constant 邊界無法等價物件"
 
-#: fortran/resolve.cc:18059
+#: fortran/resolve.cc:18068
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "結構成分『%s』於 %L 無法等價物件"
 
-#: fortran/resolve.cc:18070
+#: fortran/resolve.cc:18079
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L 的子字串長度為零"
 
-#: fortran/resolve.cc:18101
+#: fortran/resolve.cc:18110
 #, fuzzy, gcc-internal-format
 #| msgid "Syntax error in character length specification at %C"
 msgid "Self reference in character length expression for %qs at %L"
 msgstr "%C 處指定字元長度時語法錯誤"
 
-#: fortran/resolve.cc:18168
+#: fortran/resolve.cc:18177
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fortran 2003:公用的函式『%s』於 %L 的私人的型態『%s』"
 
-#: fortran/resolve.cc:18181
+#: fortran/resolve.cc:18190
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY「%s」在 %L 處沒有 IMPLICIT 類型"
 
-#: fortran/resolve.cc:18203
+#: fortran/resolve.cc:18212
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "使用者運算子程序『%s』於 %L 必須是函式"
 
-#: fortran/resolve.cc:18213
+#: fortran/resolve.cc:18222
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "使用者運算子程序『%s』於 %L 無法假設的字元長度"
 
-#: fortran/resolve.cc:18221
+#: fortran/resolve.cc:18230
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "使用者運算子程序『%s』於 %L 必須至少有一個引數"
 
-#: fortran/resolve.cc:18235
+#: fortran/resolve.cc:18244
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "第一個引數的運算子介面於 %L 無法可選的"
 
-#: fortran/resolve.cc:18253
+#: fortran/resolve.cc:18262
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "秒引數的運算子介面於 %L 無法可選的"
 
-#: fortran/resolve.cc:18260
+#: fortran/resolve.cc:18269
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "運算子介面於 %L 必須有，最多，兩引數"
 
-#: fortran/resolve.cc:18342
+#: fortran/resolve.cc:18351
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "包含的程序『%s』於 %L 的 PURE 程序必須也是 PURE"
@@ -84080,339 +84129,339 @@ msgstr "隱含地宣告的變數『%s』於 %L 可能無法是 C 可交流的但
 msgid "Function result %qs at %L has no IMPLICIT type"
 msgstr "函數計算結果『%s』於 %L 沒有任何隱含的型態"
 
-#: fortran/symbol.cc:501
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr "%s 屬性與 %s 屬性在 %L 處衝突"
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, fuzzy, gcc-internal-format
+#| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr "%s 屬性與 %s 屬性衝突，在「%s」中，位於 %L"
+
+#: fortran/symbol.cc:508
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
 msgstr "%s 屬性在 %L 處不允許出現在 BLOCAK DATA 程式單元中"
 
-#: fortran/symbol.cc:526
+#: fortran/symbol.cc:533
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Namelist group name at %L cannot have the SAVE attribute"
 msgstr "名稱表列群組名稱於 %L 無法有儲存屬性"
 
-#: fortran/symbol.cc:545
+#: fortran/symbol.cc:552
 #, fuzzy, gcc-internal-format
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
 msgstr "Fortran 2008:內部程序『%s』被做為實際引數於 %L"
 
-#: fortran/symbol.cc:578
+#: fortran/symbol.cc:585
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
 msgstr "Fortran 2003:程序指標於 %C"
 
-#: fortran/symbol.cc:790
+#: fortran/symbol.cc:797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute applied to %s %s at %L"
 msgstr "%s 屬性套用到 %s %s 於 %L"
 
-#: fortran/symbol.cc:797
+#: fortran/symbol.cc:804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "繫結©套用到 %s %s 於 %L"
 
-#: fortran/symbol.cc:918 fortran/symbol.cc:929 fortran/symbol.cc:1809
-#, gcc-internal-format, gfc-internal-format
-msgid "%s attribute conflicts with %s attribute at %L"
-msgstr "%s 屬性與 %s 屬性在 %L 處衝突"
-
-#: fortran/symbol.cc:921 fortran/symbol.cc:935
-#, fuzzy, gcc-internal-format
-#| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
-msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr "%s 屬性與 %s 屬性衝突，在「%s」中，位於 %L"
-
-#: fortran/symbol.cc:979
+#: fortran/symbol.cc:972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol at %L"
 msgstr "無法變更屬性的 USE-associated 符號於 %L"
 
-#: fortran/symbol.cc:982
+#: fortran/symbol.cc:975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot change attributes of USE-associated symbol %s at %L"
 msgstr "無法變更屬性的 USE-associated 符號 %s 於 %L"
 
-#: fortran/symbol.cc:998
+#: fortran/symbol.cc:991
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute specified at %L"
 msgstr "重複的 %s 屬性在 %L 處被指定"
 
-#: fortran/symbol.cc:1040
+#: fortran/symbol.cc:1033
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
 msgstr "ALLOCATABLE 指定的外側的介面內文於 %L"
 
-#: fortran/symbol.cc:1057
+#: fortran/symbol.cc:1050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate AUTOMATIC attribute specified at %L"
 msgstr "重製易變的屬性指定的於 %L"
 
-#: fortran/symbol.cc:1081
+#: fortran/symbol.cc:1074
 #, fuzzy, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "CODIMENSION 指定的用於『%s』外側它的介面內文於 %L"
 
-#: fortran/symbol.cc:1107
+#: fortran/symbol.cc:1100
 #, fuzzy, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
 msgstr "尺寸指定的用於『%s』外側它的介面內文於 %L"
 
-#: fortran/symbol.cc:1270
+#: fortran/symbol.cc:1263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %L appears in multiple pointer() statements"
 msgstr "Cray 點於 %L 出現在中多重指標() 敘述"
 
-#: fortran/symbol.cc:1289
+#: fortran/symbol.cc:1282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PROTECTED attribute specified at %L"
 msgstr "重製保護的屬性指定的於 %L"
 
-#: fortran/symbol.cc:1322
+#: fortran/symbol.cc:1315
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgstr "%L 處 PURE 程序不能指定 SAVE 屬性"
 
-#: fortran/symbol.cc:1334
+#: fortran/symbol.cc:1327
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SAVE attribute specified at %L"
 msgstr "%L 指定了重複的 SAVE 屬性"
 
-#: fortran/symbol.cc:1354
+#: fortran/symbol.cc:1347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VALUE attribute specified at %L"
 msgstr "重製值屬性指定的於 %L"
 
-#: fortran/symbol.cc:1373
+#: fortran/symbol.cc:1366
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "重製易變的屬性指定的於 %L"
 
-#: fortran/symbol.cc:1385
+#: fortran/symbol.cc:1378
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
 msgstr "%L 處 PURE 程序不能指定 SAVE 屬性"
 
-#: fortran/symbol.cc:1406
+#: fortran/symbol.cc:1399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "重製非同步屬性指定的於 %L"
 
-#: fortran/symbol.cc:1805
+#: fortran/symbol.cc:1798
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "%s 屬性的『%s』衝突與 %s 屬性於 %L"
 
-#: fortran/symbol.cc:1842
+#: fortran/symbol.cc:1835
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.cc:1850
+#: fortran/symbol.cc:1843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "%s 程序於 %L 已經宣告的做為 %s 程序"
 
-#: fortran/symbol.cc:1885
+#: fortran/symbol.cc:1878
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) 與 INTENT(%s) 在 %L 衝突"
 
-#: fortran/symbol.cc:1909
+#: fortran/symbol.cc:1902
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "存取規格於 %L 已經指定的"
 
-#: fortran/symbol.cc:1926
+#: fortran/symbol.cc:1919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "重製繫結屬性指定的於 %L"
 
-#: fortran/symbol.cc:1933
+#: fortran/symbol.cc:1926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "Fortran 2003:繫結©於 %L"
 
-#: fortran/symbol.cc:1949
+#: fortran/symbol.cc:1942
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "重製延伸屬性指定的於 %L"
 
-#: fortran/symbol.cc:1953
+#: fortran/symbol.cc:1946
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "Fortran 2003:延伸於 %L"
 
-#: fortran/symbol.cc:1979
+#: fortran/symbol.cc:1972
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "符號「%s」在 %L 處已經有了明確介面"
 
-#: fortran/symbol.cc:1986
+#: fortran/symbol.cc:1979
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "『%s』於 %L 有屬性指定的外側它的介面內文"
 
-#: fortran/symbol.cc:2024
+#: fortran/symbol.cc:2017
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "符號『%s』於 %L 衝突與符號從模組『%s』，use-associated 於 %L"
 
-#: fortran/symbol.cc:2028 fortran/symbol.cc:2031
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "符號「%s」在 %L 處已經有了基本類型 %s"
 
-#: fortran/symbol.cc:2038
+#: fortran/symbol.cc:2031
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "程序『%s』於 %L 可能無法有基本型式的 %s"
 
-#: fortran/symbol.cc:2050
+#: fortran/symbol.cc:2043
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "符號「%s」於 %L 處不能有類型"
 
-#: fortran/symbol.cc:2295
+#: fortran/symbol.cc:2288
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "成分『%s』於 %C 已經在中親代型態於 %L"
 
-#: fortran/symbol.cc:2380
+#: fortran/symbol.cc:2373
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "符號「%s」在 %C 處有歧義"
 
-#: fortran/symbol.cc:2412
+#: fortran/symbol.cc:2405
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "衍生類型『%s』於 %C 正在被使用之前它被定義"
 
-#: fortran/symbol.cc:2622
+#: fortran/symbol.cc:2615
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "元件「%s」在 %C 處是「%s」的 PRIVATE 元件"
 
-#: fortran/symbol.cc:2643
+#: fortran/symbol.cc:2636
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "「%s」在 %C 處不是「%s」結構的成員"
 
-#: fortran/symbol.cc:2647
+#: fortran/symbol.cc:2640
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "「%s」在 %C 處不是「%s」結構的成員"
 
-#: fortran/symbol.cc:2811
+#: fortran/symbol.cc:2804
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "重複的敘述標籤 %d 出現在 %L 和 %L 處"
 
-#: fortran/symbol.cc:2822
+#: fortran/symbol.cc:2815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "標貼 %d 於 %C 已經引用做為分支目標"
 
-#: fortran/symbol.cc:2832
+#: fortran/symbol.cc:2825
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "標貼 %d 於 %C 已經引用做為格式標貼"
 
-#: fortran/symbol.cc:2839
+#: fortran/symbol.cc:2832
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.cc:2880
+#: fortran/symbol.cc:2873
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "標貼 %d 於 %C 在之前使用的做為格式標貼"
 
-#: fortran/symbol.cc:2889
+#: fortran/symbol.cc:2882
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "標貼 %d 於 %C 在之前使用的做為分支目標"
 
-#: fortran/symbol.cc:2896
+#: fortran/symbol.cc:2889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "%C 處需要結束名"
 
-#: fortran/symbol.cc:2900
+#: fortran/symbol.cc:2893
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Labeled DO statement at %L"
 msgstr "Fortran 2008:鎖定敘述於 %C"
 
-#: fortran/symbol.cc:3241
+#: fortran/symbol.cc:3284
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "名稱『%s』於 %C 是模稜兩可的參考到『%s』從模組『%s』"
 
-#: fortran/symbol.cc:3244
+#: fortran/symbol.cc:3287
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "名稱『%s』於 %C 是模稜兩可的參考到『%s』從目前的程式單元"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.cc:3489
+#: fortran/symbol.cc:3532
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "符號『%s』於 %C 已主機關聯的"
 
-#: fortran/symbol.cc:4543
+#: fortran/symbol.cc:4586
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.cc:4556
+#: fortran/symbol.cc:4599
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "衍生類型『%s』宣告的於 %L 必須有繫結屬性為 C 可交流的"
 
-#: fortran/symbol.cc:4574
+#: fortran/symbol.cc:4617
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "衍生類型『%s』與繫結©屬性於 %L 是空的，而也許會是不可存取由 C companion 處理器"
 
-#: fortran/symbol.cc:4595
+#: fortran/symbol.cc:4638
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "成分『%s』於 %L 無法有指標屬性因為它是成員的繫結©衍生類型『%s』於 %L"
 
-#: fortran/symbol.cc:4605
+#: fortran/symbol.cc:4648
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "程序指標成分『%s』於 %L 無法成員的繫結©衍生類型『%s』於 %L"
 
-#: fortran/symbol.cc:4616
+#: fortran/symbol.cc:4659
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "成分『%s』於 %L 無法有 ALLOCATABLE 屬性因為它是成員的繫結©衍生類型『%s』於 %L"
 
-#: fortran/symbol.cc:4655
+#: fortran/symbol.cc:4698
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "成分『%s』在中衍生類型『%s』於 %L 可能無法是 C 可交流的，甚至雖然衍生類型『%s』是繫結©"
 
-#: fortran/symbol.cc:4665
+#: fortran/symbol.cc:4708
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "成分『%s』在中衍生類型『%s』於 %L 可能無法是 C 可交流的"
 
-#: fortran/symbol.cc:4677
+#: fortran/symbol.cc:4720
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "衍生類型『%s』於 %L 無法有序列屬性因為它是繫結©"
 
-#: fortran/symbol.cc:5181 fortran/symbol.cc:5186
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "符號『%s』被使用之前它被型態於 %L"
@@ -84442,24 +84491,24 @@ msgstr "重疊 unequal 初始設定式在中等價於 %L"
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
 msgstr "重疊 unequal 初始設定式在中等價於 %L"
 
-#: fortran/trans-array.cc:2338 fortran/trans-expr.cc:9854
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
 #, gcc-internal-format, gfc-internal-format
 msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
 msgstr ""
 
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
-#: fortran/trans-array.cc:6608
+#: fortran/trans-array.cc:6620
 #, fuzzy, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
 msgstr "元件號碼的在中陣列建構子於 %L 需求增加的允許 %d 上限。  參看 -fmax-array-constructor 選項"
 
-#: fortran/trans-array.cc:8852
+#: fortran/trans-array.cc:8876
 #, fuzzy, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "建立陣列暫時的於 %L 用於引數『%s』"
 
-#: fortran/trans-array.cc:12215
+#: fortran/trans-array.cc:12255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "不當的運算式型態在的期間遍歷 (%d)"
@@ -84647,37 +84696,37 @@ msgstr "傳回值『%s』的函式『%s』宣告的於 %L 無法設定"
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
 msgstr ""
 
-#: fortran/trans-expr.cc:1132
+#: fortran/trans-expr.cc:1134
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot compute the length of the char array at %L."
 msgstr ""
 
-#: fortran/trans-expr.cc:1936
+#: fortran/trans-expr.cc:1942
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
 msgstr ""
 
-#: fortran/trans-expr.cc:2272
+#: fortran/trans-expr.cc:2278
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
 msgstr ""
 
-#: fortran/trans-expr.cc:2281
+#: fortran/trans-expr.cc:2287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
 msgstr "無限制的多型於 %C 尚未支援"
 
-#: fortran/trans-expr.cc:3980
+#: fortran/trans-expr.cc:3986
 #, gcc-internal-format
 msgid "Unknown intrinsic op"
 msgstr "不明的內建作業"
 
-#: fortran/trans-expr.cc:5499
+#: fortran/trans-expr.cc:5505
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown argument list function at %L"
 msgstr "不明引數清單函式於 %L"
 
-#: fortran/trans-expr.cc:10432
+#: fortran/trans-expr.cc:10437
 #, gcc-internal-format, gfc-internal-format
 msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
 msgstr ""
@@ -84689,17 +84738,17 @@ msgid "Intrinsic function %qs (%d) not recognized"
 msgstr "內部函式 %s(%d) 無法識別"
 
 #: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
-#: fortran/trans-intrinsic.cc:3199
+#: fortran/trans-intrinsic.cc:3201
 #, fuzzy, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "『dim』引數的 %s intrinsic 於 %L 並非有效尺寸索引"
 
-#: fortran/trans-intrinsic.cc:12336 fortran/trans-stmt.cc:1104
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "Deferred-length 字元成分『%s』於 %L 不是未支援"
 
-#: fortran/trans-intrinsic.cc:12343
+#: fortran/trans-intrinsic.cc:12390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "指標物件於 %C 不應該被 coindexed"
@@ -84844,7 +84893,7 @@ msgstr "Deferred-length 字元成分『%s』於 %L 不是未支援"
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr "抱歉，只有支援用於整數 kind %d 實作的用於 image-set 於 %L"
 
-#: fortran/trans-stmt.cc:3700
+#: fortran/trans-stmt.cc:3710
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_trans_select(): Bad type for case expr."
@@ -85220,6 +85269,11 @@ msgstr "變數 %qD redeclared 做為函式"
 msgid "function %qD redeclared as variable"
 msgstr "函式 %qD redeclared 做為變數"
 
+#: lto/lto-symtab.cc:865
+#, fuzzy, gcc-internal-format
+msgid "previously declared here"
+msgstr "在之前宣告的在此"
+
 #: lto/lto.cc:174
 #, fuzzy, gcc-internal-format
 msgid "%<lto_obj_file_open()%> failed"
@@ -86484,7 +86538,7 @@ msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
 msgstr "%<-fobjc-sjlj-exceptions%> 被忽略用於 %<-fgnu-runtime%>"
 
 #: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
-#: objc/objc-next-runtime-abi-02.cc:3839
+#: objc/objc-next-runtime-abi-02.cc:3840
 #, fuzzy, gcc-internal-format
 msgid "non-objective-c type %qT cannot be caught"
 msgstr "non-objective-c 型態『%T』無法擷取到"
@@ -86494,7 +86548,7 @@ msgstr "non-objective-c 型態『%T』無法擷取到"
 msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
 msgstr "%<-fobjc-sjlj-exceptions%> 是只有支援的異常系統用於 %<-fnext-runtime%> 與 %<-fobjc-abi-version%><2"
 
-#: objc/objc-next-runtime-abi-02.cc:245
+#: objc/objc-next-runtime-abi-02.cc:246
 #, fuzzy, gcc-internal-format
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
 msgstr "%<-fobjc-sjlj-exceptions%> 被忽略用於 %<-fnext-runtime%> 時 %<-fobjc-abi-version%>>=2"
@@ -89947,10 +90001,6 @@ msgstr ""
 #~ msgid "argument 1 of __builtin_spe_predicate must be a constant"
 #~ msgstr "__builtin_spe_predicate 的第一個引數必須是常數"
 
-#, fuzzy
-#~ msgid "Builtin function %s requires the -maltivec option"
-#~ msgstr "內建函式 %s 需求 -maltivec 選項"
-
 #, fuzzy
 #~ msgid "internal error: builtin function %s had no type"
 #~ msgstr "內部錯誤：內建函式 %s 沒有任何型態"

commit 99eb84fd363b7980eac16ace5e975da65a1185e8
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Sat Aug 3 02:22:11 2024

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index d828c55306f..6262ca6d8d4 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,32 @@
+2024-08-02  Andrew Pinski  <quic_apinski@quicinc.com>
+
+	PR tree-optimization/116156
+	* tree-ssa-forwprop.cc (pass_forwprop::execute): Don't add
+	uses if the statement was a debug statement.
+
+2024-08-02  liuhongt  <hongtao.liu@intel.com>
+
+	Backported from master:
+	2024-07-30  liuhongt  <hongtao.liu@intel.com>
+
+	PR target/116043
+	* config/i386/constraints.md (Bk): Refine to
+	define_special_memory_constraint.
+
+2024-08-02  Haochen Jiang  <haochen.jiang@intel.com>
+
+	* config/i386/prfchiintrin.h
+	(_m_prefetchit0): Add macro for non-optimized option.
+	(_m_prefetchit1): Ditto.
+
+2024-08-02  Yang Yujie  <yangyujie@loongson.cn>
+
+	Backported from master:
+	2024-08-02  Yang Yujie  <yangyujie@loongson.cn>
+
+	* config/loongarch/genopts/gen-evolution.awk: Do not use
+	"length()" to compute the size of an array.
+
 2024-08-01  Jakub Jelinek  <jakub@redhat.com>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index ba6415cbd75..613753ee8b5 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240802
+20240803
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index 4d37b09efd6..e819f9e63e8 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -1,3 +1,63 @@
+2024-08-02  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2024-07-29  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/88313
+	* parser.cc (cp_parser_lambda_declarator_opt): Pass
+	lambda_p=true to cp_parser_parameter_declaration_clause.
+	(cp_parser_direct_declarator): Pass lambda_p=false to
+	to cp_parser_parameter_declaration_clause.
+	(cp_parser_parameter_declaration_clause): Add bool lambda_p
+	parameter.  Consider lambda_p instead of current_class_type
+	when setting parser->auto_is_implicit_function_template_parm_p.
+	Don't consider processing_template_parmlist.
+	(cp_parser_requirement_parameter_list): Pass lambda_p=false
+	to cp_parser_parameter_declaration_clause.
+
+2024-08-02  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2024-07-25  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/115897
+	* tree.cc (strip_typedefs): Move up the typedef recursion case.
+	Never strip a dependent alias template-id that has dependent
+	attributes.
+
+2024-08-02  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2024-07-23  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/115656
+	* constraint.cc (weakly_subsumes): Pass in_decl=tmpl to
+	get_normalized_constraints_from_info.  Rename to ...
+	(ttp_subsumes): ... this.
+	* cp-tree.h (weakly_subsumes): Rename to ...
+	(ttp_subsumes): ... this.
+	* pt.cc (is_compatible_template_arg): Adjust after renaming.
+
+2024-08-02  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2024-07-23  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/115296
+	* pt.cc (alias_ctad_tweaks): Use complain=tf_none instead of
+	tf_warning_or_error.
+
+2024-08-02  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2024-07-18  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/112288
+	* pt.cc (tsubst_friend_function): When adjusting existing
+	specializations after defining a previously declared template
+	friend, consider the most general template and correct
+	DECL_TI_ARGS adjustment.
+
 2024-08-01  Release Manager
 
 	* GCC 14.2.0 released.
diff --git a/gcc/po/ChangeLog b/gcc/po/ChangeLog
index 4ea5f663618..87c7b71a967 100644
--- a/gcc/po/ChangeLog
+++ b/gcc/po/ChangeLog
@@ -1,3 +1,9 @@
+2024-08-02  Joseph Myers  <josmyers@redhat.com>
+
+	* be.po, da.po, de.po, el.po, es.po, fi.po, fr.po, hr.po, id.po,
+	ja.po, nl.po, ru.po, sr.po, sv.po, tr.po, uk.po, vi.po, zh_CN.po,
+	zh_TW.po: Update.
+
 2024-08-01  Release Manager
 
 	* GCC 14.2.0 released.
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 794d365f469..e83dbd1caf0 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,63 @@
+2024-08-02  Andrew Pinski  <quic_apinski@quicinc.com>
+
+	PR tree-optimization/116156
+	* c-c++-common/torture/pr116156-1.c: New test.
+
+2024-08-02  liuhongt  <hongtao.liu@intel.com>
+
+	Backported from master:
+	2024-07-30  liuhongt  <hongtao.liu@intel.com>
+
+	* gcc.target/i386/pr116043.c: New test.
+
+2024-08-02  Haochen Jiang  <haochen.jiang@intel.com>
+
+	* gcc.target/i386/prefetchi-1b.c: New test.
+
+2024-08-02  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2024-07-29  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/88313
+	* g++.dg/cpp2a/lambda-targ6.C: New test.
+
+2024-08-02  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2024-07-25  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/115897
+	* g++.dg/cpp0x/alias-decl-78.C: New test.
+	* g++.dg/cpp0x/alias-decl-79.C: New test.
+	* g++.dg/cpp0x/alias-decl-pr92206-1a.C: New test.
+
+2024-08-02  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2024-07-23  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/115656
+	* g++.dg/cpp2a/concepts-ttp7.C: New test.
+
+2024-08-02  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2024-07-23  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/115296
+	* g++.dg/cpp2a/class-deduction-alias23.C: New test.
+
+2024-08-02  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2024-07-18  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/112288
+	* g++.dg/template/friend80.C: New test.
+	* g++.dg/template/friend81.C: New test.
+	* g++.dg/template/friend81a.C: New test.
+
 2024-08-01  Jakub Jelinek  <jakub@redhat.com>
 
 	Backported from master:
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index 5687e8fc11a..e09d38cc31c 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,18 @@
+2024-08-02  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2024-07-25  Patrick Palka  <ppalka@redhat.com>
+
+	PR libstdc++/116038
+	* include/std/functional (_Bind_front::operator()): Use __like_t
+	instead of std::forward when forwarding __self.
+	(_Bind_back::operator()): Likewise.
+	* include/std/ranges (_Partial::operator()): Likewise.
+	(_Pipe::operator()): Likewise.
+	* testsuite/20_util/function_objects/bind_back/116038.cc: New test.
+	* testsuite/20_util/function_objects/bind_front/116038.cc: New test.
+	* testsuite/std/ranges/adaptors/116038.cc: New test.
+
 2024-08-01  Jonathan Wakely  <jwakely@redhat.com>
 
 	Backported from master:

commit c3866651a2a4623ebca544391051d3f69f141110
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Thu Jun 20 14:28:08 2024

    libstdc++: Fix __cpp_lib_chrono for old std::string ABI
    
    The <chrono> header is incomplete for the old std::string ABI, because
    std::chrono::tzdb is only defined for the new ABI. The feature test
    macro advertising full C++20 support should not be defined for the old
    ABI.
    
    libstdc++-v3/ChangeLog:
    
            * include/bits/version.def (chrono): Add cxx11abi = yes.
            * include/bits/version.h: Regenerate.
            * testsuite/std/time/syn_c++20.cc: Adjust expected value for
            the feature test macro.
    
    (cherry picked from commit f906b107634bfac29676e7fcf364d0ca7ceed666)

diff --git a/libstdc++-v3/include/bits/version.def b/libstdc++-v3/include/bits/version.def
index e5f4c4c13c0..72e38d4d712 100644
--- a/libstdc++-v3/include/bits/version.def
+++ b/libstdc++-v3/include/bits/version.def
@@ -574,6 +574,7 @@ ftms = {
     v = 201907;
     cxxmin = 20;
     hosted = yes;
+    cxx11abi = yes; // std::chrono::tzdb requires cxx11 std::string
   };
   values = {
     v = 201611;
diff --git a/libstdc++-v3/include/bits/version.h b/libstdc++-v3/include/bits/version.h
index ad418d46664..f6b265d8ffb 100644
--- a/libstdc++-v3/include/bits/version.h
+++ b/libstdc++-v3/include/bits/version.h
@@ -639,7 +639,7 @@
 #undef __glibcxx_want_boyer_moore_searcher
 
 #if !defined(__cpp_lib_chrono)
-# if (__cplusplus >= 202002L) && _GLIBCXX_HOSTED
+# if (__cplusplus >= 202002L) && _GLIBCXX_USE_CXX11_ABI && _GLIBCXX_HOSTED
 #  define __glibcxx_chrono 201907L
 #  if defined(__glibcxx_want_all) || defined(__glibcxx_want_chrono)
 #   define __cpp_lib_chrono 201907L
diff --git a/libstdc++-v3/testsuite/std/time/syn_c++20.cc b/libstdc++-v3/testsuite/std/time/syn_c++20.cc
index f0b86199e9d..4a527262e9d 100644
--- a/libstdc++-v3/testsuite/std/time/syn_c++20.cc
+++ b/libstdc++-v3/testsuite/std/time/syn_c++20.cc
@@ -20,9 +20,16 @@
 
 #include <chrono>
 
+// std::chrono::tzdb is not defined for the old std::string ABI.
+#if _GLIBCXX_USE_CXX_ABI
+# define EXPECTED_VALUE 201907L
+#else
+# define EXPECTED_VALUE 201611L
+#endif
+
 #ifndef __cpp_lib_chrono
 # error "Feature test macro for chrono is missing in <chrono>"
-#elif __cpp_lib_chrono < 201907L
+#elif __cpp_lib_chrono < EXPECTED_VALUE
 # error "Feature test macro for chrono has wrong value in <chrono>"
 #endif
 
@@ -94,7 +101,7 @@ namespace __gnu_test
   using std::chrono::make12;
   using std::chrono::make24;
 
-#if _GLIBCXX_USE_CXX11_ABI
+#if __cpp_lib_chrono >= 201803L
   using std::chrono::tzdb;
   using std::chrono::tzdb_list;
   using std::chrono::get_tzdb;

commit 80a64e6c577ffe58e32ec9a1dd39ffb5fb467e4a
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Sun Aug 4 02:20:46 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 613753ee8b5..444c7cbae43 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240803
+20240804
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index e09d38cc31c..f05ec03c85e 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,13 @@
+2024-08-03  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-06-21  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/bits/version.def (chrono): Add cxx11abi = yes.
+	* include/bits/version.h: Regenerate.
+	* testsuite/std/time/syn_c++20.cc: Adjust expected value for
+	the feature test macro.
+
 2024-08-02  Patrick Palka  <ppalka@redhat.com>
 
 	Backported from master:

commit 5103ee74691b14fc26b14dc057e98cb3d30fac33
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Mon Aug 5 02:20:59 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 444c7cbae43..25c46364131 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240804
+20240805

commit eccf707e5ceb7e405ffe4edfbcae2f769b8386cf
Author: Christoph Müllner <christoph.muellner@vrull.eu>
Date:   Wed Jul 24 14:10:01 2024

    RISC-V: xtheadmemidx: Fix mode test for pre/post-modify addressing
    
    auto_inc_dec (-O3) performs optimizations like the following
    if RVV and XTheadMemIdx is enabled.
    
    (insn 23 20 27 3 (set (mem:V4QI (reg:DI 136 [ ivtmp.13 ]) [0 MEM <vector(4) char> [(char *)_39]+0 S4 A32])
            (reg:V4QI 168)) "gcc/testsuite/gcc.target/riscv/pr116033.c":12:27 3183 {*movv4qi}
         (nil))
    (insn 40 39 41 3 (set (reg:DI 136 [ ivtmp.13 ])
            (plus:DI (reg:DI 136 [ ivtmp.13 ])
                (const_int 20 [0x14]))) 5 {adddi3}
         (nil))
    ====>
    (insn 23 20 27 3 (set (mem:V4QI (post_modify:DI (reg:DI 136 [ ivtmp.13 ])
                    (plus:DI (reg:DI 136 [ ivtmp.13 ])
                        (const_int 20 [0x14]))) [0 MEM <vector(4) char> [(char *)_39]+0 S4 A32])
            (reg:V4QI 168)) "gcc/testsuite/gcc.target/riscv/pr116033.c":12:27 3183 {*movv4qi}
         (expr_list:REG_INC (reg:DI 136 [ ivtmp.13 ])
            (nil)))
    
    The reason why the pass believes that this is legal is,
    that the mode test in th_memidx_classify_address_modify()
    requires INTEGRAL_MODE_P (mode), which includes vector modes.
    
    Let's restrict the mode test such, that only MODE_INT is allowed.
    
            PR target/116033
    
    gcc/ChangeLog:
    
            * config/riscv/thead.cc (th_memidx_classify_address_modify):
            Fix mode test.
    
    gcc/testsuite/ChangeLog:
    
            * gcc.target/riscv/pr116033.c: New test.
    
    (cherry picked from commit a86c0cb9379e7b86625908a0250cf698276e9e02)
    Reported-by: Patrick O'Neill <patrick@rivosinc.com>
    Signed-off-by: Christoph Müllner <christoph.muellner@vrull.eu>

diff --git a/gcc/config/riscv/thead.cc b/gcc/config/riscv/thead.cc
index 951b6088859..6f5edeb7e0a 100644
--- a/gcc/config/riscv/thead.cc
+++ b/gcc/config/riscv/thead.cc
@@ -453,10 +453,8 @@ th_memidx_classify_address_modify (struct riscv_address_info *info, rtx x,
   if (!TARGET_XTHEADMEMIDX)
     return false;
 
-  if (!TARGET_64BIT && mode == DImode)
-    return false;
-
-  if (!(INTEGRAL_MODE_P (mode) && GET_MODE_SIZE (mode).to_constant () <= 8))
+  if (GET_MODE_CLASS (mode) != MODE_INT
+      || GET_MODE_SIZE (mode).to_constant () > UNITS_PER_WORD)
     return false;
 
   if (GET_CODE (x) != POST_MODIFY
diff --git a/gcc/testsuite/gcc.target/riscv/pr116033.c b/gcc/testsuite/gcc.target/riscv/pr116033.c
new file mode 100644
index 00000000000..881922da026
--- /dev/null
+++ b/gcc/testsuite/gcc.target/riscv/pr116033.c
@@ -0,0 +1,16 @@
+/* { dg-do compile } */
+/* { dg-skip-if "" { *-*-* } { "-O0" "-O1" "-Og" "-Os" "-Oz" } } */
+/* { dg-options "-march=rv64gv_xtheadmemidx" { target { rv64 } } } */
+/* { dg-options "-march=rv32gv_xtheadmemidx" { target { rv32 } } } */
+
+char arr_3[20][20];
+void init()
+{
+  for (int i_0 = 0; i_0 < 20; ++i_0)
+    for (int i_1 = 0; i_0 < 20; ++i_0)
+      for (int i_1 = 0; i_1 < 20; ++i_0)
+        for (int i_1 = 0; i_1 < 20; ++i_1)
+          arr_3[i_0][i_1] = i_1;
+}
+
+/* { dg-final { scan-assembler-not "vse8.v\t\[a-x0-9\]+,\\(\[a-x0-9\]+\\),\[0-9\]+,\[0-9\]+" } } */

commit daced7625e606228e64284f2a1d0b1dec1a83965
Author: Joseph Myers <josmyers@redhat.com>
Date:   Mon Aug 5 18:34:13 2024

    Update gcc fr.po
    
            * fr.po: Update.

diff --git a/gcc/po/fr.po b/gcc/po/fr.po
index c14d5719b71..149d4c098cc 100644
--- a/gcc/po/fr.po
+++ b/gcc/po/fr.po
@@ -97,10 +97,10 @@
 #
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 14.1.0\n"
+"Project-Id-Version: gcc 14.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
 "POT-Creation-Date: 2024-07-25 16:23+0000\n"
-"PO-Revision-Date: 2024-05-09 14:43+0200\n"
+"PO-Revision-Date: 2024-08-03 07:39+0200\n"
 "Last-Translator: Frédéric Marchal <fmarchal@perso.be>\n"
 "Language-Team: French <traduc@traduc.org>\n"
 "Language: fr\n"
@@ -37329,16 +37329,14 @@ msgid "comparison between two arrays"
 msgstr "comparaison entre deux tableaux"
 
 #: c-family/c-warn.cc:3832
-#, fuzzy, gcc-internal-format
-#| msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+#, gcc-internal-format
 msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
-msgstr "utiliser le %<+%> unaire qui dégrade les opérandes vers des pointeurs ou %<&%D[0] %s &%D[0]%> pour comparer les adresses"
+msgstr "utiliser le %<+%> unaire qui dégrade les opérandes vers des pointeurs ou %<&%s%E%s[0] %s &%s%E%s[0]%> pour comparer les adresses"
 
 #: c-family/c-warn.cc:3839
-#, fuzzy, gcc-internal-format
-#| msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+#, gcc-internal-format
 msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
-msgstr "utilisez %<&%D[0] %s &%D[0]%> pour comparer les adresses"
+msgstr "utilisez %<&%s%E%s[0] %s &%s%E%s[0]%> pour comparer les adresses"
 
 #: c-family/c-warn.cc:3901
 #, gcc-internal-format
@@ -43357,28 +43355,24 @@ msgid "capture by copy of RVV type %qT"
 msgstr "capture par copie du type RVV %qT"
 
 #: config/riscv/riscv-vector-builtins.cc:4645
-#, fuzzy, gcc-internal-format
-#| msgid "built-in function %qE requires the %qs ISA extension"
+#, gcc-internal-format
 msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
-msgstr "la fonction interne %qE requiert l'extension ISA %qs"
+msgstr "la fonction interne %qE requiert l'extension ISA zvfhmin ou zvfh"
 
 #: config/riscv/riscv-vector-builtins.cc:4655
-#, fuzzy, gcc-internal-format
-#| msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
+#, gcc-internal-format
 msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
-msgstr "%s %qT requiert l'extension ISA zve32f, zve64f, zve64d ou v"
+msgstr "la fonction interne %qE requiert l'extension ISA zve32f, zve64f, zve64d ou v"
 
 #: config/riscv/riscv-vector-builtins.cc:4665
-#, fuzzy, gcc-internal-format
-#| msgid "built-in function %qE requires the %qs ISA extension"
+#, gcc-internal-format
 msgid "built-in function %qE requires the zve64d or v ISA extension"
-msgstr "la fonction interne %qE requiert l'extension ISA %qs"
+msgstr "la fonction interne %qE requiert l'extension ISA zve64d ou v"
 
 #: config/riscv/riscv-vector-builtins.cc:4674
-#, fuzzy, gcc-internal-format
-#| msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
+#, gcc-internal-format
 msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
-msgstr "%s %qT requiert l'extension ISA zve64x, zve64f, zve64d ou v"
+msgstr "la fonction interne %qE requiert l'extension ISA zve64x, zve64f, zve64d ou v"
 
 #: config/riscv/riscv-vector-builtins.cc:4694
 #, gcc-internal-format
@@ -44004,13 +43998,12 @@ msgstr "option inconnue pour %<%s=%s%>"
 #: config/rs6000/rs6000.cc:4833
 #, gcc-internal-format
 msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
-msgstr ""
+msgstr "%<-mrop-protect%> requiert %<-mcpu=power8%> ou ultérieur"
 
 #: config/rs6000/rs6000.cc:4837
-#, fuzzy, gcc-internal-format
-#| msgid "%qs requires the ELFv2 ABI"
+#, gcc-internal-format
 msgid "%<-mrop-protect%> requires the ELFv2 ABI"
-msgstr "%qs exige l'ABI ELFv2"
+msgstr "%<-mrop-protect%> exige l'ABI ELFv2"
 
 #: config/rs6000/rs6000.cc:4855
 #, gcc-internal-format
@@ -59409,54 +59402,46 @@ msgid "declaration %qD conflicts with builtin"
 msgstr "la déclaration %qD est en conflit avec la fonction interne"
 
 #: cp/module.cc:19122
-#, fuzzy, gcc-internal-format
-#| msgid "declaration %qD conflicts with import"
+#, gcc-internal-format
 msgid "redeclaring %qD in module %qs conflicts with import"
-msgstr "la déclaration %qD est en conflit avec l'import"
+msgstr "la redéclaration %qD dans le module %qs est en conflit avec l'import"
 
 #: cp/module.cc:19125
-#, fuzzy, gcc-internal-format
-#| msgid "declaration %qD conflicts with import"
+#, gcc-internal-format
 msgid "redeclaring %qD in global module conflicts with import"
-msgstr "la déclaration %qD est en conflit avec l'import"
+msgstr "la redéclaration %qD dans le module global est en conflit avec l'import"
 
 #: cp/module.cc:19130
-#, fuzzy, gcc-internal-format
-#| msgid "import declared %q#D here"
+#, gcc-internal-format
 msgid "import declared attached to module %qs"
-msgstr "l'import a déclaré %q#D ici"
+msgstr "l'import est déclaré comme étant attaché au module %qs"
 
 #: cp/module.cc:19134
-#, fuzzy, gcc-internal-format
-#| msgid "import-declaration must be at global scope"
+#, gcc-internal-format
 msgid "import declared in global module"
-msgstr "la déclaration d'import doit être dans la portée globale"
+msgstr "l'import est déclaré dans le module global"
 
 #: cp/module.cc:19140
-#, fuzzy, gcc-internal-format
-#| msgid "conflicting declaration of template %q#D"
+#, gcc-internal-format
 msgid "conflicting declaration of %qD in module %qs"
-msgstr "déclaration conflictuelle du patron %q#D"
+msgstr "déclaration conflictuelle de %qD dans le module %qs"
 
 #: cp/module.cc:19143
-#, fuzzy, gcc-internal-format
-#| msgid "conflicting declaration of %q#D with %qL linkage"
+#, gcc-internal-format
 msgid "conflicting declaration of %qD in global module"
-msgstr "déclaration conflictuelle de %q#D avec la classe de liaison %qL"
+msgstr "déclaration conflictuelle de %qD dans le module global"
 
 # la phrase fait référence à une variable ou une fonction (cf les deux messages ci-dessus) d'où le féminin
 #: cp/module.cc:19148
-#, fuzzy, gcc-internal-format
-#| msgid "previously declared as %s"
+#, gcc-internal-format
 msgid "previously declared in module %qs"
-msgstr "précédemment déclarée comme %s"
+msgstr "précédemment déclarée dans le module %qs"
 
 # la phrase fait référence à une variable ou une fonction (cf les deux messages ci-dessus) d'où le féminin
 #: cp/module.cc:19152
-#, fuzzy, gcc-internal-format
-#| msgid "previously declared as %s"
+#, gcc-internal-format
 msgid "previously declared in global module"
-msgstr "précédemment déclarée comme %s"
+msgstr "précédemment déclaré dans le module global"
 
 # le %qs est un nom de région non traduit tel que « parallel », « task », « teams ».
 #: cp/module.cc:19404
@@ -73289,7 +73274,7 @@ msgstr "check_charlen_present(): longueur non définie"
 #: fortran/iresolve.cc:3029
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
-msgstr ""
+msgstr "TODO: MOLD polymorphique illimité dans l'intrinsèque TRANSFER à %L"
 
 #: fortran/match.cc:118
 #, gcc-internal-format
@@ -78642,10 +78627,9 @@ msgid "Using variable %qs at %L is deprecated"
 msgstr "L'utilisation de la variable %qs à %L est obsolète"
 
 #: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Bad array reference at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Invalid array reference at %L"
-msgstr "Mauvaise référence à un tableau à %L"
+msgstr "Référence invalide à un tableau à %L"
 
 #: fortran/resolve.cc:6433
 #, gcc-internal-format

commit 9906a9863d65386ee4045333eb26a2569783abb5
Author: Paul Thomas <pault@gcc.gnu.org>
Date:   Thu Jul 18 09:51:35 2024

    Fortran: Suppress bogus used uninitialized warnings [PR108889].
    
    2024-07-18  Paul Thomas  <pault@gcc.gnu.org>
    
    gcc/fortran
            PR fortran/108889
            * gfortran.h: Add bit field 'allocated_in_scope' to gfc_symbol.
            * trans-array.cc (gfc_array_allocate): Set 'allocated_in_scope'
            after allocation if not a component reference.
            (gfc_alloc_allocatable_for_assignment): If 'allocated_in_scope'
            not set, not a component ref and not allocated, set the array
            bounds and offset to give zero length in all dimensions. Then
            set allocated_in_scope.
    
    gcc/testsuite/
            PR fortran/108889
            * gfortran.dg/pr108889.f90: New test.
    
    (cherry picked from commit c3aa339ea50f050caf7ed2e497f5499ec2d7b9cc)

diff --git a/gcc/fortran/gfortran.h b/gcc/fortran/gfortran.h
index de3d9e25911..fbdf00590bc 100644
--- a/gcc/fortran/gfortran.h
+++ b/gcc/fortran/gfortran.h
@@ -1946,6 +1946,10 @@ typedef struct gfc_symbol
   /* Set if this should be passed by value, but is not a VALUE argument
      according to the Fortran standard.  */
   unsigned pass_as_value:1;
+  /* Set if an allocatable array variable has been allocated in the current
+     scope. Used in the suppression of uninitialized warnings in reallocation
+     on assignment.  */
+  unsigned allocated_in_scope:1;
 
   /* Reference counter, used for memory management.
 
diff --git a/gcc/fortran/trans-array.cc b/gcc/fortran/trans-array.cc
index 761f0a42507..d5d9c730826 100644
--- a/gcc/fortran/trans-array.cc
+++ b/gcc/fortran/trans-array.cc
@@ -6561,6 +6561,8 @@ gfc_array_allocate (gfc_se * se, gfc_expr * expr, tree status, tree errmsg,
   else
       gfc_add_expr_to_block (&se->pre, set_descriptor);
 
+  expr->symtree->n.sym->allocated_in_scope = 1;
+
   return true;
 }
 
@@ -10932,6 +10934,8 @@ gfc_alloc_allocatable_for_assignment (gfc_loopinfo *loop,
   stmtblock_t realloc_block;
   stmtblock_t alloc_block;
   stmtblock_t fblock;
+  stmtblock_t loop_pre_block;
+  gfc_ref *ref;
   gfc_ss *rss;
   gfc_ss *lss;
   gfc_array_info *linfo;
@@ -11132,6 +11136,45 @@ gfc_alloc_allocatable_for_assignment (gfc_loopinfo *loop,
 			 array1, build_int_cst (TREE_TYPE (array1), 0));
   cond_null= gfc_evaluate_now (cond_null, &fblock);
 
+  /* If the data is null, set the descriptor bounds and offset. This suppresses
+     the maybe used uninitialized warning and forces the use of malloc because
+     the size is zero in all dimensions. Note that this block is only executed
+     if the lhs is unallocated and is only applied once in any namespace.
+     Component references are not subject to the warnings.  */
+  for (ref = expr1->ref; ref; ref = ref->next)
+    if (ref->type == REF_COMPONENT)
+      break;
+
+  if (!expr1->symtree->n.sym->allocated_in_scope && !ref)
+    {
+      gfc_start_block (&loop_pre_block);
+      for (n = 0; n < expr1->rank; n++)
+	{
+	  gfc_conv_descriptor_lbound_set (&loop_pre_block, desc,
+					  gfc_rank_cst[n],
+					  gfc_index_one_node);
+	  gfc_conv_descriptor_ubound_set (&loop_pre_block, desc,
+					  gfc_rank_cst[n],
+					  gfc_index_zero_node);
+	  gfc_conv_descriptor_stride_set (&loop_pre_block, desc,
+					  gfc_rank_cst[n],
+					  gfc_index_zero_node);
+	}
+
+      tmp = gfc_conv_descriptor_offset (desc);
+      gfc_add_modify (&loop_pre_block, tmp, gfc_index_zero_node);
+
+      tmp = fold_build2_loc (input_location, EQ_EXPR,
+			     logical_type_node, array1,
+			     build_int_cst (TREE_TYPE (array1), 0));
+      tmp = build3_v (COND_EXPR, tmp,
+		      gfc_finish_block (&loop_pre_block),
+		      build_empty_stmt (input_location));
+      gfc_prepend_expr_to_block (&loop->pre, tmp);
+
+      expr1->symtree->n.sym->allocated_in_scope = 1;
+    }
+
   tmp = build3_v (COND_EXPR, cond_null,
 		  build1_v (GOTO_EXPR, jump_label1),
 		  build_empty_stmt (input_location));
diff --git a/gcc/testsuite/gfortran.dg/pr108889.f90 b/gcc/testsuite/gfortran.dg/pr108889.f90
new file mode 100644
index 00000000000..7fd4e3882a4
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/pr108889.f90
@@ -0,0 +1,43 @@
+! { dg-do compile }
+! { dg-options "-Wall -fdump-tree-original" }
+!
+! Contributed by Tobias Burnus  <burnus@gcc.gnu.org>
+!
+program main
+  implicit none
+
+  type :: struct
+    real, allocatable :: var(:)
+  end type struct
+
+  type(struct) :: single
+  real, allocatable :: ref1(:), ref2(:), ref3(:), ref4(:)
+
+  ref2 = [1,2,3,4,5]    ! Warnings here
+
+  single%var = ref2     ! No warnings for components
+  ref1 = single%var     ! Warnings here
+  ref1 = [1,2,3,4,5]    ! Should not add to tree dump count
+
+  allocate (ref3(5))
+  ref3 = single%var     ! No warnings following allocation
+
+  call set_ref4
+
+  call test (ref1)
+  call test (ref2)
+  call test (ref3)
+  call test (ref4)
+
+contains
+  subroutine test (arg)
+    real, allocatable :: arg(:)
+    if (size(arg) /= size(single%var)) stop 1
+    if (lbound(arg, 1) /= 1) stop 2
+    if (any (arg /= single%var)) stop 3
+  end
+  subroutine set_ref4
+    ref4 = single%var   ! Warnings in contained scope
+  end
+end
+! { df-final { scan-tree-dump-times "ubound = 0" 3 "original" } }
\ No newline at end of file

commit 2405d29086d5045821b1a7260b589fbae1e6f05a
Author: Paul Thomas <pault@gcc.gnu.org>
Date:   Fri Jul 19 17:58:33 2024

    libgomp: Remove bogus warnings from privatized-ref-2.f90.
    
    2024-07-19  Paul Thomas  <pault@gcc.gnu.org>
    
    libgomp/ChangeLog
    
            * testsuite/libgomp.oacc-fortran/privatized-ref-2.f90: Cut
            dg-note about 'a' and remove bogus warnings about its array
            descriptor components being used uninitialized.
    
    (cherry picked from commit 8d6994f33a98a168151a57a3d21395b19196cd9d)

diff --git a/libgomp/testsuite/libgomp.oacc-fortran/privatized-ref-2.f90 b/libgomp/testsuite/libgomp.oacc-fortran/privatized-ref-2.f90
index 498ef70b63a..8cf79a10e8d 100644
--- a/libgomp/testsuite/libgomp.oacc-fortran/privatized-ref-2.f90
+++ b/libgomp/testsuite/libgomp.oacc-fortran/privatized-ref-2.f90
@@ -29,16 +29,10 @@ program main
   implicit none (type, external)
   integer :: j
   integer, allocatable :: A(:)
-  ! { dg-note {'a' declared here} {} { target *-*-* } .-1 }
   character(len=:), allocatable :: my_str
   character(len=15), allocatable :: my_str15
 
   A = [(3*j, j=1, 10)]
-  ! { dg-bogus {'a\.offset' is used uninitialized} {PR77504 etc.} { xfail *-*-* } .-1 }
-  ! { dg-bogus {'a\.dim\[0\]\.lbound' is used uninitialized} {PR77504 etc.} { xfail *-*-* } .-2 }
-  ! { dg-bogus {'a\.dim\[0\]\.ubound' is used uninitialized} {PR77504 etc.} { xfail *-*-* } .-3 }
-  ! { dg-bogus {'a\.dim\[0\]\.lbound' may be used uninitialized} {PR77504 etc.} { xfail { ! __OPTIMIZE__ } } .-4 }
-  ! { dg-bogus {'a\.dim\[0\]\.ubound' may be used uninitialized} {PR77504 etc.} { xfail { ! __OPTIMIZE__ } } .-5 }
   call foo (A, size(A))
   call bar (A)
   my_str = "1234567890"

commit de738988ff62b76e433f2fce570fcd8ab4b16c07
Author: Ian Lance Taylor <iant@golang.org>
Date:   Tue Aug 6 01:07:12 2024

    compiler: panic arguments are empty interface type
    
    After CL 536643 passing NULL as the expected type permitted an untyped
    constant expression to remain untyped. Change to passing the empty
    interface type.
    
    The panic and print/println functions are the only builtin functions
    that turn an untyped constant expression into a regular function call,
    and we already handled print/println specially.
    
    The test case is https://go.dev/cl/603096.
    
    Fixes golang/go#68734
    
    Reviewed-on: https://go-review.googlesource.com/c/gofrontend/+/603215

diff --git a/gcc/go/gofrontend/expressions.cc b/gcc/go/gofrontend/expressions.cc
index 238d5a56ca2..2b0e40fc6f8 100644
--- a/gcc/go/gofrontend/expressions.cc
+++ b/gcc/go/gofrontend/expressions.cc
@@ -11137,6 +11137,12 @@ Builtin_call_expression::do_determine_type(Gogo* gogo,
       is_print = false;
       break;
 
+    case BUILTIN_PANIC:
+      arg_type =
+	Type::make_empty_interface_type(Linemap::predeclared_location());
+      is_print = false;
+      break;
+
     case BUILTIN_PRINT:
     case BUILTIN_PRINTLN:
       // Do not force a large integer constant to "int".

commit c5ef3b94e448e447d1e227ab1a22467f06071a55
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Tue Aug 6 02:22:27 2024

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 6262ca6d8d4..d043a7896f9 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,12 @@
+2024-08-05  Christoph Müllner  <christoph.muellner@vrull.eu>
+
+	Backported from master:
+	2024-07-25  Christoph Müllner  <christoph.muellner@vrull.eu>
+
+	PR target/116033
+	* config/riscv/thead.cc (th_memidx_classify_address_modify):
+	Fix mode test.
+
 2024-08-02  Andrew Pinski  <quic_apinski@quicinc.com>
 
 	PR tree-optimization/116156
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 25c46364131..f2c439e6ce5 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240805
+20240806
diff --git a/gcc/fortran/ChangeLog b/gcc/fortran/ChangeLog
index 1f0887f1a99..04d5d211b70 100644
--- a/gcc/fortran/ChangeLog
+++ b/gcc/fortran/ChangeLog
@@ -1,3 +1,17 @@
+2024-08-05  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from master:
+	2024-07-18  Paul Thomas  <pault@gcc.gnu.org>
+
+	PR fortran/108889
+	* gfortran.h: Add bit field 'allocated_in_scope' to gfc_symbol.
+	* trans-array.cc (gfc_array_allocate): Set 'allocated_in_scope'
+	after allocation if not a component reference.
+	(gfc_alloc_allocatable_for_assignment): If 'allocated_in_scope'
+	not set, not a component ref and not allocated, set the array
+	bounds and offset to give zero length in all dimensions. Then
+	set allocated_in_scope.
+
 2024-08-01  Release Manager
 
 	* GCC 14.2.0 released.
diff --git a/gcc/po/ChangeLog b/gcc/po/ChangeLog
index 87c7b71a967..1be188ad53c 100644
--- a/gcc/po/ChangeLog
+++ b/gcc/po/ChangeLog
@@ -1,3 +1,7 @@
+2024-08-05  Joseph Myers  <josmyers@redhat.com>
+
+	* fr.po: Update.
+
 2024-08-02  Joseph Myers  <josmyers@redhat.com>
 
 	* be.po, da.po, de.po, el.po, es.po, fi.po, fr.po, hr.po, id.po,
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index e83dbd1caf0..0c272ccfa71 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,19 @@
+2024-08-05  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from master:
+	2024-07-18  Paul Thomas  <pault@gcc.gnu.org>
+
+	PR fortran/108889
+	* gfortran.dg/pr108889.f90: New test.
+
+2024-08-05  Christoph Müllner  <christoph.muellner@vrull.eu>
+
+	Backported from master:
+	2024-07-25  Christoph Müllner  <christoph.muellner@vrull.eu>
+
+	PR target/116033
+	* gcc.target/riscv/pr116033.c: New test.
+
 2024-08-02  Andrew Pinski  <quic_apinski@quicinc.com>
 
 	PR tree-optimization/116156
diff --git a/libgomp/ChangeLog b/libgomp/ChangeLog
index 43f5ce0f674..1c4e2385c0f 100644
--- a/libgomp/ChangeLog
+++ b/libgomp/ChangeLog
@@ -1,3 +1,12 @@
+2024-08-05  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from master:
+	2024-07-19  Paul Thomas  <pault@gcc.gnu.org>
+
+	* testsuite/libgomp.oacc-fortran/privatized-ref-2.f90: Cut
+	dg-note about 'a' and remove bogus warnings about its array
+	descriptor components being used uninitialized.
+
 2024-08-01  Release Manager
 
 	* GCC 14.2.0 released.

commit ba45573c8072f06f67af22a2ca60da5f5c12beae
Author: Andrew Pinski <quic_apinski@quicinc.com>
Date:   Sat Aug 3 18:30:57 2024

    sh: Don't call make_insn_raw in sh_recog_treg_set_expr [PR116189]
    
    This was an interesting compare debug failure to debug. The first symptom
    was in gcse which would produce different order of creating psedu-registers. This
    was caused by a different order of a hashtable walk, due to the hash table having different
    number of entries. Which in turn was due to the number of max insn being different between
    the 2 runs. The place max insn uid comes from was in sh_recog_treg_set_expr which is called
    via rtx_costs and fwprop would cause rtx_costs in some cases for debug insn related stuff.
    
    Build and tested for sh4-linux-gnu.
    
            PR target/116189
    
    gcc/ChangeLog:
    
            * config/sh/sh.cc (sh_recog_treg_set_expr): Don't call make_insn_raw,
            make the insn with a fake uid.
    
    gcc/testsuite/ChangeLog:
    
            * c-c++-common/torture/pr116189-1.c: New test.
    
    Signed-off-by: Andrew Pinski <quic_apinski@quicinc.com>
    (cherry picked from commit 0355c943b9e954e8f59068971d934f1b91ecb729)

diff --git a/gcc/config/sh/sh.cc b/gcc/config/sh/sh.cc
index ef3c2e6791d..d6a6e5bd88d 100644
--- a/gcc/config/sh/sh.cc
+++ b/gcc/config/sh/sh.cc
@@ -12279,7 +12279,17 @@ sh_recog_treg_set_expr (rtx op, machine_mode mode)
      have to capture its current state and restore it afterwards.  */
   recog_data_d prev_recog_data = recog_data;
 
-  rtx_insn* i = make_insn_raw (gen_rtx_SET (get_t_reg_rtx (), op));
+  /* Note we can't use insn_raw here since that increases the uid
+     and could cause debug compare differences; this insn never leaves
+     this function so create a dummy one. */
+  rtx_insn* i = as_a <rtx_insn *> (rtx_alloc (INSN));
+
+  INSN_UID (i) = 1;
+  PATTERN (i) = gen_rtx_SET (get_t_reg_rtx (), op);
+  INSN_CODE (i) = -1;
+  REG_NOTES (i) = NULL;
+  INSN_LOCATION (i) = curr_insn_location ();
+  BLOCK_FOR_INSN (i) = NULL;
   SET_PREV_INSN (i) = NULL;
   SET_NEXT_INSN (i) = NULL;
 
diff --git a/gcc/testsuite/c-c++-common/torture/pr116189-1.c b/gcc/testsuite/c-c++-common/torture/pr116189-1.c
new file mode 100644
index 00000000000..055c563f43e
--- /dev/null
+++ b/gcc/testsuite/c-c++-common/torture/pr116189-1.c
@@ -0,0 +1,30 @@
+/* { dg-additional-options "-fcompare-debug" } */
+
+/* PR target/116189 */
+
+/* In the sh backend, we used to create insn in the path of rtx_costs.
+   This means sometimes the max uid for insns would be different between
+   debugging and non debugging which then would cause gcse's hashtable
+   to have different number of slots which would cause a different walk
+   for that hash table.  */
+
+extern void ff(void);
+extern short nn[8][4];
+typedef unsigned short move_table[4];
+extern signed long long ira_overall_cost;
+extern signed long long ira_load_cost;
+extern move_table *x_ira_register_move_cost[1];
+struct move { struct move *next; };
+unsigned short t;
+void emit_move_list(struct move * list, int freq, unsigned char mode, int regno) {
+  int cost;
+  for (; list != 0; list = list->next)
+  {
+    ff();
+    unsigned short aclass = t;
+    cost = (nn)[mode][aclass] ;
+    ira_load_cost = cost;
+    cost = x_ira_register_move_cost[mode][aclass][aclass] * freq ;
+    ira_overall_cost = cost;
+  }
+}

commit cad2693096cd2395409aada5c26b56e3aeb6e849
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Thu Aug 1 20:23:15 2024

    fortran: Fix up pasto in gfc_get_array_descr_info
    
    A static analyzer found a pasto in gfc_get_array_descr_info.
    The code does
          t = base_decl;
          if (!integer_zerop (dtype_off))
            t = fold_build_pointer_plus (t, dtype_off);
          dtype = TYPE_MAIN_VARIANT (get_dtype_type_node ());
          field = gfc_advance_chain (TYPE_FIELDS (dtype), GFC_DTYPE_RANK);
          rank_off = byte_position (field);
          if (!integer_zerop (dtype_off))
            t = fold_build_pointer_plus (t, rank_off);
    i.e. uses the same !integer_zerop check between both, while it should
    be checking rank_off in the latter case.
    This actually doesn't change anything on the generated code, because
    both the dtype_off and rank_off aren't zero,
    typedef struct dtype_type
    {
      size_t elem_len;
      int version;
      signed char rank;
      signed char type;
      signed short attribute;
    }
    dtype_type;
    struct {
      type *base_addr;
      size_t offset;
      dtype_type dtype;
      index_type span;
      descriptor_dimension dim[];
    };
    dtype_off is 16 on 64-bit arches and 8 on 32-bit ones and rank_off is
    12 on 64-bit arches and 8 on 32-bit arches, so this patch is just to
    pacify those static analyzers or be prepared if the ABI changes in the
    future.  Because in the current ABI both of those are actually non-zero,
    doing
    if (!integer_zerop (something)) t = fold_build_pointer_plus (t, something);
    actually isn't an optimization, it will consume more compile time.  If
    the ABI changes and we forget to readd it, nothing bad happens,
    fold_build_pointer_plus handles 0 addends fine, just takes some compile
    time to handle that.
    I've kept this if (!integer_zerop (data_off)) guard earlier because
    data_off is 0 in the current ABI, so it is an optimization there.
    
    2024-08-01  Jakub Jelinek  <jakub@redhat.com>
    
            * trans-types.cc (gfc_get_array_descr_info): Don't test if
            !integer_zerop (dtype_off), use fold_build_pointer_plus
            unconditionally.
    
    (cherry picked from commit 90fe402a89910d4fbe0efc15cf05cf6c0306586a)

diff --git a/gcc/fortran/trans-types.cc b/gcc/fortran/trans-types.cc
index 8466c595e06..61523c7d162 100644
--- a/gcc/fortran/trans-types.cc
+++ b/gcc/fortran/trans-types.cc
@@ -3527,14 +3527,11 @@ gfc_get_array_descr_info (const_tree type, struct array_descr_info *info)
     {
       rank = 1;
       info->ndimensions = 1;
-      t = base_decl;
-      if (!integer_zerop (dtype_off))
-	t = fold_build_pointer_plus (t, dtype_off);
+      t = fold_build_pointer_plus (base_decl, dtype_off);
       dtype = TYPE_MAIN_VARIANT (get_dtype_type_node ());
       field = gfc_advance_chain (TYPE_FIELDS (dtype), GFC_DTYPE_RANK);
       rank_off = byte_position (field);
-      if (!integer_zerop (dtype_off))
-	t = fold_build_pointer_plus (t, rank_off);
+      t = fold_build_pointer_plus (t, rank_off);
 
       t = build1 (NOP_EXPR, build_pointer_type (TREE_TYPE (field)), t);
       t = build1 (INDIRECT_REF, TREE_TYPE (field), t);

commit 3fe5720430a9ba61ed7562aac4d758cc77d49a28
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Sat Aug 3 20:37:54 2024

    libquadmath: Fix up libquadmath/math/sqrtq.c compilation in some powerpc* configurations [PR116007]
    
    My PR114623 change started using soft-fp.h and quad.h for the sqrtq implementation.
    Unfortunately, that seems to fail building in some powerpc* configurations, where
    TFmode isn't available.
    quad.h has:
     #ifndef TFtype
     typedef float TFtype __attribute__ ((mode (TF)));
     #endif
    and uses TFtype.  quad.h has:
     /* Define the complex type corresponding to __float128
        ("_Complex __float128" is not allowed) */
     #if (!defined(_ARCH_PPC)) || defined(__LONG_DOUBLE_IEEE128__)
     typedef _Complex float __attribute__((mode(TC))) __complex128;
     #else
     typedef _Complex float __attribute__((mode(KC))) __complex128;
     #endif
    with the conditional and KCmode use added during porting of libquadmath
    to powerpc*, so I've just defined TFtype for powerpc when __LONG_DOUBLE_IEEE128__
    isn't defined; I could define it to float __attribute__ ((mode (KF))) but it
    seemed easier to just define it to __float128 which should do the same thing.
    
    2024-08-03  Jakub Jelinek  <jakub@redhat.com>
    
            PR target/116007
            * math/sqrtq.c (TFtype): For PowerPC without __LONG_DOUBLE_IEEE128__
            define to __float128 before including soft-fp.h and quad.h.
    
    (cherry picked from commit 3ac02e67503ccffa3dfeeffc0a60fce6bdaca43b)

diff --git a/libquadmath/math/sqrtq.c b/libquadmath/math/sqrtq.c
index 8ca2828d42c..a58998a0667 100644
--- a/libquadmath/math/sqrtq.c
+++ b/libquadmath/math/sqrtq.c
@@ -9,6 +9,9 @@
     && defined(FE_TOWARDZERO) \
     && defined(FE_INEXACT)
 #define USE_SOFT_FP 1
+#if defined(_ARCH_PPC) && !defined(__LONG_DOUBLE_IEEE128__)
+#define TFtype __float128
+#endif
 #include "../../libgcc/soft-fp/soft-fp.h"
 #include "../../libgcc/soft-fp/quad.h"
 #endif

commit f2b5ca6be855cede3f0d35d2a1aff08d3c342ac2
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Tue Aug 6 11:09:33 2024

    wide-int: Fix up mul_internal overflow checking [PR116224]
    
    The following testcase is miscompiled, because wi::mul for (_BitInt(65))-15
    times (_BitInt(65))-15 computes the right value (_BitInt(65))225, but
    sets *overflow to wi::OVF_UNKNOWN as that it overflowed when it didn't.
    
    Even signed operands are unpacked as unsigned but because they are
    implicitly sign-extended from the represented value (the operands
    obviously have len==1), we get
    0xfffffff1, 0xffffffff, 0x1, 0x0
    in both u and v (0x1 because that is exactly 65 bits).
    We then multiply these.  Next step is because both the high and
    overflow handling expects the high half to start at a limb boundary
    the bits of the result starting with bit 65 are shifted up by 63 such
    that the bits relevant for high/need_overflow start at the half of the
    4th half wide int limb.
    Because both operands are negative that part is then adjusted.
    
    The reason mul_internal says there is overflow is because of the unspecified
    garbage in the most significant bits of the result which the adjusting
    doesn't clean up.  65 bit multiplication needs 65 bits of result and 65 bits
    of the high part, can't produce more, so the following patch fixes it by
    checking for the overflow only in those first 65 bits of the high part, not
    anything beyond that.  If it was a highpart multiply, we'd have ignored that
    as well (canonicalized).
    
    2024-08-06  Jakub Jelinek  <jakub@redhat.com>
    
            PR tree-optimization/116224
            * wide-int.cc (wi::mul_internal): If prec isn't multiple of
            HOST_BITS_PER_WIDE_INT, for need_overflow checking only look at
            the least significant prec bits starting with r[half_blocks_needed].
    
            * gcc.dg/torture/bitint-72.c: New test.
    
    (cherry picked from commit 69093fd8aa682a1b906e80b3c5f10956e692b7c4)

diff --git a/gcc/testsuite/gcc.dg/torture/bitint-72.c b/gcc/testsuite/gcc.dg/torture/bitint-72.c
new file mode 100644
index 00000000000..101018b00ee
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/torture/bitint-72.c
@@ -0,0 +1,28 @@
+/* PR tree-optimization/116224 */
+/* { dg-do run { target bitint } } */
+/* { dg-options "-std=c23" } */
+/* { dg-skip-if "" { ! run_expensive_tests }  { "*" } { "-O0" "-O2" } } */
+/* { dg-skip-if "" { ! run_expensive_tests } { "-flto" } { "" } } */
+
+#if __BITINT_MAXWIDTH__ >= 65
+#define N 65
+#else
+#define N 63
+#endif
+
+signed char g;
+
+int
+foo (signed char c, int i, _BitInt(N) b)
+{
+  __builtin_memmove (&g, &b, 1);
+  return b / i / c;
+}
+
+int
+main ()
+{
+  int x = foo (-15, -15, 900);
+  if (x != 4)
+    __builtin_abort ();
+}
diff --git a/gcc/wide-int.cc b/gcc/wide-int.cc
index 9c6eba807aa..5bd16a59564 100644
--- a/gcc/wide-int.cc
+++ b/gcc/wide-int.cc
@@ -1574,7 +1574,24 @@ wi::mul_internal (HOST_WIDE_INT *val, const HOST_WIDE_INT *op1val,
 	  top &= mask;
 	}
 
-      for (i = half_blocks_needed; i < half_blocks_needed * 2; i++)
+      unsigned int end = half_blocks_needed * 2;
+      shift = prec % HOST_BITS_PER_WIDE_INT;
+      if (shift)
+	{
+	  /* For overflow checking only look at the first prec bits
+	     starting with r[half_blocks_needed].  */
+	  if (shift <= HOST_BITS_PER_HALF_WIDE_INT)
+	    --end;
+	  shift %= HOST_BITS_PER_HALF_WIDE_INT;
+	  if (shift)
+	    {
+	      if (top)
+		r[end - 1] |= ((~(unsigned HOST_HALF_WIDE_INT) 0) << shift);
+	      else
+		r[end - 1] &= (((unsigned HOST_HALF_WIDE_INT) 1) << shift) - 1;
+	    }
+	}
+      for (i = half_blocks_needed; i < end; i++)
 	if (((HOST_WIDE_INT)(r[i] & mask)) != top)
 	  /* FIXME: Signed overflow type is not implemented yet.  */
 	  *overflow = (sgn == UNSIGNED) ? wi::OVF_OVERFLOW : wi::OVF_UNKNOWN;

commit ba26c471cf6ee760e53836fd4e9bc00250b8b882
Author: John David Anglin <danglin@gcc.gnu.org>
Date:   Tue Aug 6 19:40:26 2024

    hppa: Fix (plus (plus (mult (a) (mem_shadd_constant)) (b)) (c)) optimization
    
    The constant C must be an integral multiple of the shift value in
    the above optimization.  Non integral values can occur evaluating
    IMAGPART_EXPR when the shadd constant is 8 and we have SFmode.
    
    2024-08-06  John David Anglin  <danglin@gcc.gnu.org>
    
    gcc/ChangeLog:
    
            PR target/113384
            * config/pa/pa.cc (hppa_legitimize_address): Add check to
            ensure constant is an integral multiple of shift the value.

diff --git a/gcc/config/pa/pa.cc b/gcc/config/pa/pa.cc
index a7af6b8c121..b24434628fa 100644
--- a/gcc/config/pa/pa.cc
+++ b/gcc/config/pa/pa.cc
@@ -1407,6 +1407,7 @@ hppa_legitimize_address (rtx x, rtx oldx ATTRIBUTE_UNUSED,
       /* If the index adds a large constant, try to scale the
 	 constant so that it can be loaded with only one insn.  */
       if (GET_CODE (XEXP (idx, 1)) == CONST_INT
+	  && INTVAL (XEXP (idx, 1)) % (1 << shift_val) == 0
 	  && VAL_14_BITS_P (INTVAL (XEXP (idx, 1))
 			    / INTVAL (XEXP (XEXP (idx, 0), 1)))
 	  && INTVAL (XEXP (idx, 1)) % INTVAL (XEXP (XEXP (idx, 0), 1)) == 0)

commit 987fc8174026cb3452b63d026cef686f4177526b
Author: Jason Merrill <jason@redhat.com>
Date:   Wed Jul 24 22:20:33 2024

    c++: parse error with -std=c++14 -fconcepts [PR116071]
    
    cp_parser_simple_type_specifier tries a variety of different things that
    might qualify as a user-defined type: an actual type-name, a constrained
    auto, a CTAD placeholder.  In a context where a type-specifier is optional,
    this is all tentative.  With -std=c++14 -fconcepts, we try type-name and
    constrained auto in sub-tentative parses, and when we run out of things to
    try we haven't found anything but also haven't failed the outer tentative
    parse, so parse_definitely succeeds, discarding the nested-name-specifier.
    
    Fixed by failing if we didn't find anything.
    
    I said in r14-3203 that we should disable this combination of flags if
    further problems arise, but this seems like a more general problem that only
    happened to occur with just this combination of flags.  So it lives on.
    
            PR c++/116071
    
    gcc/cp/ChangeLog:
    
            * parser.cc (cp_parser_simple_type_specifier): Call
            cp_parser_simulate_error if nothing worked.
    
    gcc/testsuite/ChangeLog:
    
            * g++.dg/parse/pr116071.C: New test.
    
    (cherry picked from commit 8c71830b51e6fd10087ce3f6791de80eb1f10b96)

diff --git a/gcc/cp/parser.cc b/gcc/cp/parser.cc
index 00cf128522a..adb10228782 100644
--- a/gcc/cp/parser.cc
+++ b/gcc/cp/parser.cc
@@ -20625,9 +20625,13 @@ cp_parser_simple_type_specifier (cp_parser* parser,
 	}
 
       /* If it didn't work out, we don't have a TYPE.  */
-      if ((flags & CP_PARSER_FLAGS_OPTIONAL)
-	  && !cp_parser_parse_definitely (parser))
-	type = NULL_TREE;
+      if (flags & CP_PARSER_FLAGS_OPTIONAL)
+	{
+	  if (!type)
+	    cp_parser_simulate_error (parser);
+	  if (!cp_parser_parse_definitely (parser))
+	    type = NULL_TREE;
+	}
 
       /* Keep track of all name-lookups performed in class scopes.  */
       if (type
diff --git a/gcc/testsuite/g++.dg/parse/pr116071.C b/gcc/testsuite/g++.dg/parse/pr116071.C
new file mode 100644
index 00000000000..7590782d5ee
--- /dev/null
+++ b/gcc/testsuite/g++.dg/parse/pr116071.C
@@ -0,0 +1,18 @@
+// PR c++/116071
+// { dg-options "-std=c++14 -fconcepts" }
+
+template<class T> struct S { ~S(); };
+template<class T> S<T>::~S() { }
+
+template<typename MemPtr>
+struct result_of;
+
+template<typename Res, typename Class>
+struct result_of<Res Class::*>
+{
+  using type = void;
+};
+
+struct thread {
+  void join() { };
+};

commit b1102f7c478136bfe18ceaf7db9572a8a757a3d2
Author: Jason Merrill <jason@redhat.com>
Date:   Mon Aug 5 17:21:05 2024

    c++: alias and non-type template parm [PR116223]
    
    My r14-8291 for PR112632 introduced IMPLICIT_CONV_EXPR_FORCED to express
    conversions to the type of an alias template parameter.  In this example,
    that broke deduction of X in the call to foo, so let's teach deduction to
    look through it.
    
            PR c++/116223
            PR c++/112632
    
    gcc/cp/ChangeLog:
    
            * pt.cc (deducible_expression): Also look through
            IMPLICIT_CONV_EXPR_FORCED.
            (unify): Likewise.
    
    gcc/testsuite/ChangeLog:
    
            * g++.dg/cpp1z/nontype-auto25.C: New test.
    
    (cherry picked from commit 4add6cd341a779e980e41ed6fb49175fca37496e)

diff --git a/gcc/cp/pt.cc b/gcc/cp/pt.cc
index ea4a6c9bf53..96a4f45909d 100644
--- a/gcc/cp/pt.cc
+++ b/gcc/cp/pt.cc
@@ -23073,6 +23073,8 @@ deducible_expression (tree expr)
   /* Strip implicit conversions and implicit INDIRECT_REFs.  */
   while (CONVERT_EXPR_P (expr)
 	 || TREE_CODE (expr) == VIEW_CONVERT_EXPR
+	 || (TREE_CODE (expr) == IMPLICIT_CONV_EXPR
+	     && IMPLICIT_CONV_EXPR_FORCED (expr))
 	 || REFERENCE_REF_P (expr))
     expr = TREE_OPERAND (expr, 0);
   return (TREE_CODE (expr) == TEMPLATE_PARM_INDEX);
@@ -24602,7 +24604,9 @@ unify (tree tparms, tree targs, tree parm, tree arg, int strict,
      signedness is the only information lost, and I think that will be
      okay.  VIEW_CONVERT_EXPR can appear with class NTTP, thanks to
      finish_id_expression_1, and are also OK.  */
-  while (CONVERT_EXPR_P (parm) || TREE_CODE (parm) == VIEW_CONVERT_EXPR)
+  while (CONVERT_EXPR_P (parm) || TREE_CODE (parm) == VIEW_CONVERT_EXPR
+	 || (TREE_CODE (parm) == IMPLICIT_CONV_EXPR
+	     && IMPLICIT_CONV_EXPR_FORCED (parm)))
     parm = TREE_OPERAND (parm, 0);
 
   if (arg == error_mark_node)
diff --git a/gcc/testsuite/g++.dg/cpp1z/nontype-auto25.C b/gcc/testsuite/g++.dg/cpp1z/nontype-auto25.C
new file mode 100644
index 00000000000..36b38b48ec2
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp1z/nontype-auto25.C
@@ -0,0 +1,18 @@
+// PR c++/116223
+// { dg-do compile { target c++17 } }
+
+template <int T> struct A { int value = T; };
+
+template <unsigned char X> using B = A<X>;
+
+template <auto X>
+void foo(B<X>& mat) noexcept
+{
+  //    std::cout << mat.value << "\n";
+}
+
+int main()
+{
+    A<2> mat;
+    foo(mat);
+}

commit 49e8eeeb38da9e22d4d4ccec8dac610f337d8917
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Wed Aug 7 02:21:46 2024

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index d043a7896f9..2e5fb05c010 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,28 @@
+2024-08-06  John David Anglin  <danglin@gcc.gnu.org>
+
+	PR target/113384
+	* config/pa/pa.cc (hppa_legitimize_address): Add check to
+	ensure constant is an integral multiple of shift the value.
+
+2024-08-06  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2024-08-06  Jakub Jelinek  <jakub@redhat.com>
+
+	PR tree-optimization/116224
+	* wide-int.cc (wi::mul_internal): If prec isn't multiple of
+	HOST_BITS_PER_WIDE_INT, for need_overflow checking only look at
+	the least significant prec bits starting with r[half_blocks_needed].
+
+2024-08-06  Andrew Pinski  <quic_apinski@quicinc.com>
+
+	Backported from master:
+	2024-08-06  Andrew Pinski  <quic_apinski@quicinc.com>
+
+	PR target/116189
+	* config/sh/sh.cc (sh_recog_treg_set_expr): Don't call make_insn_raw,
+	make the insn with a fake uid.
+
 2024-08-05  Christoph Müllner  <christoph.muellner@vrull.eu>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index f2c439e6ce5..0795b809c24 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240806
+20240807
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index e819f9e63e8..46781e0fac0 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -1,3 +1,23 @@
+2024-08-06  Jason Merrill  <jason@redhat.com>
+
+	Backported from master:
+	2024-08-06  Jason Merrill  <jason@redhat.com>
+
+	PR c++/116223
+	PR c++/112632
+	* pt.cc (deducible_expression): Also look through
+	IMPLICIT_CONV_EXPR_FORCED.
+	(unify): Likewise.
+
+2024-08-06  Jason Merrill  <jason@redhat.com>
+
+	Backported from master:
+	2024-07-24  Jason Merrill  <jason@redhat.com>
+
+	PR c++/116071
+	* parser.cc (cp_parser_simple_type_specifier): Call
+	cp_parser_simulate_error if nothing worked.
+
 2024-08-02  Patrick Palka  <ppalka@redhat.com>
 
 	Backported from master:
diff --git a/gcc/fortran/ChangeLog b/gcc/fortran/ChangeLog
index 04d5d211b70..a16a51a786e 100644
--- a/gcc/fortran/ChangeLog
+++ b/gcc/fortran/ChangeLog
@@ -1,3 +1,12 @@
+2024-08-06  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2024-08-01  Jakub Jelinek  <jakub@redhat.com>
+
+	* trans-types.cc (gfc_get_array_descr_info): Don't test if
+	!integer_zerop (dtype_off), use fold_build_pointer_plus
+	unconditionally.
+
 2024-08-05  Paul Thomas  <pault@gcc.gnu.org>
 
 	Backported from master:
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 0c272ccfa71..e4fa87404ca 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,36 @@
+2024-08-06  Jason Merrill  <jason@redhat.com>
+
+	Backported from master:
+	2024-08-06  Jason Merrill  <jason@redhat.com>
+
+	PR c++/116223
+	PR c++/112632
+	* g++.dg/cpp1z/nontype-auto25.C: New test.
+
+2024-08-06  Jason Merrill  <jason@redhat.com>
+
+	Backported from master:
+	2024-07-24  Jason Merrill  <jason@redhat.com>
+
+	PR c++/116071
+	* g++.dg/parse/pr116071.C: New test.
+
+2024-08-06  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2024-08-06  Jakub Jelinek  <jakub@redhat.com>
+
+	PR tree-optimization/116224
+	* gcc.dg/torture/bitint-72.c: New test.
+
+2024-08-06  Andrew Pinski  <quic_apinski@quicinc.com>
+
+	Backported from master:
+	2024-08-06  Andrew Pinski  <quic_apinski@quicinc.com>
+
+	PR target/116189
+	* c-c++-common/torture/pr116189-1.c: New test.
+
 2024-08-05  Paul Thomas  <pault@gcc.gnu.org>
 
 	Backported from master:
diff --git a/libquadmath/ChangeLog b/libquadmath/ChangeLog
index 726f84535c7..b15f9987436 100644
--- a/libquadmath/ChangeLog
+++ b/libquadmath/ChangeLog
@@ -1,3 +1,12 @@
+2024-08-06  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2024-08-03  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/116007
+	* math/sqrtq.c (TFtype): For PowerPC without __LONG_DOUBLE_IEEE128__
+	define to __float128 before including soft-fp.h and quad.h.
+
 2024-08-01  Release Manager
 
 	* GCC 14.2.0 released.

commit a9255df9c8e58226c7e98b526e5f3605372a997e
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Thu Aug 8 02:23:29 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 0795b809c24..e2d907af701 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240807
+20240808

commit 9ca1d7a36abecee7da387ceb1c07d77eaad15927
Author: Georg-Johann Lay <avr@gjlay.de>
Date:   Thu Aug 8 18:31:16 2024

    AVR: target/116295 - Fix unrecognizable insn with __flash read.
    
    Some loads from non-generic address-spaces are performed by
    libgcc calls, and they don't have a POST_INC form.  Don't consider
    such insns when running -mfuse-add.
    
            PR target/116295
    gcc/
            * config/avr/avr.cc (Mem_Insn::Mem_Insn): Don't consider MEMs
            that are avr_mem_memx_p or avr_load_libgcc_p.
    
    gcc/testsuite/
            * gcc.target/avr/torture/pr116295.c: New test.
    
    (cherry picked from commit c4d3dba253b49fb0e8e32109783f76453bc53653)

diff --git a/gcc/config/avr/avr.cc b/gcc/config/avr/avr.cc
index b41592ff1a3..71929b28160 100644
--- a/gcc/config/avr/avr.cc
+++ b/gcc/config/avr/avr.cc
@@ -2052,6 +2052,10 @@ avr_pass_fuse_add::Mem_Insn::Mem_Insn (rtx_insn *insn)
   else
     return;
 
+  if (avr_mem_memx_p (mem)
+      || avr_load_libgcc_p (mem))
+    return;
+
   addr = XEXP (mem, 0);
   addr_code = GET_CODE (addr);
 
diff --git a/gcc/testsuite/gcc.target/avr/torture/pr116295.c b/gcc/testsuite/gcc.target/avr/torture/pr116295.c
new file mode 100644
index 00000000000..0b3d380ff14
--- /dev/null
+++ b/gcc/testsuite/gcc.target/avr/torture/pr116295.c
@@ -0,0 +1,22 @@
+/* { dg-do link } */
+/* { dg-additional-options "-std=gnu99" } */
+
+#ifdef __FLASH
+
+long val;
+
+__attribute__((used))
+const __flash long*
+load4_flash (const __flash long *p)
+{
+    val += *p++;
+    val += *p++;
+    return p;
+}
+
+#endif
+
+int main (void)
+{
+	return 0;
+}

commit 897cd794d341a3bdd3195e90ebeea054ac80bf65
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Fri Aug 9 02:22:36 2024

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 2e5fb05c010..8237fd50bba 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,12 @@
+2024-08-08  Georg-Johann Lay  <avr@gjlay.de>
+
+	Backported from master:
+	2024-08-08  Georg-Johann Lay  <avr@gjlay.de>
+
+	PR target/116295
+	* config/avr/avr.cc (Mem_Insn::Mem_Insn): Don't consider MEMs
+	that are avr_mem_memx_p or avr_load_libgcc_p.
+
 2024-08-06  John David Anglin  <danglin@gcc.gnu.org>
 
 	PR target/113384
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index e2d907af701..17534e79088 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240808
+20240809
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index e4fa87404ca..c27638d041e 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,11 @@
+2024-08-08  Georg-Johann Lay  <avr@gjlay.de>
+
+	Backported from master:
+	2024-08-08  Georg-Johann Lay  <avr@gjlay.de>
+
+	PR target/116295
+	* gcc.target/avr/torture/pr116295.c: New test.
+
 2024-08-06  Jason Merrill  <jason@redhat.com>
 
 	Backported from master:

commit b0dd13efca673355dd2a0c5646452c2f23f86029
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Fri Aug 9 14:32:51 2024

    i386: Fix up __builtin_ia32_b{extr{,i}_u{32,64},zhi_{s,d}i} folding [PR116287]
    
    The GENERIC folding of these builtins have cases where it folds to a
    constant regardless of the value of the first operand.  If so, we need
    to use omit_one_operand to avoid throwing away side-effects in the first
    operand if any.  The cases which verify the first argument is INTEGER_CST
    don't need that, INTEGER_CST doesn't have side-effects.
    
    2024-08-09  Jakub Jelinek  <jakub@redhat.com>
    
            PR target/116287
            * config/i386/i386.cc (ix86_fold_builtin) <case IX86_BUILTIN_BEXTR32>:
            When folding into zero without checking whether first argument is
            constant, use omit_one_operand.
            (ix86_fold_builtin) <case IX86_BUILTIN_BZHI32>: Likewise.
    
            * gcc.target/i386/bmi-pr116287.c: New test.
            * gcc.target/i386/bmi2-pr116287.c: New test.
            * gcc.target/i386/tbm-pr116287.c: New test.
    
    (cherry picked from commit 6e7088dbe3bf87108a89558ffb7df36df3469206)

diff --git a/gcc/config/i386/i386.cc b/gcc/config/i386/i386.cc
index 35a28243389..6f89891d3cb 100644
--- a/gcc/config/i386/i386.cc
+++ b/gcc/config/i386/i386.cc
@@ -18671,9 +18671,11 @@ ix86_fold_builtin (tree fndecl, int n_args,
 	      unsigned int prec = TYPE_PRECISION (TREE_TYPE (args[0]));
 	      unsigned int start = tree_to_uhwi (args[1]);
 	      unsigned int len = (start & 0xff00) >> 8;
+	      tree lhs_type = TREE_TYPE (TREE_TYPE (fndecl));
 	      start &= 0xff;
 	      if (start >= prec || len == 0)
-		res = 0;
+		return omit_one_operand (lhs_type, build_zero_cst (lhs_type),
+					 args[0]);
 	      else if (!tree_fits_uhwi_p (args[0]))
 		break;
 	      else
@@ -18682,7 +18684,7 @@ ix86_fold_builtin (tree fndecl, int n_args,
 		len = prec;
 	      if (len < HOST_BITS_PER_WIDE_INT)
 		res &= (HOST_WIDE_INT_1U << len) - 1;
-	      return build_int_cstu (TREE_TYPE (TREE_TYPE (fndecl)), res);
+	      return build_int_cstu (lhs_type, res);
 	    }
 	  break;
 
@@ -18692,15 +18694,17 @@ ix86_fold_builtin (tree fndecl, int n_args,
 	  if (tree_fits_uhwi_p (args[1]))
 	    {
 	      unsigned int idx = tree_to_uhwi (args[1]) & 0xff;
+	      tree lhs_type = TREE_TYPE (TREE_TYPE (fndecl));
 	      if (idx >= TYPE_PRECISION (TREE_TYPE (args[0])))
 		return args[0];
 	      if (idx == 0)
-		return build_int_cst (TREE_TYPE (TREE_TYPE (fndecl)), 0);
+		return omit_one_operand (lhs_type, build_zero_cst (lhs_type),
+					 args[0]);
 	      if (!tree_fits_uhwi_p (args[0]))
 		break;
 	      unsigned HOST_WIDE_INT res = tree_to_uhwi (args[0]);
 	      res &= ~(HOST_WIDE_INT_M1U << idx);
-	      return build_int_cstu (TREE_TYPE (TREE_TYPE (fndecl)), res);
+	      return build_int_cstu (lhs_type, res);
 	    }
 	  break;
 
diff --git a/gcc/testsuite/gcc.target/i386/bmi-pr116287.c b/gcc/testsuite/gcc.target/i386/bmi-pr116287.c
new file mode 100644
index 00000000000..2212cb458d2
--- /dev/null
+++ b/gcc/testsuite/gcc.target/i386/bmi-pr116287.c
@@ -0,0 +1,28 @@
+/* PR target/116287 */
+/* { dg-do run { target bmi } } */
+/* { dg-options "-O2 -mbmi" } */
+
+#include <x86intrin.h>
+
+#include "bmi-check.h"
+
+static void
+bmi_test ()
+{
+  unsigned int a = 0;
+  if (__builtin_ia32_bextr_u32 (a++, 0) != 0)
+    abort ();
+  if (__builtin_ia32_bextr_u32 (a++, 0x120) != 0)
+    abort ();
+  if (a != 2)
+    abort ();
+#ifdef __x86_64__
+  unsigned long long b = 0;
+  if (__builtin_ia32_bextr_u64 (b++, 0) != 0)
+    abort ();
+  if (__builtin_ia32_bextr_u64 (b++, 0x140) != 0)
+    abort ();
+  if (b != 2)
+    abort ();
+#endif
+}
diff --git a/gcc/testsuite/gcc.target/i386/bmi2-pr116287.c b/gcc/testsuite/gcc.target/i386/bmi2-pr116287.c
new file mode 100644
index 00000000000..51c939c39f6
--- /dev/null
+++ b/gcc/testsuite/gcc.target/i386/bmi2-pr116287.c
@@ -0,0 +1,24 @@
+/* PR target/116287 */
+/* { dg-do run { target bmi2 } } */
+/* { dg-options "-O2 -mbmi2" } */
+
+#include <x86intrin.h>
+
+#include "bmi2-check.h"
+
+static void
+bmi2_test ()
+{
+  unsigned int a = 0;
+  if (__builtin_ia32_bzhi_si (a++, 0) != 0)
+    abort ();
+  if (a != 1)
+    abort ();
+#ifdef __x86_64__
+  unsigned long long b = 0;
+  if (__builtin_ia32_bzhi_di (b++, 0) != 0)
+    abort ();
+  if (b != 1)
+    abort ();
+#endif
+}
diff --git a/gcc/testsuite/gcc.target/i386/tbm-pr116287.c b/gcc/testsuite/gcc.target/i386/tbm-pr116287.c
new file mode 100644
index 00000000000..a229d8bb416
--- /dev/null
+++ b/gcc/testsuite/gcc.target/i386/tbm-pr116287.c
@@ -0,0 +1,29 @@
+/* PR target/116287 */
+/* { dg-do compile } */
+/* { dg-options "-O2 -mtbm -fdump-tree-optimized" } */
+/* { dg-final { scan-tree-dump-not "link_error \\\(\\\);" "optimized" } } */
+
+#include <x86intrin.h>
+
+extern void link_error (void);
+
+void
+tbm_test ()
+{
+  unsigned int a = 0;
+  if (__builtin_ia32_bextri_u32 (a++, 0) != 0)
+    link_error ();
+  if (__builtin_ia32_bextri_u32 (a++, 0x120) != 0)
+    link_error ();
+  if (a != 2)
+    link_error ();
+#ifdef __x86_64__
+  unsigned long long b = 0;
+  if (__builtin_ia32_bextr_u64 (b++, 0) != 0)
+    link_error ();
+  if (__builtin_ia32_bextr_u64 (b++, 0x140) != 0)
+    link_error ();
+  if (b != 2)
+    link_error ();
+#endif
+}

commit 6f1e687d23e1474ca7b65389475beb3a24dd4aed
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Sat Aug 10 02:22:40 2024

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 8237fd50bba..dbe6692b511 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,14 @@
+2024-08-09  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2024-08-09  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/116287
+	* config/i386/i386.cc (ix86_fold_builtin) <case IX86_BUILTIN_BEXTR32>:
+	When folding into zero without checking whether first argument is
+	constant, use omit_one_operand.
+	(ix86_fold_builtin) <case IX86_BUILTIN_BZHI32>: Likewise.
+
 2024-08-08  Georg-Johann Lay  <avr@gjlay.de>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 17534e79088..5d474ddc6cc 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240809
+20240810
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index c27638d041e..f19069a762d 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,13 @@
+2024-08-09  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2024-08-09  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/116287
+	* gcc.target/i386/bmi-pr116287.c: New test.
+	* gcc.target/i386/bmi2-pr116287.c: New test.
+	* gcc.target/i386/tbm-pr116287.c: New test.
+
 2024-08-08  Georg-Johann Lay  <avr@gjlay.de>
 
 	Backported from master:

commit 534ffe70e92c8dd47d03174220d2afd017fde12c
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Sun Aug 11 02:22:27 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 5d474ddc6cc..c3de54be1f1 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240810
+20240811

commit 6bfd78c595452556b678c66b2b71785dcb16b07a
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Mon Aug 12 02:22:44 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index c3de54be1f1..2454f4b3e28 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240811
+20240812

commit f688431db9acefff850d2004ad5c35ef38c47449
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Tue Aug 13 02:22:33 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 2454f4b3e28..e2b84f6ebd8 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240812
+20240813

commit 7d9bb37174f9526639d5acaa87868a752ba7d956
Author: Michael Meissner <meissner@linux.ibm.com>
Date:   Tue Aug 13 23:22:38 2024

    Add -mcpu=power11 support.
    
    This patch adds the power11 option to the -mcpu= and -mtune= switches.
    
    This patch treats the power11 like a power10 in terms of costs and reassociation
    width.
    
    This patch issues a ".machine power11" to the assembly file if you use
    -mcpu=power11.
    
    This patch defines _ARCH_PWR11 if the user uses -mcpu=power11.
    
    This patch allows GCC to be configured with the --with-cpu=power11 and
    --with-tune=power11 options.
    
    This patch passes -mpwr11 to the assembler if the user uses -mcpu=power11.
    
    This patch adds support for using "power11" in the __builtin_cpu_is built-in
    function.
    
    Backported from master: 2024-07-22
    
    2024-08-13  Michael Meissner  <meissner@linux.ibm.com>
    
    gcc/
    
            * config.gcc (powerpc*-*-*): Add support for power11.
            * config/rs6000/aix71.h (ASM_CPU_SPEC): Add support for -mcpu=power11.
            * config/rs6000/aix72.h (ASM_CPU_SPEC): Likewise.
            * config/rs6000/aix73.h (ASM_CPU_SPEC): Likewise.
            * config/rs6000/driver-rs6000.cc (asm_names): Likewise.
            * config/rs6000/ppc-auxv.h (PPC_PLATFORM_POWER11): New define.
            * config/rs6000/rs6000-builtin.cc (cpu_is_info): Add power11.
            * config/rs6000/rs6000-c.cc (rs6000_target_modify_macros): Define
            _ARCH_PWR11 if -mcpu=power11.
            * config/rs6000/rs6000-cpus.def (POWER11_MASKS_SERVER): New define.
            (POWERPC_MASKS): Add power11.
            (power11 cpu): Add power11 definition.
            * config/rs6000/rs6000-opts.h (PROCESSOR_POWER11): Add power11 processor.
            * config/rs6000/rs6000-string.cc (expand_compare_loop): Likewise.
            * config/rs6000/rs6000-tables.opt: Regenerate.
            * config/rs6000/rs6000.cc (rs6000_option_override_internal): Add power11
            support.
            (rs6000_machine_from_flags): Likewise.
            (rs6000_reassociation_width): Likewise.
            (rs6000_adjust_cost): Likewise.
            (rs6000_issue_rate): Likewise.
            (rs6000_sched_reorder): Likewise.
            (rs6000_sched_reorder2): Likewise.
            (rs6000_register_move_cost): Likewise.
            (rs6000_opt_masks): Likewise.
            * config/rs6000/rs6000.h (ASM_CPU_SPEC): Likewise.
            * config/rs6000/rs6000.md (cpu attribute): Add power11.
            * config/rs6000/rs6000.opt (-mpower11): Add internal power11 flag.
            * doc/invoke.texi (RS/6000 and PowerPC Options): Document -mcpu=power11.
            * config/rs6000/power10.md (all reservations): Add power11 support.
    
    gcc/testsuite/
    
            * gcc.target/powerpc/power11-1.c: New test.
            * gcc.target/powerpc/power11-2.c: Likewise.
            * gcc.target/powerpc/power11-3.c: Likewise.

diff --git a/gcc/config.gcc b/gcc/config.gcc
index 95c91ee02be..a3566f5c77d 100644
--- a/gcc/config.gcc
+++ b/gcc/config.gcc
@@ -534,7 +534,7 @@ powerpc*-*-*)
 	extra_headers="${extra_headers} ppu_intrinsics.h spu2vmx.h vec_types.h si2vmx.h"
 	extra_headers="${extra_headers} amo.h"
 	case x$with_cpu in
-	    xpowerpc64|xdefault64|x6[23]0|x970|xG5|xpower[3456789]|xpower10|xpower6x|xrs64a|xcell|xa2|xe500mc64|xe5500|xe6500)
+	    xpowerpc64|xdefault64|x6[23]0|x970|xG5|xpower[3456789]|xpower1[01]|xpower6x|xrs64a|xcell|xa2|xe500mc64|xe5500|xe6500)
 		cpu_is_64bit=yes
 		;;
 	esac
@@ -5601,7 +5601,7 @@ case "${target}" in
 				eval "with_$which=405"
 				;;
 			"" | common | native \
-			| power[3456789] | power10 | power5+ | power6x \
+			| power[3456789] | power1[01] | power5+ | power6x \
 			| powerpc | powerpc64 | powerpc64le \
 			| rs64 \
 			| 401 | 403 | 405 | 405fp | 440 | 440fp | 464 | 464fp \
diff --git a/gcc/config/rs6000/aix71.h b/gcc/config/rs6000/aix71.h
index 24bc301e37d..41037b3852d 100644
--- a/gcc/config/rs6000/aix71.h
+++ b/gcc/config/rs6000/aix71.h
@@ -79,6 +79,7 @@ do {									\
 #undef ASM_CPU_SPEC
 #define ASM_CPU_SPEC \
 "%{mcpu=native: %(asm_cpu_native); \
+  mcpu=power11: -mpwr11; \
   mcpu=power10: -mpwr10; \
   mcpu=power9: -mpwr9; \
   mcpu=power8: -mpwr8; \
diff --git a/gcc/config/rs6000/aix72.h b/gcc/config/rs6000/aix72.h
index c43974f577a..fe59f8319b4 100644
--- a/gcc/config/rs6000/aix72.h
+++ b/gcc/config/rs6000/aix72.h
@@ -79,6 +79,7 @@ do {									\
 #undef ASM_CPU_SPEC
 #define ASM_CPU_SPEC \
 "%{mcpu=native: %(asm_cpu_native); \
+  mcpu=power11: -mpwr11; \
   mcpu=power10: -mpwr10; \
   mcpu=power9: -mpwr9; \
   mcpu=power8: -mpwr8; \
diff --git a/gcc/config/rs6000/aix73.h b/gcc/config/rs6000/aix73.h
index b1572bde81f..1318b0b3662 100644
--- a/gcc/config/rs6000/aix73.h
+++ b/gcc/config/rs6000/aix73.h
@@ -79,6 +79,7 @@ do {									\
 #undef ASM_CPU_SPEC
 #define ASM_CPU_SPEC \
 "%{mcpu=native: %(asm_cpu_native); \
+  mcpu=power11: -mpwr11; \
   mcpu=power10: -mpwr10; \
   mcpu=power9: -mpwr9; \
   mcpu=power8: -mpwr8; \
diff --git a/gcc/config/rs6000/driver-rs6000.cc b/gcc/config/rs6000/driver-rs6000.cc
index 3ebbaa42622..f4900724b98 100644
--- a/gcc/config/rs6000/driver-rs6000.cc
+++ b/gcc/config/rs6000/driver-rs6000.cc
@@ -451,6 +451,7 @@ static const struct asm_name asm_names[] = {
   { "power8",	"-mpwr8" },
   { "power9",	"-mpwr9" },
   { "power10",	"-mpwr10" },
+  { "power11",	"-mpwr11" },
   { "powerpc",	"-mppc" },
   { "rs64",	"-mppc" },
   { "603",	"-m603" },
@@ -479,6 +480,7 @@ static const struct asm_name asm_names[] = {
   { "power8",	"-mpower8" },
   { "power9",	"-mpower9" },
   { "power10",	"-mpower10" },
+  { "power11",	"-mpower11" },
   { "a2",	"-ma2" },
   { "powerpc",	"-mppc" },
   { "powerpc64", "-mppc64" },
diff --git a/gcc/config/rs6000/power10.md b/gcc/config/rs6000/power10.md
index fcc2199ab29..2310c460345 100644
--- a/gcc/config/rs6000/power10.md
+++ b/gcc/config/rs6000/power10.md
@@ -1,4 +1,4 @@
-;; Scheduling description for the IBM POWER10 processor.
+;; Scheduling description for the IBM Power10 and Power11 processors.
 ;; Copyright (C) 2020-2024 Free Software Foundation, Inc.
 ;;
 ;; Contributed by Pat Haugen (pthaugen@us.ibm.com).
@@ -97,12 +97,12 @@
        (eq_attr "update" "no")
        (eq_attr "size" "!128")
        (eq_attr "prefixed" "no")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,LU_power10")
 
 (define_insn_reservation "power10-fused-load" 4
   (and (eq_attr "type" "fused_load_cmpi,fused_addis_load,fused_load_load")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,LU_power10")
 
 (define_insn_reservation "power10-prefixed-load" 4
@@ -110,13 +110,13 @@
        (eq_attr "update" "no")
        (eq_attr "size" "!128")
        (eq_attr "prefixed" "yes")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,LU_power10")
 
 (define_insn_reservation "power10-load-update" 4
   (and (eq_attr "type" "load")
        (eq_attr "update" "yes")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,LU_power10+SXU_power10")
 
 (define_insn_reservation "power10-fpload-double" 4
@@ -124,7 +124,7 @@
        (eq_attr "update" "no")
        (eq_attr "size" "64")
        (eq_attr "prefixed" "no")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,LU_power10")
 
 (define_insn_reservation "power10-prefixed-fpload-double" 4
@@ -132,14 +132,14 @@
        (eq_attr "update" "no")
        (eq_attr "size" "64")
        (eq_attr "prefixed" "yes")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,LU_power10")
 
 (define_insn_reservation "power10-fpload-update-double" 4
   (and (eq_attr "type" "fpload")
        (eq_attr "update" "yes")
        (eq_attr "size" "64")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,LU_power10+SXU_power10")
 
 ; SFmode loads are cracked and have additional 3 cycles over DFmode
@@ -148,27 +148,27 @@
   (and (eq_attr "type" "fpload")
        (eq_attr "update" "no")
        (eq_attr "size" "32")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,LU_power10")
 
 (define_insn_reservation "power10-fpload-update-single" 7
   (and (eq_attr "type" "fpload")
        (eq_attr "update" "yes")
        (eq_attr "size" "32")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,LU_power10+SXU_power10")
 
 (define_insn_reservation "power10-vecload" 4
   (and (eq_attr "type" "vecload")
        (eq_attr "size" "!256")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,LU_power10")
 
 ; lxvp
 (define_insn_reservation "power10-vecload-pair" 4
   (and (eq_attr "type" "vecload")
        (eq_attr "size" "256")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,LU_power10+SXU_power10")
 
 ; Store Unit
@@ -178,12 +178,12 @@
        (eq_attr "prefixed" "no")
        (eq_attr "size" "!128")
        (eq_attr "size" "!256")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,STU_power10")
 
 (define_insn_reservation "power10-fused-store" 0
   (and (eq_attr "type" "fused_store_store")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,STU_power10")
 
 (define_insn_reservation "power10-prefixed-store" 0
@@ -191,52 +191,52 @@
        (eq_attr "prefixed" "yes")
        (eq_attr "size" "!128")
        (eq_attr "size" "!256")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,STU_power10")
 
 ; Update forms have 2 cycle latency for updated addr reg
 (define_insn_reservation "power10-store-update" 2
   (and (eq_attr "type" "store,fpstore")
        (eq_attr "update" "yes")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,STU_power10")
 
 ; stxvp
 (define_insn_reservation "power10-vecstore-pair" 0
   (and (eq_attr "type" "vecstore")
        (eq_attr "size" "256")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,stu0_power10+stu1_power10")
 
 (define_insn_reservation "power10-larx" 4
   (and (eq_attr "type" "load_l")
        (eq_attr "size" "!128")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,LU_power10")
 
 ; All load quad forms
 (define_insn_reservation "power10-lq" 4
   (and (eq_attr "type" "load,load_l")
        (eq_attr "size" "128")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,LU_power10+SXU_power10")
 
 (define_insn_reservation "power10-stcx" 0
   (and (eq_attr "type" "store_c")
        (eq_attr "size" "!128")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,STU_power10")
 
 ; All store quad forms
 (define_insn_reservation "power10-stq" 0
   (and (eq_attr "type" "store,store_c")
        (eq_attr "size" "128")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,stu0_power10+stu1_power10")
 
 (define_insn_reservation "power10-sync" 1
   (and (eq_attr "type" "sync,isync")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,STU_power10")
 
 
@@ -248,7 +248,7 @@
 (define_insn_reservation "power10-alu" 2
   (and (eq_attr "type" "add,exts,integer,logical,isel")
        (eq_attr "prefixed" "no")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 ; 4 cycle CR latency
 (define_bypass 4 "power10-alu"
@@ -256,28 +256,28 @@
 
 (define_insn_reservation "power10-fused_alu" 2
   (and (eq_attr "type" "fused_arith_logical,fused_cmp_isel,fused_carry")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,EXU_power10")
 
 ; paddi
 (define_insn_reservation "power10-paddi" 2
   (and (eq_attr "type" "add")
        (eq_attr "prefixed" "yes")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,EXU_power10")
 
 ; Rotate/shift (non-record form)
 (define_insn_reservation "power10-rot" 2
   (and (eq_attr "type" "insert,shift")
        (eq_attr "dot" "no")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 ; Record form rotate/shift
 (define_insn_reservation "power10-rot-compare" 3
   (and (eq_attr "type" "insert,shift")
        (eq_attr "dot" "yes")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 ; 5 cycle CR latency
 (define_bypass 5 "power10-rot-compare"
@@ -285,7 +285,7 @@
 
 (define_insn_reservation "power10-alu2" 3
   (and (eq_attr "type" "cntlz,popcnt,trap")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 ; 5 cycle CR latency
 (define_bypass 5 "power10-alu2"
@@ -293,24 +293,24 @@
 
 (define_insn_reservation "power10-cmp" 2
   (and (eq_attr "type" "cmp")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 ; Treat 'two' and 'three' types as 2 or 3 way cracked
 (define_insn_reservation "power10-two" 4
   (and (eq_attr "type" "two")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,EXU_power10")
 
 (define_insn_reservation "power10-three" 6
   (and (eq_attr "type" "three")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_all_power10,EXU_power10")
 
 (define_insn_reservation "power10-mul" 5
   (and (eq_attr "type" "mul")
        (eq_attr "dot" "no")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 ; 4 cycle MUL->MUL latency
 (define_bypass 4 "power10-mul"
@@ -319,7 +319,7 @@
 (define_insn_reservation "power10-mul-compare" 5
   (and (eq_attr "type" "mul")
        (eq_attr "dot" "yes")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,EXU_power10")
 ; 4 cycle MUL->MUL latency
 (define_bypass 4 "power10-mul-compare"
@@ -331,13 +331,13 @@
 (define_insn_reservation "power10-div" 12
   (and (eq_attr "type" "div")
        (eq_attr "dot" "no")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-div-compare" 12
   (and (eq_attr "type" "div")
        (eq_attr "dot" "yes")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,EXU_power10")
 ; 14 cycle CR latency
 (define_bypass 14 "power10-div-compare"
@@ -345,34 +345,34 @@
 
 (define_insn_reservation "power10-crlogical" 2
   (and (eq_attr "type" "cr_logical")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-mfcrf" 2
   (and (eq_attr "type" "mfcrf")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-mfcr" 3
   (and (eq_attr "type" "mfcr")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,EXU_power10")
 
 ; Should differentiate between 1 cr field and > 1 since target of > 1 cr
 ; is cracked
 (define_insn_reservation "power10-mtcr" 3
   (and (eq_attr "type" "mtcr")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-mtjmpr" 3
   (and (eq_attr "type" "mtjmpr")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-mfjmpr" 2
   (and (eq_attr "type" "mfjmpr")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 
@@ -380,126 +380,126 @@
 
 (define_insn_reservation "power10-fpsimple" 3
   (and (eq_attr "type" "fpsimple")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-fp" 5
   (and (eq_attr "type" "fp,dmul")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-fpcompare" 3
   (and (eq_attr "type" "fpcompare")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-sdiv" 22
   (and (eq_attr "type" "sdiv")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-ddiv" 27
   (and (eq_attr "type" "ddiv")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-sqrt" 26
   (and (eq_attr "type" "ssqrt")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-dsqrt" 36
   (and (eq_attr "type" "dsqrt")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-vec-2cyc" 2
   (and (eq_attr "type" "vecmove,veclogical,vecexts,veccmpfx")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-fused-vec" 2
   (and (eq_attr "type" "fused_vector")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,EXU_power10")
 
 (define_insn_reservation "power10-veccmp" 3
   (and (eq_attr "type" "veccmp")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-vecsimple" 2
   (and (eq_attr "type" "vecsimple")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-vecnormal" 5
   (and (eq_attr "type" "vecfloat,vecdouble")
        (eq_attr "size" "!128")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-qp" 12
   (and (eq_attr "type" "vecfloat,vecdouble")
        (eq_attr "size" "128")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-vecperm" 3
   (and (eq_attr "type" "vecperm")
        (eq_attr "prefixed" "no")
        (eq_attr "dot" "no")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-vecperm-compare" 3
   (and (eq_attr "type" "vecperm")
        (eq_attr "dot" "yes")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,EXU_power10")
 
 (define_insn_reservation "power10-prefixed-vecperm" 3
   (and (eq_attr "type" "vecperm")
        (eq_attr "prefixed" "yes")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,EXU_power10")
 
 (define_insn_reservation "power10-veccomplex" 6
   (and (eq_attr "type" "veccomplex")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-vecfdiv" 24
   (and (eq_attr "type" "vecfdiv")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-vecdiv" 27
   (and (eq_attr "type" "vecdiv")
        (eq_attr "size" "!128")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-qpdiv" 56
   (and (eq_attr "type" "vecdiv")
        (eq_attr "size" "128")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-qpmul" 24
   (and (eq_attr "type" "qmul")
        (eq_attr "size" "128")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-mtvsr" 2
   (and (eq_attr "type" "mtvsr")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-mfvsr" 2
   (and (eq_attr "type" "mfvsr")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 
@@ -507,26 +507,26 @@
 ; Branch is 2 cycles, grouped with STU for issue
 (define_insn_reservation "power10-branch" 2
   (and (eq_attr "type" "jmpreg,branch")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,STU_power10")
 
 (define_insn_reservation "power10-fused-branch" 3
   (and (eq_attr "type" "fused_mtbc")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,STU_power10")
 
 
 ; Crypto
 (define_insn_reservation "power10-crypto" 4
   (and (eq_attr "type" "crypto")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 
 ; HTM
 (define_insn_reservation "power10-htm" 2
   (and (eq_attr "type" "htmsimple,htm")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 
@@ -535,26 +535,26 @@
 (define_insn_reservation "power10-dfp" 12
   (and (eq_attr "type" "dfp")
        (eq_attr "size" "!128")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_power10")
 
 (define_insn_reservation "power10-dfpq" 12
   (and (eq_attr "type" "dfp")
        (eq_attr "size" "128")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,EXU_power10")
 
 ; MMA
 (define_insn_reservation "power10-mma" 9
   (and (eq_attr "type" "mma")
        (eq_attr "prefixed" "no")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_any_power10,EXU_super_power10")
 
 (define_insn_reservation "power10-prefixed-mma" 9
   (and (eq_attr "type" "mma")
        (eq_attr "prefixed" "yes")
-       (eq_attr "cpu" "power10"))
+       (eq_attr "cpu" "power10,power11"))
   "DU_even_power10,EXU_super_power10")
 ; 4 cycle MMA->MMA latency
 (define_bypass 4 "power10-mma,power10-prefixed-mma"
diff --git a/gcc/config/rs6000/ppc-auxv.h b/gcc/config/rs6000/ppc-auxv.h
index 364bba427d1..ed269e3b72b 100644
--- a/gcc/config/rs6000/ppc-auxv.h
+++ b/gcc/config/rs6000/ppc-auxv.h
@@ -47,9 +47,8 @@
 #define PPC_PLATFORM_PPC476            12
 #define PPC_PLATFORM_POWER8            13
 #define PPC_PLATFORM_POWER9            14
-
-/* This is not yet official.  */
 #define PPC_PLATFORM_POWER10           15
+#define PPC_PLATFORM_POWER11           16
 
 /* AT_HWCAP bits.  These must match the values defined in the Linux kernel.  */
 #define PPC_FEATURE_32              0x80000000
diff --git a/gcc/config/rs6000/rs6000-builtin.cc b/gcc/config/rs6000/rs6000-builtin.cc
index e96d5157e4d..d8b18b2b8ce 100644
--- a/gcc/config/rs6000/rs6000-builtin.cc
+++ b/gcc/config/rs6000/rs6000-builtin.cc
@@ -2493,6 +2493,7 @@ static const struct
   const char *cpu;
   unsigned int cpuid;
 } cpu_is_info[] = {
+  { "power11",	   PPC_PLATFORM_POWER11 },
   { "power10",	   PPC_PLATFORM_POWER10 },
   { "power9",	   PPC_PLATFORM_POWER9 },
   { "power8",	   PPC_PLATFORM_POWER8 },
diff --git a/gcc/config/rs6000/rs6000-c.cc b/gcc/config/rs6000/rs6000-c.cc
index 6229c503bd0..68519e1397f 100644
--- a/gcc/config/rs6000/rs6000-c.cc
+++ b/gcc/config/rs6000/rs6000-c.cc
@@ -435,6 +435,8 @@ rs6000_target_modify_macros (bool define_p, HOST_WIDE_INT flags)
     rs6000_define_or_undefine_macro (define_p, "_ARCH_PWR9");
   if ((flags & OPTION_MASK_POWER10) != 0)
     rs6000_define_or_undefine_macro (define_p, "_ARCH_PWR10");
+  if ((flags & OPTION_MASK_POWER11) != 0)
+    rs6000_define_or_undefine_macro (define_p, "_ARCH_PWR11");
   if ((flags & OPTION_MASK_SOFT_FLOAT) != 0)
     rs6000_define_or_undefine_macro (define_p, "_SOFT_FLOAT");
   if ((flags & OPTION_MASK_RECIP_PRECISION) != 0)
diff --git a/gcc/config/rs6000/rs6000-cpus.def b/gcc/config/rs6000/rs6000-cpus.def
index 6ee678e69c3..84fac8bdac1 100644
--- a/gcc/config/rs6000/rs6000-cpus.def
+++ b/gcc/config/rs6000/rs6000-cpus.def
@@ -86,6 +86,9 @@
 				 | OPTION_MASK_POWER10			\
 				 | OTHER_POWER10_MASKS)
 
+#define POWER11_MASKS_SERVER (ISA_3_1_MASKS_SERVER			\
+			      | OPTION_MASK_POWER11)
+
 /* Flags that need to be turned off if -mno-vsx.  */
 #define OTHER_VSX_VECTOR_MASKS	(OPTION_MASK_EFFICIENT_UNALIGNED_VSX	\
 				 | OPTION_MASK_FLOAT128_KEYWORD		\
@@ -123,6 +126,7 @@
 				 | OPTION_MASK_FLOAT128_KEYWORD		\
 				 | OPTION_MASK_FPRND			\
 				 | OPTION_MASK_POWER10			\
+				 | OPTION_MASK_POWER11			\
 				 | OPTION_MASK_P10_FUSION		\
 				 | OPTION_MASK_HTM			\
 				 | OPTION_MASK_ISEL			\
@@ -250,6 +254,7 @@ RS6000_CPU ("power8", PROCESSOR_POWER8, MASK_POWERPC64 | ISA_2_7_MASKS_SERVER
 RS6000_CPU ("power9", PROCESSOR_POWER9, MASK_POWERPC64 | ISA_3_0_MASKS_SERVER
 	    | OPTION_MASK_HTM)
 RS6000_CPU ("power10", PROCESSOR_POWER10, MASK_POWERPC64 | ISA_3_1_MASKS_SERVER)
+RS6000_CPU ("power11", PROCESSOR_POWER11, MASK_POWERPC64 | POWER11_MASKS_SERVER)
 RS6000_CPU ("powerpc", PROCESSOR_POWERPC, 0)
 RS6000_CPU ("powerpc64", PROCESSOR_POWERPC64, OPTION_MASK_PPC_GFXOPT
 	    | MASK_POWERPC64)
diff --git a/gcc/config/rs6000/rs6000-opts.h b/gcc/config/rs6000/rs6000-opts.h
index 33fd0efc936..88e357835a5 100644
--- a/gcc/config/rs6000/rs6000-opts.h
+++ b/gcc/config/rs6000/rs6000-opts.h
@@ -62,6 +62,7 @@ enum processor_type
    PROCESSOR_POWER8,
    PROCESSOR_POWER9,
    PROCESSOR_POWER10,
+   PROCESSOR_POWER11,
 
    PROCESSOR_RS64A,
    PROCESSOR_MPCCORE,
diff --git a/gcc/config/rs6000/rs6000-string.cc b/gcc/config/rs6000/rs6000-string.cc
index 917f5572a6d..9c8a81172e3 100644
--- a/gcc/config/rs6000/rs6000-string.cc
+++ b/gcc/config/rs6000/rs6000-string.cc
@@ -964,6 +964,7 @@ expand_compare_loop (rtx operands[])
       break;
     case PROCESSOR_POWER9:
     case PROCESSOR_POWER10:
+    case PROCESSOR_POWER11:
       if (bytes_is_const)
 	max_bytes = 191;
       else
diff --git a/gcc/config/rs6000/rs6000-tables.opt b/gcc/config/rs6000/rs6000-tables.opt
index 65f46709716..a5649fef1ec 100644
--- a/gcc/config/rs6000/rs6000-tables.opt
+++ b/gcc/config/rs6000/rs6000-tables.opt
@@ -186,14 +186,17 @@ EnumValue
 Enum(rs6000_cpu_opt_value) String(power10) Value(52)
 
 EnumValue
-Enum(rs6000_cpu_opt_value) String(powerpc) Value(53)
+Enum(rs6000_cpu_opt_value) String(power11) Value(53)
 
 EnumValue
-Enum(rs6000_cpu_opt_value) String(powerpc64) Value(54)
+Enum(rs6000_cpu_opt_value) String(powerpc) Value(54)
 
 EnumValue
-Enum(rs6000_cpu_opt_value) String(powerpc64le) Value(55)
+Enum(rs6000_cpu_opt_value) String(powerpc64) Value(55)
 
 EnumValue
-Enum(rs6000_cpu_opt_value) String(rs64) Value(56)
+Enum(rs6000_cpu_opt_value) String(powerpc64le) Value(56)
+
+EnumValue
+Enum(rs6000_cpu_opt_value) String(rs64) Value(57)
 
diff --git a/gcc/config/rs6000/rs6000.cc b/gcc/config/rs6000/rs6000.cc
index 2e686acac6a..5fd31bf8242 100644
--- a/gcc/config/rs6000/rs6000.cc
+++ b/gcc/config/rs6000/rs6000.cc
@@ -1067,7 +1067,7 @@ struct processor_costs power9_cost = {
   COSTS_N_INSNS (3),	/* SF->DF convert */
 };
 
-/* Instruction costs on POWER10 processors.  */
+/* Instruction costs on Power10/Power11 processors.  */
 static const
 struct processor_costs power10_cost = {
   COSTS_N_INSNS (2),	/* mulsi */
@@ -4370,7 +4370,8 @@ rs6000_option_override_internal (bool global_init_p)
      generating power10 instructions.  */
   if (!(rs6000_isa_flags_explicit & OPTION_MASK_P10_FUSION))
     {
-      if (rs6000_tune == PROCESSOR_POWER10)
+      if (rs6000_tune == PROCESSOR_POWER10
+	  || rs6000_tune == PROCESSOR_POWER11)
 	rs6000_isa_flags |= OPTION_MASK_P10_FUSION;
       else
 	rs6000_isa_flags &= ~OPTION_MASK_P10_FUSION;
@@ -4399,6 +4400,7 @@ rs6000_option_override_internal (bool global_init_p)
 			&& rs6000_tune != PROCESSOR_POWER8
 			&& rs6000_tune != PROCESSOR_POWER9
 			&& rs6000_tune != PROCESSOR_POWER10
+			&& rs6000_tune != PROCESSOR_POWER11
 			&& rs6000_tune != PROCESSOR_PPCA2
 			&& rs6000_tune != PROCESSOR_CELL
 			&& rs6000_tune != PROCESSOR_PPC476);
@@ -4413,6 +4415,7 @@ rs6000_option_override_internal (bool global_init_p)
 				 || rs6000_tune == PROCESSOR_POWER8
 				 || rs6000_tune == PROCESSOR_POWER9
 				 || rs6000_tune == PROCESSOR_POWER10
+				 || rs6000_tune == PROCESSOR_POWER11
 				 || rs6000_tune == PROCESSOR_PPCE500MC
 				 || rs6000_tune == PROCESSOR_PPCE500MC64
 				 || rs6000_tune == PROCESSOR_PPCE5500
@@ -4712,6 +4715,7 @@ rs6000_option_override_internal (bool global_init_p)
 	break;
 
       case PROCESSOR_POWER10:
+      case PROCESSOR_POWER11:
 	rs6000_cost = &power10_cost;
 	break;
 
@@ -5884,6 +5888,8 @@ rs6000_machine_from_flags (void)
   flags &= ~(OPTION_MASK_PPC_GFXOPT | OPTION_MASK_PPC_GPOPT | OPTION_MASK_ISEL
 	     | OPTION_MASK_ALTIVEC);
 
+  if ((flags & (POWER11_MASKS_SERVER & ~ISA_3_1_MASKS_SERVER)) != 0)
+    return "power11";
   if ((flags & (ISA_3_1_MASKS_SERVER & ~ISA_3_0_MASKS_SERVER)) != 0)
     return "power10";
   if ((flags & (ISA_3_0_MASKS_SERVER & ~ISA_2_7_MASKS_SERVER)) != 0)
@@ -10132,6 +10138,7 @@ rs6000_reassociation_width (unsigned int opc ATTRIBUTE_UNUSED,
     case PROCESSOR_POWER8:
     case PROCESSOR_POWER9:
     case PROCESSOR_POWER10:
+    case PROCESSOR_POWER11:
       if (DECIMAL_FLOAT_MODE_P (mode))
 	return 1;
       if (VECTOR_MODE_P (mode))
@@ -18213,7 +18220,8 @@ rs6000_adjust_cost (rtx_insn *insn, int dep_type, rtx_insn *dep_insn, int cost,
 
 	/* Separate a load from a narrower, dependent store.  */
 	if ((rs6000_sched_groups || rs6000_tune == PROCESSOR_POWER9
-	     || rs6000_tune == PROCESSOR_POWER10)
+	     || rs6000_tune == PROCESSOR_POWER10
+	     || rs6000_tune == PROCESSOR_POWER11)
 	    && GET_CODE (PATTERN (insn)) == SET
 	    && GET_CODE (PATTERN (dep_insn)) == SET
 	    && MEM_P (XEXP (PATTERN (insn), 1))
@@ -18252,6 +18260,7 @@ rs6000_adjust_cost (rtx_insn *insn, int dep_type, rtx_insn *dep_insn, int cost,
 		 || rs6000_tune == PROCESSOR_POWER8
 		 || rs6000_tune == PROCESSOR_POWER9
 		 || rs6000_tune == PROCESSOR_POWER10
+		 || rs6000_tune == PROCESSOR_POWER11
                  || rs6000_tune == PROCESSOR_CELL)
                 && recog_memoized (dep_insn)
                 && (INSN_CODE (dep_insn) >= 0))
@@ -18826,6 +18835,7 @@ rs6000_issue_rate (void)
   case PROCESSOR_POWER9:
     return 6;
   case PROCESSOR_POWER10:
+  case PROCESSOR_POWER11:
     return 8;
   default:
     return 1;
@@ -19541,8 +19551,10 @@ rs6000_sched_reorder (FILE *dump ATTRIBUTE_UNUSED, int sched_verbose,
   if (rs6000_tune == PROCESSOR_POWER6)
     load_store_pendulum = 0;
 
-  /* Do Power10 dependent reordering.  */
-  if (rs6000_tune == PROCESSOR_POWER10 && last_scheduled_insn)
+  /* Do Power10/Power11 dependent reordering.  */
+  if (last_scheduled_insn
+      && (rs6000_tune == PROCESSOR_POWER10
+	  || rs6000_tune == PROCESSOR_POWER11))
     power10_sched_reorder (ready, n_ready - 1);
 
   return rs6000_issue_rate ();
@@ -19566,8 +19578,10 @@ rs6000_sched_reorder2 (FILE *dump, int sched_verbose, rtx_insn **ready,
       && recog_memoized (last_scheduled_insn) >= 0)
     return power9_sched_reorder2 (ready, *pn_ready - 1);
 
-  /* Do Power10 dependent reordering.  */
-  if (rs6000_tune == PROCESSOR_POWER10 && last_scheduled_insn)
+  /* Do Power10/Power11 dependent reordering.  */
+  if (last_scheduled_insn
+      && (rs6000_tune == PROCESSOR_POWER10
+	  || rs6000_tune == PROCESSOR_POWER11))
     return power10_sched_reorder (ready, *pn_ready - 1);
 
   return cached_can_issue_more;
@@ -22784,7 +22798,8 @@ rs6000_register_move_cost (machine_mode mode,
 		 allocation a move within the same class might turn
 		 out to be a nop.  */
 	      if (rs6000_tune == PROCESSOR_POWER9
-		  || rs6000_tune == PROCESSOR_POWER10)
+		  || rs6000_tune == PROCESSOR_POWER10
+		  || rs6000_tune == PROCESSOR_POWER11)
 		ret = 3 * hard_regno_nregs (FIRST_GPR_REGNO, mode);
 	      else
 		ret = 4 * hard_regno_nregs (FIRST_GPR_REGNO, mode);
@@ -24443,6 +24458,7 @@ static struct rs6000_opt_mask const rs6000_opt_masks[] =
   { "float128-hardware",	OPTION_MASK_FLOAT128_HW,	false, true  },
   { "fprnd",			OPTION_MASK_FPRND,		false, true  },
   { "power10",			OPTION_MASK_POWER10,		false, true  },
+  { "power11",			OPTION_MASK_POWER11,		false, false },
   { "hard-dfp",			OPTION_MASK_DFP,		false, true  },
   { "htm",			OPTION_MASK_HTM,		false, true  },
   { "isel",			OPTION_MASK_ISEL,		false, true  },
diff --git a/gcc/config/rs6000/rs6000.h b/gcc/config/rs6000/rs6000.h
index 2cde2e329b0..197922fbb84 100644
--- a/gcc/config/rs6000/rs6000.h
+++ b/gcc/config/rs6000/rs6000.h
@@ -106,6 +106,7 @@
    you make changes here, make them also there.  */
 #define ASM_CPU_SPEC \
 "%{mcpu=native: %(asm_cpu_native); \
+  mcpu=power11: -mpower11; \
   mcpu=power10: -mpower10; \
   mcpu=power9: -mpower9; \
   mcpu=power8|mcpu=powerpc64le: -mpower8; \
diff --git a/gcc/config/rs6000/rs6000.md b/gcc/config/rs6000/rs6000.md
index 39c75af5c87..74b87f926d7 100644
--- a/gcc/config/rs6000/rs6000.md
+++ b/gcc/config/rs6000/rs6000.md
@@ -350,7 +350,7 @@
    ppc750,ppc7400,ppc7450,
    ppc403,ppc405,ppc440,ppc476,
    ppc8540,ppc8548,ppce300c2,ppce300c3,ppce500mc,ppce500mc64,ppce5500,ppce6500,
-   power4,power5,power6,power7,power8,power9,power10,
+   power4,power5,power6,power7,power8,power9,power10,power11,
    rs64a,mpccore,cell,ppca2,titan"
   (const (symbol_ref "(enum attr_cpu) rs6000_tune")))
 
diff --git a/gcc/config/rs6000/rs6000.opt b/gcc/config/rs6000/rs6000.opt
index e8ca70340df..94323bd1db2 100644
--- a/gcc/config/rs6000/rs6000.opt
+++ b/gcc/config/rs6000/rs6000.opt
@@ -585,6 +585,12 @@ Target Undocumented Var(rs6000_speculate_indirect_jumps) Init(1) Save
 mpower10
 Target Undocumented Mask(POWER10) Var(rs6000_isa_flags) WarnRemoved
 
+;; Users should not use -mpower11, but we need to use a bit to identify when
+;; the user changes the default cpu via  #pragma GCC target("cpu=power11")
+;; and then resets it later.
+mpower11
+Target Undocumented Mask(POWER11) Var(rs6000_isa_flags) WarnRemoved
+
 mprefixed
 Target Mask(PREFIXED) Var(rs6000_isa_flags)
 Generate (do not generate) prefixed memory instructions.
diff --git a/gcc/doc/invoke.texi b/gcc/doc/invoke.texi
index f82f7d2817b..80476bcf37a 100644
--- a/gcc/doc/invoke.texi
+++ b/gcc/doc/invoke.texi
@@ -31321,7 +31321,7 @@ Supported values for @var{cpu_type} are @samp{401}, @samp{403},
 @samp{e6500}, @samp{ec603e}, @samp{G3}, @samp{G4}, @samp{G5},
 @samp{titan}, @samp{power3}, @samp{power4}, @samp{power5}, @samp{power5+},
 @samp{power6}, @samp{power6x}, @samp{power7}, @samp{power8},
-@samp{power9}, @samp{power10}, @samp{powerpc}, @samp{powerpc64},
+@samp{power9}, @samp{power10}, @samp{power11}, @samp{powerpc}, @samp{powerpc64},
 @samp{powerpc64le}, @samp{rs64}, and @samp{native}.
 
 @option{-mcpu=powerpc}, @option{-mcpu=powerpc64}, and
diff --git a/gcc/testsuite/gcc.target/powerpc/power11-1.c b/gcc/testsuite/gcc.target/powerpc/power11-1.c
new file mode 100644
index 00000000000..029a59639b1
--- /dev/null
+++ b/gcc/testsuite/gcc.target/powerpc/power11-1.c
@@ -0,0 +1,13 @@
+/* { dg-do compile } */
+/* { dg-options "-mdejagnu-cpu=power11 -O2" } */
+
+/* Basic check to see if the compiler supports -mcpu=power11 and if it defines
+   _ARCH_PWR11.  */
+
+#ifndef _ARCH_PWR11
+#error "-mcpu=power11 is not supported"
+#endif
+
+void foo (void)
+{
+}
diff --git a/gcc/testsuite/gcc.target/powerpc/power11-2.c b/gcc/testsuite/gcc.target/powerpc/power11-2.c
new file mode 100644
index 00000000000..e3438e35015
--- /dev/null
+++ b/gcc/testsuite/gcc.target/powerpc/power11-2.c
@@ -0,0 +1,19 @@
+/* { dg-do compile } */
+/* { dg-options "-O2" } */
+
+/* Check if we can set the power11 target via a target attribute.  */
+
+__attribute__((__target__("cpu=power9")))
+void foo_p9 (void)
+{
+}
+
+__attribute__((__target__("cpu=power10")))
+void foo_p10 (void)
+{
+}
+
+__attribute__((__target__("cpu=power11")))
+void foo_p11 (void)
+{
+}
diff --git a/gcc/testsuite/gcc.target/powerpc/power11-3.c b/gcc/testsuite/gcc.target/powerpc/power11-3.c
new file mode 100644
index 00000000000..fa1aedd0429
--- /dev/null
+++ b/gcc/testsuite/gcc.target/powerpc/power11-3.c
@@ -0,0 +1,9 @@
+/* { dg-do compile }  */
+/* { dg-options "-mdejagnu-cpu=power8 -O2" }  */
+
+/* Check if we can set the power11 target via a target_clones attribute.  */
+
+__attribute__((__target_clones__("cpu=power11,cpu=power9,default")))
+void foo (void)
+{
+}

commit 5a63e19fd405acaada2792492353d9979f9e24a8
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Wed Aug 14 02:22:22 2024

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index dbe6692b511..0670abecce5 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,36 @@
+2024-08-13  Michael Meissner  <meissner@linux.ibm.com>
+
+	* config.gcc (powerpc*-*-*): Add support for power11.
+	* config/rs6000/aix71.h (ASM_CPU_SPEC): Add support for -mcpu=power11.
+	* config/rs6000/aix72.h (ASM_CPU_SPEC): Likewise.
+	* config/rs6000/aix73.h (ASM_CPU_SPEC): Likewise.
+	* config/rs6000/driver-rs6000.cc (asm_names): Likewise.
+	* config/rs6000/ppc-auxv.h (PPC_PLATFORM_POWER11): New define.
+	* config/rs6000/rs6000-builtin.cc (cpu_is_info): Add power11.
+	* config/rs6000/rs6000-c.cc (rs6000_target_modify_macros): Define
+	_ARCH_PWR11 if -mcpu=power11.
+	* config/rs6000/rs6000-cpus.def (POWER11_MASKS_SERVER): New define.
+	(POWERPC_MASKS): Add power11.
+	(power11 cpu): Add power11 definition.
+	* config/rs6000/rs6000-opts.h (PROCESSOR_POWER11): Add power11 processor.
+	* config/rs6000/rs6000-string.cc (expand_compare_loop): Likewise.
+	* config/rs6000/rs6000-tables.opt: Regenerate.
+	* config/rs6000/rs6000.cc (rs6000_option_override_internal): Add power11
+	support.
+	(rs6000_machine_from_flags): Likewise.
+	(rs6000_reassociation_width): Likewise.
+	(rs6000_adjust_cost): Likewise.
+	(rs6000_issue_rate): Likewise.
+	(rs6000_sched_reorder): Likewise.
+	(rs6000_sched_reorder2): Likewise.
+	(rs6000_register_move_cost): Likewise.
+	(rs6000_opt_masks): Likewise.
+	* config/rs6000/rs6000.h (ASM_CPU_SPEC): Likewise.
+	* config/rs6000/rs6000.md (cpu attribute): Add power11.
+	* config/rs6000/rs6000.opt (-mpower11): Add internal power11 flag.
+	* doc/invoke.texi (RS/6000 and PowerPC Options): Document -mcpu=power11.
+	* config/rs6000/power10.md (all reservations): Add power11 support.
+
 2024-08-09  Jakub Jelinek  <jakub@redhat.com>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index e2b84f6ebd8..94834f4f423 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240813
+20240814
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index f19069a762d..040710439e7 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,9 @@
+2024-08-13  Michael Meissner  <meissner@linux.ibm.com>
+
+	* gcc.target/powerpc/power11-1.c: New test.
+	* gcc.target/powerpc/power11-2.c: Likewise.
+	* gcc.target/powerpc/power11-3.c: Likewise.
+
 2024-08-09  Jakub Jelinek  <jakub@redhat.com>
 
 	Backported from master:

commit e903ada5e8881acec734eb3f89c3644bbd8da7e9
Author: Stefan Schulze Frielinghaus <stefansf@gcc.gnu.org>
Date:   Wed Aug 14 20:12:35 2024

    s390: Fix high-level builtins vec_gfmsum{,_accum}_128
    
    Starting with r14-9449-g9f2b16ce1efef0 builtins were streamlined with
    those in LLVM.  In particular s390_vgfm{,a}g have been changed from
    UV16QI to UINT128 in order to match those in LLVM.  However, these
    low-level builtins are directly used by the high-level builtins
    vec_gfmsum{,_accum}_128 which expect UV16QI instead.  Therefore,
    introduce new low-level builtins s390_vgfm{,a}g_128 and make use of
    them, respectively.
    
    gcc/ChangeLog:
    
            * config/s390/s390-builtin-types.def (BT_FN_UV16QI_UV2DI_UV2DI):
            New.
            (BT_FN_UV16QI_UV2DI_UV2DI_UV16QI): New.
            * config/s390/s390-builtins.def (s390_vgfmg_128): New.
            (s390_vgfmag_128): New.
            * config/s390/vecintrin.h (vec_gfmsum_128): Use s390_vgfmg_128.
            (vec_gfmsum_accum_128): Use s390_vgfmag_128.
    
    (cherry picked from commit e8a7142a697c5d2673adea33ba23af82a89c9559)

diff --git a/gcc/config/s390/s390-builtin-types.def b/gcc/config/s390/s390-builtin-types.def
index d70eaade8ea..e6f5631ed7a 100644
--- a/gcc/config/s390/s390-builtin-types.def
+++ b/gcc/config/s390/s390-builtin-types.def
@@ -221,6 +221,7 @@ DEF_FN_TYPE_2 (BT_FN_UV16QI_UCHAR_UCHAR, BT_UV16QI, BT_UCHAR, BT_UCHAR)
 DEF_FN_TYPE_2 (BT_FN_UV16QI_UV16QI_INTPTR, BT_UV16QI, BT_UV16QI, BT_INTPTR)
 DEF_FN_TYPE_2 (BT_FN_UV16QI_UV16QI_UCHAR, BT_UV16QI, BT_UV16QI, BT_UCHAR)
 DEF_FN_TYPE_2 (BT_FN_UV16QI_UV16QI_UV16QI, BT_UV16QI, BT_UV16QI, BT_UV16QI)
+DEF_FN_TYPE_2 (BT_FN_UV16QI_UV2DI_UV2DI, BT_UV16QI, BT_UV2DI, BT_UV2DI)
 DEF_FN_TYPE_2 (BT_FN_UV16QI_UV8HI_UV8HI, BT_UV16QI, BT_UV8HI, BT_UV8HI)
 DEF_FN_TYPE_2 (BT_FN_UV2DI_UCHAR_UCHAR, BT_UV2DI, BT_UCHAR, BT_UCHAR)
 DEF_FN_TYPE_2 (BT_FN_UV2DI_ULONGLONG_INT, BT_UV2DI, BT_ULONGLONG, BT_INT)
@@ -299,6 +300,7 @@ DEF_FN_TYPE_3 (BT_FN_UV16QI_UV16QI_UCHAR_INT, BT_UV16QI, BT_UV16QI, BT_UCHAR, BT
 DEF_FN_TYPE_3 (BT_FN_UV16QI_UV16QI_UV16QI_INT, BT_UV16QI, BT_UV16QI, BT_UV16QI, BT_INT)
 DEF_FN_TYPE_3 (BT_FN_UV16QI_UV16QI_UV16QI_INTPTR, BT_UV16QI, BT_UV16QI, BT_UV16QI, BT_INTPTR)
 DEF_FN_TYPE_3 (BT_FN_UV16QI_UV16QI_UV16QI_UV16QI, BT_UV16QI, BT_UV16QI, BT_UV16QI, BT_UV16QI)
+DEF_FN_TYPE_3 (BT_FN_UV16QI_UV2DI_UV2DI_UV16QI, BT_UV16QI, BT_UV2DI, BT_UV2DI, BT_UV16QI)
 DEF_FN_TYPE_3 (BT_FN_UV16QI_UV8HI_UV8HI_INTPTR, BT_UV16QI, BT_UV8HI, BT_UV8HI, BT_INTPTR)
 DEF_FN_TYPE_3 (BT_FN_UV2DI_UV2DI_ULONGLONG_INT, BT_UV2DI, BT_UV2DI, BT_ULONGLONG, BT_INT)
 DEF_FN_TYPE_3 (BT_FN_UV2DI_UV2DI_UV2DI_INT, BT_UV2DI, BT_UV2DI, BT_UV2DI, BT_INT)
diff --git a/gcc/config/s390/s390-builtins.def b/gcc/config/s390/s390-builtins.def
index 3a63213e571..7f6190fa810 100644
--- a/gcc/config/s390/s390-builtins.def
+++ b/gcc/config/s390/s390-builtins.def
@@ -1666,6 +1666,7 @@ B_DEF      (s390_vgfmb,                 vec_gfmsumv16qi,    0,
 B_DEF      (s390_vgfmh,                 vec_gfmsumv8hi,     0,                  B_VX,               0,                  BT_FN_UV4SI_UV8HI_UV8HI)
 B_DEF      (s390_vgfmf,                 vec_gfmsumv4si,     0,                  B_VX,               0,                  BT_FN_UV2DI_UV4SI_UV4SI)
 B_DEF      (s390_vgfmg,                 vec_gfmsum_128,     0,                  B_VX,               0,                  BT_FN_UINT128_UV2DI_UV2DI)
+B_DEF      (s390_vgfmg_128,             vec_gfmsum_128,     0,                  B_VX,               0,                  BT_FN_UV16QI_UV2DI_UV2DI)
 
 OB_DEF     (s390_vec_gfmsum_accum,      s390_vec_gfmsum_accum_u8,s390_vec_gfmsum_accum_u32,B_VX,    BT_FN_OV4SI_OV4SI_OV4SI_OV4SI)
 OB_DEF_VAR (s390_vec_gfmsum_accum_u8,   s390_vgfmab,        0,                  0,                  BT_OV_UV8HI_UV16QI_UV16QI_UV8HI)
@@ -1676,6 +1677,7 @@ B_DEF      (s390_vgfmab,                vec_gfmsum_accumv16qi,0,
 B_DEF      (s390_vgfmah,                vec_gfmsum_accumv8hi,0,                 B_VX,               0,                  BT_FN_UV4SI_UV8HI_UV8HI_UV4SI)
 B_DEF      (s390_vgfmaf,                vec_gfmsum_accumv4si,0,                 B_VX,               0,                  BT_FN_UV2DI_UV4SI_UV4SI_UV2DI)
 B_DEF      (s390_vgfmag,                vec_gfmsum_accum_128,0,                 B_VX,               0,                  BT_FN_UINT128_UV2DI_UV2DI_UINT128)
+B_DEF      (s390_vgfmag_128,            vec_gfmsum_accum_128,0,                 B_VX,               0,                  BT_FN_UV16QI_UV2DI_UV2DI_UV16QI)
 
 OB_DEF     (s390_vec_abs,               s390_vec_abs_s8,    s390_vec_abs_dbl,   B_VX,               BT_FN_OV4SI_OV4SI)
 OB_DEF_VAR (s390_vec_abs_s8,            s390_vlpb,          0,                  0,                  BT_OV_V16QI_V16QI)
diff --git a/gcc/config/s390/vecintrin.h b/gcc/config/s390/vecintrin.h
index 9abbd761067..daeed91ef97 100644
--- a/gcc/config/s390/vecintrin.h
+++ b/gcc/config/s390/vecintrin.h
@@ -98,8 +98,8 @@ __lcbb(const void *ptr, int bndry)
 #define vec_splat_u64 __builtin_s390_vec_splat_u64
 #define vec_splat_s64 __builtin_s390_vec_splat_s64
 #define vec_checksum __builtin_s390_vcksm
-#define vec_gfmsum_128 __builtin_s390_vgfmg
-#define vec_gfmsum_accum_128 __builtin_s390_vgfmag
+#define vec_gfmsum_128 __builtin_s390_vgfmg_128
+#define vec_gfmsum_accum_128 __builtin_s390_vgfmag_128
 #define vec_ceil(X)   __builtin_s390_vfi((X), 4, 6)
 #define vec_roundp(X) __builtin_s390_vfi((X), 4, 6)
 #define vec_floor(X)  __builtin_s390_vfi((X), 4, 7)

commit 726898510b02ffd8262539afd01d6b3600200596
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Thu Aug 15 02:26:05 2024

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 0670abecce5..449384cd6e0 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,16 @@
+2024-08-14  Stefan Schulze Frielinghaus  <stefansf@gcc.gnu.org>
+
+	Backported from master:
+	2024-08-14  Stefan Schulze Frielinghaus  <stefansf@gcc.gnu.org>
+
+	* config/s390/s390-builtin-types.def (BT_FN_UV16QI_UV2DI_UV2DI):
+	New.
+	(BT_FN_UV16QI_UV2DI_UV2DI_UV16QI): New.
+	* config/s390/s390-builtins.def (s390_vgfmg_128): New.
+	(s390_vgfmag_128): New.
+	* config/s390/vecintrin.h (vec_gfmsum_128): Use s390_vgfmg_128.
+	(vec_gfmsum_accum_128): Use s390_vgfmag_128.
+
 2024-08-13  Michael Meissner  <meissner@linux.ibm.com>
 
 	* config.gcc (powerpc*-*-*): Add support for power11.
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 94834f4f423..2ea444e25fe 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240814
+20240815

commit 8c98f0601f7f0d8051eda47370939198f4e01fc4
Author: Pan Li <pan2.li@intel.com>
Date:   Thu May 9 04:56:46 2024

    RISC-V: Make full-vec-move1.c test robust for optimization
    
    During investigate the support of early break autovec, we notice
    the test full-vec-move1.c will be optimized to 'return 0;' in main
    function body.  Because somehow the value of V type is compiler
    time constant,  and then the second loop will be considered as
    assert (true).
    
    Thus,  the ccp4 pass will eliminate these stmt and just return 0.
    
    typedef int16_t V __attribute__((vector_size (128)));
    
    int main ()
    {
      V v;
      for (int i = 0; i < sizeof (v) / sizeof (v[0]); i++)
        (v)[i] = i;
    
      V res = v;
      for (int i = 0; i < sizeof (v) / sizeof (v[0]); i++)
        assert (res[i] == i); // will be optimized to assert (true)
    }
    
    This patch would like to introduce a extern function to use the res[i]
    that get rid of the ccp4 optimization.
    
    gcc/testsuite/ChangeLog:
    
            * gcc.target/riscv/rvv/autovec/vls-vlmax/full-vec-move1.c:
            Introduce extern func use to get rid of ccp4 optimization.
    
    Signed-off-by: Pan Li <pan2.li@intel.com>
    (cherry picked from commit b1520d2260c5e0cfcd7a4354fab70f66e2912ff2)

diff --git a/gcc/testsuite/gcc.target/riscv/rvv/autovec/vls-vlmax/full-vec-move1.c b/gcc/testsuite/gcc.target/riscv/rvv/autovec/vls-vlmax/full-vec-move1.c
index d73bad4af6f..fae2ae91572 100644
--- a/gcc/testsuite/gcc.target/riscv/rvv/autovec/vls-vlmax/full-vec-move1.c
+++ b/gcc/testsuite/gcc.target/riscv/rvv/autovec/vls-vlmax/full-vec-move1.c
@@ -2,11 +2,12 @@
 /* { dg-additional-options "-std=c99 -O3 -march=rv64gcv_zvl128b -mabi=lp64d -fno-vect-cost-model -mrvv-vector-bits=zvl" } */
 
 #include <stdint-gcc.h>
-#include <assert.h>
 
 /* This would cause us to emit a vl1r.v for VNx4HImode even when
    the hardware vector size vl > 64.  */
 
+extern int16_t test_element (int16_t);
+
 typedef int16_t V __attribute__((vector_size (128)));
 
 int main ()
@@ -14,9 +15,10 @@ int main ()
   V v;
   for (int i = 0; i < sizeof (v) / sizeof (v[0]); i++)
     (v)[i] = i;
+
   V res = v;
   for (int i = 0; i < sizeof (v) / sizeof (v[0]); i++)
-    assert (res[i] == i);
+    test_element (res[i]);
 }
 
 /* { dg-final { scan-assembler-not {vl[1248]r.v} } }  */

commit d9bd361d893d3b62797f2962bca1b8d56521f3c3
Author: Craig Blackmore <craig.blackmore@embecosm.com>
Date:   Sun Jun 23 06:07:06 2024

    [PATCH] RISC-V: Fix unresolved mcpu-[67].c tests
    
    These tests check the sched2 dump, so skip them for optimization levels
    that do not enable sched2.
    
    gcc/testsuite/ChangeLog:
    
            * gcc.target/riscv/mcpu-6.c: Skip for -O0, -O1, -Og.
            * gcc.target/riscv/mcpu-7.c: Likewise.
    
    (cherry picked from commit 77f3b3419d476e90a2b82dff2204466aba3b9c2c)

diff --git a/gcc/testsuite/gcc.target/riscv/mcpu-6.c b/gcc/testsuite/gcc.target/riscv/mcpu-6.c
index 96faa01653e..0126011939f 100644
--- a/gcc/testsuite/gcc.target/riscv/mcpu-6.c
+++ b/gcc/testsuite/gcc.target/riscv/mcpu-6.c
@@ -1,4 +1,5 @@
 /* { dg-do compile } */
+/* { dg-skip-if "" { *-*-* } { "-O0" "-O1" "-Og" } } */
 /* Verify -mtune has higher priority than -mcpu for pipeline model .  */
 /* { dg-options "-mcpu=sifive-u74 -mtune=rocket -fdump-rtl-sched2-details -march=rv32i -mabi=ilp32" } */
 /* { dg-final { scan-rtl-dump "simple_return\[ \]+:alu" "sched2" } } */
diff --git a/gcc/testsuite/gcc.target/riscv/mcpu-7.c b/gcc/testsuite/gcc.target/riscv/mcpu-7.c
index 6832323e529..656436343bd 100644
--- a/gcc/testsuite/gcc.target/riscv/mcpu-7.c
+++ b/gcc/testsuite/gcc.target/riscv/mcpu-7.c
@@ -1,4 +1,5 @@
 /* { dg-do compile } */
+/* { dg-skip-if "" { *-*-* } { "-O0" "-O1" "-Og" } } */
 /* Verify -mtune has higher priority than -mcpu for pipeline model .  */
 /* { dg-options "-mcpu=sifive-s21 -mtune=sifive-u74 -fdump-rtl-sched2-details -march=rv32i -mabi=ilp32" } */
 /* { dg-final { scan-rtl-dump "simple_return\[ \]+:sifive_7_B" "sched2" } } */

commit 63c51e09d160a44fdce1199e8efe9d293f773a2c
Author: Patrick Palka <ppalka@redhat.com>
Date:   Thu Aug 15 16:20:18 2024

    c++/coroutines: fix passing *this to promise type, again [PR116327]
    
    In r15-2210 we got rid of the unnecessary cast to lvalue reference when
    passing *this to the promise type ctor, and as a drive-by change we also
    simplified the code to use cp_build_fold_indirect_ref.
    
    But it turns out cp_build_fold_indirect_ref does too much here, namely
    it has a shortcut for returning current_class_ref if the operand is
    current_class_ptr.  The problem with that shortcut is current_class_ref
    might have gotten clobbered earlier if it appeared in the function body,
    since rewrite_param_uses walks and rewrites in-place all local variable
    uses to their corresponding frame copy.
    
    So later cp_build_fold_indirect_ref for *this will instead return the
    clobbered current_class_ref i.e. *frame_ptr->this, which doesn't make
    sense here since we're in the ramp function and not the actor function
    where frame_ptr is in scope.
    
    This patch fixes this by using the build_fold_indirect_ref instead of
    cp_build_fold_indirect_ref.
    
            PR c++/116327
            PR c++/104981
            PR c++/115550
    
    gcc/cp/ChangeLog:
    
            * coroutines.cc (morph_fn_to_coro): Use build_fold_indirect_ref
            instead of cp_build_fold_indirect_ref.
    
    gcc/testsuite/ChangeLog:
    
            * g++.dg/coroutines/pr104981-preview-this.C: Improve coverage by
            adding a non-static data member use within the coroutine member
            function.
            * g++.dg/coroutines/pr116327-preview-this.C: New test.
    
    Reviewed-by: Jason Merrill <jason@redhat.com>
    (cherry picked from commit 303bed670af962c01b77a4f0c51de97f70e8167e)

diff --git a/gcc/cp/coroutines.cc b/gcc/cp/coroutines.cc
index 71e64960c5a..f5cfc80ca39 100644
--- a/gcc/cp/coroutines.cc
+++ b/gcc/cp/coroutines.cc
@@ -4618,7 +4618,9 @@ morph_fn_to_coro (tree orig, tree *resumer, tree *destroyer)
 	  if (parm_i->this_ptr || parm_i->lambda_cobj)
 	    {
 	      /* We pass a reference to *this to the allocator lookup.  */
-	      tree this_ref = cp_build_fold_indirect_ref (arg);
+	      /* It's unsafe to use the cp_ version here since current_class_ref
+		 might've gotten clobbered earlier during rewrite_param_uses.  */
+	      tree this_ref = build_fold_indirect_ref (arg);
 	      vec_safe_push (args, this_ref);
 	    }
 	  else
@@ -4838,7 +4840,9 @@ morph_fn_to_coro (tree orig, tree *resumer, tree *destroyer)
 	  if (parm.this_ptr || parm.lambda_cobj)
 	    {
 	      /* We pass a reference to *this to the param preview.  */
-	      tree this_ref = cp_build_fold_indirect_ref (arg);
+	      /* It's unsafe to use the cp_ version here since current_class_ref
+		 might've gotten clobbered earlier during rewrite_param_uses.  */
+	      tree this_ref = build_fold_indirect_ref (arg);
 	      vec_safe_push (promise_args, this_ref);
 	    }
 	  else if (parm.rv_ref)
diff --git a/gcc/testsuite/g++.dg/coroutines/pr104981-preview-this.C b/gcc/testsuite/g++.dg/coroutines/pr104981-preview-this.C
index 81eb963db4a..9f1e3970ce3 100644
--- a/gcc/testsuite/g++.dg/coroutines/pr104981-preview-this.C
+++ b/gcc/testsuite/g++.dg/coroutines/pr104981-preview-this.C
@@ -23,8 +23,10 @@ struct PromiseType {
 };
 
 struct Derived : Base {
+  int m = 41;
   Result f() {
-   co_return 42;
+   ++m;
+   co_return m;
   }
 };
 
diff --git a/gcc/testsuite/g++.dg/coroutines/pr116327-preview-this.C b/gcc/testsuite/g++.dg/coroutines/pr116327-preview-this.C
new file mode 100644
index 00000000000..27b69a41392
--- /dev/null
+++ b/gcc/testsuite/g++.dg/coroutines/pr116327-preview-this.C
@@ -0,0 +1,22 @@
+// PR c++/116327 - ICE in coroutine with parameter preview on lambda with captures
+
+#include <coroutine>
+
+struct coroutine{
+  struct promise_type{
+    promise_type(const auto &...){}
+    std::suspend_never initial_suspend(){ return {}; }
+    std::suspend_always final_suspend()noexcept{ return {}; }
+    void unhandled_exception(){}
+    coroutine get_return_object(){ return {}; }
+    void return_value(int)noexcept{}
+  };
+};
+
+int main(){
+  auto f = [a=0](auto) -> coroutine {
+    co_return 2;
+  };
+  f(0);
+  return 0;
+}

commit ccca8dfba8afdbc2da2c00e273fbe4f16eee4521
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Fri Aug 16 02:22:18 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 2ea444e25fe..c11f769cc2c 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240815
+20240816
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index 46781e0fac0..3dd34cf4e81 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -1,3 +1,14 @@
+2024-08-15  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2024-08-15  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/116327
+	PR c++/104981
+	PR c++/115550
+	* coroutines.cc (morph_fn_to_coro): Use build_fold_indirect_ref
+	instead of cp_build_fold_indirect_ref.
+
 2024-08-06  Jason Merrill  <jason@redhat.com>
 
 	Backported from master:
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 040710439e7..de25ede2895 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,32 @@
+2024-08-15  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2024-08-15  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/116327
+	PR c++/104981
+	PR c++/115550
+	* g++.dg/coroutines/pr104981-preview-this.C: Improve coverage by
+	adding a non-static data member use within the coroutine member
+	function.
+	* g++.dg/coroutines/pr116327-preview-this.C: New test.
+
+2024-08-15  Craig Blackmore  <craig.blackmore@embecosm.com>
+
+	Backported from master:
+	2024-06-23  Craig Blackmore  <craig.blackmore@embecosm.com>
+
+	* gcc.target/riscv/mcpu-6.c: Skip for -O0, -O1, -Og.
+	* gcc.target/riscv/mcpu-7.c: Likewise.
+
+2024-08-15  Pan Li  <pan2.li@intel.com>
+
+	Backported from master:
+	2024-05-09  Pan Li  <pan2.li@intel.com>
+
+	* gcc.target/riscv/rvv/autovec/vls-vlmax/full-vec-move1.c:
+	Introduce extern func use to get rid of ccp4 optimization.
+
 2024-08-13  Michael Meissner  <meissner@linux.ibm.com>
 
 	* gcc.target/powerpc/power11-1.c: New test.

commit 4e7735a8d87559bbddfe3a985786996e22241f8d
Author: liuhongt <hongtao.liu@intel.com>
Date:   Mon Aug 12 08:35:31 2024

    Move ix86_align_loops into a separate pass and insert the pass after pass_endbr_and_patchable_area.
    
    gcc/ChangeLog:
    
            PR target/116174
            * config/i386/i386.cc (ix86_align_loops): Move this to ..
            * config/i386/i386-features.cc (ix86_align_loops): .. here.
            (class pass_align_tight_loops): New class.
            (make_pass_align_tight_loops): New function.
            * config/i386/i386-passes.def: Insert pass_align_tight_loops
            after pass_insert_endbr_and_patchable_area.
            * config/i386/i386-protos.h (make_pass_align_tight_loops): New
            declare.
    
    gcc/testsuite/ChangeLog:
    
            * gcc.target/i386/pr116174.c: New test.
    
    (cherry picked from commit c3c83d22d212a35cb1bfb8727477819463f0dcd8)

diff --git a/gcc/config/i386/i386-features.cc b/gcc/config/i386/i386-features.cc
index e3e004d5526..7de19d42363 100644
--- a/gcc/config/i386/i386-features.cc
+++ b/gcc/config/i386/i386-features.cc
@@ -3253,6 +3253,197 @@ make_pass_remove_partial_avx_dependency (gcc::context *ctxt)
   return new pass_remove_partial_avx_dependency (ctxt);
 }
 
+/* When a hot loop can be fit into one cacheline,
+   force align the loop without considering the max skip.  */
+static void
+ix86_align_loops ()
+{
+  basic_block bb;
+
+  /* Don't do this when we don't know cache line size.  */
+  if (ix86_cost->prefetch_block == 0)
+    return;
+
+  loop_optimizer_init (AVOID_CFG_MODIFICATIONS);
+  profile_count count_threshold = cfun->cfg->count_max / param_align_threshold;
+  FOR_EACH_BB_FN (bb, cfun)
+    {
+      rtx_insn *label = BB_HEAD (bb);
+      bool has_fallthru = 0;
+      edge e;
+      edge_iterator ei;
+
+      if (!LABEL_P (label))
+	continue;
+
+      profile_count fallthru_count = profile_count::zero ();
+      profile_count branch_count = profile_count::zero ();
+
+      FOR_EACH_EDGE (e, ei, bb->preds)
+	{
+	  if (e->flags & EDGE_FALLTHRU)
+	    has_fallthru = 1, fallthru_count += e->count ();
+	  else
+	    branch_count += e->count ();
+	}
+
+      if (!fallthru_count.initialized_p () || !branch_count.initialized_p ())
+	continue;
+
+      if (bb->loop_father
+	  && bb->loop_father->latch != EXIT_BLOCK_PTR_FOR_FN (cfun)
+	  && (has_fallthru
+	      ? (!(single_succ_p (bb)
+		   && single_succ (bb) == EXIT_BLOCK_PTR_FOR_FN (cfun))
+		 && optimize_bb_for_speed_p (bb)
+		 && branch_count + fallthru_count > count_threshold
+		 && (branch_count > fallthru_count * param_align_loop_iterations))
+	      /* In case there'no fallthru for the loop.
+		 Nops inserted won't be executed.  */
+	      : (branch_count > count_threshold
+		 || (bb->count > bb->prev_bb->count * 10
+		     && (bb->prev_bb->count
+			 <= ENTRY_BLOCK_PTR_FOR_FN (cfun)->count / 2)))))
+	{
+	  rtx_insn* insn, *end_insn;
+	  HOST_WIDE_INT size = 0;
+	  bool padding_p = true;
+	  basic_block tbb = bb;
+	  unsigned cond_branch_num = 0;
+	  bool detect_tight_loop_p = false;
+
+	  for (unsigned int i = 0; i != bb->loop_father->num_nodes;
+	       i++, tbb = tbb->next_bb)
+	    {
+	      /* Only handle continuous cfg layout. */
+	      if (bb->loop_father != tbb->loop_father)
+		{
+		  padding_p = false;
+		  break;
+		}
+
+	      FOR_BB_INSNS (tbb, insn)
+		{
+		  if (!NONDEBUG_INSN_P (insn))
+		    continue;
+		  size += ix86_min_insn_size (insn);
+
+		  /* We don't know size of inline asm.
+		     Don't align loop for call.  */
+		  if (asm_noperands (PATTERN (insn)) >= 0
+		      || CALL_P (insn))
+		    {
+		      size = -1;
+		      break;
+		    }
+		}
+
+	      if (size == -1 || size > ix86_cost->prefetch_block)
+		{
+		  padding_p = false;
+		  break;
+		}
+
+	      FOR_EACH_EDGE (e, ei, tbb->succs)
+		{
+		  /* It could be part of the loop.  */
+		  if (e->dest == bb)
+		    {
+		      detect_tight_loop_p = true;
+		      break;
+		    }
+		}
+
+	      if (detect_tight_loop_p)
+		break;
+
+	      end_insn = BB_END (tbb);
+	      if (JUMP_P (end_insn))
+		{
+		  /* For decoded icache:
+		     1. Up to two branches are allowed per Way.
+		     2. A non-conditional branch is the last micro-op in a Way.
+		  */
+		  if (onlyjump_p (end_insn)
+		      && (any_uncondjump_p (end_insn)
+			  || single_succ_p (tbb)))
+		    {
+		      padding_p = false;
+		      break;
+		    }
+		  else if (++cond_branch_num >= 2)
+		    {
+		      padding_p = false;
+		      break;
+		    }
+		}
+
+	    }
+
+	  if (padding_p && detect_tight_loop_p)
+	    {
+	      emit_insn_before (gen_max_skip_align (GEN_INT (ceil_log2 (size)),
+						    GEN_INT (0)), label);
+	      /* End of function.  */
+	      if (!tbb || tbb == EXIT_BLOCK_PTR_FOR_FN (cfun))
+		break;
+	      /* Skip bb which already fits into one cacheline.  */
+	      bb = tbb;
+	    }
+	}
+    }
+
+  loop_optimizer_finalize ();
+  free_dominance_info (CDI_DOMINATORS);
+}
+
+namespace {
+
+const pass_data pass_data_align_tight_loops =
+{
+  RTL_PASS, /* type */
+  "align_tight_loops", /* name */
+  OPTGROUP_NONE, /* optinfo_flags */
+  TV_MACH_DEP, /* tv_id */
+  0, /* properties_required */
+  0, /* properties_provided */
+  0, /* properties_destroyed */
+  0, /* todo_flags_start */
+  0, /* todo_flags_finish */
+};
+
+class pass_align_tight_loops : public rtl_opt_pass
+{
+public:
+  pass_align_tight_loops (gcc::context *ctxt)
+    : rtl_opt_pass (pass_data_align_tight_loops, ctxt)
+  {}
+
+  /* opt_pass methods: */
+  bool gate (function *) final override
+    {
+      return optimize && optimize_function_for_speed_p (cfun);
+    }
+
+  unsigned int execute (function *) final override
+    {
+      timevar_push (TV_MACH_DEP);
+#ifdef ASM_OUTPUT_MAX_SKIP_ALIGN
+      ix86_align_loops ();
+#endif
+      timevar_pop (TV_MACH_DEP);
+      return 0;
+    }
+}; // class pass_align_tight_loops
+
+} // anon namespace
+
+rtl_opt_pass *
+make_pass_align_tight_loops (gcc::context *ctxt)
+{
+  return new pass_align_tight_loops (ctxt);
+}
+
 /* This compares the priority of target features in function DECL1
    and DECL2.  It returns positive value if DECL1 is higher priority,
    negative value if DECL2 is higher priority and 0 if they are the
diff --git a/gcc/config/i386/i386-passes.def b/gcc/config/i386/i386-passes.def
index 7d96766f7b9..e500f15c997 100644
--- a/gcc/config/i386/i386-passes.def
+++ b/gcc/config/i386/i386-passes.def
@@ -31,5 +31,8 @@ along with GCC; see the file COPYING3.  If not see
   INSERT_PASS_BEFORE (pass_cse2, 1, pass_stv, true /* timode_p */);
 
   INSERT_PASS_BEFORE (pass_shorten_branches, 1, pass_insert_endbr_and_patchable_area);
+  /* pass_align_tight_loops must be after pass_insert_endbr_and_patchable_area.
+     PR116174.  */
+  INSERT_PASS_BEFORE (pass_shorten_branches, 1, pass_align_tight_loops);
 
   INSERT_PASS_AFTER (pass_combine, 1, pass_remove_partial_avx_dependency);
diff --git a/gcc/config/i386/i386-protos.h b/gcc/config/i386/i386-protos.h
index 46214a63974..36c7b1aed42 100644
--- a/gcc/config/i386/i386-protos.h
+++ b/gcc/config/i386/i386-protos.h
@@ -419,6 +419,7 @@ extern rtl_opt_pass *make_pass_insert_endbr_and_patchable_area
   (gcc::context *);
 extern rtl_opt_pass *make_pass_remove_partial_avx_dependency
   (gcc::context *);
+extern rtl_opt_pass *make_pass_align_tight_loops (gcc::context *);
 
 extern bool ix86_has_no_direct_extern_access;
 
diff --git a/gcc/config/i386/i386.cc b/gcc/config/i386/i386.cc
index 6f89891d3cb..288c69467d6 100644
--- a/gcc/config/i386/i386.cc
+++ b/gcc/config/i386/i386.cc
@@ -23444,150 +23444,6 @@ ix86_split_stlf_stall_load ()
     }
 }
 
-/* When a hot loop can be fit into one cacheline,
-   force align the loop without considering the max skip.  */
-static void
-ix86_align_loops ()
-{
-  basic_block bb;
-
-  /* Don't do this when we don't know cache line size.  */
-  if (ix86_cost->prefetch_block == 0)
-    return;
-
-  loop_optimizer_init (AVOID_CFG_MODIFICATIONS);
-  profile_count count_threshold = cfun->cfg->count_max / param_align_threshold;
-  FOR_EACH_BB_FN (bb, cfun)
-    {
-      rtx_insn *label = BB_HEAD (bb);
-      bool has_fallthru = 0;
-      edge e;
-      edge_iterator ei;
-
-      if (!LABEL_P (label))
-	continue;
-
-      profile_count fallthru_count = profile_count::zero ();
-      profile_count branch_count = profile_count::zero ();
-
-      FOR_EACH_EDGE (e, ei, bb->preds)
-	{
-	  if (e->flags & EDGE_FALLTHRU)
-	    has_fallthru = 1, fallthru_count += e->count ();
-	  else
-	    branch_count += e->count ();
-	}
-
-      if (!fallthru_count.initialized_p () || !branch_count.initialized_p ())
-	continue;
-
-      if (bb->loop_father
-	  && bb->loop_father->latch != EXIT_BLOCK_PTR_FOR_FN (cfun)
-	  && (has_fallthru
-	      ? (!(single_succ_p (bb)
-		   && single_succ (bb) == EXIT_BLOCK_PTR_FOR_FN (cfun))
-		 && optimize_bb_for_speed_p (bb)
-		 && branch_count + fallthru_count > count_threshold
-		 && (branch_count > fallthru_count * param_align_loop_iterations))
-	      /* In case there'no fallthru for the loop.
-		 Nops inserted won't be executed.  */
-	      : (branch_count > count_threshold
-		 || (bb->count > bb->prev_bb->count * 10
-		     && (bb->prev_bb->count
-			 <= ENTRY_BLOCK_PTR_FOR_FN (cfun)->count / 2)))))
-	{
-	  rtx_insn* insn, *end_insn;
-	  HOST_WIDE_INT size = 0;
-	  bool padding_p = true;
-	  basic_block tbb = bb;
-	  unsigned cond_branch_num = 0;
-	  bool detect_tight_loop_p = false;
-
-	  for (unsigned int i = 0; i != bb->loop_father->num_nodes;
-	       i++, tbb = tbb->next_bb)
-	    {
-	      /* Only handle continuous cfg layout. */
-	      if (bb->loop_father != tbb->loop_father)
-		{
-		  padding_p = false;
-		  break;
-		}
-
-	      FOR_BB_INSNS (tbb, insn)
-		{
-		  if (!NONDEBUG_INSN_P (insn))
-		    continue;
-		  size += ix86_min_insn_size (insn);
-
-		  /* We don't know size of inline asm.
-		     Don't align loop for call.  */
-		  if (asm_noperands (PATTERN (insn)) >= 0
-		      || CALL_P (insn))
-		    {
-		      size = -1;
-		      break;
-		    }
-		}
-
-	      if (size == -1 || size > ix86_cost->prefetch_block)
-		{
-		  padding_p = false;
-		  break;
-		}
-
-	      FOR_EACH_EDGE (e, ei, tbb->succs)
-		{
-		  /* It could be part of the loop.  */
-		  if (e->dest == bb)
-		    {
-		      detect_tight_loop_p = true;
-		      break;
-		    }
-		}
-
-	      if (detect_tight_loop_p)
-		break;
-
-	      end_insn = BB_END (tbb);
-	      if (JUMP_P (end_insn))
-		{
-		  /* For decoded icache:
-		     1. Up to two branches are allowed per Way.
-		     2. A non-conditional branch is the last micro-op in a Way.
-		  */
-		  if (onlyjump_p (end_insn)
-		      && (any_uncondjump_p (end_insn)
-			  || single_succ_p (tbb)))
-		    {
-		      padding_p = false;
-		      break;
-		    }
-		  else if (++cond_branch_num >= 2)
-		    {
-		      padding_p = false;
-		      break;
-		    }
-		}
-
-	    }
-
-	  if (padding_p && detect_tight_loop_p)
-	    {
-	      emit_insn_before (gen_max_skip_align (GEN_INT (ceil_log2 (size)),
-						    GEN_INT (0)), label);
-	      /* End of function.  */
-	      if (!tbb || tbb == EXIT_BLOCK_PTR_FOR_FN (cfun))
-		break;
-	      /* Skip bb which already fits into one cacheline.  */
-	      bb = tbb;
-	    }
-	}
-    }
-
-  loop_optimizer_finalize ();
-  free_dominance_info (CDI_DOMINATORS);
-}
-
 /* Implement machine specific optimizations.  We implement padding of returns
    for K8 CPUs and pass to avoid 4 jumps in the single 16 byte window.  */
 static void
@@ -23611,8 +23467,6 @@ ix86_reorg (void)
 #ifdef ASM_OUTPUT_MAX_SKIP_ALIGN
       if (TARGET_FOUR_JUMP_LIMIT)
 	ix86_avoid_jump_mispredicts ();
-
-      ix86_align_loops ();
 #endif
     }
 }
diff --git a/gcc/testsuite/gcc.target/i386/pr116174.c b/gcc/testsuite/gcc.target/i386/pr116174.c
new file mode 100644
index 00000000000..8877d0b51af
--- /dev/null
+++ b/gcc/testsuite/gcc.target/i386/pr116174.c
@@ -0,0 +1,12 @@
+/* { dg-do compile { target *-*-linux* } } */
+/* { dg-options "-O2 -fcf-protection=branch" } */
+
+char *
+foo (char *dest, const char *src)
+{
+  while ((*dest++ = *src++) != '\0')
+    /* nothing */;
+  return --dest;
+}
+
+/* { dg-final { scan-assembler "\t\.cfi_startproc\n\tendbr(32|64)\n" } } */

commit 32b21292adb6ad6b5e1d60d923a773e4d0daca7b
Author: Richard Sandiford <richard.sandiford@arm.com>
Date:   Fri Aug 16 08:53:01 2024

    aarch64: Fix invalid nested subregs [PR115464]
    
    The testcase extracts one arm_neon.h vector from a pair (one subreg)
    and then reinterprets the result as an SVE vector (another subreg).
    Each subreg makes sense individually, but we can't fold them together
    into a single subreg: it's 32 bytes -> 16 bytes -> 16*N bytes,
    but the interpretation of 32 bytes -> 16*N bytes depends on
    whether N==1 or N>1.
    
    Since the second subreg makes sense individually, simplify_subreg
    should bail out rather than ICE on it.  simplify_gen_subreg will
    then do the same (because it already checks validate_subreg).
    This leaves simplify_gen_subreg returning null, requiring the
    caller to take appropriate action.
    
    I think this is relatively likely to occur elsewhere, so the patch
    adds a helper for forcing a subreg, allowing a temporary pseudo to
    be created where necessary.
    
    I'll follow up by using force_subreg in more places.  This patch
    is intended to be a minimal backportable fix for the PR.
    
    gcc/
            PR target/115464
            * simplify-rtx.cc (simplify_context::simplify_subreg): Don't try
            to fold two subregs together if their relationship isn't known
            at compile time.
            * explow.h (force_subreg): Declare.
            * explow.cc (force_subreg): New function.
            * config/aarch64/aarch64-sve-builtins-base.cc
            (svset_neonq_impl::expand): Use it instead of simplify_gen_subreg.
    
    gcc/testsuite/
            PR target/115464
            * gcc.target/aarch64/sve/acle/general/pr115464.c: New test.
    
    (cherry picked from commit 0970ff46ba6330fc80e8736fc05b2eaeeae0b6a0)

diff --git a/gcc/config/aarch64/aarch64-sve-builtins-base.cc b/gcc/config/aarch64/aarch64-sve-builtins-base.cc
index 0d2edf3f19e..c9182594bc1 100644
--- a/gcc/config/aarch64/aarch64-sve-builtins-base.cc
+++ b/gcc/config/aarch64/aarch64-sve-builtins-base.cc
@@ -1174,7 +1174,7 @@ public:
        Advanced SIMD argument as an SVE vector.  */
     if (!BYTES_BIG_ENDIAN
 	&& is_undef (CALL_EXPR_ARG (e.call_expr, 0)))
-      return simplify_gen_subreg (mode, e.args[1], GET_MODE (e.args[1]), 0);
+      return force_subreg (mode, e.args[1], GET_MODE (e.args[1]), 0);
 
     rtx_vector_builder builder (VNx16BImode, 16, 2);
     for (unsigned int i = 0; i < 16; i++)
diff --git a/gcc/explow.cc b/gcc/explow.cc
index 8e5f6b8e680..f6843398c4b 100644
--- a/gcc/explow.cc
+++ b/gcc/explow.cc
@@ -745,6 +745,21 @@ force_reg (machine_mode mode, rtx x)
   return temp;
 }
 
+/* Like simplify_gen_subreg, but force OP into a new register if the
+   subreg cannot be formed directly.  */
+
+rtx
+force_subreg (machine_mode outermode, rtx op,
+	      machine_mode innermode, poly_uint64 byte)
+{
+  rtx x = simplify_gen_subreg (outermode, op, innermode, byte);
+  if (x)
+    return x;
+
+  op = copy_to_mode_reg (innermode, op);
+  return simplify_gen_subreg (outermode, op, innermode, byte);
+}
+
 /* If X is a memory ref, copy its contents to a new temp reg and return
    that reg.  Otherwise, return X.  */
 
diff --git a/gcc/explow.h b/gcc/explow.h
index 16aa02cfb68..cbd1fcb7eb3 100644
--- a/gcc/explow.h
+++ b/gcc/explow.h
@@ -42,6 +42,8 @@ extern rtx copy_to_suggested_reg (rtx, rtx, machine_mode);
    Args are mode (in case value is a constant) and the value.  */
 extern rtx force_reg (machine_mode, rtx);
 
+extern rtx force_subreg (machine_mode, rtx, machine_mode, poly_uint64);
+
 /* Return given rtx, copied into a new temp reg if it was in memory.  */
 extern rtx force_not_mem (rtx);
 
diff --git a/gcc/simplify-rtx.cc b/gcc/simplify-rtx.cc
index dceaa13333c..729d408aa55 100644
--- a/gcc/simplify-rtx.cc
+++ b/gcc/simplify-rtx.cc
@@ -7612,6 +7612,11 @@ simplify_context::simplify_subreg (machine_mode outermode, rtx op,
       poly_uint64 innermostsize = GET_MODE_SIZE (innermostmode);
       rtx newx;
 
+      /* Make sure that the relationship between the two subregs is
+	 known at compile time.  */
+      if (!ordered_p (outersize, innermostsize))
+	return NULL_RTX;
+
       if (outermode == innermostmode
 	  && known_eq (byte, 0U)
 	  && known_eq (SUBREG_BYTE (op), 0))
diff --git a/gcc/testsuite/gcc.target/aarch64/sve/acle/general/pr115464.c b/gcc/testsuite/gcc.target/aarch64/sve/acle/general/pr115464.c
new file mode 100644
index 00000000000..d728d1325ed
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/sve/acle/general/pr115464.c
@@ -0,0 +1,13 @@
+/* { dg-options "-O2" } */
+
+#include <arm_neon.h>
+#include <arm_sve.h>
+#include <arm_neon_sve_bridge.h>
+
+svuint16_t
+convolve4_4_x (uint16x8x2_t permute_tbl)
+{
+    return svset_neonq_u16 (svundef_u16 (), permute_tbl.val[1]);
+}
+
+/* { dg-final { scan-assembler {\tmov\tz0\.d, z1\.d\n} } } */

commit 86dacfb06b90371458d58872f461d358a0834305
Author: Richard Sandiford <richard.sandiford@arm.com>
Date:   Fri Aug 16 08:53:02 2024

    aarch64: Add another use of force_subreg [PR115464]
    
    This patch includes the testcase from r15-1399 plus a miminal
    fix for it, without the other proactive uses of force_subreg.
    We can backport other force_subreg calls later if they're shown
    to be needed.
    
    gcc/
            PR target/115464
            * config/aarch64/aarch64-sve-builtins-base.cc
            (svset_neonq_impl::expand): Use force_subreg instead of
            lowpart_subreg.
    
    gcc/testsuite/
            PR target/115464
            * gcc.target/aarch64/sve/acle/general/pr115464_2.c: New test.

diff --git a/gcc/config/aarch64/aarch64-sve-builtins-base.cc b/gcc/config/aarch64/aarch64-sve-builtins-base.cc
index c9182594bc1..241a249503f 100644
--- a/gcc/config/aarch64/aarch64-sve-builtins-base.cc
+++ b/gcc/config/aarch64/aarch64-sve-builtins-base.cc
@@ -1185,7 +1185,9 @@ public:
     if (BYTES_BIG_ENDIAN)
       return e.use_exact_insn (code_for_aarch64_sve_set_neonq (mode));
     insn_code icode = code_for_vcond_mask (mode, mode);
-    e.args[1] = lowpart_subreg (mode, e.args[1], GET_MODE (e.args[1]));
+    e.args[1] = force_subreg (mode, e.args[1], GET_MODE (e.args[1]),
+			      subreg_lowpart_offset (mode,
+						     GET_MODE (e.args[1])));
     e.add_output_operand (icode);
     e.add_input_operand (icode, e.args[1]);
     e.add_input_operand (icode, e.args[0]);
diff --git a/gcc/testsuite/gcc.target/aarch64/sve/acle/general/pr115464_2.c b/gcc/testsuite/gcc.target/aarch64/sve/acle/general/pr115464_2.c
new file mode 100644
index 00000000000..f561c34f732
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/sve/acle/general/pr115464_2.c
@@ -0,0 +1,11 @@
+/* { dg-options "-O2" } */
+
+#include <arm_neon.h>
+#include <arm_sve.h>
+#include <arm_neon_sve_bridge.h>
+
+svuint16_t
+convolve4_4_x (uint16x8x2_t permute_tbl, svuint16_t a)
+{
+    return svset_neonq_u16 (a, permute_tbl.val[1]);
+}

commit 45a771d22e3090c42a4934a49da9924165e080af
Author: Lingling Kong <lingling.kong@intel.com>
Date:   Fri Aug 16 09:52:27 2024

    i386: Fix some vex insns that prohibit egpr
    
    Although these vex insn have evex counterpart, but when it
    uses the displayed vex prefix should not support APX EGPR.
    Like TARGET_AVXVNNI, TARGET_IFMA and TARGET_AVXNECONVERT.
    TARGET_AVXVNNIINT8 and TARGET_AVXVNNITINT16 also are vex
    insn should not support egpr.
    
    gcc/ChangeLog:
    
            * config/i386/sse.md (vpmadd52<vpmadd52type><mode>):
            Prohibit egpr for vex version.
            (vpdpbusd_<mode>): Ditto.
            (vpdpbusds_<mode>): Ditto.
            (vpdpwssd_<mode>): Ditto.
            (vpdpwssds_<mode>): Ditto.
            (*vcvtneps2bf16_v4sf): Ditto.
            (*vcvtneps2bf16_v8sf): Ditto.
            (vpdp<vpdotprodtype>_<mode>): Ditto.
            (vbcstnebf162ps_<mode>): Ditto.
            (vbcstnesh2ps_<mode>): Ditto.
            (vcvtnee<bf16_ph>2ps_<mode>): Ditto.
            (vcvtneo<bf16_ph>2ps_<mode>): Ditto.
            (vpdp<vpdpwprodtype>_<mode>): Ditto.

diff --git a/gcc/config/i386/sse.md b/gcc/config/i386/sse.md
index 073aae293d4..1b6f7c1d6c5 100644
--- a/gcc/config/i386/sse.md
+++ b/gcc/config/i386/sse.md
@@ -29364,7 +29364,7 @@
 	(unspec:VI8_AVX2
 	  [(match_operand:VI8_AVX2 1 "register_operand" "0,0")
 	   (match_operand:VI8_AVX2 2 "register_operand" "x,v")
-	   (match_operand:VI8_AVX2 3 "nonimmediate_operand" "xm,vm")]
+	   (match_operand:VI8_AVX2 3 "nonimmediate_operand" "xjm,vm")]
 	  VPMADD52))]
   "TARGET_AVXIFMA || (TARGET_AVX512IFMA && TARGET_AVX512VL)"
   "@
@@ -29372,6 +29372,7 @@
   vpmadd52<vpmadd52type>\t{%3, %2, %0|%0, %2, %3}"
   [(set_attr "isa" "avxifma,avx512ifmavl")
    (set_attr "type" "ssemuladd")
+   (set_attr "addr" "gpr16,*")
    (set_attr "prefix" "vex,evex")
    (set_attr "mode" "<sseinsnmode>")])
 
@@ -29989,13 +29990,14 @@
 	(unspec:VI4_AVX2
 	  [(match_operand:VI4_AVX2 1 "register_operand" "0,0")
 	   (match_operand:VI4_AVX2 2 "register_operand" "x,v")
-	   (match_operand:VI4_AVX2 3 "nonimmediate_operand" "xm,vm")]
+	   (match_operand:VI4_AVX2 3 "nonimmediate_operand" "xjm,vm")]
 	  UNSPEC_VPDPBUSD))]
   "TARGET_AVXVNNI || (TARGET_AVX512VNNI && TARGET_AVX512VL)"
   "@
   %{vex%} vpdpbusd\t{%3, %2, %0|%0, %2, %3}
   vpdpbusd\t{%3, %2, %0|%0, %2, %3}"
   [(set_attr ("prefix") ("vex,evex"))
+   (set_attr "addr" "gpr16,*")
    (set_attr ("isa") ("avxvnni,avx512vnnivl"))])
 
 (define_insn "vpdpbusd_<mode>_mask"
@@ -30057,13 +30059,14 @@
 	(unspec:VI4_AVX2
 	  [(match_operand:VI4_AVX2 1 "register_operand" "0,0")
 	   (match_operand:VI4_AVX2 2 "register_operand" "x,v")
-	   (match_operand:VI4_AVX2 3 "nonimmediate_operand" "xm,vm")]
+	   (match_operand:VI4_AVX2 3 "nonimmediate_operand" "xjm,vm")]
 	  UNSPEC_VPDPBUSDS))]
   "TARGET_AVXVNNI || (TARGET_AVX512VNNI && TARGET_AVX512VL)"
   "@
    %{vex%} vpdpbusds\t{%3, %2, %0|%0, %2, %3}
    vpdpbusds\t{%3, %2, %0|%0, %2, %3}"
   [(set_attr ("prefix") ("vex,evex"))
+   (set_attr "addr" "gpr16,*")
    (set_attr ("isa") ("avxvnni,avx512vnnivl"))])
 
 (define_insn "vpdpbusds_<mode>_mask"
@@ -30125,13 +30128,14 @@
 	(unspec:VI4_AVX2
 	  [(match_operand:VI4_AVX2 1 "register_operand" "0,0")
 	   (match_operand:VI4_AVX2 2 "register_operand" "x,v")
-	   (match_operand:VI4_AVX2 3 "nonimmediate_operand" "xm,vm")]
+	   (match_operand:VI4_AVX2 3 "nonimmediate_operand" "xjm,vm")]
 	  UNSPEC_VPDPWSSD))]
   "TARGET_AVXVNNI || (TARGET_AVX512VNNI && TARGET_AVX512VL)"
   "@
   %{vex%} vpdpwssd\t{%3, %2, %0|%0, %2, %3}
   vpdpwssd\t{%3, %2, %0|%0, %2, %3}"
   [(set_attr ("prefix") ("vex,evex"))
+   (set_attr "addr" "gpr16,*")
    (set_attr ("isa") ("avxvnni,avx512vnnivl"))])
 
 (define_insn "vpdpwssd_<mode>_mask"
@@ -30193,13 +30197,14 @@
 	(unspec:VI4_AVX2
 	  [(match_operand:VI4_AVX2 1 "register_operand" "0,0")
 	   (match_operand:VI4_AVX2 2 "register_operand" "x,v")
-	   (match_operand:VI4_AVX2 3 "nonimmediate_operand" "xm,vm")]
+	   (match_operand:VI4_AVX2 3 "nonimmediate_operand" "xjm,vm")]
 	  UNSPEC_VPDPWSSDS))]
   "TARGET_AVXVNNI || (TARGET_AVX512VNNI && TARGET_AVX512VL)"
   "@
   %{vex%} vpdpwssds\t{%3, %2, %0|%0, %2, %3}
   vpdpwssds\t{%3, %2, %0|%0, %2, %3}"
   [(set_attr ("prefix") ("vex,evex"))
+   (set_attr "addr" "gpr16,*")
    (set_attr ("isa") ("avxvnni,avx512vnnivl"))])
 
 (define_insn "vpdpwssds_<mode>_mask"
@@ -30417,13 +30422,14 @@
   [(set (match_operand:V8BF 0 "register_operand" "=x,v")
 	(vec_concat:V8BF
 	  (float_truncate:V4BF
-	    (match_operand:V4SF 1 "nonimmediate_operand" "xm,vm"))
+	    (match_operand:V4SF 1 "nonimmediate_operand" "xjm,vm"))
 	  (match_operand:V4BF 2 "const0_operand")))]
   "TARGET_AVXNECONVERT || (TARGET_AVX512BF16 && TARGET_AVX512VL)"
   "@
   %{vex%} vcvtneps2bf16{x}\t{%1, %0|%0, %1}
   vcvtneps2bf16{x}\t{%1, %0|%0, %1}"
   [(set_attr "isa" "avxneconvert,avx512bf16vl")
+   (set_attr "addr" "gpr16,*")
    (set_attr "prefix" "vex,evex")])
 
 (define_expand "avx512f_cvtneps2bf16_v4sf_maskz"
@@ -30481,12 +30487,13 @@
 (define_insn "vcvtneps2bf16_v8sf"
   [(set (match_operand:V8BF 0 "register_operand" "=x,v")
 	(float_truncate:V8BF
-	  (match_operand:V8SF 1 "nonimmediate_operand" "xm,vm")))]
+	  (match_operand:V8SF 1 "nonimmediate_operand" "xjm,vm")))]
   "TARGET_AVXNECONVERT || (TARGET_AVX512BF16 && TARGET_AVX512VL)"
   "@
   %{vex%} vcvtneps2bf16{y}\t{%1, %0|%0, %1}
   vcvtneps2bf16{y}\t{%1, %0|%0, %1}"
   [(set_attr "isa" "avxneconvert,avx512bf16vl")
+   (set_attr "addr" "gpr16,*")
    (set_attr "prefix" "vex,evex")])
 
 
@@ -30942,30 +30949,33 @@
 	(unspec:VI4_AVX
 	  [(match_operand:VI4_AVX 1 "register_operand" "0")
 	   (match_operand:VI4_AVX 2 "register_operand" "x")
-	   (match_operand:VI4_AVX 3 "nonimmediate_operand" "xm")]
+	   (match_operand:VI4_AVX 3 "nonimmediate_operand" "xjm")]
 	  VPDOTPROD))]
   "TARGET_AVXVNNIINT8"
   "vpdp<vpdotprodtype>\t{%3, %2, %0|%0, %2, %3}"
-   [(set_attr "prefix" "vex")])
+   [(set_attr "prefix" "vex")
+    (set_attr "addr" "gpr16")])
 
 (define_insn "vbcstnebf162ps_<mode>"
   [(set (match_operand:VF1_128_256 0 "register_operand" "=x")
 	(vec_duplicate:VF1_128_256
 	  (float_extend:SF
-	    (match_operand:BF 1 "memory_operand" "m"))))]
+	    (match_operand:BF 1 "memory_operand" "jm"))))]
   "TARGET_AVXNECONVERT"
   "vbcstnebf162ps\t{%1, %0|%0, %1}"
   [(set_attr "prefix" "vex")
+   (set_attr "addr" "gpr16")
    (set_attr "mode" "<sseinsnmode>")])
 
 (define_insn "vbcstnesh2ps_<mode>"
   [(set (match_operand:VF1_128_256 0 "register_operand" "=x")
 	(vec_duplicate:VF1_128_256
 	  (float_extend:SF
-	    (match_operand:HF 1 "memory_operand" "m"))))]
+	    (match_operand:HF 1 "memory_operand" "jm"))))]
   "TARGET_AVXNECONVERT"
   "vbcstnesh2ps\t{%1, %0|%0, %1}"
   [(set_attr "prefix" "vex")
+   (set_attr "addr" "gpr16")
    (set_attr "mode" "<sseinsnmode>")])
 
 (define_mode_attr bf16_ph
@@ -30976,19 +30986,20 @@
   [(set (match_operand:V4SF 0 "register_operand" "=x")
 	(float_extend:V4SF
 	  (vec_select:<ssehalfvecmode>
-	    (match_operand:VHFBF_128 1 "memory_operand" "m")
+	    (match_operand:VHFBF_128 1 "memory_operand" "jm")
 	    (parallel [(const_int 0) (const_int 2)
 		       (const_int 4) (const_int 6)]))))]
   "TARGET_AVXNECONVERT"
   "vcvtnee<bf16_ph>2ps\t{%1, %0|%0, %1}"
   [(set_attr "prefix" "vex")
+   (set_attr "addr" "gpr16")
    (set_attr "mode" "<sseinsnmode>")])
 
 (define_insn "vcvtnee<bf16_ph>2ps_<mode>"
   [(set (match_operand:V8SF 0 "register_operand" "=x")
 	(float_extend:V8SF
 	  (vec_select:<ssehalfvecmode>
-	    (match_operand:VHFBF_256 1 "memory_operand" "m")
+	    (match_operand:VHFBF_256 1 "memory_operand" "jm")
 	    (parallel [(const_int 0) (const_int 2)
 		       (const_int 4) (const_int 6)
 		       (const_int 8) (const_int 10)
@@ -30996,25 +31007,27 @@
   "TARGET_AVXNECONVERT"
   "vcvtnee<bf16_ph>2ps\t{%1, %0|%0, %1}"
   [(set_attr "prefix" "vex")
+   (set_attr "addr" "gpr16")
    (set_attr "mode" "<sseinsnmode>")])
 
 (define_insn "vcvtneo<bf16_ph>2ps_<mode>"
   [(set (match_operand:V4SF 0 "register_operand" "=x")
 	(float_extend:V4SF
 	  (vec_select:<ssehalfvecmode>
-	    (match_operand:VHFBF_128 1 "memory_operand" "m")
+	    (match_operand:VHFBF_128 1 "memory_operand" "jm")
 	    (parallel [(const_int 1) (const_int 3)
 		       (const_int 5) (const_int 7)]))))]
   "TARGET_AVXNECONVERT"
   "vcvtneo<bf16_ph>2ps\t{%1, %0|%0, %1}"
   [(set_attr "prefix" "vex")
+   (set_attr "addr" "gpr16")
    (set_attr "mode" "<sseinsnmode>")])
 
 (define_insn "vcvtneo<bf16_ph>2ps_<mode>"
   [(set (match_operand:V8SF 0 "register_operand" "=x")
 	(float_extend:V8SF
 	  (vec_select:<ssehalfvecmode>
-	    (match_operand:VHFBF_256 1 "memory_operand" "m")
+	    (match_operand:VHFBF_256 1 "memory_operand" "jm")
 	    (parallel [(const_int 1) (const_int 3)
 		       (const_int 5) (const_int 7)
 		       (const_int 9) (const_int 11)
@@ -31022,6 +31035,7 @@
   "TARGET_AVXNECONVERT"
   "vcvtneo<bf16_ph>2ps\t{%1, %0|%0, %1}"
   [(set_attr "prefix" "vex")
+   (set_attr "addr" "gpr16")
    (set_attr "mode" "<sseinsnmode>")])
 
 (define_int_iterator VPDPWPROD
@@ -31078,8 +31092,9 @@
 	(unspec:VI4_AVX
 	  [(match_operand:VI4_AVX 1 "register_operand" "0")
 	   (match_operand:VI4_AVX 2 "register_operand" "x")
-	   (match_operand:VI4_AVX 3 "nonimmediate_operand" "xm")]
+	   (match_operand:VI4_AVX 3 "nonimmediate_operand" "xjm")]
 	  VPDPWPROD))]
   "TARGET_AVXVNNIINT16"
   "vpdp<vpdpwprodtype>\t{%3, %2, %0|%0, %2, %3}"
-   [(set_attr "prefix" "vex")])
+   [(set_attr "prefix" "vex")
+    (set_attr "addr" "gpr16")])

commit 345d1452dca18cbf3a66e0a22089843d2076abd1
Author: Torbjörn SVENSSON <torbjorn.svensson@foss.st.com>
Date:   Fri Aug 16 12:03:57 2024

    testsuite: Add -fwrapv to signbit-5.c
    
    On Cortex-M55 with MVE, the test case fails due to -INT_MAX being
    undefined. Adding -fwrapv solves the issues.
    
    Regtested on x86_64-pc-linux-gnu and arm-none-eabi for
    Cortex-M0/M3/M4/M7/M33/M55/M85/A7.
    
    gcc/testsuite/ChangeLog:
    
            * gcc.dg/signbit-5.c: Add -fwrapv and remove x86 exception.
    
    Signed-off-by: Torbjörn SVENSSON <torbjorn.svensson@foss.st.com>
    Co-authored-by: Yvan ROUX <yvan.roux@foss.st.com>
    (cherry picked from commit 5a3387938d4d95717cac29eecd0ba53e0ef9094d)

diff --git a/gcc/testsuite/gcc.dg/signbit-5.c b/gcc/testsuite/gcc.dg/signbit-5.c
index 1e1b237a0e0..2bca640f930 100644
--- a/gcc/testsuite/gcc.dg/signbit-5.c
+++ b/gcc/testsuite/gcc.dg/signbit-5.c
@@ -1,8 +1,7 @@
 /* { dg-do run } */
-/* { dg-options "-O3" } */
+/* { dg-options "-O3 -fwrapv" } */
 
 /* This test does not work when the truth type does not match vector type.  */
-/* { dg-additional-options "-mno-avx512f" { target { i?86-*-* x86_64-*-* } } } */
 /* { dg-additional-options "-march=armv8-a" { target aarch64_sve } } */
 /* { dg-xfail-run-if "truth type does not match vector type" { amdgcn-*-* } } */
 /* { dg-xfail-run-if "truth type does not match vector type" { riscv_v } } */

commit 5c1f687288ec89d9884186df8998c850b43a6a2d
Author: Torbjörn SVENSSON <torbjorn.svensson@foss.st.com>
Date:   Fri Aug 16 16:10:01 2024

    testsuite: Add -fno-short-enums to pr97315-1.C
    
    The test case assumes that sizeof(tree_code) >= 2. On some targets, like
    Cortex-M on arm-none-eabi, -fshort-enums is enabled by default and in
    that case, sizeof(tree_code) will be 1 and the following warning is
    emitted:
    
    .../pr97315-1.C:8:13: warning: width of 'tree_base::code' exceeds its type
    
    Avoid the warning by forcing -fno-short-enums.
    
    gcc/testsuite/ChangeLog:
    
            * g++.dg/opt/pr97315-1.C: Add -fno-short-enums.
    
    Signed-off-by: Torbjörn SVENSSON <torbjorn.svensson@foss.st.com>
    (cherry picked from commit 10bf0357750972e20dc702997f2930eab1c1be17)

diff --git a/gcc/testsuite/g++.dg/opt/pr97315-1.C b/gcc/testsuite/g++.dg/opt/pr97315-1.C
index 5a618d8e1e8..3e439c5f179 100644
--- a/gcc/testsuite/g++.dg/opt/pr97315-1.C
+++ b/gcc/testsuite/g++.dg/opt/pr97315-1.C
@@ -1,5 +1,5 @@
 /* { dg-do compile } */
-/* { dg-options "-O3 -fno-exceptions" } */
+/* { dg-options "-O3 -fno-exceptions -fno-short-enums" } */
 
 typedef struct tree_node *tree;
 enum tree_code { RECORD_TYPE, QUAL_UNION_TYPE };

commit edf95a491077243c32c40120c808879e1b473822
Author: Torbjörn SVENSSON <torbjorn.svensson@foss.st.com>
Date:   Fri Aug 16 14:43:41 2024

    testsuite: Verify -fshort-enums and -fno-short-enums in pr33738.C
    
    For some targets, like Cortex-M on arm-none-eabi, the -fshort-enums is
    enabled by default. For these targets, the test case fails as
    sizeof(Alpha) < sizeof(int).
    To make the test case behave identical for targets that does enable
    -fshort-enums and those that does not, add -fno-short-enums in the test
    case and verify that the warning is not emitted. Then also create a copy
    and run the test with -fshort-enums and verify that the warning is
    emitted.
    
    Regtested on x86_64-pc-linux-gnu and arm-none-eabi.
    
    gcc/testsuite/ChangeLog:
    
            * g++.dg/warn/pr33738.C: Added -fno-short-enums.
            * g++.dg/warn/pr33738-2.C: Duplicate g++.dg/warn/pr33738.C with
            -fshort-enums and removed xfail.
    
    Signed-off-by: Torbjörn SVENSSON <torbjorn.svensson@foss.st.com>
    (cherry picked from commit 479dab62b828f93d6be48241178dbf654bdd33e7)

diff --git a/gcc/testsuite/g++.dg/warn/pr33738-2.C b/gcc/testsuite/g++.dg/warn/pr33738-2.C
new file mode 100644
index 00000000000..84bbdaeecc7
--- /dev/null
+++ b/gcc/testsuite/g++.dg/warn/pr33738-2.C
@@ -0,0 +1,27 @@
+// { dg-do run }
+// { dg-options "-O2 -Wtype-limits -fstrict-enums -fshort-enums" }
+extern void link_error (void);
+
+enum Alpha {
+ ZERO = 0, ONE, TWO, THREE
+};
+
+Alpha a2;
+
+int m1 = -1;
+int GetM1() {
+ return m1;
+}
+
+int main() {
+ a2 = static_cast<Alpha>(GetM1());
+ if (a2 == -1) {	// { dg-warning "always false due" } */
+    link_error ();
+ }
+ a2 = static_cast<Alpha>(GetM1());
+ if (-1 == a2) {	// { dg-warning "always false due" } */
+    link_error ();
+ }
+ return 0;
+}
+
diff --git a/gcc/testsuite/g++.dg/warn/pr33738.C b/gcc/testsuite/g++.dg/warn/pr33738.C
index 73e98d5e083..d899f91c018 100644
--- a/gcc/testsuite/g++.dg/warn/pr33738.C
+++ b/gcc/testsuite/g++.dg/warn/pr33738.C
@@ -1,5 +1,6 @@
 // { dg-do run }
-// { dg-options "-O2 -Wtype-limits -fstrict-enums" }
+// { dg-prune-output "use of enum values across objects may fail" }
+// { dg-options "-O2 -Wtype-limits -fstrict-enums -fno-short-enums" }
 extern void link_error (void);
 
 enum Alpha {

commit 507b4e147588c0fafe952b7226dd764ebeebb103
Author: Georg-Johann Lay <avr@gjlay.de>
Date:   Fri Aug 16 18:13:34 2024

    AVR: target/85624 - Use HImode for clrmemqi alignment.
    
    gcc/
            PR target/85624
            * config/avr/avr.md (*clrmemqi*): Use HImode for alignment operand.
    
    gcc/testsuite/
            * gcc.target/avr/torture/pr85624.c: New test.

diff --git a/gcc/config/avr/avr.md b/gcc/config/avr/avr.md
index dabf4c0fc5a..55de11079c3 100644
--- a/gcc/config/avr/avr.md
+++ b/gcc/config/avr/avr.md
@@ -1374,7 +1374,7 @@
   [(set (mem:BLK (match_operand:HI 0 "register_operand" "e"))
         (const_int 0))
    (use (match_operand:QI 1 "register_operand" "r"))
-   (use (match_operand:QI 2 "const_int_operand" "n"))
+   (use (match_operand:HI 2 "const_int_operand" "n"))
    (clobber (match_scratch:HI 3 "=0"))
    (clobber (match_scratch:QI 4 "=&1"))]
   ""
@@ -1392,7 +1392,7 @@
   [(set (mem:BLK (match_operand:HI 0 "register_operand" "e"))
         (const_int 0))
    (use (match_operand:QI 1 "register_operand" "r"))
-   (use (match_operand:QI 2 "const_int_operand" "n"))
+   (use (match_operand:HI 2 "const_int_operand" "n"))
    (clobber (match_scratch:HI 3 "=0"))
    (clobber (match_scratch:QI 4 "=&1"))
    (clobber (reg:CC REG_CC))]
diff --git a/gcc/testsuite/gcc.target/avr/torture/pr85624.c b/gcc/testsuite/gcc.target/avr/torture/pr85624.c
new file mode 100644
index 00000000000..b183d4558df
--- /dev/null
+++ b/gcc/testsuite/gcc.target/avr/torture/pr85624.c
@@ -0,0 +1,7 @@
+/* { dg-do compile } */
+
+int foo (void)
+{
+  volatile int arr[3] __attribute__((aligned(128))) = { 0 };
+  return arr[2];
+}

commit 02960011cb42468aa9bfa636ecbcd93ae33640b5
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Sat Aug 17 02:21:45 2024

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 449384cd6e0..966546e94fe 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,61 @@
+2024-08-16  Georg-Johann Lay  <avr@gjlay.de>
+
+	PR target/85624
+	* config/avr/avr.md (*clrmemqi*): Use HImode for alignment operand.
+
+2024-08-16  Lingling Kong  <lingling.kong@intel.com>
+
+	* config/i386/sse.md (vpmadd52<vpmadd52type><mode>):
+	Prohibit egpr for vex version.
+	(vpdpbusd_<mode>): Ditto.
+	(vpdpbusds_<mode>): Ditto.
+	(vpdpwssd_<mode>): Ditto.
+	(vpdpwssds_<mode>): Ditto.
+	(*vcvtneps2bf16_v4sf): Ditto.
+	(*vcvtneps2bf16_v8sf): Ditto.
+	(vpdp<vpdotprodtype>_<mode>): Ditto.
+	(vbcstnebf162ps_<mode>): Ditto.
+	(vbcstnesh2ps_<mode>): Ditto.
+	(vcvtnee<bf16_ph>2ps_<mode>): Ditto.
+	(vcvtneo<bf16_ph>2ps_<mode>): Ditto.
+	(vpdp<vpdpwprodtype>_<mode>): Ditto.
+
+2024-08-16  Richard Sandiford  <richard.sandiford@arm.com>
+
+	PR target/115464
+	* config/aarch64/aarch64-sve-builtins-base.cc
+	(svset_neonq_impl::expand): Use force_subreg instead of
+	lowpart_subreg.
+
+2024-08-16  Richard Sandiford  <richard.sandiford@arm.com>
+
+	Backported from master:
+	2024-06-13  Richard Sandiford  <richard.sandiford@arm.com>
+
+	PR target/115464
+	* simplify-rtx.cc (simplify_context::simplify_subreg): Don't try
+	to fold two subregs together if their relationship isn't known
+	at compile time.
+	* explow.h (force_subreg): Declare.
+	* explow.cc (force_subreg): New function.
+	* config/aarch64/aarch64-sve-builtins-base.cc
+	(svset_neonq_impl::expand): Use it instead of simplify_gen_subreg.
+
+2024-08-16  liuhongt  <hongtao.liu@intel.com>
+
+	Backported from master:
+	2024-08-14  liuhongt  <hongtao.liu@intel.com>
+
+	PR target/116174
+	* config/i386/i386.cc (ix86_align_loops): Move this to ..
+	* config/i386/i386-features.cc (ix86_align_loops): .. here.
+	(class pass_align_tight_loops): New class.
+	(make_pass_align_tight_loops): New function.
+	* config/i386/i386-passes.def: Insert pass_align_tight_loops
+	after pass_insert_endbr_and_patchable_area.
+	* config/i386/i386-protos.h (make_pass_align_tight_loops): New
+	declare.
+
 2024-08-14  Stefan Schulze Frielinghaus  <stefansf@gcc.gnu.org>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index c11f769cc2c..720f32939ba 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240816
+20240817
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index de25ede2895..2ed68f979f0 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,51 @@
+2024-08-16  Georg-Johann Lay  <avr@gjlay.de>
+
+	* gcc.target/avr/torture/pr85624.c: New test.
+
+2024-08-16  Torbjörn SVENSSON  <torbjorn.svensson@foss.st.com>
+
+	Backported from master:
+	2024-08-16  Torbjörn SVENSSON  <torbjorn.svensson@foss.st.com>
+
+	* g++.dg/warn/pr33738.C: Added -fno-short-enums.
+	* g++.dg/warn/pr33738-2.C: Duplicate g++.dg/warn/pr33738.C with
+	-fshort-enums and removed xfail.
+
+2024-08-16  Torbjörn SVENSSON  <torbjorn.svensson@foss.st.com>
+
+	Backported from master:
+	2024-08-16  Torbjörn SVENSSON  <torbjorn.svensson@foss.st.com>
+
+	* g++.dg/opt/pr97315-1.C: Add -fno-short-enums.
+
+2024-08-16  Torbjörn SVENSSON  <torbjorn.svensson@foss.st.com>
+
+	Backported from master:
+	2024-08-16  Torbjörn SVENSSON  <torbjorn.svensson@foss.st.com>
+		    Yvan ROUX  <yvan.roux@foss.st.com>
+
+	* gcc.dg/signbit-5.c: Add -fwrapv and remove x86 exception.
+
+2024-08-16  Richard Sandiford  <richard.sandiford@arm.com>
+
+	PR target/115464
+	* gcc.target/aarch64/sve/acle/general/pr115464_2.c: New test.
+
+2024-08-16  Richard Sandiford  <richard.sandiford@arm.com>
+
+	Backported from master:
+	2024-06-13  Richard Sandiford  <richard.sandiford@arm.com>
+
+	PR target/115464
+	* gcc.target/aarch64/sve/acle/general/pr115464.c: New test.
+
+2024-08-16  liuhongt  <hongtao.liu@intel.com>
+
+	Backported from master:
+	2024-08-14  liuhongt  <hongtao.liu@intel.com>
+
+	* gcc.target/i386/pr116174.c: New test.
+
 2024-08-15  Patrick Palka  <ppalka@redhat.com>
 
 	Backported from master:

commit f3d9c120a1959c5b094001516c1e5cb4ba6f4080
Author: Georg-Johann Lay <avr@gjlay.de>
Date:   Sat Aug 17 12:49:42 2024

    AVR: target/116390 - Fix an avrtiny asm out template.
    
            PR target/116390
    gcc/
            * config/avr/avr.cc (avr_out_movsi_mr_r_reg_disp_tiny): Fix
            output templates for the reg_base == reg_src and
            reg_src == reg_base - 2 cases.
    gcc/testsuite/
            * gcc.target/avr/torture/pr116390.c: New test.
    
    (cherry picked from commit 4065d163151b07b274241377e71dad028576db88)

diff --git a/gcc/config/avr/avr.cc b/gcc/config/avr/avr.cc
index 71929b28160..3c1a0bf707f 100644
--- a/gcc/config/avr/avr.cc
+++ b/gcc/config/avr/avr.cc
@@ -5501,33 +5501,33 @@ avr_out_movsi_mr_r_reg_disp_tiny (rtx op[], int *l)
   rtx src = op[1];
   rtx base = XEXP (dest, 0);
   int reg_base = REGNO (XEXP (base, 0));
-  int reg_src =true_regnum (src);
+  int reg_src = true_regnum (src);
 
   if (reg_base == reg_src)
     {
       *l = 11;
-      return ("mov __tmp_reg__,%A2"        CR_TAB
-	      "mov __zero_reg__,%B2"       CR_TAB
+      return ("mov __tmp_reg__,%A1"        CR_TAB
+	      "mov __zero_reg__,%B1"       CR_TAB
 	      TINY_ADIW (%I0, %J0, %o0)    CR_TAB
 	      "st %b0+,__tmp_reg__"        CR_TAB
 	      "st %b0+,__zero_reg__"       CR_TAB
-	      "st %b0+,%C2"                CR_TAB
-	      "st %b0,%D2"                 CR_TAB
+	      "st %b0+,%C1"                CR_TAB
+	      "st %b0,%D1"                 CR_TAB
 	      "clr __zero_reg__"           CR_TAB
 	      TINY_SBIW (%I0, %J0, %o0+3));
     }
   else if (reg_src == reg_base - 2)
     {
-      *l = 11;
-      return ("mov __tmp_reg__,%C2"         CR_TAB
-	      "mov __zero_reg__,%D2"        CR_TAB
-	      TINY_ADIW (%I0, %J0, %o0)     CR_TAB
-	      "st %b0+,%A0"                 CR_TAB
-	      "st %b0+,%B0"                 CR_TAB
-	      "st %b0+,__tmp_reg__"         CR_TAB
-	      "st %b0,__zero_reg__"         CR_TAB
-	      "clr __zero_reg__"            CR_TAB
-	      TINY_SBIW (%I0, %J0, %o0+3));
+      // This awkward case can occur when ext-dce turns zero-extend:SI(HI)
+      // into a paradoxical subreg, which register allocation may turn into
+      // something like *(R28:HI + 7) = R26:SI.  There is actually no need
+      // to store the upper 2 bytes of R26:SI as they are unused rubbish.
+      // See PR116390.
+      *l = 6;
+      return (TINY_ADIW (%I0, %J0, %o0)     CR_TAB
+	      "st %b0+,%A1"                 CR_TAB
+	      "st %b0,%B1"                  CR_TAB
+	      TINY_SBIW (%I0, %J0, %o0+1));
     }
   *l = 8;
   return (TINY_ADIW (%I0, %J0, %o0)     CR_TAB
diff --git a/gcc/testsuite/gcc.target/avr/torture/pr116390.c b/gcc/testsuite/gcc.target/avr/torture/pr116390.c
new file mode 100644
index 00000000000..70c1ad62936
--- /dev/null
+++ b/gcc/testsuite/gcc.target/avr/torture/pr116390.c
@@ -0,0 +1,71 @@
+/* { dg-do compile } */
+/* { dg-additional-options "-std=c99" } */
+
+typedef struct
+{
+    int i;
+} MyStruct;
+
+void f_ic (int, char);
+void f_pi (char const *, int);
+void f_iic (int, int, char);
+
+const MyStruct *f_rms (void);
+
+char *f_rcp (void);
+int f_ri (void);
+
+void badFoo (void)
+{
+    const MyStruct* ps = f_rms ();
+    const char* pc = f_rcp ();
+
+    unsigned n1 = f_rcp () - pc;
+
+    if (n1)
+    {
+        long n2 = n1 - ps->i;
+        if (n2 > 0)
+        {
+            if (f_ri ())
+                n2 = n1;
+
+            if (f_ri ())
+            {
+                f_iic (1, 2 * n2, ' ');
+            }
+            else
+                f_pi (pc, n2);
+        }
+        if (ps->i > 0)
+        {
+            if (n2 >= 0)
+                f_pi (pc + n2, ps->i);
+            else
+            {
+                f_ic (n2, ' ');
+            }
+        }
+
+        const int which = f_ri ();
+        switch (which)
+        {
+        case 1:
+            if (f_ri ())
+                f_rcp ()[1] = ' ';
+            break;
+
+        case 2:
+            f_pi (f_rcp (), 1);
+            break;
+
+        case 3:
+            if (f_ri () && n1 < 0)
+                f_ic (n1, ' ');
+            else
+                f_rcp ()[1] = ' ';
+            break;
+
+        }
+    }
+}

commit f4ce0980daac25eadfdbe7f4169ae02284430fa5
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Sun Aug 18 02:21:22 2024

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 966546e94fe..7ad5949db06 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,13 @@
+2024-08-17  Georg-Johann Lay  <avr@gjlay.de>
+
+	Backported from master:
+	2024-08-17  Georg-Johann Lay  <avr@gjlay.de>
+
+	PR target/116390
+	* config/avr/avr.cc (avr_out_movsi_mr_r_reg_disp_tiny): Fix
+	output templates for the reg_base == reg_src and
+	reg_src == reg_base - 2 cases.
+
 2024-08-16  Georg-Johann Lay  <avr@gjlay.de>
 
 	PR target/85624
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 720f32939ba..5e34934c797 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240817
+20240818
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 2ed68f979f0..0ddafb8ae54 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,11 @@
+2024-08-17  Georg-Johann Lay  <avr@gjlay.de>
+
+	Backported from master:
+	2024-08-17  Georg-Johann Lay  <avr@gjlay.de>
+
+	PR target/116390
+	* gcc.target/avr/torture/pr116390.c: New test.
+
 2024-08-16  Georg-Johann Lay  <avr@gjlay.de>
 
 	* gcc.target/avr/torture/pr85624.c: New test.

commit 919c42bf4487a8f0cc584a3ca53784c381f19dfa
Author: Georg-Johann Lay <avr@gjlay.de>
Date:   Sun Aug 18 15:00:55 2024

    AVR: target/116407 - Fix linker error "relocation truncated to fit".
    
    Some text peepholes output extra instructions prior to a branch
    instruction and that increase the jump offset of backward branches.
    
            PR target/116407
    gcc/
            * config/avr/avr-protos.h (avr_jump_mode): Add an int argument.
            * config/avr/avr.cc (avr_jump_mode): Add an int argument to increase
            the computed jump offset of backwards branches.
            * config/avr/avr.md (*dec-and-branchhi!=-1, *dec-and-branchsi!=-1):
            Increase the jump offset used by avr_jump_mode() as needed.
    gcc/testsuite/
            * gcc.target/avr/torture/pr116407-2.c: New test.
            * gcc.target/avr/torture/pr116407-4.c: New test.
    
    (cherry picked from commit dfb2e8caa85d1059a0ab8ed4f19568c04c9f13a4)

diff --git a/gcc/config/avr/avr-protos.h b/gcc/config/avr/avr-protos.h
index dc23cfbf461..d918e2fce31 100644
--- a/gcc/config/avr/avr-protos.h
+++ b/gcc/config/avr/avr-protos.h
@@ -112,7 +112,7 @@ extern const char* avr_out_reload_inpsi (rtx*, rtx, int*);
 extern const char* avr_out_lpm (rtx_insn *, rtx*, int*);
 extern void avr_notice_update_cc (rtx body, rtx_insn *insn);
 extern int reg_unused_after (rtx_insn *insn, rtx reg);
-extern int avr_jump_mode (rtx x, rtx_insn *insn);
+extern int avr_jump_mode (rtx x, rtx_insn *insn, int = 0);
 extern int test_hard_reg_class (enum reg_class rclass, rtx x);
 extern int jump_over_one_insn_p (rtx_insn *insn, rtx dest);
 
diff --git a/gcc/config/avr/avr.cc b/gcc/config/avr/avr.cc
index 3c1a0bf707f..c6f29fd48f9 100644
--- a/gcc/config/avr/avr.cc
+++ b/gcc/config/avr/avr.cc
@@ -3989,19 +3989,22 @@ avr_use_by_pieces_infrastructure_p (unsigned HOST_WIDE_INT size,
 /* Choose mode for jump insn:
    1 - relative jump in range -63 <= x <= 62 ;
    2 - relative jump in range -2046 <= x <= 2045 ;
-   3 - absolute jump (only for ATmega[16]03).  */
+   3 - absolute jump (only when we have JMP / CALL).
+
+   When jumping backwards, assume the jump offset is EXTRA words
+   bigger than inferred from insn addresses.  */
 
 int
-avr_jump_mode (rtx x, rtx_insn *insn)
+avr_jump_mode (rtx x, rtx_insn *insn, int extra)
 {
   int dest_addr = INSN_ADDRESSES (INSN_UID (GET_CODE (x) == LABEL_REF
 					    ? XEXP (x, 0) : x));
   int cur_addr = INSN_ADDRESSES (INSN_UID (insn));
   int jump_distance = cur_addr - dest_addr;
 
-  if (IN_RANGE (jump_distance, -63, 62))
+  if (IN_RANGE (jump_distance, -63, 62 - extra))
     return 1;
-  else if (IN_RANGE (jump_distance, -2046, 2045))
+  else if (IN_RANGE (jump_distance, -2046, 2045 - extra))
     return 2;
   else if (AVR_HAVE_JMP_CALL)
     return 3;
diff --git a/gcc/config/avr/avr.md b/gcc/config/avr/avr.md
index 55de11079c3..9aaefcfcd64 100644
--- a/gcc/config/avr/avr.md
+++ b/gcc/config/avr/avr.md
@@ -7771,7 +7771,7 @@
                        "sbc %C0,__zero_reg__" CR_TAB
                        "sbc %D0,__zero_reg__", operands);
 
-    int jump_mode = avr_jump_mode (operands[2], insn);
+    int jump_mode = avr_jump_mode (operands[2], insn, 3 - avr_adiw_reg_p (operands[0]));
     const char *op = ((EQ == <CODE>) ^ (jump_mode == 1)) ? "brcc" : "brcs";
     operands[1] = gen_rtx_CONST_STRING (VOIDmode, op);
 
@@ -7808,7 +7808,7 @@
       output_asm_insn ("subi %A0,1" CR_TAB
                        "sbc %B0,__zero_reg__", operands);
 
-    int jump_mode = avr_jump_mode (operands[2], insn);
+    int jump_mode = avr_jump_mode (operands[2], insn, 1 - avr_adiw_reg_p (operands[0]));
     const char *op = ((EQ == <CODE>) ^ (jump_mode == 1)) ? "brcc" : "brcs";
     operands[1] = gen_rtx_CONST_STRING (VOIDmode, op);
 
@@ -7847,7 +7847,7 @@
       output_asm_insn ("subi %A0,1" CR_TAB
                        "sbc %B0,__zero_reg__", operands);
 
-    int jump_mode = avr_jump_mode (operands[2], insn);
+    int jump_mode = avr_jump_mode (operands[2], insn, 1 - avr_adiw_reg_p (operands[0]));
     const char *op = ((EQ == <CODE>) ^ (jump_mode == 1)) ? "brcc" : "brcs";
     operands[1] = gen_rtx_CONST_STRING (VOIDmode, op);
 
@@ -7884,7 +7884,7 @@
                      "sub %A0,%3" CR_TAB
                      "sbc %B0,__zero_reg__", operands);
 
-    int jump_mode = avr_jump_mode (operands[2], insn);
+    int jump_mode = avr_jump_mode (operands[2], insn, 1 - avr_adiw_reg_p (operands[0]));
     const char *op = ((EQ == <CODE>) ^ (jump_mode == 1)) ? "brcc" : "brcs";
     operands[1] = gen_rtx_CONST_STRING (VOIDmode, op);
 
diff --git a/gcc/testsuite/gcc.target/avr/torture/pr116407-2.c b/gcc/testsuite/gcc.target/avr/torture/pr116407-2.c
new file mode 100644
index 00000000000..f580d129b5b
--- /dev/null
+++ b/gcc/testsuite/gcc.target/avr/torture/pr116407-2.c
@@ -0,0 +1,34 @@
+/* { dg-do link } */
+
+typedef __UINT16_TYPE__ u16;
+typedef __INT16_TYPE__  T;
+
+#ifdef __OPTIMIZE__
+
+static __inline__ __attribute__((always_inline))
+void delay (T x, u16 nops)
+{
+    do
+        __builtin_avr_nops (nops);
+    while (--x != -1);
+}
+
+#ifdef __AVR_HAVE_JMP_CALL__
+
+void delay_2043 (T x) { delay (x, 2043); }
+void delay_2044 (T x) { delay (x, 2044); }
+void delay_2045 (T x) { delay (x, 2045); }
+void delay_2046 (T x) { delay (x, 2046); }
+
+#endif /* have JUMP, CALL */
+
+void delay_61 (T x) { delay (x, 61); }
+void delay_62 (T x) { delay (x, 62); }
+void delay_63 (T x) { delay (x, 63); }
+
+#endif /* optimize */
+
+int main (void)
+{
+    return 0;
+}
diff --git a/gcc/testsuite/gcc.target/avr/torture/pr116407-4.c b/gcc/testsuite/gcc.target/avr/torture/pr116407-4.c
new file mode 100644
index 00000000000..4347d85e552
--- /dev/null
+++ b/gcc/testsuite/gcc.target/avr/torture/pr116407-4.c
@@ -0,0 +1,34 @@
+/* { dg-do link } */
+
+typedef __UINT16_TYPE__ u16;
+typedef __INT32_TYPE__  T;
+
+#ifdef __OPTIMIZE__
+
+static __inline__ __attribute__((always_inline))
+void delay (T x, u16 nops)
+{
+    do
+        __builtin_avr_nops (nops);
+    while (--x != -1);
+}
+
+#ifdef __AVR_HAVE_JMP_CALL__
+
+void delay_2043 (T x) { delay (x, 2043); }
+void delay_2044 (T x) { delay (x, 2044); }
+void delay_2045 (T x) { delay (x, 2045); }
+void delay_2046 (T x) { delay (x, 2046); }
+
+#endif /* have JUMP, CALL */
+
+void delay_61 (T x) { delay (x, 61); }
+void delay_62 (T x) { delay (x, 62); }
+void delay_63 (T x) { delay (x, 63); }
+
+#endif /* optimize */
+
+int main (void)
+{
+    return 0;
+}

commit c7257486630c419f0d140d558eaa20d183439811
Author: Georg-Johann Lay <avr@gjlay.de>
Date:   Sun Aug 18 17:07:15 2024

    AVR: ad target/116407 - Fix linker error "relocation truncated to fit".
    
            PR target/116407
    gcc/
            * config/avr/avr.md (*dec-and-branchhi!=-1.l.clobber):
            Increase the additional jump offset to 2 words.
    
    (cherry picked from commit 22acd3c4d18dbd4d4d39d7770145fe3ec36073f6)

diff --git a/gcc/config/avr/avr.md b/gcc/config/avr/avr.md
index 9aaefcfcd64..b7273fa19f6 100644
--- a/gcc/config/avr/avr.md
+++ b/gcc/config/avr/avr.md
@@ -7884,7 +7884,7 @@
                      "sub %A0,%3" CR_TAB
                      "sbc %B0,__zero_reg__", operands);
 
-    int jump_mode = avr_jump_mode (operands[2], insn, 1 - avr_adiw_reg_p (operands[0]));
+    int jump_mode = avr_jump_mode (operands[2], insn, 2);
     const char *op = ((EQ == <CODE>) ^ (jump_mode == 1)) ? "brcc" : "brcs";
     operands[1] = gen_rtx_CONST_STRING (VOIDmode, op);
 

commit 1fad6adae966ffae20a7afba14ec80e07c2d5c22
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Mon Aug 19 02:21:54 2024

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 7ad5949db06..ea9c99fbc74 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,24 @@
+2024-08-18  Georg-Johann Lay  <avr@gjlay.de>
+
+	Backported from master:
+	2024-08-18  Georg-Johann Lay  <avr@gjlay.de>
+
+	PR target/116407
+	* config/avr/avr.md (*dec-and-branchhi!=-1.l.clobber):
+	Increase the additional jump offset to 2 words.
+
+2024-08-18  Georg-Johann Lay  <avr@gjlay.de>
+
+	Backported from master:
+	2024-08-18  Georg-Johann Lay  <avr@gjlay.de>
+
+	PR target/116407
+	* config/avr/avr-protos.h (avr_jump_mode): Add an int argument.
+	* config/avr/avr.cc (avr_jump_mode): Add an int argument to increase
+	the computed jump offset of backwards branches.
+	* config/avr/avr.md (*dec-and-branchhi!=-1, *dec-and-branchsi!=-1):
+	Increase the jump offset used by avr_jump_mode() as needed.
+
 2024-08-17  Georg-Johann Lay  <avr@gjlay.de>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 5e34934c797..6197155f323 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240818
+20240819
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 0ddafb8ae54..f716cd65c05 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,12 @@
+2024-08-18  Georg-Johann Lay  <avr@gjlay.de>
+
+	Backported from master:
+	2024-08-18  Georg-Johann Lay  <avr@gjlay.de>
+
+	PR target/116407
+	* gcc.target/avr/torture/pr116407-2.c: New test.
+	* gcc.target/avr/torture/pr116407-4.c: New test.
+
 2024-08-17  Georg-Johann Lay  <avr@gjlay.de>
 
 	Backported from master:

commit af97b5eb023756c4a00c8c3327395f3d069d7e26
Author: Torbjörn SVENSSON <torbjorn.svensson@foss.st.com>
Date:   Mon Aug 19 10:44:44 2024

    testsuite: Prune warning about size of enums
    
    This fixes reported regression at
    https://linaro.atlassian.net/browse/GNU-1315.
    
    gcc/testsuite/ChangeLog:
    
            * g++.dg/warn/pr33738-2.C: dg-prune arm linker messages about
            size of enums.
    
    Signed-off-by: Torbjörn SVENSSON <torbjorn.svensson@foss.st.com>
    (cherry picked from commit 6d8b9b772e0b3969e6b3fcf0363d6afcce2e65c9)

diff --git a/gcc/testsuite/g++.dg/warn/pr33738-2.C b/gcc/testsuite/g++.dg/warn/pr33738-2.C
index 84bbdaeecc7..1ab121893ee 100644
--- a/gcc/testsuite/g++.dg/warn/pr33738-2.C
+++ b/gcc/testsuite/g++.dg/warn/pr33738-2.C
@@ -1,4 +1,5 @@
 // { dg-do run }
+// { dg-prune-output "use of enum values across objects may fail" }
 // { dg-options "-O2 -Wtype-limits -fstrict-enums -fshort-enums" }
 extern void link_error (void);
 

commit 52da8588fd06198edcda81d7acf83ec92ccb63ef
Author: Marek Polacek <polacek@redhat.com>
Date:   Thu Aug 15 17:53:10 2024

    c++: fix ICE in convert_nontype_argument [PR116384]
    
    Here we ICE since r14-8291 in C++11/C++14 modes.  Fortunately
    this is an easy one.
    
    The important bit of r14-8291 is this:
    
    @@ -20056,9 +20071,12 @@ tsubst_expr (tree t, tree args, tsubst_flags_t complain, tree in_decl)
            RETURN (retval);
          }
        if (IMPLICIT_CONV_EXPR_NONTYPE_ARG (t))
    -     /* We'll pass this to convert_nontype_argument again, we don't need
    -        to actually perform any conversion here.  */
    -     RETURN (expr);
    +     {
    +       tree r = convert_nontype_argument (type, expr, complain);
    +       if (r == NULL_TREE)
    +         r = error_mark_node;
    +       RETURN (r);
    +     }
    
    which obviously means that instead of returning right away we go
    to convert_nontype_argument.  When type is error_mark_node and we're
    in C++17, in convert_nontype_argument we go down this path:
    
          else if (INTEGRAL_OR_ENUMERATION_TYPE_P (type)
                   || cxx_dialect >= cxx17)
            {
              expr = build_converted_constant_expr (type, expr, complain);
              if (expr == error_mark_node)
                return (complain & tf_error) ? NULL_TREE : error_mark_node;
              // ...
            }
    
    but pre-C++17, we take a different route and end up crashing on
    gcc_unreachable.
    
    It would of course also work to check for error_mark_node early in
    build_converted_constant_expr.
    
            PR c++/116384
    
    gcc/cp/ChangeLog:
    
            * pt.cc (tsubst_expr) <case IMPLICIT_CONV_EXPR>: Bail if tsubst
            returns error_mark_node.
    
    gcc/testsuite/ChangeLog:
    
            * g++.dg/cpp0x/vt-116384.C: New test.
    
    (cherry picked from commit 8191f15022b0ea44fcb549449b0458d07ae02e0a)

diff --git a/gcc/cp/pt.cc b/gcc/cp/pt.cc
index 96a4f45909d..8e6a7d1a64a 100644
--- a/gcc/cp/pt.cc
+++ b/gcc/cp/pt.cc
@@ -20220,6 +20220,8 @@ tsubst_expr (tree t, tree args, tsubst_flags_t complain, tree in_decl)
     case IMPLICIT_CONV_EXPR:
       {
 	tree type = tsubst (TREE_TYPE (t), args, complain, in_decl);
+	if (type == error_mark_node)
+	  RETURN (error_mark_node);
 	tree expr = RECUR (TREE_OPERAND (t, 0));
 	if (dependent_type_p (type) || type_dependent_expression_p (expr))
 	  {
diff --git a/gcc/testsuite/g++.dg/cpp0x/vt-116384.C b/gcc/testsuite/g++.dg/cpp0x/vt-116384.C
new file mode 100644
index 00000000000..54d7f0774c5
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp0x/vt-116384.C
@@ -0,0 +1,26 @@
+// PR c++/116384
+// { dg-do compile { target c++11 } }
+
+namespace a {
+template <bool, typename> struct c;
+template <typename> struct d;
+}
+namespace e {
+namespace g {
+template <typename> using h = void;
+template <typename, template <typename> class, typename...> struct detector {};
+template <template <typename> class i, typename... args>
+struct detector<h<i<args...>>, i, args...>;
+}
+template <template <typename> class i, typename... args>
+using j = g::detector<void, i, args...>;
+template <bool b, typename k = void> using l = typename a::c<b, k>::m;
+template <typename> struct conjunction;
+namespace g {
+template <typename k> using n = l<conjunction<a::d<k>>::p>;
+}
+template <typename k, g::n<k> = true> class o;
+}
+struct r;
+template <typename k> using q = e::o<k>;
+void s() { e::j<q, r> f; }

commit 76ac16766a7e9432723de4e338192ef823518b8a
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Tue Aug 20 02:23:37 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 6197155f323..0ed256ba1fe 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240819
+20240820
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index 3dd34cf4e81..ebb02354925 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -1,3 +1,12 @@
+2024-08-19  Marek Polacek  <polacek@redhat.com>
+
+	Backported from master:
+	2024-08-19  Marek Polacek  <polacek@redhat.com>
+
+	PR c++/116384
+	* pt.cc (tsubst_expr) <case IMPLICIT_CONV_EXPR>: Bail if tsubst
+	returns error_mark_node.
+
 2024-08-15  Patrick Palka  <ppalka@redhat.com>
 
 	Backported from master:
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index f716cd65c05..81206ced115 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,19 @@
+2024-08-19  Marek Polacek  <polacek@redhat.com>
+
+	Backported from master:
+	2024-08-19  Marek Polacek  <polacek@redhat.com>
+
+	PR c++/116384
+	* g++.dg/cpp0x/vt-116384.C: New test.
+
+2024-08-19  Torbjörn SVENSSON  <torbjorn.svensson@foss.st.com>
+
+	Backported from master:
+	2024-08-19  Torbjörn SVENSSON  <torbjorn.svensson@foss.st.com>
+
+	* g++.dg/warn/pr33738-2.C: dg-prune arm linker messages about
+	size of enums.
+
 2024-08-18  Georg-Johann Lay  <avr@gjlay.de>
 
 	Backported from master:

commit 25812d8b789748911e800a972e5a3a030e3ac905
Author: Alexandre Oliva <oliva@adacore.com>
Date:   Wed Jun 26 07:08:18 2024

    [testsuite] [arm] [vect] adjust mve-vshr test [PR113281]
    
    The test was too optimistic, alas.  We used to vectorize shifts by
    clamping the shift counts below the bit width of the types (e.g. at 15
    for 16-bit vector elements), but (uint16_t)32768 >> (uint16_t)16 is
    well defined (because of promotion to 32-bit int) and must yield 0,
    not 1 (as before the fix).
    
    Unfortunately, in the gimple model of vector units, such large shift
    counts wouldn't be well-defined, so we won't vectorize such shifts any
    more, unless we can tell they're in range or undefined.
    
    So the test that expected the vectorization we no longer performed
    needs to be adjusted.  Instead of nobbling the test, Richard Earnshaw
    suggested annotating the test with the expected ranges so as to enable
    the optimization, and Christophe Lyon suggested a further
    simplification.
    
    Co-Authored-By: Richard Earnshaw <Richard.Earnshaw@arm.com>
    
    for  gcc/testsuite/ChangeLog
    
            PR tree-optimization/113281
            * gcc.target/arm/simd/mve-vshr.c: Add expected ranges.
    
    (cherry picked from commit 54d2339c9f87f702e02e571a5460e11c19e1c02f)

diff --git a/gcc/testsuite/gcc.target/arm/simd/mve-vshr.c b/gcc/testsuite/gcc.target/arm/simd/mve-vshr.c
index 8c7adef9ed8..03078de49c6 100644
--- a/gcc/testsuite/gcc.target/arm/simd/mve-vshr.c
+++ b/gcc/testsuite/gcc.target/arm/simd/mve-vshr.c
@@ -9,6 +9,8 @@
   void test_ ## NAME ##_ ## SIGN ## BITS ## x ## NB (TYPE##BITS##_t * __restrict__ dest, TYPE##BITS##_t *a, TYPE##BITS##_t *b) { \
     int i;								\
     for (i=0; i<NB; i++) {						\
+      if ((unsigned)b[i] >= (unsigned)(BITS))				\
+	__builtin_unreachable();					\
       dest[i] = a[i] OP b[i];						\
     }									\
 }

commit 5146af5ede1ffc1af1dfcc98dd706ee9baf2c146
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Wed Aug 21 02:24:10 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 0ed256ba1fe..2927c941b57 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240820
+20240821
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 81206ced115..4726faaceba 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,12 @@
+2024-08-20  Alexandre Oliva  <oliva@adacore.com>
+
+	Backported from master:
+	2024-06-26  Alexandre Oliva  <oliva@adacore.com>
+		    Richard Earnshaw  <Richard.Earnshaw@arm.com>
+
+	PR tree-optimization/113281
+	* gcc.target/arm/simd/mve-vshr.c: Add expected ranges.
+
 2024-08-19  Marek Polacek  <polacek@redhat.com>
 
 	Backported from master:

commit ffd458d815d3fc8fe1ebacb9c7b9bc6917aa25e1
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Thu Aug 22 02:22:57 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 2927c941b57..7e53ea86edc 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240821
+20240822

commit 27dc1533b6dfc49f3912c524db51d6c372a5ac3d
Author: liuhongt <hongtao.liu@intel.com>
Date:   Thu Aug 15 06:54:07 2024

    Align ix86_{move_max,store_max} with vectorizer.
    
    When none of mprefer-vector-width, avx256_optimal/avx128_optimal,
    avx256_store_by_pieces/avx512_store_by_pieces is specified, GCC will
    set ix86_{move_max,store_max} as max available vector length except
    for AVX part.
    
                  if (TARGET_AVX512F_P (opts->x_ix86_isa_flags)
                      && TARGET_EVEX512_P (opts->x_ix86_isa_flags2))
                    opts->x_ix86_move_max = PVW_AVX512;
                  else
                    opts->x_ix86_move_max = PVW_AVX128;
    
    So for -mavx2, vectorizer will choose 256-bit for vectorization, but
    128-bit is used for struct copy, there could be a potential STLF issue
    due to this "misalign".
    
    The patch fixes that.
    
    gcc/ChangeLog:
    
            * config/i386/i386-options.cc (ix86_option_override_internal):
            set ix86_{move_max,store_max} to PVW_AVX256 when TARGET_AVX
            instead of PVW_AVX128.
    
    gcc/testsuite/ChangeLog:
            * gcc.target/i386/pieces-memcpy-10.c: Add -mprefer-vector-width=128.
            * gcc.target/i386/pieces-memcpy-6.c: Ditto.
            * gcc.target/i386/pieces-memset-38.c: Ditto.
            * gcc.target/i386/pieces-memset-40.c: Ditto.
            * gcc.target/i386/pieces-memset-41.c: Ditto.
            * gcc.target/i386/pieces-memset-42.c: Ditto.
            * gcc.target/i386/pieces-memset-43.c: Ditto.
            * gcc.target/i386/pieces-strcpy-2.c: Ditto.
            * gcc.target/i386/pieces-memcpy-22.c: New test.
            * gcc.target/i386/pieces-memset-51.c: New test.
            * gcc.target/i386/pieces-strcpy-3.c: New test.
    
    (cherry picked from commit 6ea25c041964bf63014fcf7bb68fb1f5a0a4e123)

diff --git a/gcc/config/i386/i386-options.cc b/gcc/config/i386/i386-options.cc
index 6c212a8edeb..f6c450cc871 100644
--- a/gcc/config/i386/i386-options.cc
+++ b/gcc/config/i386/i386-options.cc
@@ -3062,6 +3062,9 @@ ix86_option_override_internal (bool main_args_p,
 	      if (TARGET_AVX512F_P (opts->x_ix86_isa_flags)
 		  && TARGET_EVEX512_P (opts->x_ix86_isa_flags2))
 		opts->x_ix86_move_max = PVW_AVX512;
+	      /* Align with vectorizer to avoid potential STLF issue.  */
+	      else if (TARGET_AVX_P (opts->x_ix86_isa_flags))
+		opts->x_ix86_move_max = PVW_AVX256;
 	      else
 		opts->x_ix86_move_max = PVW_AVX128;
 	    }
@@ -3086,6 +3089,9 @@ ix86_option_override_internal (bool main_args_p,
 	      if (TARGET_AVX512F_P (opts->x_ix86_isa_flags)
 		  && TARGET_EVEX512_P (opts->x_ix86_isa_flags2))
 		opts->x_ix86_store_max = PVW_AVX512;
+	      /* Align with vectorizer to avoid potential STLF issue.  */
+	      else if (TARGET_AVX_P (opts->x_ix86_isa_flags))
+		opts->x_ix86_store_max = PVW_AVX256;
 	      else
 		opts->x_ix86_store_max = PVW_AVX128;
 	    }
diff --git a/gcc/testsuite/gcc.target/i386/pieces-memcpy-10.c b/gcc/testsuite/gcc.target/i386/pieces-memcpy-10.c
index 5faee21f9b9..53ad0b3be44 100644
--- a/gcc/testsuite/gcc.target/i386/pieces-memcpy-10.c
+++ b/gcc/testsuite/gcc.target/i386/pieces-memcpy-10.c
@@ -1,5 +1,5 @@
 /* { dg-do compile } */
-/* { dg-options "-O2 -mno-avx2 -mavx -mtune=sandybridge" } */
+/* { dg-options "-O2 -mno-avx2 -mavx -mprefer-vector-width=128 -mtune=sandybridge" } */
 
 extern char *dst, *src;
 
diff --git a/gcc/testsuite/gcc.target/i386/pieces-memcpy-22.c b/gcc/testsuite/gcc.target/i386/pieces-memcpy-22.c
new file mode 100644
index 00000000000..605b3623ffc
--- /dev/null
+++ b/gcc/testsuite/gcc.target/i386/pieces-memcpy-22.c
@@ -0,0 +1,12 @@
+/* { dg-do compile { target { ! ia32 } } } */
+/* { dg-options "-O2 -mno-avx2 -mavx -mtune=generic" } */
+
+extern char *dst, *src;
+
+void
+foo (void)
+{
+  __builtin_memcpy (dst, src, 33);
+}
+
+/* { dg-final { scan-assembler-times "vmovdqu\[ \\t\]+\[^\n\]*%ymm" 2 } } */
diff --git a/gcc/testsuite/gcc.target/i386/pieces-memcpy-6.c b/gcc/testsuite/gcc.target/i386/pieces-memcpy-6.c
index 5f99cc98c47..cfd2a86cf33 100644
--- a/gcc/testsuite/gcc.target/i386/pieces-memcpy-6.c
+++ b/gcc/testsuite/gcc.target/i386/pieces-memcpy-6.c
@@ -1,5 +1,5 @@
 /* { dg-do compile { target { ! ia32 } } } */
-/* { dg-options "-O2 -mno-avx2 -mavx -mtune=sandybridge" } */
+/* { dg-options "-O2 -mno-avx2 -mavx -mprefer-vector-width=128 -mtune=sandybridge" } */
 
 extern char *dst, *src;
 
diff --git a/gcc/testsuite/gcc.target/i386/pieces-memset-38.c b/gcc/testsuite/gcc.target/i386/pieces-memset-38.c
index ed4a24a54fd..ddd194debd5 100644
--- a/gcc/testsuite/gcc.target/i386/pieces-memset-38.c
+++ b/gcc/testsuite/gcc.target/i386/pieces-memset-38.c
@@ -1,5 +1,5 @@
 /* { dg-do compile } */
-/* { dg-options "-O2 -mno-avx512f -mavx2 -mtune=sandybridge" } */
+/* { dg-options "-O2 -mno-avx512f -mavx2 -mprefer-vector-width=128 -mtune=sandybridge" } */
 
 extern char *dst;
 
diff --git a/gcc/testsuite/gcc.target/i386/pieces-memset-40.c b/gcc/testsuite/gcc.target/i386/pieces-memset-40.c
index 86358c99a83..5878876550c 100644
--- a/gcc/testsuite/gcc.target/i386/pieces-memset-40.c
+++ b/gcc/testsuite/gcc.target/i386/pieces-memset-40.c
@@ -1,5 +1,5 @@
 /* { dg-do compile } */
-/* { dg-options "-O2 -mno-avx512f -mavx2 -mtune=sandybridge" } */
+/* { dg-options "-O2 -mno-avx512f -mavx2 -mprefer-vector-width=128 -mtune=sandybridge" } */
 /* Cope with --enable-frame-pointer, Solaris/x86 -mstackrealign default.  */
 /* { dg-additional-options "-fomit-frame-pointer -mno-stackrealign" } */
 
diff --git a/gcc/testsuite/gcc.target/i386/pieces-memset-41.c b/gcc/testsuite/gcc.target/i386/pieces-memset-41.c
index d7a27f52983..27a6c8ad139 100644
--- a/gcc/testsuite/gcc.target/i386/pieces-memset-41.c
+++ b/gcc/testsuite/gcc.target/i386/pieces-memset-41.c
@@ -1,5 +1,5 @@
 /* { dg-do compile } */
-/* { dg-options "-O2 -mno-avx2 -mavx -mtune=sandybridge -mno-stackrealign" } */
+/* { dg-options "-O2 -mno-avx2 -mavx -mprefer-vector-width=128 -mtune=sandybridge -mno-stackrealign" } */
 /* Cope with --enable-frame-pointer.  */
 /* { dg-additional-options "-fomit-frame-pointer" } */
 
diff --git a/gcc/testsuite/gcc.target/i386/pieces-memset-42.c b/gcc/testsuite/gcc.target/i386/pieces-memset-42.c
index df0c122aae7..103da699ae5 100644
--- a/gcc/testsuite/gcc.target/i386/pieces-memset-42.c
+++ b/gcc/testsuite/gcc.target/i386/pieces-memset-42.c
@@ -1,5 +1,5 @@
 /* { dg-do compile } */
-/* { dg-options "-O2 -mno-avx2 -mavx -mtune=sandybridge" } */
+/* { dg-options "-O2 -mno-avx2 -mavx -mprefer-vector-width=128 -mtune=sandybridge" } */
 
 extern char *dst;
 
diff --git a/gcc/testsuite/gcc.target/i386/pieces-memset-43.c b/gcc/testsuite/gcc.target/i386/pieces-memset-43.c
index 2f2179c2df9..f1494e17610 100644
--- a/gcc/testsuite/gcc.target/i386/pieces-memset-43.c
+++ b/gcc/testsuite/gcc.target/i386/pieces-memset-43.c
@@ -1,5 +1,5 @@
 /* { dg-do compile } */
-/* { dg-options "-O2 -mno-avx2 -mavx -mtune=sandybridge" } */
+/* { dg-options "-O2 -mno-avx2 -mavx -mprefer-vector-width=128 -mtune=sandybridge" } */
 
 extern char *dst;
 
diff --git a/gcc/testsuite/gcc.target/i386/pieces-memset-51.c b/gcc/testsuite/gcc.target/i386/pieces-memset-51.c
new file mode 100644
index 00000000000..192ec0d1647
--- /dev/null
+++ b/gcc/testsuite/gcc.target/i386/pieces-memset-51.c
@@ -0,0 +1,12 @@
+/* { dg-do compile } */
+/* { dg-options "-O2 -mno-avx2 -mavx -mtune=generic" } */
+
+extern char *dst;
+
+void
+foo (int x)
+{
+  __builtin_memset (dst, x, 64);
+}
+
+/* { dg-final { scan-assembler-times "vmovdqu\[ \\t\]+\[^\n\]*%ymm" 2 } } */
diff --git a/gcc/testsuite/gcc.target/i386/pieces-strcpy-2.c b/gcc/testsuite/gcc.target/i386/pieces-strcpy-2.c
index 90446edb4f3..9bb94b7419b 100644
--- a/gcc/testsuite/gcc.target/i386/pieces-strcpy-2.c
+++ b/gcc/testsuite/gcc.target/i386/pieces-strcpy-2.c
@@ -1,5 +1,5 @@
 /* { dg-do compile { target { ! ia32 } } } */
-/* { dg-options "-O2 -mno-avx2 -mavx -mtune=sandybridge" } */
+/* { dg-options "-O2 -mno-avx2 -mavx -mprefer-vector-width=128 -mtune=sandybridge" } */
 
 extern char *strcpy (char *, const char *);
 
diff --git a/gcc/testsuite/gcc.target/i386/pieces-strcpy-3.c b/gcc/testsuite/gcc.target/i386/pieces-strcpy-3.c
new file mode 100644
index 00000000000..df7571b547f
--- /dev/null
+++ b/gcc/testsuite/gcc.target/i386/pieces-strcpy-3.c
@@ -0,0 +1,15 @@
+/* { dg-do compile { target { ! ia32 } } } */
+/* { dg-options "-O2 -mno-avx2 -mavx -mtune=generic" } */
+
+extern char *strcpy (char *, const char *);
+
+void
+foo (char *s)
+{
+  strcpy (s,
+	  "1234567890abcdef123456abcdef5678123456abcdef567abcdef678"
+	  "1234567");
+}
+
+/* { dg-final { scan-assembler-times "vmovdqa\[ \\t\]+\[^\n\]*%ymm" 2 } } */
+/* { dg-final { scan-assembler-times "vmovdqu\[ \\t\]+\[^\n\]*%ymm" 2 } } */

commit 8de3153a65ea402e110fd3ba6d89da72c5e29219
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Fri Aug 23 02:21:22 2024

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index ea9c99fbc74..6749e3e5f9a 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,12 @@
+2024-08-22  liuhongt  <hongtao.liu@intel.com>
+
+	Backported from master:
+	2024-08-22  liuhongt  <hongtao.liu@intel.com>
+
+	* config/i386/i386-options.cc (ix86_option_override_internal):
+	set ix86_{move_max,store_max} to PVW_AVX256 when TARGET_AVX
+	instead of PVW_AVX128.
+
 2024-08-18  Georg-Johann Lay  <avr@gjlay.de>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 7e53ea86edc..cd765ecede6 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240822
+20240823
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 4726faaceba..a2ffda55dc8 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,20 @@
+2024-08-22  liuhongt  <hongtao.liu@intel.com>
+
+	Backported from master:
+	2024-08-22  liuhongt  <hongtao.liu@intel.com>
+
+	* gcc.target/i386/pieces-memcpy-10.c: Add -mprefer-vector-width=128.
+	* gcc.target/i386/pieces-memcpy-6.c: Ditto.
+	* gcc.target/i386/pieces-memset-38.c: Ditto.
+	* gcc.target/i386/pieces-memset-40.c: Ditto.
+	* gcc.target/i386/pieces-memset-41.c: Ditto.
+	* gcc.target/i386/pieces-memset-42.c: Ditto.
+	* gcc.target/i386/pieces-memset-43.c: Ditto.
+	* gcc.target/i386/pieces-strcpy-2.c: Ditto.
+	* gcc.target/i386/pieces-memcpy-22.c: New test.
+	* gcc.target/i386/pieces-memset-51.c: New test.
+	* gcc.target/i386/pieces-strcpy-3.c: New test.
+
 2024-08-20  Alexandre Oliva  <oliva@adacore.com>
 
 	Backported from master:

commit 5b75e1c15f97b4a41ad0cf0876f07b5169e05940
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Sat Aug 24 02:22:38 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index cd765ecede6..8df515083dd 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240823
+20240824

commit b414466d1c08d77aa2be3f99d9c11206499df674
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Sun Aug 25 02:23:36 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 8df515083dd..928d43e6afd 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240824
+20240825

commit ef9c53b6e65893c258ec16186260be2a26edd9e3
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Mon Aug 26 02:23:14 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 928d43e6afd..0f44912c686 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240825
+20240826

commit 75892d97979f397a66730b97e8279941169e0316
Author: YunQiang Su <syq@gcc.gnu.org>
Date:   Fri Aug 23 17:46:16 2024

    MIPS: Include missing mips16.S in libgcc/lib1funcs.S
    
    mips16.S was missing since
    commit 29b74545531f6afbee9fc38c267524326dbfbedf
    Date:   Thu Jun 1 10:14:24 2023 +0800
    
        MIPS: Add speculation_barrier support
    
    Without mips16.S included, some symbols will miss for mips16, and
    so some software will fail to build.
    
    libgcc/ChangeLog:
    
            * config/mips/lib1funcs.S: Includes mips16.S.
    
    (cherry picked from commit 9522fc8bb7812f2ad50eb038e0938bfd958e730f)

diff --git a/libgcc/config/mips/lib1funcs.S b/libgcc/config/mips/lib1funcs.S
index fa8114b37d9..324a84e7846 100644
--- a/libgcc/config/mips/lib1funcs.S
+++ b/libgcc/config/mips/lib1funcs.S
@@ -19,7 +19,7 @@ a copy of the GCC Runtime Library Exception along with this program;
 see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
 <http://www.gnu.org/licenses/>.  */
 
-//#include "mips16.S"
+#include "mips16.S"
 
 #ifdef L_speculation_barrier
 

commit 90b123253dd28e03cbec03e8c71cafc366a3f602
Author: Joseph Myers <josmyers@redhat.com>
Date:   Tue Aug 27 23:21:58 2024

    Update gcc zh_CN.po
    
            * zh_CN.po: Update.

diff --git a/gcc/po/zh_CN.po b/gcc/po/zh_CN.po
index 133c36a8ec4..b80a0281e24 100644
--- a/gcc/po/zh_CN.po
+++ b/gcc/po/zh_CN.po
@@ -6,6 +6,7 @@
 # Mingye Wang (Arthur2e5) <arthur200126@gmail.com>, 2015, 2016.
 # Boyuan Yang <073plan@gmail.com>, 2019, 2023, 2024.
 # Zixing Zhou <zixingzhou@foxmail.com>, 2023.
+# Zhanhaoxiang Zhang <zzhx2006@outlook.com>, 2024.
 #
 # Fellow translatiors:
 # Many of the fuzzy strings are caused by an addition of a period (".")
@@ -35,8 +36,8 @@ msgstr ""
 "Project-Id-Version: gcc 14.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
 "POT-Creation-Date: 2024-07-25 16:23+0000\n"
-"PO-Revision-Date: 2024-08-02 12:22-0400\n"
-"Last-Translator: Boyuan Yang <073plan@gmail.com>\n"
+"PO-Revision-Date: 2024-08-27 16:17+0800\n"
+"Last-Translator: Zhanhaoxiang Zhang <zzhx2006@outlook.com>\n"
 "Language-Team: Chinese (simplified) <i18n-zh@googlegroups.com>\n"
 "Language: zh_CN\n"
 "MIME-Version: 1.0\n"
@@ -44,7 +45,7 @@ msgstr ""
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=1; plural=0;\n"
 "X-Bugs: Report translation errors to the Language-Team address.\n"
-"X-Generator: Poedit 3.4.4\n"
+"X-Generator: Poedit 3.4.2\n"
 
 #: cif-code.def:39
 msgid "function not considered for inlining"
@@ -8005,46 +8006,39 @@ msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512
 msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2、AVX512F 和 AVX512VBMI 内建函数及代码生成。"
 
 #: config/i386/i386.opt:778
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512IFMA built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX5124FMAPS built-in functions and code generation."
-msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2、AVX512F 和 AVX512IFMA 内建函数及代码生成。"
+msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2、AVX512F 和 AVX5124FMAPS 内建函数及代码生成。"
 
 #: config/i386/i386.opt:782
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512VBMI built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX5124VNNIW built-in functions and code generation."
-msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2、AVX512F 和 AVX512VBMI 内建函数及代码生成。"
+msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2、AVX512F 和 AVX5124VNNIW 内建函数及代码生成。"
 
 #: config/i386/i386.opt:786
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512DQ built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX512VPOPCNTDQ built-in functions and code generation."
-msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2、AVX512F 和 AVX512DQ 内建函数及代码生成。"
+msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2、AVX512F 和 AVX512VPOPCNTDQ 内建函数及代码生成。"
 
 #: config/i386/i386.opt:790
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512VBMI built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX512VBMI2 built-in functions and code generation."
-msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2、AVX512F 和 AVX512VBMI 内建函数及代码生成。"
+msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2、AVX512F 和 AVX512VBMI2 内建函数及代码生成。"
 
 #: config/i386/i386.opt:794
-#, fuzzy, no-c-format
-#| msgid "Support BMI built-in functions and code generation."
+#, no-c-format
 msgid "Support AVX512VNNI built-in functions and code generation."
-msgstr "支持 BMI 内建函数及代码生成"
+msgstr "支持 AVX512VNNI 内建函数及代码生成。"
 
 #: config/i386/i386.opt:798
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512IFMA built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX512BITALG built-in functions and code generation."
-msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2、AVX512F 和 AVX512IFMA 内建函数及代码生成。"
+msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2、AVX512F 和 AVX512BITALG 内建函数及代码生成。"
 
 #: config/i386/i386.opt:802
-#, fuzzy, no-c-format
-#| msgid "Support BMI built-in functions and code generation."
+#, no-c-format
 msgid "Support AVX512VP2INTERSECT built-in functions and code generation."
-msgstr "支持 BMI 内建函数及代码生成"
+msgstr "支持 AVX512VP2INTERSECT 内建函数及代码生成。"
 
 #: config/i386/i386.opt:806
 #, no-c-format
@@ -8082,58 +8076,49 @@ msgid "Support code generation of popcnt instruction."
 msgstr "支持生成 popcnt 指令。"
 
 #: config/i386/i386.opt:834
-#, fuzzy, no-c-format
-#| msgid "Support PKU built-in functions and code generation."
+#, no-c-format
 msgid "Support PCONFIG built-in functions and code generation."
-msgstr "支持 PKU 内建函数及代码生成。"
+msgstr "支持 PCONFIG 内建函数及代码生成。"
 
 #: config/i386/i386.opt:838
-#, fuzzy, no-c-format
-#| msgid "Support BMI built-in functions and code generation."
+#, no-c-format
 msgid "Support WBNOINVD built-in functions and code generation."
-msgstr "支持 BMI 内建函数及代码生成"
+msgstr "支持 WBNOINVD 内建函数及代码生成。"
 
 #: config/i386/i386.opt:842
-#, fuzzy, no-c-format
-#| msgid "Support RTM built-in functions and code generation."
+#, no-c-format
 msgid "Support PTWRITE built-in functions and code generation."
-msgstr "支持 RTM 内建函数及代码生成。"
+msgstr "支持 PTWRITE 内建函数及代码生成。"
 
 #: config/i386/i386.opt:846
-#, fuzzy, no-c-format
-#| msgid "Support BMI built-in functions and code generation."
+#, no-c-format
 msgid "Support UINTR built-in functions and code generation."
-msgstr "支持 BMI 内建函数及代码生成"
+msgstr "支持 UINTR 内建函数及代码生成。"
 
 #: config/i386/i386.opt:850
-#, fuzzy, no-c-format
-#| msgid "Support XOP built-in functions and code generation."
+#, no-c-format
 msgid "Support SGX built-in functions and code generation."
-msgstr "支持 XOP 内建函数及代码生成。"
+msgstr "支持 SGX 内建函数及代码生成。"
 
 #: config/i386/i386.opt:854
-#, fuzzy, no-c-format
-#| msgid "Support RDRND built-in functions and code generation."
+#, no-c-format
 msgid "Support RDPID built-in functions and code generation."
-msgstr "支持 RDRND 内建函数及代码生成。"
+msgstr "支持 RDPID 内建函数及代码生成。"
 
 #: config/i386/i386.opt:858
-#, fuzzy, no-c-format
-#| msgid "Support BMI built-in functions and code generation."
+#, no-c-format
 msgid "Support GFNI built-in functions and code generation."
-msgstr "支持 BMI 内建函数及代码生成"
+msgstr "支持 GFNI 内建函数及代码生成。"
 
 #: config/i386/i386.opt:862
-#, fuzzy, no-c-format
-#| msgid "Support AES built-in functions and code generation."
+#, no-c-format
 msgid "Support VAES built-in functions and code generation."
-msgstr "支持 AES 内建函数及代码生成。"
+msgstr "支持 VAES 内建函数及代码生成。"
 
 #: config/i386/i386.opt:866
-#, fuzzy, no-c-format
-#| msgid "Support PCLMUL built-in functions and code generation."
+#, no-c-format
 msgid "Support VPCLMULQDQ built-in functions and code generation."
-msgstr "支持 PCLMUL 内建函数及代码生成。"
+msgstr "支持 VPCLMULQDQ 内建函数及代码生成。"
 
 #: config/i386/i386.opt:870
 #, no-c-format
@@ -8392,28 +8377,24 @@ msgid "Force indirect call and jump via register."
 msgstr ""
 
 #: config/i386/i386.opt:1128
-#, fuzzy, no-c-format
-#| msgid "Support BMI built-in functions and code generation."
+#, no-c-format
 msgid "Support MOVDIRI built-in functions and code generation."
-msgstr "支持 BMI 内建函数及代码生成"
+msgstr "支持 MOVDIRI 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1132
-#, fuzzy, no-c-format
-#| msgid "Support BMI built-in functions and code generation."
+#, no-c-format
 msgid "Support MOVDIR64B built-in functions and code generation."
-msgstr "支持 BMI 内建函数及代码生成"
+msgstr "支持 MOVDIR64B 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1136
-#, fuzzy, no-c-format
-#| msgid "Support LWP built-in functions and code generation."
+#, no-c-format
 msgid "Support WAITPKG built-in functions and code generation."
-msgstr "支持 LWP 内建函数及代码生成。"
+msgstr "支持 WAITPKG 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1140
-#, fuzzy, no-c-format
-#| msgid "Support CLZERO built-in functions and code generation."
+#, no-c-format
 msgid "Support CLDEMOTE built-in functions and code generation."
-msgstr "支持 CLZERO 内建函数及代码。"
+msgstr "支持 CLDEMOTE 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1144
 #, fuzzy, no-c-format
@@ -8436,10 +8417,9 @@ msgid "Known choices for mitigation against straight line speculation with -mhar
 msgstr ""
 
 #: config/i386/i386.opt:1185
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512VBMI built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX512BF16 built-in functions and code generation."
-msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2、AVX512F 和 AVX512VBMI 内建函数及代码生成。"
+msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2、AVX512F 和 AVX512BF16 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1190
 #, no-c-format
@@ -8487,10 +8467,9 @@ msgid "Support WIDEKL built-in functions and code generation."
 msgstr "支持 WIDEKL 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1226
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, and AVXVNNI built-in functions and code generation."
-msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2 和 AVX512F 内建函数及代码生成。"
+msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2 和 AVXVNNI 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1231
 #, no-c-format
@@ -8498,16 +8477,14 @@ msgid "Emit GNU_PROPERTY_X86_ISA_1_NEEDED GNU property."
 msgstr ""
 
 #: config/i386/i386.opt:1235
-#, fuzzy, no-c-format
-#| msgid "Support MWAITX and MONITORX built-in functions and code generation."
+#, no-c-format
 msgid "Support MWAIT and MONITOR built-in functions and code generation."
-msgstr "支持 MWAITX 和 MONITORX 内建函数及代码生成。"
+msgstr "支持 MWAIT 和 MONITOR 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1239
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512IFMA built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX512-FP16 built-in functions and code generation."
-msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2、AVX512F 和 AVX512IFMA 内建函数及代码生成。"
+msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2、AVX512F 和 AVX512-FP16 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1243
 #, fuzzy, no-c-format
@@ -8520,46 +8497,39 @@ msgid "Instructions number above which STFL stall penalty can be compensated."
 msgstr ""
 
 #: config/i386/i386.opt:1251
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, and AVXIFMA built-in functions and code generation."
-msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2 和 AVX512F 内建函数及代码生成。"
+msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2 和 AVXIFMA 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1256
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVXVNNIINT8 built-in functions and code generation."
-msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2 和 AVX512F 内建函数及代码生成。"
+msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2 和 AVXVNNIINT8 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1261
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, and AVXNECONVERT build-in functions and code generation."
-msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2 和 AVX512F 内建函数及代码生成。"
+msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2 和 AVXNECONVERT 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1266
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, and CMPCCXADD build-in functions and code generation."
-msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2 和 AVX512F 内建函数及代码生成。"
+msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2 和 CMPCCXADD 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1271
-#, fuzzy, no-c-format
-#| msgid "Support F16C built-in functions and code generation."
+#, no-c-format
 msgid "Support AMX-FP16 built-in functions and code generation."
-msgstr "支持 F16C 内建函数及代码生成。"
+msgstr "支持 AMX-FP16 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1275
-#, fuzzy, no-c-format
-#| msgid "Support PREFETCHWT1 built-in functions and code generation."
+#, no-c-format
 msgid "Support PREFETCHI built-in functions and code generation."
-msgstr "支持 PREFETCHWT1 内建函数及代码生成。"
+msgstr "支持 PREFETCHI 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1279
-#, fuzzy, no-c-format
-#| msgid "Support BMI built-in functions and code generation."
+#, no-c-format
 msgid "Support RAOINT built-in functions and code generation."
-msgstr "支持 BMI 内建函数及代码生成"
+msgstr "支持 RAOINT 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1283
 #, no-c-format
@@ -8572,34 +8542,29 @@ msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers.
 msgstr ""
 
 #: config/i386/i386.opt:1303
-#, fuzzy, no-c-format
-#| msgid "Support AES built-in functions and code generation."
+#, no-c-format
 msgid "Support AMX-COMPLEX built-in functions and code generation."
-msgstr "支持 AES 内建函数及代码生成。"
+msgstr "支持 AMX-COMPLEX 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1307
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVXVNNIINT16 built-in functions and code generation."
-msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2 和 AVX512F 内建函数及代码生成。"
+msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2 和 AVXVNNIINT16 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1312
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and SM3 built-in functions and code generation."
-msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX 和 FMA 内建函数及代码生成。"
+msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX 和 SM3 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1317
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and SHA512 built-in functions and code generation."
-msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX 和 AVX2 内建函数及代码生成。"
+msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX 和 SHA512 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1322
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and SM4 built-in functions and code generation."
-msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX 和 FMA 内建函数及代码生成。"
+msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX 和 SM4 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1327
 #, fuzzy, no-c-format
@@ -8622,28 +8587,24 @@ msgid "Enable GPR32 in inline asm when APX_F enabled."
 msgstr ""
 
 #: config/i386/i386.opt:1368
-#, fuzzy, no-c-format
-#| msgid "Support BMI2 built-in functions and code generation."
+#, no-c-format
 msgid "Support 512 bit vector built-in functions and code generation."
-msgstr "支持 BMI2 内建函数及代码生成。"
+msgstr "支持512位矢量内建函数及代码生成。"
 
 #: config/i386/i386.opt:1372
-#, fuzzy, no-c-format
-#| msgid "Support AES built-in functions and code generation."
+#, no-c-format
 msgid "Support USER_MSR built-in functions and code generation."
-msgstr "支持 AES 内建函数及代码生成。"
+msgstr "支持 USER_MSR 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1376 config/i386/i386.opt:1386
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, and AVX10.1 built-in functions and code generation."
-msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2 和 AVX512F 内建函数及代码生成。"
+msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2 和 AVX10.1 内建函数及代码生成。"
 
 #: config/i386/i386.opt:1381
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, and AVX10.1-512 built-in functions and code generation."
-msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2 和 AVX512F 内建函数及代码生成。"
+msgstr "支持 MMX、SSE、SSE2、SSE3、SSSE3、SSE4.1、SSE4.2、AVX、AVX2 和 AVX10.1-512 内建函数及代码生成。"
 
 #: config/pa/pa64-hpux.opt:23
 #, no-c-format
@@ -25405,10 +25366,9 @@ msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
 msgstr[0] ""
 
 #: attribs.cc:2333 attribs.cc:2353
-#, fuzzy, gcc-internal-format
-#| msgid "%qD was declared here"
+#, gcc-internal-format
 msgid "%qD target declared here"
-msgstr "%qD在此声明"
+msgstr "%qD目标在此声明"
 
 #: attribs.cc:2347
 #, gcc-internal-format
@@ -25458,10 +25418,9 @@ msgid "offset %qwi outside bounds of constant string"
 msgstr "偏移量越过字符串常量界"
 
 #: builtins.cc:707 cp/name-lookup.cc:6830
-#, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
+#, gcc-internal-format
 msgid "%qE declared here"
-msgstr "%qD在此声明"
+msgstr "%qE在此声明"
 
 #: builtins.cc:1298
 #, gcc-internal-format
@@ -28429,10 +28388,9 @@ msgid "%<%.*s%> directive argument is not a nul-terminated string"
 msgstr ""
 
 #: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
-#, fuzzy, gcc-internal-format
-#| msgid "template parameter type %qT declared %<friend%>"
+#, gcc-internal-format
 msgid "referenced argument declared here"
-msgstr "模板形参类型%qT声明为%<friend%>"
+msgstr "引用的参数在此声明"
 
 #: gimple-ssa-sprintf.cc:3357
 #, gcc-internal-format
@@ -28644,10 +28602,9 @@ msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr "%qD在其类外被声明为%<constexpr%>"
 
 #: gimple-ssa-warn-access.cc:671
-#, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
+#, gcc-internal-format
 msgid "argument %qD declared here"
-msgstr "%qD在此声明"
+msgstr "参数%qD在此声明"
 
 #: gimple-ssa-warn-access.cc:730
 #, fuzzy, gcc-internal-format
@@ -29582,10 +29539,9 @@ msgid "%qD pointer overflow between offset %s and size %s accessing array %qD wi
 msgstr ""
 
 #: gimple-ssa-warn-restrict.cc:1785 c-family/c-warn.cc:3804
-#, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
+#, gcc-internal-format
 msgid "array %qD declared here"
-msgstr "%qD在此声明"
+msgstr "数组%qD在此声明"
 
 #: gimple-ssa-warn-restrict.cc:1790 gimple-ssa-warn-restrict.cc:1796
 #, gcc-internal-format
@@ -29642,10 +29598,9 @@ msgid "%qD offset %s from the object at %qE is out of the bounds of %qT"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
 #: gimple-ssa-warn-restrict.cc:1866 gimple-ssa-warn-restrict.cc:1887
-#, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
+#, gcc-internal-format
 msgid "subobject %qD declared here"
-msgstr "%qD在此声明"
+msgstr "子对象%qD在此声明"
 
 #: gimple-ssa-warn-restrict.cc:1876
 #, fuzzy, gcc-internal-format
@@ -34517,10 +34472,9 @@ msgid "in this expression"
 msgstr "  在抛出的表达式中"
 
 #: tree-ssa-uninit.cc:306
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not initialized"
+#, gcc-internal-format
 msgid "%qD is used uninitialized"
-msgstr "%qE未经初始化"
+msgstr "%qD未经初始化被使用"
 
 #: tree-ssa-uninit.cc:308
 #, fuzzy, gcc-internal-format
@@ -34529,10 +34483,9 @@ msgid "%qD may be used uninitialized"
 msgstr "此函数中的%qD在使用前可能未初始化"
 
 #: tree-ssa-uninit.cc:315
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not initialized"
+#, gcc-internal-format
 msgid "%qs is used uninitialized"
-msgstr "%qE未经初始化"
+msgstr "%qs未经初始化被使用"
 
 #: tree-ssa-uninit.cc:318
 #, fuzzy, gcc-internal-format
@@ -34546,10 +34499,9 @@ msgid "%qD was declared here"
 msgstr "%qD在此声明"
 
 #: tree-ssa-uninit.cc:339
-#, fuzzy, gcc-internal-format
-#| msgid "%qD was declared here"
+#, gcc-internal-format
 msgid "%qs was declared here"
-msgstr "%qD在此声明"
+msgstr "%qs在此声明"
 
 #: tree-ssa-uninit.cc:450 tree-ssa-uninit.cc:760
 #, fuzzy, gcc-internal-format
@@ -34563,10 +34515,9 @@ msgid "accessing argument %u of a function declared with attribute %<%s%>"
 msgstr "忽略声明有 warn_unused_result 属性的函数的返回值"
 
 #: tree-ssa-uninit.cc:747
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not initialized"
+#, gcc-internal-format
 msgid "%qE is used uninitialized"
-msgstr "%qE未经初始化"
+msgstr "%qE未经初始化被使用"
 
 #: tree-ssa-uninit.cc:882
 #, fuzzy, gcc-internal-format
@@ -39075,9 +39026,9 @@ msgid "conversion from %qT to %qT may change value"
 msgstr "%qT转换自%qT时可能改变值"
 
 #: c-family/c-warn.cc:1459 c-family/c-warn.cc:1477 c-family/c-warn.cc:1494
-#, fuzzy, gcc-internal-format
+#, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
-msgstr "C++ 中不允许从%qT到%qT的隐式转换"
+msgstr "在从%qT转换为%qT时发生溢出，值从%qE变为%qE"
 
 #: c-family/c-warn.cc:1464 c-family/c-warn.cc:1482 c-family/c-warn.cc:1499
 #, fuzzy, gcc-internal-format
@@ -39317,7 +39268,7 @@ msgstr "数组索引参数类型无效(有%qT)"
 #: c-family/c-warn.cc:1960
 #, gcc-internal-format
 msgid "invalid type argument of unary %<*%> (have %qT)"
-msgstr "一元 %<*%>参数类型无效(有%qT) "
+msgstr "一元 %<*%>参数类型无效(有%qT)"
 
 #: c-family/c-warn.cc:1965
 #, gcc-internal-format
@@ -54885,8 +54836,7 @@ msgstr "将 NULL 作为非指针实参 %P 传递给%qD"
 
 #: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
 #: cp/typeck.cc:4602
-#, fuzzy, gcc-internal-format
-#| msgid "declared here"
+#, gcc-internal-format
 msgid "  declared here"
 msgstr "在此声明"
 
@@ -55212,9 +55162,9 @@ msgid "%qD moving an object of non-trivial type %#qT and size %E into a region o
 msgstr ""
 
 #: cp/call.cc:11067
-#, fuzzy, gcc-internal-format
+#, gcc-internal-format
 msgid "%#qT declared here"
-msgstr "在此声明"
+msgstr "%#qT在此声明"
 
 #: cp/call.cc:11121
 #, fuzzy, gcc-internal-format
@@ -55463,9 +55413,9 @@ msgstr ""
 
 #: cp/class.cc:1694 cp/class.cc:1701 cp/class.cc:1708 cp/class.cc:1720
 #: cp/cvt.cc:1118 rust/backend/rust-tree.cc:643
-#, fuzzy, gcc-internal-format
+#, gcc-internal-format
 msgid "%qT declared here"
-msgstr "在此声明"
+msgstr "%qT在此声明"
 
 #: cp/class.cc:1699
 #, gcc-internal-format
@@ -55674,9 +55624,9 @@ msgid "  but does not declare %<operator=(const %T&)%>"
 msgstr "但没有重载%<operator=(const %T&)%>"
 
 #: cp/class.cc:4228
-#, fuzzy, gcc-internal-format
+#, gcc-internal-format
 msgid "pointer member %q+D declared here"
-msgstr "%q+D已在此声明过"
+msgstr "指针成员%q+D已在此声明过"
 
 #: cp/class.cc:4316
 #, gcc-internal-format
@@ -55826,9 +55776,9 @@ msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "对包含可变数组成员的结构的无效使用"
 
 #: cp/class.cc:7603
-#, fuzzy, gcc-internal-format
+#, gcc-internal-format
 msgid "array member %q#D declared here"
-msgstr "%q+D已在此声明过"
+msgstr "数组成员%q#D已在此声明过"
 
 #: cp/class.cc:7631
 #, fuzzy, gcc-internal-format
@@ -56116,10 +56066,9 @@ msgid "dynamic type %qT of its operand does not have a base class of type %qT"
 msgstr "类型%qT不是类型%qT的基类"
 
 #: cp/constexpr.cc:2566
-#, fuzzy, gcc-internal-format
-#| msgid "variable %D of type %<io%> must be uninitialized"
+#, gcc-internal-format
 msgid "virtual table pointer is used uninitialized"
-msgstr "类型为%<io%>的变量 %D 不能被初始化"
+msgstr "虚拟表指针未初始化被使用"
 
 #: cp/constexpr.cc:2598 cp/constexpr.cc:2631
 #, gcc-internal-format
@@ -57432,10 +57381,9 @@ msgid "the coroutine promise type %qT declares both %<return_value%> and %<retur
 msgstr ""
 
 #: cp/coroutines.cc:515
-#, fuzzy, gcc-internal-format
-#| msgid "%qD was declared here"
+#, gcc-internal-format
 msgid "%<return_void%> declared here"
-msgstr "%qD在此声明"
+msgstr "%<return_void%>在此声明"
 
 #: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4283
 #, fuzzy, gcc-internal-format
@@ -58076,10 +58024,9 @@ msgid "unused structured binding declaration"
 msgstr "无效的函数声明"
 
 #: cp/decl.cc:718
-#, fuzzy, gcc-internal-format
-#| msgid "unused variable %q+D"
+#, gcc-internal-format
 msgid "unused variable %qD"
-msgstr "未使用的变量%q+D"
+msgstr "未使用的变量%qD"
 
 #: cp/decl.cc:728
 #, gcc-internal-format
@@ -58271,9 +58218,9 @@ msgstr "%q+#D已在此定义过"
 
 #: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
 #: cp/name-lookup.cc:3434
-#, fuzzy, gcc-internal-format
+#, gcc-internal-format
 msgid "%q#D previously declared here"
-msgstr "%q+#D已在此定义过"
+msgstr "%q#D已在此定义过"
 
 #: cp/decl.cc:2097
 #, fuzzy, gcc-internal-format
@@ -58583,7 +58530,7 @@ msgstr "%q#T不是一个类"
 #: cp/decl.cc:4528 cp/decl.cc:4629
 #, gcc-internal-format
 msgid "no class template named %q#T in %q#T"
-msgstr "没有名为%q#T的类模板，在%q#T中 "
+msgstr "没有名为%q#T的类模板，在%q#T中"
 
 #: cp/decl.cc:4529
 #, fuzzy, gcc-internal-format
@@ -62021,10 +61968,9 @@ msgid "reference %qD is not yet bound to a value when used here"
 msgstr ""
 
 #: cp/init.cc:912
-#, fuzzy, gcc-internal-format
-#| msgid "member %qD is uninitialized reference"
+#, gcc-internal-format
 msgid "member %qD is used uninitialized"
-msgstr "成员%qD是未初始化的引用"
+msgstr "成员%qD未经初始化被使用"
 
 #: cp/init.cc:991
 #, gcc-internal-format
@@ -62859,10 +62805,9 @@ msgid "cannot import module in its own purview"
 msgstr ""
 
 #: cp/module.cc:14385 cp/module.cc:19710
-#, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
+#, gcc-internal-format
 msgid "module %qs declared here"
-msgstr "%qD在此声明"
+msgstr "模组%qs在此声明"
 
 #: cp/module.cc:14729
 #, gcc-internal-format
@@ -64308,9 +64253,9 @@ msgstr "%qD不是一个变量"
 
 #: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
 #: cp/semantics.cc:4260
-#, fuzzy, gcc-internal-format
+#, gcc-internal-format
 msgid "%q#D declared here"
-msgstr "%q+D已在此声明过"
+msgstr "%q#D在此声明"
 
 #: cp/parser.cc:11694
 #, fuzzy, gcc-internal-format
@@ -66274,9 +66219,9 @@ msgid "%qs tag used in naming %q#T"
 msgstr "使用了%qs标记，在命名%q#T时"
 
 #: cp/parser.cc:35014
-#, fuzzy, gcc-internal-format
+#, gcc-internal-format
 msgid "%q#T was previously declared here"
-msgstr "以前在此声明过"
+msgstr "%q#T之前在此声明过"
 
 #: cp/parser.cc:35135
 #, fuzzy, gcc-internal-format
@@ -66883,10 +66828,9 @@ msgid "declaration of %q+#D shadows template parameter"
 msgstr "%q+D的声明隐藏了一个形参"
 
 #: cp/pt.cc:4495
-#, fuzzy, gcc-internal-format
-#| msgid "template parameter type %qT declared %<friend%>"
+#, gcc-internal-format
 msgid "template parameter %qD declared here"
-msgstr "模板形参类型%qT声明为%<friend%>"
+msgstr "模板参数%qD在此声明"
 
 #: cp/pt.cc:5179
 #, fuzzy, gcc-internal-format
@@ -67103,10 +67047,9 @@ msgid "redeclared here as %q#D"
 msgstr "在这里又被声明为%q#D"
 
 #: cp/pt.cc:6412
-#, fuzzy, gcc-internal-format
-#| msgid "declared here"
+#, gcc-internal-format
 msgid "redeclared here"
-msgstr "在此声明"
+msgstr "在这里又被声明"
 
 #: cp/pt.cc:6423
 #, fuzzy, gcc-internal-format
@@ -68203,10 +68146,9 @@ msgid "explicit object member function overrides virtual function"
 msgstr "内建函数%q+D未被声明为函数"
 
 #: cp/search.cc:2295
-#, fuzzy, gcc-internal-format
-#| msgid "indirect function %q+D cannot be declared weakref"
+#, gcc-internal-format
 msgid "virtual function declared here"
-msgstr "内联函数%q+D不能声明为有弱链接"
+msgstr "虚函数在此声明"
 
 #: cp/semantics.cc:1114
 #, gcc-internal-format
@@ -68953,8 +68895,7 @@ msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling conventio
 msgstr ""
 
 #: cp/tree.cc:4535
-#, fuzzy, gcc-internal-format
-#| msgid "declared here"
+#, gcc-internal-format
 msgid " declared here"
 msgstr "在此声明"
 
@@ -69744,7 +69685,7 @@ msgstr "无法取右值表达式%<this%>的地址"
 #: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
 #, gcc-internal-format
 msgid "address of explicit register variable %qD requested"
-msgstr "要求显式寄存器变量%qD的地址。"
+msgstr "要求显式寄存器变量%qD的地址"
 
 #: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
 #, gcc-internal-format
@@ -79506,7 +79447,7 @@ msgstr "在%C处需要“,”"
 #: fortran/openmp.cc:6145
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
-msgstr " %C 处线程局部变量是个 COMMON 块的元素"
+msgstr "%C 处线程局部变量是个 COMMON 块的元素"
 
 #: fortran/openmp.cc:6182
 #, fuzzy, gcc-internal-format, gfc-internal-format
@@ -81007,7 +80948,7 @@ msgstr "%C处 SEQUENCE 语句必须先于 CONTAINS"
 #: fortran/parse.cc:3426
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
-msgstr "%C处已在一个 CONTAINS 块内部 "
+msgstr "%C处已在一个 CONTAINS 块内部"
 
 #: fortran/parse.cc:3545
 #, fuzzy, gcc-internal-format, gfc-internal-format
@@ -86268,9 +86209,9 @@ msgid "size of %qD differ from the size of original declaration"
 msgstr "类型%qD不匹配原先的声明"
 
 #: lto/lto-symtab.cc:757
-#, fuzzy, gcc-internal-format
+#, gcc-internal-format
 msgid "%qD was previously declared here"
-msgstr "以前在此声明过"
+msgstr "%qD以前在此声明过"
 
 #: lto/lto-symtab.cc:760
 #, gcc-internal-format
@@ -86856,7 +86797,7 @@ msgstr "已弃用类 %qE"
 #: objc/objc-act.cc:1842
 #, gcc-internal-format
 msgid "could not find setter/getter for %qE in class %qE"
-msgstr "类 %2$qE 中找不到 %1$qE 的存取器。"
+msgstr "类 %2$qE 中找不到 %1$qE 的存取器"
 
 #: objc/objc-act.cc:1892
 #, fuzzy, gcc-internal-format

commit 87aea23f9d96608ab48eb6bb000d81e5f0c18f1e
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Wed Aug 28 02:24:02 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 0f44912c686..00e43a06f4d 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240826
+20240828
diff --git a/gcc/po/ChangeLog b/gcc/po/ChangeLog
index 1be188ad53c..8ba0a78ce36 100644
--- a/gcc/po/ChangeLog
+++ b/gcc/po/ChangeLog
@@ -1,3 +1,7 @@
+2024-08-27  Joseph Myers  <josmyers@redhat.com>
+
+	* zh_CN.po: Update.
+
 2024-08-05  Joseph Myers  <josmyers@redhat.com>
 
 	* fr.po: Update.
diff --git a/libgcc/ChangeLog b/libgcc/ChangeLog
index fa9e1079920..e7c752c7e7a 100644
--- a/libgcc/ChangeLog
+++ b/libgcc/ChangeLog
@@ -1,3 +1,10 @@
+2024-08-27  YunQiang Su  <syq@gcc.gnu.org>
+
+	Backported from master:
+	2024-08-27  YunQiang Su  <syq@gcc.gnu.org>
+
+	* config/mips/lib1funcs.S: Includes mips16.S.
+
 2024-08-01  Release Manager
 
 	* GCC 14.2.0 released.

commit 377c3e9a8b73b47a1211d43fee162179ee1f87e7
Author: Xi Ruoyao <xry111@xry111.site>
Date:   Mon May 6 05:33:43 2024

    i386: testsuite: Add -no-pie for pr113689-1.c [PR70150]
    
    For a --enable-default-pie build, using -fno-pic (for compiler) but
    not -no-pie (for linker) triggers some linker warnings counted as
    excess errors:
    
        /usr/bin/ld: /tmp/cc8MgxiR.o: warning: relocation in read-only
        section `.text.startup'
        /usr/bin/ld: warning: creating DT_TEXTREL in a PIE
    
    gcc/testsuite/ChangeLog:
    
            PR testsuite/70150
            * gcc.target/i386/pr113689-1.c (dg-options): Add -no-pie.
    
    (cherry picked from commit 331f7d8a393af99afccdb2729d4ab45797fd7a86)

diff --git a/gcc/testsuite/gcc.target/i386/pr113689-1.c b/gcc/testsuite/gcc.target/i386/pr113689-1.c
index 9b8474ed933..0424db2dfdc 100644
--- a/gcc/testsuite/gcc.target/i386/pr113689-1.c
+++ b/gcc/testsuite/gcc.target/i386/pr113689-1.c
@@ -1,5 +1,5 @@
 /* { dg-do run { target { lp64 && fpic } } } */
-/* { dg-options "-O2 -fno-pic -fprofile -mcmodel=large" } */
+/* { dg-options "-O2 -fno-pic -no-pie -fprofile -mcmodel=large" } */
 /* { dg-skip-if "PR90698" { *-*-darwin* } } */
 /* { dg-skip-if "PR113909" { *-*-solaris2* } } */
 

commit f5b3dae221e6e41ebd806f504d83012173737dab
Author: Xi Ruoyao <xry111@xry111.site>
Date:   Mon May 6 05:39:14 2024

    i386: testsuite: Adapt fentryname3.c for r14-811 change [PR70150]
    
    After r14-811 "call *nop@GOTPCREL(%rip)" is only generated with
    -mno-direct-extern-access even if --enable-default-pie.  So the r13-1614
    change to this file is not valid anymore.
    
    gcc/testsuite/ChangeLog:
    
            PR testsuite/70150
            * gcc.target/i386/fentryname3.c (dg-final): Revert r13-1614
            change.
    
    (cherry picked from commit 8035619b7313d9503852e1c7c8c06cfddca4d648)

diff --git a/gcc/testsuite/gcc.target/i386/fentryname3.c b/gcc/testsuite/gcc.target/i386/fentryname3.c
index c14a4ebb0cf..bd7c997c178 100644
--- a/gcc/testsuite/gcc.target/i386/fentryname3.c
+++ b/gcc/testsuite/gcc.target/i386/fentryname3.c
@@ -3,8 +3,7 @@
 /* { dg-require-profiling "-pg" } */
 /* { dg-options "-pg -mfentry"  } */
 /* { dg-final { scan-assembler "section.*__entry_loc" } } */
-/* { dg-final { scan-assembler "0x0f, 0x1f, 0x44, 0x00, 0x00" { target nonpic } } } */
-/* { dg-final { scan-assembler "call\t\\*nop@GOTPCREL" { target { ! nonpic } } } } */
+/* { dg-final { scan-assembler "0x0f, 0x1f, 0x44, 0x00, 0x00" } } */
 /* { dg-final { scan-assembler-not "__fentry__" } } */
 
 __attribute__((fentry_name("nop"), fentry_section("__entry_loc")))

commit 4d6c0c0a0b8bbaecc186eb77928594825f5aba48
Author: Joseph Myers <josmyers@redhat.com>
Date:   Wed Aug 28 18:32:11 2024

    Add gcc ka.po
    
            * ka.po: New file.

diff --git a/gcc/po/ka.po b/gcc/po/ka.po
new file mode 100644
index 00000000000..bcb6e56c568
--- /dev/null
+++ b/gcc/po/ka.po
@@ -0,0 +1,83090 @@
+# Georgian translation for gcc.
+# Copyright (C) 2024 Free Software Foundation, Inc.
+# This file is distributed under the same license as the gcc package.
+# Temuri Doghonadze <temuri.doghonadze@gmail.com>, 2024.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: gcc-14.2.0\n"
+"Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
+"POT-Creation-Date: 2024-07-25 16:23+0000\n"
+"PO-Revision-Date: 2024-08-28 06:11+0200\n"
+"Last-Translator: Temuri Doghonadze <temuri.doghonadze@gmail.com>\n"
+"Language-Team: Georgian <(nothing)>\n"
+"Language: ka\n"
+"X-Bugs: Report translation errors to the Language-Team address.\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"Plural-Forms: nplurals=2; plural=(n != 1);\n"
+"X-Generator: Poedit 3.3.2\n"
+
+#: cif-code.def:39
+msgid "function not considered for inlining"
+msgstr ""
+
+#: cif-code.def:43
+msgid "caller is not optimized"
+msgstr ""
+
+#: cif-code.def:47
+msgid "function body not available"
+msgstr ""
+
+#: cif-code.def:51
+msgid "redefined extern inline functions are not considered for inlining"
+msgstr ""
+
+#: cif-code.def:56
+msgid "function not inlinable"
+msgstr ""
+
+#: cif-code.def:60
+msgid "function body can be overwritten at link time"
+msgstr ""
+
+#: cif-code.def:64
+msgid "function not inline candidate"
+msgstr ""
+
+#: cif-code.def:68
+msgid "--param large-function-growth limit reached"
+msgstr ""
+
+#: cif-code.def:70
+msgid "--param large-stack-frame-growth limit reached"
+msgstr ""
+
+#: cif-code.def:72
+msgid "--param max-inline-insns-single limit reached"
+msgstr ""
+
+#: cif-code.def:74
+msgid "--param max-inline-insns-auto limit reached"
+msgstr ""
+
+#: cif-code.def:76
+msgid "--param inline-unit-growth limit reached"
+msgstr ""
+
+#: cif-code.def:80
+msgid "recursive inlining"
+msgstr ""
+
+#: cif-code.def:84
+msgid "call is unlikely and code size would grow"
+msgstr ""
+
+#: cif-code.def:88
+msgid "call is considered never executed and code size would grow"
+msgstr ""
+
+#: cif-code.def:92
+msgid "function not declared inline and code size would grow"
+msgstr ""
+
+#: cif-code.def:96
+msgid "mismatched declarations during linktime optimization"
+msgstr ""
+
+#: cif-code.def:100
+msgid "variadic thunk call"
+msgstr ""
+
+#: cif-code.def:104
+msgid "originally indirect function call not considered for inlining"
+msgstr ""
+
+#: cif-code.def:108
+msgid "indirect function call with a yet undetermined callee"
+msgstr ""
+
+#: cif-code.def:112
+msgid "exception handling personality mismatch"
+msgstr ""
+
+#: cif-code.def:117
+msgid "non-call exception handling mismatch"
+msgstr ""
+
+#: cif-code.def:121
+msgid "target specific option mismatch"
+msgstr ""
+
+#: cif-code.def:125
+msgid "optimization level attribute mismatch"
+msgstr ""
+
+#: cif-code.def:129
+msgid "callee refers to comdat-local symbols"
+msgstr ""
+
+#: cif-code.def:134
+msgid "sanitizer function attribute mismatch"
+msgstr ""
+
+#: cif-code.def:139
+msgid "function has external linkage when the user requests only inlining static for live patching"
+msgstr ""
+
+#: cif-code.def:144
+msgid "unreachable"
+msgstr ""
+
+#. The remainder are real diagnostic types.
+#: diagnostic.def:33
+msgid "fatal error: "
+msgstr "ფატალური შეცდომა: "
+
+#. This is like DK_ICE, but backtrace is not printed.  Used in the driver
+#. when reporting fatal signal in the compiler.
+#: diagnostic.def:34 diagnostic.def:55
+msgid "internal compiler error: "
+msgstr "შიდა კომპლატორის შეცდომა: "
+
+#. This one is just for counting DK_WARNING promoted to DK_ERROR
+#. due to -Werror and -Werror=warning.
+#: diagnostic.def:35 diagnostic.def:52
+msgid "error: "
+msgstr ""
+
+#: diagnostic.def:36
+msgid "sorry, unimplemented: "
+msgstr "განხორციელებული არაა: "
+
+#: diagnostic.def:37
+msgid "warning: "
+msgstr "გაფრთხილება: "
+
+#: diagnostic.def:38
+msgid "anachronism: "
+msgstr "ანაქრონიზმი: "
+
+#: diagnostic.def:39
+msgid "note: "
+msgstr ""
+
+#: diagnostic.def:40
+msgid "debug: "
+msgstr "გამართვა: "
+
+#. For use when using the diagnostic_show_locus machinery to show
+#. a range of events within a path.
+#: diagnostic.def:44
+msgid "path: "
+msgstr ""
+
+#. These two would be re-classified as DK_WARNING or DK_ERROR, so the
+#. prefix does not matter.
+#: diagnostic.def:48
+msgid "pedwarn: "
+msgstr ""
+
+#: diagnostic.def:49
+msgid "permerror: "
+msgstr ""
+
+#: config/i386/djgpp.h:143
+#, c-format
+msgid "-f%s ignored (not supported for DJGPP)\n"
+msgstr ""
+
+#. The remainder are real diagnostic types.
+#: fortran/gfc-diagnostic.def:33
+msgid "Fatal Error"
+msgstr "ფატალური შეცდომა"
+
+#. This is like DK_ICE, but backtrace is not printed.  Used in the driver
+#. when reporting fatal signal in the compiler.
+#: fortran/gfc-diagnostic.def:34 fortran/gfc-diagnostic.def:50
+msgid "internal compiler error"
+msgstr "შიდა კომპლატორის შეცდომა"
+
+#: fortran/gfc-diagnostic.def:35
+msgid "Error"
+msgstr ""
+
+#: fortran/gfc-diagnostic.def:36
+msgid "sorry, unimplemented"
+msgstr "განხორციელებული არაა"
+
+#: fortran/gfc-diagnostic.def:37
+msgid "Warning"
+msgstr "გაფრთხილება"
+
+#: fortran/gfc-diagnostic.def:38
+msgid "anachronism"
+msgstr "ანაქრონიზმი"
+
+#: fortran/gfc-diagnostic.def:39
+msgid "note"
+msgstr "შენიშვნა"
+
+#: fortran/gfc-diagnostic.def:40
+msgid "debug"
+msgstr "გამართვა"
+
+#. These two would be re-classified as DK_WARNING or DK_ERROR, so the
+#. prefix does not matter.
+#: fortran/gfc-diagnostic.def:43
+msgid "pedwarn"
+msgstr ""
+
+#: fortran/gfc-diagnostic.def:44
+msgid "permerror"
+msgstr ""
+
+#. This one is just for counting DK_WARNING promoted to DK_ERROR
+#. due to -Werror and -Werror=warning.
+#: fortran/gfc-diagnostic.def:47
+msgid "error"
+msgstr ""
+
+#: gcc.cc:852 gcc.cc:909
+msgid "-gz is not supported in this configuration"
+msgstr ""
+
+#: gcc.cc:858
+msgid "-gz=zstd is not supported in this configuration"
+msgstr ""
+
+#: gcc.cc:1092
+msgid "-fuse-linker-plugin is not supported in this configuration"
+msgstr ""
+
+#: gcc.cc:1108
+msgid "cannot specify -static with -fsanitize=address"
+msgstr ""
+
+#: gcc.cc:1110
+msgid "cannot specify -static with -fsanitize=hwaddress"
+msgstr ""
+
+#: gcc.cc:1112
+msgid "cannot specify -static with -fsanitize=thread"
+msgstr ""
+
+#: gcc.cc:1134
+msgid "-fvtable-verify=std is not supported in this configuration"
+msgstr ""
+
+#: gcc.cc:1136
+msgid "-fvtable-verify=preinit is not supported in this configuration"
+msgstr ""
+
+#: gcc.cc:1279 ada/gcc-interface/lang-specs.h:37
+msgid "-pg and -fomit-frame-pointer are incompatible"
+msgstr ""
+
+#: gcc.cc:1454
+msgid "GNU C no longer supports -traditional without -E"
+msgstr ""
+
+#: gcc.cc:1463
+msgid "-E or -x required when input is from standard input"
+msgstr ""
+
+#: config/darwin.h:150
+msgid "conflicting code generation switches"
+msgstr ""
+
+#: config/darwin.h:155
+msgid "-bundle_loader not allowed with -dynamiclib"
+msgstr ""
+
+#: config/darwin.h:157
+msgid "-client_name not allowed with -dynamiclib"
+msgstr ""
+
+#: config/darwin.h:166
+msgid "-keep_private_externs not allowed with -dynamiclib"
+msgstr ""
+
+#: config/darwin.h:168
+msgid "-private_bundle not allowed with -dynamiclib"
+msgstr ""
+
+#: config/darwin.h:176
+msgid "-compatibility_version only allowed with -dynamiclib"
+msgstr ""
+
+#: config/darwin.h:178
+msgid "-current_version only allowed with -dynamiclib"
+msgstr ""
+
+#: config/darwin.h:180
+msgid "-install_name only allowed with -dynamiclib"
+msgstr ""
+
+#: config/darwin.h:191
+msgid "-bundle not allowed with -shared"
+msgstr ""
+
+#: config/darwin.h:192
+msgid "-bundle not allowed with -dynamiclib"
+msgstr ""
+
+#: config/darwin.h:208
+msgid "-force_flat_namespace not allowed with -dynamiclib"
+msgstr ""
+
+#: config/darwin.h:213 config/darwin.h:659
+msgid "gsplit-dwarf is not supported on this platform"
+msgstr ""
+
+#: config/darwin.h:282
+msgid "rdynamic is not supported"
+msgstr ""
+
+#: config/dragonfly.h:76 config/i386/freebsd.h:82 config/i386/freebsd64.h:35
+#: config/ia64/freebsd.h:26 config/rs6000/sysv4.h:750 config/sparc/freebsd.h:45
+msgid "consider using '-pg' instead of '-p' with gprof(1)"
+msgstr ""
+
+#: config/lynx.h:69
+msgid "cannot use mthreads and mlegacy-threads together"
+msgstr ""
+
+#: config/lynx.h:94
+msgid "cannot use mshared and static together"
+msgstr ""
+
+#: config/sol2.h:349 config/sol2.h:354
+msgid "does not support multilib"
+msgstr ""
+
+#: config/sol2.h:448
+msgid "-pie is not supported in this configuration"
+msgstr ""
+
+#: config/vxworks.h:219
+msgid "-Xbind-now and -Xbind-lazy are incompatible"
+msgstr ""
+
+#: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
+#: config/riscv/freebsd.h:44
+msgid "consider using `-pg' instead of `-p' with gprof (1)"
+msgstr ""
+
+#: config/arc/arc.h:68 config/mips/mips.h:1505
+msgid "may not use both -EB and -EL"
+msgstr ""
+
+#: config/avr/specs.h:70 config/pru/pru.h:58
+msgid "shared is not supported"
+msgstr "ზიარი მხარდაჭერილი არაა"
+
+#: config/bfin/elf.h:55
+msgid "no processor type specified for linking"
+msgstr ""
+
+#: config/cris/cris.h:168
+msgid "do not specify both -march=... and -mcpu=..."
+msgstr ""
+
+#: config/i386/cygwin-w64.h:64 config/i386/cygwin.h:129
+#: config/i386/mingw-w64.h:125 config/i386/mingw32.h:169
+msgid "shared and mdll are not compatible"
+msgstr ""
+
+#: config/i386/darwin.h:93
+msgid "Darwin is not an mx32 platform"
+msgstr ""
+
+#: config/i386/darwin.h:94
+msgid "Darwin does not support -mfentry or associated options"
+msgstr ""
+
+#: config/i386/sol2.h:59
+msgid "-mx32 is not supported on Solaris"
+msgstr ""
+
+#: config/mcore/mcore.h:53
+msgid "the m210 does not have little endian support"
+msgstr ""
+
+#: config/mips/r3900.h:37
+msgid "-mhard-float not supported"
+msgstr "-mhard-float მხარდაჭერილი არაა"
+
+#: config/mips/r3900.h:39
+msgid "-msingle-float and -msoft-float cannot both be specified"
+msgstr ""
+
+#: config/moxie/moxiebox.h:43
+msgid "this target is little-endian"
+msgstr ""
+
+#: config/msp430/msp430.h:90
+msgid "-mcode-region requires the large memory model (-mlarge)"
+msgstr ""
+
+#: config/msp430/msp430.h:92
+msgid "-mdata-region requires the large memory model (-mlarge)"
+msgstr ""
+
+#: config/nios2/elf.h:44
+msgid "You need a C startup file for -msys-crt0="
+msgstr ""
+
+#: config/pa/pa-hpux11.h:134 config/pa/pa-hpux11.h:137 config/pa/pa64-hpux.h:29
+#: config/pa/pa64-hpux.h:32 config/pa/pa64-hpux.h:41 config/pa/pa64-hpux.h:44
+msgid "warning: consider linking with '-static' as system libraries with"
+msgstr ""
+
+#: config/pa/pa-hpux11.h:135 config/pa/pa-hpux11.h:138 config/pa/pa64-hpux.h:30
+#: config/pa/pa64-hpux.h:33 config/pa/pa64-hpux.h:42 config/pa/pa64-hpux.h:45
+msgid "  profiling support are only provided in archive format"
+msgstr ""
+
+#: config/rs6000/darwin.h:126
+msgid " conflicting code gen style switches are used"
+msgstr ""
+
+#: config/rs6000/freebsd64.h:114
+msgid "consider using `-pg' instead of `-p' with gprof(1)"
+msgstr ""
+
+#: config/rs6000/rs6000.h:168
+msgid "Missing -mcpu option in ASM_CPU_SPEC?"
+msgstr ""
+
+#: config/rx/linux.h:53 config/rx/rx.h:82
+msgid "rx200 cpu does not have FPU hardware"
+msgstr ""
+
+#: config/rx/rx.h:80
+msgid "-mas100-syntax is incompatible with -gdwarf"
+msgstr ""
+
+#: config/rx/rx.h:81
+msgid "rx100 cpu does not have FPU hardware"
+msgstr ""
+
+#: config/s390/tpf.h:119
+msgid "static is not supported on TPF-OS"
+msgstr ""
+
+#: config/sh/sh.h:299 config/sh/sh.h:302
+msgid "SH2a does not support little-endian"
+msgstr ""
+
+#: config/sparc/linux64.h:142
+msgid "-fsanitize=address is not supported in this configuration"
+msgstr ""
+
+#: config/sparc/linux64.h:156 config/sparc/linux64.h:162
+#: config/sparc/netbsd-elf.h:103 config/sparc/netbsd-elf.h:112
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
+msgid "may not use both -m32 and -m64"
+msgstr ""
+
+#: config/vax/netbsd-elf.h:51
+msgid "the -shared option is not currently supported for VAX ELF"
+msgstr ""
+
+#: config/vax/vax.h:46 config/vax/vax.h:47
+msgid "profiling not supported with -mg"
+msgstr ""
+
+#: ada/gcc-interface/lang-specs.h:38
+msgid "-c or -S required for Ada"
+msgstr ""
+
+#: ada/gcc-interface/lang-specs.h:56
+msgid "-c required for gnat2why"
+msgstr ""
+
+#: ada/gcc-interface/lang-specs.h:67
+msgid "-c required for gnat2scil"
+msgstr ""
+
+#: fortran/lang-specs.h:63 fortran/lang-specs.h:81
+msgid "gfortran does not support -E without -cpp"
+msgstr ""
+
+#: objc/lang-specs.h:30 objc/lang-specs.h:41
+msgid "GNU Objective C no longer supports traditional compilation"
+msgstr ""
+
+#: objc/lang-specs.h:55
+msgid "objc-cpp-output is deprecated; please use objective-c-cpp-output instead"
+msgstr ""
+
+#: objcp/lang-specs.h:58
+msgid "objc++-cpp-output is deprecated; please use objective-c++-cpp-output instead"
+msgstr ""
+
+#: fortran/lang.opt:146
+#, no-c-format
+msgid "-J<directory>\tPut MODULE files in 'directory'."
+msgstr ""
+
+#: fortran/lang.opt:198
+#, no-c-format
+msgid "Warn about possible aliasing of dummy arguments."
+msgstr ""
+
+#: fortran/lang.opt:202
+#, no-c-format
+msgid "Warn about alignment of COMMON blocks."
+msgstr ""
+
+#: fortran/lang.opt:206
+#, no-c-format
+msgid "Warn about missing ampersand in continued character constants."
+msgstr ""
+
+#: fortran/lang.opt:210
+#, no-c-format
+msgid "Warn about creation of array temporaries."
+msgstr ""
+
+#: fortran/lang.opt:214 fortran/lang.opt:539 c-family/c.opt:1598
+#: config/alpha/alpha.opt:31 common.opt:685 common.opt:831 common.opt:1079
+#: common.opt:1083 common.opt:1087 common.opt:1091 common.opt:1819
+#: common.opt:1922 common.opt:2099 common.opt:2103 common.opt:2382
+#: common.opt:2604 common.opt:3371
+#, no-c-format
+msgid "Does nothing. Preserved for backward compatibility."
+msgstr ""
+
+#: fortran/lang.opt:218
+#, no-c-format
+msgid "Warn if the type of a variable might be not interoperable with C."
+msgstr ""
+
+#: fortran/lang.opt:226
+#, no-c-format
+msgid "Warn about truncated character expressions."
+msgstr ""
+
+#: fortran/lang.opt:230
+#, no-c-format
+msgid "Warn about equality comparisons involving REAL or COMPLEX expressions."
+msgstr ""
+
+#: fortran/lang.opt:238
+#, no-c-format
+msgid "Warn about most implicit conversions."
+msgstr ""
+
+#: fortran/lang.opt:242
+#, no-c-format
+msgid "Warn about possibly incorrect subscripts in do loops."
+msgstr ""
+
+#: fortran/lang.opt:250
+#, no-c-format
+msgid "Warn if loops have been interchanged."
+msgstr ""
+
+#: fortran/lang.opt:254
+#, no-c-format
+msgid "Warn about function call elimination."
+msgstr ""
+
+#: fortran/lang.opt:258
+#, no-c-format
+msgid "Warn about calls with implicit interface."
+msgstr ""
+
+#: fortran/lang.opt:262
+#, no-c-format
+msgid "Warn about called procedures not explicitly declared."
+msgstr ""
+
+#: fortran/lang.opt:266
+#, no-c-format
+msgid "Warn about constant integer divisions with truncated results."
+msgstr ""
+
+#: fortran/lang.opt:270
+#, no-c-format
+msgid "Warn about truncated source lines."
+msgstr ""
+
+#: fortran/lang.opt:274
+#, no-c-format
+msgid "Warn on intrinsics not part of the selected standard."
+msgstr ""
+
+#: fortran/lang.opt:286
+#, no-c-format
+msgid "Warn about USE statements that have no ONLY qualifier."
+msgstr ""
+
+#: fortran/lang.opt:302
+#, no-c-format
+msgid "Warn that -fno-automatic may break recursion."
+msgstr ""
+
+#: fortran/lang.opt:310
+#, no-c-format
+msgid "Warn about real-literal-constants with 'q' exponent-letter."
+msgstr ""
+
+#: fortran/lang.opt:314
+#, no-c-format
+msgid "Warn when a left-hand-side array variable is reallocated."
+msgstr ""
+
+#: fortran/lang.opt:318
+#, no-c-format
+msgid "Warn when a left-hand-side variable is reallocated."
+msgstr ""
+
+#: fortran/lang.opt:322
+#, no-c-format
+msgid "Warn if the pointer in a pointer assignment might outlive its target."
+msgstr ""
+
+#: fortran/lang.opt:330
+#, no-c-format
+msgid "Warn about \"suspicious\" constructs."
+msgstr ""
+
+#: fortran/lang.opt:334
+#, no-c-format
+msgid "Permit nonconforming uses of the tab character."
+msgstr ""
+
+#: fortran/lang.opt:338
+#, no-c-format
+msgid "Warn about an invalid DO loop."
+msgstr ""
+
+#: fortran/lang.opt:342
+#, no-c-format
+msgid "Warn about underflow of numerical constant expressions."
+msgstr ""
+
+#: fortran/lang.opt:350
+#, no-c-format
+msgid "Warn if a user-procedure has the same name as an intrinsic."
+msgstr ""
+
+#: fortran/lang.opt:358
+#, no-c-format
+msgid "Warn about unused dummy arguments."
+msgstr ""
+
+#: fortran/lang.opt:362
+#, no-c-format
+msgid "Warn about zero-trip DO loops."
+msgstr ""
+
+#: fortran/lang.opt:366
+#, no-c-format
+msgid "Enable preprocessing."
+msgstr ""
+
+#: fortran/lang.opt:374
+#, no-c-format
+msgid "Disable preprocessing."
+msgstr ""
+
+#: fortran/lang.opt:382
+#, no-c-format
+msgid "Accept argument mismatches in procedure calls."
+msgstr ""
+
+#: fortran/lang.opt:386
+#, no-c-format
+msgid "Eliminate multiple function invocations also for impure functions."
+msgstr ""
+
+#: fortran/lang.opt:390
+#, no-c-format
+msgid "Enable alignment of COMMON blocks."
+msgstr ""
+
+#: fortran/lang.opt:394
+#, no-c-format
+msgid "All intrinsics procedures are available regardless of selected standard."
+msgstr ""
+
+#: fortran/lang.opt:398
+#, no-c-format
+msgid "Allow a BOZ literal constant to appear in an invalid context and with X instead of Z."
+msgstr ""
+
+#: fortran/lang.opt:406
+#, no-c-format
+msgid "Do not treat local variables and COMMON blocks as if they were named in SAVE statements."
+msgstr ""
+
+#: fortran/lang.opt:410
+#, no-c-format
+msgid "Specify that backslash in string introduces an escape character."
+msgstr ""
+
+#: fortran/lang.opt:414
+#, no-c-format
+msgid "Produce a backtrace when a runtime error is encountered."
+msgstr ""
+
+#: fortran/lang.opt:418
+#, no-c-format
+msgid "-fblas-matmul-limit=<n>\tSize of the smallest matrix for which matmul will use BLAS."
+msgstr ""
+
+#: fortran/lang.opt:425
+#, no-c-format
+msgid "Produce a warning at runtime if a array temporary has been created for a procedure argument."
+msgstr ""
+
+#: fortran/lang.opt:429
+#, no-c-format
+msgid "-fconvert=<big-endian|little-endian|native|swap|r16_ieee|r16_ibm>\tThe endianness used for unformatted files."
+msgstr ""
+
+#: fortran/lang.opt:454
+#, no-c-format
+msgid "Use the Cray Pointer extension."
+msgstr ""
+
+#: fortran/lang.opt:458
+#, no-c-format
+msgid "Generate C prototypes from BIND(C) declarations."
+msgstr ""
+
+#: fortran/lang.opt:462
+#, no-c-format
+msgid "Generate C prototypes from non-BIND(C) external procedure definitions."
+msgstr ""
+
+#: fortran/lang.opt:466
+#, no-c-format
+msgid "Ignore 'D' in column one in fixed form."
+msgstr ""
+
+#: fortran/lang.opt:470
+#, no-c-format
+msgid "Treat lines with 'D' in column one as comments."
+msgstr ""
+
+#: fortran/lang.opt:474
+#, no-c-format
+msgid "Issue debug information for compiler-generated auxiliary variables."
+msgstr ""
+
+#: fortran/lang.opt:478
+#, no-c-format
+msgid "Enable all DEC language extensions."
+msgstr ""
+
+#: fortran/lang.opt:482
+#, no-c-format
+msgid "Enable the use of blank format items in format strings."
+msgstr ""
+
+#: fortran/lang.opt:486
+#, no-c-format
+msgid "Enable the use of character literals in assignments and data statements for non-character variables."
+msgstr ""
+
+#: fortran/lang.opt:491
+#, no-c-format
+msgid "Enable legacy parsing of INCLUDE as statement."
+msgstr ""
+
+#: fortran/lang.opt:495
+#, no-c-format
+msgid "Enable default widths for i, f and g format specifiers."
+msgstr ""
+
+#: fortran/lang.opt:499
+#, no-c-format
+msgid "Enable kind-specific variants of integer intrinsic functions."
+msgstr ""
+
+#: fortran/lang.opt:503
+#, no-c-format
+msgid "Enable legacy math intrinsics for compatibility."
+msgstr ""
+
+#: fortran/lang.opt:507
+#, no-c-format
+msgid "Enable support for DEC STRUCTURE/RECORD."
+msgstr ""
+
+#: fortran/lang.opt:511
+#, no-c-format
+msgid "Enable DEC-style STATIC and AUTOMATIC attributes."
+msgstr ""
+
+#: fortran/lang.opt:515
+#, no-c-format
+msgid "Set the default double precision kind to an 8 byte wide type."
+msgstr ""
+
+#: fortran/lang.opt:519
+#, no-c-format
+msgid "Set the default integer kind to an 8 byte wide type."
+msgstr ""
+
+#: fortran/lang.opt:523
+#, no-c-format
+msgid "Set the default real kind to an 8 byte wide type."
+msgstr ""
+
+#: fortran/lang.opt:527
+#, no-c-format
+msgid "Set the default real kind to an 10 byte wide type."
+msgstr ""
+
+#: fortran/lang.opt:531
+#, no-c-format
+msgid "Set the default real kind to an 16 byte wide type."
+msgstr ""
+
+#: fortran/lang.opt:535
+#, no-c-format
+msgid "Allow dollar signs in entity names."
+msgstr ""
+
+#: fortran/lang.opt:543
+#, no-c-format
+msgid "Display the code tree after parsing."
+msgstr ""
+
+#: fortran/lang.opt:547
+#, no-c-format
+msgid "Display the code tree after front end optimization."
+msgstr ""
+
+#: fortran/lang.opt:551
+#, no-c-format
+msgid "Display the global symbol table after parsing."
+msgstr ""
+
+#: fortran/lang.opt:555
+#, no-c-format
+msgid "Display the code tree after parsing; deprecated option."
+msgstr ""
+
+#: fortran/lang.opt:559
+#, no-c-format
+msgid "Specify that an external BLAS library should be used for matmul calls on large-size arrays."
+msgstr ""
+
+#: fortran/lang.opt:563
+#, no-c-format
+msgid "Use f2c calling convention."
+msgstr ""
+
+#: fortran/lang.opt:567
+#, no-c-format
+msgid "Assume that the source file is fixed form."
+msgstr ""
+
+#: fortran/lang.opt:571
+#, no-c-format
+msgid "Force creation of temporary to test infrequently-executed forall code."
+msgstr ""
+
+#: fortran/lang.opt:575
+#, no-c-format
+msgid "Interpret any INTEGER(4) as an INTEGER(8)."
+msgstr ""
+
+#: fortran/lang.opt:579 fortran/lang.opt:583
+#, no-c-format
+msgid "Specify where to find the compiled intrinsic modules."
+msgstr ""
+
+#: fortran/lang.opt:587
+#, no-c-format
+msgid "Allow arbitrary character line width in fixed mode."
+msgstr ""
+
+#: fortran/lang.opt:591
+#, no-c-format
+msgid "-ffixed-line-length-<n>\tUse n as character line width in fixed mode."
+msgstr ""
+
+#: fortran/lang.opt:595
+#, no-c-format
+msgid "Pad shorter fixed form lines to line width with spaces."
+msgstr ""
+
+#: fortran/lang.opt:599
+#, no-c-format
+msgid "-ffpe-trap=[...]\tStop on following floating point exceptions."
+msgstr ""
+
+#: fortran/lang.opt:603
+#, no-c-format
+msgid "-ffpe-summary=[...]\tPrint summary of floating point exceptions."
+msgstr ""
+
+#: fortran/lang.opt:607
+#, no-c-format
+msgid "Assume that the source file is free form."
+msgstr ""
+
+#: fortran/lang.opt:611
+#, no-c-format
+msgid "Allow arbitrary character line width in free mode."
+msgstr ""
+
+#: fortran/lang.opt:615
+#, no-c-format
+msgid "-ffree-line-length-<n>\tUse n as character line width in free mode."
+msgstr ""
+
+#: fortran/lang.opt:619
+#, no-c-format
+msgid "Try to interchange loops if profitable."
+msgstr ""
+
+#: fortran/lang.opt:623
+#, no-c-format
+msgid "Enable front end optimization."
+msgstr ""
+
+#: fortran/lang.opt:627
+#, no-c-format
+msgid "Specify that no implicit typing is allowed, unless overridden by explicit IMPLICIT statements."
+msgstr ""
+
+#: fortran/lang.opt:631
+#, no-c-format
+msgid "-finit-character=<n>\tInitialize local character variables to ASCII value n."
+msgstr ""
+
+#: fortran/lang.opt:635
+#, no-c-format
+msgid "Initialize components of derived type variables according to other init flags."
+msgstr ""
+
+#: fortran/lang.opt:639
+#, no-c-format
+msgid "-finit-integer=<n>\tInitialize local integer variables to n."
+msgstr ""
+
+#: fortran/lang.opt:643
+#, no-c-format
+msgid "Initialize local variables to zero (from g77)."
+msgstr ""
+
+#: fortran/lang.opt:647
+#, no-c-format
+msgid "-finit-logical=<true|false>\tInitialize local logical variables."
+msgstr ""
+
+#: fortran/lang.opt:651
+#, no-c-format
+msgid "-finit-real=<zero|snan|nan|inf|-inf>\tInitialize local real variables."
+msgstr ""
+
+#: fortran/lang.opt:673
+#, no-c-format
+msgid "-finline-arg-packing\tPerform argument packing inline."
+msgstr ""
+
+#: fortran/lang.opt:677
+#, no-c-format
+msgid "-finline-matmul-limit=<n>\tSpecify the size of the largest matrix for which matmul will be inlined."
+msgstr ""
+
+#: fortran/lang.opt:681
+#, no-c-format
+msgid "-fmax-array-constructor=<n>\tMaximum number of objects in an array constructor."
+msgstr ""
+
+#: fortran/lang.opt:685
+#, no-c-format
+msgid "-fmax-identifier-length=<n>\tMaximum identifier length."
+msgstr ""
+
+#: fortran/lang.opt:689
+#, no-c-format
+msgid "-fmax-subrecord-length=<n>\tMaximum length for subrecords."
+msgstr ""
+
+#: fortran/lang.opt:693
+#, no-c-format
+msgid "-fmax-stack-var-size=<n>\tSize in bytes of the largest array that will be put on the stack."
+msgstr ""
+
+#: fortran/lang.opt:697
+#, no-c-format
+msgid "Put all local arrays on stack."
+msgstr ""
+
+#: fortran/lang.opt:701
+#, no-c-format
+msgid "Set default accessibility of module entities to PRIVATE."
+msgstr ""
+
+#: fortran/lang.opt:721
+#, no-c-format
+msgid "Handle OpenMP allocators for allocatables and pointers."
+msgstr ""
+
+#: fortran/lang.opt:725
+#, no-c-format
+msgid "Try to lay out derived types as compactly as possible."
+msgstr ""
+
+#: fortran/lang.opt:733
+#, no-c-format
+msgid "Protect parentheses in expressions."
+msgstr ""
+
+#: fortran/lang.opt:737
+#, no-c-format
+msgid "Path to header file that should be pre-included before each compilation unit."
+msgstr ""
+
+#: fortran/lang.opt:741
+#, no-c-format
+msgid "Enable range checking during compilation."
+msgstr ""
+
+#: fortran/lang.opt:745
+#, no-c-format
+msgid "Interpret any REAL(4) as a REAL(8)."
+msgstr ""
+
+#: fortran/lang.opt:749
+#, no-c-format
+msgid "Interpret any REAL(4) as a REAL(10)."
+msgstr ""
+
+#: fortran/lang.opt:753
+#, no-c-format
+msgid "Interpret any REAL(4) as a REAL(16)."
+msgstr ""
+
+#: fortran/lang.opt:757
+#, no-c-format
+msgid "Interpret any REAL(8) as a REAL(4)."
+msgstr ""
+
+#: fortran/lang.opt:761
+#, no-c-format
+msgid "Interpret any REAL(8) as a REAL(10)."
+msgstr ""
+
+#: fortran/lang.opt:765
+#, no-c-format
+msgid "Interpret any REAL(8) as a REAL(16)."
+msgstr ""
+
+#: fortran/lang.opt:769
+#, no-c-format
+msgid "Reallocate the LHS in assignments."
+msgstr ""
+
+#: fortran/lang.opt:773
+#, no-c-format
+msgid "Use a 4-byte record marker for unformatted files."
+msgstr ""
+
+#: fortran/lang.opt:777
+#, no-c-format
+msgid "Use an 8-byte record marker for unformatted files."
+msgstr ""
+
+#: fortran/lang.opt:781
+#, no-c-format
+msgid "Allocate local variables on the stack to allow indirect recursion."
+msgstr ""
+
+#: fortran/lang.opt:785
+#, no-c-format
+msgid "Copy array sections into a contiguous block on procedure entry."
+msgstr ""
+
+#: fortran/lang.opt:789
+#, no-c-format
+msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
+msgstr ""
+
+#: fortran/lang.opt:805
+#, no-c-format
+msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
+msgstr ""
+
+#: fortran/lang.opt:809
+#, no-c-format
+msgid "Append a second underscore if the name already contains an underscore."
+msgstr ""
+
+#: fortran/lang.opt:817
+#, no-c-format
+msgid "Apply negative sign to zero values."
+msgstr ""
+
+#: fortran/lang.opt:824
+#, no-c-format
+msgid "Disallow tail call optimization when a calling routine may have omitted character lengths."
+msgstr ""
+
+#: fortran/lang.opt:828
+#, no-c-format
+msgid "Append underscores to externally visible names."
+msgstr ""
+
+#: fortran/lang.opt:832 c-family/c.opt:1733 c-family/c.opt:1810
+#: c-family/c.opt:1818 c-family/c.opt:2149 config/xtensa/xtensa.opt:42
+#: config/pa/pa.opt:46 config/pa/pa.opt:78 config/arc/arc.opt:140
+#: config/arc/arc.opt:296 config/arc/arc.opt:304 config/arc/arc.opt:308
+#: config/arc/arc.opt:312 config/arc/arc.opt:317 config/arc/arc.opt:326
+#: common.opt:643 common.opt:1177 common.opt:1181 common.opt:1185
+#: common.opt:1280 common.opt:1609 common.opt:1691 common.opt:2051
+#: common.opt:2194 common.opt:2237 common.opt:2682 common.opt:2718
+#: common.opt:2811 common.opt:2815 common.opt:2924 common.opt:3059
+#: common.opt:3067 common.opt:3075 common.opt:3083 common.opt:3184
+#: common.opt:3244 common.opt:3332 common.opt:3496 common.opt:3500
+#: common.opt:3504 common.opt:3508 common.opt:3578 common.opt:3582
+#: common.opt:3613 common.opt:3617
+#, no-c-format
+msgid "Does nothing.  Preserved for backward compatibility."
+msgstr ""
+
+#: fortran/lang.opt:872
+#, no-c-format
+msgid "Statically link the GNU Fortran helper library (libgfortran)."
+msgstr ""
+
+#: fortran/lang.opt:876
+#, no-c-format
+msgid "Statically link the GCC Quad-Precision Math Library (libquadmath)."
+msgstr ""
+
+#: fortran/lang.opt:880
+#, no-c-format
+msgid "Conform to the ISO Fortran 2003 standard."
+msgstr ""
+
+#: fortran/lang.opt:884
+#, no-c-format
+msgid "Conform to the ISO Fortran 2008 standard."
+msgstr ""
+
+#: fortran/lang.opt:888
+#, no-c-format
+msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
+msgstr ""
+
+#: fortran/lang.opt:892
+#, no-c-format
+msgid "Conform to the ISO Fortran 2018 standard."
+msgstr ""
+
+#: fortran/lang.opt:896
+#, no-c-format
+msgid "Conform to the ISO Fortran 2023 standard."
+msgstr ""
+
+#: fortran/lang.opt:900
+#, no-c-format
+msgid "Conform to the ISO Fortran 95 standard."
+msgstr ""
+
+#: fortran/lang.opt:904
+#, no-c-format
+msgid "Conform to nothing in particular."
+msgstr ""
+
+#: fortran/lang.opt:908
+#, no-c-format
+msgid "Accept extensions to support legacy code."
+msgstr ""
+
+#: rust/lang.opt:47 rust/lang.opt:51 c-family/c.opt:1469 c-family/c.opt:1473
+#, no-c-format
+msgid "Warn when a const variable is unused."
+msgstr ""
+
+#: rust/lang.opt:55 c-family/c.opt:1485
+#, no-c-format
+msgid "Warn if a caller of a function, marked with attribute warn_unused_result, does not use its return value."
+msgstr ""
+
+#: rust/lang.opt:59 c-family/c.opt:854 common.opt:654
+#, no-c-format
+msgid "Warn for infinitely recursive calls."
+msgstr ""
+
+#: rust/lang.opt:63
+#, no-c-format
+msgid "-frust-crate=<name>             Set the crate name for the compilation"
+msgstr ""
+
+#: rust/lang.opt:67
+#, no-c-format
+msgid "-frust-extern=              Specify where an external library is located"
+msgstr ""
+
+#: rust/lang.opt:71
+#, no-c-format
+msgid "Dump various Rust front end internals."
+msgstr ""
+
+#: rust/lang.opt:75
+#, no-c-format
+msgid "-frust-dump-<type>              Dump Rust frontend internal information."
+msgstr ""
+
+#: rust/lang.opt:79
+#, no-c-format
+msgid "Enable experimental compilation of Rust files at your own risk"
+msgstr ""
+
+#: rust/lang.opt:83
+#, no-c-format
+msgid "-frust-max-recursion-depth=<integer>"
+msgstr ""
+
+#: rust/lang.opt:87
+#, no-c-format
+msgid "-frust-crate-type=[bin|lib|rlib|dylib|cdylib|staticlib|proc-macro]     Crate type to emit"
+msgstr ""
+
+#: rust/lang.opt:115
+#, no-c-format
+msgid "-frust-mangling=[legacy|v0]     Version to use for name mangling"
+msgstr ""
+
+#: rust/lang.opt:128
+#, no-c-format
+msgid "-frust-cfg=<name>             Set a config expansion option"
+msgstr ""
+
+#: rust/lang.opt:132
+#, no-c-format
+msgid "-frust-edition=[2015|2018|2021]             Edition to use when compiling rust code"
+msgstr ""
+
+#: rust/lang.opt:148
+#, no-c-format
+msgid "Enable embedding metadata directly into object files"
+msgstr ""
+
+#: rust/lang.opt:152
+#, no-c-format
+msgid "-frust-metadata-output=<path.rox>  Path to output crate metadata"
+msgstr ""
+
+#: rust/lang.opt:160
+#, no-c-format
+msgid "-frust-compile-until=[ast|attributecheck|expansion|astvalidation|featuregating|nameresolution|lowering|typecheck|privacy|unsafety|const|borrowcheck|compilation|end]             The pipeline will run up until this stage when compiling Rust code"
+msgstr ""
+
+#: rust/lang.opt:209
+#, no-c-format
+msgid "Use the temporary and experimental name resolution pipeline instead of the stable one"
+msgstr ""
+
+#: rust/lang.opt:213
+#, no-c-format
+msgid "Use the WIP borrow checker."
+msgstr ""
+
+#: c-family/c.opt:182
+#, no-c-format
+msgid "-A<question>=<answer>\tAssert the <answer> to <question>.  Putting '-' before <question> disables the <answer> to <question>."
+msgstr ""
+
+#: c-family/c.opt:186
+#, no-c-format
+msgid "Do not discard comments."
+msgstr ""
+
+#: c-family/c.opt:190
+#, no-c-format
+msgid "Do not discard comments in macro expansions."
+msgstr ""
+
+#: c-family/c.opt:194
+#, no-c-format
+msgid "-D<macro>[=<val>]\tDefine a <macro> with <val> as its value.  If just <macro> is given, <val> is taken to be 1."
+msgstr ""
+
+#: c-family/c.opt:201
+#, no-c-format
+msgid "-F <dir>\tAdd <dir> to the end of the main framework include path."
+msgstr ""
+
+#: c-family/c.opt:205
+#, no-c-format
+msgid "Enable parsing GIMPLE."
+msgstr ""
+
+#: c-family/c.opt:209
+#, no-c-format
+msgid "Print the name of header files as they are used."
+msgstr ""
+
+#: c-family/c.opt:213
+#, no-c-format
+msgid "-I <dir>\tAdd <dir> to the end of the main include path."
+msgstr ""
+
+#: c-family/c.opt:217
+#, no-c-format
+msgid "Generate make dependencies."
+msgstr ""
+
+#: c-family/c.opt:221
+#, no-c-format
+msgid "Generate make dependencies and compile."
+msgstr ""
+
+#: c-family/c.opt:225
+#, no-c-format
+msgid "-MF <file>\tWrite dependency output to the given file."
+msgstr ""
+
+#: c-family/c.opt:229
+#, no-c-format
+msgid "Treat missing header files as generated files."
+msgstr ""
+
+#: c-family/c.opt:233
+#, no-c-format
+msgid "Like -M but ignore system header files."
+msgstr ""
+
+#: c-family/c.opt:237
+#, no-c-format
+msgid "Like -MD but ignore system header files."
+msgstr ""
+
+#: c-family/c.opt:241
+#, no-c-format
+msgid "Generate C++ Module dependency information."
+msgstr ""
+
+#: c-family/c.opt:249
+#, no-c-format
+msgid "Generate phony targets for all headers."
+msgstr ""
+
+#: c-family/c.opt:253
+#, no-c-format
+msgid "-MQ <target>\tAdd a target that may require quoting."
+msgstr ""
+
+#: c-family/c.opt:257
+#, no-c-format
+msgid "-MT <target>\tAdd a target that does not require quoting."
+msgstr ""
+
+#: c-family/c.opt:261
+#, no-c-format
+msgid "Structured format for output dependency information.  Supported (\"p1689r5\")."
+msgstr ""
+
+#: c-family/c.opt:265
+#, no-c-format
+msgid "File for output dependency information."
+msgstr ""
+
+#: c-family/c.opt:269
+#, no-c-format
+msgid "-fdeps-target=obj.o Output file for the compile step."
+msgstr ""
+
+#: c-family/c.opt:273
+#, no-c-format
+msgid "Do not generate #line directives."
+msgstr ""
+
+#: c-family/c.opt:277
+#, no-c-format
+msgid "-U<macro>\tUndefine <macro>."
+msgstr ""
+
+#: c-family/c.opt:281
+#, no-c-format
+msgid "Warn if the NSObject attribute is applied to a non-typedef."
+msgstr ""
+
+#: c-family/c.opt:285
+#, no-c-format
+msgid "Warn about things that will change when compiling with an ABI-compliant compiler."
+msgstr ""
+
+#: c-family/c.opt:289
+#, no-c-format
+msgid "Warn about things that change between the current -fabi-version and the specified version."
+msgstr ""
+
+#: c-family/c.opt:293
+#, no-c-format
+msgid "Warn if a subobject has an abi_tag attribute that the complete object type does not have."
+msgstr ""
+
+#: c-family/c.opt:300
+#, no-c-format
+msgid "Warn on suspicious calls of standard functions computing absolute values."
+msgstr ""
+
+#: c-family/c.opt:304
+#, no-c-format
+msgid "Warn about suspicious uses of memory addresses."
+msgstr ""
+
+#: c-family/c.opt:308
+#, no-c-format
+msgid "Warn when the address of packed member of struct or union is taken."
+msgstr ""
+
+#: c-family/c.opt:324
+#, no-c-format
+msgid "Warn about 'new' of type with extended alignment without -faligned-new."
+msgstr ""
+
+#: c-family/c.opt:328
+#, no-c-format
+msgid "-Waligned-new=[none|global|all]\tWarn even if 'new' uses a class member allocation function."
+msgstr ""
+
+#: c-family/c.opt:332 ada/gcc-interface/lang.opt:57
+#, no-c-format
+msgid "Enable most warning messages."
+msgstr ""
+
+#: c-family/c.opt:336
+#, no-c-format
+msgid "Warn on any use of alloca."
+msgstr ""
+
+#: c-family/c.opt:340
+#, no-c-format
+msgid "Warn when allocating insufficient storage for the target type of the assigned pointer."
+msgstr ""
+
+#: c-family/c.opt:344
+#, no-c-format
+msgid "-Walloc-size-larger-than=<bytes>\tWarn for calls to allocation functions that attempt to allocate objects larger than the specified number of bytes."
+msgstr ""
+
+#: c-family/c.opt:349
+#, no-c-format
+msgid "Disable Walloc-size-larger-than= warning.  Equivalent to Walloc-size-larger-than=<SIZE_MAX> or larger."
+msgstr ""
+
+#: c-family/c.opt:353
+#, no-c-format
+msgid "Warn for calls to allocation functions that specify zero bytes."
+msgstr ""
+
+#: c-family/c.opt:357
+#, no-c-format
+msgid "-Walloca-larger-than=<number>\tWarn on unbounded uses of alloca, and on bounded uses of alloca whose bound can be larger than <number> bytes."
+msgstr ""
+
+#: c-family/c.opt:363
+#, no-c-format
+msgid "Disable Walloca-larger-than= warning.  Equivalent to Walloca-larger-than=<SIZE_MAX> or larger."
+msgstr ""
+
+#: c-family/c.opt:367
+#, no-c-format
+msgid "Warn if conversion of the result of arithmetic might change the value even though converting the operands cannot."
+msgstr ""
+
+#: c-family/c.opt:375
+#, no-c-format
+msgid "Warn about comparisons between two operands of array type."
+msgstr ""
+
+#: c-family/c.opt:379 c-family/c.opt:383
+#, no-c-format
+msgid "Warn about mismatched declarations of array parameters and unsafe accesses to them."
+msgstr ""
+
+#: c-family/c.opt:387
+#, no-c-format
+msgid "Warn whenever an Objective-C assignment is being intercepted by the garbage collector."
+msgstr ""
+
+#: c-family/c.opt:391
+#, no-c-format
+msgid "Warn about casting functions to incompatible types."
+msgstr ""
+
+#: c-family/c.opt:399
+#, no-c-format
+msgid "-Wbidi-chars=[none|unpaired|any|ucn] Warn about UTF-8 bidirectional control characters."
+msgstr ""
+
+#: c-family/c.opt:422
+#, no-c-format
+msgid "Warn about boolean expression compared with an integer value different from true/false."
+msgstr ""
+
+#: c-family/c.opt:426
+#, no-c-format
+msgid "Warn about certain operations on boolean expressions."
+msgstr ""
+
+#: c-family/c.opt:430
+#, no-c-format
+msgid "Warn when a built-in function is declared with the wrong signature."
+msgstr ""
+
+#: c-family/c.opt:434
+#, no-c-format
+msgid "Warn when a built-in preprocessor macro is undefined or redefined."
+msgstr ""
+
+#: c-family/c.opt:438
+#, no-c-format
+msgid "Warn about features not present in ISO C11, but present in ISO C23."
+msgstr ""
+
+#: c-family/c.opt:442
+#, no-c-format
+msgid "Deprecated in favor of -Wc11-c23-compat."
+msgstr ""
+
+#: c-family/c.opt:446
+#, no-c-format
+msgid "Warn about features not present in ISO C90, but present in ISO C99."
+msgstr ""
+
+#: c-family/c.opt:450
+#, no-c-format
+msgid "Warn about features not present in ISO C99, but present in ISO C11."
+msgstr ""
+
+#: c-family/c.opt:454
+#, no-c-format
+msgid "Warn about C constructs that are not in the common subset of C and C++."
+msgstr ""
+
+#: c-family/c.opt:461
+#, no-c-format
+msgid "Warn about C++ constructs whose meaning differs between ISO C++ 1998 and ISO C++ 2011."
+msgstr ""
+
+#: c-family/c.opt:465
+#, no-c-format
+msgid "Warn about C++ constructs whose meaning differs between ISO C++ 2011 and ISO C++ 2014."
+msgstr ""
+
+#: c-family/c.opt:472
+#, no-c-format
+msgid "Warn about C++ constructs whose meaning differs between ISO C++ 2014 and ISO C++ 2017."
+msgstr ""
+
+#: c-family/c.opt:479
+#, no-c-format
+msgid "Warn about C++ constructs whose meaning differs between ISO C++ 2017 and ISO C++ 2020."
+msgstr ""
+
+#: c-family/c.opt:483
+#, no-c-format
+msgid "Warn about C++11 constructs in code compiled with an older standard."
+msgstr ""
+
+#: c-family/c.opt:487
+#, no-c-format
+msgid "Warn about C++14 constructs in code compiled with an older standard."
+msgstr ""
+
+#: c-family/c.opt:491
+#, no-c-format
+msgid "Warn about C++17 constructs in code compiled with an older standard."
+msgstr ""
+
+#: c-family/c.opt:495
+#, no-c-format
+msgid "Warn about C++20 constructs in code compiled with an older standard."
+msgstr ""
+
+#: c-family/c.opt:499
+#, no-c-format
+msgid "Warn about C++23 constructs in code compiled with an older standard."
+msgstr ""
+
+#: c-family/c.opt:503
+#, no-c-format
+msgid "Warn about C++26 constructs in code compiled with an older standard."
+msgstr ""
+
+#: c-family/c.opt:507
+#, no-c-format
+msgid "Warn about suspicious calls to calloc-like functions where sizeof expression is the earlier size argument and not the latter."
+msgstr ""
+
+#: c-family/c.opt:511
+#, no-c-format
+msgid "Warn about casts between incompatible function types."
+msgstr ""
+
+#: c-family/c.opt:515
+#, no-c-format
+msgid "Warn about casts which discard qualifiers."
+msgstr ""
+
+#: c-family/c.opt:519
+#, no-c-format
+msgid "Warn about a cast to reference type that does not use a related user-defined conversion function."
+msgstr ""
+
+#: c-family/c.opt:523 c-family/c.opt:527
+#, no-c-format
+msgid "Warn about catch handlers of non-reference type."
+msgstr ""
+
+#: c-family/c.opt:531
+#, no-c-format
+msgid "Complain about a name being declared as a class member after a previous use of the same name."
+msgstr ""
+
+#: c-family/c.opt:535
+#, no-c-format
+msgid "Warn about subscripts whose type is \"char\"."
+msgstr ""
+
+#: c-family/c.opt:539 c-family/c.opt:1630 c-family/c.opt:1634
+#: c-family/c.opt:1638 c-family/c.opt:1642 c-family/c.opt:1646
+#: c-family/c.opt:1650 c-family/c.opt:1654 c-family/c.opt:1661
+#: c-family/c.opt:1665 c-family/c.opt:1669 c-family/c.opt:1673
+#: c-family/c.opt:1677 c-family/c.opt:1681 c-family/c.opt:1685
+#: c-family/c.opt:1689 c-family/c.opt:1693 c-family/c.opt:1697
+#: c-family/c.opt:1701 c-family/c.opt:1705 c-family/c.opt:1709
+#: config/i386/i386.opt:1022
+#, no-c-format
+msgid "Removed in GCC 9.  This switch has no effect."
+msgstr ""
+
+#: c-family/c.opt:543
+#, no-c-format
+msgid "Warn when a conversion function will never be called due to the type it converts to."
+msgstr ""
+
+#: c-family/c.opt:547
+#, no-c-format
+msgid "Warn for unsafe raw memory writes to objects of class types."
+msgstr ""
+
+#: c-family/c.opt:551
+#, no-c-format
+msgid "Warn about variables that might be changed by \"longjmp\" or \"vfork\"."
+msgstr ""
+
+#: c-family/c.opt:555
+#, no-c-format
+msgid "Warn about uses of a comma operator within a subscripting expression."
+msgstr ""
+
+#: c-family/c.opt:559
+#, no-c-format
+msgid "Warn about possibly nested block comments, and C++ comments spanning more than one physical line."
+msgstr ""
+
+#: c-family/c.opt:563
+#, no-c-format
+msgid "Synonym for -Wcomment."
+msgstr ""
+
+#: c-family/c.opt:567
+#, no-c-format
+msgid "Warn for conditionally-supported constructs."
+msgstr ""
+
+#: c-family/c.opt:571
+#, no-c-format
+msgid "Warn for implicit type conversions that may change a value."
+msgstr ""
+
+#: c-family/c.opt:575
+#, no-c-format
+msgid "Warn for converting NULL from/to a non-pointer type."
+msgstr ""
+
+#: c-family/c.opt:583
+#, no-c-format
+msgid "Warn when performing class template argument deduction on a type with no deduction guides."
+msgstr ""
+
+#: c-family/c.opt:588
+#, no-c-format
+msgid "Warn when all constructors and destructors are private."
+msgstr ""
+
+#: c-family/c.opt:592
+#, no-c-format
+msgid "Warn about dangling else."
+msgstr ""
+
+#: c-family/c.opt:596 c-family/c.opt:600
+#, no-c-format
+msgid "Warn for uses of pointers to auto variables whose lifetime has ended."
+msgstr ""
+
+#: c-family/c.opt:604
+#, no-c-format
+msgid "Warn when a reference is bound to a temporary whose lifetime has ended."
+msgstr ""
+
+#: c-family/c.opt:608
+#, no-c-format
+msgid "Warn about __TIME__, __DATE__ and __TIMESTAMP__ usage."
+msgstr ""
+
+#: c-family/c.opt:612
+#, no-c-format
+msgid "Warn when a declaration is found after a statement."
+msgstr ""
+
+#: c-family/c.opt:616
+#, no-c-format
+msgid "Warn for missing parameter types in function declarations."
+msgstr ""
+
+#: c-family/c.opt:620
+#, no-c-format
+msgid "Warn when deleting a pointer to incomplete type."
+msgstr ""
+
+#: c-family/c.opt:624
+#, no-c-format
+msgid "Warn about deleting polymorphic objects with non-virtual destructors."
+msgstr ""
+
+#: c-family/c.opt:632
+#, no-c-format
+msgid "Mark implicitly-declared copy operations as deprecated if the class has a user-provided copy operation."
+msgstr ""
+
+#: c-family/c.opt:637
+#, no-c-format
+msgid "Mark implicitly-declared copy operations as deprecated if the class has a user-provided copy operation or destructor."
+msgstr ""
+
+#: c-family/c.opt:642
+#, no-c-format
+msgid "Warn about deprecated arithmetic conversions on operands of enumeration types."
+msgstr ""
+
+#: c-family/c.opt:646
+#, no-c-format
+msgid "Warn about deprecated arithmetic conversions on operands where one is of enumeration type and the other is of a floating-point type."
+msgstr ""
+
+#: c-family/c.opt:651
+#, no-c-format
+msgid "Warn about positional initialization of structs requiring designated initializers."
+msgstr ""
+
+#: c-family/c.opt:655
+#, no-c-format
+msgid "Warn if qualifiers on arrays which are pointer targets are discarded."
+msgstr ""
+
+#: c-family/c.opt:659
+#, no-c-format
+msgid "Warn if type qualifiers on pointers are discarded."
+msgstr ""
+
+#: c-family/c.opt:663
+#, no-c-format
+msgid "Warn about compile-time integer division by zero."
+msgstr ""
+
+#: c-family/c.opt:667
+#, no-c-format
+msgid "Warn about implicit conversions from \"float\" to \"double\"."
+msgstr ""
+
+#: c-family/c.opt:671
+#, no-c-format
+msgid "Warn when a declaration has duplicate const, volatile, restrict or _Atomic specifier."
+msgstr ""
+
+#: c-family/c.opt:675
+#, no-c-format
+msgid "Warn about duplicated branches in if-else statements."
+msgstr ""
+
+#: c-family/c.opt:679
+#, no-c-format
+msgid "Warn about duplicated conditions in an if-else-if chain."
+msgstr ""
+
+#: c-family/c.opt:683
+#, no-c-format
+msgid "Warn about violations of Effective C++ style rules."
+msgstr ""
+
+#: c-family/c.opt:687
+#, no-c-format
+msgid "Warn if an additional enum-base is used in an elaborated-type-specifier."
+msgstr ""
+
+#: c-family/c.opt:691
+#, no-c-format
+msgid "Warn about an empty body in an if or else statement."
+msgstr ""
+
+#: c-family/c.opt:695
+#, no-c-format
+msgid "Warn about stray tokens after #else and #endif."
+msgstr ""
+
+#: c-family/c.opt:699
+#, no-c-format
+msgid "Warn about comparison of different enum types."
+msgstr ""
+
+#: c-family/c.opt:703
+#, no-c-format
+msgid "Warn about implicit conversion of enum types."
+msgstr ""
+
+#: c-family/c.opt:707
+#, no-c-format
+msgid "Warn about enum/integer type mismatches."
+msgstr ""
+
+#: c-family/c.opt:715
+#, no-c-format
+msgid "This switch is deprecated; use -Werror=implicit-function-declaration instead."
+msgstr ""
+
+#: c-family/c.opt:719
+#, no-c-format
+msgid "Warn when an exception handler is shadowed by another handler."
+msgstr ""
+
+#: c-family/c.opt:723
+#, no-c-format
+msgid "Warn if \"defined\" is used outside #if."
+msgstr ""
+
+#: c-family/c.opt:731
+#, no-c-format
+msgid "Warn about semicolon after in-class function definition."
+msgstr ""
+
+#: c-family/c.opt:735
+#, no-c-format
+msgid "Warn when a structure containing a C99 flexible array member as the last field is not at the end of another structure."
+msgstr ""
+
+#: c-family/c.opt:740
+#, no-c-format
+msgid "Warn for implicit type conversions that cause loss of floating point precision."
+msgstr ""
+
+#: c-family/c.opt:744
+#, no-c-format
+msgid "Warn if testing floating point numbers for equality."
+msgstr ""
+
+#: c-family/c.opt:748 c-family/c.opt:803
+#, no-c-format
+msgid "Warn about printf/scanf/strftime/strfmon format string anomalies."
+msgstr ""
+
+#: c-family/c.opt:752
+#, no-c-format
+msgid "Warn about format strings that contain NUL bytes."
+msgstr ""
+
+#: c-family/c.opt:756
+#, no-c-format
+msgid "Warn about GCC format strings with strings unsuitable for diagnostics."
+msgstr ""
+
+#: c-family/c.opt:760
+#, no-c-format
+msgid "Warn if passing too many arguments to a function for its format string."
+msgstr ""
+
+#: c-family/c.opt:764
+#, no-c-format
+msgid "Warn about format strings that are not literals."
+msgstr ""
+
+#: c-family/c.opt:768
+#, no-c-format
+msgid "Warn about function calls with format strings that write past the end of the destination region.  Same as -Wformat-overflow=1."
+msgstr ""
+
+#: c-family/c.opt:773
+#, no-c-format
+msgid "Warn about function calls with format strings that write past the end of the destination region."
+msgstr ""
+
+#: c-family/c.opt:778
+#, no-c-format
+msgid "Warn about possible security problems with format functions."
+msgstr ""
+
+#: c-family/c.opt:782
+#, no-c-format
+msgid "Warn about sign differences with format functions."
+msgstr ""
+
+#: c-family/c.opt:786
+#, no-c-format
+msgid "Warn about calls to snprintf and similar functions that truncate output. Same as -Wformat-truncation=1."
+msgstr ""
+
+#: c-family/c.opt:791
+#, no-c-format
+msgid "Warn about calls to snprintf and similar functions that truncate output."
+msgstr ""
+
+#: c-family/c.opt:795
+#, no-c-format
+msgid "Warn about strftime formats yielding 2-digit years."
+msgstr ""
+
+#: c-family/c.opt:799
+#, no-c-format
+msgid "Warn about zero-length formats."
+msgstr ""
+
+#: c-family/c.opt:807
+#, no-c-format
+msgid "Warn when __builtin_frame_address or __builtin_return_address is used unsafely."
+msgstr ""
+
+#: c-family/c.opt:811
+#, no-c-format
+msgid "Warn about the global module fragment not containing only preprocessing directives."
+msgstr ""
+
+#: c-family/c.opt:815
+#, no-c-format
+msgid "Warn when the field in a struct is not aligned."
+msgstr ""
+
+#: c-family/c.opt:819
+#, no-c-format
+msgid "Warn whenever type qualifiers are ignored."
+msgstr ""
+
+#: c-family/c.opt:823
+#, no-c-format
+msgid "Warn whenever attributes are ignored."
+msgstr ""
+
+#: c-family/c.opt:827
+#, no-c-format
+msgid "Warn about implicit declarations."
+msgstr ""
+
+#: c-family/c.opt:835
+#, no-c-format
+msgid "Warn about implicit function declarations."
+msgstr ""
+
+#: c-family/c.opt:839
+#, no-c-format
+msgid "Warn when a declaration does not specify a type."
+msgstr ""
+
+#: c-family/c.opt:846
+#, no-c-format
+msgid "Warn when a base is inaccessible in derived due to ambiguity."
+msgstr ""
+
+#: c-family/c.opt:850
+#, no-c-format
+msgid "Warn when there is a conversion between pointers that have incompatible types."
+msgstr ""
+
+#: c-family/c.opt:858
+#, no-c-format
+msgid "Warn about variables which are initialized to themselves."
+msgstr ""
+
+#: c-family/c.opt:862
+#, no-c-format
+msgid "Warn about uses of std::initializer_list that can result in dangling pointers."
+msgstr ""
+
+#: c-family/c.opt:866
+#, no-c-format
+msgid "Warn about nonsensical values of --param destructive-interference-size or constructive-interference-size."
+msgstr ""
+
+#: c-family/c.opt:871
+#, no-c-format
+msgid "Warn about C++11 inheriting constructors when the base has a variadic constructor."
+msgstr ""
+
+#: c-family/c.opt:875
+#, no-c-format
+msgid "Warn about incompatible integer to pointer and pointer to integer conversions."
+msgstr ""
+
+#: c-family/c.opt:879
+#, no-c-format
+msgid "Warn for suspicious integer expressions in boolean context."
+msgstr ""
+
+#: c-family/c.opt:883
+#, no-c-format
+msgid "Warn when there is a cast to a pointer from an integer of a different size."
+msgstr ""
+
+#: c-family/c.opt:887
+#, no-c-format
+msgid "Warn when a function never produces a constant expression."
+msgstr ""
+
+#: c-family/c.opt:891
+#, no-c-format
+msgid "Warn about invalid uses of the \"offsetof\" macro."
+msgstr ""
+
+#: c-family/c.opt:895
+#, no-c-format
+msgid "Warn about PCH files that are found but not used."
+msgstr ""
+
+#: c-family/c.opt:899
+#, no-c-format
+msgid "Warn about invalid UTF-8 characters."
+msgstr ""
+
+#: c-family/c.opt:903
+#, no-c-format
+msgid "Warn when a jump misses a variable initialization."
+msgstr ""
+
+#: c-family/c.opt:907
+#, no-c-format
+msgid "Warn when a string or character literal is followed by a ud-suffix which does not begin with an underscore."
+msgstr ""
+
+#: c-family/c.opt:911
+#, no-c-format
+msgid "Warn when logical not is used on the left hand side operand of a comparison."
+msgstr ""
+
+#: c-family/c.opt:915
+#, no-c-format
+msgid "Warn when a logical operator is suspiciously always evaluating to true or false."
+msgstr ""
+
+#: c-family/c.opt:919
+#, no-c-format
+msgid "Do not warn about using \"long long\" when -pedantic."
+msgstr ""
+
+#: c-family/c.opt:923
+#, no-c-format
+msgid "Warn about suspicious declarations of \"main\"."
+msgstr ""
+
+#: c-family/c.opt:935
+#, no-c-format
+msgid "Warn about suspicious calls to memset where the third argument contains the number of elements not multiplied by the element size."
+msgstr ""
+
+#: c-family/c.opt:939
+#, no-c-format
+msgid "Warn about suspicious calls to memset where the third argument is constant literal zero and the second is not."
+msgstr ""
+
+#: c-family/c.opt:943
+#, no-c-format
+msgid "Warn when the indentation of the code does not reflect the block structure."
+msgstr ""
+
+#: c-family/c.opt:947
+#, no-c-format
+msgid "Warn for deallocation calls with arguments returned from mismatched allocation functions."
+msgstr ""
+
+#: c-family/c.opt:952
+#, no-c-format
+msgid "Warn for mismatches between calls to operator new or delete and the corresponding call to the allocation or deallocation function."
+msgstr ""
+
+#: c-family/c.opt:957
+#, no-c-format
+msgid "Warn when a class is redeclared or referenced using a mismatched class-key."
+msgstr ""
+
+#: c-family/c.opt:961
+#, no-c-format
+msgid "Warn about declarations of entities that may be missing attributes that related entities have been declared with."
+msgstr ""
+
+#: c-family/c.opt:966
+#, no-c-format
+msgid "Warn about possibly missing braces around initializers."
+msgstr ""
+
+#: c-family/c.opt:970
+#, no-c-format
+msgid "Warn about global functions without previous declarations."
+msgstr ""
+
+#: c-family/c.opt:974
+#, no-c-format
+msgid "Warn about missing fields in struct initializers."
+msgstr ""
+
+#: c-family/c.opt:982
+#, no-c-format
+msgid "Warn about user-specified include directories that do not exist."
+msgstr ""
+
+#: c-family/c.opt:986
+#, no-c-format
+msgid "Warn about function parameters declared without a type specifier in K&R-style functions."
+msgstr ""
+
+#: c-family/c.opt:990
+#, no-c-format
+msgid "Warn about global functions without prototypes."
+msgstr ""
+
+#: c-family/c.opt:994
+#, no-c-format
+msgid "Warn about likely missing requires keyword."
+msgstr ""
+
+#: c-family/c.opt:998
+#, no-c-format
+msgid "Warn when the template keyword is missing after a member access token in a dependent member access expression if that member is a template."
+msgstr ""
+
+#: c-family/c.opt:1002
+#, no-c-format
+msgid "Warn about global variables without previous declarations."
+msgstr ""
+
+#: c-family/c.opt:1009
+#, no-c-format
+msgid "Warn about use of multi-character character constants."
+msgstr ""
+
+#: c-family/c.opt:1013
+#, no-c-format
+msgid "Warn on direct multiple inheritance."
+msgstr ""
+
+#: c-family/c.opt:1017
+#, no-c-format
+msgid "Warn about unsafe macros expanding to multiple statements used as a body of a clause such as if, else, while, switch, or for."
+msgstr ""
+
+#: c-family/c.opt:1021
+#, no-c-format
+msgid "Warn on namespace definition."
+msgstr ""
+
+#: c-family/c.opt:1025
+#, no-c-format
+msgid "Warn about narrowing conversions within { } that are ill-formed in C++11."
+msgstr ""
+
+#: c-family/c.opt:1029
+#, no-c-format
+msgid "Warn about \"extern\" declarations not at file scope."
+msgstr ""
+
+#: c-family/c.opt:1033
+#, no-c-format
+msgid "Warn when a noexcept expression evaluates to false even though the expression can't actually throw."
+msgstr ""
+
+#: c-family/c.opt:1037
+#, no-c-format
+msgid "Warn if C++17 noexcept function type will change the mangled name of a symbol."
+msgstr ""
+
+#: c-family/c.opt:1041
+#, no-c-format
+msgid "Warn when non-templatized friend functions are declared within a template."
+msgstr ""
+
+#: c-family/c.opt:1045
+#, no-c-format
+msgid "Warn about non-virtual destructors."
+msgstr ""
+
+#: c-family/c.opt:1049
+#, no-c-format
+msgid "Warn about NULL being passed to argument slots marked as requiring non-NULL."
+msgstr ""
+
+#: c-family/c.opt:1065
+#, no-c-format
+msgid "-Wnormalized=[none|id|nfc|nfkc]\tWarn about non-normalized Unicode strings."
+msgstr ""
+
+#: c-family/c.opt:1088
+#, no-c-format
+msgid "Warn if a class interface has no superclass.  Root classes may use an attribute to suppress this warning."
+msgstr ""
+
+#: c-family/c.opt:1093
+#, no-c-format
+msgid "Warn if a C-style cast is used in a program."
+msgstr ""
+
+#: c-family/c.opt:1097
+#, no-c-format
+msgid "Warn for obsolescent usage in a declaration."
+msgstr ""
+
+#: c-family/c.opt:1101
+#, no-c-format
+msgid "Warn if an old-style parameter definition is used."
+msgstr ""
+
+#: c-family/c.opt:1105
+#, no-c-format
+msgid "Warn about potentially suboptimal choices related to OpenACC parallelism."
+msgstr ""
+
+#: c-family/c.opt:1109
+#, no-c-format
+msgid "Warn about suspicious OpenMP code."
+msgstr ""
+
+#: c-family/c.opt:1113
+#, no-c-format
+msgid "Warn if a simd directive is overridden by the vectorizer cost model."
+msgstr ""
+
+#: c-family/c.opt:1117
+#, no-c-format
+msgid "Warn if a string is longer than the maximum portable length specified by the standard."
+msgstr ""
+
+#: c-family/c.opt:1121 c-family/c.opt:1125
+#, no-c-format
+msgid "Warn about overloaded virtual function names."
+msgstr ""
+
+#: c-family/c.opt:1129
+#, no-c-format
+msgid "Warn about overriding initializers without side effects."
+msgstr ""
+
+#: c-family/c.opt:1133
+#, no-c-format
+msgid "Warn about overriding initializers with side effects."
+msgstr ""
+
+#: c-family/c.opt:1137
+#, no-c-format
+msgid "Warn if the named return value optimization is not performed although it is allowed."
+msgstr ""
+
+#: c-family/c.opt:1141
+#, no-c-format
+msgid "Warn about packed bit-fields whose offset changed in GCC 4.4."
+msgstr ""
+
+#: c-family/c.opt:1145
+#, no-c-format
+msgid "Warn when fields in a struct with the packed attribute are misaligned."
+msgstr ""
+
+#: c-family/c.opt:1149
+#, no-c-format
+msgid "Warn about possibly missing parentheses."
+msgstr ""
+
+#: c-family/c.opt:1157
+#, no-c-format
+msgid "Warn about calling std::move on a local object in a return statement preventing copy elision."
+msgstr ""
+
+#: c-family/c.opt:1161 c-family/c.opt:1165
+#, no-c-format
+msgid "Warn for placement new expressions with undefined behavior."
+msgstr ""
+
+#: c-family/c.opt:1169
+#, no-c-format
+msgid "Warn when converting the type of pointers to member functions."
+msgstr ""
+
+#: c-family/c.opt:1173
+#, no-c-format
+msgid "Warn about function pointer arithmetic."
+msgstr ""
+
+#: c-family/c.opt:1177
+#, no-c-format
+msgid "Warn when a pointer differs in signedness in an assignment."
+msgstr ""
+
+#: c-family/c.opt:1181
+#, no-c-format
+msgid "Warn when a pointer is compared with a zero character constant."
+msgstr ""
+
+#: c-family/c.opt:1185
+#, no-c-format
+msgid "Warn when a pointer is cast to an integer of a different size."
+msgstr ""
+
+#: c-family/c.opt:1189
+#, no-c-format
+msgid "Warn about misuses of pragmas."
+msgstr ""
+
+#: c-family/c.opt:1193
+#, no-c-format
+msgid "Warn if constructor or destructors with priorities from 0 to 100 are used."
+msgstr ""
+
+#: c-family/c.opt:1197
+#, no-c-format
+msgid "Warn if a property for an Objective-C object has no assign semantics specified."
+msgstr ""
+
+#: c-family/c.opt:1201
+#, no-c-format
+msgid "Warn if inherited methods are unimplemented."
+msgstr ""
+
+#: c-family/c.opt:1205
+#, no-c-format
+msgid "Warn when a range-based for-loop is creating unnecessary copies."
+msgstr ""
+
+#: c-family/c.opt:1209
+#, no-c-format
+msgid "Warn about multiple declarations of the same object."
+msgstr ""
+
+#: c-family/c.opt:1213
+#, no-c-format
+msgid "Warn about redundant calls to std::move."
+msgstr ""
+
+#: c-family/c.opt:1217
+#, no-c-format
+msgid "Warn when a class or enumerated type is referenced using a redundant class-key."
+msgstr ""
+
+#: c-family/c.opt:1221
+#, no-c-format
+msgid "Warn about uses of register storage specifier."
+msgstr ""
+
+#: c-family/c.opt:1225
+#, no-c-format
+msgid "Warn when the compiler reorders code."
+msgstr ""
+
+#: c-family/c.opt:1229
+#, no-c-format
+msgid "Warn when an argument passed to a restrict-qualified parameter aliases with another argument."
+msgstr ""
+
+#: c-family/c.opt:1234
+#, no-c-format
+msgid "Warn whenever void-returning functions return a non-void expressions, or a return expression is missing in a function not returning void."
+msgstr ""
+
+#: c-family/c.opt:1238
+#, no-c-format
+msgid "Warn whenever a function's return type defaults to \"int\" (C), or about inconsistent return types (C++)."
+msgstr ""
+
+#: c-family/c.opt:1242
+#, no-c-format
+msgid "Warn on suspicious constructs involving reverse scalar storage order."
+msgstr ""
+
+#: c-family/c.opt:1246
+#, no-c-format
+msgid "Warn if a selector has multiple methods."
+msgstr ""
+
+#: c-family/c.opt:1250
+#, no-c-format
+msgid "Warn when a value is moved to itself with std::move."
+msgstr ""
+
+#: c-family/c.opt:1254
+#, no-c-format
+msgid "Warn about possible violations of sequence point rules."
+msgstr ""
+
+#: c-family/c.opt:1258
+#, no-c-format
+msgid "Warn if a local declaration hides an instance variable."
+msgstr ""
+
+#: c-family/c.opt:1262 c-family/c.opt:1266
+#, no-c-format
+msgid "Warn if left shift of a signed value overflows."
+msgstr ""
+
+#: c-family/c.opt:1270
+#, no-c-format
+msgid "Warn if shift count is negative."
+msgstr ""
+
+#: c-family/c.opt:1274
+#, no-c-format
+msgid "Warn if shift count >= width of type."
+msgstr ""
+
+#: c-family/c.opt:1278
+#, no-c-format
+msgid "Warn if left shifting a negative value."
+msgstr ""
+
+#: c-family/c.opt:1282
+#, no-c-format
+msgid "Warn about signed-unsigned comparisons."
+msgstr ""
+
+#: c-family/c.opt:1290
+#, no-c-format
+msgid "Warn for implicit type conversions between signed and unsigned integers."
+msgstr ""
+
+#: c-family/c.opt:1294
+#, no-c-format
+msgid "Warn when overload promotes from unsigned to signed."
+msgstr ""
+
+#: c-family/c.opt:1298
+#, no-c-format
+msgid "Warn about missing sized deallocation functions."
+msgstr ""
+
+#: c-family/c.opt:1302
+#, no-c-format
+msgid "Warn about divisions of two sizeof operators when the first one is applied to an array and the divisor does not equal the size of the array element."
+msgstr ""
+
+#: c-family/c.opt:1307
+#, no-c-format
+msgid "Warn when sizeof is applied on a parameter declared as an array."
+msgstr ""
+
+#: c-family/c.opt:1311
+#, no-c-format
+msgid "Warn about suspicious divisions of two sizeof expressions that don't work correctly with pointers."
+msgstr ""
+
+#: c-family/c.opt:1315
+#, no-c-format
+msgid "Warn about suspicious length parameters to certain string functions if the argument uses sizeof."
+msgstr ""
+
+#: c-family/c.opt:1323
+#, no-c-format
+msgid "Warn about improper usages of flexible array members according to the level of -fstrict-flex-arrays."
+msgstr ""
+
+#: c-family/c.opt:1328
+#, no-c-format
+msgid "Warn about uncasted NULL used as sentinel."
+msgstr ""
+
+#: c-family/c.opt:1336
+#, no-c-format
+msgid "Warn about unprototyped function declarations."
+msgstr ""
+
+#: c-family/c.opt:1340
+#, no-c-format
+msgid "Warn if type signatures of candidate methods do not match exactly."
+msgstr ""
+
+#: c-family/c.opt:1344
+#, no-c-format
+msgid "Warn about calls to strcmp and strncmp used in equality expressions that are necessarily true or false due to the length of one and size of the other argument."
+msgstr ""
+
+#: c-family/c.opt:1350
+#, no-c-format
+msgid "Warn about buffer overflow in string manipulation functions like memcpy and strcpy."
+msgstr ""
+
+#: c-family/c.opt:1355
+#, no-c-format
+msgid "Under the control of Object Size type, warn about buffer overflow in string manipulation functions like memcpy and strcpy."
+msgstr ""
+
+#: c-family/c.opt:1360
+#, no-c-format
+msgid "Warn about reading past the end of a source array in string manipulation functions like memchr and memcpy."
+msgstr ""
+
+#: c-family/c.opt:1364
+#, no-c-format
+msgid "Warn about truncation in string manipulation functions like strncat and strncpy."
+msgstr ""
+
+#: c-family/c.opt:1368
+#, no-c-format
+msgid "Warn if a class type has a base or a field whose type uses the anonymous namespace or depends on a type with no linkage."
+msgstr ""
+
+#: c-family/c.opt:1372
+#, no-c-format
+msgid "Warn about functions which might be candidates for format attributes."
+msgstr ""
+
+#: c-family/c.opt:1376
+#, no-c-format
+msgid "Suggest that the override keyword be used when the declaration of a virtual function overrides another."
+msgstr ""
+
+#: c-family/c.opt:1381
+#, no-c-format
+msgid "Warn about enumerated switches, with no default, missing a case."
+msgstr ""
+
+#: c-family/c.opt:1385
+#, no-c-format
+msgid "Warn about enumerated switches missing a \"default:\" statement."
+msgstr ""
+
+#: c-family/c.opt:1389
+#, no-c-format
+msgid "Warn about all enumerated switches missing a specific case."
+msgstr ""
+
+#: c-family/c.opt:1393
+#, no-c-format
+msgid "Warn about switches with boolean controlling expression."
+msgstr ""
+
+#: c-family/c.opt:1397
+#, no-c-format
+msgid "Warn about switch values that are outside of the switch's type range."
+msgstr ""
+
+#: c-family/c.opt:1401
+#, no-c-format
+msgid "Warn when __sync_fetch_and_nand and __sync_nand_and_fetch built-in functions are used."
+msgstr ""
+
+#: c-family/c.opt:1405
+#, no-c-format
+msgid "Deprecated.  This switch has no effect."
+msgstr ""
+
+#: c-family/c.opt:1413
+#, no-c-format
+msgid "Warn on primary template declaration."
+msgstr ""
+
+#: c-family/c.opt:1417
+#, no-c-format
+msgid "Warn if a comparison always evaluates to true or false."
+msgstr ""
+
+#: c-family/c.opt:1421
+#, no-c-format
+msgid "Warn about simple-template-id in a constructor or destructor."
+msgstr ""
+
+#: c-family/c.opt:1425
+#, no-c-format
+msgid "Warn if a throw expression will always result in a call to terminate()."
+msgstr ""
+
+#: c-family/c.opt:1429
+#, no-c-format
+msgid "Warn about features not present in traditional C."
+msgstr ""
+
+#: c-family/c.opt:1433
+#, no-c-format
+msgid "Warn of prototypes causing type conversions different from what would happen in the absence of prototype."
+msgstr ""
+
+#: c-family/c.opt:1437
+#, no-c-format
+msgid "Warn if trigraphs are encountered that might affect the meaning of the program."
+msgstr ""
+
+#: c-family/c.opt:1441
+#, no-c-format
+msgid "Warn about @selector()s without previously declared methods."
+msgstr ""
+
+#: c-family/c.opt:1445
+#, no-c-format
+msgid "Warn if an undefined macro is used in an #if directive."
+msgstr ""
+
+#: c-family/c.opt:1449
+#, no-c-format
+msgid "Warn about invalid forms of delimited or named escape sequences."
+msgstr ""
+
+#: c-family/c.opt:1457
+#, no-c-format
+msgid "Warn about unrecognized pragmas."
+msgstr ""
+
+#: c-family/c.opt:1461
+#, no-c-format
+msgid "Warn about unsuffixed float constants."
+msgstr ""
+
+#: c-family/c.opt:1477
+#, no-c-format
+msgid "Warn when typedefs locally defined in a function are not used."
+msgstr ""
+
+#: c-family/c.opt:1481
+#, no-c-format
+msgid "Warn about macros defined in the main file that are not used."
+msgstr ""
+
+#: c-family/c.opt:1501
+#, no-c-format
+msgid "Warn about useless casts."
+msgstr ""
+
+#: c-family/c.opt:1505
+#, no-c-format
+msgid "Warn about using variadic macros."
+msgstr ""
+
+#: c-family/c.opt:1509
+#, no-c-format
+msgid "Warn about questionable usage of the macros used to retrieve variable arguments."
+msgstr ""
+
+#: c-family/c.opt:1513
+#, no-c-format
+msgid "Warn about the most vexing parse syntactic ambiguity."
+msgstr ""
+
+#: c-family/c.opt:1517
+#, no-c-format
+msgid "Warn if a virtual base has a non-trivial move assignment operator."
+msgstr ""
+
+#: c-family/c.opt:1521
+#, no-c-format
+msgid "Warn if a variable length array is used."
+msgstr ""
+
+#: c-family/c.opt:1525
+#, no-c-format
+msgid "-Wvla-larger-than=<number>\tWarn on unbounded uses of variable-length arrays, and on bounded uses of variable-length arrays whose bound can be larger than <number> bytes."
+msgstr ""
+
+#: c-family/c.opt:1531
+#, no-c-format
+msgid "Disable Wvla-larger-than= warning.  Equivalent to Wvla-larger-than=<SIZE_MAX> or larger."
+msgstr ""
+
+#: c-family/c.opt:1535
+#, no-c-format
+msgid "Warn about mismatched declarations of VLA parameters."
+msgstr ""
+
+#: c-family/c.opt:1539
+#, no-c-format
+msgid "Warn about deprecated uses of volatile qualifier."
+msgstr ""
+
+#: c-family/c.opt:1543
+#, no-c-format
+msgid "Warn when a register variable is declared volatile."
+msgstr ""
+
+#: c-family/c.opt:1547
+#, no-c-format
+msgid "Warn on direct virtual inheritance."
+msgstr ""
+
+#: c-family/c.opt:1551
+#, no-c-format
+msgid "In C++, nonzero means warn about deprecated conversion from string literals to 'char *'.  In C, similar warning, except that the conversion is of course not deprecated by the ISO C standard."
+msgstr ""
+
+#: c-family/c.opt:1555
+#, no-c-format
+msgid "Warn about xor operators where it appears the user meant exponentiation."
+msgstr ""
+
+#: c-family/c.opt:1559
+#, no-c-format
+msgid "Warn when a literal '0' is used as null pointer."
+msgstr ""
+
+#: c-family/c.opt:1563
+#, no-c-format
+msgid "Warn about accesses to interior zero-length array members."
+msgstr ""
+
+#: c-family/c.opt:1567
+#, no-c-format
+msgid "A synonym for -std=c89 (for C) or -std=c++98 (for C++)."
+msgstr ""
+
+#: c-family/c.opt:1575
+#, no-c-format
+msgid "The version of the C++ ABI used for -Wabi warnings and link compatibility aliases."
+msgstr ""
+
+#: c-family/c.opt:1579
+#, no-c-format
+msgid "Enforce class member access control semantics."
+msgstr ""
+
+#: c-family/c.opt:1583
+#, no-c-format
+msgid "-fada-spec-parent=unit\tDump Ada specs as child units of given parent."
+msgstr ""
+
+#: c-family/c.opt:1587
+#, no-c-format
+msgid "Support C++17 allocation of over-aligned types."
+msgstr ""
+
+#: c-family/c.opt:1591
+#, no-c-format
+msgid "-faligned-new=<N>\tUse C++17 over-aligned type allocation for alignments greater than N."
+msgstr ""
+
+#: c-family/c.opt:1602 c-family/c.opt:1919 c-family/c.opt:2321
+#: c-family/c.opt:2325 c-family/c.opt:2341
+#, no-c-format
+msgid "No longer supported."
+msgstr ""
+
+#: c-family/c.opt:1606
+#, no-c-format
+msgid "Recognize the \"asm\" keyword."
+msgstr ""
+
+#: c-family/c.opt:1614
+#, no-c-format
+msgid "Recognize built-in functions."
+msgstr ""
+
+#: c-family/c.opt:1621
+#, no-c-format
+msgid "Where shorter, use canonicalized paths to systems headers."
+msgstr ""
+
+#: c-family/c.opt:1625
+#, no-c-format
+msgid "Enable the char8_t fundamental type and use it as the type for UTF-8 string and character literals."
+msgstr ""
+
+#: c-family/c.opt:1713
+#, no-c-format
+msgid "Removed in GCC 8.  This switch has no effect."
+msgstr ""
+
+#: c-family/c.opt:1717
+#, no-c-format
+msgid "Enable support for C++ concepts."
+msgstr ""
+
+#: c-family/c.opt:1721
+#, no-c-format
+msgid "Enable certain features present in the Concepts TS."
+msgstr ""
+
+#: c-family/c.opt:1725
+#, no-c-format
+msgid "Specify maximum error replay depth during recursive diagnosis of a constraint satisfaction failure."
+msgstr ""
+
+#: c-family/c.opt:1729
+#, no-c-format
+msgid "Allow the arguments of the '?' operator to have different types."
+msgstr ""
+
+#: c-family/c.opt:1737
+#, no-c-format
+msgid "-fconst-string-class=<name>\tUse class <name> for constant strings."
+msgstr ""
+
+#: c-family/c.opt:1741
+#, no-c-format
+msgid "-fconstexpr-depth=<number>\tSpecify maximum constexpr recursion depth."
+msgstr ""
+
+#: c-family/c.opt:1745
+#, no-c-format
+msgid "-fconstexpr-cache-depth=<number>\tSpecify maximum constexpr recursion cache depth."
+msgstr ""
+
+#: c-family/c.opt:1749
+#, no-c-format
+msgid "Allow IEC559 floating point exceptions in constant expressions."
+msgstr ""
+
+#: c-family/c.opt:1753
+#, no-c-format
+msgid "-fconstexpr-loop-limit=<number>\tSpecify maximum constexpr loop iteration count."
+msgstr ""
+
+#: c-family/c.opt:1757
+#, no-c-format
+msgid "-fconstexpr-ops-limit=<number>\tSpecify maximum number of constexpr operations during a single constexpr evaluation."
+msgstr ""
+
+#: c-family/c.opt:1761
+#, no-c-format
+msgid "Enable certain features present in drafts of C++ Contracts."
+msgstr ""
+
+#: c-family/c.opt:1774
+#, no-c-format
+msgid "-fcontract-assumption-mode=[on|off]\tEnable or disable treating axiom level contracts as assumptions (default on)."
+msgstr ""
+
+#: c-family/c.opt:1778
+#, no-c-format
+msgid "-fcontract-build-level=[off|default|audit]\tSpecify max contract level to generate runtime checks for."
+msgstr ""
+
+#: c-family/c.opt:1782
+#, no-c-format
+msgid "-fcontract-strict-declarations=[on|off]\tEnable or disable warnings on generalized redeclaration of functions with contracts (default off)."
+msgstr ""
+
+#: c-family/c.opt:1786
+#, no-c-format
+msgid "-fcontract-mode=[on|off]\tEnable or disable all contract facilities (default on)."
+msgstr ""
+
+#: c-family/c.opt:1790
+#, no-c-format
+msgid "-fcontract-continuation-mode=[on|off]\tEnable or disable contract continuation mode (default off)."
+msgstr ""
+
+#: c-family/c.opt:1794
+#, no-c-format
+msgid "-fcontract-role=<name>:<semantics>\tSpecify the semantics for all levels in a role (default, review), or a custom contract role with given semantics (ex: opt:assume,assume,assume)."
+msgstr ""
+
+#: c-family/c.opt:1798
+#, no-c-format
+msgid "-fcontract-semantic=<level>:<semantic>\tSpecify the concrete semantics for level."
+msgstr ""
+
+#: c-family/c.opt:1802
+#, no-c-format
+msgid "Enable C++ coroutines (experimental)."
+msgstr ""
+
+#: c-family/c.opt:1806
+#, no-c-format
+msgid "Emit debug annotations during preprocessing."
+msgstr ""
+
+#: c-family/c.opt:1814
+#, no-c-format
+msgid "Factor complex constructors and destructors to favor space over speed."
+msgstr ""
+
+#: c-family/c.opt:1822
+#, no-c-format
+msgid "Print hierarchical comparisons when template types are mismatched."
+msgstr ""
+
+#: c-family/c.opt:1826
+#, no-c-format
+msgid "Note all candidates during overload resolution failure."
+msgstr ""
+
+#: c-family/c.opt:1830
+#, no-c-format
+msgid "Preprocess directives only."
+msgstr ""
+
+#: c-family/c.opt:1834
+#, no-c-format
+msgid "Permit '$' as an identifier character."
+msgstr ""
+
+#: c-family/c.opt:1838
+#, no-c-format
+msgid "-fmacro-prefix-map=<old>=<new>\tMap one directory name to another in __FILE__, __BASE_FILE__, and __builtin_FILE()."
+msgstr ""
+
+#: c-family/c.opt:1842
+#, no-c-format
+msgid "Write all declarations as Ada code transitively."
+msgstr ""
+
+#: c-family/c.opt:1846
+#, no-c-format
+msgid "Write all declarations as Ada code for the given file only."
+msgstr ""
+
+#: c-family/c.opt:1853
+#, no-c-format
+msgid "Do not elide common elements in template comparisons."
+msgstr ""
+
+#: c-family/c.opt:1857
+#, no-c-format
+msgid "Generate code to check exception specifications."
+msgstr ""
+
+#: c-family/c.opt:1864
+#, no-c-format
+msgid "-fexec-charset=<cset>\tConvert all strings and character constants to character set <cset>."
+msgstr ""
+
+#: c-family/c.opt:1868
+#, no-c-format
+msgid "Permit universal character names (\\u and \\U) in identifiers."
+msgstr ""
+
+#: c-family/c.opt:1872
+#, no-c-format
+msgid "-finput-charset=<cset>\tSpecify the default character set for source files."
+msgstr ""
+
+#: c-family/c.opt:1876
+#, no-c-format
+msgid "Support dynamic initialization of thread-local variables in a different translation unit."
+msgstr ""
+
+#: c-family/c.opt:1883
+#, no-c-format
+msgid "Fold calls to simple inline functions."
+msgstr ""
+
+#: c-family/c.opt:1890
+#, no-c-format
+msgid "Do not assume that standard C libraries and \"main\" exist."
+msgstr ""
+
+#: c-family/c.opt:1894
+#, no-c-format
+msgid "Recognize GNU-defined keywords."
+msgstr ""
+
+#: c-family/c.opt:1898
+#, no-c-format
+msgid "Generate code for GNU runtime environment."
+msgstr ""
+
+#: c-family/c.opt:1902
+#, no-c-format
+msgid "Use traditional GNU semantics for inline functions."
+msgstr ""
+
+#: c-family/c.opt:1915
+#, no-c-format
+msgid "Assume normal C execution environment."
+msgstr ""
+
+#: c-family/c.opt:1923
+#, no-c-format
+msgid "Implement P2564 for consteval propagation."
+msgstr ""
+
+#: c-family/c.opt:1927
+#, no-c-format
+msgid "Export functions even if they can be inlined."
+msgstr ""
+
+#: c-family/c.opt:1931
+#, no-c-format
+msgid "Make inline functions constexpr by default."
+msgstr ""
+
+#: c-family/c.opt:1935
+#, no-c-format
+msgid "Emit implicit instantiations of inline templates."
+msgstr ""
+
+#: c-family/c.opt:1939
+#, no-c-format
+msgid "Emit implicit instantiations of templates."
+msgstr ""
+
+#: c-family/c.opt:1943
+#, no-c-format
+msgid "Implement C++17 inheriting constructor semantics."
+msgstr ""
+
+#: c-family/c.opt:1950
+#, no-c-format
+msgid "Don't emit dllexported inline functions unless needed."
+msgstr ""
+
+#: c-family/c.opt:1957
+#, no-c-format
+msgid "Allow implicit conversions between vectors with differing numbers of subparts and/or differing element types."
+msgstr ""
+
+#: c-family/c.opt:1961
+#, no-c-format
+msgid "Enable C++ modules-ts (experimental)."
+msgstr ""
+
+#: c-family/c.opt:1969
+#, no-c-format
+msgid "Enable C++ header module (experimental)."
+msgstr ""
+
+#: c-family/c.opt:1976
+#, no-c-format
+msgid "Member functions defined within their class are inline in module purview."
+msgstr ""
+
+#: c-family/c.opt:1980
+#, no-c-format
+msgid "Only emit Compiled Module Interface."
+msgstr ""
+
+#: c-family/c.opt:1984
+#, no-c-format
+msgid "Mapper for module to CMI files."
+msgstr ""
+
+#: c-family/c.opt:1988
+#, no-c-format
+msgid "Enable lazy module importing."
+msgstr ""
+
+#: c-family/c.opt:1996
+#, no-c-format
+msgid "Warn about macros that have conflicting header units definitions."
+msgstr ""
+
+#: c-family/c.opt:2000
+#, no-c-format
+msgid "Warn if pointers of distinct types are compared without a cast."
+msgstr ""
+
+#: c-family/c.opt:2004
+#, no-c-format
+msgid "Note #include directives translated to import declarations."
+msgstr ""
+
+#: c-family/c.opt:2008
+#, no-c-format
+msgid "Note #include directives not translated to import declarations, and not known to be textual."
+msgstr ""
+
+#: c-family/c.opt:2012
+#, no-c-format
+msgid "Note a #include translation of a specific header."
+msgstr ""
+
+#: c-family/c.opt:2016
+#, no-c-format
+msgid "Note Compiled Module Interface pathnames."
+msgstr ""
+
+#: c-family/c.opt:2020
+#, no-c-format
+msgid "Note Compiled Module Interface pathname of a specific module or header-unit."
+msgstr ""
+
+#: c-family/c.opt:2024
+#, no-c-format
+msgid "fmax-include-depth=<number> Set the maximum depth of the nested #include."
+msgstr ""
+
+#: c-family/c.opt:2028
+#, no-c-format
+msgid "Don't warn about uses of Microsoft extensions."
+msgstr ""
+
+#: c-family/c.opt:2047
+#, no-c-format
+msgid "Implement resolution of DR 150 for matching of template template arguments."
+msgstr ""
+
+#: c-family/c.opt:2051
+#, no-c-format
+msgid "Generate code for NeXT (Apple macOS) runtime environment."
+msgstr ""
+
+#: c-family/c.opt:2055
+#, no-c-format
+msgid "Assume that receivers of Objective-C messages may be nil."
+msgstr ""
+
+#: c-family/c.opt:2059
+#, no-c-format
+msgid "Allow access to instance variables as if they were local declarations within instance method implementations."
+msgstr ""
+
+#: c-family/c.opt:2063
+#, no-c-format
+msgid "-fvisibility=[private|protected|public|package]\tSet the default symbol visibility."
+msgstr ""
+
+#: c-family/c.opt:2088
+#, no-c-format
+msgid "Treat a throw() exception specification as noexcept to improve code size."
+msgstr ""
+
+#: c-family/c.opt:2092
+#, no-c-format
+msgid "Specify which ABI to use for Objective-C family code and meta-data generation."
+msgstr ""
+
+#: c-family/c.opt:2098
+#, no-c-format
+msgid "Generate special Objective-C methods to initialize/destroy non-POD C++ ivars, if needed."
+msgstr ""
+
+#: c-family/c.opt:2102
+#, no-c-format
+msgid "Allow fast jumps to the message dispatcher."
+msgstr ""
+
+#: c-family/c.opt:2108
+#, no-c-format
+msgid "Enable Objective-C exception and synchronization syntax."
+msgstr ""
+
+#: c-family/c.opt:2112
+#, no-c-format
+msgid "Enable garbage collection (GC) in Objective-C/Objective-C++ programs."
+msgstr ""
+
+#: c-family/c.opt:2116
+#, no-c-format
+msgid "Enable inline checks for nil receivers with the NeXT runtime and ABI version 2."
+msgstr ""
+
+#: c-family/c.opt:2121
+#, no-c-format
+msgid "Enable Objective-C setjmp exception handling runtime."
+msgstr ""
+
+#: c-family/c.opt:2125
+#, no-c-format
+msgid "Conform to the Objective-C 1.0 language as implemented in GCC 4.0."
+msgstr ""
+
+#: c-family/c.opt:2129
+#, no-c-format
+msgid "Enable OpenACC."
+msgstr ""
+
+#: c-family/c.opt:2133
+#, no-c-format
+msgid "Specify default OpenACC compute dimensions."
+msgstr ""
+
+#: c-family/c.opt:2137
+#, no-c-format
+msgid "Enable OpenMP (implies -frecursive in Fortran)."
+msgstr ""
+
+#: c-family/c.opt:2141
+#, no-c-format
+msgid "Enable OpenMP's SIMD directives."
+msgstr ""
+
+#: c-family/c.opt:2145
+#, no-c-format
+msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
+msgstr ""
+
+#: c-family/c.opt:2156
+#, no-c-format
+msgid "Look for and use PCH files even when preprocessing."
+msgstr ""
+
+#: c-family/c.opt:2160
+#, no-c-format
+msgid "Downgrade conformance errors to warnings."
+msgstr ""
+
+#: c-family/c.opt:2164
+#, no-c-format
+msgid "Enable Plan 9 language extensions."
+msgstr ""
+
+#: c-family/c.opt:2168
+#, no-c-format
+msgid "Treat the input file as already preprocessed."
+msgstr ""
+
+#: c-family/c.opt:2176
+#, no-c-format
+msgid "-ftrack-macro-expansion=<0|1|2>\tTrack locations of tokens coming from macro expansion and display them in error messages."
+msgstr ""
+
+#: c-family/c.opt:2180
+#, no-c-format
+msgid "Do not pretty-print template specializations as the template signature followed by the arguments."
+msgstr ""
+
+#: c-family/c.opt:2184
+#, no-c-format
+msgid "Treat known sprintf return values as constants."
+msgstr ""
+
+#: c-family/c.opt:2188
+#, no-c-format
+msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
+msgstr ""
+
+#: c-family/c.opt:2192
+#, no-c-format
+msgid "Removed in GCC 10.  This switch has no effect."
+msgstr ""
+
+#: c-family/c.opt:2196
+#, no-c-format
+msgid "Generate run time type descriptor information."
+msgstr ""
+
+#: c-family/c.opt:2200 ada/gcc-interface/lang.opt:81
+#, no-c-format
+msgid "Use the narrowest integer type possible for enumeration types."
+msgstr ""
+
+#: c-family/c.opt:2204
+#, no-c-format
+msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
+msgstr ""
+
+#: c-family/c.opt:2208
+#, no-c-format
+msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
+msgstr ""
+
+#: c-family/c.opt:2212 ada/gcc-interface/lang.opt:85
+#, no-c-format
+msgid "Make \"char\" signed by default."
+msgstr ""
+
+#: c-family/c.opt:2216
+#, no-c-format
+msgid "Enable C++14 sized deallocation support."
+msgstr ""
+
+#: c-family/c.opt:2223
+#, no-c-format
+msgid "-fstrict-flex-arrays=<level>    Control when to treat the trailing array of a structure as a flexible array member for the purposes of accessing the elements of such an array. The default is treating all trailing arrays of structures as flexible array members."
+msgstr ""
+
+#: c-family/c.opt:2230
+#, no-c-format
+msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
+msgstr ""
+
+#: c-family/c.opt:2246
+#, no-c-format
+msgid "Display statistics accumulated during compilation."
+msgstr ""
+
+#: c-family/c.opt:2250
+#, no-c-format
+msgid "Assume that values of enumeration type are always within the minimum range of that type."
+msgstr ""
+
+#: c-family/c.opt:2257 c-family/c.opt:2262
+#, no-c-format
+msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
+msgstr ""
+
+#: c-family/c.opt:2279
+#, no-c-format
+msgid "Set the maximum number of template instantiation notes for a single warning or error."
+msgstr ""
+
+#: c-family/c.opt:2286
+#, no-c-format
+msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
+msgstr ""
+
+#: c-family/c.opt:2293
+#, no-c-format
+msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
+msgstr ""
+
+#: c-family/c.opt:2297
+#, no-c-format
+msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
+msgstr ""
+
+#: c-family/c.opt:2301 ada/gcc-interface/lang.opt:89
+#, no-c-format
+msgid "Make \"char\" unsigned by default."
+msgstr ""
+
+#: c-family/c.opt:2305
+#, no-c-format
+msgid "Use __cxa_atexit to register destructors."
+msgstr ""
+
+#: c-family/c.opt:2309
+#, no-c-format
+msgid "Use __cxa_get_exception_ptr in exception handling."
+msgstr ""
+
+#: c-family/c.opt:2313
+#, no-c-format
+msgid "Marks all inlined functions and methods as having hidden visibility."
+msgstr ""
+
+#: c-family/c.opt:2317
+#, no-c-format
+msgid "Changes visibility to match Microsoft Visual Studio by default."
+msgstr ""
+
+#: c-family/c.opt:2329
+#, no-c-format
+msgid "Emit common-like symbols as weak symbols."
+msgstr ""
+
+#: c-family/c.opt:2333
+#, no-c-format
+msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
+msgstr ""
+
+#: c-family/c.opt:2337
+#, no-c-format
+msgid "Generate a #line directive pointing at the current working directory."
+msgstr ""
+
+#: c-family/c.opt:2345
+#, no-c-format
+msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
+msgstr ""
+
+#: c-family/c.opt:2349
+#, no-c-format
+msgid "Dump declarations to a .decl file."
+msgstr ""
+
+#: c-family/c.opt:2353
+#, no-c-format
+msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
+msgstr ""
+
+#: c-family/c.opt:2357
+#, no-c-format
+msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
+msgstr ""
+
+#: c-family/c.opt:2361
+#, no-c-format
+msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
+msgstr ""
+
+#: c-family/c.opt:2365
+#, no-c-format
+msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
+msgstr ""
+
+#: c-family/c.opt:2370
+#, no-c-format
+msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
+msgstr ""
+
+#: c-family/c.opt:2374
+#, no-c-format
+msgid "-imacros <file>\tAccept definition of macros in <file>."
+msgstr ""
+
+#: c-family/c.opt:2378
+#, no-c-format
+msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
+msgstr ""
+
+#: c-family/c.opt:2382
+#, no-c-format
+msgid "-include <file>\tInclude the contents of <file> before other files."
+msgstr ""
+
+#: c-family/c.opt:2386
+#, no-c-format
+msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
+msgstr ""
+
+#: c-family/c.opt:2390
+#, no-c-format
+msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
+msgstr ""
+
+#: c-family/c.opt:2394
+#, no-c-format
+msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
+msgstr ""
+
+#: c-family/c.opt:2398
+#, no-c-format
+msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
+msgstr ""
+
+#: c-family/c.opt:2402
+#, no-c-format
+msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
+msgstr ""
+
+#: c-family/c.opt:2406
+#, no-c-format
+msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
+msgstr ""
+
+#: c-family/c.opt:2416
+#, no-c-format
+msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
+msgstr ""
+
+#: c-family/c.opt:2420
+#, no-c-format
+msgid "Do not search standard system include directories for C++."
+msgstr ""
+
+#: c-family/c.opt:2432
+#, no-c-format
+msgid "Generate C header of platform-specific features."
+msgstr ""
+
+#: c-family/c.opt:2436
+#, no-c-format
+msgid "Remap file names when including files."
+msgstr ""
+
+#: c-family/c.opt:2440 c-family/c.opt:2444
+#, no-c-format
+msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
+msgstr ""
+
+#: c-family/c.opt:2448
+#, no-c-format
+msgid "Conform to the ISO 2011 C++ standard."
+msgstr ""
+
+#: c-family/c.opt:2452
+#, no-c-format
+msgid "Deprecated in favor of -std=c++11."
+msgstr ""
+
+#: c-family/c.opt:2456
+#, no-c-format
+msgid "Deprecated in favor of -std=c++14."
+msgstr ""
+
+#: c-family/c.opt:2460
+#, no-c-format
+msgid "Conform to the ISO 2014 C++ standard."
+msgstr ""
+
+#: c-family/c.opt:2464
+#, no-c-format
+msgid "Deprecated in favor of -std=c++17."
+msgstr ""
+
+#: c-family/c.opt:2468
+#, no-c-format
+msgid "Conform to the ISO 2017 C++ standard."
+msgstr ""
+
+#: c-family/c.opt:2472 c-family/c.opt:2476
+#, no-c-format
+msgid "Conform to the ISO 2020 C++ standard (experimental and incomplete support)."
+msgstr ""
+
+#: c-family/c.opt:2480 c-family/c.opt:2484
+#, no-c-format
+msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
+msgstr ""
+
+#: c-family/c.opt:2488 c-family/c.opt:2492
+#, no-c-format
+msgid "Conform to the ISO 2026 C++ draft standard (experimental and incomplete support)."
+msgstr ""
+
+#: c-family/c.opt:2496 c-family/c.opt:2650
+#, no-c-format
+msgid "Conform to the ISO 2011 C standard."
+msgstr ""
+
+#: c-family/c.opt:2500
+#, no-c-format
+msgid "Deprecated in favor of -std=c11."
+msgstr ""
+
+#: c-family/c.opt:2504 c-family/c.opt:2508 c-family/c.opt:2654
+#: c-family/c.opt:2658
+#, no-c-format
+msgid "Conform to the ISO 2017 C standard (published in 2018)."
+msgstr ""
+
+#: c-family/c.opt:2512 c-family/c.opt:2662
+#, no-c-format
+msgid "Conform to the ISO 2023 C standard draft (expected to be published in 2024) (experimental and incomplete support)."
+msgstr ""
+
+#: c-family/c.opt:2516
+#, no-c-format
+msgid "Deprecated in favor of -std=c23."
+msgstr ""
+
+#: c-family/c.opt:2520 c-family/c.opt:2524 c-family/c.opt:2634
+#, no-c-format
+msgid "Conform to the ISO 1990 C standard."
+msgstr ""
+
+#: c-family/c.opt:2528 c-family/c.opt:2642
+#, no-c-format
+msgid "Conform to the ISO 1999 C standard."
+msgstr ""
+
+#: c-family/c.opt:2532
+#, no-c-format
+msgid "Deprecated in favor of -std=c99."
+msgstr ""
+
+#: c-family/c.opt:2536 c-family/c.opt:2541
+#, no-c-format
+msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
+msgstr ""
+
+#: c-family/c.opt:2546
+#, no-c-format
+msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
+msgstr ""
+
+#: c-family/c.opt:2550
+#, no-c-format
+msgid "Deprecated in favor of -std=gnu++11."
+msgstr ""
+
+#: c-family/c.opt:2554
+#, no-c-format
+msgid "Deprecated in favor of -std=gnu++14."
+msgstr ""
+
+#: c-family/c.opt:2558
+#, no-c-format
+msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
+msgstr ""
+
+#: c-family/c.opt:2562
+#, no-c-format
+msgid "Deprecated in favor of -std=gnu++17."
+msgstr ""
+
+#: c-family/c.opt:2566
+#, no-c-format
+msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
+msgstr ""
+
+#: c-family/c.opt:2570 c-family/c.opt:2574
+#, no-c-format
+msgid "Conform to the ISO 2020 C++ standard with GNU extensions (experimental and incomplete support)."
+msgstr ""
+
+#: c-family/c.opt:2578 c-family/c.opt:2582
+#, no-c-format
+msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
+msgstr ""
+
+#: c-family/c.opt:2586 c-family/c.opt:2590
+#, no-c-format
+msgid "Conform to the ISO 2026 C++ draft standard with GNU extensions (experimental and incomplete support)."
+msgstr ""
+
+#: c-family/c.opt:2594
+#, no-c-format
+msgid "Conform to the ISO 2011 C standard with GNU extensions."
+msgstr ""
+
+#: c-family/c.opt:2598
+#, no-c-format
+msgid "Deprecated in favor of -std=gnu11."
+msgstr ""
+
+#: c-family/c.opt:2602 c-family/c.opt:2606
+#, no-c-format
+msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extensions."
+msgstr ""
+
+#: c-family/c.opt:2610
+#, no-c-format
+msgid "Conform to the ISO 2023 C standard draft (expected to be published in 2024) with GNU extensions (experimental and incomplete support)."
+msgstr ""
+
+#: c-family/c.opt:2614
+#, no-c-format
+msgid "Deprecated in favor of -std=gnu23."
+msgstr ""
+
+#: c-family/c.opt:2618 c-family/c.opt:2622
+#, no-c-format
+msgid "Conform to the ISO 1990 C standard with GNU extensions."
+msgstr ""
+
+#: c-family/c.opt:2626
+#, no-c-format
+msgid "Conform to the ISO 1999 C standard with GNU extensions."
+msgstr ""
+
+#: c-family/c.opt:2630
+#, no-c-format
+msgid "Deprecated in favor of -std=gnu99."
+msgstr ""
+
+#: c-family/c.opt:2638
+#, no-c-format
+msgid "Conform to the ISO 1990 C standard as amended in 1994."
+msgstr ""
+
+#: c-family/c.opt:2646
+#, no-c-format
+msgid "Deprecated in favor of -std=iso9899:1999."
+msgstr ""
+
+#: c-family/c.opt:2666
+#, no-c-format
+msgid "-stdlib=[libstdc++|libc++]\tThe standard library to be used for C++ headers and runtime."
+msgstr ""
+
+#: c-family/c.opt:2683
+#, no-c-format
+msgid "Enable traditional preprocessing."
+msgstr ""
+
+#: c-family/c.opt:2687
+#, no-c-format
+msgid "-trigraphs\tSupport ISO C trigraphs."
+msgstr ""
+
+#: c-family/c.opt:2691
+#, no-c-format
+msgid "Do not predefine system-specific and GCC-specific macros."
+msgstr ""
+
+#: ada/gcc-interface/lang.opt:61
+#, no-c-format
+msgid "Dump Source Coverage Obligations."
+msgstr ""
+
+#: ada/gcc-interface/lang.opt:65
+#, no-c-format
+msgid "Synonym of -gnatk8."
+msgstr ""
+
+#: ada/gcc-interface/lang.opt:73
+#, no-c-format
+msgid "Do not look for object files in standard path."
+msgstr ""
+
+#: ada/gcc-interface/lang.opt:77
+#, no-c-format
+msgid "Select the runtime."
+msgstr ""
+
+#: ada/gcc-interface/lang.opt:93
+#, no-c-format
+msgid "Catch typos."
+msgstr ""
+
+#: ada/gcc-interface/lang.opt:97
+#, no-c-format
+msgid "Set name of output ALI file (internal switch)."
+msgstr ""
+
+#: ada/gcc-interface/lang.opt:101
+#, no-c-format
+msgid "-gnat<options>\tSpecify options to GNAT."
+msgstr ""
+
+#: ada/gcc-interface/lang.opt:105
+#, no-c-format
+msgid "Ignored."
+msgstr "იგნორირებულია."
+
+#: d/lang.opt:51
+#, no-c-format
+msgid "-Hd <dir>\tWrite D interface files to directory <dir>."
+msgstr ""
+
+#: d/lang.opt:55
+#, no-c-format
+msgid "-Hf <file>\tWrite D interface to <file>."
+msgstr ""
+
+#: d/lang.opt:127
+#, no-c-format
+msgid "Warn about casts that will produce a null result."
+msgstr ""
+
+#: d/lang.opt:143
+#, no-c-format
+msgid "Warn when a special enum is declared with the wrong base type."
+msgstr ""
+
+#: d/lang.opt:151
+#, no-c-format
+msgid "Warn from speculative compiles such as __traits(compiles)."
+msgstr ""
+
+#: d/lang.opt:163
+#, no-c-format
+msgid "Generate JSON file."
+msgstr ""
+
+#: d/lang.opt:167
+#, no-c-format
+msgid "-Xf <file>\tWrite JSON output to the given <file>."
+msgstr ""
+
+#: d/lang.opt:171
+#, no-c-format
+msgid "Debug library to use instead of phobos."
+msgstr ""
+
+#: d/lang.opt:175
+#, no-c-format
+msgid "Default library to use instead of phobos."
+msgstr ""
+
+#: d/lang.opt:179
+#, no-c-format
+msgid "Do link the standard D startup files in the compilation."
+msgstr ""
+
+#: d/lang.opt:186
+#, no-c-format
+msgid "Generate code for all template instantiations."
+msgstr ""
+
+#: d/lang.opt:190
+#, no-c-format
+msgid "Generate code for assert contracts."
+msgstr ""
+
+#: d/lang.opt:198
+#, no-c-format
+msgid "-fbounds-check=[on|safeonly|off]\tTurn array bounds checks on, in @safe code only, or off."
+msgstr ""
+
+#: d/lang.opt:240
+#, no-c-format
+msgid "-fcheckaction=[throw,halt,context]\tBehavior on contract failure."
+msgstr ""
+
+#: d/lang.opt:256
+#, no-c-format
+msgid "Compile in debug code."
+msgstr ""
+
+#: d/lang.opt:260
+#, no-c-format
+msgid "-fdebug=<ident>\tCompile in debug code identified by <ident>."
+msgstr ""
+
+#: d/lang.opt:264
+#, no-c-format
+msgid "Generate documentation."
+msgstr ""
+
+#: d/lang.opt:268
+#, no-c-format
+msgid "-fdoc-dir=<dir>\tWrite documentation file to directory <dir>."
+msgstr ""
+
+#: d/lang.opt:272
+#, no-c-format
+msgid "-fdoc-file=<file>\tWrite documentation to <file>."
+msgstr ""
+
+#: d/lang.opt:276
+#, no-c-format
+msgid "-fdoc-inc=<file>\tInclude a Ddoc macro <file>."
+msgstr ""
+
+#: d/lang.opt:280
+#, no-c-format
+msgid "Assume that standard D runtime libraries and \"D main\" exist."
+msgstr ""
+
+#: d/lang.opt:284
+#, no-c-format
+msgid "Add comments for ignored declarations in the generated C++ header."
+msgstr ""
+
+#: d/lang.opt:288
+#, no-c-format
+msgid "-fdump-cxx-spec=<filename>\tWrite all declarations as C++ code to <filename>."
+msgstr ""
+
+#: d/lang.opt:292
+#, no-c-format
+msgid "Display the frontend AST after parsing and semantic passes."
+msgstr ""
+
+#: d/lang.opt:300
+#, no-c-format
+msgid "-fextern-std=<standard>\tSet C++ name mangling compatibility with <standard>."
+msgstr ""
+
+#: d/lang.opt:325
+#, no-c-format
+msgid "Ignore unsupported pragmas."
+msgstr ""
+
+#: d/lang.opt:329
+#, no-c-format
+msgid "Generate code for class invariant contracts."
+msgstr ""
+
+#: d/lang.opt:333
+#, no-c-format
+msgid "Generate a default D main() function when compiling."
+msgstr ""
+
+#: d/lang.opt:337
+#, no-c-format
+msgid "-fmodule-file=<package.module>=<filespec>\tuse <filespec> as source file for <package.module>."
+msgstr ""
+
+#: d/lang.opt:341
+#, no-c-format
+msgid "Generate ModuleInfo struct for output module."
+msgstr ""
+
+#: d/lang.opt:345
+#, no-c-format
+msgid "Process all modules specified on the command line, but only generate code for the module specified by the argument."
+msgstr ""
+
+#: d/lang.opt:349
+#, no-c-format
+msgid "Generate code for postcondition contracts."
+msgstr ""
+
+#: d/lang.opt:353
+#, no-c-format
+msgid "Generate code for precondition contracts."
+msgstr ""
+
+#: d/lang.opt:357
+#, no-c-format
+msgid "Turn on all upcoming D language features."
+msgstr ""
+
+#: d/lang.opt:361
+#, no-c-format
+msgid "Implement D bit-fields."
+msgstr ""
+
+#: d/lang.opt:365
+#, no-c-format
+msgid "Implement DIP1000: Scoped pointers."
+msgstr ""
+
+#: d/lang.opt:369
+#, no-c-format
+msgid "Implement DIP1008: Allow exceptions in @nogc code."
+msgstr ""
+
+#: d/lang.opt:373
+#, no-c-format
+msgid "Implement DIP1021: Mutable function arguments."
+msgstr ""
+
+#: d/lang.opt:377
+#, no-c-format
+msgid "Destruct fields of partially constructed objects."
+msgstr ""
+
+#: d/lang.opt:381
+#, no-c-format
+msgid "Use field-wise comparisons for struct equality."
+msgstr ""
+
+#: d/lang.opt:385
+#, no-c-format
+msgid "When a symbol is resolved, check `alias this' scope before going to upper scopes."
+msgstr ""
+
+#: d/lang.opt:389
+#, no-c-format
+msgid "Disallow unsound immutable conversions that were formerly incorrectly permitted."
+msgstr ""
+
+#: d/lang.opt:393
+#, no-c-format
+msgid "Implement 'in' parameters to mean scope const."
+msgstr ""
+
+#: d/lang.opt:397
+#, no-c-format
+msgid "Implement 'in' contracts of overridden methods to be a superset of parent contract."
+msgstr ""
+
+#: d/lang.opt:401
+#, no-c-format
+msgid "Disable access to shared memory objects."
+msgstr ""
+
+#: d/lang.opt:405
+#, no-c-format
+msgid "Enable rvalue arguments to ref parameters."
+msgstr ""
+
+#: d/lang.opt:409
+#, no-c-format
+msgid "Disable access to variables marked `@system' from @safe code."
+msgstr ""
+
+#: d/lang.opt:413
+#, no-c-format
+msgid "Compile release version."
+msgstr ""
+
+#: d/lang.opt:417
+#, no-c-format
+msgid "Turn off all revertable D language features."
+msgstr ""
+
+#: d/lang.opt:421
+#, no-c-format
+msgid "Revert DIP1000: Scoped pointers."
+msgstr ""
+
+#: d/lang.opt:425
+#, no-c-format
+msgid "Don't destruct fields of partially constructed objects."
+msgstr ""
+
+#: d/lang.opt:429
+#, no-c-format
+msgid "Don't use C-style integral promotion for unary '+', '-' and '~'."
+msgstr ""
+
+#: d/lang.opt:437
+#, no-c-format
+msgid "-fsave-mixins=<filename>\tExpand and save mixins to file specified by <filename>."
+msgstr ""
+
+#: d/lang.opt:441
+#, no-c-format
+msgid "Generate code for switches without a default case."
+msgstr ""
+
+#: d/lang.opt:445
+#, no-c-format
+msgid "List information on all D language transitions."
+msgstr ""
+
+#: d/lang.opt:449
+#, no-c-format
+msgid "List all non-mutable fields which occupy an object instance."
+msgstr ""
+
+#: d/lang.opt:453
+#, no-c-format
+msgid "List all usages of 'in' on parameter."
+msgstr ""
+
+#: d/lang.opt:457
+#, no-c-format
+msgid "List all hidden GC allocations."
+msgstr ""
+
+#: d/lang.opt:461
+#, no-c-format
+msgid "List statistics on template instantiations."
+msgstr ""
+
+#: d/lang.opt:465
+#, no-c-format
+msgid "List all variables going into thread local storage."
+msgstr ""
+
+#: d/lang.opt:469
+#, no-c-format
+msgid "Compile in unittest code."
+msgstr ""
+
+#: d/lang.opt:473
+#, no-c-format
+msgid "-fversion=<ident>\tCompile in version code identified by <ident>."
+msgstr ""
+
+#: d/lang.opt:477
+#, no-c-format
+msgid "Emit template instantiations as weak symbols."
+msgstr ""
+
+#: d/lang.opt:497
+#, no-c-format
+msgid "Do not link the standard D library in the compilation."
+msgstr ""
+
+#: d/lang.opt:505
+#, no-c-format
+msgid "Link the standard D library statically in the compilation."
+msgstr ""
+
+#: d/lang.opt:509
+#, no-c-format
+msgid "Link the standard D library dynamically in the compilation."
+msgstr ""
+
+#: m2/lang.opt:35
+#, no-c-format
+msgid "turns on case statement label compile time checking when using an expression of an enum type."
+msgstr ""
+
+#: m2/lang.opt:39
+#, no-c-format
+msgid "compiler checks to force definition module procedure parameter names with their implementation module counterpart"
+msgstr ""
+
+#: m2/lang.opt:43
+#, no-c-format
+msgid "compiler warns if a cast is being used on types of differing sizes"
+msgstr ""
+
+#: m2/lang.opt:47
+#, no-c-format
+msgid "inform user which parameters will be passed by reference"
+msgstr ""
+
+#: m2/lang.opt:51
+#, no-c-format
+msgid "extra compile time semantic checking, typically tries to catch poor programming style"
+msgstr ""
+
+#: m2/lang.opt:55
+#, no-c-format
+msgid "turns on compile time analysis in the first basic block of a procedure detecting access to uninitialized data."
+msgstr ""
+
+#: m2/lang.opt:59
+#, no-c-format
+msgid "turns on compile time analysis to detect access to uninitialized variables, the checking can be specified by: known,cond,all."
+msgstr ""
+
+#: m2/lang.opt:63
+#, no-c-format
+msgid "automatically initializes all pointers to NIL"
+msgstr ""
+
+#: m2/lang.opt:67
+#, no-c-format
+msgid "turns on runtime subrange, array index and indirection via NIL pointer checking"
+msgstr ""
+
+#: m2/lang.opt:71
+#, no-c-format
+msgid "turns on runtime checking to check whether a CASE statement requires an ELSE clause when one was not specified"
+msgstr ""
+
+#: m2/lang.opt:75
+#, no-c-format
+msgid "use cpp to preprocess the module"
+msgstr ""
+
+#: m2/lang.opt:79 m2/lang.opt:83
+#, no-c-format
+msgid "passed to the preprocessor if -fcpp is used (internal switch)"
+msgstr ""
+
+#: m2/lang.opt:87
+#, no-c-format
+msgid "call a real function, rather than the builtin equivalent"
+msgstr ""
+
+#: m2/lang.opt:91
+#, no-c-format
+msgid "turn on internal debugging of the compiler (internal switch)"
+msgstr ""
+
+#: m2/lang.opt:95
+#, no-c-format
+msgid "turn on tracing of procedure line numbers (internal switch)"
+msgstr ""
+
+#: m2/lang.opt:99
+#, no-c-format
+msgid "recognize the specified suffix as a definition module filename"
+msgstr ""
+
+#: m2/lang.opt:103
+#, no-c-format
+msgid "display all inbuilt system items"
+msgstr ""
+
+#: m2/lang.opt:107
+#, no-c-format
+msgid "allows opaque types to be implemented as any type (a GNU Modula-2 extension)"
+msgstr ""
+
+#: m2/lang.opt:111
+#, no-c-format
+msgid "turns on runtime checking to check whether a floating point number will exceed range"
+msgstr ""
+
+#: m2/lang.opt:115
+#, no-c-format
+msgid "create a topologically sorted module list from all dependent modules used in the application"
+msgstr ""
+
+#: m2/lang.opt:119 m2/lang.opt:211
+#, no-c-format
+msgid "turns on all range checking for numerical values"
+msgstr ""
+
+#: m2/lang.opt:123
+#, no-c-format
+msgid "use ISO dialect of Modula-2"
+msgstr ""
+
+#: m2/lang.opt:127
+#, no-c-format
+msgid "specify the library order, the libraries may be specified by a comma separated abbreviation: log,min,pim,iso or by directory names: m2log,m2min,m2pim,m2iso."
+msgstr ""
+
+#: m2/lang.opt:131
+#, no-c-format
+msgid "set all location values to a specific value (internal switch)"
+msgstr ""
+
+#: m2/lang.opt:135
+#, no-c-format
+msgid "turn on internal debug tracing for quad,token,line,all (internal switch)"
+msgstr ""
+
+#: m2/lang.opt:139
+#, no-c-format
+msgid "generate extra nops to improve debugging, producing an instruction for every code related keyword"
+msgstr ""
+
+#: m2/lang.opt:143
+#, no-c-format
+msgid "generate error messages which render keywords in lower case"
+msgstr ""
+
+#: m2/lang.opt:147
+#, no-c-format
+msgid "specify the module mangled prefix name for all modules in the following include paths"
+msgstr ""
+
+#: m2/lang.opt:155
+#, no-c-format
+msgid "insert plugin to identify runtime errors at compiletime"
+msgstr ""
+
+#: m2/lang.opt:159
+#, no-c-format
+msgid "specify the module mangled prefix name"
+msgstr ""
+
+#: m2/lang.opt:163
+#, no-c-format
+msgid "display statistics about the amount of source lines compiled and symbols used"
+msgstr ""
+
+#: m2/lang.opt:167
+#, no-c-format
+msgid "experimental flag to turn on the new strict type checker"
+msgstr ""
+
+#: m2/lang.opt:171
+#, no-c-format
+msgid "compile all implementation modules and program module at once"
+msgstr ""
+
+#: m2/lang.opt:175
+#, no-c-format
+msgid "recognize the specified suffix as implementation and module filenames"
+msgstr ""
+
+#: m2/lang.opt:179
+#, no-c-format
+msgid "turns on runtime checking to detect accessing data through a NIL value pointer"
+msgstr ""
+
+#: m2/lang.opt:183
+#, no-c-format
+msgid "use PIM [234] dialect of Modula-2"
+msgstr ""
+
+#: m2/lang.opt:187
+#, no-c-format
+msgid "use PIM 2 dialect of Modula-2"
+msgstr ""
+
+#: m2/lang.opt:191
+#, no-c-format
+msgid "use PIM 3 dialect of Modula-2"
+msgstr ""
+
+#: m2/lang.opt:195
+#, no-c-format
+msgid "use PIM 4 dialect of Modula-2"
+msgstr ""
+
+#: m2/lang.opt:199
+#, no-c-format
+msgid "force positive result from MOD and DIV result floor"
+msgstr ""
+
+#: m2/lang.opt:203
+#, no-c-format
+msgid "link against the pthread library (default on)"
+msgstr ""
+
+#: m2/lang.opt:207
+#, no-c-format
+msgid "internal compiler debugging information, dump the list of quadruples"
+msgstr ""
+
+#: m2/lang.opt:215
+#, no-c-format
+msgid "turns on runtime checking for functions which finish without executing a RETURN statement"
+msgstr ""
+
+#: m2/lang.opt:219
+#, no-c-format
+msgid "specify the list of runtime modules and their initialization order"
+msgstr ""
+
+#: m2/lang.opt:223
+#, no-c-format
+msgid "the modules initialization order is dynamically determined by M2RTS and application dependencies"
+msgstr ""
+
+#: m2/lang.opt:227
+#, no-c-format
+msgid "generate a C source scaffold for the current module being compiled"
+msgstr ""
+
+#: m2/lang.opt:231
+#, no-c-format
+msgid "generate a C++ source scaffold for the current module being compiled"
+msgstr ""
+
+#: m2/lang.opt:235
+#, no-c-format
+msgid "generate the main function"
+msgstr ""
+
+#: m2/lang.opt:239
+#, no-c-format
+msgid "generate static scaffold initialization and finalization for every module inside main"
+msgstr ""
+
+#: m2/lang.opt:243
+#, no-c-format
+msgid "generate a shared library from the module"
+msgstr ""
+
+#: m2/lang.opt:247
+#, no-c-format
+msgid "turns on all software runtime checking (an abbreviation for -fnil -frange -findex -fwholediv -fcase -freturn -fwholevalue -ffloatvalue)"
+msgstr ""
+
+#: m2/lang.opt:251
+#, no-c-format
+msgid "display the location of module source files as they are compiled"
+msgstr ""
+
+#: m2/lang.opt:255
+#, no-c-format
+msgid "create a swig interface file for the module"
+msgstr ""
+
+#: m2/lang.opt:259
+#, no-c-format
+msgid "optimize non var unbounded parameters by passing it by reference, providing it is not written to within the callee procedure."
+msgstr ""
+
+#: m2/lang.opt:263
+#, no-c-format
+msgid "orders the initialization/finalizations for scaffold-static or force linking of modules if scaffold-dynamic"
+msgstr ""
+
+#: m2/lang.opt:271
+#, no-c-format
+msgid "turns on all division and modulus by zero checking for ordinal values"
+msgstr ""
+
+#: m2/lang.opt:275
+#, no-c-format
+msgid "turns on runtime checking to check whether a whole number will exceed range"
+msgstr ""
+
+#: m2/lang.opt:279
+#, no-c-format
+msgid "Link the standard Modula-2 libraries statically in the compilation."
+msgstr ""
+
+#: m2/lang.opt:424 m2/lang.opt:428
+#, no-c-format
+msgid "save temporary preprocessed files"
+msgstr ""
+
+#: go/lang.opt:42
+#, no-c-format
+msgid "-fgo-c-header=<file>\tWrite Go struct definitions to file as C code."
+msgstr ""
+
+#: go/lang.opt:46
+#, no-c-format
+msgid "Add explicit checks for division by zero."
+msgstr ""
+
+#: go/lang.opt:50
+#, no-c-format
+msgid "Add explicit checks for division overflow in INT_MIN / -1."
+msgstr ""
+
+#: go/lang.opt:54
+#, no-c-format
+msgid "Apply special rules for compiling runtime package."
+msgstr ""
+
+#: go/lang.opt:58
+#, no-c-format
+msgid "-fgo-dump-<type>\tDump Go frontend internal information."
+msgstr ""
+
+#: go/lang.opt:62
+#, no-c-format
+msgid "-fgo-embedcfg=<file>\tList embedded files via go:embed."
+msgstr ""
+
+#: go/lang.opt:66
+#, no-c-format
+msgid "-fgo-importcfg=<file>\tProvide file that tells where to find imports."
+msgstr ""
+
+#: go/lang.opt:70
+#, no-c-format
+msgid "-fgo-optimize-<type>\tTurn on optimization passes in the frontend."
+msgstr ""
+
+#: go/lang.opt:74
+#, no-c-format
+msgid "-fgo-pkgpath=<string>\tSet Go package path."
+msgstr ""
+
+#: go/lang.opt:78
+#, no-c-format
+msgid "-fgo-prefix=<string>\tSet package-specific prefix for exported Go names."
+msgstr ""
+
+#: go/lang.opt:82
+#, no-c-format
+msgid "-fgo-relative-import-path=<path>\tTreat a relative import as relative to path."
+msgstr ""
+
+#: go/lang.opt:86
+#, no-c-format
+msgid "Functions which return values must end with return statements."
+msgstr ""
+
+#: go/lang.opt:90
+#, no-c-format
+msgid "Emit debugging information related to the escape analysis pass when run with -fgo-optimize-allocs."
+msgstr ""
+
+#: go/lang.opt:94
+#, no-c-format
+msgid "-fgo-debug-escape-hash=<string>\tHash value to debug escape analysis."
+msgstr ""
+
+#: go/lang.opt:98
+#, no-c-format
+msgid "Emit optimization diagnostics."
+msgstr ""
+
+#: analyzer/analyzer.opt:27
+#, no-c-format
+msgid "The maximum number of 'after supernode' exploded nodes within the analyzer per supernode, before terminating analysis."
+msgstr ""
+
+#: analyzer/analyzer.opt:31
+#, no-c-format
+msgid "The maximum number of exploded nodes per program point within the analyzer, before terminating analysis of that point."
+msgstr ""
+
+#: analyzer/analyzer.opt:35
+#, no-c-format
+msgid "The maximum number of constraints per state."
+msgstr ""
+
+#: analyzer/analyzer.opt:39
+#, no-c-format
+msgid "The maximum number of infeasible edges to reject before declaring a diagnostic as infeasible."
+msgstr ""
+
+#: analyzer/analyzer.opt:43
+#, no-c-format
+msgid "The maximum number of times a callsite can appear in a call stack within the analyzer, before terminating analysis of a call that would recurse deeper."
+msgstr ""
+
+#: analyzer/analyzer.opt:47
+#, no-c-format
+msgid "The maximum depth of a symbolic value, before approximating the value as unknown."
+msgstr ""
+
+#: analyzer/analyzer.opt:51
+#, no-c-format
+msgid "The minimum number of supernodes within a function for the analyzer to consider summarizing its effects at call sites."
+msgstr ""
+
+#: analyzer/analyzer.opt:55
+#, no-c-format
+msgid "The maximum depth of exploded nodes that should appear in a dot dump before switching to a less verbose format."
+msgstr ""
+
+#: analyzer/analyzer.opt:59
+#, no-c-format
+msgid "The number of bytes at which to ellipsize string literals in analyzer text art diagrams."
+msgstr ""
+
+#: analyzer/analyzer.opt:63
+#, no-c-format
+msgid "The number of literal bytes to show at the head of a string literal in text art when ellipsizing it."
+msgstr ""
+
+#: analyzer/analyzer.opt:67
+#, no-c-format
+msgid "The number of literal bytes to show at the tail of a string literal in text art when ellipsizing it."
+msgstr ""
+
+#: analyzer/analyzer.opt:71
+#, no-c-format
+msgid "The ideal width in characters of text art diagrams generated by the analyzer."
+msgstr ""
+
+#: analyzer/analyzer.opt:75
+#, no-c-format
+msgid "Warn about code paths in which a pointer to a buffer is assigned to an incompatible type."
+msgstr ""
+
+#: analyzer/analyzer.opt:79
+#, no-c-format
+msgid "Warn about code paths in which a pointer is checked for NULL after it has already been dereferenced."
+msgstr ""
+
+#: analyzer/analyzer.opt:83
+#, no-c-format
+msgid "Warn about code paths in which a stdio FILE can be closed more than once."
+msgstr ""
+
+#: analyzer/analyzer.opt:87
+#, no-c-format
+msgid "Warn about code paths in which a pointer can be freed more than once."
+msgstr ""
+
+#: analyzer/analyzer.opt:91
+#, no-c-format
+msgid "Warn about code paths in which sensitive data is written to a file."
+msgstr ""
+
+#: analyzer/analyzer.opt:95
+#, no-c-format
+msgid "Warn about code paths in which sensitive data is copied across a security boundary."
+msgstr ""
+
+#: analyzer/analyzer.opt:99
+#, no-c-format
+msgid "Warn about code paths in which read on a write-only file descriptor is attempted, or vice versa."
+msgstr ""
+
+#: analyzer/analyzer.opt:103
+#, no-c-format
+msgid "Warn about code paths in which a file descriptor can be closed more than once."
+msgstr ""
+
+#: analyzer/analyzer.opt:107
+#, no-c-format
+msgid "Warn about code paths in which a file descriptor is not closed."
+msgstr ""
+
+#: analyzer/analyzer.opt:111
+#, no-c-format
+msgid "Warn about code paths in which an operation is attempted in the wrong phase of a file descriptor's lifetime."
+msgstr ""
+
+#: analyzer/analyzer.opt:115
+#, no-c-format
+msgid "Warn about code paths in which an operation is attempted on the wrong type of file descriptor."
+msgstr ""
+
+#: analyzer/analyzer.opt:119
+#, no-c-format
+msgid "Warn about code paths in which a read or write is performed on a closed file descriptor."
+msgstr ""
+
+#: analyzer/analyzer.opt:123
+#, no-c-format
+msgid "Warn about code paths in which a file descriptor is used without being checked for validity."
+msgstr ""
+
+#: analyzer/analyzer.opt:127
+#, no-c-format
+msgid "Warn about code paths in which a stdio FILE is not closed."
+msgstr ""
+
+#: analyzer/analyzer.opt:131
+#, no-c-format
+msgid "Warn about code paths in which a non-heap pointer is freed."
+msgstr ""
+
+#: analyzer/analyzer.opt:135
+#, no-c-format
+msgid "Warn about code paths in which floating-point arithmetic is used in locations where precise computation is needed."
+msgstr ""
+
+#: analyzer/analyzer.opt:139
+#, no-c-format
+msgid "Warn about code paths which appear to lead to an infinite loop."
+msgstr ""
+
+#: analyzer/analyzer.opt:143
+#, no-c-format
+msgid "Warn about code paths which appear to lead to infinite recursion."
+msgstr ""
+
+#: analyzer/analyzer.opt:147
+#, no-c-format
+msgid "Warn about code paths in which a NULL function pointer is called."
+msgstr ""
+
+#: analyzer/analyzer.opt:151
+#, no-c-format
+msgid "Warn about code paths in which a heap-allocated pointer leaks."
+msgstr ""
+
+#: analyzer/analyzer.opt:155
+#, no-c-format
+msgid "Warn about code paths in which the wrong deallocation function is called."
+msgstr ""
+
+#: analyzer/analyzer.opt:159
+#, no-c-format
+msgid "Warn about code paths in which a write or read to a buffer is out-of-bounds."
+msgstr ""
+
+#: analyzer/analyzer.opt:163
+#, no-c-format
+msgid "Warn about code paths in which undefined behavior would occur due to overlapping buffers."
+msgstr ""
+
+#: analyzer/analyzer.opt:167
+#, no-c-format
+msgid "Warn about code paths in which a possibly-NULL value is passed to a must-not-be-NULL function argument."
+msgstr ""
+
+#: analyzer/analyzer.opt:171
+#, no-c-format
+msgid "Warn about code paths in which a possibly-NULL pointer is dereferenced."
+msgstr ""
+
+#: analyzer/analyzer.opt:175
+#, no-c-format
+msgid "Warn about code paths in which an async-signal-unsafe function is called from a signal handler."
+msgstr ""
+
+#: analyzer/analyzer.opt:179
+#, no-c-format
+msgid "Warn about code paths in which NULL is passed to a must-not-be-NULL function argument."
+msgstr ""
+
+#: analyzer/analyzer.opt:183
+#, no-c-format
+msgid "Warn about code paths in which a NULL pointer is dereferenced."
+msgstr ""
+
+#: analyzer/analyzer.opt:187
+#, no-c-format
+msgid "Warn about code paths in which an on-stack buffer is passed to putenv."
+msgstr ""
+
+#: analyzer/analyzer.opt:191
+#, no-c-format
+msgid "Warn about code paths in which a shift with negative count is attempted."
+msgstr ""
+
+#: analyzer/analyzer.opt:195
+#, no-c-format
+msgid "Warn about code paths in which a shift with count >= width of type is attempted."
+msgstr ""
+
+#: analyzer/analyzer.opt:199
+#, no-c-format
+msgid "Warn about code paths in which a longjmp rewinds to a jmp_buf saved in a stack frame that has returned."
+msgstr ""
+
+#: analyzer/analyzer.opt:203
+#, no-c-format
+msgid "Warn about code paths in which an unsanitized value is used as an allocation size."
+msgstr ""
+
+#: analyzer/analyzer.opt:207
+#, no-c-format
+msgid "Warn about code paths in which an unsanitized value is used as an array index."
+msgstr ""
+
+#: analyzer/analyzer.opt:211
+#, no-c-format
+msgid "Warn about code paths in which an 'assert()' is made involving an unsanitized value."
+msgstr ""
+
+#: analyzer/analyzer.opt:215
+#, no-c-format
+msgid "Warn about code paths in which an unsanitized value is used as a divisor."
+msgstr ""
+
+#: analyzer/analyzer.opt:219
+#, no-c-format
+msgid "Warn about code paths in which an unsanitized value is used as a pointer offset."
+msgstr ""
+
+#: analyzer/analyzer.opt:223
+#, no-c-format
+msgid "Warn about code paths in which an unsanitized value is used as a size."
+msgstr ""
+
+#: analyzer/analyzer.opt:227
+#, no-c-format
+msgid "Warn about code paths in which a call is made to strtok with undefined behavior."
+msgstr ""
+
+#: analyzer/analyzer.opt:231
+#, no-c-format
+msgid "Warn about code paths in which a freed value is used."
+msgstr ""
+
+#: analyzer/analyzer.opt:235
+#, no-c-format
+msgid "Warn about code paths in which a pointer to a stale stack frame is used."
+msgstr ""
+
+#: analyzer/analyzer.opt:239
+#, no-c-format
+msgid "Warn about code paths in which va_arg uses the wrong type."
+msgstr ""
+
+#: analyzer/analyzer.opt:243
+#, no-c-format
+msgid "Warn about code paths in which va_arg is used too many times on a va_list."
+msgstr ""
+
+#: analyzer/analyzer.opt:247
+#, no-c-format
+msgid "Warn about code paths in which va_start or va_copy is used without a corresponding va_end."
+msgstr ""
+
+#: analyzer/analyzer.opt:251
+#, no-c-format
+msgid "Warn about code paths in which a va_list is used after va_end."
+msgstr ""
+
+#: analyzer/analyzer.opt:255
+#, no-c-format
+msgid "Warn about code paths which attempt to write to a const object."
+msgstr ""
+
+#: analyzer/analyzer.opt:259
+#, no-c-format
+msgid "Warn about code paths which attempt to write to a string literal."
+msgstr ""
+
+#: analyzer/analyzer.opt:263
+#, no-c-format
+msgid "Warn about code paths in which an uninitialized value is used."
+msgstr ""
+
+#: analyzer/analyzer.opt:267
+#, no-c-format
+msgid "Warn if expressions are too complicated for the analyzer to fully track."
+msgstr ""
+
+#: analyzer/analyzer.opt:271
+#, no-c-format
+msgid "Warn if the code is too complicated for the analyzer to fully explore."
+msgstr ""
+
+#: analyzer/analyzer.opt:275
+#, no-c-format
+msgid "Restrict the analyzer to run just the named checker."
+msgstr ""
+
+#: analyzer/analyzer.opt:279
+#, no-c-format
+msgid "Add extra annotations to diagrams."
+msgstr ""
+
+#: analyzer/analyzer.opt:283
+#, no-c-format
+msgid "Avoid combining multiple statements into one exploded edge."
+msgstr ""
+
+#: analyzer/analyzer.opt:287
+#, no-c-format
+msgid "Verify that paths are feasible when emitting diagnostics."
+msgstr ""
+
+#: analyzer/analyzer.opt:291
+#, no-c-format
+msgid "Issue a note when diagnostics are deduplicated."
+msgstr ""
+
+#: analyzer/analyzer.opt:295
+#, no-c-format
+msgid "Purge unneeded state during analysis."
+msgstr ""
+
+#: analyzer/analyzer.opt:299
+#, no-c-format
+msgid "Merge similar-enough states during analysis."
+msgstr ""
+
+#: analyzer/analyzer.opt:303
+#, no-c-format
+msgid "Stop exploring an execution path after certain diagnostics."
+msgstr ""
+
+#: analyzer/analyzer.opt:307
+#, no-c-format
+msgid "Enable transitivity of constraints during analysis."
+msgstr ""
+
+#: analyzer/analyzer.opt:311
+#, no-c-format
+msgid "Show events within system headers in analyzer execution paths."
+msgstr ""
+
+#: analyzer/analyzer.opt:315
+#, no-c-format
+msgid "Approximate the effect of function calls to simplify analysis."
+msgstr ""
+
+#: analyzer/analyzer.opt:319
+#, no-c-format
+msgid "Try to reconstruct function calls and returns after inlining."
+msgstr ""
+
+#: analyzer/analyzer.opt:323
+#, no-c-format
+msgid "Emit more verbose descriptions of control flow in diagnostics."
+msgstr ""
+
+#: analyzer/analyzer.opt:327
+#, no-c-format
+msgid "Emit more verbose descriptions of state changes in diagnostics."
+msgstr ""
+
+#: analyzer/analyzer.opt:331
+#, no-c-format
+msgid "Control which events are displayed in diagnostic paths."
+msgstr ""
+
+#: analyzer/analyzer.opt:335
+#, no-c-format
+msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
+msgstr ""
+
+#: analyzer/analyzer.opt:339
+#, no-c-format
+msgid "Dump various analyzer internals to stderr."
+msgstr ""
+
+#: analyzer/analyzer.opt:343
+#, no-c-format
+msgid "Dump analyzer-specific call graph information to a SRCFILE.callgraph.dot file."
+msgstr ""
+
+#: analyzer/analyzer.opt:347
+#, no-c-format
+msgid "Dump the analyzer exploded graph to a SRCFILE.eg.dot file."
+msgstr ""
+
+#: analyzer/analyzer.opt:351
+#, no-c-format
+msgid "Emit diagnostics showing the location of nodes in the exploded graph."
+msgstr ""
+
+#: analyzer/analyzer.opt:355
+#, no-c-format
+msgid "Dump a textual representation of the exploded graph to SRCFILE.eg.txt."
+msgstr ""
+
+#: analyzer/analyzer.opt:359
+#, no-c-format
+msgid "Dump a textual representation of the exploded graph to SRCFILE.eg-ID.txt."
+msgstr ""
+
+#: analyzer/analyzer.opt:363
+#, no-c-format
+msgid "Dump a textual representation of each diagnostic's exploded path to SRCFILE.IDX.KIND.epath.txt."
+msgstr ""
+
+#: analyzer/analyzer.opt:367
+#, no-c-format
+msgid "Dump various analyzer internals to SRCFILE.*.fg.dot and SRCFILE.*.tg.dot."
+msgstr ""
+
+#: analyzer/analyzer.opt:371
+#, no-c-format
+msgid "Dump various analyzer internals to SRCFILE.*.infinite-loop.dot."
+msgstr ""
+
+#: analyzer/analyzer.opt:375
+#, no-c-format
+msgid "Dump analyzer-specific data to a SRCFILE.analyzer.json.gz file."
+msgstr ""
+
+#: analyzer/analyzer.opt:379
+#, no-c-format
+msgid "Dump state-purging information to a SRCFILE.state-purge.dot file."
+msgstr ""
+
+#: analyzer/analyzer.opt:383
+#, no-c-format
+msgid "Dump the analyzer supergraph to a SRCFILE.supergraph.dot file."
+msgstr ""
+
+#: analyzer/analyzer.opt:387
+#, no-c-format
+msgid "Emit custom warnings with internal details intended for analyzer developers."
+msgstr ""
+
+#: config/vms/vms.opt:27
+#, no-c-format
+msgid "Malloc data into P2 space."
+msgstr ""
+
+#: config/vms/vms.opt:31
+#, no-c-format
+msgid "Set name of main routine for the debugger."
+msgstr ""
+
+#: config/vms/vms.opt:35
+#, no-c-format
+msgid "Use VMS exit codes instead of posix ones."
+msgstr ""
+
+#: config/vms/vms.opt:39
+#, no-c-format
+msgid "-mpointer-size=[no,32,short,64,long]\tSet the default pointer size."
+msgstr ""
+
+#: config/mcore/mcore.opt:23
+#, no-c-format
+msgid "Generate code for the M*Core M210."
+msgstr ""
+
+#: config/mcore/mcore.opt:27
+#, no-c-format
+msgid "Generate code for the M*Core M340."
+msgstr ""
+
+#: config/mcore/mcore.opt:31
+#, no-c-format
+msgid "Force functions to be aligned to a 4 byte boundary."
+msgstr ""
+
+#: config/mcore/mcore.opt:35 config/moxie/moxie.opt:23 config/csky/csky.opt:44
+#, no-c-format
+msgid "Generate big-endian code."
+msgstr ""
+
+#: config/mcore/mcore.opt:39
+#, no-c-format
+msgid "Emit call graph information."
+msgstr ""
+
+#: config/mcore/mcore.opt:43
+#, no-c-format
+msgid "Use the divide instruction."
+msgstr ""
+
+#: config/mcore/mcore.opt:47
+#, no-c-format
+msgid "Inline constants if it can be done in 2 insns or less."
+msgstr ""
+
+#: config/mcore/mcore.opt:51 config/moxie/moxie.opt:27 config/csky/csky.opt:51
+#, no-c-format
+msgid "Generate little-endian code."
+msgstr ""
+
+#: config/mcore/mcore.opt:56 config/fr30/fr30.opt:27
+#, no-c-format
+msgid "Assume that run-time support has been provided, so omit -lsim from the linker command line."
+msgstr ""
+
+#: config/mcore/mcore.opt:60
+#, no-c-format
+msgid "Use arbitrary sized immediates in bit operations."
+msgstr ""
+
+#: config/mcore/mcore.opt:64
+#, no-c-format
+msgid "Prefer word accesses over byte accesses."
+msgstr ""
+
+#: config/mcore/mcore.opt:71
+#, no-c-format
+msgid "Set the maximum amount for a single stack increment operation."
+msgstr ""
+
+#: config/mcore/mcore.opt:75
+#, no-c-format
+msgid "Always treat bitfields as int-sized."
+msgstr ""
+
+#: config/linux-android.opt:23
+#, no-c-format
+msgid "Generate code for the Android platform."
+msgstr ""
+
+#: config/mmix/mmix.opt:24
+#, no-c-format
+msgid "For intrinsics library: pass all parameters in registers."
+msgstr ""
+
+#: config/mmix/mmix.opt:28
+#, no-c-format
+msgid "Use register stack for parameters and return value."
+msgstr ""
+
+#: config/mmix/mmix.opt:32
+#, no-c-format
+msgid "Use call-clobbered registers for parameters and return value."
+msgstr ""
+
+#: config/mmix/mmix.opt:37
+#, no-c-format
+msgid "Use epsilon-respecting floating point compare instructions."
+msgstr ""
+
+#: config/mmix/mmix.opt:41
+#, no-c-format
+msgid "Use zero-extending memory loads, not sign-extending ones."
+msgstr ""
+
+#: config/mmix/mmix.opt:45
+#, no-c-format
+msgid "Generate divide results with reminder having the same sign as the divisor (not the dividend)."
+msgstr ""
+
+#: config/mmix/mmix.opt:49
+#, no-c-format
+msgid "Prepend global symbols with \":\" (for use with PREFIX)."
+msgstr ""
+
+#: config/mmix/mmix.opt:53
+#, no-c-format
+msgid "Do not provide a default start-address 0x100 of the program."
+msgstr ""
+
+#: config/mmix/mmix.opt:57
+#, no-c-format
+msgid "Link to emit program in ELF format (rather than mmo)."
+msgstr ""
+
+#: config/mmix/mmix.opt:61
+#, no-c-format
+msgid "Use P-mnemonics for branches statically predicted as taken."
+msgstr ""
+
+#: config/mmix/mmix.opt:65
+#, no-c-format
+msgid "Don't use P-mnemonics for branches."
+msgstr ""
+
+#: config/mmix/mmix.opt:79
+#, no-c-format
+msgid "Use addresses that allocate global registers."
+msgstr ""
+
+#: config/mmix/mmix.opt:83
+#, no-c-format
+msgid "Do not use addresses that allocate global registers."
+msgstr ""
+
+#: config/mmix/mmix.opt:87
+#, no-c-format
+msgid "Generate a single exit point for each function."
+msgstr ""
+
+#: config/mmix/mmix.opt:91
+#, no-c-format
+msgid "Do not generate a single exit point for each function."
+msgstr ""
+
+#: config/mmix/mmix.opt:95
+#, no-c-format
+msgid "Set start-address of the program."
+msgstr ""
+
+#: config/mmix/mmix.opt:99
+#, no-c-format
+msgid "Set start-address of data."
+msgstr ""
+
+#: config/darwin.opt:34
+#, no-c-format
+msgid "Generate code for darwin loadable kernel extensions."
+msgstr ""
+
+#: config/darwin.opt:38 config/darwin.opt:46
+#, no-c-format
+msgid "Generate compile-time CFString objects."
+msgstr ""
+
+#: config/darwin.opt:42
+#, no-c-format
+msgid "-iframework <dir>\tAdd <dir> to the end of the system framework include path."
+msgstr ""
+
+#: config/darwin.opt:50
+#, no-c-format
+msgid "Warn if constant CFString objects contain non-portable characters."
+msgstr ""
+
+#: config/darwin.opt:55
+#, no-c-format
+msgid "Generate AT&T-style stubs for Mach-O."
+msgstr ""
+
+#: config/darwin.opt:59
+#, no-c-format
+msgid "Generate code suitable for executables (NOT shared libs)."
+msgstr ""
+
+#: config/darwin.opt:63
+#, no-c-format
+msgid "Generate code suitable for fast turn around debugging."
+msgstr ""
+
+#: config/darwin.opt:67
+#, no-c-format
+msgid "Generate code for the kernel or loadable kernel extensions."
+msgstr ""
+
+#: config/darwin.opt:75
+#, no-c-format
+msgid "The earliest macOS version on which this program will run."
+msgstr ""
+
+#: config/darwin.opt:80
+#, no-c-format
+msgid "Set sizeof(bool) to 1."
+msgstr ""
+
+#: config/darwin.opt:84
+#, no-c-format
+msgid "Force generation of external symbol indirection stubs."
+msgstr ""
+
+#: config/darwin.opt:92
+#, no-c-format
+msgid "-mtarget-linker <version>\tSpecify that ld64 <version> is the toolchain linker for the current invocation."
+msgstr ""
+
+#: config/darwin.opt:98
+#, no-c-format
+msgid "Load all members of archive libraries, rather than only those that satisfy undefined symbols."
+msgstr ""
+
+#: config/darwin.opt:102
+#, no-c-format
+msgid "-allowable_client <name>\tThe output dylib is private to the client <name>."
+msgstr ""
+
+#: config/darwin.opt:106
+#, no-c-format
+msgid "-arch <name>\tGenerate output for architecture <name>."
+msgstr ""
+
+#: config/darwin.opt:110
+#, no-c-format
+msgid "Mismatches between file architecture and one specified by \"-arch\" are errors instead of warnings."
+msgstr ""
+
+#: config/darwin.opt:114
+#, no-c-format
+msgid "The earliest macOS version on which this program will run (formatted for the assembler)."
+msgstr ""
+
+#: config/darwin.opt:118
+#, no-c-format
+msgid "Generate an output executable that binds symbols on load, rather than lazily."
+msgstr ""
+
+#: config/darwin.opt:122
+#, no-c-format
+msgid "Generate a Mach-O bundle (file type MH_BUNDLE)."
+msgstr ""
+
+#: config/darwin.opt:126
+#, no-c-format
+msgid "-bundle_loader <executable>\tTreat <executable> (that will be loading this bundle) as if it was one of the dynamic libraries the bundle is linked against for symbol resolution."
+msgstr ""
+
+#: config/darwin.opt:130
+#, no-c-format
+msgid "-client_name <name>\tEnable the executable being built to link against a private dylib (using allowable_client)."
+msgstr ""
+
+#: config/darwin.opt:134
+#, no-c-format
+msgid "-compatibility_version <number>\tSet the version for the client interface.  Client programs must record a value less than or equal to <number>, or the binding will fail at runtime."
+msgstr ""
+
+#: config/darwin.opt:138
+#, no-c-format
+msgid "-current_version <number>\tSet the current version for the library to <number>."
+msgstr ""
+
+#: config/darwin.opt:142
+#, no-c-format
+msgid "Remove code and data that is unreachable from any exported symbol (including the entry point)."
+msgstr ""
+
+#: config/darwin.opt:146
+#, no-c-format
+msgid "-dylib_file install_name:file_name\tThis allows linking of a dylib with \"install_name\" but to be found in a different install position \"file_name\""
+msgstr ""
+
+#: config/darwin.opt:150
+#, no-c-format
+msgid "Produce a Mach-O dylinker (file type MH_DYLINKER), only used for building dyld."
+msgstr ""
+
+#: config/darwin.opt:154
+#, no-c-format
+msgid "-dylinker_install_name <path>\tOnly used for building dyld."
+msgstr ""
+
+#: config/darwin.opt:158
+#, no-c-format
+msgid "The default (and opposite of -static), implied by user mode executables, shared libraries and bundles."
+msgstr ""
+
+#: config/darwin.opt:162
+#, no-c-format
+msgid "Produce a Mach-O shared library (file type MH_DYLIB), synonym for \"-shared\"."
+msgstr ""
+
+#: config/darwin.opt:166
+#, no-c-format
+msgid "-exported_symbols_list <filename>\tExport global symbols in <filename> in linked output file; any symbols not mentioned will be treated as \"hidden\"."
+msgstr ""
+
+#: config/darwin.opt:170
+#, no-c-format
+msgid "Supply a list of objects to be linked from a file, rather than the command line."
+msgstr ""
+
+#: config/darwin.opt:174 config/darwin.opt:194
+#, no-c-format
+msgid "Used for generating code for some older kernel revisions."
+msgstr ""
+
+#: config/darwin.opt:178
+#, no-c-format
+msgid "Ignore the normal two-level namespace; resolve symbols in command line order and do not record which library provided the resolved symbol."
+msgstr ""
+
+#: config/darwin.opt:182
+#, no-c-format
+msgid "For the assembler (and linker) permit any architecture sub-variant to be used without error."
+msgstr ""
+
+#: config/darwin.opt:186
+#, no-c-format
+msgid "Set the output object such that, on loading, dyld will ignore any two-level namespace information and resolve symbols in the discovery order for loaded libs."
+msgstr ""
+
+#: config/darwin.opt:190
+#, no-c-format
+msgid "-framework <name>\tThe linker should search for the framework <name> in the framework search path."
+msgstr ""
+
+#: config/darwin.opt:198
+#, no-c-format
+msgid "Abbreviation for \"-g -fno-eliminate-unused-debug-symbols\"."
+msgstr ""
+
+#: config/darwin.opt:202
+#, no-c-format
+msgid "Abbreviation for \"-g -feliminate-unused-debug-symbols\"."
+msgstr ""
+
+#: config/darwin.opt:206
+#, no-c-format
+msgid "Automatically adds space for longer path names in load commands (up to MAXPATHLEN)."
+msgstr ""
+
+#: config/darwin.opt:210
+#, no-c-format
+msgid "-image_base <address>\tSpecify <address> as the base address for a dylib or bundle."
+msgstr ""
+
+#: config/darwin.opt:214
+#, no-c-format
+msgid "-init <symbol_name>\tThe symbol <symbol_name> will be used as the first initializer for a dylib."
+msgstr ""
+
+#: config/darwin.opt:218
+#, no-c-format
+msgid "-install_name <name>\tSet the install name for a dylib."
+msgstr ""
+
+#: config/darwin.opt:222
+#, no-c-format
+msgid "Usually \"private extern\" (hidden) symbols are made local when linking, this command suppresses that such that they remain exported."
+msgstr ""
+
+#: config/darwin.opt:226
+#, no-c-format
+msgid "(Obsolete after 10.4) Multi modules are ignored at runtime since macOS 10.4."
+msgstr ""
+
+#: config/darwin.opt:230
+#, no-c-format
+msgid "(Obsolete after 10.4) -multiply_defined <treatment>\tProvided a mechanism for warning about symbols defined in multiple dylibs."
+msgstr ""
+
+#: config/darwin.opt:234
+#, no-c-format
+msgid "(Obsolete after 10.4) -multiply_defined_unused <treatment>\tProvided a mechanism for warning about symbols defined in the current executable also being defined in linked dylibs."
+msgstr ""
+
+#: config/darwin.opt:238
+#, no-c-format
+msgid "(Obsolete) Current linkers never dead-strip these items, so the option is not needed."
+msgstr ""
+
+#: config/darwin.opt:242
+#, no-c-format
+msgid "Do not add a default symbol exports to modules or dynamic libraries."
+msgstr ""
+
+#: config/darwin.opt:246
+#, no-c-format
+msgid "Do not add default run paths (for the compiler library directories) to executables, modules or dynamic libraries."
+msgstr ""
+
+#: config/darwin.opt:250
+#, no-c-format
+msgid "(Obsolete after 10.3.9) Set MH_NOPREFIXBINDING, in an executable."
+msgstr ""
+
+#: config/darwin.opt:254
+#, no-c-format
+msgid "(Obsolete after 10.4)\tSet MH_NOMULTIDEFS in an umbrella framework."
+msgstr ""
+
+#: config/darwin.opt:258 config/darwin.opt:273 config/darwin.opt:277
+#, no-c-format
+msgid "(Obsolete) LD_PREBIND is no longer supported."
+msgstr ""
+
+#: config/darwin.opt:262
+#, no-c-format
+msgid "(Obsolete) This is the default."
+msgstr ""
+
+#: config/darwin.opt:269
+#, no-c-format
+msgid "-pagezero_size <size>\tAllows setting the page 0 size to 4kb when required."
+msgstr ""
+
+#: config/darwin.opt:281
+#, no-c-format
+msgid "Produces a Mach-O file suitable for embedded/ROM use."
+msgstr ""
+
+#: config/darwin.opt:285
+#, no-c-format
+msgid "(Obsolete) Allowed linking to proceed with \"-flat_namespace\" when a linked bundle contained a symbol also exported from the main executable."
+msgstr ""
+
+#: config/darwin.opt:292
+#, no-c-format
+msgid "Synonym for \"-export-dynamic\" for linker versions that support it."
+msgstr ""
+
+#: config/darwin.opt:296
+#, no-c-format
+msgid "-read_only_relocs <treatment>\tAllow relocations in read-only pages (not recommended)."
+msgstr ""
+
+#: config/darwin.opt:300
+#, no-c-format
+msgid "-sectalign <segname> <sectname> <value>\tSet section <sectname> in segment <segname> to have alignment <value> which must be an integral power of two expressed in hexadecimal form."
+msgstr ""
+
+#: config/darwin.opt:304
+#, no-c-format
+msgid "-sectcreate <segname> <sectname> <file>\tCreate section <sectname> in segment <segname> from the contents of <file>."
+msgstr ""
+
+#: config/darwin.opt:308
+#, no-c-format
+msgid "(Obsolete) -sectobjectsymbols <segname> <sectname>\tSetting a local symbol at the start of a section is no longer supported."
+msgstr ""
+
+#: config/darwin.opt:312
+#, no-c-format
+msgid "(Obsolete) -sectorder <segname> <sectname> <orderfile>\tReplaced by a more general option \"-order_file\"."
+msgstr ""
+
+#: config/darwin.opt:316
+#, no-c-format
+msgid "-seg_addr_table <file>\tSpecify the base addresses for dynamic libraries; <file> contains a line for each library."
+msgstr ""
+
+#: config/darwin.opt:321
+#, no-c-format
+msgid "(Obsolete, ld_classic only) -seg_addr_table_filename <path>."
+msgstr ""
+
+#: config/darwin.opt:325
+#, no-c-format
+msgid "Synonym for \"image_base\"."
+msgstr ""
+
+#: config/darwin.opt:329
+#, no-c-format
+msgid "-segaddr <name> <address>\tSet the base address of segment <name> to <address> which must be aligned to a page boundary (currently 4kb)."
+msgstr ""
+
+#: config/darwin.opt:334
+#, no-c-format
+msgid "(Obsolete, ld_classic only) -sectcreate <segname> <sectname> <file>\tAllowed creation of a section from a file."
+msgstr ""
+
+#: config/darwin.opt:338
+#, no-c-format
+msgid "(Obsolete) Object files with LINKEDIT sections are no longer supported."
+msgstr ""
+
+#: config/darwin.opt:342
+#, no-c-format
+msgid "-segprot <segname> <max_prot> <init_prot>\tThe virtual memory protections for segment <segname> have maximum and initial values <max_prot> and <init_prot> respectively.  The specified values may contain \"r\", \"w\", \"x\" or \"-\" the latter meaning \"no access\"."
+msgstr ""
+
+#: config/darwin.opt:346
+#, no-c-format
+msgid "-segs_read_only_addr <address>\tSpecify that <address> is the base address of the read-only segments of a dylib."
+msgstr ""
+
+#: config/darwin.opt:350
+#, no-c-format
+msgid "-segs_read_write_addr <address>\tSpecify that <address> is the base address address of the read-write segments of a dylib."
+msgstr ""
+
+#: config/darwin.opt:354
+#, no-c-format
+msgid "(Obsolete)\tThis is the default."
+msgstr ""
+
+#: config/darwin.opt:358
+#, no-c-format
+msgid "-sub_library <name>\tLibrary named <name> will be re-exported (only useful for dylibs)."
+msgstr ""
+
+#: config/darwin.opt:362
+#, no-c-format
+msgid "-sub_umbrella <name>\tFramework named <name> will be re-exported (only useful for dylibs)."
+msgstr ""
+
+#: config/darwin.opt:366
+#, no-c-format
+msgid "This is the default."
+msgstr ""
+
+#: config/darwin.opt:370
+#, no-c-format
+msgid "Add extra information to the executable that can speed up dynamic loading (provided that dependent libraries are unchanged)."
+msgstr ""
+
+#: config/darwin.opt:374
+#, no-c-format
+msgid "-umbrella <framework>\tThe specified framework will be re-exported."
+msgstr ""
+
+#: config/darwin.opt:378
+#, no-c-format
+msgid "-undefined <treatment>\tSpecify the handling for undefined symbols (default is error)."
+msgstr ""
+
+#: config/darwin.opt:382
+#, no-c-format
+msgid "-unexported_symbols_list <filename>\tDo not export the global symbols listed in <filename>."
+msgstr ""
+
+#: config/darwin.opt:386
+#, no-c-format
+msgid "-weak_reference_mismatches <treatment>\tSpecifies what to do if a symbol import conflicts between file (weak in one and not in another) the default is to treat the symbol as non-weak."
+msgstr ""
+
+#: config/darwin.opt:390
+#, no-c-format
+msgid "Logs which object files the linker loads."
+msgstr ""
+
+#: config/darwin.opt:394
+#, no-c-format
+msgid "Logs which symbol(s) caused an object to be loaded."
+msgstr ""
+
+#: config/darwin.opt:402
+#, no-c-format
+msgid "(Obsolete, ignored)\tOld support similar to \"-whyload\"."
+msgstr ""
+
+#: config/darwin.opt:406
+#, no-c-format
+msgid "(Obsolete and unhandled by ld64, ignored)\tld should produce an executable (only handled by ld_classic)."
+msgstr ""
+
+#: config/bfin/bfin.opt:40 config/msp430/msp430.opt:3 config/c6x/c6x.opt:38
+#, no-c-format
+msgid "Use simulator runtime."
+msgstr ""
+
+#: config/bfin/bfin.opt:44 config/arm/arm.opt:117
+#, no-c-format
+msgid "Specify the name of the target CPU."
+msgstr ""
+
+#: config/bfin/bfin.opt:48
+#, no-c-format
+msgid "Omit frame pointer for leaf functions."
+msgstr ""
+
+#: config/bfin/bfin.opt:52
+#, no-c-format
+msgid "Program is entirely located in low 64k of memory."
+msgstr ""
+
+#: config/bfin/bfin.opt:56
+#, no-c-format
+msgid "Work around a hardware anomaly by adding a number of NOPs before a CSYNC or SSYNC instruction."
+msgstr ""
+
+#: config/bfin/bfin.opt:61
+#, no-c-format
+msgid "Avoid speculative loads to work around a hardware anomaly."
+msgstr ""
+
+#: config/bfin/bfin.opt:65
+#, no-c-format
+msgid "Enabled ID based shared library."
+msgstr ""
+
+#: config/bfin/bfin.opt:69
+#, no-c-format
+msgid "Generate code that won't be linked against any other ID shared libraries, but may be used as a shared library."
+msgstr ""
+
+#: config/bfin/bfin.opt:74 config/m68k/m68k.opt:175
+#, no-c-format
+msgid "ID of shared library to build."
+msgstr ""
+
+#: config/bfin/bfin.opt:78 config/m68k/m68k.opt:171
+#, no-c-format
+msgid "Enable separate data segment."
+msgstr ""
+
+#: config/bfin/bfin.opt:82 config/c6x/c6x.opt:63
+#, no-c-format
+msgid "Avoid generating pc-relative calls; use indirection."
+msgstr ""
+
+#: config/bfin/bfin.opt:86
+#, no-c-format
+msgid "Link with the fast floating-point library."
+msgstr ""
+
+#: config/bfin/bfin.opt:90 config/arm/arm.opt:345 config/frv/frv.opt:130
+#, no-c-format
+msgid "Enable Function Descriptor PIC mode."
+msgstr ""
+
+#: config/bfin/bfin.opt:94 config/frv/frv.opt:162
+#, no-c-format
+msgid "Enable inlining of PLT in function calls."
+msgstr ""
+
+#: config/bfin/bfin.opt:98
+#, no-c-format
+msgid "Do stack checking using bounds in L1 scratch memory."
+msgstr ""
+
+#: config/bfin/bfin.opt:102
+#, no-c-format
+msgid "Enable multicore support."
+msgstr ""
+
+#: config/bfin/bfin.opt:106
+#, no-c-format
+msgid "Build for Core A."
+msgstr ""
+
+#: config/bfin/bfin.opt:110
+#, no-c-format
+msgid "Build for Core B."
+msgstr ""
+
+#: config/bfin/bfin.opt:114
+#, no-c-format
+msgid "Build for SDRAM."
+msgstr ""
+
+#: config/bfin/bfin.opt:118
+#, no-c-format
+msgid "Assume ICPLBs are enabled at runtime."
+msgstr ""
+
+#: config/m68k/m68k-tables.opt:25
+#, no-c-format
+msgid "Known M68K CPUs (for use with the -mcpu= option):"
+msgstr ""
+
+#: config/m68k/m68k-tables.opt:365
+#, no-c-format
+msgid "Known M68K microarchitectures (for use with the -mtune= option):"
+msgstr ""
+
+#: config/m68k/m68k-tables.opt:411
+#, no-c-format
+msgid "Known M68K ISAs (for use with the -march= option):"
+msgstr ""
+
+#: config/m68k/ieee.opt:24 config/i386/i386.opt:389
+#, no-c-format
+msgid "Use IEEE math for fp comparisons."
+msgstr ""
+
+#: config/m68k/m68k.opt:30
+#, no-c-format
+msgid "Generate code for a 520X."
+msgstr ""
+
+#: config/m68k/m68k.opt:34
+#, no-c-format
+msgid "Generate code for a 5206e."
+msgstr ""
+
+#: config/m68k/m68k.opt:38
+#, no-c-format
+msgid "Generate code for a 528x."
+msgstr ""
+
+#: config/m68k/m68k.opt:42
+#, no-c-format
+msgid "Generate code for a 5307."
+msgstr ""
+
+#: config/m68k/m68k.opt:46
+#, no-c-format
+msgid "Generate code for a 5407."
+msgstr ""
+
+#: config/m68k/m68k.opt:50 config/m68k/m68k.opt:111
+#, no-c-format
+msgid "Generate code for a 68000."
+msgstr ""
+
+#: config/m68k/m68k.opt:54
+#, no-c-format
+msgid "Generate code for a 68010."
+msgstr ""
+
+#: config/m68k/m68k.opt:58 config/m68k/m68k.opt:115
+#, no-c-format
+msgid "Generate code for a 68020."
+msgstr ""
+
+#: config/m68k/m68k.opt:62
+#, no-c-format
+msgid "Generate code for a 68040, without any new instructions."
+msgstr ""
+
+#: config/m68k/m68k.opt:66
+#, no-c-format
+msgid "Generate code for a 68060, without any new instructions."
+msgstr ""
+
+#: config/m68k/m68k.opt:70
+#, no-c-format
+msgid "Generate code for a 68030."
+msgstr ""
+
+#: config/m68k/m68k.opt:74
+#, no-c-format
+msgid "Generate code for a 68040."
+msgstr ""
+
+#: config/m68k/m68k.opt:78
+#, no-c-format
+msgid "Generate code for a 68060."
+msgstr ""
+
+#: config/m68k/m68k.opt:82
+#, no-c-format
+msgid "Generate code for a 68302."
+msgstr ""
+
+#: config/m68k/m68k.opt:86
+#, no-c-format
+msgid "Generate code for a 68332."
+msgstr ""
+
+#: config/m68k/m68k.opt:91
+#, no-c-format
+msgid "Generate code for a 68851."
+msgstr ""
+
+#: config/m68k/m68k.opt:95
+#, no-c-format
+msgid "Generate code that uses 68881 floating-point instructions."
+msgstr ""
+
+#: config/m68k/m68k.opt:99
+#, no-c-format
+msgid "Align variables on a 32-bit boundary."
+msgstr ""
+
+#: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
+#: config/nds32/nds32.opt:171 config/c6x/c6x.opt:67
+#, no-c-format
+msgid "Specify the name of the target architecture."
+msgstr ""
+
+#: config/m68k/m68k.opt:107
+#, no-c-format
+msgid "Use the bit-field instructions."
+msgstr ""
+
+#: config/m68k/m68k.opt:119
+#, no-c-format
+msgid "Generate code for a ColdFire v4e."
+msgstr ""
+
+#: config/m68k/m68k.opt:123
+#, no-c-format
+msgid "Specify the target CPU."
+msgstr ""
+
+#: config/m68k/m68k.opt:127
+#, no-c-format
+msgid "Generate code for a cpu32."
+msgstr ""
+
+#: config/m68k/m68k.opt:131
+#, no-c-format
+msgid "Use hardware division instructions on ColdFire."
+msgstr ""
+
+#: config/m68k/m68k.opt:135
+#, no-c-format
+msgid "Generate code for a Fido A."
+msgstr ""
+
+#: config/m68k/m68k.opt:139
+#, no-c-format
+msgid "Generate code which uses hardware floating point instructions."
+msgstr ""
+
+#: config/m68k/m68k.opt:143
+#, no-c-format
+msgid "Enable ID based shared library."
+msgstr ""
+
+#: config/m68k/m68k.opt:147
+#, no-c-format
+msgid "Use 32-bit offsets in jump tables rather than 16-bit offsets."
+msgstr ""
+
+#: config/m68k/m68k.opt:151
+#, no-c-format
+msgid "Do not use the bit-field instructions."
+msgstr ""
+
+#: config/m68k/m68k.opt:155
+#, no-c-format
+msgid "Use normal calling convention."
+msgstr ""
+
+#: config/m68k/m68k.opt:159
+#, no-c-format
+msgid "Consider type 'int' to be 32 bits wide."
+msgstr ""
+
+#: config/m68k/m68k.opt:163
+#, no-c-format
+msgid "Generate pc-relative code."
+msgstr ""
+
+#: config/m68k/m68k.opt:167
+#, no-c-format
+msgid "Use different calling convention using 'rtd'."
+msgstr ""
+
+#: config/m68k/m68k.opt:179
+#, no-c-format
+msgid "Consider type 'int' to be 16 bits wide."
+msgstr ""
+
+#: config/m68k/m68k.opt:183
+#, no-c-format
+msgid "Generate code with library calls for floating point."
+msgstr ""
+
+#: config/m68k/m68k.opt:187 config/xtensa/xtensa.opt:73
+#, no-c-format
+msgid "Do not use unaligned memory references."
+msgstr ""
+
+#: config/m68k/m68k.opt:191
+#, no-c-format
+msgid "Tune for the specified target CPU or architecture."
+msgstr ""
+
+#: config/m68k/m68k.opt:195
+#, no-c-format
+msgid "Support more than 8192 GOT entries on ColdFire."
+msgstr ""
+
+#: config/m68k/m68k.opt:199
+#, no-c-format
+msgid "Support TLS segment larger than 64K."
+msgstr ""
+
+#: config/riscv/riscv.opt:26 config/aarch64/aarch64.opt:74
+#: config/arm/arm.opt:105 config/microblaze/microblaze.opt:60
+#, no-c-format
+msgid "Assume target CPU is configured as big endian."
+msgstr ""
+
+#: config/riscv/riscv.opt:30 config/aarch64/aarch64.opt:94
+#: config/arm/arm.opt:170 config/microblaze/microblaze.opt:64
+#, no-c-format
+msgid "Assume target CPU is configured as little endian."
+msgstr ""
+
+#: config/riscv/riscv.opt:34
+#, no-c-format
+msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
+msgstr ""
+
+#: config/riscv/riscv.opt:38
+#, no-c-format
+msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
+msgstr ""
+
+#: config/riscv/riscv.opt:42
+#, no-c-format
+msgid "Specify integer and floating-point calling convention."
+msgstr ""
+
+#: config/riscv/riscv.opt:46 config/i386/i386.opt:444
+#, no-c-format
+msgid "Attempt to keep stack aligned to this power of 2."
+msgstr ""
+
+#: config/riscv/riscv.opt:50
+#, no-c-format
+msgid "Supported ABIs (for use with the -mabi= option):"
+msgstr ""
+
+#: config/riscv/riscv.opt:78
+#, no-c-format
+msgid "Use hardware floating-point divide and square root instructions."
+msgstr ""
+
+#: config/riscv/riscv.opt:82
+#, no-c-format
+msgid "Use hardware instructions for integer division."
+msgstr ""
+
+#: config/riscv/riscv.opt:86
+#, no-c-format
+msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
+msgstr ""
+
+#: config/riscv/riscv.opt:91
+#, no-c-format
+msgid "-march=help\tPrint supported -march extensions."
+msgstr ""
+
+#: config/riscv/riscv.opt:103 config/mips/mips.opt:430
+#, no-c-format
+msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
+msgstr ""
+
+#: config/riscv/riscv.opt:107
+#, no-c-format
+msgid "-mcpu=PROCESSOR\tUse architecture of and optimize the output for PROCESSOR."
+msgstr ""
+
+#: config/riscv/riscv.opt:111
+#, no-c-format
+msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
+msgstr ""
+
+#: config/riscv/riscv.opt:115
+#, no-c-format
+msgid "Use smaller but slower prologue and epilogue code."
+msgstr ""
+
+#: config/riscv/riscv.opt:119
+#, no-c-format
+msgid "Convert BASE + LARGE_OFFSET addresses to NEW_BASE + SMALL_OFFSET to allow more memory accesses to be generated as compressed instructions.  Currently targets 32-bit integer load/stores."
+msgstr ""
+
+#: config/riscv/riscv.opt:125 config/aarch64/aarch64.opt:98
+#: config/loongarch/loongarch.opt:266
+#, no-c-format
+msgid "Specify the code model."
+msgstr ""
+
+#: config/riscv/riscv.opt:129 config/loongarch/loongarch.opt:206
+#, no-c-format
+msgid "Do not generate unaligned memory accesses."
+msgstr ""
+
+#: config/riscv/riscv.opt:133 config/i386/i386.opt:308
+#: config/rs6000/aix64.opt:36 config/rs6000/linux64.opt:32
+#, no-c-format
+msgid "Known code models (for use with the -mcmodel= option):"
+msgstr ""
+
+#: config/riscv/riscv.opt:146
+#, no-c-format
+msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
+msgstr ""
+
+#: config/riscv/riscv.opt:150 config/loongarch/loongarch.opt:274
+#, no-c-format
+msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
+msgstr ""
+
+#: config/riscv/riscv.opt:155
+#, no-c-format
+msgid "Enable the CSR checking for the ISA-dependent CSR and the read-only CSR. The ISA-dependent CSR are only valid when the specific ISA is set.  The read-only CSR can not be written by the CSR instructions."
+msgstr ""
+
+#: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:141
+#: config/i386/i386.opt:420
+#, no-c-format
+msgid "Omit the frame pointer in leaf functions."
+msgstr ""
+
+#: config/riscv/riscv.opt:183
+#, no-c-format
+msgid "Emit RISC-V ELF attribute."
+msgstr ""
+
+#: config/riscv/riscv.opt:187 config/i386/i386.opt:261
+#, no-c-format
+msgid "Use the given data alignment."
+msgstr ""
+
+#: config/riscv/riscv.opt:191 config/i386/i386.opt:265
+#, no-c-format
+msgid "Known data alignment choices (for use with the -malign-data= option):"
+msgstr ""
+
+#: config/riscv/riscv.opt:201 config/aarch64/aarch64.opt:304
+#: config/i386/i386.opt:1038 config/arm/arm.opt:349
+#: config/rs6000/rs6000.opt:554
+#, no-c-format
+msgid "Use given stack-protector guard."
+msgstr ""
+
+#: config/riscv/riscv.opt:205 config/aarch64/aarch64.opt:308
+#: config/arm/arm.opt:353 config/rs6000/rs6000.opt:558
+#, no-c-format
+msgid "Valid arguments to -mstack-protector-guard=:"
+msgstr ""
+
+#: config/riscv/riscv.opt:215 config/i386/i386.opt:1052
+#: config/rs6000/rs6000.opt:568
+#, no-c-format
+msgid "Use the given base register for addressing the stack-protector guard."
+msgstr ""
+
+#: config/riscv/riscv.opt:222 config/i386/i386.opt:1059
+#: config/rs6000/rs6000.opt:575
+#, no-c-format
+msgid "Use the given offset for addressing the stack-protector guard."
+msgstr ""
+
+#: config/riscv/riscv.opt:494
+#, no-c-format
+msgid "Supported ISA specs (for use with the -misa-spec= option):"
+msgstr ""
+
+#: config/riscv/riscv.opt:507
+#, no-c-format
+msgid "Set the version of RISC-V ISA spec."
+msgstr ""
+
+#: config/riscv/riscv.opt:511
+#, no-c-format
+msgid "Enable conditional moves unconditionally."
+msgstr ""
+
+#: config/riscv/riscv.opt:515
+#, no-c-format
+msgid "Always inline subword atomic operations."
+msgstr ""
+
+#: config/riscv/riscv.opt:519
+#, no-c-format
+msgid "Inline strcmp calls if possible."
+msgstr ""
+
+#: config/riscv/riscv.opt:523
+#, no-c-format
+msgid "Inline strncmp calls if possible."
+msgstr ""
+
+#: config/riscv/riscv.opt:527
+#, no-c-format
+msgid "Inline strlen calls if possible."
+msgstr ""
+
+#: config/riscv/riscv.opt:531
+#, no-c-format
+msgid "Max number of bytes to compare as part of inlined strcmp/strncmp routines (default: 64)."
+msgstr ""
+
+#: config/riscv/riscv.opt:535
+#, no-c-format
+msgid "The RVV possible LMUL (-mrvv-max-lmul=):"
+msgstr ""
+
+#: config/riscv/riscv.opt:554
+#, no-c-format
+msgid "-mrvv-max-lmul=<string>\tSet the RVV LMUL of auto-vectorization."
+msgstr ""
+
+#: config/riscv/riscv.opt:561
+#, no-c-format
+msgid "Valid arguments to -param=vsetvl-strategy=:"
+msgstr ""
+
+#: config/riscv/riscv.opt:574
+#, no-c-format
+msgid "-param=vsetvl-strategy=<string>\tSet the optimization level of VSETVL insert pass."
+msgstr ""
+
+#: config/riscv/riscv.opt:578 config/i386/i386.opt:496
+#, no-c-format
+msgid "Valid arguments to -mstringop-strategy=:"
+msgstr ""
+
+#: config/riscv/riscv.opt:594
+#, no-c-format
+msgid "Specify stringop expansion strategy."
+msgstr ""
+
+#: config/riscv/riscv.opt:598
+#, no-c-format
+msgid "The possible RVV vector register lengths:"
+msgstr ""
+
+#: config/riscv/riscv.opt:608
+#, no-c-format
+msgid "-mrvv-vector-bits=<string>\tSet the kind of bits for an RVV vector register."
+msgstr ""
+
+#: config/riscv/riscv.opt:612 config/aarch64/aarch64.opt:49
+#: config/loongarch/loongarch.opt:283
+#, no-c-format
+msgid "The possible TLS dialects:"
+msgstr ""
+
+#: config/riscv/riscv.opt:622 config/aarch64/aarch64.opt:145
+#: config/loongarch/loongarch.opt:293
+#, no-c-format
+msgid "Specify TLS dialect."
+msgstr ""
+
+#: config/m32c/m32c.opt:23
+#, no-c-format
+msgid "-msim\tUse simulator runtime."
+msgstr ""
+
+#: config/m32c/m32c.opt:27
+#, no-c-format
+msgid "-mcpu=r8c\tCompile code for R8C variants."
+msgstr ""
+
+#: config/m32c/m32c.opt:31
+#, no-c-format
+msgid "-mcpu=m16c\tCompile code for M16C variants."
+msgstr ""
+
+#: config/m32c/m32c.opt:35
+#, no-c-format
+msgid "-mcpu=m32cm\tCompile code for M32CM variants."
+msgstr ""
+
+#: config/m32c/m32c.opt:39
+#, no-c-format
+msgid "-mcpu=m32c\tCompile code for M32C variants."
+msgstr ""
+
+#: config/m32c/m32c.opt:43
+#, no-c-format
+msgid "-memregs=\tNumber of memreg bytes (default: 16, range: 0..16)."
+msgstr ""
+
+#: config/msp430/msp430.opt:7
+#, no-c-format
+msgid "Use a lightweight configuration of printf and puts to reduce code size. For single-threaded applications, not requiring reentrant I/O only. Requires Newlib Nano IO."
+msgstr ""
+
+#: config/msp430/msp430.opt:11
+#, no-c-format
+msgid "Force assembly output to always use hex constants."
+msgstr ""
+
+#: config/msp430/msp430.opt:15
+#, no-c-format
+msgid "Specify the MCU to build for."
+msgstr ""
+
+#: config/msp430/msp430.opt:19
+#, no-c-format
+msgid "Warn if an MCU name is unrecognized or conflicts with other options (default: on)."
+msgstr ""
+
+#: config/msp430/msp430.opt:23
+#, no-c-format
+msgid "Warn if devices.csv is not found or there are problem parsing it (default: on)."
+msgstr ""
+
+#: config/msp430/msp430.opt:27
+#, no-c-format
+msgid "Specify the ISA to build for: msp430, msp430x, msp430xv2."
+msgstr ""
+
+#: config/msp430/msp430.opt:52
+#, no-c-format
+msgid "Select large model - 20-bit addresses/pointers."
+msgstr ""
+
+#: config/msp430/msp430.opt:56
+#, no-c-format
+msgid "Select small model - 16-bit addresses/pointers (default)."
+msgstr ""
+
+#: config/msp430/msp430.opt:60
+#, no-c-format
+msgid "Optimize opcode sizes at link time."
+msgstr ""
+
+#: config/msp430/msp430.opt:67 config/pru/pru.opt:26
+#, no-c-format
+msgid "Use a minimum runtime (no static initializers or ctors) for memory-constrained devices."
+msgstr ""
+
+#: config/msp430/msp430.opt:74
+#, no-c-format
+msgid "Specify the type of hardware multiply to support."
+msgstr ""
+
+#: config/msp430/msp430.opt:96
+#, no-c-format
+msgid "Specify whether functions should be placed into the lower or upper memory regions, or if they should be shuffled between the regions (either) for best fit (default: lower)."
+msgstr ""
+
+#: config/msp430/msp430.opt:100
+#, no-c-format
+msgid "Specify whether variables should be placed into the lower or upper memory regions, or if they should be shuffled between the regions (either) for best fit (default: lower)."
+msgstr ""
+
+#: config/msp430/msp430.opt:104
+#, no-c-format
+msgid "Add the .lower prefix to section names when compiling with -m{code,data}-region=lower (disabled by default)."
+msgstr ""
+
+#: config/msp430/msp430.opt:123
+#, no-c-format
+msgid "Passes on a request to the assembler to enable fixes for various silicon errata."
+msgstr ""
+
+#: config/msp430/msp430.opt:127
+#, no-c-format
+msgid "Passes on a request to the assembler to warn about various silicon errata."
+msgstr ""
+
+#: config/msp430/msp430.opt:131
+#, no-c-format
+msgid "The path to devices.csv.  The GCC driver can normally locate devices.csv itself and pass this option to the compiler, so the user shouldn't need to pass this."
+msgstr ""
+
+#: config/msp430/msp430.opt:136
+#, no-c-format
+msgid "For shift operations by a constant amount, which require an individual instruction to shift by one position, set the maximum number of inline shift instructions (maximum value 64) to emit instead of using the corresponding __mspabi helper function. The default value is 4."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:61 config/loongarch/loongarch.opt:244
+#, no-c-format
+msgid "The code model option names for -mcmodel:"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:78 config/i386/i386.opt:1073
+#, no-c-format
+msgid "Generate code which uses only the general registers."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:82 config/i386/i386.opt:1165
+#, no-c-format
+msgid "Generate code to mitigate against straight line speculation."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:86
+#, no-c-format
+msgid "Workaround for ARM Cortex-A53 Erratum number 835769."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:90
+#, no-c-format
+msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:102
+#, no-c-format
+msgid "The register used to access the thread pointer:"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:133
+#, no-c-format
+msgid "Specify the thread pointer register."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:137
+#, no-c-format
+msgid "Don't assume that unaligned accesses are handled by the system."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:149
+#, no-c-format
+msgid "Specifies bit size of immediate TLS offsets.  Valid values are 12, 24, 32, 48."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:168
+#, no-c-format
+msgid "Use features of architecture ARCH."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:172
+#, no-c-format
+msgid "Use features of and optimize for CPU."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:176
+#, no-c-format
+msgid "Optimize for CPU."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:180
+#, no-c-format
+msgid "Generate code that conforms to the specified ABI."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:184
+#, no-c-format
+msgid "-moverride=<string>\tPower users only! Override CPU optimization parameters."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:188
+#, no-c-format
+msgid "Known AArch64 ABIs (for use with the -mabi= option):"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:198
+#, no-c-format
+msgid "PC relative literal loads."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:202 config/arm/arm.opt:337
+#, no-c-format
+msgid "Use branch-protection features."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:206
+#, no-c-format
+msgid "Select return address signing scope."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:210
+#, no-c-format
+msgid "Supported AArch64 return address signing scope (for use with -msign-return-address= option):"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:223
+#, no-c-format
+msgid "Enable the reciprocal square root approximation.  Enabling this reduces precision of reciprocal square root results to about 16 bits for single precision and to 32 bits for double precision."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:229
+#, no-c-format
+msgid "Enable the square root approximation.  Enabling this reduces precision of square root results to about 16 bits for single precision and to 32 bits for double precision. If enabled, it implies -mlow-precision-recip-sqrt."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:236
+#, no-c-format
+msgid "Enable the division approximation.  Enabling this reduces precision of division results to about 16 bits for single precision and to 32 bits for double precision."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:254
+#, no-c-format
+msgid "Specify when to enable an early register allocation pass.  The possibilities are: all functions, functions that have access to strided multi-register instructions, and no functions."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:260
+#, no-c-format
+msgid "The possible SVE vector lengths:"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:282
+#, no-c-format
+msgid "-msve-vector-bits=<number>\tSet the number of bits in an SVE vector register."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:286
+#, no-c-format
+msgid "Enables verbose cost model dumping in the debug dump files."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:290
+#, no-c-format
+msgid "Generate code to track when the CPU might be speculating incorrectly."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:294
+#, no-c-format
+msgid "Enable the copy of the AArch64 load/store pair fusion pass that runs before register allocation."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:299
+#, no-c-format
+msgid "Enable the copy of the AArch64 load/store pair fusion pass that runs after register allocation."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:318
+#, no-c-format
+msgid "Use the system register specified on the command line as the stack protector guard register. This option is for use with fstack-protector-strong and not for use in user-land code."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:324
+#, no-c-format
+msgid "Use an immediate to offset from the stack protector guard register, sp_el0. This option is for use with fstack-protector-strong and not for use in user-land code."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:333
+#, no-c-format
+msgid "Generate local calls to out-of-line atomic operations."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:337
+#, no-c-format
+msgid "When vectorizing, consider using multiple different approaches and use the cost model to choose the cheapest one."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:342
+#, no-c-format
+msgid "The number of Newton iterations for calculating the reciprocal for float type.  The precision of division is proportional to this param when division approximation is enabled.  The default value is 1."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:346
+#, no-c-format
+msgid "The number of Newton iterations for calculating the reciprocal for double type.  The precision of division is proportional to this param when division approximation is enabled.  The default value is 2."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:356
+#, no-c-format
+msgid "Constant memcpy size in bytes above which to start using MOPS sequence."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:360
+#, no-c-format
+msgid "Constant memmove size in bytes above which to start using MOPS sequence."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:364
+#, no-c-format
+msgid "Constant memset size in bytes from which to start using MOPS sequence."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:368
+#, no-c-format
+msgid "Limit how much the autovectorizer may unroll a loop."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:372
+#, no-c-format
+msgid "--param=aarch64-ldp-policy=[default|always|never|aligned] Fine-grained policy for load pairs."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:376
+#, no-c-format
+msgid "--param=aarch64-stp-policy=[default|always|never|aligned] Fine-grained policy for store pairs."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:395
+#, no-c-format
+msgid "Limit on number of alias checks performed when attempting to form an ldp/stp."
+msgstr ""
+
+#: config/aarch64/aarch64.opt:399
+#, no-c-format
+msgid "Param to control which writeback opportunities we try to handle in the load/store pair fusion pass.  A value of zero disables writeback handling.  One means we try to form pairs involving one or more existing individual writeback accesses where possible.  A value of two means we also try to opportunistically form writeback opportunities by folding in trailing destructive updates of the base register used by a pair."
+msgstr ""
+
+#: config/linux.opt:24
+#, no-c-format
+msgid "Use Bionic C library."
+msgstr ""
+
+#: config/linux.opt:28
+#, no-c-format
+msgid "Use GNU C library."
+msgstr ""
+
+#: config/linux.opt:32
+#, no-c-format
+msgid "Use uClibc C library."
+msgstr ""
+
+#: config/linux.opt:36
+#, no-c-format
+msgid "Use musl C library."
+msgstr ""
+
+#: config/ia64/ilp32.opt:3
+#, no-c-format
+msgid "Generate ILP32 code."
+msgstr ""
+
+#: config/ia64/ilp32.opt:7
+#, no-c-format
+msgid "Generate LP64 code."
+msgstr ""
+
+#: config/ia64/ia64.opt:28
+#, no-c-format
+msgid "Generate big endian code."
+msgstr ""
+
+#: config/ia64/ia64.opt:32
+#, no-c-format
+msgid "Generate little endian code."
+msgstr ""
+
+#: config/ia64/ia64.opt:36
+#, no-c-format
+msgid "Generate code for GNU as."
+msgstr ""
+
+#: config/ia64/ia64.opt:40
+#, no-c-format
+msgid "Generate code for GNU ld."
+msgstr ""
+
+#: config/ia64/ia64.opt:44
+#, no-c-format
+msgid "Emit stop bits before and after volatile extended asms."
+msgstr ""
+
+#: config/ia64/ia64.opt:48
+#, no-c-format
+msgid "Use in/loc/out register names."
+msgstr ""
+
+#: config/ia64/ia64.opt:55
+#, no-c-format
+msgid "Enable use of sdata/scommon/sbss."
+msgstr ""
+
+#: config/ia64/ia64.opt:59
+#, no-c-format
+msgid "Generate code without GP reg."
+msgstr ""
+
+#: config/ia64/ia64.opt:63
+#, no-c-format
+msgid "gp is constant (but save/restore gp on indirect calls)."
+msgstr ""
+
+#: config/ia64/ia64.opt:67
+#, no-c-format
+msgid "Generate self-relocatable code."
+msgstr ""
+
+#: config/ia64/ia64.opt:71
+#, no-c-format
+msgid "Generate inline floating point division, optimize for latency."
+msgstr ""
+
+#: config/ia64/ia64.opt:75
+#, no-c-format
+msgid "Generate inline floating point division, optimize for throughput."
+msgstr ""
+
+#: config/ia64/ia64.opt:82
+#, no-c-format
+msgid "Generate inline integer division, optimize for latency."
+msgstr ""
+
+#: config/ia64/ia64.opt:86
+#, no-c-format
+msgid "Generate inline integer division, optimize for throughput."
+msgstr ""
+
+#: config/ia64/ia64.opt:90
+#, no-c-format
+msgid "Do not inline integer division."
+msgstr ""
+
+#: config/ia64/ia64.opt:94
+#, no-c-format
+msgid "Generate inline square root, optimize for latency."
+msgstr ""
+
+#: config/ia64/ia64.opt:98
+#, no-c-format
+msgid "Generate inline square root, optimize for throughput."
+msgstr ""
+
+#: config/ia64/ia64.opt:102
+#, no-c-format
+msgid "Do not inline square root."
+msgstr ""
+
+#: config/ia64/ia64.opt:106
+#, no-c-format
+msgid "Enable DWARF line debug info via GNU as."
+msgstr ""
+
+#: config/ia64/ia64.opt:110
+#, no-c-format
+msgid "Enable earlier placing stop bits for better scheduling."
+msgstr ""
+
+#: config/ia64/ia64.opt:114 config/pa/pa.opt:70 config/sh/sh.opt:227
+#, no-c-format
+msgid "Specify range of registers to make fixed."
+msgstr ""
+
+#: config/ia64/ia64.opt:118 config/alpha/alpha.opt:130
+#, no-c-format
+msgid "Specify bit size of immediate TLS offsets."
+msgstr ""
+
+#: config/ia64/ia64.opt:122 config/i386/i386.opt:542 config/s390/s390.opt:203
+#: config/sparc/sparc.opt:146 config/visium/visium.opt:49
+#, no-c-format
+msgid "Schedule code for given CPU."
+msgstr ""
+
+#: config/ia64/ia64.opt:126
+#, no-c-format
+msgid "Known Itanium CPUs (for use with the -mtune= option):"
+msgstr ""
+
+#: config/ia64/ia64.opt:136
+#, no-c-format
+msgid "Use data speculation before reload."
+msgstr ""
+
+#: config/ia64/ia64.opt:140
+#, no-c-format
+msgid "Use data speculation after reload."
+msgstr ""
+
+#: config/ia64/ia64.opt:144
+#, no-c-format
+msgid "Use control speculation."
+msgstr ""
+
+#: config/ia64/ia64.opt:148
+#, no-c-format
+msgid "Use in block data speculation before reload."
+msgstr ""
+
+#: config/ia64/ia64.opt:152
+#, no-c-format
+msgid "Use in block data speculation after reload."
+msgstr ""
+
+#: config/ia64/ia64.opt:156
+#, no-c-format
+msgid "Use in block control speculation."
+msgstr ""
+
+#: config/ia64/ia64.opt:160
+#, no-c-format
+msgid "Use simple data speculation check."
+msgstr ""
+
+#: config/ia64/ia64.opt:164
+#, no-c-format
+msgid "Use simple data speculation check for control speculation."
+msgstr ""
+
+#: config/ia64/ia64.opt:174
+#, no-c-format
+msgid "Count speculative dependencies while calculating priority of instructions."
+msgstr ""
+
+#: config/ia64/ia64.opt:178
+#, no-c-format
+msgid "Place a stop bit after every cycle when scheduling."
+msgstr ""
+
+#: config/ia64/ia64.opt:182
+#, no-c-format
+msgid "Assume that floating-point stores and loads are not likely to cause conflict when placed into one instruction group."
+msgstr ""
+
+#: config/ia64/ia64.opt:186
+#, no-c-format
+msgid "Soft limit on number of memory insns per instruction group, giving lower priority to subsequent memory insns attempting to schedule in the same insn group. Frequently useful to prevent cache bank conflicts.  Default value is 1."
+msgstr ""
+
+#: config/ia64/ia64.opt:190
+#, no-c-format
+msgid "Disallow more than 'msched-max-memory-insns' in instruction group. Otherwise, limit is 'soft' (prefer non-memory operations when limit is reached)."
+msgstr ""
+
+#: config/ia64/ia64.opt:194
+#, no-c-format
+msgid "Don't generate checks for control speculation in selective scheduling."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:24
+#, no-c-format
+msgid "Don't use any of r32..r63."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:28
+#, no-c-format
+msgid "Preferentially allocate registers that allow short instruction generation."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:32
+#, no-c-format
+msgid "Set branch cost."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:36
+#, no-c-format
+msgid "Enable conditional move instruction usage."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:40
+#, no-c-format
+msgid "Set number of nops to emit before each insn pattern."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:52
+#, no-c-format
+msgid "Use software floating point comparisons."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:56
+#, no-c-format
+msgid "Enable split of 32 bit immediate loads into low / high part."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:60
+#, no-c-format
+msgid "Enable use of POST_INC / POST_DEC."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:64
+#, no-c-format
+msgid "Enable use of POST_MODIFY."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:68
+#, no-c-format
+msgid "Set number of bytes on the stack preallocated for use by the callee."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:72
+#, no-c-format
+msgid "Assume round to nearest is selected for purposes of scheduling."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:76
+#, no-c-format
+msgid "Generate call insns as indirect calls."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:80
+#, no-c-format
+msgid "Generate call insns as direct calls."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:84
+#, no-c-format
+msgid "Assume labels and symbols can be addressed using 16 bit absolute addresses."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:108
+#, no-c-format
+msgid "A floating point to integer truncation may be replaced with rounding to save mode switching."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:112
+#, no-c-format
+msgid "Vectorize for double-word operations."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:128
+#, no-c-format
+msgid "Split unaligned 8 byte vector moves before post-modify address generation."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:132
+#, no-c-format
+msgid "Use the floating point unit for integer add/subtract."
+msgstr ""
+
+#: config/epiphany/epiphany.opt:136
+#, no-c-format
+msgid "Set register to hold -1."
+msgstr ""
+
+#: config/ft32/ft32.opt:23
+#, no-c-format
+msgid "Target the software simulator."
+msgstr ""
+
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:234 config/mips/mips.opt:418
+#: config/arc/arc.opt:405
+#, no-c-format
+msgid "Use LRA instead of reload."
+msgstr ""
+
+#: config/ft32/ft32.opt:31
+#, no-c-format
+msgid "Avoid use of the DIV and MOD instructions."
+msgstr ""
+
+#: config/ft32/ft32.opt:35
+#, no-c-format
+msgid "Target the FT32B architecture."
+msgstr ""
+
+#: config/ft32/ft32.opt:39
+#, no-c-format
+msgid "Enable FT32B code compression."
+msgstr ""
+
+#: config/ft32/ft32.opt:43
+#, no-c-format
+msgid "Avoid placing any readable data in program memory."
+msgstr ""
+
+#: config/h8300/h8300.opt:23
+#, no-c-format
+msgid "Generate H8S code."
+msgstr ""
+
+#: config/h8300/h8300.opt:27
+#, no-c-format
+msgid "Generate H8SX code."
+msgstr ""
+
+#: config/h8300/h8300.opt:31
+#, no-c-format
+msgid "Generate H8S/2600 code."
+msgstr ""
+
+#: config/h8300/h8300.opt:35
+#, no-c-format
+msgid "Make integers 32 bits wide."
+msgstr ""
+
+#: config/h8300/h8300.opt:42
+#, no-c-format
+msgid "Use registers for argument passing."
+msgstr ""
+
+#: config/h8300/h8300.opt:46
+#, no-c-format
+msgid "Consider access to byte sized memory slow."
+msgstr ""
+
+#: config/h8300/h8300.opt:50
+#, no-c-format
+msgid "Enable linker relaxing."
+msgstr ""
+
+#: config/h8300/h8300.opt:54
+#, no-c-format
+msgid "Generate H8/300H code."
+msgstr ""
+
+#: config/h8300/h8300.opt:58
+#, no-c-format
+msgid "Enable the normal mode."
+msgstr ""
+
+#: config/h8300/h8300.opt:62
+#, no-c-format
+msgid "Use H8/300 alignment rules."
+msgstr ""
+
+#: config/h8300/h8300.opt:66
+#, no-c-format
+msgid "Push extended registers on stack in monitor functions."
+msgstr ""
+
+#: config/h8300/h8300.opt:70
+#, no-c-format
+msgid "Do not push extended registers on stack in monitor functions."
+msgstr ""
+
+#: config/pru/pru.opt:31
+#, no-c-format
+msgid "-mmcu=MCU\tSelect the target System-On-Chip variant that embeds this PRU."
+msgstr ""
+
+#: config/pru/pru.opt:35
+#, no-c-format
+msgid "Make GCC pass the --no-relax command-line option to the linker instead of the --relax option."
+msgstr ""
+
+#: config/pru/pru.opt:40
+#, no-c-format
+msgid "Allow (or do not allow) gcc to use the LOOP instruction."
+msgstr ""
+
+#: config/pru/pru.opt:44
+#, no-c-format
+msgid "Select target ABI variant."
+msgstr ""
+
+#: config/pru/pru.opt:48
+#, no-c-format
+msgid "ABI variant code generation (for use with -mabi= option):"
+msgstr ""
+
+#: config/pdp11/pdp11.opt:23
+#, no-c-format
+msgid "Generate code for an 11/10."
+msgstr ""
+
+#: config/pdp11/pdp11.opt:27
+#, no-c-format
+msgid "Generate code for an 11/40."
+msgstr ""
+
+#: config/pdp11/pdp11.opt:31
+#, no-c-format
+msgid "Generate code for an 11/45."
+msgstr ""
+
+#: config/pdp11/pdp11.opt:35
+#, no-c-format
+msgid "Return floating-point results in ac0 (fr0 in Unix assembler syntax)."
+msgstr ""
+
+#: config/pdp11/pdp11.opt:39
+#, no-c-format
+msgid "Use the DEC assembler syntax."
+msgstr ""
+
+#: config/pdp11/pdp11.opt:43
+#, no-c-format
+msgid "Use the GNU assembler syntax."
+msgstr ""
+
+#: config/pdp11/pdp11.opt:47 config/rs6000/rs6000.opt:183
+#: config/frv/frv.opt:158
+#, no-c-format
+msgid "Use hardware floating point."
+msgstr ""
+
+#: config/pdp11/pdp11.opt:51
+#, no-c-format
+msgid "Use 16 bit int."
+msgstr ""
+
+#: config/pdp11/pdp11.opt:55
+#, no-c-format
+msgid "Use 32 bit int."
+msgstr ""
+
+#: config/pdp11/pdp11.opt:59 config/rs6000/rs6000.opt:179
+#, no-c-format
+msgid "Do not use hardware floating point."
+msgstr ""
+
+#: config/pdp11/pdp11.opt:63
+#, no-c-format
+msgid "Target has split I&D."
+msgstr ""
+
+#: config/pdp11/pdp11.opt:67
+#, no-c-format
+msgid "Use UNIX assembler syntax."
+msgstr ""
+
+#: config/pdp11/pdp11.opt:71
+#, no-c-format
+msgid "Use LRA register allocator."
+msgstr ""
+
+#: config/xtensa/xtensa.opt:26
+#, no-c-format
+msgid "Use CONST16 instruction to load constants."
+msgstr ""
+
+#: config/xtensa/xtensa.opt:30
+#, no-c-format
+msgid "Disable position-independent code (PIC) for use in OS kernel code."
+msgstr ""
+
+#: config/xtensa/xtensa.opt:34
+#, no-c-format
+msgid "Use indirect CALLXn instructions for large programs."
+msgstr ""
+
+#: config/xtensa/xtensa.opt:38
+#, no-c-format
+msgid "Set extra memory access cost for L32R instruction, in clock-cycle units."
+msgstr ""
+
+#: config/xtensa/xtensa.opt:46
+#, no-c-format
+msgid "Automatically align branch targets to reduce branch penalties."
+msgstr ""
+
+#: config/xtensa/xtensa.opt:50
+#, no-c-format
+msgid "Intersperse literal pools with code in the text section."
+msgstr ""
+
+#: config/xtensa/xtensa.opt:54
+#, no-c-format
+msgid "Relax literals in assembler and place them automatically in the text section."
+msgstr ""
+
+#: config/xtensa/xtensa.opt:58
+#, no-c-format
+msgid "-mno-serialize-volatile\tDo not serialize volatile memory references with MEMW instructions."
+msgstr ""
+
+#: config/xtensa/xtensa.opt:65
+#, no-c-format
+msgid "Use call0 ABI."
+msgstr ""
+
+#: config/xtensa/xtensa.opt:69
+#, no-c-format
+msgid "Use windowed registers ABI."
+msgstr ""
+
+#: config/i386/cygming.opt:23
+#, no-c-format
+msgid "Create console application."
+msgstr ""
+
+#: config/i386/cygming.opt:27
+#, no-c-format
+msgid "Generate code for a DLL."
+msgstr ""
+
+#: config/i386/cygming.opt:31
+#, no-c-format
+msgid "Ignore dllimport for functions."
+msgstr ""
+
+#: config/i386/cygming.opt:35
+#, no-c-format
+msgid "Use Mingw-specific thread support."
+msgstr ""
+
+#: config/i386/cygming.opt:39
+#, no-c-format
+msgid "Set Windows defines."
+msgstr ""
+
+#: config/i386/cygming.opt:43
+#, no-c-format
+msgid "Create GUI application."
+msgstr ""
+
+#: config/i386/cygming.opt:47
+#, no-c-format
+msgid "Use the GNU extension to the PE format for aligned common data."
+msgstr ""
+
+#: config/i386/cygming.opt:51
+#, no-c-format
+msgid "Compile code that relies on Cygwin DLL wrappers to support C++ operator new/delete replacement."
+msgstr ""
+
+#: config/i386/cygming.opt:55
+#, no-c-format
+msgid "For nested functions on stack executable permission is set."
+msgstr ""
+
+#: config/i386/cygming.opt:62
+#, no-c-format
+msgid "Put relocated read-only data into .data section."
+msgstr ""
+
+#: config/i386/mingw.opt:23
+#, no-c-format
+msgid "Preprocess, compile or link with specified C RunTime DLL library."
+msgstr ""
+
+#: config/i386/mingw.opt:33
+#, no-c-format
+msgid "Warn about none ISO msvcrt scanf/printf width extensions."
+msgstr ""
+
+#: config/i386/mingw-w64.opt:23
+#, no-c-format
+msgid "Use unicode startup and define UNICODE macro."
+msgstr ""
+
+#: config/i386/i386.opt:213
+#, no-c-format
+msgid "sizeof(long double) is 16."
+msgstr ""
+
+#: config/i386/i386.opt:217 config/i386/i386.opt:385
+#, no-c-format
+msgid "Use hardware fp."
+msgstr ""
+
+#: config/i386/i386.opt:221
+#, no-c-format
+msgid "sizeof(long double) is 12."
+msgstr ""
+
+#: config/i386/i386.opt:225
+#, no-c-format
+msgid "Use 80-bit long double."
+msgstr ""
+
+#: config/i386/i386.opt:229 config/s390/s390.opt:163
+#: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
+#, no-c-format
+msgid "Use 64-bit long double."
+msgstr ""
+
+#: config/i386/i386.opt:233 config/s390/s390.opt:159
+#: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
+#, no-c-format
+msgid "Use 128-bit long double."
+msgstr ""
+
+#: config/i386/i386.opt:237 config/sh/sh.opt:179
+#, no-c-format
+msgid "Reserve space for outgoing arguments in the function prologue."
+msgstr ""
+
+#: config/i386/i386.opt:241
+#, no-c-format
+msgid "Align some doubles on dword boundary."
+msgstr ""
+
+#: config/i386/i386.opt:245
+#, no-c-format
+msgid "Function starts are aligned to this power of 2."
+msgstr ""
+
+#: config/i386/i386.opt:249
+#, no-c-format
+msgid "Jump targets are aligned to this power of 2."
+msgstr ""
+
+#: config/i386/i386.opt:253
+#, no-c-format
+msgid "Loop code aligned to this power of 2."
+msgstr ""
+
+#: config/i386/i386.opt:257
+#, no-c-format
+msgid "Align destination of the string operations."
+msgstr ""
+
+#: config/i386/i386.opt:278 config/s390/s390.opt:56
+#, no-c-format
+msgid "Generate code for given CPU."
+msgstr ""
+
+#: config/i386/i386.opt:282 config/bpf/bpf.opt:100
+#, no-c-format
+msgid "Use given assembler dialect."
+msgstr ""
+
+#: config/i386/i386.opt:286
+#, no-c-format
+msgid "Known assembler dialects (for use with the -masm= option):"
+msgstr ""
+
+#: config/i386/i386.opt:296
+#, no-c-format
+msgid "Branches are this expensive (arbitrary units)."
+msgstr ""
+
+#: config/i386/i386.opt:300
+#, no-c-format
+msgid "-mlarge-data-threshold=<number>\tData greater than given threshold will go into a large data section in x86-64 medium and large code models."
+msgstr ""
+
+#: config/i386/i386.opt:304
+#, no-c-format
+msgid "Use given x86-64 code model."
+msgstr ""
+
+#: config/i386/i386.opt:327
+#, no-c-format
+msgid "Use given address mode."
+msgstr ""
+
+#: config/i386/i386.opt:331
+#, no-c-format
+msgid "Known address mode (for use with the -maddress-mode= option):"
+msgstr ""
+
+#: config/i386/i386.opt:344
+#, no-c-format
+msgid "Generate sin, cos, sqrt for FPU."
+msgstr ""
+
+#: config/i386/i386.opt:348
+#, no-c-format
+msgid "Always use Dynamic Realigned Argument Pointer (DRAP) to realign stack."
+msgstr ""
+
+#: config/i386/i386.opt:352
+#, no-c-format
+msgid "Return values of functions in FPU registers."
+msgstr ""
+
+#: config/i386/i386.opt:356
+#, no-c-format
+msgid "Generate floating point mathematics using given instruction set."
+msgstr ""
+
+#: config/i386/i386.opt:360
+#, no-c-format
+msgid "Valid arguments to -mfpmath=:"
+msgstr ""
+
+#: config/i386/i386.opt:393
+#, no-c-format
+msgid "Inline all known string operations."
+msgstr ""
+
+#: config/i386/i386.opt:397
+#, no-c-format
+msgid "Inline memset/memcpy string operations, but perform inline version only for small blocks."
+msgstr ""
+
+#: config/i386/i386.opt:404
+#, no-c-format
+msgid "Use native (MS) bitfield layout."
+msgstr ""
+
+#: config/i386/i386.opt:424
+#, no-c-format
+msgid "Relax cmpxchg loop for atomic_fetch_{or,xor,and,nand} by adding load and cmp before cmpxchg, execute pause and loop back to load and compare if load value is not expected."
+msgstr ""
+
+#: config/i386/i386.opt:428
+#, no-c-format
+msgid "Set 80387 floating-point precision to 32-bit."
+msgstr ""
+
+#: config/i386/i386.opt:432
+#, no-c-format
+msgid "Set 80387 floating-point precision to 64-bit."
+msgstr ""
+
+#: config/i386/i386.opt:436
+#, no-c-format
+msgid "Set 80387 floating-point precision to 80-bit."
+msgstr ""
+
+#: config/i386/i386.opt:440
+#, no-c-format
+msgid "Set the FTZ and DAZ Flags."
+msgstr ""
+
+#: config/i386/i386.opt:448
+#, no-c-format
+msgid "Assume incoming stack aligned to this power of 2."
+msgstr ""
+
+#: config/i386/i386.opt:452
+#, no-c-format
+msgid "Use push instructions to save outgoing arguments."
+msgstr ""
+
+#: config/i386/i386.opt:456
+#, no-c-format
+msgid "Use red-zone in the x86-64 code."
+msgstr ""
+
+#: config/i386/i386.opt:460
+#, no-c-format
+msgid "Number of registers used to pass integer arguments."
+msgstr ""
+
+#: config/i386/i386.opt:464
+#, no-c-format
+msgid "Alternate calling convention."
+msgstr ""
+
+#: config/i386/i386.opt:468 config/alpha/alpha.opt:23
+#, no-c-format
+msgid "Do not use hardware fp."
+msgstr ""
+
+#: config/i386/i386.opt:472
+#, no-c-format
+msgid "Use SSE register passing conventions for SF and DF mode."
+msgstr ""
+
+#: config/i386/i386.opt:476
+#, no-c-format
+msgid "Realign stack in prologue."
+msgstr ""
+
+#: config/i386/i386.opt:480
+#, no-c-format
+msgid "Enable stack probing."
+msgstr ""
+
+#: config/i386/i386.opt:484
+#, no-c-format
+msgid "Specify memcpy expansion strategy when expected size is known."
+msgstr ""
+
+#: config/i386/i386.opt:488
+#, no-c-format
+msgid "Specify memset expansion strategy when expected size is known."
+msgstr ""
+
+#: config/i386/i386.opt:492
+#, no-c-format
+msgid "Chose strategy to generate stringop using."
+msgstr ""
+
+#: config/i386/i386.opt:524
+#, no-c-format
+msgid "Use given thread-local storage dialect."
+msgstr ""
+
+#: config/i386/i386.opt:528
+#, no-c-format
+msgid "Known TLS dialects (for use with the -mtls-dialect= option):"
+msgstr ""
+
+#: config/i386/i386.opt:538
+#, no-c-format
+msgid "Use direct references against %gs when accessing tls data."
+msgstr ""
+
+#: config/i386/i386.opt:546
+#, no-c-format
+msgid "Fine grain control of tune features."
+msgstr ""
+
+#: config/i386/i386.opt:550
+#, no-c-format
+msgid "Clear all tune features."
+msgstr ""
+
+#: config/i386/i386.opt:557
+#, no-c-format
+msgid "Generate code that conforms to Intel MCU psABI."
+msgstr ""
+
+#: config/i386/i386.opt:561
+#, no-c-format
+msgid "Generate code that conforms to the given ABI."
+msgstr ""
+
+#: config/i386/i386.opt:565 config/nds32/nds32.opt:51
+#, no-c-format
+msgid "Known ABIs (for use with the -mabi= option):"
+msgstr ""
+
+#: config/i386/i386.opt:575
+#, no-c-format
+msgid "Use libgcc stubs to save and restore registers clobbered by 64-bit Microsoft to System V ABI calls."
+msgstr ""
+
+#: config/i386/i386.opt:579 config/rs6000/rs6000.opt:195
+#, no-c-format
+msgid "Vector library ABI to use."
+msgstr ""
+
+#: config/i386/i386.opt:583
+#, no-c-format
+msgid "Known vectorization library ABIs (for use with the -mveclibabi= option):"
+msgstr ""
+
+#: config/i386/i386.opt:593
+#, no-c-format
+msgid "Return 8-byte vectors in memory."
+msgstr ""
+
+#: config/i386/i386.opt:597
+#, no-c-format
+msgid "Generate reciprocals instead of divss and sqrtss."
+msgstr ""
+
+#: config/i386/i386.opt:601 config/loongarch/loongarch.opt:235
+#, no-c-format
+msgid "Control generation of reciprocal estimates."
+msgstr ""
+
+#: config/i386/i386.opt:605
+#, no-c-format
+msgid "Generate cld instruction in the function prologue."
+msgstr ""
+
+#: config/i386/i386.opt:609
+#, no-c-format
+msgid "Generate vzeroupper instruction before a transfer of control flow out of the function."
+msgstr ""
+
+#: config/i386/i386.opt:614
+#, no-c-format
+msgid "Disable Scalar to Vector optimization pass transforming 64-bit integer computations into a vector ones."
+msgstr ""
+
+#: config/i386/i386.opt:619
+#, no-c-format
+msgid "The maximum number of use and def visits when discovering a STV chain before the discovery is aborted."
+msgstr ""
+
+#: config/i386/i386.opt:623
+#, no-c-format
+msgid "Do dispatch scheduling if processor is bdver1, bdver2, bdver3, bdver4 or znver1 and Haifa scheduling is selected."
+msgstr ""
+
+#: config/i386/i386.opt:628
+#, no-c-format
+msgid "Use 128-bit AVX instructions instead of 256-bit AVX instructions in the auto-vectorizer."
+msgstr ""
+
+#: config/i386/i386.opt:632
+#, no-c-format
+msgid "Use given register vector width instructions instead of maximum register width in the auto-vectorizer."
+msgstr ""
+
+#: config/i386/i386.opt:636
+#, no-c-format
+msgid "Known preferred register vector length (to use with the -mprefer-vector-width= option):"
+msgstr ""
+
+#: config/i386/i386.opt:652
+#, no-c-format
+msgid "Enable floating-point status flags setting SSE vector operations on partial vectors."
+msgstr ""
+
+#: config/i386/i386.opt:656
+#, no-c-format
+msgid "Maximum number of bits that can be moved from memory to memory efficiently."
+msgstr ""
+
+#: config/i386/i386.opt:660
+#, no-c-format
+msgid "Maximum number of bits that can be stored to memory efficiently."
+msgstr ""
+
+#: config/i386/i386.opt:664
+#, no-c-format
+msgid "Optimize noreturn functions by not saving callee-saved registers used in the function."
+msgstr ""
+
+#: config/i386/i386.opt:670
+#, no-c-format
+msgid "Generate 32bit i386 code."
+msgstr ""
+
+#: config/i386/i386.opt:674
+#, no-c-format
+msgid "Generate 64bit x86-64 code."
+msgstr ""
+
+#: config/i386/i386.opt:678
+#, no-c-format
+msgid "Generate 32bit x86-64 code."
+msgstr ""
+
+#: config/i386/i386.opt:682
+#, no-c-format
+msgid "Generate 16bit i386 code."
+msgstr ""
+
+#: config/i386/i386.opt:686
+#, no-c-format
+msgid "Support MMX built-in functions."
+msgstr ""
+
+#: config/i386/i386.opt:690
+#, no-c-format
+msgid "Support 3DNow! built-in functions."
+msgstr ""
+
+#: config/i386/i386.opt:694
+#, no-c-format
+msgid "Support Athlon 3Dnow! built-in functions."
+msgstr ""
+
+#: config/i386/i386.opt:698
+#, no-c-format
+msgid "Support MMX and SSE built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:702
+#, no-c-format
+msgid "Support MMX, SSE and SSE2 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:706
+#, no-c-format
+msgid "Support MMX, SSE, SSE2 and SSE3 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:710
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3 and SSSE3 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:714
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3 and SSE4.1 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:718 config/i386/i386.opt:722
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1 and SSE4.2 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:726
+#, no-c-format
+msgid "Do not support SSE4.1 and SSE4.2 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:734
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2 and AVX built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:738
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:742
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:746
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512PF built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:750
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512ER built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:754
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512CD built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:758
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512DQ built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:762
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512BW built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:766
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512VL built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:770
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512IFMA built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:774
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512VBMI built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:778
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX5124FMAPS built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:782
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX5124VNNIW built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:786
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX512VPOPCNTDQ built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:790
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX512VBMI2 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:794
+#, no-c-format
+msgid "Support AVX512VNNI built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:798
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX512BITALG built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:802
+#, no-c-format
+msgid "Support AVX512VP2INTERSECT built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:806
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:810
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3 and SSE4A built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:814
+#, no-c-format
+msgid "Support FMA4 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:818
+#, no-c-format
+msgid "Support XOP built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:822
+#, no-c-format
+msgid "Support LWP built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:826
+#, no-c-format
+msgid "Support code generation of Advanced Bit Manipulation (ABM) instructions."
+msgstr ""
+
+#: config/i386/i386.opt:830
+#, no-c-format
+msgid "Support code generation of popcnt instruction."
+msgstr ""
+
+#: config/i386/i386.opt:834
+#, no-c-format
+msgid "Support PCONFIG built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:838
+#, no-c-format
+msgid "Support WBNOINVD built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:842
+#, no-c-format
+msgid "Support PTWRITE built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:846
+#, no-c-format
+msgid "Support UINTR built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:850
+#, no-c-format
+msgid "Support SGX built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:854
+#, no-c-format
+msgid "Support RDPID built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:858
+#, no-c-format
+msgid "Support GFNI built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:862
+#, no-c-format
+msgid "Support VAES built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:866
+#, no-c-format
+msgid "Support VPCLMULQDQ built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:870
+#, no-c-format
+msgid "Support BMI built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:874
+#, no-c-format
+msgid "Support BMI2 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:878
+#, no-c-format
+msgid "Support LZCNT built-in function and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:882
+#, no-c-format
+msgid "Support Hardware Lock Elision prefixes."
+msgstr ""
+
+#: config/i386/i386.opt:886
+#, no-c-format
+msgid "Support RDSEED instruction."
+msgstr ""
+
+#: config/i386/i386.opt:890
+#, no-c-format
+msgid "Support PREFETCHW instruction."
+msgstr ""
+
+#: config/i386/i386.opt:894
+#, no-c-format
+msgid "Support flag-preserving add-carry instructions."
+msgstr ""
+
+#: config/i386/i386.opt:898
+#, no-c-format
+msgid "Support CLFLUSHOPT instructions."
+msgstr ""
+
+#: config/i386/i386.opt:902
+#, no-c-format
+msgid "Support CLWB instruction."
+msgstr ""
+
+#: config/i386/i386.opt:909
+#, no-c-format
+msgid "Support FXSAVE and FXRSTOR instructions."
+msgstr ""
+
+#: config/i386/i386.opt:913
+#, no-c-format
+msgid "Support XSAVE and XRSTOR instructions."
+msgstr ""
+
+#: config/i386/i386.opt:917
+#, no-c-format
+msgid "Support XSAVEOPT instruction."
+msgstr ""
+
+#: config/i386/i386.opt:921
+#, no-c-format
+msgid "Support XSAVEC instructions."
+msgstr ""
+
+#: config/i386/i386.opt:925
+#, no-c-format
+msgid "Support XSAVES and XRSTORS instructions."
+msgstr ""
+
+#: config/i386/i386.opt:929
+#, no-c-format
+msgid "Support TBM built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:933
+#, no-c-format
+msgid "Support code generation of cmpxchg16b instruction."
+msgstr ""
+
+#: config/i386/i386.opt:937
+#, no-c-format
+msgid "Support code generation of sahf instruction in 64bit x86-64 code."
+msgstr ""
+
+#: config/i386/i386.opt:941
+#, no-c-format
+msgid "Support code generation of movbe instruction."
+msgstr ""
+
+#: config/i386/i386.opt:945
+#, no-c-format
+msgid "Support code generation of crc32 instruction."
+msgstr ""
+
+#: config/i386/i386.opt:949
+#, no-c-format
+msgid "Support AES built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:953
+#, no-c-format
+msgid "Support SHA1 and SHA256 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:957
+#, no-c-format
+msgid "Support PCLMUL built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:961
+#, no-c-format
+msgid "Encode SSE instructions with VEX prefix."
+msgstr ""
+
+#: config/i386/i386.opt:965
+#, no-c-format
+msgid "Support FSGSBASE built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:969
+#, no-c-format
+msgid "Support RDRND built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:973
+#, no-c-format
+msgid "Support F16C built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:977
+#, no-c-format
+msgid "Support PREFETCHWT1 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:981
+#, no-c-format
+msgid "Emit profiling counter call at function entry before prologue."
+msgstr ""
+
+#: config/i386/i386.opt:985
+#, no-c-format
+msgid "Generate __mcount_loc section with all mcount or __fentry__ calls."
+msgstr ""
+
+#: config/i386/i386.opt:989 config/s390/s390.opt:311
+#, no-c-format
+msgid "Generate mcount/__fentry__ calls as nops. To activate they need to be patched in."
+msgstr ""
+
+#: config/i386/i386.opt:994
+#, no-c-format
+msgid "Set name of __fentry__ symbol called at function entry."
+msgstr ""
+
+#: config/i386/i386.opt:998
+#, no-c-format
+msgid "Set name of section to record mrecord-mcount calls."
+msgstr ""
+
+#: config/i386/i386.opt:1002
+#, no-c-format
+msgid "Skip setting up RAX register when passing variable arguments."
+msgstr ""
+
+#: config/i386/i386.opt:1006
+#, no-c-format
+msgid "Expand 32bit/64bit integer divide into 8bit unsigned integer divide with run-time check."
+msgstr ""
+
+#: config/i386/i386.opt:1010
+#, no-c-format
+msgid "Split 32-byte AVX unaligned load."
+msgstr ""
+
+#: config/i386/i386.opt:1014
+#, no-c-format
+msgid "Split 32-byte AVX unaligned store."
+msgstr ""
+
+#: config/i386/i386.opt:1018
+#, no-c-format
+msgid "Support RTM built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1026
+#, no-c-format
+msgid "Support MWAITX and MONITORX built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1030
+#, no-c-format
+msgid "Support CLZERO built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1034
+#, no-c-format
+msgid "Support PKU built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1042
+#, no-c-format
+msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
+msgstr ""
+
+#: config/i386/i386.opt:1066
+#, no-c-format
+msgid "Use the given symbol for addressing the stack-protector guard."
+msgstr ""
+
+#: config/i386/i386.opt:1077
+#, no-c-format
+msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
+msgstr ""
+
+#: config/i386/i386.opt:1082
+#, no-c-format
+msgid "Turn on CET instrumentation for switch statements that use a jump table and an indirect jump."
+msgstr ""
+
+#: config/i386/i386.opt:1087
+#, no-c-format
+msgid "Insert ENDBR instruction at function entry only via cf_check attribute for CET instrumentation."
+msgstr ""
+
+#: config/i386/i386.opt:1092
+#, no-c-format
+msgid "Make all function calls indirect."
+msgstr ""
+
+#: config/i386/i386.opt:1096
+#, no-c-format
+msgid "Convert indirect call and jump to call and return thunks."
+msgstr ""
+
+#: config/i386/i386.opt:1100
+#, no-c-format
+msgid "Convert function return to call and return thunk."
+msgstr ""
+
+#: config/i386/i386.opt:1104 config/s390/s390.opt:277
+#, no-c-format
+msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
+msgstr ""
+
+#: config/i386/i386.opt:1120
+#, no-c-format
+msgid "Add CS prefix to call and jmp to indirect thunk with branch target in r8-r15 registers."
+msgstr ""
+
+#: config/i386/i386.opt:1124
+#, no-c-format
+msgid "Force indirect call and jump via register."
+msgstr ""
+
+#: config/i386/i386.opt:1128
+#, no-c-format
+msgid "Support MOVDIRI built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1132
+#, no-c-format
+msgid "Support MOVDIR64B built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1136
+#, no-c-format
+msgid "Support WAITPKG built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1140
+#, no-c-format
+msgid "Support CLDEMOTE built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1144
+#, no-c-format
+msgid "Instrument function exit in instrumented functions with __fentry__."
+msgstr ""
+
+#: config/i386/i386.opt:1148
+#, no-c-format
+msgid "Known choices for return instrumentation with -minstrument-return=:"
+msgstr ""
+
+#: config/i386/i386.opt:1161
+#, no-c-format
+msgid "Generate a __return_loc section pointing to all return instrumentation code."
+msgstr ""
+
+#: config/i386/i386.opt:1169
+#, no-c-format
+msgid "Known choices for mitigation against straight line speculation with -mharden-sls=:"
+msgstr ""
+
+#: config/i386/i386.opt:1185
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX512BF16 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1190
+#, no-c-format
+msgid "Support ENQCMD built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1194
+#, no-c-format
+msgid "Support SERIALIZE built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1198
+#, no-c-format
+msgid "Support TSXLDTRK built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1202
+#, no-c-format
+msgid "Support AMX-TILE built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1206
+#, no-c-format
+msgid "Support AMX-INT8 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1210
+#, no-c-format
+msgid "Support AMX-BF16 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1214
+#, no-c-format
+msgid "Support HRESET built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1218
+#, no-c-format
+msgid "Support KL built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1222
+#, no-c-format
+msgid "Support WIDEKL built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1226
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, and AVXVNNI built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1231
+#, no-c-format
+msgid "Emit GNU_PROPERTY_X86_ISA_1_NEEDED GNU property."
+msgstr ""
+
+#: config/i386/i386.opt:1235
+#, no-c-format
+msgid "Support MWAIT and MONITOR built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1239
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX512-FP16 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1243
+#, no-c-format
+msgid "Do not use GOT to access external symbols."
+msgstr ""
+
+#: config/i386/i386.opt:1247
+#, no-c-format
+msgid "Instructions number above which STFL stall penalty can be compensated."
+msgstr ""
+
+#: config/i386/i386.opt:1251
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, and AVXIFMA built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1256
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVXVNNIINT8 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1261
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, and AVXNECONVERT build-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1266
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, and CMPCCXADD build-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1271
+#, no-c-format
+msgid "Support AMX-FP16 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1275
+#, no-c-format
+msgid "Support PREFETCHI built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1279
+#, no-c-format
+msgid "Support RAOINT built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1283
+#, no-c-format
+msgid "Enable conservative small loop unrolling."
+msgstr ""
+
+#: config/i386/i386.opt:1287
+#, no-c-format
+msgid "-mlam=[none|u48|u57] Instrument meta data position in user data pointers."
+msgstr ""
+
+#: config/i386/i386.opt:1303
+#, no-c-format
+msgid "Support AMX-COMPLEX built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1307
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVXVNNIINT16 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1312
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and SM3 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1317
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and SHA512 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1322
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and SM4 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1327
+#, no-c-format
+msgid "Enable vectorization for gather instruction."
+msgstr ""
+
+#: config/i386/i386.opt:1331
+#, no-c-format
+msgid "Enable vectorization for scatter instruction."
+msgstr ""
+
+#: config/i386/i386.opt:1335
+#, no-c-format
+msgid "Support code generation for APX features, including EGPR, PUSH2POP2, NDD and PPX."
+msgstr ""
+
+#: config/i386/i386.opt:1364
+#, no-c-format
+msgid "Enable GPR32 in inline asm when APX_F enabled."
+msgstr ""
+
+#: config/i386/i386.opt:1368
+#, no-c-format
+msgid "Support 512 bit vector built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1372
+#, no-c-format
+msgid "Support USER_MSR built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1376 config/i386/i386.opt:1386
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, and AVX10.1 built-in functions and code generation."
+msgstr ""
+
+#: config/i386/i386.opt:1381
+#, no-c-format
+msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, and AVX10.1-512 built-in functions and code generation."
+msgstr ""
+
+#: config/pa/pa64-hpux.opt:23
+#, no-c-format
+msgid "Assume code will be linked by GNU ld."
+msgstr ""
+
+#: config/pa/pa64-hpux.opt:27
+#, no-c-format
+msgid "Assume code will be linked by HP ld."
+msgstr ""
+
+#: config/pa/pa-hpux1010.opt:23 config/pa/pa-hpux.opt:31
+#: config/pa/pa-hpux1131.opt:23 config/pa/pa-hpux1111.opt:23
+#, no-c-format
+msgid "Specify UNIX standard for predefines and linking."
+msgstr ""
+
+#: config/pa/pa-hpux.opt:27
+#, no-c-format
+msgid "Generate cpp defines for server IO."
+msgstr ""
+
+#: config/pa/pa-hpux.opt:35
+#, no-c-format
+msgid "Generate cpp defines for workstation IO."
+msgstr ""
+
+#: config/pa/pa.opt:30 config/pa/pa.opt:95 config/pa/pa.opt:107
+#, no-c-format
+msgid "Generate PA1.0 code."
+msgstr ""
+
+#: config/pa/pa.opt:34 config/pa/pa.opt:111 config/pa/pa.opt:156
+#, no-c-format
+msgid "Generate PA1.1 code."
+msgstr ""
+
+#: config/pa/pa.opt:38 config/pa/pa.opt:115
+#, no-c-format
+msgid "Generate PA2.0 code (requires binutils 2.10 or later)."
+msgstr ""
+
+#: config/pa/pa.opt:42
+#, no-c-format
+msgid "Generate libcalls for atomic loads and stores when sync libcalls are disabled."
+msgstr ""
+
+#: config/pa/pa.opt:50
+#, no-c-format
+msgid "Caller copies function arguments passed by hidden reference."
+msgstr ""
+
+#: config/pa/pa.opt:54
+#, no-c-format
+msgid "Use ldcw/ldcd coherent cache-control hint."
+msgstr ""
+
+#: config/pa/pa.opt:58
+#, no-c-format
+msgid "Disable FP regs.  Equivalent to -msoft-float."
+msgstr ""
+
+#: config/pa/pa.opt:62
+#, no-c-format
+msgid "Disable indexed addressing."
+msgstr ""
+
+#: config/pa/pa.opt:66
+#, no-c-format
+msgid "Generate fast indirect calls."
+msgstr ""
+
+#: config/pa/pa.opt:74
+#, no-c-format
+msgid "Assume code will be assembled by GAS."
+msgstr ""
+
+#: config/pa/pa.opt:83
+#, no-c-format
+msgid "Enable linker optimizations."
+msgstr ""
+
+#: config/pa/pa.opt:87
+#, no-c-format
+msgid "Always generate long calls."
+msgstr ""
+
+#: config/pa/pa.opt:91
+#, no-c-format
+msgid "Emit long load/store sequences."
+msgstr ""
+
+#: config/pa/pa.opt:99
+#, no-c-format
+msgid "Disable space regs."
+msgstr ""
+
+#: config/pa/pa.opt:103
+#, no-c-format
+msgid "Assume memory references are ordered and barriers are not needed."
+msgstr ""
+
+#: config/pa/pa.opt:119
+#, no-c-format
+msgid "Use portable calling conventions."
+msgstr ""
+
+#: config/pa/pa.opt:123
+#, no-c-format
+msgid "Specify CPU for scheduling purposes.  Valid arguments are 700, 7100, 7100LC, 7200, 7300, and 8000."
+msgstr ""
+
+#: config/pa/pa.opt:148 config/frv/frv.opt:215
+#, no-c-format
+msgid "Use software floating point."
+msgstr ""
+
+#: config/pa/pa.opt:152
+#, no-c-format
+msgid "Use software integer multiplication."
+msgstr ""
+
+#: config/pa/pa.opt:160
+#, no-c-format
+msgid "Do not disable space regs."
+msgstr ""
+
+#: config/v850/v850.opt:29
+#, no-c-format
+msgid "Use registers r2 and r5."
+msgstr ""
+
+#: config/v850/v850.opt:33
+#, no-c-format
+msgid "Use 4 byte entries in switch tables."
+msgstr ""
+
+#: config/v850/v850.opt:37
+#, no-c-format
+msgid "Enable backend debugging."
+msgstr ""
+
+#: config/v850/v850.opt:41
+#, no-c-format
+msgid "Do not use the callt instruction (default)."
+msgstr ""
+
+#: config/v850/v850.opt:45
+#, no-c-format
+msgid "Reuse r30 on a per function basis."
+msgstr ""
+
+#: config/v850/v850.opt:52
+#, no-c-format
+msgid "Prohibit PC relative function calls."
+msgstr ""
+
+#: config/v850/v850.opt:56
+#, no-c-format
+msgid "Use stubs for function prologues."
+msgstr ""
+
+#: config/v850/v850.opt:60
+#, no-c-format
+msgid "Set the max size of data eligible for the SDA area."
+msgstr ""
+
+#: config/v850/v850.opt:67
+#, no-c-format
+msgid "Enable the use of the short load instructions."
+msgstr ""
+
+#: config/v850/v850.opt:71
+#, no-c-format
+msgid "Same as: -mep -mprolog-function."
+msgstr ""
+
+#: config/v850/v850.opt:75
+#, no-c-format
+msgid "Set the max size of data eligible for the TDA area."
+msgstr ""
+
+#: config/v850/v850.opt:82
+#, no-c-format
+msgid "Do not enforce strict alignment."
+msgstr ""
+
+#: config/v850/v850.opt:86
+#, no-c-format
+msgid "Put jump tables for switch statements into the .data section rather than the .code section."
+msgstr ""
+
+#: config/v850/v850.opt:93
+#, no-c-format
+msgid "Compile for the v850 processor."
+msgstr ""
+
+#: config/v850/v850.opt:97
+#, no-c-format
+msgid "Compile for the v850e processor."
+msgstr ""
+
+#: config/v850/v850.opt:101
+#, no-c-format
+msgid "Compile for the v850e1 processor."
+msgstr ""
+
+#: config/v850/v850.opt:105
+#, no-c-format
+msgid "Compile for the v850es variant of the v850e1."
+msgstr ""
+
+#: config/v850/v850.opt:109
+#, no-c-format
+msgid "Compile for the v850e2 processor."
+msgstr ""
+
+#: config/v850/v850.opt:113
+#, no-c-format
+msgid "Compile for the v850e2v3 processor."
+msgstr ""
+
+#: config/v850/v850.opt:117
+#, no-c-format
+msgid "Compile for the v850e3v5 processor."
+msgstr ""
+
+#: config/v850/v850.opt:124
+#, no-c-format
+msgid "Enable v850e3v5 loop instructions."
+msgstr ""
+
+#: config/v850/v850.opt:128
+#, no-c-format
+msgid "Set the max size of data eligible for the ZDA area."
+msgstr ""
+
+#: config/v850/v850.opt:135
+#, no-c-format
+msgid "Enable relaxing in the assembler."
+msgstr ""
+
+#: config/v850/v850.opt:139
+#, no-c-format
+msgid "Prohibit PC relative jumps."
+msgstr ""
+
+#: config/v850/v850.opt:143
+#, no-c-format
+msgid "Inhibit the use of hardware floating point instructions."
+msgstr ""
+
+#: config/v850/v850.opt:147
+#, no-c-format
+msgid "Allow the use of hardware floating point instructions for V850E2V3 and up."
+msgstr ""
+
+#: config/v850/v850.opt:151
+#, no-c-format
+msgid "Enable support for the RH850 ABI.  This is the default."
+msgstr ""
+
+#: config/v850/v850.opt:155
+#, no-c-format
+msgid "Enable support for the old GCC ABI."
+msgstr ""
+
+#: config/v850/v850.opt:159
+#, no-c-format
+msgid "Support alignments of up to 64-bits."
+msgstr ""
+
+#: config/g.opt:27
+#, no-c-format
+msgid "-G<number>\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
+msgstr ""
+
+#: config/lynx.opt:23
+#, no-c-format
+msgid "Support legacy multi-threading."
+msgstr ""
+
+#: config/lynx.opt:27
+#, no-c-format
+msgid "Use shared libraries."
+msgstr ""
+
+#: config/lynx.opt:31
+#, no-c-format
+msgid "Support multi-threading."
+msgstr ""
+
+#: config/nvptx/nvptx-gen.opt:24
+#, no-c-format
+msgid "Known PTX ISA target architectures (for use with the -misa= option):"
+msgstr ""
+
+#: config/nvptx/nvptx.opt:28
+#, no-c-format
+msgid "Ignored, but preserved for backward compatibility.  Only 64-bit ABI is supported."
+msgstr ""
+
+#: config/nvptx/nvptx.opt:33
+#, no-c-format
+msgid "Link in code for a __main kernel."
+msgstr ""
+
+#: config/nvptx/nvptx.opt:37
+#, no-c-format
+msgid "Optimize partition neutering."
+msgstr ""
+
+#: config/nvptx/nvptx.opt:41
+#, no-c-format
+msgid "Use custom stacks instead of local memory for automatic storage."
+msgstr ""
+
+#: config/nvptx/nvptx.opt:45
+#, no-c-format
+msgid "Specify size of .local memory used for stack when the exact amount is not known."
+msgstr ""
+
+#: config/nvptx/nvptx.opt:49
+#, no-c-format
+msgid "Generate code that can keep local state uniform across all lanes."
+msgstr ""
+
+#: config/nvptx/nvptx.opt:53
+#, no-c-format
+msgid "Generate code for OpenMP offloading: enables -msoft-stack and -muniform-simt."
+msgstr ""
+
+#: config/nvptx/nvptx.opt:57
+#, no-c-format
+msgid "Specify the PTX ISA target architecture to use."
+msgstr ""
+
+#: config/nvptx/nvptx.opt:61
+#, no-c-format
+msgid "Alias:"
+msgstr "მეტსახელი:"
+
+#: config/nvptx/nvptx.opt:122
+#, no-c-format
+msgid "Known PTX ISA versions (for use with the -mptx= option):"
+msgstr ""
+
+#: config/nvptx/nvptx.opt:141
+#, no-c-format
+msgid "Specify the PTX ISA version to use."
+msgstr ""
+
+#: config/nvptx/nvptx.opt:145
+#, no-c-format
+msgid "Initialize ptx registers."
+msgstr ""
+
+#: config/vxworks.opt:36
+#, no-c-format
+msgid "Assume the VxWorks RTP environment."
+msgstr ""
+
+#: config/vxworks.opt:43
+#, no-c-format
+msgid "Assume the VxWorks vThreads environment."
+msgstr ""
+
+#: config/avr/avr.opt:23
+#, no-c-format
+msgid "Optimization. Use subroutines for function prologues and epilogues."
+msgstr ""
+
+#: config/avr/avr.opt:27
+#, no-c-format
+msgid "-mmcu=<MCU>\tSelect the target MCU."
+msgstr ""
+
+#: config/avr/avr.opt:31
+#, no-c-format
+msgid "Optimization. Allow usage of __gcc_isr pseudo instructions in ISR prologues and epilogues."
+msgstr ""
+
+#: config/avr/avr.opt:35
+#, no-c-format
+msgid "This option is used internally. Set the number of 64 KiB flash segments."
+msgstr ""
+
+#: config/avr/avr.opt:39
+#, no-c-format
+msgid "This option is used internally. Indicate presence of a processor erratum.  Do not skip 32-bit instructions."
+msgstr ""
+
+#: config/avr/avr.opt:43
+#, no-c-format
+msgid "This option is used internally. Enable Read-Modify-Write (RMW) instructions support/use."
+msgstr ""
+
+#: config/avr/avr.opt:53
+#, no-c-format
+msgid "This option is used internally for multilib generation and selection.  Assume RJMP / RCALL can target all program memory."
+msgstr ""
+
+#: config/avr/avr.opt:57
+#, no-c-format
+msgid "Use an 8-bit 'int' type."
+msgstr ""
+
+#: config/avr/avr.opt:61
+#, no-c-format
+msgid "Change the stack pointer without disabling interrupts."
+msgstr ""
+
+#: config/avr/avr.opt:65
+#, no-c-format
+msgid "-mbranch-cost=<cost>\tOptimization. Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 0."
+msgstr ""
+
+#: config/avr/avr.opt:69
+#, no-c-format
+msgid "Optimization. Treat main as if it had attribute OS_task."
+msgstr ""
+
+#: config/avr/avr.opt:79
+#, no-c-format
+msgid "Change only the low 8 bits of the stack pointer."
+msgstr ""
+
+#: config/avr/avr.opt:83
+#, no-c-format
+msgid "Optimization. Relax branches."
+msgstr ""
+
+#: config/avr/avr.opt:87
+#, no-c-format
+msgid "Make the linker relaxation machine assume that a program counter wrap-around occurs."
+msgstr ""
+
+#: config/avr/avr.opt:91
+#, no-c-format
+msgid "Optimization. Accumulate outgoing function arguments and acquire/release the needed stack space for outgoing function arguments in function prologue/epilogue.  Without this option, outgoing arguments are pushed before calling a function and popped afterwards.  This option can lead to reduced code size for functions that call many functions that get their arguments on the stack like, for example printf."
+msgstr ""
+
+#: config/avr/avr.opt:95
+#, no-c-format
+msgid "Optimization. When accessing RAM, use X as imposed by the hardware, i.e. just use pre-decrement, post-increment and indirect addressing with the X register.  Without this option, the compiler may assume that there is an addressing mode X+const similar to Y+const and Z+const and emit instructions to emulate such an addressing mode for X."
+msgstr ""
+
+#: config/avr/avr.opt:99
+#, no-c-format
+msgid "This option is used internally. The device has the bitfield NVMCTRL_CTRLB.FLMAP."
+msgstr ""
+
+#: config/avr/avr.opt:103
+#, no-c-format
+msgid "The device has the .rodata section located in the RAM area."
+msgstr ""
+
+#: config/avr/avr.opt:108
+#, no-c-format
+msgid "This option is used internally for multilib generation and selection. The device has no SPH special function register."
+msgstr ""
+
+#: config/avr/avr.opt:112
+#, no-c-format
+msgid "Optimization. Split register additions from load/store instructions. Most useful on Reduced Tiny."
+msgstr ""
+
+#: config/avr/avr.opt:116
+#, no-c-format
+msgid "-mfuse-add=<0,2>\tOptimization. Split register additions from load/store instructions. Most useful on Reduced Tiny."
+msgstr ""
+
+#: config/avr/avr.opt:120
+#, no-c-format
+msgid "Warn if the address space of an address is changed."
+msgstr ""
+
+#: config/avr/avr.opt:124
+#, no-c-format
+msgid "Warn if the ISR is misspelled, i.e. without __vector prefix. Enabled by default."
+msgstr ""
+
+#: config/avr/avr.opt:128
+#, no-c-format
+msgid "Allow to use truncation instead of rounding towards zero for fractional fixed-point types."
+msgstr ""
+
+#: config/avr/avr.opt:132
+#, no-c-format
+msgid "Assume that all data in static storage can be accessed by LDS / STS instructions.  This option is only useful for reduced Tiny devices like ATtiny40."
+msgstr ""
+
+#: config/avr/avr.opt:136
+#, no-c-format
+msgid "-mdouble=<BITS>\tUse <BITS> bits wide double type."
+msgstr ""
+
+#: config/avr/avr.opt:140
+#, no-c-format
+msgid "-mlong-double=<BITS>\tUse <BITS> bits wide long double type."
+msgstr ""
+
+#: config/avr/avr.opt:144
+#, no-c-format
+msgid "Do not link against the device-specific library lib<MCU>.a."
+msgstr ""
+
+#: config/avr/avr.opt:148
+#, no-c-format
+msgid "Do not use the device-specific specs file device-specs/specs-<MCU>."
+msgstr ""
+
+#: config/avr/avr.opt:152
+#, no-c-format
+msgid "Available BITS selections:"
+msgstr ""
+
+#: config/m32r/m32r.opt:34
+#, no-c-format
+msgid "Compile for the m32rx."
+msgstr ""
+
+#: config/m32r/m32r.opt:38
+#, no-c-format
+msgid "Compile for the m32r2."
+msgstr ""
+
+#: config/m32r/m32r.opt:42
+#, no-c-format
+msgid "Compile for the m32r."
+msgstr ""
+
+#: config/m32r/m32r.opt:46
+#, no-c-format
+msgid "Align all loops to 32 byte boundary."
+msgstr ""
+
+#: config/m32r/m32r.opt:50
+#, no-c-format
+msgid "Prefer branches over conditional execution."
+msgstr ""
+
+#: config/m32r/m32r.opt:54
+#, no-c-format
+msgid "Give branches their default cost."
+msgstr ""
+
+#: config/m32r/m32r.opt:58
+#, no-c-format
+msgid "Display compile time statistics."
+msgstr ""
+
+#: config/m32r/m32r.opt:62
+#, no-c-format
+msgid "Specify cache flush function."
+msgstr ""
+
+#: config/m32r/m32r.opt:66
+#, no-c-format
+msgid "Specify cache flush trap number."
+msgstr ""
+
+#: config/m32r/m32r.opt:70
+#, no-c-format
+msgid "Only issue one instruction per cycle."
+msgstr ""
+
+#: config/m32r/m32r.opt:74
+#, no-c-format
+msgid "Allow two instructions to be issued per cycle."
+msgstr ""
+
+#: config/m32r/m32r.opt:78
+#, no-c-format
+msgid "Code size: small, medium or large."
+msgstr ""
+
+#: config/m32r/m32r.opt:94
+#, no-c-format
+msgid "Don't call any cache flush functions."
+msgstr ""
+
+#: config/m32r/m32r.opt:98
+#, no-c-format
+msgid "Don't call any cache flush trap."
+msgstr ""
+
+#: config/m32r/m32r.opt:105
+#, no-c-format
+msgid "Small data area: none, sdata, use."
+msgstr ""
+
+#: config/s390/tpf.opt:23
+#, no-c-format
+msgid "Enable TPF-OS tracing code."
+msgstr ""
+
+#: config/s390/tpf.opt:27
+#, no-c-format
+msgid "Set the trace check address for prologue tpf hook"
+msgstr ""
+
+#: config/s390/tpf.opt:31
+#, no-c-format
+msgid "Set the trace jump address for prologue tpf hook"
+msgstr ""
+
+#: config/s390/tpf.opt:35
+#, no-c-format
+msgid "Set the trace check address for epilogue tpf hook"
+msgstr ""
+
+#: config/s390/tpf.opt:39
+#, no-c-format
+msgid "Set the trace jump address for epilogue tpf hook"
+msgstr ""
+
+#: config/s390/tpf.opt:43
+#, no-c-format
+msgid "Set the prologue and epilogue hook addresses to TPF_TRACE_PROLOGUE_SKIP_TARGET and TPF_TRACE_EPILOGUE_SKIP_TARGET. Equivalent to using -mtpf-trace-hook-prologue-target=TPF_TRACE_PROLOGUE_SKIP_TARGET and -mtpf-trace-hook-epilogue-target=TPF_TRACE_EPILOGUE_SKIP_TARGET"
+msgstr ""
+
+#: config/s390/tpf.opt:47
+#, no-c-format
+msgid "Specify main object for TPF-OS."
+msgstr ""
+
+#: config/s390/s390.opt:48
+#, no-c-format
+msgid "31 bit ABI."
+msgstr ""
+
+#: config/s390/s390.opt:52
+#, no-c-format
+msgid "64 bit ABI."
+msgstr ""
+
+#: config/s390/s390.opt:129
+#, no-c-format
+msgid "Maintain backchain pointer."
+msgstr ""
+
+#: config/s390/s390.opt:133
+#, no-c-format
+msgid "Additional debug prints."
+msgstr ""
+
+#: config/s390/s390.opt:137
+#, no-c-format
+msgid "ESA/390 architecture."
+msgstr ""
+
+#: config/s390/s390.opt:141
+#, no-c-format
+msgid "Enable decimal floating point hardware support."
+msgstr ""
+
+#: config/s390/s390.opt:145
+#, no-c-format
+msgid "Enable hardware floating point."
+msgstr ""
+
+#: config/s390/s390.opt:149
+#, no-c-format
+msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
+msgstr ""
+
+#: config/s390/s390.opt:167
+#, no-c-format
+msgid "Use hardware transactional execution instructions."
+msgstr ""
+
+#: config/s390/s390.opt:171
+#, no-c-format
+msgid "Use hardware vector facility instructions and enable the vector ABI."
+msgstr ""
+
+#: config/s390/s390.opt:175
+#, no-c-format
+msgid "Use packed stack layout."
+msgstr ""
+
+#: config/s390/s390.opt:179
+#, no-c-format
+msgid "Use bras for executable < 64k."
+msgstr ""
+
+#: config/s390/s390.opt:183
+#, no-c-format
+msgid "Disable hardware floating point."
+msgstr ""
+
+#: config/s390/s390.opt:187
+#, no-c-format
+msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
+msgstr ""
+
+#: config/s390/s390.opt:191
+#, no-c-format
+msgid "Switches off the -mstack-guard= option."
+msgstr ""
+
+#: config/s390/s390.opt:195
+#, no-c-format
+msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
+msgstr ""
+
+#: config/s390/s390.opt:199
+#, no-c-format
+msgid "Switches off the -mstack-size= option."
+msgstr ""
+
+#: config/s390/s390.opt:207
+#, no-c-format
+msgid "Use the mvcle instruction for block moves."
+msgstr ""
+
+#: config/s390/s390.opt:211
+#, no-c-format
+msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
+msgstr ""
+
+#: config/s390/s390.opt:216
+#, no-c-format
+msgid "Warn if a function uses alloca or creates an array with dynamic size."
+msgstr ""
+
+#: config/s390/s390.opt:220
+#, no-c-format
+msgid "Warn if a single function's framesize exceeds the given framesize."
+msgstr ""
+
+#: config/s390/s390.opt:224
+#, no-c-format
+msgid "z/Architecture."
+msgstr ""
+
+#: config/s390/s390.opt:228
+#, no-c-format
+msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
+msgstr ""
+
+#: config/s390/s390.opt:238 config/arm/arm.opt:178
+#, no-c-format
+msgid "Assume data segments are relative to text segment."
+msgstr ""
+
+#: config/s390/s390.opt:243
+#, no-c-format
+msgid "Wrap all indirect branches into execute in order to disable branch prediction."
+msgstr ""
+
+#: config/s390/s390.opt:248
+#, no-c-format
+msgid "Wrap indirect table jumps and computed gotos into execute in order to disable branch prediction.  Using thunk or thunk-extern with this option requires the thunks to be considered signal handlers to order to generate correct CFI.  For environments where unwinding (e.g. for exceptions) is required please use thunk-inline instead."
+msgstr ""
+
+#: config/s390/s390.opt:256
+#, no-c-format
+msgid "Wrap all indirect calls into execute in order to disable branch prediction."
+msgstr ""
+
+#: config/s390/s390.opt:260
+#, no-c-format
+msgid "Wrap all indirect return branches into execute in order to disable branch prediction."
+msgstr ""
+
+#: config/s390/s390.opt:265
+#, no-c-format
+msgid "Wrap indirect return branches into execute in order to disable branch prediction. This affects only branches where the return address is going to be restored from memory."
+msgstr ""
+
+#: config/s390/s390.opt:271
+#, no-c-format
+msgid "Wrap indirect return branches into execute in order to disable branch prediction. This affects only branches where the return address doesn't need to be restored from memory."
+msgstr ""
+
+#: config/s390/s390.opt:293
+#, no-c-format
+msgid "Generate sections .s390_indirect_jump, .s390_indirect_call, .s390_return_reg, and .s390_return_mem to contain the indirect branch locations which have been patched as part of using one of the -mindirect-branch* or -mfunction-return* options.  The sections consist of an array of 32 bit elements. Each entry holds the offset from the entry to the patched location."
+msgstr ""
+
+#: config/s390/s390.opt:302
+#, no-c-format
+msgid "Emit profiling counter call at function entry before prologue. The compiled code will require a 64-bit CPU and glibc 2.29 or newer to run."
+msgstr ""
+
+#: config/s390/s390.opt:307
+#, no-c-format
+msgid "Generate __mcount_loc section with all _mcount and __fentry__ calls."
+msgstr ""
+
+#: config/s390/s390.opt:316
+#, no-c-format
+msgid "Emit fused multiply-add instructions for long doubles in vector registers (wfmaxb, wfmsxb, wfnmaxb, wfnmsxb).  Reassociation pass does not handle fused multiply-adds, therefore code generated by the middle-end is prone to having long fused multiply-add chains.  This is not pipeline-friendly, and the default behavior is to emit separate multiplication and addition instructions for long doubles in vector registers, because measurements show that this improves performance.  This option allows overriding it for testing purposes."
+msgstr ""
+
+#: config/s390/s390.opt:331
+#, no-c-format
+msgid "Store all argument registers on the stack."
+msgstr ""
+
+#: config/s390/s390.opt:335
+#, no-c-format
+msgid "Assume external symbols, whose natural alignment would be 1, to be potentially unaligned.  By default all symbols without explicit alignment are assumed to reside on a 2 byte boundary as mandated by the IBM Z ABI."
+msgstr ""
+
+#: config/rl78/rl78.opt:27 config/rx/elf.opt:26 config/csky/csky.opt:198
+#, no-c-format
+msgid "Use the simulator runtime."
+msgstr ""
+
+#: config/rl78/rl78.opt:31
+#, no-c-format
+msgid "Selects the type of hardware multiplication and division to use (none/g13/g14)."
+msgstr ""
+
+#: config/rl78/rl78.opt:50
+#, no-c-format
+msgid "Use all registers, reserving none for interrupt handlers."
+msgstr ""
+
+#: config/rl78/rl78.opt:54
+#, no-c-format
+msgid "Enable assembler and linker relaxation.  Enabled by default at -Os."
+msgstr ""
+
+#: config/rl78/rl78.opt:58
+#, no-c-format
+msgid "Selects the type of RL78 core being targeted (g10/g13/g14).  The default is the G14.  If set, also selects the hardware multiply support to be used."
+msgstr ""
+
+#: config/rl78/rl78.opt:77
+#, no-c-format
+msgid "Alias for -mcpu=g10."
+msgstr ""
+
+#: config/rl78/rl78.opt:81
+#, no-c-format
+msgid "Alias for -mcpu=g13."
+msgstr ""
+
+#: config/rl78/rl78.opt:85 config/rl78/rl78.opt:89
+#, no-c-format
+msgid "Alias for -mcpu=g14."
+msgstr ""
+
+#: config/rl78/rl78.opt:93
+#, no-c-format
+msgid "Assume ES is zero throughout program execution, use ES: for read-only data."
+msgstr ""
+
+#: config/rl78/rl78.opt:97
+#, no-c-format
+msgid "Stores the MDUC registers in interrupt handlers for G13 target."
+msgstr ""
+
+#: config/stormy16/stormy16.opt:24
+#, no-c-format
+msgid "Provide libraries for the simulator."
+msgstr ""
+
+#: config/arm/arm-tables.opt:25
+#, no-c-format
+msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
+msgstr ""
+
+#: config/arm/arm-tables.opt:305
+#, no-c-format
+msgid "Known ARM architectures (for use with the -march= option):"
+msgstr ""
+
+#: config/arm/arm-tables.opt:411
+#, no-c-format
+msgid "Known ARM FPUs (for use with the -mfpu= option):"
+msgstr ""
+
+#: config/arm/arm.opt:35
+#, no-c-format
+msgid "TLS dialect to use:"
+msgstr ""
+
+#: config/arm/arm.opt:45
+#, no-c-format
+msgid "Specify an ABI."
+msgstr ""
+
+#: config/arm/arm.opt:49
+#, no-c-format
+msgid "Known ARM ABIs (for use with the -mabi= option):"
+msgstr ""
+
+#: config/arm/arm.opt:68
+#, no-c-format
+msgid "Generate a call to abort if a noreturn function returns."
+msgstr ""
+
+#: config/arm/arm.opt:75
+#, no-c-format
+msgid "Generate APCS conformant stack frames."
+msgstr ""
+
+#: config/arm/arm.opt:79
+#, no-c-format
+msgid "Generate re-entrant, PIC code."
+msgstr ""
+
+#: config/arm/arm.opt:101
+#, no-c-format
+msgid "Generate code in 32 bit ARM state."
+msgstr ""
+
+#: config/arm/arm.opt:109
+#, no-c-format
+msgid "Thumb: Assume non-static functions may be called from ARM code."
+msgstr ""
+
+#: config/arm/arm.opt:113
+#, no-c-format
+msgid "Thumb: Assume function pointers may go to non-Thumb aware code."
+msgstr ""
+
+#: config/arm/arm.opt:121 config/csky/csky.opt:73
+#, no-c-format
+msgid "Specify if floating point hardware should be used."
+msgstr ""
+
+#: config/arm/arm.opt:125
+#, no-c-format
+msgid "Specify that the compiler should target secure code as per ARMv8-M Security Extensions."
+msgstr ""
+
+#: config/arm/arm.opt:129 config/csky/csky.opt:77
+#, no-c-format
+msgid "Known floating-point ABIs (for use with the -mfloat-abi= option):"
+msgstr ""
+
+#: config/arm/arm.opt:142
+#, no-c-format
+msgid "Switch ARM/Thumb modes on alternating functions for compiler testing."
+msgstr ""
+
+#: config/arm/arm.opt:146
+#, no-c-format
+msgid "Specify the __fp16 floating-point format."
+msgstr ""
+
+#: config/arm/arm.opt:150
+#, no-c-format
+msgid "Known __fp16 formats (for use with the -mfp16-format= option):"
+msgstr ""
+
+#: config/arm/arm.opt:163
+#, no-c-format
+msgid "Specify the name of the target floating point hardware/format."
+msgstr ""
+
+#: config/arm/arm.opt:174
+#, no-c-format
+msgid "Generate call insns as indirect calls, if necessary."
+msgstr ""
+
+#: config/arm/arm.opt:182
+#, no-c-format
+msgid "Specify the register to be used for PIC addressing."
+msgstr ""
+
+#: config/arm/arm.opt:186
+#, no-c-format
+msgid "Store function names in object code."
+msgstr ""
+
+#: config/arm/arm.opt:190
+#, no-c-format
+msgid "Permit scheduling of a function's prologue sequence."
+msgstr ""
+
+#: config/arm/arm.opt:194 config/rs6000/rs6000.opt:235
+#, no-c-format
+msgid "Do not load the PIC register in function prologues."
+msgstr ""
+
+#: config/arm/arm.opt:201
+#, no-c-format
+msgid "Specify the minimum bit alignment of structures. (Deprecated)."
+msgstr ""
+
+#: config/arm/arm.opt:205
+#, no-c-format
+msgid "Generate code for Thumb state."
+msgstr ""
+
+#: config/arm/arm.opt:209
+#, no-c-format
+msgid "Support calls between Thumb and ARM instruction sets."
+msgstr ""
+
+#: config/arm/arm.opt:213
+#, no-c-format
+msgid "Specify thread local storage scheme."
+msgstr ""
+
+#: config/arm/arm.opt:217
+#, no-c-format
+msgid "Specify how to access the thread pointer."
+msgstr ""
+
+#: config/arm/arm.opt:221
+#, no-c-format
+msgid "Valid arguments to -mtp=:"
+msgstr ""
+
+#: config/arm/arm.opt:243
+#, no-c-format
+msgid "Thumb: Generate (non-leaf) stack frames even if not needed."
+msgstr ""
+
+#: config/arm/arm.opt:247
+#, no-c-format
+msgid "Thumb: Generate (leaf) stack frames even if not needed."
+msgstr ""
+
+#: config/arm/arm.opt:251 config/mn10300/mn10300.opt:42
+#, no-c-format
+msgid "Tune code for the given processor."
+msgstr ""
+
+#: config/arm/arm.opt:255
+#, no-c-format
+msgid "Print CPU tuning information as comment in assembler file.  This is an option used only for regression testing of the compiler and not intended for ordinary use in compiling code."
+msgstr ""
+
+#: config/arm/arm.opt:266
+#, no-c-format
+msgid "Use Neon quad-word (rather than double-word) registers for vectorization."
+msgstr ""
+
+#: config/arm/arm.opt:270
+#, no-c-format
+msgid "Use Neon double-word (rather than quad-word) registers for vectorization."
+msgstr ""
+
+#: config/arm/arm.opt:274
+#, no-c-format
+msgid "Enable more verbose RTX cost dumps during debug.  For GCC developers use only."
+msgstr ""
+
+#: config/arm/arm.opt:278
+#, no-c-format
+msgid "Only generate absolute relocations on word sized values."
+msgstr ""
+
+#: config/arm/arm.opt:282
+#, no-c-format
+msgid "Generate IT blocks appropriate for ARMv8."
+msgstr ""
+
+#: config/arm/arm.opt:286
+#, no-c-format
+msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
+msgstr ""
+
+#: config/arm/arm.opt:291
+#, no-c-format
+msgid "Mitigate issues with VLLDM on some M-profile devices (CVE-2021-35465)."
+msgstr ""
+
+#: config/arm/arm.opt:295
+#, no-c-format
+msgid "Mitigate issues with AES instructions on Cortex-A57 and Cortex-A72 (Arm erratum #1742098)."
+msgstr ""
+
+#: config/arm/arm.opt:300
+#, no-c-format
+msgid "Mitigate issues with AES instructions on Cortex-A57 and Cortex-A72 (Arm erratum #1655431)."
+msgstr ""
+
+#: config/arm/arm.opt:305 config/nds32/nds32.opt:461 config/arc/arc.opt:495
+#, no-c-format
+msgid "Enable unaligned word and halfword accesses to packed data."
+msgstr ""
+
+#: config/arm/arm.opt:309
+#, no-c-format
+msgid "This option is deprecated and has no effect."
+msgstr ""
+
+#: config/arm/arm.opt:313
+#, no-c-format
+msgid "Assume loading data from flash is slower than fetching instructions."
+msgstr ""
+
+#: config/arm/arm.opt:317
+#, no-c-format
+msgid "Assume unified syntax for inline assembly code."
+msgstr ""
+
+#: config/arm/arm.opt:321
+#, no-c-format
+msgid "Do not allow constant data to be placed in code sections."
+msgstr ""
+
+#: config/arm/arm.opt:325
+#, no-c-format
+msgid "When linking for big-endian targets, generate a BE8 format image."
+msgstr ""
+
+#: config/arm/arm.opt:329
+#, no-c-format
+msgid "When linking for big-endian targets, generate a legacy BE32 format image."
+msgstr ""
+
+#: config/arm/arm.opt:333 config/sh/sh.opt:195
+#, no-c-format
+msgid "Cost to assume for a branch insn."
+msgstr ""
+
+#: config/arm/arm.opt:341
+#, no-c-format
+msgid "Generate code which uses the core registers only (r0-r14)."
+msgstr ""
+
+#: config/arm/arm.opt:363
+#, no-c-format
+msgid "Use an immediate to offset from the TLS register. This option is for use with fstack-protector-guard=tls and not for use in user-land code."
+msgstr ""
+
+#: config/sparc/sparc.opt:30 config/sparc/sparc.opt:34
+#: config/visium/visium.opt:37
+#, no-c-format
+msgid "Use hardware FP."
+msgstr ""
+
+#: config/sparc/sparc.opt:38 config/visium/visium.opt:41
+#, no-c-format
+msgid "Do not use hardware FP."
+msgstr ""
+
+#: config/sparc/sparc.opt:42
+#, no-c-format
+msgid "Use flat register window model."
+msgstr ""
+
+#: config/sparc/sparc.opt:46
+#, no-c-format
+msgid "Assume possible double misalignment."
+msgstr ""
+
+#: config/sparc/sparc.opt:50
+#, no-c-format
+msgid "Use ABI reserved registers."
+msgstr ""
+
+#: config/sparc/sparc.opt:54
+#, no-c-format
+msgid "Use hardware quad FP instructions."
+msgstr ""
+
+#: config/sparc/sparc.opt:58
+#, no-c-format
+msgid "Do not use hardware quad fp instructions."
+msgstr ""
+
+#: config/sparc/sparc.opt:62 config/vax/vax.opt:47
+#, no-c-format
+msgid "Enable Local Register Allocation."
+msgstr ""
+
+#: config/sparc/sparc.opt:66
+#, no-c-format
+msgid "Compile for V8+ ABI."
+msgstr ""
+
+#: config/sparc/sparc.opt:70
+#, no-c-format
+msgid "Use UltraSPARC Visual Instruction Set version 1.0 extensions."
+msgstr ""
+
+#: config/sparc/sparc.opt:74
+#, no-c-format
+msgid "Use UltraSPARC Visual Instruction Set version 2.0 extensions."
+msgstr ""
+
+#: config/sparc/sparc.opt:78
+#, no-c-format
+msgid "Use UltraSPARC Visual Instruction Set version 3.0 extensions."
+msgstr ""
+
+#: config/sparc/sparc.opt:82
+#, no-c-format
+msgid "Use UltraSPARC Visual Instruction Set version 4.0 extensions."
+msgstr ""
+
+#: config/sparc/sparc.opt:86
+#, no-c-format
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr ""
+
+#: config/sparc/sparc.opt:90
+#, no-c-format
+msgid "Use UltraSPARC Compare-and-Branch extensions."
+msgstr ""
+
+#: config/sparc/sparc.opt:94
+#, no-c-format
+msgid "Use UltraSPARC Fused Multiply-Add extensions."
+msgstr ""
+
+#: config/sparc/sparc.opt:98
+#, no-c-format
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr ""
+
+#: config/sparc/sparc.opt:102
+#, no-c-format
+msgid "Use UltraSPARC Population-Count instruction."
+msgstr ""
+
+#: config/sparc/sparc.opt:106
+#, no-c-format
+msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
+msgstr ""
+
+#: config/sparc/sparc.opt:110
+#, no-c-format
+msgid "Pointers are 64-bit."
+msgstr ""
+
+#: config/sparc/sparc.opt:114
+#, no-c-format
+msgid "Pointers are 32-bit."
+msgstr ""
+
+#: config/sparc/sparc.opt:118
+#, no-c-format
+msgid "Use 64-bit ABI."
+msgstr ""
+
+#: config/sparc/sparc.opt:122
+#, no-c-format
+msgid "Use 32-bit ABI."
+msgstr ""
+
+#: config/sparc/sparc.opt:126
+#, no-c-format
+msgid "Use stack bias."
+msgstr ""
+
+#: config/sparc/sparc.opt:130
+#, no-c-format
+msgid "Use structs on stronger alignment for double-word copies."
+msgstr ""
+
+#: config/sparc/sparc.opt:134
+#, no-c-format
+msgid "Optimize tail call instructions in assembler and linker."
+msgstr ""
+
+#: config/sparc/sparc.opt:138
+#, no-c-format
+msgid "Do not generate code that can only run in supervisor mode (default)."
+msgstr ""
+
+#: config/sparc/sparc.opt:142
+#, no-c-format
+msgid "Use instructions of and schedule code for given CPU."
+msgstr ""
+
+#: config/sparc/sparc.opt:228
+#, no-c-format
+msgid "Use given SPARC-V9 code model."
+msgstr ""
+
+#: config/sparc/sparc.opt:250
+#, no-c-format
+msgid "Enable debug output."
+msgstr "გამართვის გამოტანის ჩართვა."
+
+#: config/sparc/sparc.opt:254
+#, no-c-format
+msgid "Enable strict 32-bit psABI struct return checking."
+msgstr ""
+
+#: config/sparc/sparc.opt:258
+#, no-c-format
+msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
+msgstr ""
+
+#: config/sparc/sparc.opt:263
+#, no-c-format
+msgid "Enable workarounds for the errata of the UT699 processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:267
+#, no-c-format
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:271
+#, no-c-format
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:308
+#, no-c-format
+msgid "Specify the memory model in effect for the program."
+msgstr ""
+
+#: config/rs6000/darwin.opt:38 config/rs6000/sysv4.opt:145
+#, no-c-format
+msgid "Generate 64-bit code."
+msgstr ""
+
+#: config/rs6000/darwin.opt:42 config/rs6000/sysv4.opt:149
+#, no-c-format
+msgid "Generate 32-bit code."
+msgstr ""
+
+#: config/rs6000/rs6000-tables.opt:24
+#, no-c-format
+msgid "Known CPUs (for use with the -mcpu= and -mtune= options):"
+msgstr ""
+
+#: config/rs6000/476.opt:24
+#, no-c-format
+msgid "Preserve the PowerPC 476's link stack by matching up a blr with the bcl/bl insns used for GOT accesses."
+msgstr ""
+
+#: config/rs6000/aix64.opt:24
+#, no-c-format
+msgid "Compile for 64-bit pointers."
+msgstr ""
+
+#: config/rs6000/aix64.opt:28
+#, no-c-format
+msgid "Compile for 32-bit pointers."
+msgstr ""
+
+#: config/rs6000/aix64.opt:32 config/rs6000/linux64.opt:28
+#, no-c-format
+msgid "Select code model."
+msgstr ""
+
+#: config/rs6000/aix64.opt:49
+#, no-c-format
+msgid "Support message passing with the Parallel Environment."
+msgstr ""
+
+#: config/rs6000/linux64.opt:24
+#, no-c-format
+msgid "Call mcount for profiling before a function prologue."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:117
+#, no-c-format
+msgid "Use PowerPC-64 instruction set."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:121
+#, no-c-format
+msgid "Use PowerPC General Purpose group optional instructions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:125
+#, no-c-format
+msgid "Use PowerPC Graphics group optional instructions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:129
+#, no-c-format
+msgid "Use PowerPC V2.01 single field mfcr instruction."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:133
+#, no-c-format
+msgid "Use PowerPC V2.02 popcntb instruction."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:137
+#, no-c-format
+msgid "Use PowerPC V2.02 floating point rounding instructions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:141
+#, no-c-format
+msgid "Use PowerPC V2.05 compare bytes instruction."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:152
+#, no-c-format
+msgid "Use AltiVec instructions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:156
+#, no-c-format
+msgid "Use decimal floating point instructions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:160
+#, no-c-format
+msgid "Use 4xx half-word multiply instructions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:164
+#, no-c-format
+msgid "Use 4xx string-search dlmzb instruction."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:168
+#, no-c-format
+msgid "Generate load/store multiple instructions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:187
+#, no-c-format
+msgid "Use PowerPC V2.06 popcntd instruction."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:191
+#, no-c-format
+msgid "Under -ffast-math, generate a FRIZ instruction for (double)(long long) conversions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:199
+#, no-c-format
+msgid "Use vector/scalar (VSX) instructions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:227
+#, no-c-format
+msgid "Do not generate load/store with update instructions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:231
+#, no-c-format
+msgid "Generate load/store with update instructions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:239
+#, no-c-format
+msgid "Avoid generation of indexed load/store instructions when possible."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:246
+#, no-c-format
+msgid "Schedule the start and end of the procedure."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:250
+#, no-c-format
+msgid "Return all structures in memory (AIX default)."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:254
+#, no-c-format
+msgid "Return small structures in registers (SVR4 default)."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:258
+#, no-c-format
+msgid "Conform more closely to IBM XLC semantics."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:262 config/rs6000/rs6000.opt:266
+#, no-c-format
+msgid "Generate software reciprocal divide and square root for better throughput."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:270
+#, no-c-format
+msgid "Assume that the reciprocal estimate instructions provide more accuracy."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:274
+#, no-c-format
+msgid "Do not place floating point constants in TOC."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:278
+#, no-c-format
+msgid "Place floating point constants in TOC."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:282
+#, no-c-format
+msgid "Do not place symbol+offset constants in TOC."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:286
+#, no-c-format
+msgid "Place symbol+offset constants in TOC."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:297
+#, no-c-format
+msgid "Use only one TOC entry per procedure."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:301
+#, no-c-format
+msgid "Put everything in the regular TOC."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:305
+#, no-c-format
+msgid "Generate VRSAVE instructions when generating AltiVec code."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:309
+#, no-c-format
+msgid "Deprecated option.  Use -mno-vrsave instead."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:313
+#, no-c-format
+msgid "Deprecated option.  Use -mvrsave instead."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:317
+#, no-c-format
+msgid "Max number of bytes to move inline."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:321
+#, no-c-format
+msgid "Generate unaligned VSX load/store for inline expansion of memcpy/memmove."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:325
+#, no-c-format
+msgid "Generate unaligned VSX vector pair load/store for inline expansion of memcpy/memmove."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:329
+#, no-c-format
+msgid "Max number of bytes to compare without loops."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:333
+#, no-c-format
+msgid "Max number of bytes to compare with loops."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:337
+#, no-c-format
+msgid "Max number of bytes to compare."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:341
+#, no-c-format
+msgid "Generate isel instructions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:345
+#, no-c-format
+msgid "-mdebug=\tEnable debug output."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:350
+#, no-c-format
+msgid "Use the AltiVec ABI extensions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:354
+#, no-c-format
+msgid "Do not use the AltiVec ABI extensions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:359
+#, no-c-format
+msgid "Use the AIX Vector Extended ABI."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:363
+#, no-c-format
+msgid "Do not use the AIX Vector Extended ABI."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:368
+#, no-c-format
+msgid "Use the ELFv1 ABI."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:372
+#, no-c-format
+msgid "Use the ELFv2 ABI."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:392
+#, no-c-format
+msgid "-mcpu=\tUse features of and schedule code for given CPU."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:396
+#, no-c-format
+msgid "-mtune=\tSchedule code for given CPU."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:400
+#, no-c-format
+msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:416
+#, no-c-format
+msgid "Avoid all range limits on call instructions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:424
+#, no-c-format
+msgid "Warn about deprecated 'vector long ...' AltiVec type usage."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:428
+#, no-c-format
+msgid "Use -mlong-double-64 for 64-bit IEEE floating point format.  Use -mlong-double-128 for 128-bit floating point format (either IEEE or IBM)."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:437
+#, no-c-format
+msgid "Determine which dependences between insns are considered costly."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:441
+#, no-c-format
+msgid "Specify which post scheduling nop insertion scheme to apply."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:445
+#, no-c-format
+msgid "Specify alignment of structure fields default/natural."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:449
+#, no-c-format
+msgid "Valid arguments to -malign-:"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:459
+#, no-c-format
+msgid "Specify scheduling priority for dispatch slot restricted insns."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:463
+#, no-c-format
+msgid "Use r11 to hold the static link in calls to functions via pointers."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:467
+#, no-c-format
+msgid "Save the TOC in the prologue for indirect calls rather than inline."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:479
+#, no-c-format
+msgid "Fuse certain integer operations together for better performance on power8."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:483
+#, no-c-format
+msgid "Allow sign extension in fusion operations."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:487
+#, no-c-format
+msgid "Use vector and scalar instructions added in ISA 2.07."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:491
+#, no-c-format
+msgid "Fuse certain integer operations together for better performance on power10."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:495
+#, no-c-format
+msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:502
+#, no-c-format
+msgid "Use ISA 2.07 transactional memory (HTM) instructions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:506
+#, no-c-format
+msgid "Generate the quad word memory instructions (lq/stq)."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:510
+#, no-c-format
+msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:514
+#, no-c-format
+msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:518
+#, no-c-format
+msgid "Analyze and remove doubleword swaps from VSX computations."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:526
+#, no-c-format
+msgid "Use certain scalar instructions added in ISA 3.0."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:530
+#, no-c-format
+msgid "Use vector instructions added in ISA 3.0."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:534
+#, no-c-format
+msgid "Use the new min/max instructions defined in ISA 3.0."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:538
+#, no-c-format
+msgid "Generate the integer modulo instructions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:542
+#, no-c-format
+msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:546
+#, no-c-format
+msgid "Enable using IEEE 128-bit floating point instructions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:550
+#, no-c-format
+msgid "Enable default conversions between __float128 & long double."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:590
+#, no-c-format
+msgid "Generate (do not generate) prefixed memory instructions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:594
+#, no-c-format
+msgid "Generate (do not generate) pc-relative memory addressing."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:598
+#, no-c-format
+msgid "Generate (do not generate) pc-relative memory optimizations for externals."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:602
+#, no-c-format
+msgid "Generate (do not generate) MMA instructions."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:609
+#, no-c-format
+msgid "Enable instructions that guard against return-oriented programming attacks."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:613
+#, no-c-format
+msgid "Generate code that will run in privileged state."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:617
+#, no-c-format
+msgid "Generate (do not generate) code that uses the XXSPLTIW instruction."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:621
+#, no-c-format
+msgid "Generate (do not generate) code that uses the XXSPLTIDP instruction."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:625
+#, no-c-format
+msgid "Generate (do not generate) code that uses the LXVKQ instruction."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:631
+#, no-c-format
+msgid "Used to limit unroll factor which indicates how much the autovectorizer may unroll a loop.  The default value is 4."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:637
+#, no-c-format
+msgid "When costing for loop vectorization, we probably need to penalize the loop body cost if the existing cost model may not adequately reflect delays from unavailable vector resources.  We collect the cost for vectorized statements and non-vectorized statements separately, check the proportion of vec_cost to total cost of vec_cost and non vec_cost, and penalize only if the proportion exceeds the threshold specified by this parameter.  The default value is 85."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:646
+#, no-c-format
+msgid "Like parameter rs6000-density-pct-threshold, we also check the total sum of vec_cost and non vec_cost, and penalize only if the sum exceeds the threshold specified by this parameter.  The default value is 70."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:652
+#, no-c-format
+msgid "When both heuristics with rs6000-density-pct-threshold and rs6000-density-size-threshold are satisfied, we decide to penalize the loop body cost by the value which is specified by this parameter.  The default value is 10."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:659
+#, no-c-format
+msgid "When costing for loop vectorization, we probably need to penalize the loop body cost by accounting for excess strided or elementwise loads.  We collect the numbers for general statements and load statements according to the information for statements to be vectorized, check the proportion of load statements, and penalize only if the proportion exceeds the threshold specified by this parameter.  The default value is 45."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:668
+#, no-c-format
+msgid "Like parameter rs6000-density-load-pct-threshold, we also check if the total number of load statements exceeds the threshold specified by this parameter, and penalize only if it's satisfied.  The default value is 20."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:674 config/loongarch/loongarch.opt:302
+#, no-c-format
+msgid "Indicate how many non memory access vector instructions can be issued per cycle, it's used in unroll factor determination for autovectorizer.  The default value is 4."
+msgstr ""
+
+#: config/rs6000/rs6000.opt:680
+#, no-c-format
+msgid "When reduction factor computed for a loop exceeds the threshold specified by this parameter, prefer to unroll this loop.  The default value is 1."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:24
+#, no-c-format
+msgid "-mcall-ABI\tSelect ABI calling convention."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:28
+#, no-c-format
+msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:32
+#, no-c-format
+msgid "Allow readonly data in sdata."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:36
+#, no-c-format
+msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:52
+#, no-c-format
+msgid "Align to the base type of the bit-field."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:56
+#, no-c-format
+msgid "Align to the base type of the bit-field. Don't assume that unaligned accesses are handled by the system."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:61 config/rs6000/sysv4.opt:65
+#, no-c-format
+msgid "Produce code relocatable at runtime."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:69 config/rs6000/sysv4.opt:73
+#, no-c-format
+msgid "Produce little endian code."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:77 config/rs6000/sysv4.opt:81
+#, no-c-format
+msgid "Produce big endian code."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:86 config/rs6000/sysv4.opt:90
+#: config/rs6000/sysv4.opt:99 config/rs6000/sysv4.opt:141
+#: config/rs6000/sysv4.opt:153
+#, no-c-format
+msgid "No description yet."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:94
+#, no-c-format
+msgid "Assume all variable arg functions are prototyped."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:103
+#, no-c-format
+msgid "Use EABI."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:107
+#, no-c-format
+msgid "Allow bit-fields to cross word boundaries."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:111
+#, no-c-format
+msgid "Use alternate register names."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:117
+#, no-c-format
+msgid "Use default method for sdata handling."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:121
+#, no-c-format
+msgid "Link with libsim.a, libc.a and sim-crt0.o."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:125
+#, no-c-format
+msgid "Link with libads.a, libc.a and crt0.o."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:129
+#, no-c-format
+msgid "Link with libyk.a, libc.a and crt0.o."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:133
+#, no-c-format
+msgid "Link with libmvme.a, libc.a and crt0.o."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:137
+#, no-c-format
+msgid "Set the PPC_EMB bit in the ELF flags header."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:157
+#, no-c-format
+msgid "Generate code to use a non-exec PLT and GOT."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:161
+#, no-c-format
+msgid "Generate code for old exec BSS PLT."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:165
+#, no-c-format
+msgid "Use inline plt sequences to implement long calls and -fno-plt."
+msgstr ""
+
+#: config/rs6000/sysv4.opt:169
+#, no-c-format
+msgid "Emit .gnu_attribute tags."
+msgstr ""
+
+#: config/alpha/alpha.opt:27
+#, no-c-format
+msgid "Use fp registers."
+msgstr ""
+
+#: config/alpha/alpha.opt:35
+#, no-c-format
+msgid "Request IEEE-conformant math library routines (OSF/1)."
+msgstr ""
+
+#: config/alpha/alpha.opt:39
+#, no-c-format
+msgid "Emit IEEE-conformant code, without inexact exceptions."
+msgstr ""
+
+#: config/alpha/alpha.opt:46
+#, no-c-format
+msgid "Do not emit complex integer constants to read-only memory."
+msgstr ""
+
+#: config/alpha/alpha.opt:50
+#, no-c-format
+msgid "Use VAX fp."
+msgstr ""
+
+#: config/alpha/alpha.opt:54
+#, no-c-format
+msgid "Do not use VAX fp."
+msgstr ""
+
+#: config/alpha/alpha.opt:58
+#, no-c-format
+msgid "Emit code for the byte/word ISA extension."
+msgstr ""
+
+#: config/alpha/alpha.opt:62
+#, no-c-format
+msgid "Emit code for the motion video ISA extension."
+msgstr ""
+
+#: config/alpha/alpha.opt:66
+#, no-c-format
+msgid "Emit code for the fp move and sqrt ISA extension."
+msgstr ""
+
+#: config/alpha/alpha.opt:70
+#, no-c-format
+msgid "Emit code for the counting ISA extension."
+msgstr ""
+
+#: config/alpha/alpha.opt:74
+#, no-c-format
+msgid "Emit code using explicit relocation directives."
+msgstr ""
+
+#: config/alpha/alpha.opt:78
+#, no-c-format
+msgid "Emit 16-bit relocations to the small data areas."
+msgstr ""
+
+#: config/alpha/alpha.opt:82
+#, no-c-format
+msgid "Emit 32-bit relocations to the small data areas."
+msgstr ""
+
+#: config/alpha/alpha.opt:86
+#, no-c-format
+msgid "Emit direct branches to local functions."
+msgstr ""
+
+#: config/alpha/alpha.opt:90
+#, no-c-format
+msgid "Emit indirect branches to local functions."
+msgstr ""
+
+#: config/alpha/alpha.opt:94
+#, no-c-format
+msgid "Emit rdval instead of rduniq for thread pointer."
+msgstr ""
+
+#: config/alpha/alpha.opt:106
+#, no-c-format
+msgid "Use features of and schedule given CPU."
+msgstr ""
+
+#: config/alpha/alpha.opt:110
+#, no-c-format
+msgid "Schedule given CPU."
+msgstr ""
+
+#: config/alpha/alpha.opt:114
+#, no-c-format
+msgid "Control the generated fp rounding mode."
+msgstr ""
+
+#: config/alpha/alpha.opt:118
+#, no-c-format
+msgid "Control the IEEE trap mode."
+msgstr ""
+
+#: config/alpha/alpha.opt:122
+#, no-c-format
+msgid "Control the precision given to fp exceptions."
+msgstr ""
+
+#: config/alpha/alpha.opt:126
+#, no-c-format
+msgid "Tune expected memory latency."
+msgstr ""
+
+#: config/lm32/lm32.opt:24
+#, no-c-format
+msgid "Enable multiply instructions."
+msgstr ""
+
+#: config/lm32/lm32.opt:28
+#, no-c-format
+msgid "Enable divide and modulus instructions."
+msgstr ""
+
+#: config/lm32/lm32.opt:32
+#, no-c-format
+msgid "Enable barrel shift instructions."
+msgstr ""
+
+#: config/lm32/lm32.opt:36
+#, no-c-format
+msgid "Enable sign extend instructions."
+msgstr ""
+
+#: config/lm32/lm32.opt:40
+#, no-c-format
+msgid "Enable user-defined instructions."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:41
+#, no-c-format
+msgid "Basic ISAs of LoongArch:"
+msgstr ""
+
+#: config/loongarch/loongarch.opt:49
+#, no-c-format
+msgid "FPU types of LoongArch:"
+msgstr ""
+
+#: config/loongarch/loongarch.opt:62
+#, no-c-format
+msgid "-mfpu=FPU\tGenerate code for the given FPU."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:69 config/mips/mips.opt:398
+#, no-c-format
+msgid "Prevent the use of all hardware floating-point instructions."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:73 config/mips/mips.opt:390
+#, no-c-format
+msgid "Restrict the use of hardware floating-point instructions to 32-bit operations."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:77 config/mips/mips.opt:116
+#, no-c-format
+msgid "Allow hardware floating-point instructions to cover both 32-bit and 64-bit operations."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:81
+#, no-c-format
+msgid "SIMD extension levels of LoongArch:"
+msgstr ""
+
+#: config/loongarch/loongarch.opt:94
+#, no-c-format
+msgid "-msimd=SIMD\tGenerate code for the given SIMD extension."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:98
+#, no-c-format
+msgid "Enable LoongArch SIMD Extension (LSX, 128-bit)."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:102
+#, no-c-format
+msgid "Enable LoongArch Advanced SIMD Extension (LASX, 256-bit)."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:107
+#, no-c-format
+msgid "LoongArch ARCH presets:"
+msgstr ""
+
+#: config/loongarch/loongarch.opt:132
+#, no-c-format
+msgid "-march=PROCESSOR\tGenerate code for the given PROCESSOR ISA."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:136
+#, no-c-format
+msgid "LoongArch TUNE presets:"
+msgstr ""
+
+#: config/loongarch/loongarch.opt:155
+#, no-c-format
+msgid "-mtune=PROCESSOR\tGenerate optimized code for PROCESSOR."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:164
+#, no-c-format
+msgid "Base ABI types for LoongArch:"
+msgstr ""
+
+#: config/loongarch/loongarch.opt:177
+#, no-c-format
+msgid "-mabi=BASEABI\tGenerate code that conforms to the given BASEABI."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:186 config/mips/mips.opt:71
+#, no-c-format
+msgid "-mbranch-cost=COST\tSet the cost of branches to roughly COST instructions."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:190 config/mips/mips.opt:83
+#, no-c-format
+msgid "Trap on integer divide by zero."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:194
+#, no-c-format
+msgid "Conditional moves for integral are enabled."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:198
+#, no-c-format
+msgid "Conditional moves for float are enabled."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:202
+#, no-c-format
+msgid "Prevent optimizing block moves, which is also the default behavior of -Os."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:210
+#, no-c-format
+msgid "-mmax-inline-memcpy-size=SIZE\tSet the max size of memcpy to inline, default is 1024."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:214 config/mips/mips.opt:150
+#, no-c-format
+msgid "The code model option names for -mexplicit-relocs:"
+msgstr ""
+
+#: config/loongarch/loongarch.opt:227 config/mips/mips.opt:163
+#, no-c-format
+msgid "Use %reloc() assembly operators."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:231 config/mips/mips.opt:167
+#, no-c-format
+msgid "Use %reloc() assembly operators (for backward compatibility)."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:239
+#, no-c-format
+msgid "Generate approximate reciprocal divide and square root for better throughput."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:270
+#, no-c-format
+msgid "Avoid using the GOT to access external symbols."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:279
+#, no-c-format
+msgid "Pass -mrelax or -mno-relax option to the assembler."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:297
+#, no-c-format
+msgid "Used to limit unroll factor which indicates how much the autovectorizer may unroll a loop.  The default value is 6."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:315
+#, no-c-format
+msgid "Support frecipe.{s/d} and frsqrte.{s/d} instructions."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:319
+#, no-c-format
+msgid "Support div.w[u] and mod.w[u] instructions with inputs not sign-extended."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:323
+#, no-c-format
+msgid "Support am{swap/add}[_db].{b/h} instructions."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:327
+#, no-c-format
+msgid "Support amcas[_db].{b/h/w/d} instructions."
+msgstr ""
+
+#: config/loongarch/loongarch.opt:331
+#, no-c-format
+msgid "Do not need load-load barriers (dbar 0x700)."
+msgstr ""
+
+#: config/or1k/elf.opt:28
+#, no-c-format
+msgid "Configure the newlib board specific runtime.  The default is or1ksim."
+msgstr ""
+
+#: config/or1k/elf.opt:32
+#, no-c-format
+msgid "This option is ignored; it is provided for compatibility purposes only.  This used to select linker and preprocessor options for use with newlib."
+msgstr ""
+
+#: config/or1k/or1k.opt:29
+#, no-c-format
+msgid "Enable generation of hardware divide (l.div, l.divu) instructions.  This is the default; use -msoft-div to override."
+msgstr ""
+
+#: config/or1k/or1k.opt:34
+#, no-c-format
+msgid "Enable generation of binaries which use functions from libgcc to perform divide operations.  The default is -mhard-div."
+msgstr ""
+
+#: config/or1k/or1k.opt:39
+#, no-c-format
+msgid "Enable generation of hardware multiply instructions (l.mul, l.muli) instructions. This is the default; use -msoft-mul to override."
+msgstr ""
+
+#: config/or1k/or1k.opt:44
+#, no-c-format
+msgid "Enable generation of binaries which use functions from libgcc to perform multiply operations. The default is -mhard-mul."
+msgstr ""
+
+#: config/or1k/or1k.opt:49
+#, no-c-format
+msgid "Enable generation of binaries which use functions from libgcc to perform floating point operations.  This is the default; use -mhard-float to override."
+msgstr ""
+
+#: config/or1k/or1k.opt:54
+#, no-c-format
+msgid "Enable generation of hardware floating point instructions. The default is -msoft-float."
+msgstr ""
+
+#: config/or1k/or1k.opt:59
+#, no-c-format
+msgid "When -mhard-float is selected, enables generation of double-precision floating point instructions.  By default functions from libgcc are used to perform double-precision floating point operations."
+msgstr ""
+
+#: config/or1k/or1k.opt:65
+#, no-c-format
+msgid "When -mhard-float is selected, enables generation of unordered floating point compare and set flag (lf.sfun*) instructions.  By default functions from libgcc are used to perform unordered floating point compare and set flag operations."
+msgstr ""
+
+#: config/or1k/or1k.opt:71
+#, no-c-format
+msgid "Specify the code model used for accessing memory addresses.  Specifying large enables generating binaries with large global offset tables.  By default the value is small."
+msgstr ""
+
+#: config/or1k/or1k.opt:77
+#, no-c-format
+msgid "Known code model types (for use with the -mcmodel= option):"
+msgstr ""
+
+#: config/or1k/or1k.opt:87
+#, no-c-format
+msgid "Enable generation of conditional move (l.cmov) instructions.  By default the equivalent will be generated using set and branch."
+msgstr ""
+
+#: config/or1k/or1k.opt:92
+#, no-c-format
+msgid "Enable generation of rotate right (l.ror) instructions.  By default functions from libgcc are used to perform rotate right operations."
+msgstr ""
+
+#: config/or1k/or1k.opt:97
+#, no-c-format
+msgid "Enable generation of rotate right with immediate (l.rori) instructions.  By default functions from libgcc are used to perform rotate right with immediate operations."
+msgstr ""
+
+#: config/or1k/or1k.opt:103
+#, no-c-format
+msgid "Enable generation of sign extension (l.ext*) instructions.  By default memory loads are used to perform sign extension."
+msgstr ""
+
+#: config/or1k/or1k.opt:108
+#, no-c-format
+msgid "Enable generation of compare and set flag with immediate (l.sf*i) instructions. By default extra instructions will be generated to store the immediate to a register first."
+msgstr ""
+
+#: config/or1k/or1k.opt:114
+#, no-c-format
+msgid "Enable generation of shift with immediate (l.srai, l.srli, l.slli) instructions. By default extra instructions will be generated to store the immediate to a register first."
+msgstr ""
+
+#: config/nios2/elf.opt:26
+#, no-c-format
+msgid "Link with a limited version of the C library."
+msgstr ""
+
+#: config/nios2/elf.opt:30
+#, no-c-format
+msgid "Name of system library to link against."
+msgstr ""
+
+#: config/nios2/elf.opt:34
+#, no-c-format
+msgid "Name of the startfile."
+msgstr ""
+
+#: config/nios2/elf.opt:38
+#, no-c-format
+msgid "Link with HAL BSP."
+msgstr ""
+
+#: config/nios2/nios2.opt:35
+#, no-c-format
+msgid "Enable DIV, DIVU."
+msgstr ""
+
+#: config/nios2/nios2.opt:39
+#, no-c-format
+msgid "Enable MUL instructions."
+msgstr ""
+
+#: config/nios2/nios2.opt:43
+#, no-c-format
+msgid "Enable MULX instructions, assume fast shifter."
+msgstr ""
+
+#: config/nios2/nios2.opt:47
+#, no-c-format
+msgid "Use table based fast divide (default at -O3)."
+msgstr ""
+
+#: config/nios2/nios2.opt:51
+#, no-c-format
+msgid "All memory accesses use I/O load/store instructions."
+msgstr ""
+
+#: config/nios2/nios2.opt:55
+#, no-c-format
+msgid "Volatile memory accesses use I/O load/store instructions."
+msgstr ""
+
+#: config/nios2/nios2.opt:59
+#, no-c-format
+msgid "Volatile memory accesses do not use I/O load/store instructions."
+msgstr ""
+
+#: config/nios2/nios2.opt:63
+#, no-c-format
+msgid "Enable/disable GP-relative addressing."
+msgstr ""
+
+#: config/nios2/nios2.opt:67
+#, no-c-format
+msgid "Valid options for GP-relative addressing (for -mgpopt):"
+msgstr ""
+
+#: config/nios2/nios2.opt:86
+#, no-c-format
+msgid "Equivalent to -mgpopt=local."
+msgstr ""
+
+#: config/nios2/nios2.opt:90
+#, no-c-format
+msgid "Equivalent to -mgpopt=none."
+msgstr ""
+
+#: config/nios2/nios2.opt:94 config/c6x/c6x.opt:30 config/mips/mips.opt:134
+#, no-c-format
+msgid "Use big-endian byte order."
+msgstr ""
+
+#: config/nios2/nios2.opt:98 config/c6x/c6x.opt:34 config/mips/mips.opt:138
+#, no-c-format
+msgid "Use little-endian byte order."
+msgstr ""
+
+#: config/nios2/nios2.opt:102
+#, no-c-format
+msgid "Floating point custom instruction configuration name."
+msgstr ""
+
+#: config/nios2/nios2.opt:106
+#, no-c-format
+msgid "Do not use the ftruncds custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:110
+#, no-c-format
+msgid "Integer id (N) of ftruncds custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:114
+#, no-c-format
+msgid "Do not use the fextsd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:118
+#, no-c-format
+msgid "Integer id (N) of fextsd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:122
+#, no-c-format
+msgid "Do not use the fixdu custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:126
+#, no-c-format
+msgid "Integer id (N) of fixdu custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:130
+#, no-c-format
+msgid "Do not use the fixdi custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:134
+#, no-c-format
+msgid "Integer id (N) of fixdi custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:138
+#, no-c-format
+msgid "Do not use the fixsu custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:142
+#, no-c-format
+msgid "Integer id (N) of fixsu custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:146
+#, no-c-format
+msgid "Do not use the fixsi custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:150
+#, no-c-format
+msgid "Integer id (N) of fixsi custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:154
+#, no-c-format
+msgid "Do not use the floatud custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:158
+#, no-c-format
+msgid "Integer id (N) of floatud custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:162
+#, no-c-format
+msgid "Do not use the floatid custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:166
+#, no-c-format
+msgid "Integer id (N) of floatid custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:170
+#, no-c-format
+msgid "Do not use the floatus custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:174
+#, no-c-format
+msgid "Integer id (N) of floatus custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:178
+#, no-c-format
+msgid "Do not use the floatis custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:182
+#, no-c-format
+msgid "Integer id (N) of floatis custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:186
+#, no-c-format
+msgid "Do not use the fcmpned custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:190
+#, no-c-format
+msgid "Integer id (N) of fcmpned custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:194
+#, no-c-format
+msgid "Do not use the fcmpeqd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:198
+#, no-c-format
+msgid "Integer id (N) of fcmpeqd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:202
+#, no-c-format
+msgid "Do not use the fcmpged custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:206
+#, no-c-format
+msgid "Integer id (N) of fcmpged custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:210
+#, no-c-format
+msgid "Do not use the fcmpgtd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:214
+#, no-c-format
+msgid "Integer id (N) of fcmpgtd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:218
+#, no-c-format
+msgid "Do not use the fcmpled custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:222
+#, no-c-format
+msgid "Integer id (N) of fcmpled custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:226
+#, no-c-format
+msgid "Do not use the fcmpltd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:230
+#, no-c-format
+msgid "Integer id (N) of fcmpltd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:234
+#, no-c-format
+msgid "Do not use the flogd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:238
+#, no-c-format
+msgid "Integer id (N) of flogd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:242
+#, no-c-format
+msgid "Do not use the fexpd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:246
+#, no-c-format
+msgid "Integer id (N) of fexpd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:250
+#, no-c-format
+msgid "Do not use the fatand custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:254
+#, no-c-format
+msgid "Integer id (N) of fatand custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:258
+#, no-c-format
+msgid "Do not use the ftand custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:262
+#, no-c-format
+msgid "Integer id (N) of ftand custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:266
+#, no-c-format
+msgid "Do not use the fsind custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:270
+#, no-c-format
+msgid "Integer id (N) of fsind custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:274
+#, no-c-format
+msgid "Do not use the fcosd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:278
+#, no-c-format
+msgid "Integer id (N) of fcosd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:282
+#, no-c-format
+msgid "Do not use the fsqrtd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:286
+#, no-c-format
+msgid "Integer id (N) of fsqrtd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:290
+#, no-c-format
+msgid "Do not use the fabsd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:294
+#, no-c-format
+msgid "Integer id (N) of fabsd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:298
+#, no-c-format
+msgid "Do not use the fnegd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:302
+#, no-c-format
+msgid "Integer id (N) of fnegd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:306
+#, no-c-format
+msgid "Do not use the fmaxd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:310
+#, no-c-format
+msgid "Integer id (N) of fmaxd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:314
+#, no-c-format
+msgid "Do not use the fmind custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:318
+#, no-c-format
+msgid "Integer id (N) of fmind custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:322
+#, no-c-format
+msgid "Do not use the fdivd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:326
+#, no-c-format
+msgid "Integer id (N) of fdivd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:330
+#, no-c-format
+msgid "Do not use the fmuld custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:334
+#, no-c-format
+msgid "Integer id (N) of fmuld custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:338
+#, no-c-format
+msgid "Do not use the fsubd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:342
+#, no-c-format
+msgid "Integer id (N) of fsubd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:346
+#, no-c-format
+msgid "Do not use the faddd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:350
+#, no-c-format
+msgid "Integer id (N) of faddd custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:354
+#, no-c-format
+msgid "Do not use the fcmpnes custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:358
+#, no-c-format
+msgid "Integer id (N) of fcmpnes custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:362
+#, no-c-format
+msgid "Do not use the fcmpeqs custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:366
+#, no-c-format
+msgid "Integer id (N) of fcmpeqs custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:370
+#, no-c-format
+msgid "Do not use the fcmpges custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:374
+#, no-c-format
+msgid "Integer id (N) of fcmpges custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:378
+#, no-c-format
+msgid "Do not use the fcmpgts custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:382
+#, no-c-format
+msgid "Integer id (N) of fcmpgts custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:386
+#, no-c-format
+msgid "Do not use the fcmples custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:390
+#, no-c-format
+msgid "Integer id (N) of fcmples custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:394
+#, no-c-format
+msgid "Do not use the fcmplts custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:398
+#, no-c-format
+msgid "Integer id (N) of fcmplts custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:402
+#, no-c-format
+msgid "Do not use the flogs custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:406
+#, no-c-format
+msgid "Integer id (N) of flogs custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:410
+#, no-c-format
+msgid "Do not use the fexps custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:414
+#, no-c-format
+msgid "Integer id (N) of fexps custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:418
+#, no-c-format
+msgid "Do not use the fatans custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:422
+#, no-c-format
+msgid "Integer id (N) of fatans custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:426
+#, no-c-format
+msgid "Do not use the ftans custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:430
+#, no-c-format
+msgid "Integer id (N) of ftans custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:434
+#, no-c-format
+msgid "Do not use the fsins custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:438
+#, no-c-format
+msgid "Integer id (N) of fsins custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:442
+#, no-c-format
+msgid "Do not use the fcoss custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:446
+#, no-c-format
+msgid "Integer id (N) of fcoss custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:450
+#, no-c-format
+msgid "Do not use the fsqrts custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:454
+#, no-c-format
+msgid "Integer id (N) of fsqrts custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:458
+#, no-c-format
+msgid "Do not use the fabss custom instr."
+msgstr ""
+
+#: config/nios2/nios2.opt:462
+#, no-c-format
+msgid "Integer id (N) of fabss custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:466
+#, no-c-format
+msgid "Do not use the fnegs custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:470
+#, no-c-format
+msgid "Integer id (N) of fnegs custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:474
+#, no-c-format
+msgid "Do not use the fmaxs custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:478
+#, no-c-format
+msgid "Integer id (N) of fmaxs custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:482
+#, no-c-format
+msgid "Do not use the fmins custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:486
+#, no-c-format
+msgid "Integer id (N) of fmins custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:490
+#, no-c-format
+msgid "Do not use the fdivs custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:494
+#, no-c-format
+msgid "Integer id (N) of fdivs custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:498
+#, no-c-format
+msgid "Do not use the fmuls custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:502
+#, no-c-format
+msgid "Integer id (N) of fmuls custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:506
+#, no-c-format
+msgid "Do not use the fsubs custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:510
+#, no-c-format
+msgid "Integer id (N) of fsubs custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:514
+#, no-c-format
+msgid "Do not use the fadds custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:518
+#, no-c-format
+msgid "Integer id (N) of fadds custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:522
+#, no-c-format
+msgid "Do not use the frdy custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:526
+#, no-c-format
+msgid "Integer id (N) of frdy custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:530
+#, no-c-format
+msgid "Do not use the frdxhi custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:534
+#, no-c-format
+msgid "Integer id (N) of frdxhi custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:538
+#, no-c-format
+msgid "Do not use the frdxlo custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:542
+#, no-c-format
+msgid "Integer id (N) of frdxlo custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:546
+#, no-c-format
+msgid "Do not use the fwry custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:550
+#, no-c-format
+msgid "Integer id (N) of fwry custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:554
+#, no-c-format
+msgid "Do not use the fwrx custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:558
+#, no-c-format
+msgid "Integer id (N) of fwrx custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:562
+#, no-c-format
+msgid "Do not use the round custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:566
+#, no-c-format
+msgid "Integer id (N) of round custom instruction."
+msgstr ""
+
+#: config/nios2/nios2.opt:574
+#, no-c-format
+msgid "Valid Nios II ISA levels (for -march):"
+msgstr ""
+
+#: config/nios2/nios2.opt:584
+#, no-c-format
+msgid "Enable generation of R2 BMX instructions."
+msgstr ""
+
+#: config/nios2/nios2.opt:588
+#, no-c-format
+msgid "Enable generation of R2 CDX instructions."
+msgstr ""
+
+#: config/nios2/nios2.opt:592
+#, no-c-format
+msgid "Regular expression matching additional GP-addressible section names."
+msgstr ""
+
+#: config/nios2/nios2.opt:596
+#, no-c-format
+msgid "Regular expression matching section names for r0-relative addressing."
+msgstr ""
+
+#: config/rx/elf.opt:32
+#, no-c-format
+msgid "Generate assembler output that is compatible with the Renesas AS100 assembler.  This may restrict some of the compiler's capabilities.  The default is to generate GAS compatible syntax."
+msgstr ""
+
+#: config/rx/elf.opt:38 config/rx/rx.opt:99
+#, no-c-format
+msgid "Specifies the number of registers to reserve for interrupt handlers."
+msgstr ""
+
+#: config/rx/elf.opt:44 config/rx/rx.opt:105
+#, no-c-format
+msgid "Specifies whether interrupt functions should save and restore the accumulator register."
+msgstr ""
+
+#: config/rx/rx.opt:29
+#, no-c-format
+msgid "Store doubles in 64 bits."
+msgstr ""
+
+#: config/rx/rx.opt:33
+#, no-c-format
+msgid "Stores doubles in 32 bits.  This is the default."
+msgstr ""
+
+#: config/rx/rx.opt:37
+#, no-c-format
+msgid "Disable the use of RX FPU instructions."
+msgstr ""
+
+#: config/rx/rx.opt:44
+#, no-c-format
+msgid "Enable the use of RX FPU instructions.  This is the default."
+msgstr ""
+
+#: config/rx/rx.opt:50
+#, no-c-format
+msgid "Specify the target RX cpu type."
+msgstr ""
+
+#: config/rx/rx.opt:71
+#, no-c-format
+msgid "Data is stored in big-endian format."
+msgstr ""
+
+#: config/rx/rx.opt:75
+#, no-c-format
+msgid "Data is stored in little-endian format.  (Default)."
+msgstr ""
+
+#: config/rx/rx.opt:81
+#, no-c-format
+msgid "Maximum size of global and static variables which can be placed into the small data area."
+msgstr ""
+
+#: config/rx/rx.opt:87
+#, no-c-format
+msgid "Enable linker relaxation."
+msgstr ""
+
+#: config/rx/rx.opt:93
+#, no-c-format
+msgid "Maximum size in bytes of constant values allowed as operands."
+msgstr ""
+
+#: config/rx/rx.opt:111
+#, no-c-format
+msgid "Enables Position-Independent-Data (PID) mode."
+msgstr ""
+
+#: config/rx/rx.opt:117
+#, no-c-format
+msgid "Warn when multiple, different, fast interrupt handlers are in the compilation unit."
+msgstr ""
+
+#: config/rx/rx.opt:123
+#, no-c-format
+msgid "Enable the use of the old, broken, ABI where all stacked function arguments are aligned to 32-bits."
+msgstr ""
+
+#: config/rx/rx.opt:127
+#, no-c-format
+msgid "Enable the use the standard RX ABI where all stacked function arguments are naturally aligned.  This is the default."
+msgstr ""
+
+#: config/rx/rx.opt:133
+#, no-c-format
+msgid "Enable the use of the LRA register allocator."
+msgstr ""
+
+#: config/rx/rx.opt:139
+#, no-c-format
+msgid "Enables or disables the use of the SMOVF, SMOVB, SMOVU, SUNTIL, SWHILE and RMPA instructions.  Enabled by default."
+msgstr ""
+
+#: config/rx/rx.opt:145
+#, no-c-format
+msgid "Always use JSR, never BSR, for calls."
+msgstr ""
+
+#: config/visium/visium.opt:25
+#, no-c-format
+msgid "Link with libc.a and libdebug.a."
+msgstr ""
+
+#: config/visium/visium.opt:29
+#, no-c-format
+msgid "Link with libc.a and libsim.a."
+msgstr ""
+
+#: config/visium/visium.opt:33
+#, no-c-format
+msgid "Use hardware FP (default)."
+msgstr ""
+
+#: config/visium/visium.opt:45
+#, no-c-format
+msgid "Use features of and schedule code for given CPU."
+msgstr ""
+
+#: config/visium/visium.opt:65
+#, no-c-format
+msgid "Generate code for the supervisor mode (default)."
+msgstr ""
+
+#: config/visium/visium.opt:69
+#, no-c-format
+msgid "Generate code for the user mode."
+msgstr ""
+
+#: config/visium/visium.opt:73
+#, no-c-format
+msgid "Only retained for backward compatibility."
+msgstr ""
+
+#: config/sol2.opt:32
+#, no-c-format
+msgid "Clear hardware capabilities when linking."
+msgstr ""
+
+#: config/sol2.opt:36
+#, no-c-format
+msgid "Pass -z text to linker."
+msgstr ""
+
+#: config/moxie/moxie.opt:31
+#, no-c-format
+msgid "Enable MUL.X and UMUL.X instructions."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:40
+#, no-c-format
+msgid "Use software emulation for floating point (default)."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:44
+#, no-c-format
+msgid "Use hardware floating point instructions."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:48
+#, no-c-format
+msgid "Use table lookup optimization for small signed integer divisions."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:52
+#, no-c-format
+msgid "-mcpu=PROCESSOR\t\tUse features of and schedule code for given CPU."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:56
+#, no-c-format
+msgid "Don't optimize block moves, use memcpy."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:68
+#, no-c-format
+msgid "Use the soft multiply emulation (default)."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:72
+#, no-c-format
+msgid "Use reorder instructions (swap and byte reversed load/store) (default)."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:76
+#, no-c-format
+msgid "Use the software emulation for divides (default)."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:80
+#, no-c-format
+msgid "Use the hardware barrel shifter instead of emulation."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:84
+#, no-c-format
+msgid "Use pattern compare instructions."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:88
+#, no-c-format
+msgid "Check for stack overflow at runtime."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:92 config/iq2000/iq2000.opt:65
+#, no-c-format
+msgid "Use GP relative sdata/sbss sections."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:96
+#, no-c-format
+msgid "Clear the BSS to zero and place zero initialized in BSS."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:100
+#, no-c-format
+msgid "Use multiply high instructions for high part of 32x32 multiply."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:104
+#, no-c-format
+msgid "Use hardware floating point conversion instructions."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:108
+#, no-c-format
+msgid "Use hardware floating point square root instruction."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:112
+#, no-c-format
+msgid "Description for mxl-mode-executable."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:116
+#, no-c-format
+msgid "Description for mxl-mode-xmdstub."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:120
+#, no-c-format
+msgid "Description for mxl-mode-bootstrap."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:124
+#, no-c-format
+msgid "Description for mxl-mode-novectors."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:128
+#, no-c-format
+msgid "Use hardware prefetch instruction."
+msgstr ""
+
+#: config/microblaze/microblaze.opt:132
+#, no-c-format
+msgid "Data referenced by offset from start of text instead of GOT (with -fPIC/-fPIE)."
+msgstr ""
+
+#: config/vax/vax.opt:23 config/vax/vax.opt:27
+#, no-c-format
+msgid "Target DFLOAT double precision code."
+msgstr ""
+
+#: config/vax/vax.opt:31 config/vax/vax.opt:35
+#, no-c-format
+msgid "Generate GFLOAT double precision code."
+msgstr ""
+
+#: config/vax/vax.opt:39
+#, no-c-format
+msgid "Generate code for GNU assembler (gas)."
+msgstr ""
+
+#: config/vax/vax.opt:43
+#, no-c-format
+msgid "Generate code for UNIX assembler."
+msgstr ""
+
+#: config/vax/vax.opt:51
+#, no-c-format
+msgid "Use VAXC structure conventions."
+msgstr ""
+
+#: config/vax/vax.opt:55
+#, no-c-format
+msgid "Use new adddi3/subdi3 patterns."
+msgstr ""
+
+#: config/frv/frv.opt:30
+#, no-c-format
+msgid "Use 4 media accumulators."
+msgstr ""
+
+#: config/frv/frv.opt:34
+#, no-c-format
+msgid "Use 8 media accumulators."
+msgstr ""
+
+#: config/frv/frv.opt:38
+#, no-c-format
+msgid "Enable label alignment optimizations."
+msgstr ""
+
+#: config/frv/frv.opt:42
+#, no-c-format
+msgid "Dynamically allocate cc registers."
+msgstr ""
+
+#: config/frv/frv.opt:49
+#, no-c-format
+msgid "Set the cost of branches."
+msgstr ""
+
+#: config/frv/frv.opt:53
+#, no-c-format
+msgid "Enable conditional execution other than moves/scc."
+msgstr ""
+
+#: config/frv/frv.opt:57
+#, no-c-format
+msgid "Change the maximum length of conditionally-executed sequences."
+msgstr ""
+
+#: config/frv/frv.opt:61
+#, no-c-format
+msgid "Change the number of temporary registers that are available to conditionally-executed sequences."
+msgstr ""
+
+#: config/frv/frv.opt:65
+#, no-c-format
+msgid "Enable conditional moves."
+msgstr ""
+
+#: config/frv/frv.opt:69
+#, no-c-format
+msgid "Set the target CPU type."
+msgstr ""
+
+#: config/frv/frv.opt:73
+#, no-c-format
+msgid "Known FR-V CPUs (for use with the -mcpu= option):"
+msgstr ""
+
+#: config/frv/frv.opt:122
+#, no-c-format
+msgid "Use fp double instructions."
+msgstr ""
+
+#: config/frv/frv.opt:126
+#, no-c-format
+msgid "Change the ABI to allow double word insns."
+msgstr ""
+
+#: config/frv/frv.opt:134
+#, no-c-format
+msgid "Just use icc0/fcc0."
+msgstr ""
+
+#: config/frv/frv.opt:138
+#, no-c-format
+msgid "Only use 32 FPRs."
+msgstr ""
+
+#: config/frv/frv.opt:142
+#, no-c-format
+msgid "Use 64 FPRs."
+msgstr ""
+
+#: config/frv/frv.opt:146
+#, no-c-format
+msgid "Only use 32 GPRs."
+msgstr ""
+
+#: config/frv/frv.opt:150
+#, no-c-format
+msgid "Use 64 GPRs."
+msgstr ""
+
+#: config/frv/frv.opt:154
+#, no-c-format
+msgid "Enable use of GPREL for read-only data in FDPIC."
+msgstr ""
+
+#: config/frv/frv.opt:166
+#, no-c-format
+msgid "Enable PIC support for building libraries."
+msgstr ""
+
+#: config/frv/frv.opt:170
+#, no-c-format
+msgid "Follow the EABI linkage requirements."
+msgstr ""
+
+#: config/frv/frv.opt:174
+#, no-c-format
+msgid "Disallow direct calls to global functions."
+msgstr ""
+
+#: config/frv/frv.opt:178
+#, no-c-format
+msgid "Use media instructions."
+msgstr ""
+
+#: config/frv/frv.opt:182
+#, no-c-format
+msgid "Use multiply add/subtract instructions."
+msgstr ""
+
+#: config/frv/frv.opt:186
+#, no-c-format
+msgid "Enable optimizing &&/|| in conditional execution."
+msgstr ""
+
+#: config/frv/frv.opt:190
+#, no-c-format
+msgid "Enable nested conditional execution optimizations."
+msgstr ""
+
+#: config/frv/frv.opt:195
+#, no-c-format
+msgid "Do not mark ABI switches in e_flags."
+msgstr ""
+
+#: config/frv/frv.opt:199
+#, no-c-format
+msgid "Remove redundant membars."
+msgstr ""
+
+#: config/frv/frv.opt:203
+#, no-c-format
+msgid "Pack VLIW instructions."
+msgstr ""
+
+#: config/frv/frv.opt:207
+#, no-c-format
+msgid "Enable setting GPRs to the result of comparisons."
+msgstr ""
+
+#: config/frv/frv.opt:211
+#, no-c-format
+msgid "Change the amount of scheduler lookahead."
+msgstr ""
+
+#: config/frv/frv.opt:219
+#, no-c-format
+msgid "Assume a large TLS segment."
+msgstr ""
+
+#: config/frv/frv.opt:223
+#, no-c-format
+msgid "Do not assume a large TLS segment."
+msgstr ""
+
+#: config/frv/frv.opt:228
+#, no-c-format
+msgid "Cause gas to print tomcat statistics."
+msgstr ""
+
+#: config/frv/frv.opt:233
+#, no-c-format
+msgid "Link with the library-pic libraries."
+msgstr ""
+
+#: config/frv/frv.opt:237
+#, no-c-format
+msgid "Allow branches to be packed with other instructions."
+msgstr ""
+
+#: config/mn10300/mn10300.opt:30
+#, no-c-format
+msgid "Target the AM33 processor."
+msgstr ""
+
+#: config/mn10300/mn10300.opt:34
+#, no-c-format
+msgid "Target the AM33/2.0 processor."
+msgstr ""
+
+#: config/mn10300/mn10300.opt:38
+#, no-c-format
+msgid "Target the AM34 processor."
+msgstr ""
+
+#: config/mn10300/mn10300.opt:46
+#, no-c-format
+msgid "Work around hardware multiply bug."
+msgstr ""
+
+#: config/mn10300/mn10300.opt:55
+#, no-c-format
+msgid "Enable linker relaxations."
+msgstr ""
+
+#: config/mn10300/mn10300.opt:59
+#, no-c-format
+msgid "Return pointers in both a0 and d0."
+msgstr ""
+
+#: config/mn10300/mn10300.opt:63
+#, no-c-format
+msgid "Allow gcc to generate LIW instructions."
+msgstr ""
+
+#: config/mn10300/mn10300.opt:67
+#, no-c-format
+msgid "Allow gcc to generate the SETLB and Lcc instructions."
+msgstr ""
+
+#: config/nds32/nds32-elf.opt:3 config/nds32/nds32-linux.opt:3
+#, no-c-format
+msgid "Specify the address generation strategy for code model."
+msgstr ""
+
+#: config/nds32/nds32-elf.opt:7 config/nds32/nds32-linux.opt:7
+#, no-c-format
+msgid "Known cmodel types (for use with the -mcmodel= option):"
+msgstr ""
+
+#: config/nds32/nds32.opt:29 config/nds32/nds32.opt:89
+#, no-c-format
+msgid "Generate code in big-endian mode."
+msgstr ""
+
+#: config/nds32/nds32.opt:33 config/nds32/nds32.opt:93
+#, no-c-format
+msgid "Generate code in little-endian mode."
+msgstr ""
+
+#: config/nds32/nds32.opt:37
+#, no-c-format
+msgid "Force performing fp-as-gp optimization."
+msgstr ""
+
+#: config/nds32/nds32.opt:41
+#, no-c-format
+msgid "Forbid performing fp-as-gp optimization."
+msgstr ""
+
+#: config/nds32/nds32.opt:47
+#, no-c-format
+msgid "Specify which ABI type to generate code for: 2, 2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:61
+#, no-c-format
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2."
+msgstr ""
+
+#: config/nds32/nds32.opt:65
+#, no-c-format
+msgid "Specify use soft floating point ABI which mean alias to -mabi=2fp+."
+msgstr ""
+
+#: config/nds32/nds32.opt:71
+#, no-c-format
+msgid "Use reduced-set registers for register allocation."
+msgstr ""
+
+#: config/nds32/nds32.opt:75
+#, no-c-format
+msgid "Use full-set registers for register allocation."
+msgstr ""
+
+#: config/nds32/nds32.opt:81
+#, no-c-format
+msgid "Always align function entry, jump target and return address."
+msgstr ""
+
+#: config/nds32/nds32.opt:85
+#, no-c-format
+msgid "Align function entry to 4 byte."
+msgstr ""
+
+#: config/nds32/nds32.opt:97
+#, no-c-format
+msgid "Prevent $fp being allocated during register allocation so that compiler is able to force performing fp-as-gp optimization."
+msgstr ""
+
+#: config/nds32/nds32.opt:101
+#, no-c-format
+msgid "Forbid using $fp to access static and global variables.  This option strictly forbids fp-as-gp optimization regardless of '-mforce-fp-as-gp'."
+msgstr ""
+
+#: config/nds32/nds32.opt:105
+#, no-c-format
+msgid "Specify the address generation strategy for ICT call's code model."
+msgstr ""
+
+#: config/nds32/nds32.opt:109
+#, no-c-format
+msgid "Known cmodel types (for use with the -mict-model= option):"
+msgstr ""
+
+#: config/nds32/nds32.opt:119
+#, no-c-format
+msgid "Generate conditional move instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:123
+#, no-c-format
+msgid "Generate hardware abs instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:127
+#, no-c-format
+msgid "Generate performance extension instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:131
+#, no-c-format
+msgid "Generate performance extension version 2 instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:135
+#, no-c-format
+msgid "Generate string extension instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:139
+#, no-c-format
+msgid "Generate DSP extension instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:143
+#, no-c-format
+msgid "Generate v3 push25/pop25 instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:147
+#, no-c-format
+msgid "Generate 16-bit instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:151
+#, no-c-format
+msgid "Insert relax hint for linker to do relaxation."
+msgstr ""
+
+#: config/nds32/nds32.opt:155
+#, no-c-format
+msgid "Enable Virtual Hosting support."
+msgstr ""
+
+#: config/nds32/nds32.opt:159
+#, no-c-format
+msgid "Specify the size of each interrupt vector, which must be 4 or 16."
+msgstr ""
+
+#: config/nds32/nds32.opt:163
+#, no-c-format
+msgid "Specify the security level of c-isr for the whole file."
+msgstr ""
+
+#: config/nds32/nds32.opt:167
+#, no-c-format
+msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
+msgstr ""
+
+#: config/nds32/nds32.opt:175
+#, no-c-format
+msgid "Known arch types (for use with the -march= option):"
+msgstr ""
+
+#: config/nds32/nds32.opt:197
+#, no-c-format
+msgid "Specify the cpu for pipeline model."
+msgstr ""
+
+#: config/nds32/nds32.opt:201
+#, no-c-format
+msgid "Known cpu types (for use with the -mcpu= option):"
+msgstr ""
+
+#: config/nds32/nds32.opt:361
+#, no-c-format
+msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
+msgstr ""
+
+#: config/nds32/nds32.opt:365
+#, no-c-format
+msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
+msgstr ""
+
+#: config/nds32/nds32.opt:393
+#, no-c-format
+msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
+msgstr ""
+
+#: config/nds32/nds32.opt:412
+#, no-c-format
+msgid "Specify how many read/write ports for n9/n10 cores.  The value should be 3r2w or 2r1w."
+msgstr ""
+
+#: config/nds32/nds32.opt:425
+#, no-c-format
+msgid "Enable constructor/destructor feature."
+msgstr ""
+
+#: config/nds32/nds32.opt:429
+#, no-c-format
+msgid "Guide linker to relax instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:433
+#, no-c-format
+msgid "Generate floating-point multiply-accumulation instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:437
+#, no-c-format
+msgid "Generate single-precision floating-point instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:441
+#, no-c-format
+msgid "Generate double-precision floating-point instructions."
+msgstr ""
+
+#: config/nds32/nds32.opt:445
+#, no-c-format
+msgid "Force disable hardware loop, even use -mext-dsp."
+msgstr ""
+
+#: config/nds32/nds32.opt:449
+#, no-c-format
+msgid "Permit scheduling of a function's prologue and epilogue sequence."
+msgstr ""
+
+#: config/nds32/nds32.opt:453
+#, no-c-format
+msgid "Generate return instruction in naked function."
+msgstr ""
+
+#: config/nds32/nds32.opt:457
+#, no-c-format
+msgid "Always save $lp in the stack."
+msgstr ""
+
+#: config/nds32/nds32.opt:465
+#, no-c-format
+msgid "Allow use r15 for inline ASM."
+msgstr ""
+
+#: config/iq2000/iq2000.opt:31
+#, no-c-format
+msgid "Specify CPU for code generation purposes."
+msgstr ""
+
+#: config/iq2000/iq2000.opt:47
+#, no-c-format
+msgid "Specify CPU for scheduling purposes."
+msgstr ""
+
+#: config/iq2000/iq2000.opt:51
+#, no-c-format
+msgid "Known IQ2000 CPUs (for use with the -mcpu= option):"
+msgstr ""
+
+#: config/iq2000/iq2000.opt:61 config/mips/mips.opt:142
+#, no-c-format
+msgid "Use ROM instead of RAM."
+msgstr ""
+
+#: config/iq2000/iq2000.opt:70
+#, no-c-format
+msgid "No default crt0.o."
+msgstr ""
+
+#: config/iq2000/iq2000.opt:74 config/mips/mips.opt:446
+#, no-c-format
+msgid "Put uninitialized constants in ROM (needs -membedded-data)."
+msgstr ""
+
+#: config/csky/csky.opt:34
+#, no-c-format
+msgid "Specify the target architecture."
+msgstr ""
+
+#: config/csky/csky.opt:38
+#, no-c-format
+msgid "Specify the target processor."
+msgstr ""
+
+#: config/csky/csky.opt:90
+#, no-c-format
+msgid "Specify the target floating-point hardware/format."
+msgstr ""
+
+#: config/csky/csky.opt:94
+#, no-c-format
+msgid "Generate C-SKY FPU double float instructions (default for hard float)."
+msgstr ""
+
+#: config/csky/csky.opt:98
+#, no-c-format
+msgid "Generate frecipd/fsqrtd/fdivd instructions (default for hard float)."
+msgstr ""
+
+#: config/csky/csky.opt:106
+#, no-c-format
+msgid "Enable the extended LRW instruction (default for CK801)."
+msgstr ""
+
+#: config/csky/csky.opt:110
+#, no-c-format
+msgid "Enable interrupt stack instructions."
+msgstr ""
+
+#: config/csky/csky.opt:114
+#, no-c-format
+msgid "Enable multiprocessor instructions."
+msgstr ""
+
+#: config/csky/csky.opt:118
+#, no-c-format
+msgid "Enable coprocessor instructions."
+msgstr ""
+
+#: config/csky/csky.opt:122
+#, no-c-format
+msgid "Enable cache prefetch instructions."
+msgstr ""
+
+#: config/csky/csky.opt:126
+#, no-c-format
+msgid "Enable C-SKY SECURE instructions."
+msgstr ""
+
+#: config/csky/csky.opt:133
+#, no-c-format
+msgid "Enable C-SKY TRUST instructions."
+msgstr ""
+
+#: config/csky/csky.opt:137
+#, no-c-format
+msgid "Enable C-SKY DSP instructions."
+msgstr ""
+
+#: config/csky/csky.opt:141
+#, no-c-format
+msgid "Enable C-SKY Enhanced DSP instructions."
+msgstr ""
+
+#: config/csky/csky.opt:145
+#, no-c-format
+msgid "Enable C-SKY Vector DSP instructions."
+msgstr ""
+
+#: config/csky/csky.opt:151
+#, no-c-format
+msgid "Generate divide instructions."
+msgstr ""
+
+#: config/csky/csky.opt:155
+#, no-c-format
+msgid "Generate code for Smart Mode."
+msgstr ""
+
+#: config/csky/csky.opt:159
+#, no-c-format
+msgid "Enable use of R16-R31 (default)."
+msgstr ""
+
+#: config/csky/csky.opt:163
+#, no-c-format
+msgid "Generate code using global anchor symbol addresses."
+msgstr ""
+
+#: config/csky/csky.opt:167
+#, no-c-format
+msgid "Generate push/pop instructions (default)."
+msgstr ""
+
+#: config/csky/csky.opt:171
+#, no-c-format
+msgid "Generate stm/ldm instructions (default)."
+msgstr ""
+
+#: config/csky/csky.opt:178
+#, no-c-format
+msgid "Generate constant pools in the compiler instead of assembler."
+msgstr ""
+
+#: config/csky/csky.opt:182
+#, no-c-format
+msgid "Emit .stack_size directives."
+msgstr ""
+
+#: config/csky/csky.opt:186
+#, no-c-format
+msgid "Generate code for C-SKY compiler runtime instead of libgcc."
+msgstr ""
+
+#: config/csky/csky.opt:190
+#, no-c-format
+msgid "Set the branch costs to roughly the specified number of instructions."
+msgstr ""
+
+#: config/csky/csky.opt:194
+#, no-c-format
+msgid "Permit scheduling of function prologue and epilogue sequences."
+msgstr ""
+
+#: config/csky/csky_tables.opt:24
+#, no-c-format
+msgid "Known CSKY CPUs (for use with the -mcpu= options):"
+msgstr ""
+
+#: config/csky/csky_tables.opt:205
+#, no-c-format
+msgid "Known CSKY architectures (for use with the -march= option):"
+msgstr ""
+
+#: config/csky/csky_tables.opt:227
+#, no-c-format
+msgid "Known CSKY FPUs (for use with the -mfpu= option):"
+msgstr ""
+
+#: config/c6x/c6x-tables.opt:24
+#, no-c-format
+msgid "Known C6X ISAs (for use with the -march= option):"
+msgstr ""
+
+#: config/c6x/c6x.opt:42
+#, no-c-format
+msgid "Select method for sdata handling."
+msgstr ""
+
+#: config/c6x/c6x.opt:46
+#, no-c-format
+msgid "Valid arguments for the -msdata= option:"
+msgstr ""
+
+#: config/c6x/c6x.opt:59
+#, no-c-format
+msgid "Compile for the DSBT shared library ABI."
+msgstr ""
+
+#: config/cris/cris.opt:45
+#, no-c-format
+msgid "Work around bug in multiplication instruction."
+msgstr ""
+
+#: config/cris/cris.opt:51
+#, no-c-format
+msgid "Compile for ETRAX 4 (CRIS v3)."
+msgstr ""
+
+#: config/cris/cris.opt:56
+#, no-c-format
+msgid "Compile for ETRAX 100 (CRIS v8)."
+msgstr ""
+
+#: config/cris/cris.opt:64
+#, no-c-format
+msgid "Emit verbose debug information in assembly code."
+msgstr ""
+
+#: config/cris/cris.opt:71
+#, no-c-format
+msgid "Do not use condition codes from normal instructions."
+msgstr ""
+
+#: config/cris/cris.opt:80
+#, no-c-format
+msgid "Do not emit addressing modes with side-effect assignment."
+msgstr ""
+
+#: config/cris/cris.opt:89
+#, no-c-format
+msgid "Do not tune stack alignment."
+msgstr ""
+
+#: config/cris/cris.opt:98
+#, no-c-format
+msgid "Do not tune writable data alignment."
+msgstr ""
+
+#: config/cris/cris.opt:107
+#, no-c-format
+msgid "Do not tune code and read-only data alignment."
+msgstr ""
+
+#: config/cris/cris.opt:116
+#, no-c-format
+msgid "Align code and data to 32 bits."
+msgstr ""
+
+#: config/cris/cris.opt:133
+#, no-c-format
+msgid "Don't align items in code or data."
+msgstr ""
+
+#: config/cris/cris.opt:142
+#, no-c-format
+msgid "Do not emit function prologue or epilogue."
+msgstr ""
+
+#: config/cris/cris.opt:149
+#, no-c-format
+msgid "Use the most feature-enabling options allowed by other options."
+msgstr ""
+
+#: config/cris/cris.opt:158
+#, no-c-format
+msgid "Override -mbest-lib-options."
+msgstr ""
+
+#: config/cris/cris.opt:165
+#, no-c-format
+msgid "-march=ARCH\tGenerate code for the specified chip or CPU version."
+msgstr ""
+
+#: config/cris/cris.opt:169
+#, no-c-format
+msgid "-mtune=ARCH\tTune alignment for the specified chip or CPU version."
+msgstr ""
+
+#: config/cris/cris.opt:173
+#, no-c-format
+msgid "-mmax-stackframe=SIZE\tWarn when a stackframe is larger than the specified size."
+msgstr ""
+
+#: config/cris/cris.opt:180
+#, no-c-format
+msgid "Emit traps as \"break 8\", default for CRIS v3 and up.  If disabled, calls to abort() are used."
+msgstr ""
+
+#: config/cris/cris.opt:184
+#, no-c-format
+msgid "Emit checks causing \"break 8\" instructions to execute when applying atomic builtins on misaligned memory."
+msgstr ""
+
+#: config/cris/cris.opt:188
+#, no-c-format
+msgid "Handle atomic builtins that may be applied to unaligned data by calling library functions. Overrides -mtrap-unaligned-atomic."
+msgstr ""
+
+#: config/sh/superh.opt:6
+#, no-c-format
+msgid "Board name [and memory region]."
+msgstr ""
+
+#: config/sh/superh.opt:10
+#, no-c-format
+msgid "Runtime name."
+msgstr ""
+
+#: config/sh/sh.opt:42
+#, no-c-format
+msgid "Generate SH1 code."
+msgstr ""
+
+#: config/sh/sh.opt:46
+#, no-c-format
+msgid "Generate SH2 code."
+msgstr ""
+
+#: config/sh/sh.opt:50
+#, no-c-format
+msgid "Generate default double-precision SH2a-FPU code."
+msgstr ""
+
+#: config/sh/sh.opt:54
+#, no-c-format
+msgid "Generate SH2a FPU-less code."
+msgstr ""
+
+#: config/sh/sh.opt:58
+#, no-c-format
+msgid "Generate default single-precision SH2a-FPU code."
+msgstr ""
+
+#: config/sh/sh.opt:62
+#, no-c-format
+msgid "Generate only single-precision SH2a-FPU code."
+msgstr ""
+
+#: config/sh/sh.opt:66
+#, no-c-format
+msgid "Generate SH2e code."
+msgstr ""
+
+#: config/sh/sh.opt:70
+#, no-c-format
+msgid "Generate SH3 code."
+msgstr ""
+
+#: config/sh/sh.opt:74
+#, no-c-format
+msgid "Generate SH3e code."
+msgstr ""
+
+#: config/sh/sh.opt:78
+#, no-c-format
+msgid "Generate SH4 code."
+msgstr ""
+
+#: config/sh/sh.opt:82
+#, no-c-format
+msgid "Generate SH4-100 code."
+msgstr ""
+
+#: config/sh/sh.opt:86
+#, no-c-format
+msgid "Generate SH4-200 code."
+msgstr ""
+
+#: config/sh/sh.opt:92
+#, no-c-format
+msgid "Generate SH4-300 code."
+msgstr ""
+
+#: config/sh/sh.opt:96
+#, no-c-format
+msgid "Generate SH4 FPU-less code."
+msgstr ""
+
+#: config/sh/sh.opt:100
+#, no-c-format
+msgid "Generate SH4-100 FPU-less code."
+msgstr ""
+
+#: config/sh/sh.opt:104
+#, no-c-format
+msgid "Generate SH4-200 FPU-less code."
+msgstr ""
+
+#: config/sh/sh.opt:108
+#, no-c-format
+msgid "Generate SH4-300 FPU-less code."
+msgstr ""
+
+#: config/sh/sh.opt:112
+#, no-c-format
+msgid "Generate code for SH4 340 series (MMU/FPU-less)."
+msgstr ""
+
+#: config/sh/sh.opt:117
+#, no-c-format
+msgid "Generate code for SH4 400 series (MMU/FPU-less)."
+msgstr ""
+
+#: config/sh/sh.opt:122
+#, no-c-format
+msgid "Generate code for SH4 500 series (FPU-less)."
+msgstr ""
+
+#: config/sh/sh.opt:127
+#, no-c-format
+msgid "Generate default single-precision SH4 code."
+msgstr ""
+
+#: config/sh/sh.opt:131
+#, no-c-format
+msgid "Generate default single-precision SH4-100 code."
+msgstr ""
+
+#: config/sh/sh.opt:135
+#, no-c-format
+msgid "Generate default single-precision SH4-200 code."
+msgstr ""
+
+#: config/sh/sh.opt:139
+#, no-c-format
+msgid "Generate default single-precision SH4-300 code."
+msgstr ""
+
+#: config/sh/sh.opt:143
+#, no-c-format
+msgid "Generate only single-precision SH4 code."
+msgstr ""
+
+#: config/sh/sh.opt:147
+#, no-c-format
+msgid "Generate only single-precision SH4-100 code."
+msgstr ""
+
+#: config/sh/sh.opt:151
+#, no-c-format
+msgid "Generate only single-precision SH4-200 code."
+msgstr ""
+
+#: config/sh/sh.opt:155
+#, no-c-format
+msgid "Generate only single-precision SH4-300 code."
+msgstr ""
+
+#: config/sh/sh.opt:159
+#, no-c-format
+msgid "Generate SH4a code."
+msgstr ""
+
+#: config/sh/sh.opt:163
+#, no-c-format
+msgid "Generate SH4a FPU-less code."
+msgstr ""
+
+#: config/sh/sh.opt:167
+#, no-c-format
+msgid "Generate default single-precision SH4a code."
+msgstr ""
+
+#: config/sh/sh.opt:171
+#, no-c-format
+msgid "Generate only single-precision SH4a code."
+msgstr ""
+
+#: config/sh/sh.opt:175
+#, no-c-format
+msgid "Generate SH4al-dsp code."
+msgstr ""
+
+#: config/sh/sh.opt:183
+#, no-c-format
+msgid "Generate code in big endian mode."
+msgstr ""
+
+#: config/sh/sh.opt:187
+#, no-c-format
+msgid "Generate 32-bit offsets in switch tables."
+msgstr ""
+
+#: config/sh/sh.opt:191
+#, no-c-format
+msgid "Generate bit instructions."
+msgstr ""
+
+#: config/sh/sh.opt:199
+#, no-c-format
+msgid "Assume that zero displacement conditional branches are fast."
+msgstr ""
+
+#: config/sh/sh.opt:203
+#, no-c-format
+msgid "Force the usage of delay slots for conditional branches."
+msgstr ""
+
+#: config/sh/sh.opt:207
+#, no-c-format
+msgid "Align doubles at 64-bit boundaries."
+msgstr ""
+
+#: config/sh/sh.opt:211
+#, no-c-format
+msgid "Division strategy, one of: call-div1, call-fp, call-table."
+msgstr ""
+
+#: config/sh/sh.opt:215
+#, no-c-format
+msgid "Specify name for 32 bit signed division function."
+msgstr ""
+
+#: config/sh/sh.opt:219
+#, no-c-format
+msgid "Generate ELF FDPIC code."
+msgstr ""
+
+#: config/sh/sh.opt:223
+#, no-c-format
+msgid "Enable the use of 64-bit floating point registers in fmov instructions.  See -mdalign if 64-bit alignment is required."
+msgstr ""
+
+#: config/sh/sh.opt:231 config/sh/sh.opt:269
+#, no-c-format
+msgid "Follow Renesas (formerly Hitachi) / SuperH calling conventions."
+msgstr ""
+
+#: config/sh/sh.opt:235
+#, no-c-format
+msgid "Increase the IEEE compliance for floating-point comparisons."
+msgstr ""
+
+#: config/sh/sh.opt:239
+#, no-c-format
+msgid "Inline code to invalidate instruction cache entries after setting up nested function trampolines."
+msgstr ""
+
+#: config/sh/sh.opt:243 config/arc/arc.opt:242
+#, no-c-format
+msgid "Annotate assembler instructions with estimated addresses."
+msgstr ""
+
+#: config/sh/sh.opt:247
+#, no-c-format
+msgid "Generate code in little endian mode."
+msgstr ""
+
+#: config/sh/sh.opt:251
+#, no-c-format
+msgid "Mark MAC register as call-clobbered."
+msgstr ""
+
+#: config/sh/sh.opt:257
+#, no-c-format
+msgid "Make structs a multiple of 4 bytes (warning: ABI altered)."
+msgstr ""
+
+#: config/sh/sh.opt:261
+#, no-c-format
+msgid "Emit function-calls using global offset table when generating PIC."
+msgstr ""
+
+#: config/sh/sh.opt:265
+#, no-c-format
+msgid "Shorten address references during linking."
+msgstr ""
+
+#: config/sh/sh.opt:273
+#, no-c-format
+msgid "Specify the model for atomic operations."
+msgstr ""
+
+#: config/sh/sh.opt:277
+#, no-c-format
+msgid "Use tas.b instruction for __atomic_test_and_set."
+msgstr ""
+
+#: config/sh/sh.opt:281
+#, no-c-format
+msgid "Cost to assume for a multiply insn."
+msgstr ""
+
+#: config/sh/sh.opt:285
+#, no-c-format
+msgid "Don't generate privileged-mode only code; implies -mno-inline-ic_invalidate if the inline code would not work in user mode."
+msgstr ""
+
+#: config/sh/sh.opt:291
+#, no-c-format
+msgid "Pretend a branch-around-a-move is a conditional move."
+msgstr ""
+
+#: config/sh/sh.opt:295
+#, no-c-format
+msgid "Enable the use of the fsca instruction."
+msgstr ""
+
+#: config/sh/sh.opt:299
+#, no-c-format
+msgid "Enable the use of the fsrra instruction."
+msgstr ""
+
+#: config/sh/sh.opt:303
+#, no-c-format
+msgid "Use LRA instead of reload (transitional)."
+msgstr ""
+
+#: config/gcn/gcn.opt:26
+#, no-c-format
+msgid "GCN GPU type to use:"
+msgstr ""
+
+#: config/gcn/gcn.opt:60 config/gcn/gcn.opt:64
+#, no-c-format
+msgid "Specify the name of the target GPU."
+msgstr ""
+
+#: config/gcn/gcn.opt:68
+#, no-c-format
+msgid "Generate code for a 32-bit ABI."
+msgstr ""
+
+#: config/gcn/gcn.opt:72
+#, no-c-format
+msgid "Generate code for a 64-bit ABI."
+msgstr ""
+
+#: config/gcn/gcn.opt:76
+#, no-c-format
+msgid "Enable OpenMP GPU offloading."
+msgstr ""
+
+#: config/gcn/gcn.opt:87
+#, no-c-format
+msgid "Obsolete; use GCN_STACK_SIZE at runtime."
+msgstr ""
+
+#: config/gcn/gcn.opt:93
+#, no-c-format
+msgid "Amount of local data-share (LDS) memory to reserve for gang-private variables."
+msgstr ""
+
+#: config/gcn/gcn.opt:97
+#, no-c-format
+msgid "Warn about invalid OpenACC dimensions."
+msgstr ""
+
+#: config/gcn/gcn.opt:101
+#, no-c-format
+msgid "SRAM-ECC and XNACK modes:"
+msgstr ""
+
+#: config/gcn/gcn.opt:117
+#, no-c-format
+msgid "Compile for devices requiring XNACK enabled. Default \"any\" if USM is supported."
+msgstr ""
+
+#: config/gcn/gcn.opt:121
+#, no-c-format
+msgid "Compile for devices with the SRAM ECC feature enabled, or not. Default \"any\"."
+msgstr ""
+
+#: config/gcn/gcn.opt:125
+#, no-c-format
+msgid "--param=gcn-preferred-vectorization-factor=[default,32,64]\tPreferred vectorization factor."
+msgstr ""
+
+#: config/fr30/fr30.opt:23
+#, no-c-format
+msgid "Assume small address space."
+msgstr ""
+
+#: config/bpf/bpf.opt:28
+#, no-c-format
+msgid "Generate xBPF."
+msgstr ""
+
+#: config/bpf/bpf.opt:34
+#, no-c-format
+msgid "Generate big-endian eBPF."
+msgstr ""
+
+#: config/bpf/bpf.opt:38
+#, no-c-format
+msgid "Generate little-endian eBPF."
+msgstr ""
+
+#: config/bpf/bpf.opt:42
+#, no-c-format
+msgid "Set a hard limit for the size of each stack frame, in bytes."
+msgstr ""
+
+#: config/bpf/bpf.opt:46
+#, no-c-format
+msgid "Generate all necessary information for BPF Compile Once - Run Everywhere."
+msgstr ""
+
+#: config/bpf/bpf.opt:52
+#, no-c-format
+msgid "Enable extra conditional-branch instructions j(s)lt and j(s)le."
+msgstr ""
+
+#: config/bpf/bpf.opt:56
+#, no-c-format
+msgid "Enable 32-bit ALU instructions."
+msgstr ""
+
+#: config/bpf/bpf.opt:60
+#, no-c-format
+msgid "Enable 32-bit jump instructions."
+msgstr ""
+
+#: config/bpf/bpf.opt:64
+#, no-c-format
+msgid "Enable general atomic operations introduced in v3 ISA."
+msgstr ""
+
+#: config/bpf/bpf.opt:68
+#, no-c-format
+msgid "Enable byte swap instructions."
+msgstr ""
+
+#: config/bpf/bpf.opt:72
+#, no-c-format
+msgid "Enable signed division and modulus instructions."
+msgstr ""
+
+#: config/bpf/bpf.opt:76
+#, no-c-format
+msgid "Enable signed move and memory load instructions."
+msgstr ""
+
+#: config/bpf/bpf.opt:80
+#, no-c-format
+msgid "Select the eBPF ISA version to target in code generation."
+msgstr ""
+
+#: config/bpf/bpf.opt:84
+#, no-c-format
+msgid "Valid ISA versions (for use with the -mcpu= option)"
+msgstr ""
+
+#: config/bpf/bpf.opt:104
+#, no-c-format
+msgid "Known assembler dialects (for use with the -masm= option)"
+msgstr ""
+
+#: config/bpf/bpf.opt:114
+#, no-c-format
+msgid "-minline-memops-threshold=<number> Maximum size of memset/memmove/memcpy to inline, larger sizes will use a library call."
+msgstr ""
+
+#: config/mips/mips.opt:32
+#, no-c-format
+msgid "-mabi=ABI\tGenerate code that conforms to the given ABI."
+msgstr ""
+
+#: config/mips/mips.opt:36
+#, no-c-format
+msgid "Known MIPS ABIs (for use with the -mabi= option):"
+msgstr ""
+
+#: config/mips/mips.opt:55
+#, no-c-format
+msgid "Generate code that can be used in SVR4-style dynamic objects."
+msgstr ""
+
+#: config/mips/mips.opt:59
+#, no-c-format
+msgid "Use PMC-style 'mad' instructions."
+msgstr ""
+
+#: config/mips/mips.opt:63
+#, no-c-format
+msgid "Use integer madd/msub instructions."
+msgstr ""
+
+#: config/mips/mips.opt:67
+#, no-c-format
+msgid "-march=ISA\tGenerate code for the given ISA."
+msgstr ""
+
+#: config/mips/mips.opt:75
+#, no-c-format
+msgid "Use Branch Likely instructions, overriding the architecture default."
+msgstr ""
+
+#: config/mips/mips.opt:79
+#, no-c-format
+msgid "Switch on/off MIPS16 ASE on alternating functions for compiler testing."
+msgstr ""
+
+#: config/mips/mips.opt:87
+#, no-c-format
+msgid "-mcode-readable=SETTING\tSpecify when instructions are allowed to access code."
+msgstr ""
+
+#: config/mips/mips.opt:91
+#, no-c-format
+msgid "Valid arguments to -mcode-readable=:"
+msgstr ""
+
+#: config/mips/mips.opt:104
+#, no-c-format
+msgid "Use branch-and-break sequences to check for integer divide by zero."
+msgstr ""
+
+#: config/mips/mips.opt:108
+#, no-c-format
+msgid "Use trap instructions to check for integer divide by zero."
+msgstr ""
+
+#: config/mips/mips.opt:112
+#, no-c-format
+msgid "Allow the use of MDMX instructions."
+msgstr ""
+
+#: config/mips/mips.opt:120
+#, no-c-format
+msgid "Use MIPS-DSP instructions."
+msgstr ""
+
+#: config/mips/mips.opt:124
+#, no-c-format
+msgid "Use MIPS-DSP REV 2 instructions."
+msgstr ""
+
+#: config/mips/mips.opt:146
+#, no-c-format
+msgid "Use Enhanced Virtual Addressing instructions."
+msgstr ""
+
+#: config/mips/mips.opt:171
+#, no-c-format
+msgid "Don't use %reloc() assembly operators (for backward compatibility)."
+msgstr ""
+
+#: config/mips/mips.opt:175
+#, no-c-format
+msgid "Use -G for data that is not defined by the current object."
+msgstr ""
+
+#: config/mips/mips.opt:179
+#, no-c-format
+msgid "Work around certain 24K errata."
+msgstr ""
+
+#: config/mips/mips.opt:183
+#, no-c-format
+msgid "Work around certain R4000 errata."
+msgstr ""
+
+#: config/mips/mips.opt:187
+#, no-c-format
+msgid "Work around certain R4400 errata."
+msgstr ""
+
+#: config/mips/mips.opt:191
+#, no-c-format
+msgid "Work around the R5900 short loop erratum."
+msgstr ""
+
+#: config/mips/mips.opt:195
+#, no-c-format
+msgid "Work around certain RM7000 errata."
+msgstr ""
+
+#: config/mips/mips.opt:199
+#, no-c-format
+msgid "Work around certain R10000 errata."
+msgstr ""
+
+#: config/mips/mips.opt:203
+#, no-c-format
+msgid "Work around errata for early SB-1 revision 2 cores."
+msgstr ""
+
+#: config/mips/mips.opt:207
+#, no-c-format
+msgid "Work around certain VR4120 errata."
+msgstr ""
+
+#: config/mips/mips.opt:211
+#, no-c-format
+msgid "Work around VR4130 mflo/mfhi errata."
+msgstr ""
+
+#: config/mips/mips.opt:215
+#, no-c-format
+msgid "Work around an early 4300 hardware bug."
+msgstr ""
+
+#: config/mips/mips.opt:219
+#, no-c-format
+msgid "FP exceptions are enabled."
+msgstr ""
+
+#: config/mips/mips.opt:223
+#, no-c-format
+msgid "Use 32-bit floating-point registers."
+msgstr ""
+
+#: config/mips/mips.opt:227
+#, no-c-format
+msgid "Conform to the o32 FPXX ABI."
+msgstr ""
+
+#: config/mips/mips.opt:231
+#, no-c-format
+msgid "Use 64-bit floating-point registers."
+msgstr ""
+
+#: config/mips/mips.opt:235
+#, no-c-format
+msgid "-mflush-func=FUNC\tUse FUNC to flush the cache before calling stack trampolines."
+msgstr ""
+
+#: config/mips/mips.opt:239
+#, no-c-format
+msgid "-mabs=MODE\tSelect the IEEE 754 ABS/NEG instruction execution mode."
+msgstr ""
+
+#: config/mips/mips.opt:243
+#, no-c-format
+msgid "-mnan=ENCODING\tSelect the IEEE 754 NaN data encoding."
+msgstr ""
+
+#: config/mips/mips.opt:247
+#, no-c-format
+msgid "Known MIPS IEEE 754 settings (for use with the -mabs= and -mnan= options):"
+msgstr ""
+
+#: config/mips/mips.opt:257
+#, no-c-format
+msgid "Use 32-bit general registers."
+msgstr ""
+
+#: config/mips/mips.opt:261
+#, no-c-format
+msgid "Use 64-bit general registers."
+msgstr ""
+
+#: config/mips/mips.opt:265
+#, no-c-format
+msgid "Use GP-relative addressing to access small data."
+msgstr ""
+
+#: config/mips/mips.opt:269
+#, no-c-format
+msgid "When generating -mabicalls code, allow executables to use PLTs and copy relocations."
+msgstr ""
+
+#: config/mips/mips.opt:273
+#, no-c-format
+msgid "Allow the use of hardware floating-point ABI and instructions."
+msgstr ""
+
+#: config/mips/mips.opt:277
+#, no-c-format
+msgid "Generate code that is link-compatible with MIPS16 and microMIPS code."
+msgstr ""
+
+#: config/mips/mips.opt:281
+#, no-c-format
+msgid "An alias for minterlink-compressed provided for backward-compatibility."
+msgstr ""
+
+#: config/mips/mips.opt:285
+#, no-c-format
+msgid "-mipsN\tGenerate code for ISA level N."
+msgstr ""
+
+#: config/mips/mips.opt:289
+#, no-c-format
+msgid "Generate MIPS16 code."
+msgstr ""
+
+#: config/mips/mips.opt:293
+#, no-c-format
+msgid "Use MIPS-3D instructions."
+msgstr ""
+
+#: config/mips/mips.opt:297
+#, no-c-format
+msgid "Use ll, sc and sync instructions."
+msgstr ""
+
+#: config/mips/mips.opt:301
+#, no-c-format
+msgid "Use -G for object-local data."
+msgstr ""
+
+#: config/mips/mips.opt:305
+#, no-c-format
+msgid "Use indirect calls."
+msgstr ""
+
+#: config/mips/mips.opt:309
+#, no-c-format
+msgid "Use a 32-bit long type."
+msgstr ""
+
+#: config/mips/mips.opt:313
+#, no-c-format
+msgid "Use a 64-bit long type."
+msgstr ""
+
+#: config/mips/mips.opt:317
+#, no-c-format
+msgid "Pass the address of the ra save location to _mcount in $12."
+msgstr ""
+
+#: config/mips/mips.opt:321
+#, no-c-format
+msgid "Don't optimize block moves."
+msgstr ""
+
+#: config/mips/mips.opt:325
+#, no-c-format
+msgid "Use microMIPS instructions."
+msgstr ""
+
+#: config/mips/mips.opt:329
+#, no-c-format
+msgid "Use MIPS MSA Extension instructions."
+msgstr ""
+
+#: config/mips/mips.opt:333
+#, no-c-format
+msgid "Allow the use of MT instructions."
+msgstr ""
+
+#: config/mips/mips.opt:337
+#, no-c-format
+msgid "Prevent the use of all floating-point operations."
+msgstr ""
+
+#: config/mips/mips.opt:341
+#, no-c-format
+msgid "Use MCU instructions."
+msgstr ""
+
+#: config/mips/mips.opt:345
+#, no-c-format
+msgid "Do not use a cache-flushing function before calling stack trampolines."
+msgstr ""
+
+#: config/mips/mips.opt:349
+#, no-c-format
+msgid "Do not use MDMX instructions."
+msgstr ""
+
+#: config/mips/mips.opt:353
+#, no-c-format
+msgid "Generate normal-mode code."
+msgstr ""
+
+#: config/mips/mips.opt:357
+#, no-c-format
+msgid "Do not use MIPS-3D instructions."
+msgstr ""
+
+#: config/mips/mips.opt:361
+#, no-c-format
+msgid "Use paired-single floating-point instructions."
+msgstr ""
+
+#: config/mips/mips.opt:365
+#, no-c-format
+msgid "-mr10k-cache-barrier=SETTING\tSpecify when r10k cache barriers should be inserted."
+msgstr ""
+
+#: config/mips/mips.opt:369
+#, no-c-format
+msgid "Valid arguments to -mr10k-cache-barrier=:"
+msgstr ""
+
+#: config/mips/mips.opt:382
+#, no-c-format
+msgid "Try to allow the linker to turn PIC calls into direct calls."
+msgstr ""
+
+#: config/mips/mips.opt:386
+#, no-c-format
+msgid "When generating -mabicalls code, make the code suitable for use in shared libraries."
+msgstr ""
+
+#: config/mips/mips.opt:394
+#, no-c-format
+msgid "Use SmartMIPS instructions."
+msgstr ""
+
+#: config/mips/mips.opt:402
+#, no-c-format
+msgid "Optimize lui/addiu address loads."
+msgstr ""
+
+#: config/mips/mips.opt:406
+#, no-c-format
+msgid "Enable the MIPS16e V2 instructions."
+msgstr ""
+
+#: config/mips/mips.opt:410
+#, no-c-format
+msgid "Assume all symbols have 32-bit values."
+msgstr ""
+
+#: config/mips/mips.opt:414
+#, no-c-format
+msgid "Use synci instruction to invalidate i-cache."
+msgstr ""
+
+#: config/mips/mips.opt:422
+#, no-c-format
+msgid "Use lwxc1/swxc1/ldxc1/sdxc1 instructions where applicable."
+msgstr ""
+
+#: config/mips/mips.opt:426
+#, no-c-format
+msgid "Use 4-operand madd.s/madd.d and related instructions where applicable."
+msgstr ""
+
+#: config/mips/mips.opt:434
+#, no-c-format
+msgid "Don't generate code with unaligned load store, only valid for MIPS R6."
+msgstr ""
+
+#: config/mips/mips.opt:438
+#, no-c-format
+msgid "Generate code with unaligned load store for R6 (alias of -mno-strict-align)."
+msgstr ""
+
+#: config/mips/mips.opt:442
+#, no-c-format
+msgid "Don't generate code with unaligned load store for R6 (alias of -mstrict-align)."
+msgstr ""
+
+#: config/mips/mips.opt:450
+#, no-c-format
+msgid "Use Virtualization (VZ) instructions."
+msgstr ""
+
+#: config/mips/mips.opt:454
+#, no-c-format
+msgid "Use eXtended Physical Address (XPA) instructions."
+msgstr ""
+
+#: config/mips/mips.opt:458
+#, no-c-format
+msgid "Use Cyclic Redundancy Check (CRC) instructions."
+msgstr ""
+
+#: config/mips/mips.opt:462
+#, no-c-format
+msgid "Use Global INValidate (GINV) instructions."
+msgstr ""
+
+#: config/mips/mips.opt:466
+#, no-c-format
+msgid "Perform VR4130-specific alignment optimizations."
+msgstr ""
+
+#: config/mips/mips.opt:470
+#, no-c-format
+msgid "Lift restrictions on GOT size."
+msgstr ""
+
+#: config/mips/mips.opt:474
+#, no-c-format
+msgid "Enable use of odd-numbered single-precision registers."
+msgstr ""
+
+#: config/mips/mips.opt:478
+#, no-c-format
+msgid "Optimize frame header."
+msgstr ""
+
+#: config/mips/mips.opt:485
+#, no-c-format
+msgid "Enable load/store bonding."
+msgstr ""
+
+#: config/mips/mips.opt:489
+#, no-c-format
+msgid "Specify the compact branch usage policy."
+msgstr ""
+
+#: config/mips/mips.opt:493
+#, no-c-format
+msgid "Policies available for use with -mcompact-branches=:"
+msgstr ""
+
+#: config/mips/mips.opt:506
+#, no-c-format
+msgid "Use Loongson MultiMedia extensions Instructions (MMI) instructions."
+msgstr ""
+
+#: config/mips/mips.opt:510
+#, no-c-format
+msgid "Use Loongson EXTension (EXT) instructions."
+msgstr ""
+
+#: config/mips/mips.opt:514
+#, no-c-format
+msgid "Use Loongson EXTension R2 (EXT2) instructions."
+msgstr ""
+
+#: config/mips/mips-tables.opt:24
+#, no-c-format
+msgid "Known MIPS CPUs (for use with the -march= and -mtune= options):"
+msgstr ""
+
+#: config/mips/mips-tables.opt:28
+#, no-c-format
+msgid "Known MIPS ISA levels (for use with the -mips option):"
+msgstr ""
+
+#: config/arc/arc-tables.opt:25
+#, no-c-format
+msgid "Known ARC CPUs (for use with the -mcpu= option):"
+msgstr ""
+
+#: config/arc/arc.opt:26
+#, no-c-format
+msgid "Compile code for big endian mode."
+msgstr ""
+
+#: config/arc/arc.opt:30
+#, no-c-format
+msgid "Compile code for little endian mode.  This is the default."
+msgstr ""
+
+#: config/arc/arc.opt:34
+#, no-c-format
+msgid "Disable ARCompact specific pass to generate conditional execution instructions."
+msgstr ""
+
+#: config/arc/arc.opt:38
+#, no-c-format
+msgid "Generate ARCompact 32-bit code for ARC600 processor."
+msgstr ""
+
+#: config/arc/arc.opt:42
+#, no-c-format
+msgid "Same as -mA6."
+msgstr ""
+
+#: config/arc/arc.opt:46
+#, no-c-format
+msgid "Generate ARCompact 32-bit code for ARC601 processor."
+msgstr ""
+
+#: config/arc/arc.opt:50
+#, no-c-format
+msgid "Generate ARCompact 32-bit code for ARC700 processor."
+msgstr ""
+
+#: config/arc/arc.opt:54
+#, no-c-format
+msgid "Same as -mA7."
+msgstr ""
+
+#: config/arc/arc.opt:58
+#, no-c-format
+msgid "Force all calls to be made via a jli instruction."
+msgstr ""
+
+#: config/arc/arc.opt:62
+#, no-c-format
+msgid "-mmpy-option=MPY\tCompile ARCv2 code with a multiplier design option."
+msgstr ""
+
+#: config/arc/arc.opt:132
+#, no-c-format
+msgid "Enable DIV-REM instructions for ARCv2."
+msgstr ""
+
+#: config/arc/arc.opt:136
+#, no-c-format
+msgid "Enable code density instructions for ARCv2."
+msgstr ""
+
+#: config/arc/arc.opt:146
+#, no-c-format
+msgid "Use ordinarily cached memory accesses for volatile references."
+msgstr ""
+
+#: config/arc/arc.opt:150
+#, no-c-format
+msgid "Enable cache bypass for volatile references."
+msgstr ""
+
+#: config/arc/arc.opt:154
+#, no-c-format
+msgid "Generate instructions supported by barrel shifter."
+msgstr ""
+
+#: config/arc/arc.opt:158
+#, no-c-format
+msgid "Generate norm instruction."
+msgstr ""
+
+#: config/arc/arc.opt:162
+#, no-c-format
+msgid "Generate swap instruction."
+msgstr ""
+
+#: config/arc/arc.opt:166
+#, no-c-format
+msgid "Generate mul64 and mulu64 instructions."
+msgstr ""
+
+#: config/arc/arc.opt:170
+#, no-c-format
+msgid "Do not generate mpy instructions for ARC700."
+msgstr ""
+
+#: config/arc/arc.opt:174
+#, no-c-format
+msgid "Generate extended arithmetic instructions, only valid for ARC700."
+msgstr ""
+
+#: config/arc/arc.opt:178
+#, no-c-format
+msgid "Dummy flag. This is the default unless FPX switches are provided explicitly."
+msgstr ""
+
+#: config/arc/arc.opt:182
+#, no-c-format
+msgid "Generate call insns as register indirect calls."
+msgstr ""
+
+#: config/arc/arc.opt:186
+#, no-c-format
+msgid "Do no generate BRcc instructions in arc_reorg."
+msgstr ""
+
+#: config/arc/arc.opt:190
+#, no-c-format
+msgid "Generate sdata references.  This is the default, unless you compile for PIC."
+msgstr ""
+
+#: config/arc/arc.opt:194
+#, no-c-format
+msgid "Generate millicode thunks."
+msgstr ""
+
+#: config/arc/arc.opt:198 config/arc/arc.opt:202
+#, no-c-format
+msgid "FPX: Generate Single Precision FPX (compact) instructions."
+msgstr ""
+
+#: config/arc/arc.opt:206
+#, no-c-format
+msgid "FPX: Generate Single Precision FPX (fast) instructions."
+msgstr ""
+
+#: config/arc/arc.opt:210
+#, no-c-format
+msgid "FPX: Enable Argonaut ARC CPU Double Precision Floating Point extensions."
+msgstr ""
+
+#: config/arc/arc.opt:214 config/arc/arc.opt:218
+#, no-c-format
+msgid "FPX: Generate Double Precision FPX (compact) instructions."
+msgstr ""
+
+#: config/arc/arc.opt:222
+#, no-c-format
+msgid "FPX: Generate Double Precision FPX (fast) instructions."
+msgstr ""
+
+#: config/arc/arc.opt:226
+#, no-c-format
+msgid "Disable LR and SR instructions from using FPX extension aux registers."
+msgstr ""
+
+#: config/arc/arc.opt:230
+#, no-c-format
+msgid "Enable generation of ARC SIMD instructions via target-specific builtins."
+msgstr ""
+
+#: config/arc/arc.opt:234
+#, no-c-format
+msgid "-mcpu=CPU\tCompile code for ARC variant CPU."
+msgstr ""
+
+#: config/arc/arc.opt:238
+#, no-c-format
+msgid "Size optimization level: 0:none 1:opportunistic 2: regalloc 3:drop align, -Os."
+msgstr ""
+
+#: config/arc/arc.opt:246
+#, no-c-format
+msgid "Cost to assume for a multiply instruction, with 4 being equal to a normal insn."
+msgstr ""
+
+#: config/arc/arc.opt:250
+#, no-c-format
+msgid "-mtune=TUNE\tTune code for given ARC variant."
+msgstr ""
+
+#: config/arc/arc.opt:284
+#, no-c-format
+msgid "Enable the use of indexed loads."
+msgstr ""
+
+#: config/arc/arc.opt:288
+#, no-c-format
+msgid "Enable the use of pre/post modify with register displacement."
+msgstr ""
+
+#: config/arc/arc.opt:292
+#, no-c-format
+msgid "Generate 32x16 multiply and mac instructions."
+msgstr ""
+
+#: config/arc/arc.opt:300
+#, no-c-format
+msgid "Don't use less than 25 bit addressing range for calls."
+msgstr ""
+
+#: config/arc/arc.opt:322
+#, no-c-format
+msgid "Enable pre-reload use of cbranchsi pattern."
+msgstr ""
+
+#: config/arc/arc.opt:330
+#, no-c-format
+msgid "Use pc-relative switch case tables - this enables case table shortening."
+msgstr ""
+
+#: config/arc/arc.opt:334
+#, no-c-format
+msgid "Enable compact casesi pattern."
+msgstr ""
+
+#: config/arc/arc.opt:338
+#, no-c-format
+msgid "Enable 'q' instruction alternatives."
+msgstr ""
+
+#: config/arc/arc.opt:342
+#, no-c-format
+msgid "Expand adddi3 and subdi3 at rtl generation time into add.f / adc etc."
+msgstr ""
+
+#: config/arc/arc.opt:349
+#, no-c-format
+msgid "Enable variable polynomial CRC extension."
+msgstr ""
+
+#: config/arc/arc.opt:353
+#, no-c-format
+msgid "Enable DSP 3.1 Pack A extensions."
+msgstr ""
+
+#: config/arc/arc.opt:357
+#, no-c-format
+msgid "Enable dual viterbi butterfly extension."
+msgstr ""
+
+#: config/arc/arc.opt:367
+#, no-c-format
+msgid "Enable Dual and Single Operand Instructions for Telephony."
+msgstr ""
+
+#: config/arc/arc.opt:371
+#, no-c-format
+msgid "Enable XY Memory extension (DSP version 3)."
+msgstr ""
+
+#: config/arc/arc.opt:376
+#, no-c-format
+msgid "Enable Locked Load/Store Conditional extension."
+msgstr ""
+
+#: config/arc/arc.opt:380
+#, no-c-format
+msgid "Enable swap byte ordering extension instruction."
+msgstr ""
+
+#: config/arc/arc.opt:384
+#, no-c-format
+msgid "Enable 64-bit Time-Stamp Counter extension instruction."
+msgstr ""
+
+#: config/arc/arc.opt:388
+#, no-c-format
+msgid "Pass -EB option through to linker."
+msgstr ""
+
+#: config/arc/arc.opt:392
+#, no-c-format
+msgid "Pass -EL option through to linker."
+msgstr ""
+
+#: config/arc/arc.opt:396
+#, no-c-format
+msgid "Pass -marclinux option through to linker."
+msgstr ""
+
+#: config/arc/arc.opt:400
+#, no-c-format
+msgid "Pass -marclinux_prof option through to linker."
+msgstr ""
+
+#: config/arc/arc.opt:409
+#, no-c-format
+msgid "Don't indicate any priority with TARGET_REGISTER_PRIORITY."
+msgstr ""
+
+#: config/arc/arc.opt:413
+#, no-c-format
+msgid "Indicate priority for r0..r3 / r12..r15 with TARGET_REGISTER_PRIORITY."
+msgstr ""
+
+#: config/arc/arc.opt:417
+#, no-c-format
+msgid "Reduce priority for r0..r3 / r12..r15 with TARGET_REGISTER_PRIORITY."
+msgstr ""
+
+#: config/arc/arc.opt:429
+#, no-c-format
+msgid "Enable atomic instructions."
+msgstr ""
+
+#: config/arc/arc.opt:433
+#, no-c-format
+msgid "Enable double load/store instructions for ARC HS."
+msgstr ""
+
+#: config/arc/arc.opt:437
+#, no-c-format
+msgid "Specify the name of the target floating point configuration."
+msgstr ""
+
+#: config/arc/arc.opt:480
+#, no-c-format
+msgid "Specify thread pointer register number."
+msgstr ""
+
+#: config/arc/arc.opt:487
+#, no-c-format
+msgid "Enable use of NPS400 bit operations."
+msgstr ""
+
+#: config/arc/arc.opt:491
+#, no-c-format
+msgid "Enable use of NPS400 xld/xst extension."
+msgstr ""
+
+#: config/arc/arc.opt:499
+#, no-c-format
+msgid "Specifies the registers that the processor saves on an interrupt entry and exit."
+msgstr ""
+
+#: config/arc/arc.opt:503
+#, no-c-format
+msgid "Specifies the number of registers replicated in second register bank on entry to fast interrupt."
+msgstr ""
+
+#: config/arc/arc.opt:507
+#, no-c-format
+msgid "Sets LP_COUNT register width.  Possible values are 8, 16, 20, 24, 28, and 32."
+msgstr ""
+
+#: config/arc/arc.opt:532
+#, no-c-format
+msgid "Enable 16-entry register file."
+msgstr ""
+
+#: config/arc/arc.opt:536
+#, no-c-format
+msgid "Enable use of BI/BIH instructions when available."
+msgstr ""
+
+#: config/arc/arc.opt:540
+#, no-c-format
+msgid "Enable ENTER_S and LEAVE_S opcodes for ARCv2."
+msgstr ""
+
+#: config/vxworks-smp.opt:25
+#, no-c-format
+msgid "Select VxWorks SMP C runtimes for linking."
+msgstr ""
+
+#: lto/lang.opt:50
+#, no-c-format
+msgid "Set linker output type (used internally during LTO optimization)."
+msgstr ""
+
+#: lto/lang.opt:54
+#, no-c-format
+msgid "Run the link-time optimizer in local transformation (LTRANS) mode."
+msgstr ""
+
+#: lto/lang.opt:58
+#, no-c-format
+msgid "Specify a file to which a list of files output by LTRANS is written."
+msgstr ""
+
+#: lto/lang.opt:62
+#, no-c-format
+msgid "The resolution file."
+msgstr ""
+
+#: lto/lang.opt:66
+#, no-c-format
+msgid "Run the link-time optimizer in whole program analysis (WPA) mode."
+msgstr ""
+
+#: lto/lang.opt:70
+#, no-c-format
+msgid "Whole program analysis (WPA) mode with number of parallel jobs specified."
+msgstr ""
+
+#: lto/lang.opt:78
+#, no-c-format
+msgid "Call the dump function for variables and function in IL."
+msgstr ""
+
+#: lto/lang.opt:82
+#, no-c-format
+msgid "Dump the demangled output."
+msgstr ""
+
+#: lto/lang.opt:86
+#, no-c-format
+msgid "Dump only the defined symbols."
+msgstr ""
+
+#: lto/lang.opt:90
+#, no-c-format
+msgid "Print the initial values of the variables."
+msgstr ""
+
+#: lto/lang.opt:94
+#, no-c-format
+msgid "Sort the symbols alphabetically."
+msgstr ""
+
+#: lto/lang.opt:98
+#, no-c-format
+msgid "Sort the symbols according to size."
+msgstr ""
+
+#: lto/lang.opt:102
+#, no-c-format
+msgid "Display the symbols in reverse order."
+msgstr ""
+
+#: lto/lang.opt:109
+#, no-c-format
+msgid "Dump the details of LTO objects."
+msgstr ""
+
+#: lto/lang.opt:113
+#, no-c-format
+msgid "Dump the statistics of tree types."
+msgstr ""
+
+#: lto/lang.opt:117
+#, no-c-format
+msgid "Dump the statistics of trees."
+msgstr ""
+
+#: lto/lang.opt:121
+#, no-c-format
+msgid "Dump the statistics of gimple statements."
+msgstr ""
+
+#: lto/lang.opt:131
+#, no-c-format
+msgid "Dump the dump tool command line options."
+msgstr ""
+
+#: lto/lang.opt:135
+#, no-c-format
+msgid "Dump the symtab callgraph."
+msgstr ""
+
+#: common.opt:243
+#, no-c-format
+msgid "Provide bash completion for options starting with provided string."
+msgstr ""
+
+#: common.opt:295
+#, no-c-format
+msgid "Display this information."
+msgstr ""
+
+#: common.opt:299
+#, no-c-format
+msgid "--help=<class>\tDisplay descriptions of a specific class of options.  <class> is one or more of optimizers, target, warnings, undocumented, params."
+msgstr ""
+
+#: common.opt:420
+#, no-c-format
+msgid "Display target specific command line options (including assembler and linker options)."
+msgstr ""
+
+#: common.opt:466
+#, no-c-format
+msgid "-O<number>\tSet optimization level to <number>."
+msgstr ""
+
+#: common.opt:470
+#, no-c-format
+msgid "Optimize for space rather than speed."
+msgstr ""
+
+#: common.opt:474
+#, no-c-format
+msgid "Optimize for speed disregarding exact standards compliance."
+msgstr ""
+
+#: common.opt:478
+#, no-c-format
+msgid "Optimize for debugging experience rather than speed or size."
+msgstr ""
+
+#: common.opt:482
+#, no-c-format
+msgid "Optimize for space aggressively rather than speed."
+msgstr ""
+
+#: common.opt:522
+#, no-c-format
+msgid "This switch is deprecated; use -Wextra instead."
+msgstr ""
+
+#: common.opt:535
+#, no-c-format
+msgid "Warn about returning structures, unions or arrays."
+msgstr ""
+
+#: common.opt:539
+#, no-c-format
+msgid "Warn if a loop with constant number of iterations triggers undefined behavior."
+msgstr ""
+
+#: common.opt:546
+#, no-c-format
+msgid "Warn if an array is accessed out of bounds."
+msgstr ""
+
+#: common.opt:550 common.opt:554
+#, no-c-format
+msgid "Warn for uses of pointers to deallocated storage."
+msgstr ""
+
+#: common.opt:558
+#, no-c-format
+msgid "Warn about inappropriate attribute usage."
+msgstr ""
+
+#: common.opt:562
+#, no-c-format
+msgid "Do not warn about specified attributes."
+msgstr ""
+
+#: common.opt:566 common.opt:570
+#, no-c-format
+msgid "Warn about type safety and similar errors and mismatches in declarations with alias attributes."
+msgstr ""
+
+#: common.opt:574
+#, no-c-format
+msgid "Warn when profiling instrumentation was requested, but could not be applied to a certain function."
+msgstr ""
+
+#: common.opt:579 common.opt:583
+#, no-c-format
+msgid "Warn about pointer casts which increase alignment."
+msgstr ""
+
+#: common.opt:587
+#, no-c-format
+msgid "Complain when a command-line option is valid, but not applicable to the current front end."
+msgstr ""
+
+#: common.opt:591
+#, no-c-format
+msgid "Warn when a #warning directive is encountered."
+msgstr ""
+
+#: common.opt:595
+#, no-c-format
+msgid "Warn about uses of __attribute__((warning)) declarations."
+msgstr ""
+
+#: common.opt:599
+#, no-c-format
+msgid "Warn if a deprecated compiler feature, class, method, or field is used."
+msgstr ""
+
+#: common.opt:603
+#, no-c-format
+msgid "Warn about uses of __attribute__((deprecated)) declarations."
+msgstr ""
+
+#: common.opt:607
+#, no-c-format
+msgid "Warn when an optimization pass is disabled."
+msgstr ""
+
+#: common.opt:611
+#, no-c-format
+msgid "Treat all warnings as errors."
+msgstr ""
+
+#: common.opt:615
+#, no-c-format
+msgid "Treat specified warning as error."
+msgstr ""
+
+#: common.opt:619
+#, no-c-format
+msgid "Print extra (possibly unwanted) warnings."
+msgstr ""
+
+#: common.opt:623
+#, no-c-format
+msgid "Exit on the first error occurred."
+msgstr ""
+
+#: common.opt:627
+#, no-c-format
+msgid "-Wframe-larger-than=<byte-size>\tWarn if a function's stack frame requires in excess of <byte-size>."
+msgstr ""
+
+#: common.opt:631
+#, no-c-format
+msgid "Disable -Wframe-larger-than= warning.  Equivalent to -Wframe-larger-than=<SIZE_MAX> or larger."
+msgstr ""
+
+#: common.opt:635
+#, no-c-format
+msgid "Warn when attempting to free a non-heap object."
+msgstr ""
+
+#: common.opt:639
+#, no-c-format
+msgid "Warn when -fhardened did not enable an option from its set."
+msgstr ""
+
+#: common.opt:650
+#, no-c-format
+msgid "Warn when a switch case falls through."
+msgstr ""
+
+#: common.opt:658
+#, no-c-format
+msgid "Warn when an inlined function cannot be inlined."
+msgstr ""
+
+#: common.opt:662
+#, no-c-format
+msgid "Warn when an atomic memory model parameter is known to be outside the valid range."
+msgstr ""
+
+#: common.opt:669
+#, no-c-format
+msgid "-Wlarger-than=<byte-size>\tWarn if an object's size exceeds <byte-size>."
+msgstr ""
+
+#: common.opt:673
+#, no-c-format
+msgid "Disable -Wlarger-than= warning.  Equivalent to -Wlarger-than=<SIZE_MAX> or larger."
+msgstr ""
+
+#: common.opt:677
+#, no-c-format
+msgid "Warn if comparing pointer parameter with nonnull attribute with NULL."
+msgstr ""
+
+#: common.opt:681
+#, no-c-format
+msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
+msgstr ""
+
+#: common.opt:692
+#, no-c-format
+msgid "Warn about some C++ One Definition Rule violations during link time optimization."
+msgstr ""
+
+#: common.opt:696
+#, no-c-format
+msgid "Warn about overflow in arithmetic expressions."
+msgstr ""
+
+#: common.opt:700
+#, no-c-format
+msgid "During link time optimization warn about mismatched types of global declarations."
+msgstr ""
+
+#: common.opt:704
+#, no-c-format
+msgid "Warn when the packed attribute has no effect on struct layout."
+msgstr ""
+
+#: common.opt:708
+#, no-c-format
+msgid "Warn when padding is required to align structure members."
+msgstr ""
+
+#: common.opt:712
+#, no-c-format
+msgid "Issue warnings needed for strict compliance to the standard."
+msgstr ""
+
+#: common.opt:716
+#, no-c-format
+msgid "Warn about returning a pointer/reference to a local or temporary variable."
+msgstr ""
+
+#: common.opt:720
+#, no-c-format
+msgid "Warn when one variable shadows another.  Same as -Wshadow=global."
+msgstr ""
+
+#: common.opt:724
+#, no-c-format
+msgid "Warn when one variable shadows another (globally)."
+msgstr ""
+
+#: common.opt:728
+#, no-c-format
+msgid "Warn when one local variable shadows another local variable or parameter."
+msgstr ""
+
+#: common.opt:735
+#, no-c-format
+msgid "Warn when one local variable shadows another local variable or parameter of compatible type."
+msgstr ""
+
+#: common.opt:742
+#, no-c-format
+msgid "Warn when not issuing stack smashing protection for some reason."
+msgstr ""
+
+#: common.opt:746
+#, no-c-format
+msgid "-Wstack-usage=<byte-size>\tWarn if stack usage might exceed <byte-size>."
+msgstr ""
+
+#: common.opt:750
+#, no-c-format
+msgid "Disable Wstack-usage= warning.  Equivalent to Wstack-usage=<SIZE_MAX> or larger."
+msgstr ""
+
+#: common.opt:754 common.opt:758
+#, no-c-format
+msgid "Warn about code which might break strict aliasing rules."
+msgstr ""
+
+#: common.opt:762 common.opt:766
+#, no-c-format
+msgid "Warn about optimizations that assume that signed overflow is undefined."
+msgstr ""
+
+#: common.opt:770
+#, no-c-format
+msgid "Warn about functions which might be candidates for __attribute__((cold))."
+msgstr ""
+
+#: common.opt:774
+#, no-c-format
+msgid "Warn about functions which might be candidates for __attribute__((const))."
+msgstr ""
+
+#: common.opt:778
+#, no-c-format
+msgid "Warn about functions which might be candidates for __attribute__((pure))."
+msgstr ""
+
+#: common.opt:782
+#, no-c-format
+msgid "Warn about functions which might be candidates for __attribute__((noreturn))."
+msgstr ""
+
+#: common.opt:786
+#, no-c-format
+msgid "Warn about functions which might be candidates for __attribute__((malloc))."
+msgstr ""
+
+#: common.opt:790
+#, no-c-format
+msgid "Warn about functions which might be candidates for __attribute__((returns_nonnull))."
+msgstr ""
+
+#: common.opt:794
+#, no-c-format
+msgid "Warn about C++ polymorphic types where adding final keyword would improve code quality."
+msgstr ""
+
+#: common.opt:798
+#, no-c-format
+msgid "Warn about C++ virtual methods where adding final keyword would improve code quality."
+msgstr ""
+
+#: common.opt:802
+#, no-c-format
+msgid "Warn about statements between switch's controlling expression and the first case."
+msgstr ""
+
+#: common.opt:807
+#, no-c-format
+msgid "Do not suppress warnings from system headers."
+msgstr ""
+
+#: common.opt:811
+#, no-c-format
+msgid "Warn whenever a trampoline is generated."
+msgstr ""
+
+#: common.opt:815
+#, no-c-format
+msgid "Warn about cases where -ftrivial-auto-var-init cannot initialize an auto variable."
+msgstr ""
+
+#: common.opt:819
+#, no-c-format
+msgid "Warn if a comparison is always true or always false due to the limited range of the data type."
+msgstr ""
+
+#: common.opt:823
+#, no-c-format
+msgid "Warn about uninitialized automatic variables."
+msgstr ""
+
+#: common.opt:827
+#, no-c-format
+msgid "Warn about maybe uninitialized automatic variables."
+msgstr ""
+
+#: common.opt:835
+#, no-c-format
+msgid "Enable all -Wunused- warnings."
+msgstr ""
+
+#: common.opt:839
+#, no-c-format
+msgid "Warn when a function parameter is only set, otherwise unused."
+msgstr ""
+
+#: common.opt:843
+#, no-c-format
+msgid "Warn when a variable is only set, otherwise unused."
+msgstr ""
+
+#: common.opt:847
+#, no-c-format
+msgid "Warn when a function is unused."
+msgstr ""
+
+#: common.opt:851
+#, no-c-format
+msgid "Warn when a label is unused."
+msgstr ""
+
+#: common.opt:855
+#, no-c-format
+msgid "Warn when a function parameter is unused."
+msgstr ""
+
+#: common.opt:859
+#, no-c-format
+msgid "Warn when an expression value is unused."
+msgstr ""
+
+#: common.opt:863
+#, no-c-format
+msgid "Warn when a variable is unused."
+msgstr ""
+
+#: common.opt:867
+#, no-c-format
+msgid "Warn in case profiles in -fprofile-use do not match."
+msgstr ""
+
+#: common.opt:871
+#, no-c-format
+msgid "Warn in case a function ends earlier than it begins due to an invalid linenum macros."
+msgstr ""
+
+#: common.opt:875
+#, no-c-format
+msgid "Warn when a conditional has too many terms and condition coverage profiling gives up instrumenting the expression."
+msgstr ""
+
+#: common.opt:880
+#, no-c-format
+msgid "Warn in case profiles in -fprofile-use do not exist."
+msgstr ""
+
+#: common.opt:884
+#, no-c-format
+msgid "Warn when a vector operation is compiled outside the SIMD."
+msgstr ""
+
+#: common.opt:888
+#, no-c-format
+msgid "Warn about unsupported features in ThreadSanitizer."
+msgstr ""
+
+#: common.opt:904
+#, no-c-format
+msgid "-aux-info <file>\tEmit declaration information into <file>."
+msgstr ""
+
+#: common.opt:917
+#, no-c-format
+msgid "-d<letters>\tEnable dumps from specific passes of the compiler."
+msgstr ""
+
+#: common.opt:921
+#, no-c-format
+msgid "-dumpbase <file>\tSet the file basename to be used for dumps."
+msgstr ""
+
+#: common.opt:925
+#, no-c-format
+msgid "-dumpbase-ext .<ext>    Drop a trailing .<ext> from the dump basename to name auxiliary output files."
+msgstr ""
+
+#: common.opt:929
+#, no-c-format
+msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
+msgstr ""
+
+#: common.opt:1035
+#, no-c-format
+msgid "The version of the C++ ABI in use."
+msgstr ""
+
+#: common.opt:1039
+#, no-c-format
+msgid "Aggressively optimize loops using language constraints."
+msgstr ""
+
+#: common.opt:1043
+#, no-c-format
+msgid "Align the start of functions."
+msgstr ""
+
+#: common.opt:1050
+#, no-c-format
+msgid "Align labels which are only reached by jumping."
+msgstr ""
+
+#: common.opt:1057
+#, no-c-format
+msgid "Align all labels."
+msgstr ""
+
+#: common.opt:1064
+#, no-c-format
+msgid "Align the start of loops."
+msgstr ""
+
+#: common.opt:1071
+#, no-c-format
+msgid "Allow the compiler to introduce new data races on stores."
+msgstr ""
+
+#: common.opt:1075
+#, no-c-format
+msgid "Enable static analysis pass."
+msgstr ""
+
+#: common.opt:1095
+#, no-c-format
+msgid "Select what to sanitize."
+msgstr ""
+
+#: common.opt:1099
+#, no-c-format
+msgid "Select type of coverage sanitization."
+msgstr ""
+
+#: common.opt:1112
+#, no-c-format
+msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
+msgstr ""
+
+#: common.opt:1116
+#, no-c-format
+msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
+msgstr ""
+
+#: common.opt:1121
+#, no-c-format
+msgid "After diagnosing undefined behavior attempt to continue execution."
+msgstr ""
+
+#: common.opt:1125
+#, no-c-format
+msgid "This switch is deprecated; use -fsanitize-recover= instead."
+msgstr ""
+
+#: common.opt:1129
+#, no-c-format
+msgid "Use traps instead of diagnostics of undefined behavior sanitizers."
+msgstr ""
+
+#: common.opt:1139
+#, no-c-format
+msgid "This switch is deprecated; use -fsanitize-trap= instead."
+msgstr ""
+
+#: common.opt:1143
+#, no-c-format
+msgid "Generate unwind tables that are exact at each instruction boundary."
+msgstr ""
+
+#: common.opt:1147
+#, no-c-format
+msgid "Generate auto-inc/dec instructions."
+msgstr ""
+
+#: common.opt:1151
+#, no-c-format
+msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
+msgstr ""
+
+#: common.opt:1156
+#, no-c-format
+msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
+msgstr ""
+
+#: common.opt:1165
+#, no-c-format
+msgid "Generate code to check bounds before indexing arrays."
+msgstr ""
+
+#: common.opt:1169
+#, no-c-format
+msgid "Replace add, compare, branch with branch on count register."
+msgstr ""
+
+#: common.opt:1173
+#, no-c-format
+msgid "Use profiling information for branch probabilities."
+msgstr ""
+
+#: common.opt:1189
+#, no-c-format
+msgid "Output callgraph information on a per-file basis."
+msgstr ""
+
+#: common.opt:1193
+#, no-c-format
+msgid "Output callgraph information on a per-file basis with decorations."
+msgstr ""
+
+#: common.opt:1197
+#, no-c-format
+msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
+msgstr ""
+
+#: common.opt:1201
+#, no-c-format
+msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
+msgstr ""
+
+#: common.opt:1208
+#, no-c-format
+msgid "Save registers around function calls."
+msgstr ""
+
+#: common.opt:1212
+#, no-c-format
+msgid "This switch is deprecated; do not use."
+msgstr ""
+
+#: common.opt:1216
+#, no-c-format
+msgid "Check the return value of new in C++."
+msgstr ""
+
+#: common.opt:1220 common.opt:1224
+#, no-c-format
+msgid "Perform internal consistency checkings."
+msgstr ""
+
+#: common.opt:1228
+#, no-c-format
+msgid "For -f*-prefix-map= options compare canonicalized pathnames rather than just strings."
+msgstr ""
+
+#: common.opt:1232
+#, no-c-format
+msgid "Enable code hoisting."
+msgstr ""
+
+#: common.opt:1236
+#, no-c-format
+msgid "Looks for opportunities to reduce stack adjustments and stack references."
+msgstr ""
+
+#: common.opt:1240
+#, no-c-format
+msgid "Put uninitialized globals in the common section."
+msgstr ""
+
+#: common.opt:1248
+#, no-c-format
+msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
+msgstr ""
+
+#: common.opt:1252
+#, no-c-format
+msgid "Run only the second compilation of -fcompare-debug."
+msgstr ""
+
+#: common.opt:1256
+#, no-c-format
+msgid "Perform comparison elimination after register allocation has finished."
+msgstr ""
+
+#: common.opt:1260
+#, no-c-format
+msgid "Do not perform optimizations increasing noticeably stack usage."
+msgstr ""
+
+#: common.opt:1264
+#, no-c-format
+msgid "Perform a register copy-propagation optimization pass."
+msgstr ""
+
+#: common.opt:1268
+#, no-c-format
+msgid "Fold instructions calculating memory offsets to the memory access instruction if possible."
+msgstr ""
+
+#: common.opt:1272
+#, no-c-format
+msgid "Perform cross-jumping optimization."
+msgstr ""
+
+#: common.opt:1276
+#, no-c-format
+msgid "When running CSE, follow jumps to their targets."
+msgstr ""
+
+#: common.opt:1284
+#, no-c-format
+msgid "Omit range reduction step when performing complex division."
+msgstr ""
+
+#: common.opt:1288
+#, no-c-format
+msgid "Complex multiplication and division follow Fortran rules."
+msgstr ""
+
+#: common.opt:1292
+#, no-c-format
+msgid "Place data items into their own section."
+msgstr ""
+
+#: common.opt:1296
+#, no-c-format
+msgid "List all available debugging counters with their limits and counts."
+msgstr ""
+
+#: common.opt:1300
+#, no-c-format
+msgid "-fdbg-cnt=<counter>[:<lower_limit1>-]<upper_limit1>[:<lower_limit2>-<upper_limit2>:...][,<counter>:...]\tSet the debug counter limit."
+msgstr ""
+
+#: common.opt:1304
+#, no-c-format
+msgid "-fdebug-prefix-map=<old>=<new>\tMap one directory name to another in debug information."
+msgstr ""
+
+#: common.opt:1308
+#, no-c-format
+msgid "-ffile-prefix-map=<old>=<new>\tMap one directory name to another in compilation result."
+msgstr ""
+
+#: common.opt:1312
+#, no-c-format
+msgid "Output .debug_types section when using DWARF v4 debuginfo."
+msgstr ""
+
+#: common.opt:1318
+#, no-c-format
+msgid "Defer popping functions args from stack until later."
+msgstr ""
+
+#: common.opt:1322
+#, no-c-format
+msgid "Attempt to fill delay slots of branch instructions."
+msgstr ""
+
+#: common.opt:1326
+#, no-c-format
+msgid "Delete dead instructions that may throw exceptions."
+msgstr ""
+
+#: common.opt:1330
+#, no-c-format
+msgid "Delete useless null pointer checks."
+msgstr ""
+
+#: common.opt:1334
+#, no-c-format
+msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
+msgstr ""
+
+#: common.opt:1338
+#, no-c-format
+msgid "Perform speculative devirtualization."
+msgstr ""
+
+#: common.opt:1342
+#, no-c-format
+msgid "Try to convert virtual calls to direct ones."
+msgstr ""
+
+#: common.opt:1346
+#, no-c-format
+msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
+msgstr ""
+
+#: common.opt:1363
+#, no-c-format
+msgid "Show the source line with a caret indicating the column."
+msgstr ""
+
+#: common.opt:1367
+#, no-c-format
+msgid "Show labels annotating ranges of source code when showing source."
+msgstr ""
+
+#: common.opt:1371
+#, no-c-format
+msgid "Show line numbers in the left margin when showing source."
+msgstr ""
+
+#: common.opt:1379
+#, no-c-format
+msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
+msgstr ""
+
+#: common.opt:1399
+#, no-c-format
+msgid "Enable formatting of JSON output."
+msgstr ""
+
+#: common.opt:1403
+#, no-c-format
+msgid "-fdiagnostics-urls=[never|always|auto]\tEmbed URLs in diagnostics."
+msgstr ""
+
+#: common.opt:1423
+#, no-c-format
+msgid "-fdiagnostics-column-unit=[display|byte]\tSelect whether column numbers are output as display columns (default) or raw bytes."
+msgstr ""
+
+#: common.opt:1427
+#, no-c-format
+msgid "-fdiagnostics-column-origin=<number>\tSet the number of the first column.  The default is 1-based as per GNU style, but some utilities may expect 0-based, for example."
+msgstr ""
+
+#: common.opt:1431
+#, no-c-format
+msgid "-fdiagnostics-format=[text|sarif-stderr|sarif-file|json|json-stderr|json-file]\tSelect output format."
+msgstr ""
+
+#: common.opt:1435
+#, no-c-format
+msgid "-fdiagnostics-escape-format=[unicode|bytes]\tSelect how to escape non-printable-ASCII bytes in the source for diagnostics that suggest it."
+msgstr ""
+
+#: common.opt:1482
+#, no-c-format
+msgid "Print fix-it hints in machine-readable form."
+msgstr ""
+
+#: common.opt:1486
+#, no-c-format
+msgid "Print fix-it hints to stderr in unified diff format."
+msgstr ""
+
+#: common.opt:1490
+#, no-c-format
+msgid "Amend appropriate diagnostic messages with the command line option that controls them."
+msgstr ""
+
+#: common.opt:1494
+#, no-c-format
+msgid "Print CWE identifiers for diagnostic messages, where available."
+msgstr ""
+
+#: common.opt:1498
+#, no-c-format
+msgid "Print any rules associated with diagnostic messages."
+msgstr ""
+
+#: common.opt:1502
+#, no-c-format
+msgid "Specify how to print any control-flow path associated with a diagnostic."
+msgstr ""
+
+#: common.opt:1506
+#, no-c-format
+msgid "Turn off any diagnostics features that complicate the output, such as line numbers, color, and warning URLs."
+msgstr ""
+
+#: common.opt:1510
+#, no-c-format
+msgid "-ftabstop=<number>      Distance between tab stops for column reporting."
+msgstr ""
+
+#: common.opt:1526
+#, no-c-format
+msgid "Show stack depths of events in paths."
+msgstr ""
+
+#: common.opt:1530
+#, no-c-format
+msgid "-fdiagnostics-text-art-charset=[none|ascii|unicode|emoji]\tDetermine which characters to use in text arg diagrams."
+msgstr ""
+
+#: common.opt:1549
+#, no-c-format
+msgid "Set minimum width of left margin of source code when showing source."
+msgstr ""
+
+#: common.opt:1553
+#, no-c-format
+msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2\tDisable an optimization pass."
+msgstr ""
+
+#: common.opt:1557
+#, no-c-format
+msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2\tEnable an optimization pass."
+msgstr ""
+
+#: common.opt:1561
+#, no-c-format
+msgid "-fdump-<type>\tDump various compiler internals to a file."
+msgstr ""
+
+#: common.opt:1568
+#, no-c-format
+msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
+msgstr ""
+
+#: common.opt:1572
+#, no-c-format
+msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
+msgstr ""
+
+#: common.opt:1576
+#, no-c-format
+msgid "Suppress output of addresses in debugging dumps."
+msgstr ""
+
+#: common.opt:1580
+#, no-c-format
+msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
+msgstr ""
+
+#: common.opt:1585
+#, no-c-format
+msgid "Dump detailed information on GCC's internal representation of source code locations."
+msgstr ""
+
+#: common.opt:1589
+#, no-c-format
+msgid "Dump optimization passes."
+msgstr ""
+
+#: common.opt:1593
+#, no-c-format
+msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
+msgstr ""
+
+#: common.opt:1597
+#, no-c-format
+msgid "Suppress output of previous and next insn numbers in debugging dumps."
+msgstr ""
+
+#: common.opt:1601
+#, no-c-format
+msgid "Enable CFI tables via GAS assembler directives."
+msgstr ""
+
+#: common.opt:1605
+#, no-c-format
+msgid "Perform early inlining."
+msgstr ""
+
+#: common.opt:1613
+#, no-c-format
+msgid "Perform interprocedural reduction of aggregates."
+msgstr ""
+
+#: common.opt:1617
+#, no-c-format
+msgid "Perform unused symbol elimination in debug info."
+msgstr ""
+
+#: common.opt:1621
+#, no-c-format
+msgid "Perform unused type elimination in debug info."
+msgstr ""
+
+#: common.opt:1625
+#, no-c-format
+msgid "Do not suppress C++ class debug information."
+msgstr ""
+
+#: common.opt:1629
+#, no-c-format
+msgid "Enable exception handling."
+msgstr ""
+
+#: common.opt:1633
+#, no-c-format
+msgid "Perform a number of minor, expensive optimizations."
+msgstr ""
+
+#: common.opt:1637
+#, no-c-format
+msgid "-fexcess-precision=[fast|standard|16]\tSpecify handling of excess floating-point precision."
+msgstr ""
+
+#: common.opt:1655
+#, no-c-format
+msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
+msgstr ""
+
+#: common.opt:1671
+#, no-c-format
+msgid "Output lto objects containing both the intermediate language and binary output."
+msgstr ""
+
+#: common.opt:1675
+#, no-c-format
+msgid "Assume no NaNs or infinities are generated."
+msgstr ""
+
+#: common.opt:1679
+#, no-c-format
+msgid "Assume that loops with an exit will terminate and not loop indefinitely."
+msgstr ""
+
+#: common.opt:1683
+#, no-c-format
+msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
+msgstr ""
+
+#: common.opt:1687
+#, no-c-format
+msgid "Don't allocate floats and doubles in extended-precision registers."
+msgstr ""
+
+#: common.opt:1695
+#, no-c-format
+msgid "Perform a forward propagation pass on RTL."
+msgstr ""
+
+#: common.opt:1699
+#, no-c-format
+msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
+msgstr ""
+
+#: common.opt:1715
+#, no-c-format
+msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
+msgstr ""
+
+#: common.opt:1722
+#, no-c-format
+msgid "Allow function addresses to be held in registers."
+msgstr ""
+
+#: common.opt:1726
+#, no-c-format
+msgid "Place each function into its own section."
+msgstr ""
+
+#: common.opt:1730
+#, no-c-format
+msgid "Perform global common subexpression elimination."
+msgstr ""
+
+#: common.opt:1734
+#, no-c-format
+msgid "Perform enhanced load motion during global common subexpression elimination."
+msgstr ""
+
+#: common.opt:1738
+#, no-c-format
+msgid "Perform store motion after global common subexpression elimination."
+msgstr ""
+
+#: common.opt:1742
+#, no-c-format
+msgid "Perform redundant load after store elimination in global common subexpression elimination."
+msgstr ""
+
+#: common.opt:1747
+#, no-c-format
+msgid "Perform global common subexpression elimination after register allocation has finished."
+msgstr ""
+
+#: common.opt:1764
+#, no-c-format
+msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information."
+msgstr ""
+
+#: common.opt:1769
+#, no-c-format
+msgid "Enable in and out of Graphite representation."
+msgstr ""
+
+#: common.opt:1773
+#, no-c-format
+msgid "Enable Graphite Identity transformation."
+msgstr ""
+
+#: common.opt:1777
+#, no-c-format
+msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
+msgstr ""
+
+#: common.opt:1786
+#, no-c-format
+msgid "Improve GCC's ability to track column numbers in large source files, at the expense of slower compilation."
+msgstr ""
+
+#: common.opt:1791
+#, no-c-format
+msgid "Mark all loops as parallel."
+msgstr ""
+
+#: common.opt:1795 common.opt:1803 common.opt:3148
+#, no-c-format
+msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
+msgstr ""
+
+#: common.opt:1799
+#, no-c-format
+msgid "Enable loop interchange on trees."
+msgstr ""
+
+#: common.opt:1807
+#, no-c-format
+msgid "Perform unroll-and-jam on loops."
+msgstr ""
+
+#: common.opt:1811
+#, no-c-format
+msgid "Enable support for GNU transactional memory."
+msgstr ""
+
+#: common.opt:1815
+#, no-c-format
+msgid "Use STB_GNU_UNIQUE if supported by the assembler."
+msgstr ""
+
+#: common.opt:1823
+#, no-c-format
+msgid "Enable the loop nest optimizer."
+msgstr ""
+
+#: common.opt:1827
+#, no-c-format
+msgid "Force bitfield accesses to match their type width."
+msgstr ""
+
+#: common.opt:1831
+#, no-c-format
+msgid "Merge adjacent stores."
+msgstr ""
+
+#: common.opt:1835
+#, no-c-format
+msgid "Enable guessing of branch probabilities."
+msgstr ""
+
+#: common.opt:1839
+#, no-c-format
+msgid "Enable various security-relevant flags."
+msgstr ""
+
+#: common.opt:1843
+#, no-c-format
+msgid "Harden conditionals not used in branches, checking reversed conditions."
+msgstr ""
+
+#: common.opt:1847
+#, no-c-format
+msgid "Harden conditional branches by checking reversed conditions."
+msgstr ""
+
+#: common.opt:1851
+#, no-c-format
+msgid "Harden control flow by recording and checking execution paths."
+msgstr ""
+
+#: common.opt:1855
+#, no-c-format
+msgid "Disable CFR in leaf functions."
+msgstr ""
+
+#: common.opt:1859
+#, no-c-format
+msgid "Check CFR execution paths also before calls followed by returns of their results."
+msgstr ""
+
+#: common.opt:1863
+#, no-c-format
+msgid "Check CFR execution paths also when exiting a function through an exception."
+msgstr ""
+
+#: common.opt:1867
+#, no-c-format
+msgid "-fhardcfr-check-noreturn-calls=[always|no-xthrow|nothrow|never]\tCheck CFR execution paths also before calling noreturn functions."
+msgstr ""
+
+#: common.opt:1890
+#, no-c-format
+msgid "Process #ident directives."
+msgstr ""
+
+#: common.opt:1894
+#, no-c-format
+msgid "Perform conversion of conditional jumps to branchless equivalents."
+msgstr ""
+
+#: common.opt:1898
+#, no-c-format
+msgid "Perform conversion of conditional jumps to conditional execution."
+msgstr ""
+
+#: common.opt:1902
+#, no-c-format
+msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
+msgstr ""
+
+#: common.opt:1918
+#, no-c-format
+msgid "Convert conditional jumps in innermost loops to branchless equivalents."
+msgstr ""
+
+#: common.opt:1930
+#, no-c-format
+msgid "Do not generate .size directives."
+msgstr ""
+
+#: common.opt:1934
+#, no-c-format
+msgid "Perform indirect inlining."
+msgstr ""
+
+#: common.opt:1940
+#, no-c-format
+msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
+msgstr ""
+
+#: common.opt:1944
+#, no-c-format
+msgid "Integrate functions into their callers when code size is known not to grow."
+msgstr ""
+
+#: common.opt:1948
+#, no-c-format
+msgid "Integrate functions not declared \"inline\" into their callers when profitable."
+msgstr ""
+
+#: common.opt:1952
+#, no-c-format
+msgid "Integrate functions only required by their single caller."
+msgstr ""
+
+#: common.opt:1959
+#, no-c-format
+msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
+msgstr ""
+
+#: common.opt:1963
+#, no-c-format
+msgid "Inline __atomic operations when a lock free instruction sequence is available."
+msgstr ""
+
+#: common.opt:1973
+#, no-c-format
+msgid "-finline-stringops[=memcmp|memcpy|memmove|memset] Expand supported mem/str operations inline, even if against optimization."
+msgstr ""
+
+#: common.opt:2004
+#, no-c-format
+msgid "-fcf-protection=[full|branch|return|none|check]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
+msgstr ""
+
+#: common.opt:2027
+#, no-c-format
+msgid "Instrument function entry and exit with profiling calls."
+msgstr ""
+
+#: common.opt:2031
+#, no-c-format
+msgid "Instrument function entry and exit with profiling calls invoked once."
+msgstr ""
+
+#: common.opt:2035
+#, no-c-format
+msgid "-finstrument-functions-exclude-function-list=name,...\tDo not instrument listed functions."
+msgstr ""
+
+#: common.opt:2039
+#, no-c-format
+msgid "-finstrument-functions-exclude-file-list=filename,...\tDo not instrument functions listed in files."
+msgstr ""
+
+#: common.opt:2043
+#, no-c-format
+msgid "Perform interprocedural constant propagation."
+msgstr ""
+
+#: common.opt:2047
+#, no-c-format
+msgid "Perform cloning to make Interprocedural constant propagation stronger."
+msgstr ""
+
+#: common.opt:2055
+#, no-c-format
+msgid "Perform interprocedural bitwise constant propagation."
+msgstr ""
+
+#: common.opt:2059
+#, no-c-format
+msgid "Perform interprocedural modref analysis."
+msgstr ""
+
+#: common.opt:2063
+#, no-c-format
+msgid "Perform interprocedural profile propagation."
+msgstr ""
+
+#: common.opt:2067
+#, no-c-format
+msgid "Perform interprocedural points-to analysis."
+msgstr ""
+
+#: common.opt:2071
+#, no-c-format
+msgid "Discover pure and const functions."
+msgstr ""
+
+#: common.opt:2075
+#, no-c-format
+msgid "Perform Identical Code Folding for functions and read-only variables."
+msgstr ""
+
+#: common.opt:2079
+#, no-c-format
+msgid "Perform Identical Code Folding for functions."
+msgstr ""
+
+#: common.opt:2083
+#, no-c-format
+msgid "Perform Identical Code Folding for variables."
+msgstr ""
+
+#: common.opt:2087
+#, no-c-format
+msgid "Discover read-only and non addressable static variables."
+msgstr ""
+
+#: common.opt:2091
+#, no-c-format
+msgid "Discover read-only, write-only and non-addressable static variables."
+msgstr ""
+
+#: common.opt:2095
+#, no-c-format
+msgid "Reduce stack alignment on call sites if possible."
+msgstr ""
+
+#: common.opt:2107
+#, no-c-format
+msgid "Perform IPA Value Range Propagation."
+msgstr ""
+
+#: common.opt:2111
+#, no-c-format
+msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
+msgstr ""
+
+#: common.opt:2115
+#, no-c-format
+msgid "Assume strict aliasing rules apply across (uninlined) function boundaries."
+msgstr ""
+
+#: common.opt:2128
+#, no-c-format
+msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
+msgstr ""
+
+#: common.opt:2144
+#, no-c-format
+msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
+msgstr ""
+
+#: common.opt:2149
+#, no-c-format
+msgid "Use IRA based register pressure calculation in RTL loop optimizations."
+msgstr ""
+
+#: common.opt:2154
+#, no-c-format
+msgid "Share slots for saving different hard registers."
+msgstr ""
+
+#: common.opt:2158
+#, no-c-format
+msgid "Share stack slots for spilled pseudo-registers."
+msgstr ""
+
+#: common.opt:2162
+#, no-c-format
+msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
+msgstr ""
+
+#: common.opt:2166
+#, no-c-format
+msgid "Optimize induction variables on trees."
+msgstr ""
+
+#: common.opt:2170
+#, no-c-format
+msgid "Use jump tables for sufficiently large switch statements."
+msgstr ""
+
+#: common.opt:2174
+#, no-c-format
+msgid "Use bit tests for sufficiently large switch statements."
+msgstr ""
+
+#: common.opt:2178
+#, no-c-format
+msgid "Generate code for functions even if they are fully inlined."
+msgstr ""
+
+#: common.opt:2182
+#, no-c-format
+msgid "Generate code for static functions even if they are never called."
+msgstr ""
+
+#: common.opt:2186
+#, no-c-format
+msgid "Emit static const variables even if they are not used."
+msgstr ""
+
+#: common.opt:2190
+#, no-c-format
+msgid "Give external symbols a leading underscore."
+msgstr ""
+
+#: common.opt:2198
+#, no-c-format
+msgid "Do CFG-sensitive rematerialization in LRA."
+msgstr ""
+
+#: common.opt:2202
+#, no-c-format
+msgid "Enable link-time optimization."
+msgstr ""
+
+#: common.opt:2206
+#, no-c-format
+msgid "Link-time optimization with number of parallel jobs or jobserver."
+msgstr ""
+
+#: common.opt:2228
+#, no-c-format
+msgid "Specify the algorithm to partition symbols and vars at linktime."
+msgstr ""
+
+#: common.opt:2233
+#, no-c-format
+msgid "Use zlib/zstd compression level <number> for IL."
+msgstr ""
+
+#: common.opt:2241
+#, no-c-format
+msgid "Report various link-time optimization statistics."
+msgstr ""
+
+#: common.opt:2245
+#, no-c-format
+msgid "Report various link-time optimization statistics for WPA only."
+msgstr ""
+
+#: common.opt:2249
+#, no-c-format
+msgid "Set errno after built-in math functions."
+msgstr ""
+
+#: common.opt:2253
+#, no-c-format
+msgid "-fmax-errors=<number>\tMaximum number of errors to report."
+msgstr ""
+
+#: common.opt:2257
+#, no-c-format
+msgid "Report on permanent memory allocation."
+msgstr ""
+
+#: common.opt:2261
+#, no-c-format
+msgid "Report on permanent memory allocation in WPA only."
+msgstr ""
+
+#: common.opt:2268
+#, no-c-format
+msgid "Attempt to merge identical constants and constant variables."
+msgstr ""
+
+#: common.opt:2272
+#, no-c-format
+msgid "Attempt to merge identical constants across compilation units."
+msgstr ""
+
+#: common.opt:2276
+#, no-c-format
+msgid "Attempt to merge identical debug strings across compilation units."
+msgstr ""
+
+#: common.opt:2280
+#, no-c-format
+msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
+msgstr ""
+
+#: common.opt:2284
+#, no-c-format
+msgid "Align the start of every function."
+msgstr ""
+
+#: common.opt:2288
+#, no-c-format
+msgid "Perform SMS based modulo scheduling before the first scheduling pass."
+msgstr ""
+
+#: common.opt:2292
+#, no-c-format
+msgid "Perform SMS based modulo scheduling with register moves allowed."
+msgstr ""
+
+#: common.opt:2296
+#, no-c-format
+msgid "Move loop invariant computations out of loops."
+msgstr ""
+
+#: common.opt:2300
+#, no-c-format
+msgid "Move stores out of loops."
+msgstr ""
+
+#: common.opt:2304
+#, no-c-format
+msgid "Building block for specs-based multilib-aware TFLAGS."
+msgstr ""
+
+#: common.opt:2308
+#, no-c-format
+msgid "Use the RTL dead code elimination pass."
+msgstr ""
+
+#: common.opt:2312
+#, no-c-format
+msgid "Use the RTL dead store elimination pass."
+msgstr ""
+
+#: common.opt:2316
+#, no-c-format
+msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
+msgstr ""
+
+#: common.opt:2320
+#, no-c-format
+msgid "Support synchronous non-call exceptions."
+msgstr ""
+
+#: common.opt:2327
+#, no-c-format
+msgid "-foffload-options=<targets>=<options>\tSpecify options for the offloading targets."
+msgstr ""
+
+#: common.opt:2331
+#, no-c-format
+msgid "-foffload-abi=[lp64|ilp32]\tSet the ABI to use in an offload compiler."
+msgstr ""
+
+#: common.opt:2344
+#, no-c-format
+msgid "When possible do not generate stack frames."
+msgstr ""
+
+#: common.opt:2351
+#, no-c-format
+msgid "Generate SIMD clones for functions with the OpenMP declare target directive."
+msgstr ""
+
+#: common.opt:2370
+#, no-c-format
+msgid "Enable all optimization info dumps on stderr."
+msgstr ""
+
+#: common.opt:2374
+#, no-c-format
+msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
+msgstr ""
+
+#: common.opt:2378
+#, no-c-format
+msgid "Write a SRCFILE.opt-record.json file detailing what optimizations were performed."
+msgstr ""
+
+#: common.opt:2386
+#, no-c-format
+msgid "Optimize sibling and tail recursive calls."
+msgstr ""
+
+#: common.opt:2390
+#, no-c-format
+msgid "Perform partial inlining."
+msgstr ""
+
+#: common.opt:2394 common.opt:2398
+#, no-c-format
+msgid "Report on memory allocation before interprocedural optimization."
+msgstr ""
+
+#: common.opt:2402
+#, no-c-format
+msgid "Pack structure members together without holes."
+msgstr ""
+
+#: common.opt:2406
+#, no-c-format
+msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
+msgstr ""
+
+#: common.opt:2410
+#, no-c-format
+msgid "Return small aggregates in memory, not registers."
+msgstr ""
+
+#: common.opt:2414
+#, no-c-format
+msgid "Perform loop peeling."
+msgstr ""
+
+#: common.opt:2418
+#, no-c-format
+msgid "Enable machine specific peephole optimizations."
+msgstr ""
+
+#: common.opt:2422
+#, no-c-format
+msgid "Enable an RTL peephole pass before sched2."
+msgstr ""
+
+#: common.opt:2426
+#, no-c-format
+msgid "Generate position-independent code if possible (large mode)."
+msgstr ""
+
+#: common.opt:2430
+#, no-c-format
+msgid "Generate position-independent code for executables if possible (large mode)."
+msgstr ""
+
+#: common.opt:2434
+#, no-c-format
+msgid "Generate position-independent code if possible (small mode)."
+msgstr ""
+
+#: common.opt:2438
+#, no-c-format
+msgid "Generate position-independent code for executables if possible (small mode)."
+msgstr ""
+
+#: common.opt:2442
+#, no-c-format
+msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
+msgstr ""
+
+#: common.opt:2446
+#, no-c-format
+msgid "Specify a plugin to load."
+msgstr ""
+
+#: common.opt:2450
+#, no-c-format
+msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
+msgstr ""
+
+#: common.opt:2454
+#, no-c-format
+msgid "Run predictive commoning optimization."
+msgstr ""
+
+#: common.opt:2458
+#, no-c-format
+msgid "Generate prefetch instructions, if available, for arrays in loops."
+msgstr ""
+
+#: common.opt:2462
+#, no-c-format
+msgid "Enable basic program profiling code."
+msgstr ""
+
+#: common.opt:2466
+#, no-c-format
+msgid "Generate absolute source path names for gcov."
+msgstr ""
+
+#: common.opt:2470
+#, no-c-format
+msgid "Insert arc-based program profiling code."
+msgstr ""
+
+#: common.opt:2474
+#, no-c-format
+msgid "Insert condition coverage profiling code."
+msgstr ""
+
+#: common.opt:2478
+#, no-c-format
+msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
+msgstr ""
+
+#: common.opt:2483
+#, no-c-format
+msgid "Select the name for storing the profile note file."
+msgstr ""
+
+#: common.opt:2487
+#, no-c-format
+msgid "Enable correction of flow inconsistent profile data input."
+msgstr ""
+
+#: common.opt:2491
+#, no-c-format
+msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
+msgstr ""
+
+#: common.opt:2495
+#, no-c-format
+msgid "Instrument only functions from files whose name matches any of the regular expressions (separated by semi-colons)."
+msgstr ""
+
+#: common.opt:2499
+#, no-c-format
+msgid "Instrument only functions from files whose name does not match any of the regular expressions (separated by semi-colons)."
+msgstr ""
+
+#: common.opt:2515
+#, no-c-format
+msgid "-fprofile-reproducible=[serial|parallel-runs|multithreaded]\tControl level of reproducibility of profile gathered by -fprofile-generate."
+msgstr ""
+
+#: common.opt:2531
+#, no-c-format
+msgid "Remove prefix from absolute path before mangling name for -fprofile-generate= and -fprofile-use=."
+msgstr ""
+
+#: common.opt:2535
+#, no-c-format
+msgid "-fprofile-prefix-map=<old>=<new>\tMap one directory name to another in GCOV coverage result."
+msgstr ""
+
+#: common.opt:2539
+#, no-c-format
+msgid "Enable common options for generating profile info for profile feedback directed optimizations."
+msgstr ""
+
+#: common.opt:2543
+#, no-c-format
+msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
+msgstr ""
+
+#: common.opt:2547
+#, no-c-format
+msgid "Register the profile information in the .gcov_info section instead of using a constructor/destructor."
+msgstr ""
+
+#: common.opt:2551
+#, no-c-format
+msgid "Register the profile information in the specified section instead of using a constructor/destructor."
+msgstr ""
+
+#: common.opt:2555
+#, no-c-format
+msgid "Do not assume that functions never executed during the train run are cold."
+msgstr ""
+
+#: common.opt:2559
+#, no-c-format
+msgid "Enable common options for performing profile feedback directed optimizations."
+msgstr ""
+
+#: common.opt:2563
+#, no-c-format
+msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
+msgstr ""
+
+#: common.opt:2567
+#, no-c-format
+msgid "Insert code to profile values of expressions."
+msgstr ""
+
+#: common.opt:2571
+#, no-c-format
+msgid "Report on consistency of profile."
+msgstr ""
+
+#: common.opt:2575
+#, no-c-format
+msgid "Enable function reordering that improves code placement."
+msgstr ""
+
+#: common.opt:2579
+#, no-c-format
+msgid "Insert NOP instructions at each function entry."
+msgstr ""
+
+#: common.opt:2586
+#, no-c-format
+msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
+msgstr ""
+
+#: common.opt:2596
+#, no-c-format
+msgid "Record gcc command line switches in the object file."
+msgstr ""
+
+#: common.opt:2600
+#, no-c-format
+msgid "Return small aggregates in registers."
+msgstr ""
+
+#: common.opt:2608
+#, no-c-format
+msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
+msgstr ""
+
+#: common.opt:2622
+#, no-c-format
+msgid "-flive-patching=[inline-only-static|inline-clone]\tControl IPA optimizations to provide a safe compilation for live-patching.  At the same time, provides multiple-level control on the enabled IPA optimizations."
+msgstr ""
+
+#: common.opt:2637
+#, no-c-format
+msgid "Tell DCE to remove unused C++ allocations."
+msgstr ""
+
+#: common.opt:2641
+#, no-c-format
+msgid "Relief of register pressure through live range shrinkage."
+msgstr ""
+
+#: common.opt:2645
+#, no-c-format
+msgid "Perform a register renaming optimization pass."
+msgstr ""
+
+#: common.opt:2649
+#, no-c-format
+msgid "Perform a target dependent instruction fusion optimization pass."
+msgstr ""
+
+#: common.opt:2653
+#, no-c-format
+msgid "Reorder basic blocks to improve code placement."
+msgstr ""
+
+#: common.opt:2657
+#, no-c-format
+msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
+msgstr ""
+
+#: common.opt:2670
+#, no-c-format
+msgid "Reorder basic blocks and partition into hot and cold sections."
+msgstr ""
+
+#: common.opt:2674
+#, no-c-format
+msgid "Reorder functions to improve code placement."
+msgstr ""
+
+#: common.opt:2678
+#, no-c-format
+msgid "Add a common subexpression elimination pass after loop optimizations."
+msgstr ""
+
+#: common.opt:2686
+#, no-c-format
+msgid "Disable optimizations that assume default FP rounding behavior."
+msgstr ""
+
+#: common.opt:2690
+#, no-c-format
+msgid "Enable scheduling across basic blocks."
+msgstr ""
+
+#: common.opt:2694
+#, no-c-format
+msgid "Enable register pressure sensitive insn scheduling."
+msgstr ""
+
+#: common.opt:2698
+#, no-c-format
+msgid "Allow speculative motion of non-loads."
+msgstr ""
+
+#: common.opt:2702
+#, no-c-format
+msgid "Allow speculative motion of some loads."
+msgstr ""
+
+#: common.opt:2706
+#, no-c-format
+msgid "Allow speculative motion of more loads."
+msgstr ""
+
+#: common.opt:2710
+#, no-c-format
+msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
+msgstr ""
+
+#: common.opt:2714
+#, no-c-format
+msgid "If scheduling post reload, do superblock scheduling."
+msgstr ""
+
+#: common.opt:2722
+#, no-c-format
+msgid "Reschedule instructions before register allocation."
+msgstr ""
+
+#: common.opt:2726
+#, no-c-format
+msgid "Reschedule instructions after register allocation."
+msgstr ""
+
+#: common.opt:2733
+#, no-c-format
+msgid "Schedule instructions using selective scheduling algorithm."
+msgstr ""
+
+#: common.opt:2737
+#, no-c-format
+msgid "Run selective scheduling after reload."
+msgstr ""
+
+#: common.opt:2741
+#, no-c-format
+msgid "Run self-tests, using the given path to locate test files."
+msgstr ""
+
+#: common.opt:2745
+#, no-c-format
+msgid "Perform software pipelining of inner loops during selective scheduling."
+msgstr ""
+
+#: common.opt:2749
+#, no-c-format
+msgid "Perform software pipelining of outer loops during selective scheduling."
+msgstr ""
+
+#: common.opt:2753
+#, no-c-format
+msgid "Reschedule pipelined regions without pipelining."
+msgstr ""
+
+#: common.opt:2757
+#, no-c-format
+msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
+msgstr ""
+
+#: common.opt:2763
+#, no-c-format
+msgid "Allow premature scheduling of queued insns."
+msgstr ""
+
+#: common.opt:2767
+#, no-c-format
+msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
+msgstr ""
+
+#: common.opt:2775
+#, no-c-format
+msgid "Set dependence distance checking in premature scheduling of queued insns."
+msgstr ""
+
+#: common.opt:2779
+#, no-c-format
+msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
+msgstr ""
+
+#: common.opt:2783
+#, no-c-format
+msgid "Enable the group heuristic in the scheduler."
+msgstr ""
+
+#: common.opt:2787
+#, no-c-format
+msgid "Enable the critical path heuristic in the scheduler."
+msgstr ""
+
+#: common.opt:2791
+#, no-c-format
+msgid "Enable the speculative instruction heuristic in the scheduler."
+msgstr ""
+
+#: common.opt:2795
+#, no-c-format
+msgid "Enable the rank heuristic in the scheduler."
+msgstr ""
+
+#: common.opt:2799
+#, no-c-format
+msgid "Enable the last instruction heuristic in the scheduler."
+msgstr ""
+
+#: common.opt:2803
+#, no-c-format
+msgid "Enable the dependent count heuristic in the scheduler."
+msgstr ""
+
+#: common.opt:2807
+#, no-c-format
+msgid "Access data in the same section from shared anchor points."
+msgstr ""
+
+#: common.opt:2819
+#, no-c-format
+msgid "Turn on Redundant Extensions Elimination pass."
+msgstr ""
+
+#: common.opt:2823
+#, no-c-format
+msgid "Show column numbers in diagnostics, when available.  Default on."
+msgstr ""
+
+#: common.opt:2827
+#, no-c-format
+msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
+msgstr ""
+
+#: common.opt:2832
+#, no-c-format
+msgid "Shrink-wrap parts of the prologue and epilogue separately."
+msgstr ""
+
+#: common.opt:2836
+#, no-c-format
+msgid "Disable optimizations observable by IEEE signaling NaNs."
+msgstr ""
+
+#: common.opt:2840
+#, no-c-format
+msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
+msgstr ""
+
+#: common.opt:2844
+#, no-c-format
+msgid "Convert floating point constants to single precision constants."
+msgstr ""
+
+#: common.opt:2848
+#, no-c-format
+msgid "Split lifetimes of induction variables when loops are unrolled."
+msgstr ""
+
+#: common.opt:2852
+#, no-c-format
+msgid "Generate discontiguous stack frames."
+msgstr ""
+
+#: common.opt:2856
+#, no-c-format
+msgid "Split wide types into independent registers."
+msgstr ""
+
+#: common.opt:2860
+#, no-c-format
+msgid "Split wide types into independent registers earlier."
+msgstr ""
+
+#: common.opt:2864
+#, no-c-format
+msgid "Enable backward propagation of use properties at the SSA level."
+msgstr ""
+
+#: common.opt:2868
+#, no-c-format
+msgid "Optimize conditional patterns using SSA PHI nodes."
+msgstr ""
+
+#: common.opt:2872
+#, no-c-format
+msgid "Optimize amount of stdarg registers saved to stack at start of function."
+msgstr ""
+
+#: common.opt:2876
+#, no-c-format
+msgid "Apply variable expansion when loops are unrolled."
+msgstr ""
+
+#: common.opt:2880
+#, no-c-format
+msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
+msgstr ""
+
+#: common.opt:2884
+#, no-c-format
+msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
+msgstr ""
+
+#: common.opt:2888
+#, no-c-format
+msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
+msgstr ""
+
+#: common.opt:2896
+#, no-c-format
+msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
+msgstr ""
+
+#: common.opt:2900
+#, no-c-format
+msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
+msgstr ""
+
+#: common.opt:2904
+#, no-c-format
+msgid "Use propolice as a stack protection method."
+msgstr ""
+
+#: common.opt:2908
+#, no-c-format
+msgid "Use a stack protection method for every function."
+msgstr ""
+
+#: common.opt:2912
+#, no-c-format
+msgid "Use a smart stack protection method for certain functions."
+msgstr ""
+
+#: common.opt:2916
+#, no-c-format
+msgid "Use stack protection method only for functions with the stack_protect attribute."
+msgstr ""
+
+#: common.opt:2920
+#, no-c-format
+msgid "Output stack usage information on a per-function basis."
+msgstr ""
+
+#: common.opt:2932
+#, no-c-format
+msgid "Assume strict aliasing rules apply."
+msgstr ""
+
+#: common.opt:2936
+#, no-c-format
+msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
+msgstr ""
+
+#: common.opt:2940
+#, no-c-format
+msgid "Disable stack scrub entirely, disregarding strub attributes."
+msgstr ""
+
+#: common.opt:2944
+#, no-c-format
+msgid "Enable stack scrub as per attributes, with strict call checking."
+msgstr ""
+
+#: common.opt:2953
+#, no-c-format
+msgid "Restore default strub mode: as per attributes, with relaxed checking."
+msgstr ""
+
+#: common.opt:2957
+#, no-c-format
+msgid "Enable stack scrubbing for all viable functions."
+msgstr ""
+
+#: common.opt:2961
+#, no-c-format
+msgid "Enable at-calls stack scrubbing for all viable functions."
+msgstr ""
+
+#: common.opt:2965
+#, no-c-format
+msgid "Enable internal stack scrubbing for all viable functions."
+msgstr ""
+
+#: common.opt:2969
+#, no-c-format
+msgid "Implement __atomic operations via libcalls to legacy __sync functions."
+msgstr ""
+
+#: common.opt:2973
+#, no-c-format
+msgid "Check for syntax errors, then stop."
+msgstr ""
+
+#: common.opt:2977
+#, no-c-format
+msgid "Create data files needed by \"gcov\"."
+msgstr ""
+
+#: common.opt:2981
+#, no-c-format
+msgid "Perform jump threading optimizations."
+msgstr ""
+
+#: common.opt:2985
+#, no-c-format
+msgid "Report the time taken by each compiler pass."
+msgstr ""
+
+#: common.opt:2989
+#, no-c-format
+msgid "Record times taken by sub-phases separately."
+msgstr ""
+
+#: common.opt:2993
+#, no-c-format
+msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
+msgstr ""
+
+#: common.opt:3012
+#, no-c-format
+msgid "Reorder top level functions, variables, and asms."
+msgstr ""
+
+#: common.opt:3016
+#, no-c-format
+msgid "Perform superblock formation via tail duplication."
+msgstr ""
+
+#: common.opt:3020
+#, no-c-format
+msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
+msgstr ""
+
+#: common.opt:3025
+#, no-c-format
+msgid "Whether trampolines are generated in executable memory rather than executable stack."
+msgstr ""
+
+#: common.opt:3043
+#, no-c-format
+msgid "Assume floating-point operations can trap."
+msgstr ""
+
+#: common.opt:3047
+#, no-c-format
+msgid "Trap for signed overflow in addition, subtraction and multiplication."
+msgstr ""
+
+#: common.opt:3051
+#, no-c-format
+msgid "Enable SSA-CCP optimization on trees."
+msgstr ""
+
+#: common.opt:3055
+#, no-c-format
+msgid "Enable SSA-BIT-CCP optimization on trees."
+msgstr ""
+
+#: common.opt:3063
+#, no-c-format
+msgid "Enable loop header copying on trees."
+msgstr ""
+
+#: common.opt:3071
+#, no-c-format
+msgid "Enable SSA coalescing of user variables."
+msgstr ""
+
+#: common.opt:3079
+#, no-c-format
+msgid "Enable copy propagation on trees."
+msgstr ""
+
+#: common.opt:3087
+#, no-c-format
+msgid "Transform condition stores into unconditional ones."
+msgstr ""
+
+#: common.opt:3091
+#, no-c-format
+msgid "Perform conversions of switch initializations."
+msgstr ""
+
+#: common.opt:3095
+#, no-c-format
+msgid "Enable SSA dead code elimination optimization on trees."
+msgstr ""
+
+#: common.opt:3099
+#, no-c-format
+msgid "Enable dominator optimizations."
+msgstr ""
+
+#: common.opt:3103
+#, no-c-format
+msgid "Enable tail merging on trees."
+msgstr ""
+
+#: common.opt:3107
+#, no-c-format
+msgid "Enable dead store elimination."
+msgstr ""
+
+#: common.opt:3111
+#, no-c-format
+msgid "Enable forward propagation on trees."
+msgstr ""
+
+#: common.opt:3115
+#, no-c-format
+msgid "Enable Full Redundancy Elimination (FRE) on trees."
+msgstr ""
+
+#: common.opt:3119
+#, no-c-format
+msgid "Enable string length optimizations on trees."
+msgstr ""
+
+#: common.opt:3123
+#, no-c-format
+msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgstr ""
+
+#: common.opt:3129
+#, no-c-format
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgstr ""
+
+#: common.opt:3136
+#, no-c-format
+msgid "Enable loop distribution on trees."
+msgstr ""
+
+#: common.opt:3140
+#, no-c-format
+msgid "Enable loop distribution for patterns transformed into a library call."
+msgstr ""
+
+#: common.opt:3144
+#, no-c-format
+msgid "Enable loop invariant motion on trees."
+msgstr ""
+
+#: common.opt:3152
+#, no-c-format
+msgid "Create canonical induction variables in loops."
+msgstr ""
+
+#: common.opt:3156
+#, no-c-format
+msgid "Enable loop optimizations on tree level."
+msgstr ""
+
+#: common.opt:3160
+#, no-c-format
+msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
+msgstr ""
+
+#: common.opt:3164
+#, no-c-format
+msgid "Enable hoisting loads from conditional pointers."
+msgstr ""
+
+#: common.opt:3168
+#, no-c-format
+msgid "Enable SSA-PRE optimization on trees."
+msgstr ""
+
+#: common.opt:3172
+#, no-c-format
+msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
+msgstr ""
+
+#: common.opt:3176
+#, no-c-format
+msgid "Perform function-local points-to analysis on trees."
+msgstr ""
+
+#: common.opt:3180
+#, no-c-format
+msgid "Enable reassociation on tree level."
+msgstr ""
+
+#: common.opt:3188
+#, no-c-format
+msgid "Enable SSA code sinking on trees."
+msgstr ""
+
+#: common.opt:3192
+#, no-c-format
+msgid "Perform straight-line strength reduction."
+msgstr ""
+
+#: common.opt:3196
+#, no-c-format
+msgid "Perform scalar replacement of aggregates."
+msgstr ""
+
+#: common.opt:3200
+#, no-c-format
+msgid "Replace temporary expressions in the SSA->normal pass."
+msgstr ""
+
+#: common.opt:3204
+#, no-c-format
+msgid "Perform live range splitting during the SSA->normal pass."
+msgstr ""
+
+#: common.opt:3208
+#, no-c-format
+msgid "Perform Value Range Propagation on trees."
+msgstr ""
+
+#: common.opt:3212
+#, no-c-format
+msgid "Split paths leading to loop backedges."
+msgstr ""
+
+#: common.opt:3216
+#, no-c-format
+msgid "Assume common declarations may be overridden with ones with a larger trailing array."
+msgstr ""
+
+#: common.opt:3221
+#, no-c-format
+msgid "Compile whole compilation unit at a time."
+msgstr ""
+
+#: common.opt:3225
+#, no-c-format
+msgid "Trap on __builtin_unreachable instead of using it for optimization."
+msgstr ""
+
+#: common.opt:3229
+#, no-c-format
+msgid "Perform loop unrolling when iteration count is known."
+msgstr ""
+
+#: common.opt:3233
+#, no-c-format
+msgid "Perform loop unrolling for all loops."
+msgstr ""
+
+#: common.opt:3248
+#, no-c-format
+msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
+msgstr ""
+
+#: common.opt:3253
+#, no-c-format
+msgid "Same as -fassociative-math for expressions which include division."
+msgstr ""
+
+#: common.opt:3261
+#, no-c-format
+msgid "Allow math optimizations that may violate IEEE or ISO standards."
+msgstr ""
+
+#: common.opt:3265
+#, no-c-format
+msgid "Perform loop unswitching."
+msgstr ""
+
+#: common.opt:3269
+#, no-c-format
+msgid "Perform loop splitting."
+msgstr ""
+
+#: common.opt:3273
+#, no-c-format
+msgid "Version loops based on whether indices have a stride of one."
+msgstr ""
+
+#: common.opt:3277
+#, no-c-format
+msgid "Just generate unwind tables for exception handling."
+msgstr ""
+
+#: common.opt:3281
+#, no-c-format
+msgid "Use the bfd linker instead of the default linker."
+msgstr ""
+
+#: common.opt:3285
+#, no-c-format
+msgid "Use the gold linker instead of the default linker."
+msgstr ""
+
+#: common.opt:3289
+#, no-c-format
+msgid "Use the lld LLVM linker instead of the default linker."
+msgstr ""
+
+#: common.opt:3293
+#, no-c-format
+msgid "Use the Modern linker (MOLD) linker instead of the default linker."
+msgstr ""
+
+#: common.opt:3303
+#, no-c-format
+msgid "Perform variable tracking."
+msgstr ""
+
+#: common.opt:3310
+#, no-c-format
+msgid "Perform variable tracking by annotating assignments."
+msgstr ""
+
+#: common.opt:3316
+#, no-c-format
+msgid "Toggle -fvar-tracking-assignments."
+msgstr ""
+
+#: common.opt:3323
+#, no-c-format
+msgid "Perform variable tracking and also tag variables that are uninitialized."
+msgstr ""
+
+#: common.opt:3328
+#, no-c-format
+msgid "Enable vectorization on trees."
+msgstr ""
+
+#: common.opt:3336
+#, no-c-format
+msgid "Enable loop vectorization on trees."
+msgstr ""
+
+#: common.opt:3340
+#, no-c-format
+msgid "Enable basic block vectorization (SLP) on trees."
+msgstr ""
+
+#: common.opt:3344
+#, no-c-format
+msgid "-fvect-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the cost model for vectorization."
+msgstr ""
+
+#: common.opt:3348
+#, no-c-format
+msgid "-fsimd-cost-model=[unlimited|dynamic|cheap|very-cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
+msgstr ""
+
+#: common.opt:3367
+#, no-c-format
+msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
+msgstr ""
+
+#: common.opt:3375
+#, no-c-format
+msgid "Enable copy propagation of scalar-evolution information."
+msgstr ""
+
+#: common.opt:3379
+#, no-c-format
+msgid "-ftrivial-auto-var-init=[uninitialized|pattern|zero]\tAdd initializations to automatic variables."
+msgstr ""
+
+#: common.opt:3401
+#, no-c-format
+msgid "Add extra commentary to assembler output."
+msgstr ""
+
+#: common.opt:3405
+#, no-c-format
+msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
+msgstr ""
+
+#: common.opt:3424
+#, no-c-format
+msgid "Validate vtable pointers before using them."
+msgstr ""
+
+#: common.opt:3440
+#, no-c-format
+msgid "Output vtable verification counters."
+msgstr ""
+
+#: common.opt:3444
+#, no-c-format
+msgid "Output vtable verification pointer sets information."
+msgstr ""
+
+#: common.opt:3448
+#, no-c-format
+msgid "Use expression value profiles in optimizations."
+msgstr ""
+
+#: common.opt:3452
+#, no-c-format
+msgid "Construct webs and split unrelated uses of single variable."
+msgstr ""
+
+#: common.opt:3456
+#, no-c-format
+msgid "Enable conditional dead code elimination for builtin calls."
+msgstr ""
+
+#: common.opt:3460
+#, no-c-format
+msgid "Perform whole program optimizations."
+msgstr ""
+
+#: common.opt:3464
+#, no-c-format
+msgid "Assume pointer overflow wraps around."
+msgstr ""
+
+#: common.opt:3468
+#, no-c-format
+msgid "Assume signed arithmetic overflow wraps around."
+msgstr ""
+
+#: common.opt:3472
+#, no-c-format
+msgid "Put zero initialized data in the bss section."
+msgstr ""
+
+#: common.opt:3476
+#, no-c-format
+msgid "Clear call-used registers upon function return."
+msgstr ""
+
+#: common.opt:3480
+#, no-c-format
+msgid "Generate debug information in default format."
+msgstr ""
+
+#: common.opt:3484
+#, no-c-format
+msgid "Assume assembler support for (DWARF2+) .loc directives."
+msgstr ""
+
+#: common.opt:3488
+#, no-c-format
+msgid "Assume assembler support for view in (DWARF2+) .loc directives."
+msgstr ""
+
+#: common.opt:3492
+#, no-c-format
+msgid "Generate debug information in CodeView format."
+msgstr ""
+
+#: common.opt:3512
+#, no-c-format
+msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
+msgstr ""
+
+#: common.opt:3518
+#, no-c-format
+msgid "Generate CTF debug information at default level."
+msgstr ""
+
+#: common.opt:3522
+#, no-c-format
+msgid "Generate BTF debug information at default level."
+msgstr ""
+
+#: common.opt:3526
+#, no-c-format
+msgid "Generate debug information in default version of DWARF format."
+msgstr ""
+
+#: common.opt:3530
+#, no-c-format
+msgid "Generate debug information in DWARF v2 (or later) format."
+msgstr ""
+
+#: common.opt:3534
+#, no-c-format
+msgid "Use 32-bit DWARF format when emitting DWARF debug information."
+msgstr ""
+
+#: common.opt:3538
+#, no-c-format
+msgid "Use 64-bit DWARF format when emitting DWARF debug information."
+msgstr ""
+
+#: common.opt:3542
+#, no-c-format
+msgid "Generate debug information in default extended format."
+msgstr ""
+
+#: common.opt:3546
+#, no-c-format
+msgid "Generate extended entry point information for inlined functions."
+msgstr ""
+
+#: common.opt:3550
+#, no-c-format
+msgid "Compute locview reset points based on insn length estimates."
+msgstr ""
+
+#: common.opt:3558
+#, no-c-format
+msgid "Don't generate DWARF pubnames and pubtypes sections."
+msgstr ""
+
+#: common.opt:3562
+#, no-c-format
+msgid "Generate DWARF pubnames and pubtypes sections."
+msgstr ""
+
+#: common.opt:3566
+#, no-c-format
+msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
+msgstr ""
+
+#: common.opt:3570
+#, no-c-format
+msgid "Record gcc command line switches in DWARF DW_AT_producer."
+msgstr ""
+
+#: common.opt:3574
+#, no-c-format
+msgid "Generate debug information in separate .dwo files."
+msgstr ""
+
+#: common.opt:3586
+#, no-c-format
+msgid "Emit progressive recommended breakpoint locations."
+msgstr ""
+
+#: common.opt:3590
+#, no-c-format
+msgid "Don't emit DWARF additions beyond selected version."
+msgstr ""
+
+#: common.opt:3594
+#, no-c-format
+msgid "Add description attributes to some DWARF DIEs that have no name attribute."
+msgstr ""
+
+#: common.opt:3598
+#, no-c-format
+msgid "Toggle debug information generation."
+msgstr ""
+
+#: common.opt:3602
+#, no-c-format
+msgid "Augment variable location lists with progressive views."
+msgstr ""
+
+#: common.opt:3609
+#, no-c-format
+msgid "Generate debug information in VMS format."
+msgstr ""
+
+#: common.opt:3638
+#, no-c-format
+msgid "Generate compressed debug sections."
+msgstr ""
+
+#: common.opt:3642
+#, no-c-format
+msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
+msgstr ""
+
+#: common.opt:3649
+#, no-c-format
+msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
+msgstr ""
+
+#: common.opt:3653
+#, no-c-format
+msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
+msgstr ""
+
+#: common.opt:3681
+#, no-c-format
+msgid "-o <file>\tPlace output into <file>."
+msgstr ""
+
+#: common.opt:3685
+#, no-c-format
+msgid "Enable function profiling."
+msgstr ""
+
+#: common.opt:3695
+#, no-c-format
+msgid "Like -pedantic but issue them as errors."
+msgstr ""
+
+#: common.opt:3735
+#, no-c-format
+msgid "Do not display functions compiled or elapsed time."
+msgstr ""
+
+#: common.opt:3767
+#, no-c-format
+msgid "Enable verbose output."
+msgstr ""
+
+#: common.opt:3771
+#, no-c-format
+msgid "Display the compiler's version."
+msgstr ""
+
+#: common.opt:3775
+#, no-c-format
+msgid "Suppress warnings."
+msgstr ""
+
+#: common.opt:3785
+#, no-c-format
+msgid "Create a shared library."
+msgstr ""
+
+#: common.opt:3845
+#, no-c-format
+msgid "Don't create a dynamically linked position independent executable."
+msgstr ""
+
+#: common.opt:3849
+#, no-c-format
+msgid "Create a dynamically linked position independent executable."
+msgstr ""
+
+#: common.opt:3853
+#, no-c-format
+msgid "Create a static position independent executable."
+msgstr ""
+
+#: common.opt:3860
+#, no-c-format
+msgid "Use caller save register across calls if possible."
+msgstr ""
+
+#: params.opt:27
+#, no-c-format
+msgid "Loops iterating at least selected number of iterations will get loop alignment."
+msgstr ""
+
+#: params.opt:31
+#, no-c-format
+msgid "Select fraction of the maximal frequency of executions of basic block in function given basic block get alignment."
+msgstr ""
+
+#: params.opt:35
+#, no-c-format
+msgid "Enable asan globals protection."
+msgstr ""
+
+#: params.opt:39
+#, no-c-format
+msgid "Enable asan allocas/VLAs protection."
+msgstr ""
+
+#: params.opt:43
+#, no-c-format
+msgid "Enable asan load operations protection."
+msgstr ""
+
+#: params.opt:47
+#, no-c-format
+msgid "Enable asan store operations protection."
+msgstr ""
+
+#: params.opt:51
+#, no-c-format
+msgid "Use callbacks instead of inline code if number of accesses in function becomes greater or equal to this number."
+msgstr ""
+
+#: params.opt:55
+#, no-c-format
+msgid "Prefix calls to memcpy, memset and memmove with __asan_ or __hwasan_ for -fsanitize=kernel-address or -fsanitize=kernel-hwaddress."
+msgstr ""
+
+#: params.opt:59
+#, no-c-format
+msgid "Enable asan builtin functions protection."
+msgstr ""
+
+#: params.opt:63
+#, no-c-format
+msgid "Enable asan stack protection."
+msgstr ""
+
+#: params.opt:67
+#, no-c-format
+msgid "Enable asan detection of use-after-return bugs."
+msgstr ""
+
+#: params.opt:71
+#, no-c-format
+msgid "Enable hwasan instrumentation of statically sized stack-allocated variables."
+msgstr ""
+
+#: params.opt:75
+#, no-c-format
+msgid "Use random base tag for each frame, as opposed to base always zero."
+msgstr ""
+
+#: params.opt:79
+#, no-c-format
+msgid "Enable hwasan instrumentation of allocas/VLAs."
+msgstr ""
+
+#: params.opt:83
+#, no-c-format
+msgid "Enable hwasan instrumentation of load operations."
+msgstr ""
+
+#: params.opt:87
+#, no-c-format
+msgid "Enable hwasan instrumentation of store operations."
+msgstr ""
+
+#: params.opt:91
+#, no-c-format
+msgid "Enable hwasan instrumentation of builtin functions."
+msgstr ""
+
+#: params.opt:95
+#, no-c-format
+msgid "Average number of iterations of a loop."
+msgstr ""
+
+#: params.opt:99
+#, no-c-format
+msgid "Maximum number of bits for which we avoid creating FMAs."
+msgstr ""
+
+#: params.opt:103
+#, no-c-format
+msgid "Set the estimated probability in percentage for builtin expect. The default value is 90% probability."
+msgstr ""
+
+#: params.opt:107
+#, no-c-format
+msgid "The maximum length of a constant string for a builtin string cmp call eligible for inlining. The default value is 3."
+msgstr ""
+
+#: params.opt:111
+#, no-c-format
+msgid "The smallest number of different values for which it is best to use a jump-table instead of a tree of conditional branches, if 0, use the default for the machine."
+msgstr ""
+
+#: params.opt:115
+#, no-c-format
+msgid "Probability that COMDAT function will be shared with different compilation unit."
+msgstr ""
+
+#: params.opt:119
+#, no-c-format
+msgid "Maximum number of namespaces to search for alternatives when name lookup fails."
+msgstr ""
+
+#: params.opt:123
+#, no-c-format
+msgid "Maximum number of queries into the alias oracle per store."
+msgstr ""
+
+#: params.opt:127
+#, no-c-format
+msgid "Maximum size (in bytes) of objects tracked bytewise by dead store elimination."
+msgstr ""
+
+#: params.opt:131
+#, no-c-format
+msgid "Maximal estimated growth of function body caused by early inlining of single call."
+msgstr ""
+
+#: params.opt:135
+#, no-c-format
+msgid "Scale factor to apply to the number of statements in a threading path crossing a loop backedge when comparing to max-jump-thread-duplication-stmts."
+msgstr ""
+
+#: params.opt:139
+#, no-c-format
+msgid "Whether the target fully pipelines FMA instructions.  If non-zero, reassociation considers the benefit of parallelizing FMA's multiplication part and addition part, assuming FMUL and FMA use the same units that can also do FADD."
+msgstr ""
+
+#: params.opt:146
+#, no-c-format
+msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
+msgstr ""
+
+#: params.opt:150
+#, no-c-format
+msgid "The threshold ratio for performing partial redundancy elimination after reload."
+msgstr ""
+
+#: params.opt:154
+#, no-c-format
+msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
+msgstr ""
+
+#: params.opt:158
+#, no-c-format
+msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
+msgstr ""
+
+#: params.opt:162
+#, no-c-format
+msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
+msgstr ""
+
+#: params.opt:166
+#, no-c-format
+msgid "Minimum heap size before we start collecting garbage, in kilobytes."
+msgstr ""
+
+#: params.opt:170
+#, no-c-format
+msgid "The number of executions of a basic block which is considered hot. The parameter is used only in GIMPLE FE."
+msgstr ""
+
+#: params.opt:174
+#, no-c-format
+msgid "Whether codegen errors should be ICEs when -fchecking."
+msgstr ""
+
+#: params.opt:178
+#, no-c-format
+msgid "Maximum number of arrays per SCoP."
+msgstr ""
+
+#: params.opt:182
+#, no-c-format
+msgid "Maximum number of parameters in a SCoP."
+msgstr ""
+
+#: params.opt:186
+#, no-c-format
+msgid "Maximum number of blocks for -fharden-control-flow-redundancy."
+msgstr ""
+
+#: params.opt:190
+#, no-c-format
+msgid "Maximum number of blocks for in-line -fharden-control-flow-redundancy."
+msgstr ""
+
+#: params.opt:194
+#, no-c-format
+msgid "The number of elements for which hash table verification is done for each searched element."
+msgstr ""
+
+#: params.opt:198
+#, no-c-format
+msgid "The denominator n of fraction 1/n of the maximal execution count of a basic block in the entire program that a basic block needs to at least have in order to be considered hot (used in non-LTO mode)."
+msgstr ""
+
+#: params.opt:202
+#, no-c-format
+msgid "The number of most executed permilles of the profiled execution of the entire program to which the execution count of a basic block must be part of in order to be considered hot (used in LTO mode)."
+msgstr ""
+
+#: params.opt:206
+#, no-c-format
+msgid "The denominator n of fraction 1/n of the execution frequency of the entry block of a function that a basic block of this function needs to at least have in order to be considered hot."
+msgstr ""
+
+#: params.opt:210
+#, no-c-format
+msgid "The scale (in percents) applied to inline-insns-single and auto limits when heuristics hints that inlining is very profitable."
+msgstr ""
+
+#: params.opt:214
+#, no-c-format
+msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
+msgstr ""
+
+#: params.opt:218
+#, no-c-format
+msgid "How much can given compilation unit grow because of the inlining (in percent)."
+msgstr ""
+
+#: params.opt:222
+#, no-c-format
+msgid "The upper bound for sharing integer constants."
+msgstr ""
+
+#: params.opt:226
+#, no-c-format
+msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
+msgstr ""
+
+#: params.opt:230
+#, no-c-format
+msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known."
+msgstr ""
+
+#: params.opt:234
+#, no-c-format
+msgid "Maximum depth of recursive cloning for self-recursive function."
+msgstr ""
+
+#: params.opt:238
+#, no-c-format
+msgid "Recursive cloning only when the probability of call being executed exceeds the parameter."
+msgstr ""
+
+#: params.opt:242
+#, no-c-format
+msgid "When propagating IPA-CP effect estimates, multiply frequencies of recursive edges that bring back an unchanged value by this factor."
+msgstr ""
+
+#: params.opt:246
+#, no-c-format
+msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning."
+msgstr ""
+
+#: params.opt:250
+#, no-c-format
+msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning."
+msgstr ""
+
+#: params.opt:254
+#, no-c-format
+msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
+msgstr ""
+
+#: params.opt:258
+#, no-c-format
+msgid "The size of translation unit that IPA-CP pass considers large."
+msgstr ""
+
+#: params.opt:262
+#, no-c-format
+msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
+msgstr ""
+
+#: params.opt:266
+#, no-c-format
+msgid "When using profile feedback, use the edge at this percentage position in frequency histogram as the bases for IPA-CP heuristics."
+msgstr ""
+
+#: params.opt:270
+#, no-c-format
+msgid "Maximum number of statements visited during jump function offset discovery."
+msgstr ""
+
+#: params.opt:274
+#, no-c-format
+msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
+msgstr ""
+
+#: params.opt:278
+#, no-c-format
+msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
+msgstr ""
+
+#: params.opt:282
+#, no-c-format
+msgid "Maximum number of operations in a parameter expression that can be handled by IPA analysis."
+msgstr ""
+
+#: params.opt:286
+#, no-c-format
+msgid "Maximum number of different predicates used to track properties of loops in IPA analysis."
+msgstr ""
+
+#: params.opt:290
+#, no-c-format
+msgid "Maximal number of boundary endpoints of case ranges of switch statement used during IPA function summary generation."
+msgstr ""
+
+#: params.opt:294
+#, no-c-format
+msgid "Minimum probability (in percent) of dereferencing of a function pointer parameter for it to be considered for replacement with simple values."
+msgstr ""
+
+#: params.opt:298
+#, no-c-format
+msgid "Maximum pieces that IPA-SRA tracks per formal parameter, as a consequence, also the maximum number of replacements of a formal parameter."
+msgstr ""
+
+#: params.opt:302
+#, no-c-format
+msgid "Maximum allowed growth of total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
+msgstr ""
+
+#: params.opt:306
+#, no-c-format
+msgid "Additional maximum allowed growth of total size of new parameters that ipa-sra replaces a pointer to an aggregate with, if it points to a local variable that the caller only writes to and passes it as an argument to functions."
+msgstr ""
+
+#: params.opt:310
+#, no-c-format
+msgid "The number of registers in each class kept unused by loop invariant motion."
+msgstr ""
+
+#: params.opt:314
+#, no-c-format
+msgid "Max size of conflict table in MB."
+msgstr ""
+
+#: params.opt:318
+#, no-c-format
+msgid "Approximate function insn number in 1K units triggering simple local RA."
+msgstr ""
+
+#: params.opt:322
+#, no-c-format
+msgid "Max loops number for regional RA."
+msgstr ""
+
+#: params.opt:326
+#, no-c-format
+msgid "Control ira to consider matching constraint (duplicated operand number) heavily in all available alternatives for preferred register class.  If it is set as zero, it means ira only respects the matching constraint when it's in the only available alternative with an appropriate register class.  Otherwise, it means ira will check all available alternatives for preferred register class even if it has found some choice with an appropriate register class and respect the found qualified matching constraint."
+msgstr ""
+
+#: params.opt:330
+#, no-c-format
+msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
+msgstr ""
+
+#: params.opt:334
+#, no-c-format
+msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
+msgstr ""
+
+#: params.opt:338
+#, no-c-format
+msgid "Bound on number of iv uses in loop optimized in iv optimizations."
+msgstr ""
+
+#: params.opt:342
+#, no-c-format
+msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for size."
+msgstr ""
+
+#: params.opt:346
+#, no-c-format
+msgid "The maximum code size growth ratio when expanding into a jump table (in percent).  The parameter is used when optimizing for speed."
+msgstr ""
+
+#: params.opt:350
+#, no-c-format
+msgid "The size of L1 cache line."
+msgstr ""
+
+#: params.opt:354
+#, no-c-format
+msgid "The minimum recommended offset between two concurrently-accessed objects to avoid additional performance degradation due to contention introduced by the implementation.  Typically the L1 cache line size, but can be larger to accommodate a variety of target processors with different cache line sizes. C++17 code might use this value in structure layout, but is strongly discouraged from doing so in public ABIs."
+msgstr ""
+
+#: params.opt:363
+#, no-c-format
+msgid "The maximum recommended size of contiguous memory occupied by two objects accessed with temporal locality by concurrent threads.  Typically the L1 cache line size, but can be smaller to accommodate a variety of target processors with different cache line sizes."
+msgstr ""
+
+#: params.opt:370
+#, no-c-format
+msgid "The size of L1 cache."
+msgstr ""
+
+#: params.opt:374
+#, no-c-format
+msgid "The size of L2 cache."
+msgstr ""
+
+#: params.opt:378
+#, no-c-format
+msgid "Maximal growth due to inlining of large function (in percent)."
+msgstr ""
+
+#: params.opt:382
+#, no-c-format
+msgid "The size of function body to be considered large."
+msgstr ""
+
+#: params.opt:386
+#, no-c-format
+msgid "The size of stack frame to be considered large."
+msgstr ""
+
+#: params.opt:390
+#, no-c-format
+msgid "Maximal stack frame growth due to inlining (in percent)."
+msgstr ""
+
+#: params.opt:394
+#, no-c-format
+msgid "The size of translation unit to be considered large."
+msgstr ""
+
+#: params.opt:398
+#, no-c-format
+msgid "Maximum number of concurrently open C++ module files when lazy loading."
+msgstr ""
+
+#: params.opt:402
+#, no-c-format
+msgid "The minimum cost of an expensive expression in the loop invariant motion."
+msgstr ""
+
+#: params.opt:406
+#, no-c-format
+msgid "True if a non-short-circuit operation is optimal."
+msgstr ""
+
+#: params.opt:410
+#, no-c-format
+msgid "Size of tiles for loop blocking."
+msgstr ""
+
+#: params.opt:414
+#, no-c-format
+msgid "The maximum number of stmts in loop nest for loop interchange."
+msgstr ""
+
+#: params.opt:418
+#, no-c-format
+msgid "The minimum stride ratio for loop interchange to be profitable."
+msgstr ""
+
+#: params.opt:422
+#, no-c-format
+msgid "Max basic blocks number in loop for loop invariant motion."
+msgstr ""
+
+#: params.opt:426
+#, no-c-format
+msgid "Maximum number of datarefs in loop for building loop data dependencies."
+msgstr ""
+
+#: params.opt:430
+#, no-c-format
+msgid "The maximum number of instructions in an inner loop that is being considered for versioning."
+msgstr ""
+
+#: params.opt:434
+#, no-c-format
+msgid "The maximum number of instructions in an outer loop that is being considered for versioning, on top of the instructions in inner loops."
+msgstr ""
+
+#: params.opt:438
+#, no-c-format
+msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
+msgstr ""
+
+#: params.opt:442
+#, no-c-format
+msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
+msgstr ""
+
+#: params.opt:446
+#, no-c-format
+msgid "Maximal size of a partition for LTO (in estimated instructions)."
+msgstr ""
+
+#: params.opt:450
+#, no-c-format
+msgid "maximal number of LTO partitions streamed in parallel."
+msgstr ""
+
+#: params.opt:454
+#, no-c-format
+msgid "Minimal size of a partition for LTO (in estimated instructions)."
+msgstr ""
+
+#: params.opt:458
+#, no-c-format
+msgid "Number of partitions the program should be split to."
+msgstr ""
+
+#: params.opt:462
+#, no-c-format
+msgid "The maximum number of instructions to consider to unroll in a loop on average."
+msgstr ""
+
+#: params.opt:466
+#, no-c-format
+msgid "The maximum number of insns combine tries to combine."
+msgstr ""
+
+#: params.opt:470
+#, no-c-format
+msgid "The maximum depth of a loop nest we completely peel."
+msgstr ""
+
+#: params.opt:474
+#, no-c-format
+msgid "The maximum number of peelings of a single loop that is peeled completely."
+msgstr ""
+
+#: params.opt:478
+#, no-c-format
+msgid "The maximum number of insns of a completely peeled loop."
+msgstr ""
+
+#: params.opt:482
+#, no-c-format
+msgid "The maximum number of incoming edges to consider for crossjumping."
+msgstr ""
+
+#: params.opt:486
+#, no-c-format
+msgid "The maximum instructions CSE process before flushing."
+msgstr ""
+
+#: params.opt:490
+#, no-c-format
+msgid "The maximum length of path considered in cse."
+msgstr ""
+
+#: params.opt:494
+#, no-c-format
+msgid "The maximum memory locations recorded by cselib."
+msgstr ""
+
+#: params.opt:498
+#, no-c-format
+msgid "Max. count of debug markers to expand or inline."
+msgstr ""
+
+#: params.opt:502
+#, no-c-format
+msgid "The maximum number of instructions to consider to fill a delay slot."
+msgstr ""
+
+#: params.opt:506
+#, no-c-format
+msgid "The maximum number of instructions to consider to find accurate live register information."
+msgstr ""
+
+#: params.opt:510
+#, no-c-format
+msgid "Maximum number of active local stores in RTL dead store elimination."
+msgstr ""
+
+#: params.opt:514
+#, no-c-format
+msgid "The maximum number of nested indirect inlining performed by early inliner."
+msgstr ""
+
+#: params.opt:518
+#, no-c-format
+msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
+msgstr ""
+
+#: params.opt:522
+#, no-c-format
+msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
+msgstr ""
+
+#: params.opt:526
+#, no-c-format
+msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
+msgstr ""
+
+#: params.opt:530
+#, no-c-format
+msgid "The maximum amount of memory to be allocated by GCSE, in kilobytes."
+msgstr ""
+
+#: params.opt:534
+#, no-c-format
+msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
+msgstr ""
+
+#: params.opt:538
+#, no-c-format
+msgid "The maximum expansion factor when copying basic blocks."
+msgstr ""
+
+#: params.opt:542
+#, no-c-format
+msgid "Maximum depth of search in the dominator tree for expressions to hoist."
+msgstr ""
+
+#: params.opt:546
+#, no-c-format
+msgid "Maximum loop depth of a call which is considered for inlining functions called once."
+msgstr ""
+
+#: params.opt:550
+#, no-c-format
+msgid "Maximum combined size of caller and callee which is inlined if callee is called once."
+msgstr ""
+
+#: params.opt:554
+#, no-c-format
+msgid "The maximum number of instructions when automatically inlining."
+msgstr ""
+
+#: params.opt:558
+#, no-c-format
+msgid "The maximum number of instructions inline function can grow to via recursive inlining."
+msgstr ""
+
+#: params.opt:562
+#, no-c-format
+msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
+msgstr ""
+
+#: params.opt:566
+#, no-c-format
+msgid "The maximum number of instructions in a single function eligible for inlining."
+msgstr ""
+
+#: params.opt:570
+#, no-c-format
+msgid "The maximum number of instructions when inlining for size."
+msgstr ""
+
+#: params.opt:574
+#, no-c-format
+msgid "The maximum number of instructions when automatically inlining small functions."
+msgstr ""
+
+#: params.opt:578
+#, no-c-format
+msgid "The maximum depth of recursive inlining for inline functions."
+msgstr ""
+
+#: params.opt:582
+#, no-c-format
+msgid "The maximum depth of recursive inlining for non-inline functions."
+msgstr ""
+
+#: params.opt:586
+#, no-c-format
+msgid "Maximum number of isl operations, 0 means unlimited."
+msgstr ""
+
+#: params.opt:590
+#, no-c-format
+msgid "Bound on the cost of an expression to compute the number of iterations."
+msgstr ""
+
+#: params.opt:594
+#, no-c-format
+msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
+msgstr ""
+
+#: params.opt:598
+#, no-c-format
+msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
+msgstr ""
+
+#: params.opt:602
+#, no-c-format
+msgid "Search space limit for the backwards jump threader."
+msgstr ""
+
+#: params.opt:606
+#, no-c-format
+msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
+msgstr ""
+
+#: params.opt:610
+#, no-c-format
+msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
+msgstr ""
+
+#: params.opt:614
+#, no-c-format
+msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
+msgstr ""
+
+#: params.opt:618
+#, no-c-format
+msgid "Minimum page size for warning purposes."
+msgstr ""
+
+#: params.opt:622
+#, no-c-format
+msgid "Maximum length of partial antic set when performing tree pre optimization."
+msgstr ""
+
+#: params.opt:626
+#, no-c-format
+msgid "The maximum number of branches on the path through the peeled sequence."
+msgstr ""
+
+#: params.opt:630
+#, no-c-format
+msgid "The maximum number of peelings of a single loop."
+msgstr ""
+
+#: params.opt:634
+#, no-c-format
+msgid "The maximum number of insns of a peeled loop."
+msgstr ""
+
+#: params.opt:638
+#, no-c-format
+msgid "The maximum length of scheduling's pending operations list."
+msgstr ""
+
+#: params.opt:642 params.opt:686
+#, no-c-format
+msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
+msgstr ""
+
+#: params.opt:646 params.opt:690
+#, no-c-format
+msgid "The maximum number of insns in a region to be considered for interblock scheduling."
+msgstr ""
+
+#: params.opt:650
+#, no-c-format
+msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
+msgstr ""
+
+#: params.opt:654
+#, no-c-format
+msgid "The maximum number of loop iterations we predict statically."
+msgstr ""
+
+#: params.opt:658
+#, no-c-format
+msgid "The maximum number of instructions to search backward when looking for equivalent reload."
+msgstr ""
+
+#: params.opt:662
+#, no-c-format
+msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
+msgstr ""
+
+#: params.opt:666
+#, no-c-format
+msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
+msgstr ""
+
+#: params.opt:670
+#, no-c-format
+msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
+msgstr ""
+
+#: params.opt:674
+#, no-c-format
+msgid "The maximum number of iterations through CFG to extend regions."
+msgstr ""
+
+#: params.opt:678
+#, no-c-format
+msgid "The maximum conflict delay for an insn to be considered for speculative motion."
+msgstr ""
+
+#: params.opt:682
+#, no-c-format
+msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
+msgstr ""
+
+#: params.opt:694
+#, no-c-format
+msgid "Maximum length of candidate scans for straight-line strength reduction."
+msgstr ""
+
+#: params.opt:698
+#, no-c-format
+msgid "Maximum number of may-defs visited when devirtualizing speculatively."
+msgstr ""
+
+#: params.opt:702
+#, no-c-format
+msgid "Maximum recursion depth allowed when querying a property of an SSA name."
+msgstr ""
+
+#: params.opt:706
+#, no-c-format
+msgid "Maximum number of constant stores to merge in the store merging pass."
+msgstr ""
+
+#: params.opt:710
+#, no-c-format
+msgid "Maximum number of conditional store pairs that can be sunk."
+msgstr ""
+
+#: params.opt:714 params.opt:718
+#, no-c-format
+msgid "Maximum number of store chains to track at the same time in the store merging pass."
+msgstr ""
+
+#: params.opt:722
+#, no-c-format
+msgid "Maximum amount of similar bbs to compare a bb with."
+msgstr ""
+
+#: params.opt:726
+#, no-c-format
+msgid "Maximum amount of iterations of the pass over a function."
+msgstr ""
+
+#: params.opt:730
+#, no-c-format
+msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
+msgstr ""
+
+#: params.opt:734
+#, no-c-format
+msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
+msgstr ""
+
+#: params.opt:738
+#, no-c-format
+msgid "The maximum number of unrollings of a single loop."
+msgstr ""
+
+#: params.opt:742
+#, no-c-format
+msgid "The maximum number of instructions to consider to unroll in a loop."
+msgstr ""
+
+#: params.opt:746
+#, no-c-format
+msgid "The maximum number of insns of an unswitched loop."
+msgstr ""
+
+#: params.opt:750
+#, no-c-format
+msgid "The maximum depth of a loop nest to be unswitched."
+msgstr ""
+
+#: params.opt:754
+#, no-c-format
+msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
+msgstr ""
+
+#: params.opt:758
+#, no-c-format
+msgid "Max. recursion depth for expanding var tracking expressions."
+msgstr ""
+
+#: params.opt:762
+#, no-c-format
+msgid "Max. size of loc list for which reverse ops should be added."
+msgstr ""
+
+#: params.opt:766
+#, no-c-format
+msgid "Max. size of var tracking hash tables."
+msgstr ""
+
+#: params.opt:770
+#, no-c-format
+msgid "Maximum number of VALUEs handled during a single find_base_term call."
+msgstr ""
+
+#: params.opt:774
+#, no-c-format
+msgid "The minimum number of matching instructions to consider for crossjumping."
+msgstr ""
+
+#: params.opt:778
+#, no-c-format
+msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
+msgstr ""
+
+#: params.opt:782
+#, no-c-format
+msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
+msgstr ""
+
+#: params.opt:786
+#, no-c-format
+msgid "The minimum threshold for probability of semi-invariant condition statement to trigger loop split."
+msgstr ""
+
+#: params.opt:790
+#, no-c-format
+msgid "The minimum UID to be used for a nondebug insn."
+msgstr ""
+
+#: params.opt:794
+#, no-c-format
+msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
+msgstr ""
+
+#: params.opt:798
+#, no-c-format
+msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
+msgstr ""
+
+#: params.opt:802
+#, no-c-format
+msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
+msgstr ""
+
+#: params.opt:806
+#, no-c-format
+msgid "--param=openacc-kernels=[decompose|parloops]\tSpecify mode of OpenACC 'kernels' constructs handling."
+msgstr ""
+
+#: params.opt:819
+#, no-c-format
+msgid "--param=openacc-privatization=[quiet|noisy]\tSpecify mode of OpenACC privatization diagnostics."
+msgstr ""
+
+#: params.opt:832
+#, no-c-format
+msgid "Chunk size of omp schedule for loops parallelized by parloops."
+msgstr ""
+
+#: params.opt:836
+#, no-c-format
+msgid "Minimum number of iterations per thread of an innermost parallelized loop."
+msgstr ""
+
+#: params.opt:840
+#, no-c-format
+msgid "--param=parloops-schedule=[static|dynamic|guided|auto|runtime]\tSchedule type of omp schedule for loops parallelized by parloops."
+msgstr ""
+
+#: params.opt:862
+#, no-c-format
+msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
+msgstr ""
+
+#: params.opt:866
+#, no-c-format
+msgid "Maximal estimated outcome of branch considered predictable."
+msgstr ""
+
+#: params.opt:870
+#, no-c-format
+msgid "Whether software prefetch hints should be issued for non-constant strides."
+msgstr ""
+
+#: params.opt:874
+#, no-c-format
+msgid "The number of insns executed before prefetch is completed."
+msgstr ""
+
+#: params.opt:878
+#, no-c-format
+msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
+msgstr ""
+
+#: params.opt:882
+#, no-c-format
+msgid "The minimum constant stride beyond which we should use prefetch hints for."
+msgstr ""
+
+#: params.opt:886
+#, no-c-format
+msgid "Use internal function id in profile lookup."
+msgstr ""
+
+#: params.opt:890
+#, no-c-format
+msgid "--param=ranger-debug=[none|trace|gori|cache|tracegori|all] Specifies the output mode for debugging ranger."
+msgstr ""
+
+#: params.opt:915
+#, no-c-format
+msgid "Maximum depth of logical expression evaluation ranger will look through when evaluating outgoing edge ranges."
+msgstr ""
+
+#: params.opt:920
+#, no-c-format
+msgid "Maximum depth of instruction chains to consider for recomputation in the outgoing range calculator."
+msgstr ""
+
+#: params.opt:925
+#, no-c-format
+msgid "Maximum number of relations the oracle will register in a basic block."
+msgstr ""
+
+#: params.opt:929
+#, no-c-format
+msgid "Maximum depth of a loop nest to fully value-number optimistically."
+msgstr ""
+
+#: params.opt:933
+#, no-c-format
+msgid "Maximum number of disambiguations to perform per memory access."
+msgstr ""
+
+#: params.opt:937
+#, no-c-format
+msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
+msgstr ""
+
+#: params.opt:941
+#, no-c-format
+msgid "Bound on size of expressions used in the scalar evolutions analyzer."
+msgstr ""
+
+#: params.opt:945
+#, no-c-format
+msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into, at '0' only enable instruction sorting heuristic.  Disabled by default."
+msgstr ""
+
+#: params.opt:949
+#, no-c-format
+msgid "Minimal distance between possibly conflicting store and load."
+msgstr ""
+
+#: params.opt:953
+#, no-c-format
+msgid "Which -fsched-pressure algorithm to apply."
+msgstr ""
+
+#: params.opt:957
+#, no-c-format
+msgid "The minimal probability of speculation success (in percents), so that speculative insn will be scheduled."
+msgstr ""
+
+#: params.opt:961
+#, no-c-format
+msgid "The minimum probability an edge must have for the scheduler to save its state across it."
+msgstr ""
+
+#: params.opt:965
+#, no-c-format
+msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
+msgstr ""
+
+#: params.opt:969
+#, no-c-format
+msgid "The maximum size of the lookahead window of selective scheduling."
+msgstr ""
+
+#: params.opt:973
+#, no-c-format
+msgid "Maximum number of times that an insn could be scheduled."
+msgstr ""
+
+#: params.opt:977
+#, no-c-format
+msgid "The number of prefetches that can run at the same time."
+msgstr ""
+
+#: params.opt:981
+#, no-c-format
+msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
+msgstr ""
+
+#: params.opt:985
+#, no-c-format
+msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
+msgstr ""
+
+#: params.opt:989
+#, no-c-format
+msgid "A threshold on the average loop count considered by the swing modulo scheduler."
+msgstr ""
+
+#: params.opt:993
+#, no-c-format
+msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
+msgstr ""
+
+#: params.opt:997
+#, no-c-format
+msgid "The minimum value of stage count that swing modulo scheduler will generate."
+msgstr ""
+
+#: params.opt:1001
+#, no-c-format
+msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
+msgstr ""
+
+#: params.opt:1005
+#, no-c-format
+msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
+msgstr ""
+
+#: params.opt:1009
+#, no-c-format
+msgid "Maximum number of artificial accesses to enable forward propagation that Scalar Replacement of Aggregates will keep for one local variable."
+msgstr ""
+
+#: params.opt:1013
+#, no-c-format
+msgid "The maximum number of SSA_NAME assignments to follow in determining a value."
+msgstr ""
+
+#: params.opt:1017
+#, no-c-format
+msgid "The lower bound for a buffer to be considered for stack smashing protection."
+msgstr ""
+
+#: params.opt:1021
+#, no-c-format
+msgid "Size of the stack guard expressed as a power of two in bytes."
+msgstr ""
+
+#: params.opt:1025
+#, no-c-format
+msgid "Interval in which to probe the stack expressed as a power of two in bytes."
+msgstr ""
+
+#: params.opt:1029
+#, no-c-format
+msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
+msgstr ""
+
+#: params.opt:1033
+#, no-c-format
+msgid "Maximum size of a single store merging region in bytes."
+msgstr ""
+
+#: params.opt:1037
+#, no-c-format
+msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
+msgstr ""
+
+#: params.opt:1041
+#, no-c-format
+msgid "Maximum number of bases stored in each modref tree."
+msgstr ""
+
+#: params.opt:1045
+#, no-c-format
+msgid "Maximum number of references stored in each modref base."
+msgstr ""
+
+#: params.opt:1049
+#, no-c-format
+msgid "Maximum number of accesses stored in each modref reference."
+msgstr ""
+
+#: params.opt:1053
+#, no-c-format
+msgid "Maximum number of tests performed by modref query."
+msgstr ""
+
+#: params.opt:1057
+#, no-c-format
+msgid "Maximum depth of DFS walk used by modref escape analysis."
+msgstr ""
+
+#: params.opt:1061
+#, no-c-format
+msgid "Maximum number of escape points tracked by modref per SSA-name."
+msgstr ""
+
+#: params.opt:1065
+#, no-c-format
+msgid "Maximum number of times a given range is adjusted during the dataflow."
+msgstr ""
+
+#: params.opt:1069
+#, no-c-format
+msgid "--param=threader-debug=[none|all] Enables verbose dumping of the threader solver."
+msgstr ""
+
+#: params.opt:1082
+#, no-c-format
+msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
+msgstr ""
+
+#: params.opt:1086
+#, no-c-format
+msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
+msgstr ""
+
+#: params.opt:1090
+#, no-c-format
+msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
+msgstr ""
+
+#: params.opt:1094
+#, no-c-format
+msgid "Maximal code growth caused by tail duplication (in percent)."
+msgstr ""
+
+#: params.opt:1098
+#, no-c-format
+msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
+msgstr ""
+
+#: params.opt:1102
+#, no-c-format
+msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
+msgstr ""
+
+#: params.opt:1106
+#, no-c-format
+msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
+msgstr ""
+
+#: params.opt:1110
+#, no-c-format
+msgid "Set the maximum number of instructions executed in parallel in reassociated tree.  If 0, use the target dependent heuristic."
+msgstr ""
+
+#: params.opt:1114
+#, no-c-format
+msgid "Emit special instrumentation for accesses to volatiles."
+msgstr ""
+
+#: params.opt:1118
+#, no-c-format
+msgid "Emit instrumentation calls to __tsan_func_entry() and __tsan_func_exit()."
+msgstr ""
+
+#: params.opt:1122
+#, no-c-format
+msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
+msgstr ""
+
+#: params.opt:1126
+#, no-c-format
+msgid "Maximum number of predicates anded for each predicate ored in the normalized predicate chain."
+msgstr ""
+
+#: params.opt:1131
+#, no-c-format
+msgid "Maximum number of predicates ored in the normalized predicate chain."
+msgstr ""
+
+#: params.opt:1135
+#, no-c-format
+msgid "Instruction accounted for function prologue, epilogue and other overhead."
+msgstr ""
+
+#: params.opt:1139
+#, no-c-format
+msgid "Time accounted for function prologue, epilogue and other overhead."
+msgstr ""
+
+#: params.opt:1143
+#, no-c-format
+msgid "Instruction accounted for function thunk overhead."
+msgstr ""
+
+#: params.opt:1147
+#, no-c-format
+msgid "Time accounted for function thunk overhead."
+msgstr ""
+
+#: params.opt:1151
+#, no-c-format
+msgid "The denominator n of fraction 1/n of the number of profiled runs of the entire program below which the execution count of a basic block must be in order for the basic block to be considered unlikely."
+msgstr ""
+
+#: params.opt:1155
+#, no-c-format
+msgid "Maximum unroll factor for the unroll-and-jam transformation."
+msgstr ""
+
+#: params.opt:1159
+#, no-c-format
+msgid "Minimum percentage of memrefs that must go away for unroll-and-jam to be considered profitable."
+msgstr ""
+
+#: params.opt:1163
+#, no-c-format
+msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
+msgstr ""
+
+#: params.opt:1167
+#, no-c-format
+msgid "Whether to use canonical types."
+msgstr ""
+
+#: params.opt:1171
+#, no-c-format
+msgid "Enable loop epilogue vectorization using smaller vector size."
+msgstr ""
+
+#: params.opt:1175
+#, no-c-format
+msgid "Maximum number of possible vector layouts (such as permutations) to consider when optimizing to-be-vectorized code."
+msgstr ""
+
+#: params.opt:1179
+#, no-c-format
+msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
+msgstr ""
+
+#: params.opt:1183
+#, no-c-format
+msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
+msgstr ""
+
+#: params.opt:1187
+#, no-c-format
+msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
+msgstr ""
+
+#: params.opt:1191
+#, no-c-format
+msgid "Controls how loop vectorizer uses partial vectors.  0 means never, 1 means only for loops whose need to iterate can be removed, 2 means for all loops.  The default value is 2."
+msgstr ""
+
+#: params.opt:1195
+#, no-c-format
+msgid "The maximum factor which the loop vectorizer applies to the cost of statements in an inner loop relative to the loop being vectorized."
+msgstr ""
+
+#: params.opt:1199
+#, no-c-format
+msgid "Enable loop vectorization of floating point inductions."
+msgstr ""
+
+#: params.opt:1203
+#, no-c-format
+msgid "Maximum number of basic blocks before VRP uses a sparse bitmap cache."
+msgstr ""
+
+#: params.opt:1207
+#, no-c-format
+msgid "Maximum number of outgoing edges in a switch before VRP will not process it."
+msgstr ""
+
+#: params.opt:1211
+#, no-c-format
+msgid "Maximum number of basic blocks for VRP to use a basic cache vector."
+msgstr ""
+
+#: cfgrtl.cc:2837
+msgid "flow control insn inside a basic block"
+msgstr ""
+
+#: cfgrtl.cc:3129
+msgid "insn outside basic block"
+msgstr ""
+
+#: cfgrtl.cc:3137
+msgid "return not followed by barrier"
+msgstr ""
+
+#: collect-utils.cc:206
+#, c-format
+msgid "[cannot find %s]"
+msgstr ""
+
+#: collect2.cc:1561
+#, c-format
+msgid "collect2 version %s\n"
+msgstr ""
+
+#: collect2.cc:1666
+#, c-format
+msgid "%d constructor found\n"
+msgid_plural "%d constructors found\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: collect2.cc:1670
+#, c-format
+msgid "%d destructor found\n"
+msgid_plural "%d destructors found\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: collect2.cc:1674
+#, c-format
+msgid "%d frame table found\n"
+msgid_plural "%d frame tables found\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: collect2.cc:1829
+#, c-format
+msgid "[Leaving %s]\n"
+msgstr ""
+
+#: collect2.cc:2059
+#, c-format
+msgid ""
+"\n"
+"write_c_file - output name is %s, prefix is %s\n"
+msgstr ""
+
+#: collect2.cc:2583
+#, c-format
+msgid ""
+"\n"
+"ldd output with constructors/destructors.\n"
+msgstr ""
+
+#: cprop.cc:1759
+msgid "const/copy propagation disabled"
+msgstr ""
+
+#: diagnostic-format-json.cc:343 diagnostic-format-sarif.cc:1780
+#, c-format
+msgid "error: unable to open '%s' for writing: %s\n"
+msgstr ""
+
+#. Print a header for the remaining output to stderr, and
+#. return, attempting to print the usual ICE messages to
+#. stderr.  Hopefully this will be helpful to the user in
+#. indicating what's gone wrong (also for DejaGnu, for pruning
+#. those messages).
+#: diagnostic-format-sarif.cc:1699
+#, c-format
+msgid "Internal compiler error:\n"
+msgstr ""
+
+#: diagnostic.cc:729
+#, c-format
+msgid "compilation terminated due to -fmax-errors=%u.\n"
+msgstr ""
+
+#: diagnostic.cc:756
+#, c-format
+msgid "compilation terminated due to -Wfatal-errors.\n"
+msgstr ""
+
+#: diagnostic.cc:788
+#, c-format
+msgid "Please submit a full bug report, with preprocessed source.\n"
+msgstr ""
+
+#: diagnostic.cc:791
+#, c-format
+msgid "Please submit a full bug report, with preprocessed source (by using -freport-bug).\n"
+msgstr ""
+
+#: diagnostic.cc:795
+#, c-format
+msgid "Please include the complete backtrace with any bug report.\n"
+msgstr ""
+
+#: diagnostic.cc:797
+#, c-format
+msgid "See %s for instructions.\n"
+msgstr ""
+
+#: diagnostic.cc:805
+#, c-format
+msgid "compilation terminated.\n"
+msgstr ""
+
+#: diagnostic.cc:881
+msgid "                 from"
+msgstr ""
+
+#: diagnostic.cc:882
+msgid "In file included from"
+msgstr ""
+
+#. 2
+#: diagnostic.cc:883
+msgid "        included from"
+msgstr ""
+
+#: diagnostic.cc:884
+msgid "In module"
+msgstr ""
+
+#. 4
+#: diagnostic.cc:885
+msgid "of module"
+msgstr ""
+
+#: diagnostic.cc:886
+msgid "In module imported at"
+msgstr ""
+
+#. 6
+#: diagnostic.cc:887
+msgid "imported at"
+msgstr ""
+
+#: diagnostic.cc:1592
+#, c-format
+msgid "%s:%d: confused by earlier errors, bailing out\n"
+msgstr ""
+
+#: diagnostic.cc:2303
+#, c-format
+msgid "internal compiler error: error reporting routines re-entered.\n"
+msgstr ""
+
+#: diagnostic.cc:2334 diagnostic.cc:2353
+#, gcc-internal-format, gfc-internal-format
+msgid "in %s, at %s:%d"
+msgstr ""
+
+#: diagnostic.cc:2404
+#, c-format
+msgid "%s: all warnings being treated as errors"
+msgstr ""
+
+#: diagnostic.cc:2409
+#, c-format
+msgid "%s: some warnings being treated as errors"
+msgstr ""
+
+#: final.cc:1097
+msgid "negative insn length"
+msgstr ""
+
+#: final.cc:2807
+msgid "could not split insn"
+msgstr ""
+
+#: final.cc:3182
+msgid "invalid 'asm': "
+msgstr ""
+
+#: final.cc:3315
+#, c-format
+msgid "nested assembly dialect alternatives"
+msgstr ""
+
+#: final.cc:3343 final.cc:3355
+#, c-format
+msgid "unterminated assembly dialect alternative"
+msgstr ""
+
+#: final.cc:3497
+#, c-format
+msgid "operand number missing after %%-letter"
+msgstr ""
+
+#: final.cc:3500 final.cc:3541
+#, c-format
+msgid "operand number out of range"
+msgstr ""
+
+#: final.cc:3558
+#, c-format
+msgid "invalid %%-code"
+msgstr ""
+
+#: final.cc:3592
+#, c-format
+msgid "'%%l' operand isn't a label"
+msgstr ""
+
+#. We can't handle floating point constants;
+#. PRINT_OPERAND must handle them.
+#. We can't handle floating point constants;
+#. TARGET_PRINT_OPERAND must handle them.
+#: final.cc:3728 config/arc/arc.cc:6311 config/i386/i386.cc:12926
+#, c-format
+msgid "floating constant misused"
+msgstr ""
+
+#: final.cc:3786 config/arc/arc.cc:6408 config/i386/i386.cc:13017
+#: config/pdp11/pdp11.cc:1872
+#, c-format
+msgid "invalid expression as operand"
+msgstr ""
+
+#: gcc.cc:126
+#, c-format
+msgid "%s\n"
+msgstr ""
+
+#: gcc.cc:1860
+#, c-format
+msgid "Using built-in specs.\n"
+msgstr ""
+
+#: gcc.cc:2105
+#, c-format
+msgid ""
+"Setting spec %s to '%s'\n"
+"\n"
+msgstr ""
+
+#: gcc.cc:2310
+#, c-format
+msgid "Reading specs from %s\n"
+msgstr ""
+
+#: gcc.cc:2440
+#, c-format
+msgid "could not find specs file %s\n"
+msgstr ""
+
+#: gcc.cc:2511
+#, c-format
+msgid "rename spec %s to %s\n"
+msgstr ""
+
+#: gcc.cc:2513
+#, c-format
+msgid ""
+"spec is '%s'\n"
+"\n"
+msgstr ""
+
+#: gcc.cc:3374
+#, c-format
+msgid ""
+"\n"
+"Go ahead? (y or n) "
+msgstr ""
+
+#: gcc.cc:3546
+#, c-format
+msgid "# %s %.2f %.2f\n"
+msgstr ""
+
+#: gcc.cc:3726
+#, c-format
+msgid "Usage: %s [options] file...\n"
+msgstr "გამოყენება: %s [პარამეტრები] ფაილი...\n"
+
+#: gcc.cc:3727
+msgid "Options:\n"
+msgstr ""
+
+#: gcc.cc:3729
+msgid "  -pass-exit-codes         Exit with highest error code from a phase.\n"
+msgstr ""
+
+#: gcc.cc:3730
+msgid "  --help                   Display this information.\n"
+msgstr ""
+
+#: gcc.cc:3731
+msgid "  --target-help            Display target specific command line options (including assembler and linker options).\n"
+msgstr ""
+
+#: gcc.cc:3733
+msgid "  --help={common|optimizers|params|target|warnings|[^]{joined|separate|undocumented}}[,...].\n"
+msgstr ""
+
+#: gcc.cc:3734
+msgid "                           Display specific types of command line options.\n"
+msgstr ""
+
+#: gcc.cc:3736
+msgid "  (Use '-v --help' to display command line options of sub-processes).\n"
+msgstr ""
+
+#: gcc.cc:3737
+msgid "  --version                Display compiler version information.\n"
+msgstr ""
+
+#: gcc.cc:3738
+msgid "  -dumpspecs               Display all of the built in spec strings.\n"
+msgstr ""
+
+#: gcc.cc:3739
+msgid "  -dumpversion             Display the version of the compiler.\n"
+msgstr ""
+
+#: gcc.cc:3740
+msgid "  -dumpmachine             Display the compiler's target processor.\n"
+msgstr ""
+
+#: gcc.cc:3741
+msgid "  -foffload=<targets>      Specify offloading targets.\n"
+msgstr ""
+
+#: gcc.cc:3742
+msgid "  -print-search-dirs       Display the directories in the compiler's search path.\n"
+msgstr ""
+
+#: gcc.cc:3743
+msgid "  -print-libgcc-file-name  Display the name of the compiler's companion library.\n"
+msgstr ""
+
+#: gcc.cc:3744
+msgid "  -print-file-name=<lib>   Display the full path to library <lib>.\n"
+msgstr ""
+
+#: gcc.cc:3745
+msgid "  -print-prog-name=<prog>  Display the full path to compiler component <prog>.\n"
+msgstr ""
+
+#: gcc.cc:3746
+msgid ""
+"  -print-multiarch         Display the target's normalized GNU triplet, used as\n"
+"                           a component in the library path.\n"
+msgstr ""
+
+#: gcc.cc:3749
+msgid "  -print-multi-directory   Display the root directory for versions of libgcc.\n"
+msgstr ""
+
+#: gcc.cc:3750
+msgid ""
+"  -print-multi-lib         Display the mapping between command line options and\n"
+"                           multiple library search directories.\n"
+msgstr ""
+
+#: gcc.cc:3753
+msgid "  -print-multi-os-directory Display the relative path to OS libraries.\n"
+msgstr ""
+
+#: gcc.cc:3754
+msgid "  -print-sysroot           Display the target libraries directory.\n"
+msgstr ""
+
+#: gcc.cc:3755
+msgid "  -print-sysroot-headers-suffix Display the sysroot suffix used to find headers.\n"
+msgstr ""
+
+#: gcc.cc:3756
+msgid "  -Wa,<options>            Pass comma-separated <options> on to the assembler.\n"
+msgstr ""
+
+#: gcc.cc:3757
+msgid "  -Wp,<options>            Pass comma-separated <options> on to the preprocessor.\n"
+msgstr ""
+
+#: gcc.cc:3758
+msgid "  -Wl,<options>            Pass comma-separated <options> on to the linker.\n"
+msgstr ""
+
+#: gcc.cc:3759
+msgid "  -Xassembler <arg>        Pass <arg> on to the assembler.\n"
+msgstr ""
+
+#: gcc.cc:3760
+msgid "  -Xpreprocessor <arg>     Pass <arg> on to the preprocessor.\n"
+msgstr ""
+
+#: gcc.cc:3761
+msgid "  -Xlinker <arg>           Pass <arg> on to the linker.\n"
+msgstr ""
+
+#: gcc.cc:3762
+msgid "  -save-temps              Do not delete intermediate files.\n"
+msgstr ""
+
+#: gcc.cc:3763
+msgid "  -save-temps=<arg>        Do not delete intermediate files.\n"
+msgstr ""
+
+#: gcc.cc:3764
+msgid ""
+"  -no-canonical-prefixes   Do not canonicalize paths when building relative\n"
+"                           prefixes to other gcc components.\n"
+msgstr ""
+
+#: gcc.cc:3767
+msgid "  -pipe                    Use pipes rather than intermediate files.\n"
+msgstr ""
+
+#: gcc.cc:3768
+msgid "  -time                    Time the execution of each subprocess.\n"
+msgstr ""
+
+#: gcc.cc:3769
+msgid "  -specs=<file>            Override built-in specs with the contents of <file>.\n"
+msgstr ""
+
+#: gcc.cc:3770
+msgid "  -std=<standard>          Assume that the input sources are for <standard>.\n"
+msgstr ""
+
+#: gcc.cc:3771
+msgid ""
+"  --sysroot=<directory>    Use <directory> as the root directory for headers\n"
+"                           and libraries.\n"
+msgstr ""
+
+#: gcc.cc:3774
+msgid "  -B <directory>           Add <directory> to the compiler's search paths.\n"
+msgstr ""
+
+#: gcc.cc:3775
+msgid "  -v                       Display the programs invoked by the compiler.\n"
+msgstr ""
+
+#: gcc.cc:3776
+msgid "  -###                     Like -v but options quoted and commands not executed.\n"
+msgstr ""
+
+#: gcc.cc:3777
+msgid "  -E                       Preprocess only; do not compile, assemble or link.\n"
+msgstr ""
+
+#: gcc.cc:3778
+msgid "  -S                       Compile only; do not assemble or link.\n"
+msgstr ""
+
+#: gcc.cc:3779
+msgid "  -c                       Compile and assemble, but do not link.\n"
+msgstr ""
+
+#: gcc.cc:3780
+msgid "  -o <file>                Place the output into <file>.\n"
+msgstr ""
+
+#: gcc.cc:3781
+msgid ""
+"  -pie                     Create a dynamically linked position independent\n"
+"                           executable.\n"
+msgstr ""
+
+#: gcc.cc:3783
+msgid "  -shared                  Create a shared library.\n"
+msgstr ""
+
+#: gcc.cc:3784
+msgid ""
+"  -x <language>            Specify the language of the following input files.\n"
+"                           Permissible languages include: c c++ assembler none\n"
+"                           'none' means revert to the default behavior of\n"
+"                           guessing the language based on the file's extension.\n"
+msgstr ""
+
+#: gcc.cc:3791
+#, c-format
+msgid ""
+"\n"
+"Options starting with -g, -f, -m, -O, -W, or --param are automatically\n"
+" passed on to the various sub-processes invoked by %s.  In order to pass\n"
+" other options on to these processes the -W<letter> options must be used.\n"
+msgstr ""
+
+#: gcc.cc:6910
+#, c-format
+msgid "Processing spec (%s), which is '%s'\n"
+msgstr ""
+
+#: gcc.cc:7671
+#, c-format
+msgid "Target: %s\n"
+msgstr ""
+
+#: gcc.cc:7672
+#, c-format
+msgid "Configured with: %s\n"
+msgstr "აგების პარამეტრები: %s\n"
+
+#: gcc.cc:7686
+#, c-format
+msgid "Thread model: %s\n"
+msgstr ""
+
+#: gcc.cc:7687
+#, c-format
+msgid "Supported LTO compression algorithms: zlib"
+msgstr ""
+
+#: gcc.cc:7689
+#, c-format
+msgid " zstd"
+msgstr ""
+
+#: gcc.cc:7691 gcov.cc:1610 gcov.cc:1668 gcov.cc:1680 gcov.cc:3098
+#, c-format
+msgid "\n"
+msgstr ""
+
+#: gcc.cc:7702
+#, c-format
+msgid "gcc version %s %s\n"
+msgstr ""
+
+#: gcc.cc:7705
+#, c-format
+msgid "gcc driver version %s %sexecuting gcc version %s\n"
+msgstr ""
+
+#: gcc.cc:7778 gcc.cc:7988
+#, c-format
+msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
+msgstr ""
+
+#: gcc.cc:7912
+#, c-format
+msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
+msgstr ""
+
+#: gcc.cc:8764
+#, c-format
+msgid "install: %s%s\n"
+msgstr ""
+
+#: gcc.cc:8767
+#, c-format
+msgid "programs: %s\n"
+msgstr ""
+
+#: gcc.cc:8769
+#, c-format
+msgid "libraries: %s\n"
+msgstr ""
+
+#: gcc.cc:8886
+#, c-format
+msgid ""
+"\n"
+"For bug reporting instructions, please see:\n"
+msgstr ""
+
+#: gcc.cc:8902 gcov-tool.cc:594
+#, c-format
+msgid "%s %s%s\n"
+msgstr ""
+
+#: gcc.cc:8905 gcov-tool.cc:596 gcov.cc:1015 fortran/gfortranspec.cc:282
+msgid "(C)"
+msgstr ""
+
+#: gcc.cc:8906 gcov-tool.cc:598 gcov.cc:1017 fortran/gfortranspec.cc:283
+#, c-format
+msgid ""
+"This is free software; see the source for copying conditions.  There is NO\n"
+"warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
+"\n"
+msgstr ""
+
+#: gcc.cc:9249
+#, c-format
+msgid ""
+"\n"
+"Linker options\n"
+"==============\n"
+"\n"
+msgstr ""
+
+#: gcc.cc:9250
+#, c-format
+msgid ""
+"Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
+"\n"
+msgstr ""
+
+#: gcc.cc:10651
+#, c-format
+msgid ""
+"Assembler options\n"
+"=================\n"
+"\n"
+msgstr ""
+
+#: gcc.cc:10652
+#, c-format
+msgid ""
+"Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
+"\n"
+msgstr ""
+
+#: gcov-tool.cc:157 gcov-tool.cc:300
+#, c-format
+msgid "no profile files were merged\n"
+msgstr ""
+
+#: gcov-tool.cc:169
+#, c-format
+msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
+msgstr ""
+
+#: gcov-tool.cc:170 gcov-tool.cc:337
+#, c-format
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr ""
+
+#: gcov-tool.cc:171 gcov-tool.cc:242 gcov-tool.cc:339 gcov-tool.cc:491
+#, c-format
+msgid "    -v, --verbose                       Verbose mode\n"
+msgstr ""
+
+#: gcov-tool.cc:172 gcov-tool.cc:243
+#, c-format
+msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
+msgstr ""
+
+#: gcov-tool.cc:188
+#, c-format
+msgid "Merge subcommand usage:"
+msgstr ""
+
+#: gcov-tool.cc:240
+#, c-format
+msgid ""
+"  merge-stream [options] [<file>]       Merge coverage stream file (or stdin)\n"
+"                                        and coverage file contents\n"
+msgstr ""
+
+#: gcov-tool.cc:258
+#, c-format
+msgid "Merge-stream subcommand usage:"
+msgstr ""
+
+#: gcov-tool.cc:335
+#, c-format
+msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
+msgstr ""
+
+#: gcov-tool.cc:336
+#, c-format
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgstr ""
+
+#: gcov-tool.cc:338
+#, c-format
+msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
+msgstr ""
+
+#: gcov-tool.cc:356
+#, c-format
+msgid "Rewrite subcommand usage:"
+msgstr ""
+
+#: gcov-tool.cc:395
+#, c-format
+msgid "scaling cannot co-exist with normalization, skipping\n"
+msgstr ""
+
+#: gcov-tool.cc:408 gcov-tool.cc:418
+#, c-format
+msgid "incorrect format in scaling, using 1/1\n"
+msgstr ""
+
+#: gcov-tool.cc:428
+#, c-format
+msgid "normalization cannot co-exist with scaling\n"
+msgstr ""
+
+#: gcov-tool.cc:485
+#, c-format
+msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
+msgstr ""
+
+#: gcov-tool.cc:486
+#, c-format
+msgid "    -f, --function                      Print function level info\n"
+msgstr ""
+
+#: gcov-tool.cc:487
+#, c-format
+msgid "    -F, --fullname                      Print full filename\n"
+msgstr ""
+
+#: gcov-tool.cc:488
+#, c-format
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgstr ""
+
+#: gcov-tool.cc:489
+#, c-format
+msgid "    -o, --object                        Print object level info\n"
+msgstr ""
+
+#: gcov-tool.cc:490
+#, c-format
+msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
+msgstr ""
+
+#: gcov-tool.cc:510
+#, c-format
+msgid "Overlap subcommand usage:"
+msgstr ""
+
+#: gcov-tool.cc:576
+#, c-format
+msgid ""
+"Usage: %s [OPTION]... SUB_COMMAND [OPTION]...\n"
+"\n"
+msgstr ""
+
+#: gcov-tool.cc:577
+#, c-format
+msgid ""
+"Offline tool to handle gcda counts\n"
+"\n"
+msgstr ""
+
+#: gcov-tool.cc:578
+#, c-format
+msgid "  -h, --help                            Print this help, then exit\n"
+msgstr ""
+
+#: gcov-tool.cc:579
+#, c-format
+msgid "  -v, --version                         Print version number, then exit\n"
+msgstr ""
+
+#: gcov-tool.cc:584 gcov.cc:1002
+#, c-format
+msgid ""
+"\n"
+"For bug reporting instructions, please see:\n"
+"%s.\n"
+msgstr ""
+
+#: gcov-tool.cc:595
+#, c-format
+msgid "Copyright %s 2024 Free Software Foundation, Inc.\n"
+msgstr ""
+
+#: gcov.cc:969
+#, c-format
+msgid ""
+"Usage: gcov [OPTION...] SOURCE|OBJ...\n"
+"\n"
+msgstr ""
+
+#: gcov.cc:970
+#, c-format
+msgid ""
+"Print code coverage information.\n"
+"\n"
+msgstr ""
+
+#: gcov.cc:971
+#, c-format
+msgid "  -a, --all-blocks                Show information for every basic block\n"
+msgstr ""
+
+#: gcov.cc:972
+#, c-format
+msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
+msgstr ""
+
+#: gcov.cc:973
+#, c-format
+msgid ""
+"  -c, --branch-counts             Output counts of branches taken\n"
+"                                    rather than percentages\n"
+msgstr ""
+
+#: gcov.cc:975
+#, c-format
+msgid ""
+"  -g, --conditions                Include modified condition/decision\n"
+"                                    coverage in output\n"
+msgstr ""
+
+#: gcov.cc:977
+#, c-format
+msgid "  -d, --display-progress          Display progress information\n"
+msgstr ""
+
+#: gcov.cc:978
+#, c-format
+msgid "  -D, --debug\t\t\t    Display debugging dumps\n"
+msgstr ""
+
+#: gcov.cc:979
+#, c-format
+msgid "  -f, --function-summaries        Output summaries for each function\n"
+msgstr ""
+
+#: gcov.cc:980
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr ""
+
+#: gcov.cc:981
+#, c-format
+msgid ""
+"  -j, --json-format               Output JSON intermediate format\n"
+"                                    into .gcov.json.gz file\n"
+msgstr ""
+
+#: gcov.cc:983
+#, c-format
+msgid "  -H, --human-readable            Output human readable numbers\n"
+msgstr ""
+
+#: gcov.cc:984
+#, c-format
+msgid "  -k, --use-colors                Emit colored output\n"
+msgstr ""
+
+#: gcov.cc:985
+#, c-format
+msgid ""
+"  -l, --long-file-names           Use long output file names for included\n"
+"                                    source files\n"
+msgstr ""
+
+#: gcov.cc:987
+#, c-format
+msgid "  -m, --demangled-names           Output demangled function names\n"
+msgstr ""
+
+#: gcov.cc:988
+#, c-format
+msgid "  -n, --no-output                 Do not create an output file\n"
+msgstr ""
+
+#: gcov.cc:989
+#, c-format
+msgid "  -o, --object-directory DIR|FILE Search for object files in DIR or called FILE\n"
+msgstr ""
+
+#: gcov.cc:990
+#, c-format
+msgid "  -p, --preserve-paths            Preserve all pathname components\n"
+msgstr ""
+
+#: gcov.cc:991
+#, c-format
+msgid "  -q, --use-hotness-colors        Emit perf-like colored output for hot lines\n"
+msgstr ""
+
+#: gcov.cc:992
+#, c-format
+msgid "  -r, --relative-only             Only show data for relative sources\n"
+msgstr ""
+
+#: gcov.cc:993
+#, c-format
+msgid "  -s, --source-prefix DIR         Source prefix to elide\n"
+msgstr ""
+
+#: gcov.cc:994
+#, c-format
+msgid "  -t, --stdout                    Output to stdout instead of a file\n"
+msgstr ""
+
+#: gcov.cc:995
+#, c-format
+msgid "  -u, --unconditional-branches    Show unconditional branch counts too\n"
+msgstr ""
+
+#: gcov.cc:996
+#, c-format
+msgid "  -v, --version                   Print version number, then exit\n"
+msgstr ""
+
+#: gcov.cc:997
+#, c-format
+msgid "  -w, --verbose                   Print verbose informations\n"
+msgstr ""
+
+#: gcov.cc:998
+#, c-format
+msgid "  -x, --hash-filenames            Hash long pathnames\n"
+msgstr ""
+
+#: gcov.cc:999
+#, c-format
+msgid ""
+"\n"
+"Obsolete options:\n"
+msgstr ""
+
+#: gcov.cc:1000
+#, c-format
+msgid "  -i, --json-format               Replaced with -j, --json-format\n"
+msgstr ""
+
+#: gcov.cc:1001
+#, c-format
+msgid "  -j, --human-readable            Replaced with -H, --human-readable\n"
+msgstr ""
+
+#: gcov.cc:1012
+#, c-format
+msgid "gcov %s%s\n"
+msgstr ""
+
+#: gcov.cc:1013
+#, c-format
+msgid "JSON format version: %s\n"
+msgstr ""
+
+#: gcov.cc:1454
+#, c-format
+msgid "'%s' file is already processed\n"
+msgstr ""
+
+#: gcov.cc:1570 gcov.cc:1699
+#, c-format
+msgid "Creating '%s'\n"
+msgstr ""
+
+#: gcov.cc:1574
+#, c-format
+msgid "Error writing output file '%s'\n"
+msgstr ""
+
+#: gcov.cc:1582
+#, c-format
+msgid "Could not open output file '%s'\n"
+msgstr ""
+
+#: gcov.cc:1589
+#, c-format
+msgid "Removing '%s'\n"
+msgstr ""
+
+#: gcov.cc:1704
+#, c-format
+msgid "Cannot open JSON output file %s\n"
+msgstr ""
+
+#: gcov.cc:1713
+#, c-format
+msgid "Error writing JSON output file %s\n"
+msgstr ""
+
+#: gcov.cc:1878
+#, c-format
+msgid "%s:source file is newer than notes file '%s'\n"
+msgstr ""
+
+#: gcov.cc:1883
+#, c-format
+msgid "(the message is displayed only once per source file)\n"
+msgstr ""
+
+#: gcov.cc:1903
+#, c-format
+msgid "%s:cannot open notes file\n"
+msgstr ""
+
+#: gcov.cc:1910
+#, c-format
+msgid "%s:not a gcov notes file\n"
+msgstr ""
+
+#: gcov.cc:1924
+#, c-format
+msgid "%s:version '%.4s', prefer '%.4s'\n"
+msgstr ""
+
+#: gcov.cc:1977
+#, c-format
+msgid "%s:already seen blocks for '%s'\n"
+msgstr ""
+
+#: gcov.cc:2064
+#, c-format
+msgid "%s:already seen conditions for '%s'\n"
+msgstr ""
+
+#: gcov.cc:2115 gcov.cc:2244
+#, c-format
+msgid "%s:corrupted\n"
+msgstr ""
+
+#: gcov.cc:2123
+#, c-format
+msgid "%s:no functions found\n"
+msgstr ""
+
+#: gcov.cc:2141
+#, c-format
+msgid "%s:cannot open data file, assuming not executed\n"
+msgstr ""
+
+#: gcov.cc:2148
+#, c-format
+msgid "%s:not a gcov data file\n"
+msgstr ""
+
+#: gcov.cc:2162
+#, c-format
+msgid "%s:version '%.4s', prefer version '%.4s'\n"
+msgstr ""
+
+#: gcov.cc:2169
+#, c-format
+msgid "%s:stamp mismatch with notes file\n"
+msgstr ""
+
+#: gcov.cc:2206
+#, c-format
+msgid "%s:profile mismatch for '%s'\n"
+msgstr ""
+
+#: gcov.cc:2243
+#, c-format
+msgid "%s:overflowed\n"
+msgstr ""
+
+#: gcov.cc:2291
+#, c-format
+msgid "%s:'%s' lacks entry and/or exit blocks\n"
+msgstr ""
+
+#: gcov.cc:2296
+#, c-format
+msgid "%s:'%s' has arcs to entry block\n"
+msgstr ""
+
+#: gcov.cc:2304
+#, c-format
+msgid "%s:'%s' has arcs from exit block\n"
+msgstr ""
+
+#: gcov.cc:2513
+#, c-format
+msgid "%s:graph is unsolvable for '%s'\n"
+msgstr ""
+
+#: gcov.cc:2638
+#, c-format
+msgid "Lines executed:%s of %d\n"
+msgstr ""
+
+#: gcov.cc:2641
+#, c-format
+msgid "No executable lines\n"
+msgstr ""
+
+#: gcov.cc:2649 gcov.cc:2658
+#, c-format
+msgid "%s '%s'\n"
+msgstr ""
+
+#: gcov.cc:2665
+#, c-format
+msgid "Branches executed:%s of %d\n"
+msgstr ""
+
+#: gcov.cc:2669
+#, c-format
+msgid "Taken at least once:%s of %d\n"
+msgstr ""
+
+#: gcov.cc:2675
+#, c-format
+msgid "No branches\n"
+msgstr ""
+
+#: gcov.cc:2677
+#, c-format
+msgid "Calls executed:%s of %d\n"
+msgstr ""
+
+#: gcov.cc:2681
+#, c-format
+msgid "No calls\n"
+msgstr ""
+
+#: gcov.cc:2688
+#, c-format
+msgid "Condition outcomes covered:%s of %d\n"
+msgstr ""
+
+#: gcov.cc:2693
+#, c-format
+msgid "No conditions\n"
+msgstr ""
+
+#: gcov.cc:2913
+#, c-format
+msgid "%s:no lines for '%s'\n"
+msgstr ""
+
+#: gcov.cc:3049
+#, c-format
+msgid "condition outcomes covered %d/%d\n"
+msgstr ""
+
+#: gcov.cc:3062
+#, c-format
+msgid "condition %2u not covered (%s%s)\n"
+msgstr ""
+
+#: gcov.cc:3076
+#, c-format
+msgid "call   %2d returned %s\n"
+msgstr ""
+
+#: gcov.cc:3081
+#, c-format
+msgid "call   %2d never executed\n"
+msgstr ""
+
+#: gcov.cc:3086
+#, c-format
+msgid "branch %2d taken %s%s"
+msgstr ""
+
+#: gcov.cc:3091
+#, c-format
+msgid "branch %2d never executed%s"
+msgstr ""
+
+#: gcov.cc:3096
+#, c-format
+msgid " (BB %d)"
+msgstr ""
+
+#: gcov.cc:3103
+#, c-format
+msgid "unconditional %2d taken %s\n"
+msgstr ""
+
+#: gcov.cc:3106
+#, c-format
+msgid "unconditional %2d never executed\n"
+msgstr ""
+
+#: gcov.cc:3369
+#, c-format
+msgid "Cannot open source file %s\n"
+msgstr ""
+
+#: gcse.cc:2592
+msgid "PRE disabled"
+msgstr ""
+
+#: gcse.cc:3520
+msgid "GCSE disabled"
+msgstr ""
+
+#: incpath.cc:77
+#, c-format
+msgid "ignoring duplicate directory \"%s\"\n"
+msgstr ""
+
+#: incpath.cc:80
+#, c-format
+msgid "  as it is a non-system directory that duplicates a system directory\n"
+msgstr ""
+
+#: incpath.cc:84
+#, c-format
+msgid "ignoring nonexistent directory \"%s\"\n"
+msgstr ""
+
+#: incpath.cc:391
+#, c-format
+msgid "#include \"...\" search starts here:\n"
+msgstr ""
+
+#: incpath.cc:395
+#, c-format
+msgid "#include <...> search starts here:\n"
+msgstr ""
+
+#: incpath.cc:400
+#, c-format
+msgid "End of search list.\n"
+msgstr ""
+
+#: input.cc:35
+msgid "<built-in>"
+msgstr ""
+
+#. Opening quotation mark.
+#: intl.cc:62
+msgid "`"
+msgstr ""
+
+#. Closing quotation mark.
+#: intl.cc:65
+msgid "'"
+msgstr ""
+
+#: langhooks.cc:384
+msgid "At top level:"
+msgstr ""
+
+#: langhooks.cc:400
+#, c-format
+msgid "In member function %qs"
+msgstr ""
+
+#: langhooks.cc:404
+#, c-format
+msgid "In function %qs"
+msgstr ""
+
+#: langhooks.cc:449
+msgid "    inlined from %qs at %r%s:%d:%d%R"
+msgstr ""
+
+#: langhooks.cc:454
+msgid "    inlined from %qs at %r%s:%d%R"
+msgstr ""
+
+#: langhooks.cc:460
+#, c-format
+msgid "    inlined from %qs"
+msgstr ""
+
+#: lra-assigns.cc:1868 reload1.cc:2073
+msgid "this is the insn:"
+msgstr ""
+
+#: lra-constraints.cc:3266
+msgid "unable to generate reloads for impossible constraints:"
+msgstr ""
+
+#: lra-constraints.cc:4234 reload.cc:3839
+msgid "unable to generate reloads for:"
+msgstr ""
+
+#. What to print when a switch has no documentation.
+#: opts.cc:329
+msgid "This option lacks documentation."
+msgstr ""
+
+#: opts.cc:330
+msgid "Uses of this option are diagnosed."
+msgstr ""
+
+#: opts.cc:1688
+#, c-format
+msgid "Same as %s%s (or, in negated form, %s%s)."
+msgstr ""
+
+#: opts.cc:1693
+#, c-format
+msgid "Same as %s%s."
+msgstr ""
+
+#: opts.cc:1698
+#, c-format
+msgid "Same as %s."
+msgstr ""
+
+#: opts.cc:1706
+#, c-format
+msgid "%s  Same as %s."
+msgstr ""
+
+#: opts.cc:1769
+msgid "[available in "
+msgstr ""
+
+#: opts.cc:1801
+msgid "[default]"
+msgstr ""
+
+#: opts.cc:1810
+#, c-format
+msgid "%llu bytes"
+msgstr ""
+
+#: opts.cc:1847
+msgid "[enabled]"
+msgstr ""
+
+#: opts.cc:1849
+msgid "[disabled]"
+msgstr ""
+
+#: opts.cc:1885
+#, c-format
+msgid " No options with the desired characteristics were found\n"
+msgstr ""
+
+#: opts.cc:1894
+#, c-format
+msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
+msgstr ""
+
+#: opts.cc:1900
+#, c-format
+msgid " All options with the desired characteristics have already been displayed\n"
+msgstr ""
+
+#: opts.cc:1945
+#, c-format
+msgid ""
+"  Known valid arguments for %s option:\n"
+"   "
+msgstr ""
+
+#: opts.cc:1995
+msgid "The following options are target specific"
+msgstr ""
+
+#: opts.cc:1998
+msgid "The following options control compiler warning messages"
+msgstr ""
+
+#: opts.cc:2001
+msgid "The following options control optimizations"
+msgstr ""
+
+#: opts.cc:2004 opts.cc:2044
+msgid "The following options are language-independent"
+msgstr ""
+
+#: opts.cc:2007
+msgid "The following options control parameters"
+msgstr ""
+
+#: opts.cc:2013
+msgid "The following options are specific to just the language "
+msgstr ""
+
+#: opts.cc:2015
+msgid "The following options are supported by the language "
+msgstr ""
+
+#: opts.cc:2026
+msgid "The following options are not documented"
+msgstr ""
+
+#: opts.cc:2028
+msgid "The following options take separate arguments"
+msgstr ""
+
+#: opts.cc:2030
+msgid "The following options take joined arguments"
+msgstr ""
+
+#: opts.cc:2042
+msgid "The following options are language-related"
+msgstr ""
+
+#: passes.cc:1833
+#, c-format
+msgid "during %s pass: %s\n"
+msgstr ""
+
+#: passes.cc:1838
+#, c-format
+msgid "dump file: %s\n"
+msgstr ""
+
+#: plugin.cc:965
+msgid "Event"
+msgstr "მოვლენა"
+
+#: plugin.cc:965
+msgid "Plugins"
+msgstr "დამატებები"
+
+#: plugin.cc:997
+#, c-format
+msgid "*** WARNING *** there are active plugins, do not report this as a bug unless you can reproduce it without enabling any plugins.\n"
+msgstr ""
+
+#: postreload-gcse.cc:1356
+msgid "using simple load CSE after register allocation"
+msgstr ""
+
+#. It's the compiler's fault.
+#: reload1.cc:5994
+msgid "could not find a spill register"
+msgstr ""
+
+#. It's the compiler's fault.
+#: reload1.cc:7876
+msgid "VOIDmode on an output"
+msgstr ""
+
+#: reload1.cc:8632
+msgid "failure trying to reload:"
+msgstr ""
+
+#: rtl-error.cc:116
+msgid "unrecognizable insn:"
+msgstr ""
+
+#: rtl-error.cc:118
+msgid "insn does not satisfy its constraints:"
+msgstr ""
+
+#: targhooks.cc:2382
+#, c-format
+msgid "created and used with differing settings of '%s'"
+msgstr ""
+
+#: targhooks.cc:2397
+msgid "created and used with different settings of %<-fpic%>"
+msgstr ""
+
+#: targhooks.cc:2399
+msgid "created and used with different settings of %<-fpie%>"
+msgstr ""
+
+#: toplev.cc:315
+#, c-format
+msgid "unrecoverable error"
+msgstr ""
+
+#: toplev.cc:608
+#, c-format
+msgid ""
+"%s%s%s %sversion %s (%s)\n"
+"%s\tcompiled by GNU C version %s, "
+msgstr ""
+
+#: toplev.cc:610
+#, c-format
+msgid "%s%s%s %sversion %s (%s) compiled by CC, "
+msgstr ""
+
+#: toplev.cc:614
+#, c-format
+msgid "GMP version %s, MPFR version %s, MPC version %s, isl version %s\n"
+msgstr ""
+
+#: toplev.cc:616
+#, c-format
+msgid "%s%swarning: %s header version %s differs from library version %s.\n"
+msgstr ""
+
+#: toplev.cc:618
+#, c-format
+msgid "%s%sGGC heuristics: --param ggc-min-expand=%d --param ggc-min-heapsize=%d\n"
+msgstr ""
+
+#: tree-diagnostic-path.cc:342 tree-diagnostic.cc:294 c/c-decl.cc:6534
+#: c/c-typeck.cc:8236 cp/error.cc:1189 c-family/c-pretty-print.cc:446
+#, gcc-internal-format
+msgid "<anonymous>"
+msgstr "<ანონიმური>"
+
+#: c-family/c-format.cc:432
+msgid "format"
+msgstr ""
+
+#: c-family/c-format.cc:433
+msgid "field width specifier"
+msgstr ""
+
+#: c-family/c-format.cc:434
+msgid "field precision specifier"
+msgstr ""
+
+#: c-family/c-format.cc:571 c-family/c-format.cc:595
+#: config/i386/msformat-c.cc:45
+msgid "' ' flag"
+msgstr ""
+
+#: c-family/c-format.cc:571 c-family/c-format.cc:595
+#: config/i386/msformat-c.cc:45
+msgid "the ' ' printf flag"
+msgstr ""
+
+#: c-family/c-format.cc:572 c-family/c-format.cc:596 c-family/c-format.cc:627
+#: c-family/c-format.cc:693 config/i386/msformat-c.cc:46
+msgid "'+' flag"
+msgstr ""
+
+#: c-family/c-format.cc:572 c-family/c-format.cc:596 c-family/c-format.cc:627
+#: config/i386/msformat-c.cc:46
+msgid "the '+' printf flag"
+msgstr ""
+
+#: c-family/c-format.cc:573 c-family/c-format.cc:597 c-family/c-format.cc:628
+#: c-family/c-format.cc:668 config/i386/msformat-c.cc:47
+#: config/i386/msformat-c.cc:82
+msgid "'#' flag"
+msgstr ""
+
+#: c-family/c-format.cc:573 c-family/c-format.cc:597 c-family/c-format.cc:628
+#: config/i386/msformat-c.cc:47
+msgid "the '#' printf flag"
+msgstr ""
+
+#: c-family/c-format.cc:574 c-family/c-format.cc:598 c-family/c-format.cc:666
+#: config/i386/msformat-c.cc:48
+msgid "'0' flag"
+msgstr ""
+
+#: c-family/c-format.cc:574 c-family/c-format.cc:598
+#: config/i386/msformat-c.cc:48
+msgid "the '0' printf flag"
+msgstr ""
+
+#: c-family/c-format.cc:575 c-family/c-format.cc:599 c-family/c-format.cc:665
+#: c-family/c-format.cc:696 config/i386/msformat-c.cc:49
+msgid "'-' flag"
+msgstr ""
+
+#: c-family/c-format.cc:575 c-family/c-format.cc:599
+#: config/i386/msformat-c.cc:49
+msgid "the '-' printf flag"
+msgstr ""
+
+#: c-family/c-format.cc:576 c-family/c-format.cc:648
+#: config/i386/msformat-c.cc:50 config/i386/msformat-c.cc:70
+msgid "''' flag"
+msgstr ""
+
+#: c-family/c-format.cc:576 config/i386/msformat-c.cc:50
+msgid "the ''' printf flag"
+msgstr ""
+
+#: c-family/c-format.cc:577 c-family/c-format.cc:649
+msgid "'I' flag"
+msgstr ""
+
+#: c-family/c-format.cc:577
+msgid "the 'I' printf flag"
+msgstr ""
+
+#: c-family/c-format.cc:578 c-family/c-format.cc:600 c-family/c-format.cc:646
+#: c-family/c-format.cc:669 c-family/c-format.cc:697 config/sol2-c.cc:43
+#: config/i386/msformat-c.cc:51 config/i386/msformat-c.cc:68
+msgid "field width"
+msgstr ""
+
+#: c-family/c-format.cc:578 c-family/c-format.cc:600 config/sol2-c.cc:43
+#: config/i386/msformat-c.cc:51
+msgid "field width in printf format"
+msgstr ""
+
+#: c-family/c-format.cc:579 c-family/c-format.cc:601 c-family/c-format.cc:630
+#: config/i386/msformat-c.cc:52
+msgid "precision"
+msgstr "სიზუსტე"
+
+#: c-family/c-format.cc:579 c-family/c-format.cc:601 c-family/c-format.cc:630
+#: config/i386/msformat-c.cc:52
+msgid "precision in printf format"
+msgstr ""
+
+#: c-family/c-format.cc:580 c-family/c-format.cc:602 c-family/c-format.cc:631
+#: c-family/c-format.cc:647 c-family/c-format.cc:700 config/sol2-c.cc:44
+#: config/i386/msformat-c.cc:53 config/i386/msformat-c.cc:69
+msgid "length modifier"
+msgstr ""
+
+#: c-family/c-format.cc:580 c-family/c-format.cc:602 c-family/c-format.cc:631
+#: config/sol2-c.cc:44 config/i386/msformat-c.cc:53
+msgid "length modifier in printf format"
+msgstr ""
+
+#: c-family/c-format.cc:629
+msgid "'q' flag"
+msgstr ""
+
+#: c-family/c-format.cc:629
+msgid "the 'q' diagnostic flag"
+msgstr ""
+
+#: c-family/c-format.cc:643 config/i386/msformat-c.cc:66
+msgid "assignment suppression"
+msgstr ""
+
+#: c-family/c-format.cc:643 config/i386/msformat-c.cc:66
+msgid "the assignment suppression scanf feature"
+msgstr ""
+
+#: c-family/c-format.cc:644 config/i386/msformat-c.cc:67
+msgid "'a' flag"
+msgstr ""
+
+#: c-family/c-format.cc:644 config/i386/msformat-c.cc:67
+msgid "the 'a' scanf flag"
+msgstr ""
+
+#: c-family/c-format.cc:645
+msgid "'m' flag"
+msgstr ""
+
+#: c-family/c-format.cc:645
+msgid "the 'm' scanf flag"
+msgstr ""
+
+#: c-family/c-format.cc:646 config/i386/msformat-c.cc:68
+msgid "field width in scanf format"
+msgstr ""
+
+#: c-family/c-format.cc:647 config/i386/msformat-c.cc:69
+msgid "length modifier in scanf format"
+msgstr ""
+
+#: c-family/c-format.cc:648 config/i386/msformat-c.cc:70
+msgid "the ''' scanf flag"
+msgstr ""
+
+#: c-family/c-format.cc:649
+msgid "the 'I' scanf flag"
+msgstr ""
+
+#: c-family/c-format.cc:664
+msgid "'_' flag"
+msgstr ""
+
+#: c-family/c-format.cc:664
+msgid "the '_' strftime flag"
+msgstr ""
+
+#: c-family/c-format.cc:665
+msgid "the '-' strftime flag"
+msgstr ""
+
+#: c-family/c-format.cc:666
+msgid "the '0' strftime flag"
+msgstr ""
+
+#: c-family/c-format.cc:667 c-family/c-format.cc:692
+msgid "'^' flag"
+msgstr ""
+
+#: c-family/c-format.cc:667
+msgid "the '^' strftime flag"
+msgstr ""
+
+#: c-family/c-format.cc:668 config/i386/msformat-c.cc:82
+msgid "the '#' strftime flag"
+msgstr ""
+
+#: c-family/c-format.cc:669
+msgid "field width in strftime format"
+msgstr ""
+
+#: c-family/c-format.cc:670
+msgid "'E' modifier"
+msgstr ""
+
+#: c-family/c-format.cc:670
+msgid "the 'E' strftime modifier"
+msgstr ""
+
+#: c-family/c-format.cc:671
+msgid "'O' modifier"
+msgstr ""
+
+#: c-family/c-format.cc:671
+msgid "the 'O' strftime modifier"
+msgstr ""
+
+#: c-family/c-format.cc:672 c-family/c-format.cc:673
+msgid "the 'O' modifier"
+msgstr ""
+
+#: c-family/c-format.cc:691
+msgid "fill character"
+msgstr ""
+
+#: c-family/c-format.cc:691
+msgid "fill character in strfmon format"
+msgstr ""
+
+#: c-family/c-format.cc:692
+msgid "the '^' strfmon flag"
+msgstr ""
+
+#: c-family/c-format.cc:693
+msgid "the '+' strfmon flag"
+msgstr ""
+
+#: c-family/c-format.cc:694
+msgid "'(' flag"
+msgstr ""
+
+#: c-family/c-format.cc:694
+msgid "the '(' strfmon flag"
+msgstr ""
+
+#: c-family/c-format.cc:695
+msgid "'!' flag"
+msgstr ""
+
+#: c-family/c-format.cc:695
+msgid "the '!' strfmon flag"
+msgstr ""
+
+#: c-family/c-format.cc:696
+msgid "the '-' strfmon flag"
+msgstr ""
+
+#: c-family/c-format.cc:697
+msgid "field width in strfmon format"
+msgstr ""
+
+#: c-family/c-format.cc:698
+msgid "left precision"
+msgstr ""
+
+#: c-family/c-format.cc:698
+msgid "left precision in strfmon format"
+msgstr ""
+
+#: c-family/c-format.cc:699
+msgid "right precision"
+msgstr ""
+
+#: c-family/c-format.cc:699
+msgid "right precision in strfmon format"
+msgstr ""
+
+#: c-family/c-format.cc:700
+msgid "length modifier in strfmon format"
+msgstr ""
+
+#. Handle deferred options from command-line.
+#: c-family/c-opts.cc:1588 fortran/cpp.cc:621
+msgid "<command-line>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:11980 config/loongarch/loongarch.cc:6155
+#, c-format
+msgid "unsupported operand for code '%c'"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:11989 config/aarch64/aarch64.cc:12002
+#: config/aarch64/aarch64.cc:12014 config/aarch64/aarch64.cc:12025
+#: config/aarch64/aarch64.cc:12041 config/aarch64/aarch64.cc:12055
+#: config/aarch64/aarch64.cc:12075 config/aarch64/aarch64.cc:12157
+#: config/aarch64/aarch64.cc:12168 config/aarch64/aarch64.cc:12182
+#: config/aarch64/aarch64.cc:12408 config/aarch64/aarch64.cc:12421
+#: config/aarch64/aarch64.cc:12438 config/pru/pru.cc:1794
+#: config/pru/pru.cc:1805 config/pru/pru.cc:1877
+#, c-format
+msgid "invalid operand for '%%%c'"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:12093 config/aarch64/aarch64.cc:12104
+#: config/aarch64/aarch64.cc:12268 config/aarch64/aarch64.cc:12279
+#: config/riscv/riscv.cc:6170 config/riscv/riscv.cc:6178
+#: config/riscv/riscv.cc:6185 config/riscv/riscv.cc:6189
+#: config/riscv/riscv.cc:6231 config/riscv/riscv.cc:6249
+#, c-format
+msgid "invalid vector constant"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:12118
+#, c-format
+msgid "incompatible floating point / vector register operand for '%%%c'"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:12130
+#, c-format
+msgid "incompatible operand for '%%%c'"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:12150
+#, c-format
+msgid "incompatible register operand for '%%%c'"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:12215 config/arm/arm.cc:24876
+#, c-format
+msgid "missing operand"
+msgstr "აკლია ოპერანდი"
+
+#: config/aarch64/aarch64.cc:12305
+#, c-format
+msgid "invalid constant"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:12308
+#, c-format
+msgid "invalid operand"
+msgstr "არასწორი ოპერანდი"
+
+#: config/aarch64/aarch64.cc:12446 config/aarch64/aarch64.cc:12451
+#, c-format
+msgid "invalid operand prefix '%%%c'"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:12471
+#, c-format
+msgid "invalid address mode"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:29016
+msgid "cannot combine GNU and SVE vectors in a binary operation"
+msgstr ""
+
+#: config/alpha/alpha.cc:5094 config/i386/i386.cc:14193
+#: config/rs6000/rs6000.cc:14631 config/sparc/sparc.cc:9384
+#, c-format
+msgid "'%%&' used without any local dynamic TLS references"
+msgstr ""
+
+#: config/alpha/alpha.cc:5152 config/bfin/bfin.cc:1428
+#, c-format
+msgid "invalid %%J value"
+msgstr ""
+
+#: config/alpha/alpha.cc:5182 config/ia64/ia64.cc:5588 config/or1k/or1k.cc:1252
+#, c-format
+msgid "invalid %%r value"
+msgstr ""
+
+#: config/alpha/alpha.cc:5192 config/ia64/ia64.cc:5542
+#: config/rs6000/rs6000.cc:14326 config/xtensa/xtensa.cc:3066
+#, c-format
+msgid "invalid %%R value"
+msgstr ""
+
+#: config/alpha/alpha.cc:5198 config/rs6000/rs6000.cc:14246
+#: config/xtensa/xtensa.cc:3039
+#, c-format
+msgid "invalid %%N value"
+msgstr ""
+
+#: config/alpha/alpha.cc:5206 config/rs6000/rs6000.cc:14274
+#, c-format
+msgid "invalid %%P value"
+msgstr ""
+
+#: config/alpha/alpha.cc:5214
+#, c-format
+msgid "invalid %%h value"
+msgstr ""
+
+#: config/alpha/alpha.cc:5222 config/xtensa/xtensa.cc:3059
+#, c-format
+msgid "invalid %%L value"
+msgstr ""
+
+#: config/alpha/alpha.cc:5241
+#, c-format
+msgid "invalid %%m value"
+msgstr ""
+
+#: config/alpha/alpha.cc:5247
+#, c-format
+msgid "invalid %%M value"
+msgstr ""
+
+#: config/alpha/alpha.cc:5284
+#, c-format
+msgid "invalid %%U value"
+msgstr ""
+
+#: config/alpha/alpha.cc:5292 config/rs6000/rs6000.cc:14334
+#, c-format
+msgid "invalid %%s value"
+msgstr ""
+
+#: config/alpha/alpha.cc:5303
+#, c-format
+msgid "invalid %%C value"
+msgstr ""
+
+#: config/alpha/alpha.cc:5340 config/rs6000/rs6000.cc:14110
+#, c-format
+msgid "invalid %%E value"
+msgstr ""
+
+#: config/alpha/alpha.cc:5365 config/alpha/alpha.cc:5415
+#, c-format
+msgid "unknown relocation unspec"
+msgstr ""
+
+#: config/alpha/alpha.cc:5374 config/gcn/gcn.cc:7419 config/gcn/gcn.cc:7428
+#: config/gcn/gcn.cc:7488 config/gcn/gcn.cc:7496 config/gcn/gcn.cc:7512
+#: config/gcn/gcn.cc:7530 config/gcn/gcn.cc:7581 config/gcn/gcn.cc:7700
+#: config/gcn/gcn.cc:7817 config/rs6000/rs6000.cc:14636
+#, c-format
+msgid "invalid %%xn code"
+msgstr ""
+
+#: config/alpha/alpha.cc:5480
+#, c-format
+msgid "invalid operand address"
+msgstr ""
+
+#: config/arc/arc.cc:4901
+#, c-format
+msgid "invalid operand to %%Z code"
+msgstr ""
+
+#: config/arc/arc.cc:4909
+#, c-format
+msgid "invalid operand to %%z code"
+msgstr ""
+
+#: config/arc/arc.cc:4917
+#, c-format
+msgid "invalid operands to %%c code"
+msgstr ""
+
+#: config/arc/arc.cc:4925
+#, c-format
+msgid "invalid operand to %%M code"
+msgstr ""
+
+#: config/arc/arc.cc:4933 config/m32r/m32r.cc:2088
+#, c-format
+msgid "invalid operand to %%p code"
+msgstr ""
+
+#: config/arc/arc.cc:4941
+#, c-format
+msgid "invalid operand for %%s code"
+msgstr ""
+
+#: config/arc/arc.cc:4959
+#, c-format
+msgid "invalid operand for %%N code"
+msgstr ""
+
+#: config/arc/arc.cc:4972
+#, c-format
+msgid "invalid operand for %%N or %%S code"
+msgstr ""
+
+#: config/arc/arc.cc:4994 config/m32r/m32r.cc:2081
+#, c-format
+msgid "invalid operand to %%s code"
+msgstr ""
+
+#: config/arc/arc.cc:5114 config/m32r/m32r.cc:2114
+#, c-format
+msgid "invalid operand to %%R code"
+msgstr ""
+
+#: config/arc/arc.cc:5190 config/m32r/m32r.cc:2137
+#, c-format
+msgid "invalid operand to %%H/%%L code"
+msgstr ""
+
+#: config/arc/arc.cc:5258 config/m32r/m32r.cc:2208
+#, c-format
+msgid "invalid operand to %%U code"
+msgstr ""
+
+#: config/arc/arc.cc:5270
+#, c-format
+msgid "invalid operand to %%V code"
+msgstr ""
+
+#: config/arc/arc.cc:5320
+#, c-format
+msgid "invalid operand to %%O code"
+msgstr ""
+
+#. Unknown flag.
+#. Undocumented flag.
+#: config/arc/arc.cc:5343 config/epiphany/epiphany.cc:1309
+#: config/m32r/m32r.cc:2235 config/nds32/nds32.cc:3519
+#: config/sparc/sparc.cc:9663
+#, c-format
+msgid "invalid operand output code"
+msgstr ""
+
+#: config/arc/arc.cc:6396
+#, c-format
+msgid "invalid UNSPEC as operand: %d"
+msgstr ""
+
+#: config/arc/arc.cc:6612
+msgid "unrecognized supposed constant"
+msgstr ""
+
+#: config/arm/arm.cc:21119 config/arm/arm.cc:21144 config/arm/arm.cc:21154
+#: config/arm/arm.cc:21163 config/arm/arm.cc:21172
+#, c-format
+msgid "invalid shift operand"
+msgstr ""
+
+#: config/arm/arm.cc:24126 config/arm/arm.cc:24144
+#, c-format
+msgid "predicated Thumb instruction"
+msgstr ""
+
+#: config/arm/arm.cc:24132
+#, c-format
+msgid "predicated instruction in conditional sequence"
+msgstr ""
+
+#: config/arm/arm.cc:24253 config/arm/arm.cc:24266 config/arm/arm.cc:24291
+#: config/nios2/nios2.cc:3085
+#, c-format
+msgid "Unsupported operand for code '%c'"
+msgstr ""
+
+#: config/arm/arm.cc:24368 config/arm/arm.cc:24390 config/arm/arm.cc:24400
+#: config/arm/arm.cc:24410 config/arm/arm.cc:24420 config/arm/arm.cc:24459
+#: config/arm/arm.cc:24477 config/arm/arm.cc:24495 config/arm/arm.cc:24522
+#: config/arm/arm.cc:24537 config/arm/arm.cc:24564 config/arm/arm.cc:24571
+#: config/arm/arm.cc:24589 config/arm/arm.cc:24596 config/arm/arm.cc:24604
+#: config/arm/arm.cc:24625 config/arm/arm.cc:24632 config/arm/arm.cc:24823
+#: config/arm/arm.cc:24830 config/arm/arm.cc:24857 config/arm/arm.cc:24864
+#: config/bfin/bfin.cc:1441 config/bfin/bfin.cc:1448 config/bfin/bfin.cc:1455
+#: config/bfin/bfin.cc:1462 config/bfin/bfin.cc:1471 config/bfin/bfin.cc:1478
+#: config/bfin/bfin.cc:1485 config/bfin/bfin.cc:1492 config/nds32/nds32.cc:3545
+#, c-format
+msgid "invalid operand for code '%c'"
+msgstr ""
+
+#: config/arm/arm.cc:24472
+#, c-format
+msgid "instruction never executed"
+msgstr ""
+
+#. Former Maverick support, removed after GCC-4.7.
+#: config/arm/arm.cc:24513
+#, c-format
+msgid "obsolete Maverick format code '%c'"
+msgstr ""
+
+#: config/arm/arm.cc:34536
+msgid "invalid conversion from type %<bfloat16_t%>"
+msgstr ""
+
+#: config/arm/arm.cc:34538
+msgid "invalid conversion to type %<bfloat16_t%>"
+msgstr ""
+
+#: config/arm/arm.cc:34553 config/arm/arm.cc:34569
+msgid "operation not permitted on type %<bfloat16_t%>"
+msgstr ""
+
+#: config/avr/avr.cc:3616
+#, c-format
+msgid "address operand requires constraint for X, Y, or Z register"
+msgstr ""
+
+#: config/avr/avr.cc:3799
+msgid "operands to %T/%t must be reg + const_int:"
+msgstr ""
+
+#: config/avr/avr.cc:3849 config/avr/avr.cc:3916
+msgid "bad address, not an I/O address:"
+msgstr ""
+
+#: config/avr/avr.cc:3858
+msgid "bad address, not a constant:"
+msgstr ""
+
+#: config/avr/avr.cc:3876 config/avr/avr.cc:3883
+msgid "bad address, not (reg+disp):"
+msgstr ""
+
+#: config/avr/avr.cc:3890
+msgid "bad address, not post_inc or pre_dec:"
+msgstr ""
+
+#: config/avr/avr.cc:3902
+msgid "internal compiler error.  Bad address:"
+msgstr ""
+
+#: config/avr/avr.cc:3935
+#, c-format
+msgid "Unsupported code '%c' for fixed-point:"
+msgstr ""
+
+#: config/avr/avr.cc:3954
+msgid "internal compiler error.  Unknown mode:"
+msgstr ""
+
+#: config/avr/avr.cc:4827 config/avr/avr.cc:5787 config/avr/avr.cc:6234
+msgid "invalid insn:"
+msgstr ""
+
+#: config/avr/avr.cc:4898 config/avr/avr.cc:5009 config/avr/avr.cc:5067
+#: config/avr/avr.cc:5119 config/avr/avr.cc:5138 config/avr/avr.cc:5330
+#: config/avr/avr.cc:5638 config/avr/avr.cc:5923 config/avr/avr.cc:6127
+#: config/avr/avr.cc:6291 config/avr/avr.cc:6384 config/avr/avr.cc:6582
+msgid "incorrect insn:"
+msgstr ""
+
+#: config/avr/avr.cc:5154 config/avr/avr.cc:5429 config/avr/avr.cc:5709
+#: config/avr/avr.cc:5995 config/avr/avr.cc:6173 config/avr/avr.cc:6440
+#: config/avr/avr.cc:6640
+msgid "unknown move insn:"
+msgstr ""
+
+#: config/avr/avr.cc:7407
+msgid "bad shift insn:"
+msgstr ""
+
+#: config/avr/avr.cc:7515 config/avr/avr.cc:7998 config/avr/avr.cc:8415
+msgid "internal compiler error.  Incorrect shift:"
+msgstr ""
+
+#: config/avr/avr.cc:10239
+msgid "unsupported fixed-point conversion"
+msgstr ""
+
+#: config/avr/avr.cc:11614
+msgid "variable"
+msgstr "ცვლადი"
+
+#: config/avr/avr.cc:11619
+msgid "function parameter"
+msgstr "ფუნქციის პარამეტრი"
+
+#: config/avr/avr.cc:11624
+msgid "structure field"
+msgstr ""
+
+#: config/avr/avr.cc:11630
+msgid "return type of function"
+msgstr ""
+
+#: config/avr/avr.cc:11635
+msgid "pointer"
+msgstr ""
+
+#: config/avr/driver-avr.cc:50
+#, c-format
+msgid ""
+"Running spec function '%s' with %d args\n"
+"\n"
+msgstr ""
+
+#: config/bfin/bfin.cc:1390
+#, c-format
+msgid "invalid %%j value"
+msgstr ""
+
+#: config/bfin/bfin.cc:1583 config/c6x/c6x.cc:2279
+#, c-format
+msgid "invalid const_double operand"
+msgstr ""
+
+#: config/bpf/bpf.cc:929
+msgid "invalid address in operand"
+msgstr ""
+
+#. Fallthrough.
+#: config/bpf/bpf.cc:936
+msgid "unsupported operand"
+msgstr ""
+
+#. Format punctuators via %s to avoid -Wformat-diag.
+#: config/cris/cris.cc:779 config/ft32/ft32.cc:110 config/moxie/moxie.cc:108
+#: final.cc:3187 final.cc:3189 fold-const.cc:348 gcc.cc:6261 gcc.cc:6275
+#: rtl-error.cc:101 toplev.cc:319 cp/logic.cc:312 cp/logic.cc:314
+#: cp/typeck.cc:7748 d/d-convert.cc:237 go/go-gcc-diagnostics.cc:28
+#: go/go-gcc-diagnostics.cc:37 go/go-gcc-diagnostics.cc:45
+#: go/go-gcc-diagnostics.cc:53 lto/lto-object.cc:180 lto/lto-object.cc:277
+#: lto/lto-object.cc:334 lto/lto-object.cc:358 m2/gm2-gcc/m2linemap.cc:182
+#: m2/gm2-gcc/m2linemap.cc:253 m2/gm2-gcc/m2linemap.cc:362
+#: rust/rust-diagnostics.cc:164 rust/rust-diagnostics.cc:182
+#: rust/rust-diagnostics.cc:243 rust/rust-diagnostics.cc:266
+#: rust/rust-diagnostics.cc:287 rust/rust-diagnostics.cc:306
+#: rust/rust-diagnostics.cc:322 rust/rust-diagnostics.cc:338
+#: rust/rust-diagnostics.cc:357 rust/rust-diagnostics.cc:373
+#, gcc-internal-format, gfc-internal-format
+msgid "%s"
+msgstr ""
+
+#: config/cris/cris.cc:830
+msgid "unexpected index-type in cris_print_index"
+msgstr ""
+
+#: config/cris/cris.cc:844
+msgid "unexpected base-type in cris_print_base"
+msgstr ""
+
+#: config/cris/cris.cc:899
+msgid "invalid operand for 'b' modifier"
+msgstr ""
+
+#: config/cris/cris.cc:916
+msgid "invalid operand for 'o' modifier"
+msgstr ""
+
+#: config/cris/cris.cc:935
+msgid "invalid operand for 'O' modifier"
+msgstr ""
+
+#: config/cris/cris.cc:968
+msgid "invalid operand for 'p' modifier"
+msgstr ""
+
+#: config/cris/cris.cc:1007
+msgid "invalid operand for 'z' modifier"
+msgstr ""
+
+#: config/cris/cris.cc:1054 config/cris/cris.cc:1088
+msgid "invalid operand for 'H' modifier"
+msgstr ""
+
+#: config/cris/cris.cc:1064
+msgid "bad register"
+msgstr ""
+
+#: config/cris/cris.cc:1108
+msgid "invalid operand for 'e' modifier"
+msgstr ""
+
+#: config/cris/cris.cc:1125
+msgid "invalid operand for 'm' modifier"
+msgstr ""
+
+#: config/cris/cris.cc:1150
+msgid "invalid operand for 'A' modifier"
+msgstr ""
+
+#: config/cris/cris.cc:1205
+msgid "invalid operand for 'D' modifier"
+msgstr ""
+
+#: config/cris/cris.cc:1222 config/cris/cris.cc:1227
+msgid "invalid operand for 'T' modifier"
+msgstr ""
+
+#: config/cris/cris.cc:1238 config/ft32/ft32.cc:236 config/moxie/moxie.cc:178
+msgid "invalid operand modifier letter"
+msgstr ""
+
+#: config/cris/cris.cc:1290
+msgid "unexpected multiplicative operand"
+msgstr ""
+
+#: config/cris/cris.cc:1310 config/ft32/ft32.cc:259 config/moxie/moxie.cc:203
+msgid "unexpected operand"
+msgstr ""
+
+#: config/cris/cris.cc:1349 config/cris/cris.cc:1359
+msgid "unrecognized address"
+msgstr ""
+
+#: config/cris/cris.cc:2591 config/cris/cris.cc:2644
+msgid "unexpected side-effects in address"
+msgstr ""
+
+#: config/fr30/fr30.cc:513
+#, c-format
+msgid "fr30_print_operand_address: unhandled address"
+msgstr ""
+
+#: config/fr30/fr30.cc:537
+#, c-format
+msgid "fr30_print_operand: unrecognized %%p code"
+msgstr ""
+
+#: config/fr30/fr30.cc:557
+#, c-format
+msgid "fr30_print_operand: unrecognized %%b code"
+msgstr ""
+
+#: config/fr30/fr30.cc:578
+#, c-format
+msgid "fr30_print_operand: unrecognized %%B code"
+msgstr ""
+
+#: config/fr30/fr30.cc:586
+#, c-format
+msgid "fr30_print_operand: invalid operand to %%A code"
+msgstr ""
+
+#: config/fr30/fr30.cc:603
+#, c-format
+msgid "fr30_print_operand: invalid %%x code"
+msgstr ""
+
+#: config/fr30/fr30.cc:610
+#, c-format
+msgid "fr30_print_operand: invalid %%F code"
+msgstr ""
+
+#: config/fr30/fr30.cc:627
+#, c-format
+msgid "fr30_print_operand: unknown code"
+msgstr ""
+
+#: config/fr30/fr30.cc:655 config/fr30/fr30.cc:664 config/fr30/fr30.cc:675
+#: config/fr30/fr30.cc:688
+#, c-format
+msgid "fr30_print_operand: unhandled MEM"
+msgstr ""
+
+#: config/frv/frv.cc:2492
+msgid "bad insn to frv_print_operand_address:"
+msgstr ""
+
+#: config/frv/frv.cc:2503
+msgid "bad register to frv_print_operand_memory_reference_reg:"
+msgstr ""
+
+#: config/frv/frv.cc:2542 config/frv/frv.cc:2552 config/frv/frv.cc:2561
+#: config/frv/frv.cc:2582 config/frv/frv.cc:2587
+msgid "bad insn to frv_print_operand_memory_reference:"
+msgstr ""
+
+#: config/frv/frv.cc:2672
+#, c-format
+msgid "bad condition code"
+msgstr ""
+
+#: config/frv/frv.cc:2746
+msgid "bad insn in frv_print_operand, bad const_double"
+msgstr ""
+
+#: config/frv/frv.cc:2807
+msgid "bad insn to frv_print_operand, 'e' modifier:"
+msgstr ""
+
+#: config/frv/frv.cc:2815
+msgid "bad insn to frv_print_operand, 'F' modifier:"
+msgstr ""
+
+#: config/frv/frv.cc:2831
+msgid "bad insn to frv_print_operand, 'f' modifier:"
+msgstr ""
+
+#: config/frv/frv.cc:2845
+msgid "bad insn to frv_print_operand, 'g' modifier:"
+msgstr ""
+
+#: config/frv/frv.cc:2893
+msgid "bad insn to frv_print_operand, 'L' modifier:"
+msgstr ""
+
+#: config/frv/frv.cc:2906
+msgid "bad insn to frv_print_operand, 'M/N' modifier:"
+msgstr ""
+
+#: config/frv/frv.cc:2927
+msgid "bad insn to frv_print_operand, 'O' modifier:"
+msgstr ""
+
+#: config/frv/frv.cc:2945
+msgid "bad insn to frv_print_operand, P modifier:"
+msgstr ""
+
+#: config/frv/frv.cc:2965
+msgid "bad insn in frv_print_operand, z case"
+msgstr ""
+
+#: config/frv/frv.cc:2996
+msgid "bad insn in frv_print_operand, 0 case"
+msgstr ""
+
+#: config/frv/frv.cc:3001
+msgid "frv_print_operand: unknown code"
+msgstr ""
+
+#: config/frv/frv.cc:4375
+msgid "bad output_move_single operand"
+msgstr ""
+
+#: config/frv/frv.cc:4502
+msgid "bad output_move_double operand"
+msgstr ""
+
+#: config/frv/frv.cc:4644
+msgid "bad output_condmove_single operand"
+msgstr ""
+
+#: config/gcn/gcn.cc:7101 config/gcn/gcn.cc:7121 config/gcn/gcn.cc:7125
+#: config/gcn/gcn.cc:7461 config/gcn/gcn.cc:7472 config/gcn/gcn.cc:7475
+#, c-format
+msgid "bad ADDR_SPACE_GLOBAL address"
+msgstr ""
+
+#: config/gcn/gcn.cc:7241 config/gcn/gcn.cc:7264 config/gcn/gcn.cc:7296
+#: config/gcn/gcn.cc:7312 config/gcn/gcn.cc:7327 config/gcn/gcn.cc:7346
+#: config/gcn/gcn.cc:7410 config/gcn/gcn.cc:7606 config/gcn/gcn.cc:7721
+#, c-format
+msgid "invalid operand %%xn code"
+msgstr ""
+
+#: config/gcn/gcn.cc:7709
+#, c-format
+msgid "operand %%xn code invalid for QImode"
+msgstr ""
+
+#: config/gcn/gcn.cc:7797
+#, c-format
+msgid "invalid fp constant"
+msgstr ""
+
+#: config/h8300/h8300.cc:1628 config/h8300/h8300.cc:1636
+#: config/h8300/h8300.cc:1644 config/h8300/h8300.cc:1652
+#: config/h8300/h8300.cc:1660 config/h8300/h8300.cc:1668
+#, c-format
+msgid "Expected register or constant integer."
+msgstr ""
+
+#: config/i386/i386.cc:13011
+#, c-format
+msgid "invalid UNSPEC as operand"
+msgstr ""
+
+#: config/i386/i386.cc:13550
+#, c-format
+msgid "invalid use of register '%s'"
+msgstr ""
+
+#: config/i386/i386.cc:13555
+#, c-format
+msgid "invalid use of asm flag output"
+msgstr ""
+
+#: config/i386/i386.cc:13788
+#, c-format
+msgid "invalid operand size for operand code 'O'"
+msgstr ""
+
+#: config/i386/i386.cc:13823
+#, c-format
+msgid "invalid operand size for operand code 'z'"
+msgstr ""
+
+#: config/i386/i386.cc:13898
+#, c-format
+msgid "invalid operand type used with operand code '%c'"
+msgstr ""
+
+#: config/i386/i386.cc:13903
+#, c-format
+msgid "invalid operand size for operand code '%c'"
+msgstr ""
+
+#: config/i386/i386.cc:13981
+#, c-format
+msgid "operand is not a condition code, invalid operand code 'Y'"
+msgstr ""
+
+#: config/i386/i386.cc:14060
+#, c-format
+msgid "operand is not a condition code, invalid operand code 'D'"
+msgstr ""
+
+#: config/i386/i386.cc:14078
+#, c-format
+msgid "operand is not a condition code, invalid operand code '%c'"
+msgstr ""
+
+#: config/i386/i386.cc:14091
+#, c-format
+msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
+msgstr ""
+
+#: config/i386/i386.cc:14106
+#, c-format
+msgid "operand is not an integer, invalid operand code 'K'"
+msgstr ""
+
+#: config/i386/i386.cc:14134
+#, c-format
+msgid "operand is not a specific integer, invalid operand code 'r'"
+msgstr ""
+
+#: config/i386/i386.cc:14152
+#, c-format
+msgid "operand is not an integer, invalid operand code 'R'"
+msgstr ""
+
+#: config/i386/i386.cc:14175
+#, c-format
+msgid "operand is not a specific integer, invalid operand code 'R'"
+msgstr ""
+
+#: config/i386/i386.cc:14268
+#, c-format
+msgid "invalid operand code '%c'"
+msgstr ""
+
+#: config/i386/i386.cc:14330 config/i386/i386.cc:14719
+#, c-format
+msgid "invalid constraints for operand"
+msgstr ""
+
+#: config/i386/i386.cc:14431
+#, c-format
+msgid "invalid vector immediate"
+msgstr ""
+
+#: config/i386/i386.cc:17551
+msgid "unknown insn mode"
+msgstr ""
+
+#: config/i386/i386.cc:23777
+msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
+msgstr ""
+
+#: config/i386/i386.cc:23780
+msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
+msgstr ""
+
+#: config/i386/i386.cc:23783
+msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
+msgstr ""
+
+#: config/i386/i386.cc:23786
+msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
+msgstr ""
+
+#: config/i386/i386.cc:23824 config/i386/i386.cc:23849
+msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
+msgstr ""
+
+#: config/i386/i386.cc:23827 config/i386/i386.cc:23853
+msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
+msgstr ""
+
+#: config/ia64/ia64.cc:5470
+#, c-format
+msgid "invalid %%G mode"
+msgstr ""
+
+#: config/ia64/ia64.cc:5641
+#, c-format
+msgid "ia64_print_operand: unknown code"
+msgstr ""
+
+#: config/ia64/ia64.cc:11265
+msgid "invalid conversion from %<__fpreg%>"
+msgstr ""
+
+#: config/ia64/ia64.cc:11268
+msgid "invalid conversion to %<__fpreg%>"
+msgstr ""
+
+#: config/ia64/ia64.cc:11281 config/ia64/ia64.cc:11292
+msgid "invalid operation on %<__fpreg%>"
+msgstr ""
+
+#: config/iq2000/iq2000.cc:3123
+#, c-format
+msgid "invalid %%P operand"
+msgstr ""
+
+#: config/iq2000/iq2000.cc:3131 config/rs6000/rs6000.cc:14264
+#, c-format
+msgid "invalid %%p value"
+msgstr ""
+
+#: config/iq2000/iq2000.cc:3190
+#, c-format
+msgid "invalid use of %%d, %%x, or %%X"
+msgstr ""
+
+#: config/lm32/lm32.cc:524
+#, c-format
+msgid "only 0.0 can be loaded as an immediate"
+msgstr ""
+
+#: config/lm32/lm32.cc:594
+msgid "bad operand"
+msgstr ""
+
+#: config/lm32/lm32.cc:606
+msgid "can't use non gp relative absolute address"
+msgstr ""
+
+#: config/lm32/lm32.cc:610
+msgid "invalid addressing mode"
+msgstr ""
+
+#: config/loongarch/loongarch.cc:5887 config/loongarch/loongarch.cc:5909
+#: config/loongarch/loongarch.cc:6310 config/mips/mips.cc:9248
+#: config/mips/mips.cc:9275 config/mips/mips.cc:9458
+#, c-format
+msgid "'%%%c' is not a valid operand prefix"
+msgstr ""
+
+#: config/loongarch/loongarch.cc:6147 config/loongarch/loongarch.cc:6167
+#: config/loongarch/loongarch.cc:6213 config/loongarch/loongarch.cc:6220
+#: config/loongarch/loongarch.cc:6267 config/loongarch/loongarch.cc:6270
+#: config/loongarch/loongarch.cc:6282 config/loongarch/loongarch.cc:6289
+#: config/loongarch/loongarch.cc:6299 config/loongarch/loongarch.cc:6302
+#: config/loongarch/loongarch.cc:6323 config/loongarch/loongarch.cc:6330
+#: config/loongarch/loongarch.cc:6357 config/loongarch/loongarch.cc:6368
+#: config/loongarch/loongarch.cc:6383 config/loongarch/loongarch.cc:6392
+#: config/mips/mips.cc:9347 config/mips/mips.cc:9354 config/mips/mips.cc:9361
+#: config/mips/mips.cc:9368 config/mips/mips.cc:9381 config/mips/mips.cc:9388
+#: config/mips/mips.cc:9398 config/mips/mips.cc:9401 config/mips/mips.cc:9413
+#: config/mips/mips.cc:9416 config/mips/mips.cc:9476 config/mips/mips.cc:9483
+#: config/mips/mips.cc:9504 config/mips/mips.cc:9519 config/mips/mips.cc:9538
+#: config/mips/mips.cc:9547 config/riscv/riscv.cc:5974
+#: config/riscv/riscv.cc:6349 config/riscv/riscv.cc:6355
+#: config/riscv/riscv.cc:6371 config/riscv/riscv.cc:6382
+#, c-format
+msgid "invalid use of '%%%c'"
+msgstr ""
+
+#: config/m32r/m32r.cc:2146
+msgid "bad insn for 'A'"
+msgstr ""
+
+#: config/m32r/m32r.cc:2193
+#, c-format
+msgid "invalid operand to %%T/%%B code"
+msgstr ""
+
+#: config/m32r/m32r.cc:2216
+#, c-format
+msgid "invalid operand to %%N code"
+msgstr ""
+
+#: config/m32r/m32r.cc:2249
+msgid "pre-increment address is not a register"
+msgstr ""
+
+#: config/m32r/m32r.cc:2256
+msgid "pre-decrement address is not a register"
+msgstr ""
+
+#: config/m32r/m32r.cc:2263
+msgid "post-increment address is not a register"
+msgstr ""
+
+#: config/m32r/m32r.cc:2338 config/m32r/m32r.cc:2353
+#: config/rs6000/rs6000.cc:20989
+msgid "bad address"
+msgstr "ცუდი მისამართი"
+
+#: config/m32r/m32r.cc:2358
+msgid "lo_sum not of register"
+msgstr ""
+
+#: config/microblaze/microblaze.cc:2299
+#, c-format
+msgid "unknown punctuation '%c'"
+msgstr ""
+
+#: config/microblaze/microblaze.cc:2308
+#, c-format
+msgid "null pointer"
+msgstr ""
+
+#: config/microblaze/microblaze.cc:2343
+#, c-format
+msgid "PRINT_OPERAND, invalid insn for %%C"
+msgstr ""
+
+#: config/microblaze/microblaze.cc:2372
+#, c-format
+msgid "PRINT_OPERAND, invalid insn for %%N"
+msgstr ""
+
+#: config/microblaze/microblaze.cc:2392 config/microblaze/microblaze.cc:2568
+msgid "insn contains an invalid address !"
+msgstr ""
+
+#: config/microblaze/microblaze.cc:2408 config/microblaze/microblaze.cc:2638
+#: config/xtensa/xtensa.cc:3163
+msgid "invalid address"
+msgstr ""
+
+#: config/microblaze/microblaze.cc:2511
+#, c-format
+msgid "letter %c was found & insn was not CONST_INT"
+msgstr ""
+
+#: config/mmix/mmix.cc:1635 config/mmix/mmix.cc:1756
+msgid "MMIX Internal: Expected a CONST_INT, not this"
+msgstr ""
+
+#: config/mmix/mmix.cc:1714
+msgid "MMIX Internal: Bad value for 'm', not a CONST_INT"
+msgstr ""
+
+#: config/mmix/mmix.cc:1724
+msgid "MMIX Internal: Expected a register, not this"
+msgstr ""
+
+#: config/mmix/mmix.cc:1734
+msgid "MMIX Internal: Expected a constant, not this"
+msgstr ""
+
+#. We need the original here.
+#: config/mmix/mmix.cc:1818
+msgid "MMIX Internal: Cannot decode this operand"
+msgstr ""
+
+#: config/mmix/mmix.cc:1877
+msgid "MMIX Internal: This is not a recognized address"
+msgstr ""
+
+#: config/mmix/mmix.cc:2769
+msgid "MMIX Internal: Trying to output invalidly reversed condition:"
+msgstr ""
+
+#: config/mmix/mmix.cc:2776
+msgid "MMIX Internal: What's the CC of this?"
+msgstr ""
+
+#: config/mmix/mmix.cc:2780
+msgid "MMIX Internal: What is the CC of this?"
+msgstr ""
+
+#: config/mmix/mmix.cc:2822
+msgid "MMIX Internal: This is not a constant:"
+msgstr ""
+
+#: config/msp430/msp430.cc:4229
+#, c-format
+msgid "%%d, %%e, %%f, %%g operand modifiers are for memory references or constant values only"
+msgstr ""
+
+#: config/msp430/msp430.cc:4342
+#, c-format
+msgid "invalid operand prefix"
+msgstr ""
+
+#: config/msp430/msp430.cc:4376
+#, c-format
+msgid "invalid zero extract"
+msgstr ""
+
+#: config/or1k/or1k.cc:1157 config/or1k/or1k.cc:1165
+#, c-format
+msgid "invalid relocation"
+msgstr ""
+
+#: config/or1k/or1k.cc:1259
+#, c-format
+msgid "invalid %%H value"
+msgstr ""
+
+#: config/or1k/or1k.cc:1272 config/xtensa/xtensa.cc:3080
+#, c-format
+msgid "invalid %%d value"
+msgstr ""
+
+#: config/or1k/or1k.cc:1320
+#, c-format
+msgid "unknown operand letter: '%c'"
+msgstr ""
+
+#: config/pru/pru.cc:1745 config/pru/pru.cc:1756
+#, c-format
+msgid "I/O register operand for '%%%c'"
+msgstr ""
+
+#: config/pru/pru.cc:1762
+#, c-format
+msgid "non 32 bit register operand for '%%%c'"
+msgstr ""
+
+#: config/pru/pru.cc:1847
+#, c-format
+msgid "unsupported code '%c' for fixed-point:"
+msgstr ""
+
+#: config/pru/pru.cc:1861
+#, c-format
+msgid "double constants not supported"
+msgstr "ორმაგი კონსტანტები მხარდაჭერილი არაა"
+
+#: config/pru/pru.cc:1944
+#, c-format
+msgid "unsupported operand %s for code '%c'"
+msgstr ""
+
+#: config/pru/pru.cc:1954
+#, c-format
+msgid "unexpected text address:"
+msgstr ""
+
+#: config/pru/pru.cc:1973
+#, c-format
+msgid "unsupported constant address:"
+msgstr ""
+
+#: config/pru/pru.cc:2034
+#, c-format
+msgid "unsupported memory expression:"
+msgstr ""
+
+#: config/riscv/riscv.cc:6151
+#, c-format
+msgid "invalid vector operand"
+msgstr ""
+
+#: config/rl78/rl78.cc:1998 config/rl78/rl78.cc:2084
+#, c-format
+msgid "q/Q modifiers invalid for symbol references"
+msgstr ""
+
+#: config/rs6000/host-darwin.cc:96
+#, c-format
+msgid "Out of stack space.\n"
+msgstr ""
+
+#: config/rs6000/host-darwin.cc:117
+#, c-format
+msgid "Try running '%s' in the shell to raise its limit.\n"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:3823
+msgid "%<-mvsx%> requires hardware floating point"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:3831
+msgid "%<-mvsx%> needs indexed addressing"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:3836
+msgid "%<-mvsx%> and %<-mno-altivec%> are incompatible"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:3838
+msgid "%<-mno-altivec%> disables vsx"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:3958
+msgid "%<-mquad-memory%> requires 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:3961
+msgid "%<-mquad-memory-atomic%> requires 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:3973
+msgid "%<-mquad-memory%> is not available in little endian mode"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:11354
+msgid "bad move"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:13894
+msgid "Bad 128-bit move"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14074
+#, c-format
+msgid "invalid %%A value"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14083 config/xtensa/xtensa.cc:3015
+#, c-format
+msgid "invalid %%D value"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14098
+#, c-format
+msgid "invalid %%e value"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14119
+#, c-format
+msgid "invalid %%f value"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14128
+#, c-format
+msgid "invalid %%F value"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14137
+#, c-format
+msgid "invalid %%G value"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14172
+#, c-format
+msgid "invalid %%j code"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14182
+#, c-format
+msgid "invalid %%J code"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14192
+#, c-format
+msgid "invalid %%k value"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14207 config/xtensa/xtensa.cc:3052
+#, c-format
+msgid "invalid %%K value"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14254
+#, c-format
+msgid "invalid %%O value"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14301
+#, c-format
+msgid "invalid %%q value"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14343
+#, c-format
+msgid "invalid %%t value"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14360
+#, c-format
+msgid "invalid %%T value"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14372
+#, c-format
+msgid "invalid %%u value"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14386 config/xtensa/xtensa.cc:3027
+#, c-format
+msgid "invalid %%v value"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14436
+#, c-format
+msgid "invalid %%V value"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14452 config/xtensa/xtensa.cc:3073
+#, c-format
+msgid "invalid %%x value"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14509
+#, c-format
+msgid "invalid %%z value"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:14578
+#, c-format
+msgid "invalid %%y value, try using the 'Z' constraint"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:15520
+msgid "Invalid mixing of IEEE 128-bit and IBM 128-bit floating point types"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:24390
+msgid "AltiVec argument passed to unprototyped function"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:28005
+msgid "Could not generate addis value for fusion"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:28074
+msgid "Unable to generate load/store offset for fusion"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:28150
+msgid "Bad GPR fusion"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:28752
+msgid "invalid conversion from type %<__vector_quad%>"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:28754
+msgid "invalid conversion to type %<__vector_quad%>"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:28756
+msgid "invalid conversion from type %<__vector_pair%>"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:28758
+msgid "invalid conversion to type %<__vector_pair%>"
+msgstr ""
+
+#: config/s390/s390.cc:8416
+#, c-format
+msgid "symbolic memory references are only supported on z10 or later"
+msgstr ""
+
+#: config/s390/s390.cc:8427
+#, c-format
+msgid "cannot decompose address"
+msgstr ""
+
+#: config/s390/s390.cc:8509
+#, c-format
+msgid "invalid comparison operator for 'E' output modifier"
+msgstr ""
+
+#: config/s390/s390.cc:8532
+#, c-format
+msgid "invalid reference for 'J' output modifier"
+msgstr ""
+
+#: config/s390/s390.cc:8550
+#, c-format
+msgid "invalid address for 'O' output modifier"
+msgstr ""
+
+#: config/s390/s390.cc:8572
+#, c-format
+msgid "invalid address for 'R' output modifier"
+msgstr ""
+
+#: config/s390/s390.cc:8590
+#, c-format
+msgid "memory reference expected for 'S' output modifier"
+msgstr ""
+
+#: config/s390/s390.cc:8600
+#, c-format
+msgid "invalid address for 'S' output modifier"
+msgstr ""
+
+#: config/s390/s390.cc:8621
+#, c-format
+msgid "register or memory expression expected for 'N' output modifier"
+msgstr ""
+
+#: config/s390/s390.cc:8632
+#, c-format
+msgid "register or memory expression expected for 'M' output modifier"
+msgstr ""
+
+#: config/s390/s390.cc:8741 config/s390/s390.cc:8762
+#, c-format
+msgid "invalid constant for output modifier '%c'"
+msgstr ""
+
+#: config/s390/s390.cc:8759
+#, c-format
+msgid "invalid constant - try using an output modifier"
+msgstr ""
+
+#: config/s390/s390.cc:8796
+#, c-format
+msgid "invalid constant vector for output modifier '%c'"
+msgstr ""
+
+#: config/s390/s390.cc:8803
+#, c-format
+msgid "invalid expression - try using an output modifier"
+msgstr ""
+
+#: config/s390/s390.cc:8806
+#, c-format
+msgid "invalid expression for output modifier '%c'"
+msgstr ""
+
+#: config/s390/s390.cc:12665
+msgid "vector argument passed to unprototyped function"
+msgstr ""
+
+#: config/s390/s390.cc:17111
+msgid "types differ in signedness"
+msgstr ""
+
+#: config/s390/s390.cc:17121
+msgid "binary operator does not support two vector bool operands"
+msgstr ""
+
+#: config/s390/s390.cc:17124
+msgid "binary operator does not support vector bool operand"
+msgstr ""
+
+#: config/s390/s390.cc:17132
+msgid "binary operator does not support mixing vector bool with floating point vector operands"
+msgstr ""
+
+#: config/sh/sh.cc:1222
+#, c-format
+msgid "invalid operand to %%R"
+msgstr ""
+
+#: config/sh/sh.cc:1249
+#, c-format
+msgid "invalid operand to %%S"
+msgstr ""
+
+#: config/sh/sh.cc:8667
+msgid "created and used with different architectures / ABIs"
+msgstr ""
+
+#: config/sh/sh.cc:8669
+msgid "created and used with different ABIs"
+msgstr ""
+
+#: config/sh/sh.cc:8671
+msgid "created and used with different endianness"
+msgstr ""
+
+#: config/sparc/sparc.cc:9393 config/sparc/sparc.cc:9399
+#, c-format
+msgid "invalid %%Y operand"
+msgstr ""
+
+#: config/sparc/sparc.cc:9486
+#, c-format
+msgid "invalid %%A operand"
+msgstr ""
+
+#: config/sparc/sparc.cc:9506
+#, c-format
+msgid "invalid %%B operand"
+msgstr ""
+
+#: config/sparc/sparc.cc:9586
+#, c-format
+msgid "invalid %%C operand"
+msgstr ""
+
+#: config/sparc/sparc.cc:9618
+#, c-format
+msgid "invalid %%D operand"
+msgstr ""
+
+#: config/sparc/sparc.cc:9637
+#, c-format
+msgid "invalid %%f operand"
+msgstr ""
+
+#: config/sparc/sparc.cc:9649
+#, c-format
+msgid "invalid %%s operand"
+msgstr ""
+
+#: config/sparc/sparc.cc:9694
+#, c-format
+msgid "floating-point constant not a valid immediate operand"
+msgstr ""
+
+#: config/stormy16/stormy16.cc:1895 config/stormy16/stormy16.cc:1966
+#, c-format
+msgid "'B' operand is not constant"
+msgstr ""
+
+#: config/stormy16/stormy16.cc:1922
+#, c-format
+msgid "'B' operand has multiple bits set"
+msgstr ""
+
+#: config/stormy16/stormy16.cc:1948
+#, c-format
+msgid "'o' operand is not constant"
+msgstr ""
+
+#: config/stormy16/stormy16.cc:1980
+#, c-format
+msgid "'h' operand is not SImode register"
+msgstr ""
+
+#: config/stormy16/stormy16.cc:1988
+#, c-format
+msgid "xstormy16_print_operand: unknown code"
+msgstr ""
+
+#: config/v850/v850.cc:271
+msgid "const_double_split got a bad insn:"
+msgstr ""
+
+#: config/v850/v850.cc:885
+msgid "output_move_single:"
+msgstr ""
+
+#: config/vax/vax.cc:483
+#, c-format
+msgid "symbol used with both base and indexed registers"
+msgstr ""
+
+#: config/vax/vax.cc:492
+#, c-format
+msgid "symbol with offset used in PIC mode"
+msgstr ""
+
+#: config/vax/vax.cc:580
+#, c-format
+msgid "symbol used as immediate operand"
+msgstr ""
+
+#: config/vax/vax.cc:1683
+msgid "illegal operand detected"
+msgstr ""
+
+#: config/visium/visium.cc:3367
+msgid "illegal operand "
+msgstr ""
+
+#: config/visium/visium.cc:3418
+msgid "illegal operand address (1)"
+msgstr ""
+
+#: config/visium/visium.cc:3425
+msgid "illegal operand address (2)"
+msgstr ""
+
+#: config/visium/visium.cc:3440
+msgid "illegal operand address (3)"
+msgstr ""
+
+#: config/visium/visium.cc:3448
+msgid "illegal operand address (4)"
+msgstr ""
+
+#: config/xtensa/xtensa-dynconfig.cc:63
+msgid "Unable to load DLL."
+msgstr ""
+
+#: config/xtensa/xtensa.cc:833 config/xtensa/xtensa.cc:871
+msgid "bad test"
+msgstr ""
+
+#: config/xtensa/xtensa.cc:3047
+msgid "invalid mask"
+msgstr ""
+
+#: config/xtensa/xtensa.cc:3099 config/xtensa/xtensa.cc:3109
+#, c-format
+msgid "invalid %%t/%%b value"
+msgstr ""
+
+#: config/xtensa/xtensa.cc:3188
+msgid "no register in address"
+msgstr ""
+
+#: config/xtensa/xtensa.cc:3196
+msgid "address offset not a constant"
+msgstr ""
+
+#: c/c-objc-common.cc:227
+msgid "{erroneous}"
+msgstr ""
+
+#: c/c-objc-common.cc:268
+msgid "aka"
+msgstr ""
+
+#: c/c-objc-common.cc:360
+msgid "({anonymous})"
+msgstr ""
+
+#. If we have
+#. declaration-specifiers declarator decl-specs
+#. then assume we have a missing semicolon, which would
+#. give us:
+#. declaration-specifiers declarator  decl-specs
+#. ^
+#. ;
+#. <~~~~~~~~~ declaration ~~~~~~~~~~>
+#. Use c_parser_require to get an error with a fix-it hint.
+#: c/c-parser.cc:2934 c/c-parser.cc:3059 c/c-parser.cc:3073 c/c-parser.cc:7006
+#: c/c-parser.cc:7761 c/c-parser.cc:8217 c/c-parser.cc:8404 c/c-parser.cc:8437
+#: c/c-parser.cc:8708 c/c-parser.cc:13166 c/c-parser.cc:13201
+#: c/c-parser.cc:13232 c/c-parser.cc:13279 c/c-parser.cc:13460
+#: c/c-parser.cc:14293 c/c-parser.cc:14368 c/c-parser.cc:14411
+#: c/c-parser.cc:21325 c/c-parser.cc:21405 c/c-parser.cc:21734
+#: c/c-parser.cc:21760 c/c-parser.cc:21783 c/c-parser.cc:22319
+#: c/c-parser.cc:22362 c/gimple-parser.cc:411 c/gimple-parser.cc:452
+#: c/gimple-parser.cc:461 c/gimple-parser.cc:670 c/gimple-parser.cc:2351
+#: c/gimple-parser.cc:2388 c/gimple-parser.cc:2467 c/gimple-parser.cc:2494
+#: c/c-parser.cc:3888 c/c-parser.cc:4079 c/c-parser.cc:4114 c/c-parser.cc:13453
+#: c/gimple-parser.cc:2158 c/gimple-parser.cc:2215 cp/parser.cc:15847
+#: cp/parser.cc:33812 cp/parser.cc:34451
+#, gcc-internal-format
+msgid "expected %<;%>"
+msgstr ""
+
+#: c/c-parser.cc:3569 c/c-parser.cc:4679 c/c-parser.cc:4874 c/c-parser.cc:4932
+#: c/c-parser.cc:4990 c/c-parser.cc:5373 c/c-parser.cc:5396 c/c-parser.cc:5405
+#: c/c-parser.cc:5456 c/c-parser.cc:5465 c/c-parser.cc:10145
+#: c/c-parser.cc:10213 c/c-parser.cc:10735 c/c-parser.cc:10761
+#: c/c-parser.cc:10795 c/c-parser.cc:10907 c/c-parser.cc:11726
+#: c/c-parser.cc:13567 c/c-parser.cc:16181 c/c-parser.cc:16916
+#: c/c-parser.cc:16975 c/c-parser.cc:17030 c/c-parser.cc:18889
+#: c/c-parser.cc:19009 c/c-parser.cc:20418 c/c-parser.cc:21825
+#: c/c-parser.cc:22327 c/c-parser.cc:25649 c/c-parser.cc:25731
+#: c/gimple-parser.cc:195 c/gimple-parser.cc:198 c/gimple-parser.cc:546
+#: c/gimple-parser.cc:580 c/gimple-parser.cc:585 c/gimple-parser.cc:754
+#: c/gimple-parser.cc:851 c/gimple-parser.cc:1089 c/gimple-parser.cc:1115
+#: c/gimple-parser.cc:1118 c/gimple-parser.cc:1249 c/gimple-parser.cc:1376
+#: c/gimple-parser.cc:1506 c/gimple-parser.cc:1522 c/gimple-parser.cc:1578
+#: c/gimple-parser.cc:1605 c/gimple-parser.cc:1635 c/gimple-parser.cc:1661
+#: c/gimple-parser.cc:1868 c/gimple-parser.cc:2080 c/gimple-parser.cc:2100
+#: c/gimple-parser.cc:2261 c/gimple-parser.cc:2424 c/c-parser.cc:8660
+#: cp/parser.cc:34499
+#, gcc-internal-format
+msgid "expected %<)%>"
+msgstr ""
+
+#: c/c-parser.cc:4768 c/c-parser.cc:5516 c/c-parser.cc:5876 c/c-parser.cc:5894
+#: c/c-parser.cc:5895 c/c-parser.cc:6341 c/c-parser.cc:6385 c/c-parser.cc:8759
+#: c/c-parser.cc:10898 c/c-parser.cc:12179 c/c-parser.cc:12550
+#: c/c-parser.cc:15496 c/gimple-parser.cc:1844 cp/parser.cc:34463
+#, gcc-internal-format
+msgid "expected %<]%>"
+msgstr ""
+
+#: c/c-parser.cc:4970
+msgid "expected %<;%>, %<,%> or %<)%>"
+msgstr ""
+
+#. Look for the two `(' tokens.
+#: c/c-parser.cc:5425 c/c-parser.cc:5430 c/c-parser.cc:16164
+#: c/c-parser.cc:17005 c/c-parser.cc:24793 c/c-parser.cc:25457
+#: c/c-parser.cc:25674 c/gimple-parser.cc:180 c/gimple-parser.cc:493
+#: c/gimple-parser.cc:532 c/gimple-parser.cc:564 c/gimple-parser.cc:821
+#: c/gimple-parser.cc:1083 c/gimple-parser.cc:1109 c/gimple-parser.cc:1236
+#: c/gimple-parser.cc:1371 c/gimple-parser.cc:1496 c/gimple-parser.cc:1601
+#: c/gimple-parser.cc:1619 c/gimple-parser.cc:1654 c/gimple-parser.cc:2049
+#: c/gimple-parser.cc:2060 c/gimple-parser.cc:2066 c/gimple-parser.cc:2249
+#: c/gimple-parser.cc:2421 c/c-parser.cc:15945 cp/parser.cc:34454
+#, gcc-internal-format
+msgid "expected %<(%>"
+msgstr ""
+
+#: c/c-parser.cc:5872 c/c-parser.cc:5874 c/c-parser.cc:15401 cp/parser.cc:34466
+#: cp/parser.cc:38335 go/gofrontend/embed.cc:440
+#, gcc-internal-format
+msgid "expected %<[%>"
+msgstr ""
+
+#: c/c-parser.cc:6522 c/c-parser.cc:13796 c/c-parser.cc:21300
+#: c/c-parser.cc:21386 c/c-parser.cc:22147 c/c-parser.cc:23105
+#: c/c-parser.cc:26917 c/gimple-parser.cc:404 c/gimple-parser.cc:2427
+#: c/c-parser.cc:3875 c/c-parser.cc:4103 c/c-parser.cc:13348 cp/parser.cc:21607
+#: cp/parser.cc:34460 go/gofrontend/embed.cc:371
+#, gcc-internal-format
+msgid "expected %<{%>"
+msgstr ""
+
+#: c/c-parser.cc:7368 c/c-parser.cc:7377 c/c-parser.cc:9208 c/c-parser.cc:10350
+#: c/c-parser.cc:13560 c/c-parser.cc:13957 c/c-parser.cc:14021
+#: c/c-parser.cc:15478 c/c-parser.cc:16596 c/c-parser.cc:16833
+#: c/c-parser.cc:17386 c/c-parser.cc:17489 c/c-parser.cc:18030
+#: c/c-parser.cc:18466 c/c-parser.cc:18542 c/c-parser.cc:18659
+#: c/c-parser.cc:18731 c/c-parser.cc:24660 c/c-parser.cc:25514
+#: c/c-parser.cc:25573 c/gimple-parser.cc:587 c/gimple-parser.cc:892
+#: c/gimple-parser.cc:2475 c/gimple-parser.cc:2502 c/c-parser.cc:8667
+#: c/c-parser.cc:16089 c/c-parser.cc:17494 cp/parser.cc:34493
+#: cp/parser.cc:36196 cp/parser.cc:39266 cp/parser.cc:40159
+#: go/gofrontend/embed.cc:404
+#, gcc-internal-format
+msgid "expected %<:%>"
+msgstr ""
+
+#: c/c-parser.cc:8199 cp/parser.cc:34380
+#, gcc-internal-format
+msgid "expected %<while%>"
+msgstr ""
+
+#: c/c-parser.cc:10108 c/c-parser.cc:10301 c/c-parser.cc:10785
+#: c/c-parser.cc:10828 c/c-parser.cc:10969 c/c-parser.cc:11716
+#: c/c-parser.cc:17010 c/c-parser.cc:18611 c/gimple-parser.cc:1086
+#: c/gimple-parser.cc:1112 c/gimple-parser.cc:1240 c/gimple-parser.cc:1243
+#: c/gimple-parser.cc:1623 c/gimple-parser.cc:1629 cp/parser.cc:33810
+#: cp/parser.cc:34469
+#, gcc-internal-format
+msgid "expected %<,%>"
+msgstr ""
+
+#: c/c-parser.cc:10679
+msgid "expected %<.%>"
+msgstr ""
+
+#: c/c-parser.cc:13019 c/c-parser.cc:13051 c/c-parser.cc:13291
+#: cp/parser.cc:36770 cp/parser.cc:36791
+#, gcc-internal-format
+msgid "expected %<@end%>"
+msgstr ""
+
+#: c/c-parser.cc:13709 c/gimple-parser.cc:1411 cp/parser.cc:34478
+#, gcc-internal-format
+msgid "expected %<>%>"
+msgstr ""
+
+#: c/c-parser.cc:17584 c/c-parser.cc:19027 cp/parser.cc:34502
+#, gcc-internal-format
+msgid "expected %<,%> or %<)%>"
+msgstr ""
+
+#. All following cases are statements with LHS.
+#: c/c-parser.cc:18458 c/c-parser.cc:21193 c/c-parser.cc:21240
+#: c/c-parser.cc:21397 c/c-parser.cc:21744 c/c-parser.cc:22306
+#: c/c-parser.cc:24841 c/c-parser.cc:25715 c/gimple-parser.cc:745
+#: c/c-parser.cc:6408 c/c-parser.cc:21317 c/c-parser.cc:21540
+#: cp/parser.cc:34481 cp/parser.cc:43149 cp/parser.cc:43322
+#, gcc-internal-format
+msgid "expected %<=%>"
+msgstr ""
+
+#: c/c-parser.cc:21328 c/c-parser.cc:21408 c/c-parser.cc:21761
+#: c/c-parser.cc:22216 c/gimple-parser.cc:1677 c/gimple-parser.cc:1709
+#: c/gimple-parser.cc:1719 c/gimple-parser.cc:2512 cp/parser.cc:34457
+#: cp/parser.cc:36980
+#, gcc-internal-format
+msgid "expected %<}%>"
+msgstr ""
+
+#: c/c-parser.cc:21421 cp/parser.cc:43247
+#, gcc-internal-format
+msgid "expected %<else%>"
+msgstr ""
+
+#: c/c-parser.cc:23152 c/c-parser.cc:23141 cp/parser.cc:45942
+#, gcc-internal-format
+msgid "expected %<#pragma omp section%> or %<}%>"
+msgstr ""
+
+#: c/c-parser.cc:26281 cp/parser.cc:49919
+msgid "<message unknown at compile time>"
+msgstr ""
+
+#: c/c-typeck.cc:9041
+msgid "(anonymous)"
+msgstr ""
+
+#: c/gimple-parser.cc:1400 cp/parser.cc:18950 cp/parser.cc:34475
+#, gcc-internal-format
+msgid "expected %<<%>"
+msgstr ""
+
+#: c/gimple-parser.cc:2471 c/gimple-parser.cc:2498 c/gimple-parser.cc:2337
+#: c/gimple-parser.cc:2374
+#, gcc-internal-format
+msgid "expected label"
+msgstr ""
+
+#: cp/call.cc:4136
+msgid "candidate:"
+msgstr ""
+
+#: cp/call.cc:8333
+msgid "  after user-defined conversion:"
+msgstr ""
+
+#: cp/call.cc:8499 cp/pt.cc:2044 cp/pt.cc:26386
+msgid "candidate is:"
+msgid_plural "candidates are:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: cp/call.cc:13021 cp/call.cc:13447
+msgid "candidate 1:"
+msgstr ""
+
+#: cp/call.cc:13023 cp/call.cc:13448
+msgid "candidate 2:"
+msgstr ""
+
+#: cp/error.cc:464
+msgid "<missing>"
+msgstr ""
+
+#: cp/error.cc:566
+msgid "<brace-enclosed initializer list>"
+msgstr ""
+
+#: cp/error.cc:568
+msgid "<unresolved overloaded function type>"
+msgstr ""
+
+#: cp/error.cc:735
+msgid "<type error>"
+msgstr ""
+
+#. A lambda's "type" is essentially its signature.
+#: cp/error.cc:842
+msgid "<lambda"
+msgstr ""
+
+#: cp/error.cc:856 objc/objc-act.cc:6365 cp/cxx-pretty-print.cc:154
+#: cp/cxx-pretty-print.cc:2862
+#, gcc-internal-format
+msgid "<unnamed>"
+msgstr "<უსახელო>"
+
+#: cp/error.cc:858
+#, c-format
+msgid "<unnamed %s>"
+msgstr ""
+
+#: cp/error.cc:996
+msgid "<typeprefixerror>"
+msgstr ""
+
+#: cp/error.cc:1137
+#, c-format
+msgid "(static initializers for %s)"
+msgstr ""
+
+#: cp/error.cc:1139
+#, c-format
+msgid "(static destructors for %s)"
+msgstr ""
+
+#: cp/error.cc:1185
+msgid "<structured bindings>"
+msgstr ""
+
+#: cp/error.cc:1311
+msgid "vtable for "
+msgstr ""
+
+#: cp/error.cc:1335
+msgid "<return value> "
+msgstr ""
+
+#: cp/error.cc:1350
+msgid "{anonymous}"
+msgstr ""
+
+#: cp/error.cc:1352
+msgid "(anonymous namespace)"
+msgstr ""
+
+#: cp/error.cc:1452
+msgid "<template arguments error>"
+msgstr ""
+
+#: cp/error.cc:1477
+msgid "<enumerator>"
+msgstr ""
+
+#: cp/error.cc:1537
+msgid "<declaration error>"
+msgstr ""
+
+#: cp/error.cc:2109 cp/error.cc:2129
+msgid "<template parameter error>"
+msgstr ""
+
+#: cp/error.cc:2259
+msgid "<statement>"
+msgstr ""
+
+#: cp/error.cc:2289 cp/error.cc:3391 c-family/c-pretty-print.cc:2708
+#, gcc-internal-format
+msgid "<unknown>"
+msgstr ""
+
+#. While waiting for caret diagnostics, avoid printing
+#. __cxa_allocate_exception, __cxa_throw, and the like.
+#: cp/error.cc:2307
+msgid "<throw-expression>"
+msgstr ""
+
+#: cp/error.cc:2408
+msgid "<ubsan routine call>"
+msgstr ""
+
+#: cp/error.cc:2910
+msgid "<unparsed>"
+msgstr ""
+
+#: cp/error.cc:3063
+msgid "<lambda>"
+msgstr ""
+
+#: cp/error.cc:3102
+msgid "*this"
+msgstr ""
+
+#: cp/error.cc:3116
+msgid "<expression error>"
+msgstr ""
+
+#: cp/error.cc:3131
+msgid "<unknown operator>"
+msgstr ""
+
+#: cp/error.cc:3606
+msgid "At global scope:"
+msgstr ""
+
+#: cp/error.cc:3665
+msgid "    inlined from %qD at %r%s:%d:%d%R"
+msgstr ""
+
+#: cp/error.cc:3670
+msgid "    inlined from %qD at %r%s:%d%R"
+msgstr ""
+
+#: cp/error.cc:3676
+msgid "    inlined from %qD"
+msgstr ""
+
+#: cp/error.cc:3703
+msgid "In static member function %qD"
+msgstr ""
+
+#: cp/error.cc:3705
+msgid "In copy constructor %qD"
+msgstr ""
+
+#: cp/error.cc:3707
+msgid "In constructor %qD"
+msgstr ""
+
+#: cp/error.cc:3709
+msgid "In destructor %qD"
+msgstr ""
+
+#: cp/error.cc:3711
+msgid "In lambda function"
+msgstr ""
+
+#: cp/error.cc:3713
+msgid "In explicit object member function %qD"
+msgstr ""
+
+#: cp/error.cc:3715
+msgid "In member function %qD"
+msgstr ""
+
+#: cp/error.cc:3718
+msgid "In function %qD"
+msgstr ""
+
+#: cp/error.cc:3741
+#, c-format
+msgid "%s: In substitution of %qS:\n"
+msgstr ""
+
+#: cp/error.cc:3742
+msgid "%s: In instantiation of %q#D:\n"
+msgstr ""
+
+#: cp/error.cc:3767 cp/error.cc:3925
+msgid "%r%s:%d:%d:%R   "
+msgstr ""
+
+#: cp/error.cc:3770 cp/error.cc:3928
+msgid "%r%s:%d:%R   "
+msgstr ""
+
+#: cp/error.cc:3778
+#, c-format
+msgid "recursively required by substitution of %qS\n"
+msgstr ""
+
+#: cp/error.cc:3779
+#, c-format
+msgid "required by substitution of %qS\n"
+msgstr ""
+
+#: cp/error.cc:3784
+msgid "recursively required from %q#D\n"
+msgstr ""
+
+#: cp/error.cc:3785
+msgid "required from %q#D\n"
+msgstr ""
+
+#: cp/error.cc:3792
+msgid "recursively required from here\n"
+msgstr ""
+
+#: cp/error.cc:3793
+msgid "required from here\n"
+msgstr ""
+
+#: cp/error.cc:3849
+msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
+msgstr ""
+
+#: cp/error.cc:3855
+msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
+msgstr ""
+
+#: cp/error.cc:3909
+msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
+msgstr ""
+
+#: cp/error.cc:3913
+msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
+msgstr ""
+
+#: cp/pt.cc:2042 cp/semantics.cc:6308
+msgid "candidates are:"
+msgstr ""
+
+#: cp/rtti.cc:592
+msgid "target is not pointer or reference to class"
+msgstr ""
+
+#: cp/rtti.cc:597
+msgid "target is not pointer or reference to complete type"
+msgstr ""
+
+#: cp/rtti.cc:603
+msgid "target is not pointer or reference"
+msgstr ""
+
+#: cp/rtti.cc:619
+msgid "source is not a pointer"
+msgstr ""
+
+#: cp/rtti.cc:624
+msgid "source is not a pointer to class"
+msgstr ""
+
+#: cp/rtti.cc:629
+msgid "source is a pointer to incomplete type"
+msgstr ""
+
+#: cp/rtti.cc:642
+msgid "source is not of class type"
+msgstr ""
+
+#: cp/rtti.cc:647
+msgid "source is of incomplete class type"
+msgstr ""
+
+#: cp/rtti.cc:658
+msgid "conversion casts away constness"
+msgstr ""
+
+#: cp/rtti.cc:818
+msgid "source type is not polymorphic"
+msgstr ""
+
+#: cp/typeck.cc:7439 c/c-typeck.cc:4685
+#, gcc-internal-format
+msgid "wrong type argument to unary minus"
+msgstr ""
+
+#: cp/typeck.cc:7440 c/c-typeck.cc:4671
+#, gcc-internal-format
+msgid "wrong type argument to unary plus"
+msgstr ""
+
+#: cp/typeck.cc:7467 c/c-typeck.cc:4730
+#, gcc-internal-format
+msgid "wrong type argument to bit-complement"
+msgstr ""
+
+#: cp/typeck.cc:7484 c/c-typeck.cc:4738
+#, gcc-internal-format
+msgid "wrong type argument to abs"
+msgstr ""
+
+#: cp/typeck.cc:7496 c/c-typeck.cc:4760
+#, gcc-internal-format
+msgid "wrong type argument to conjugation"
+msgstr ""
+
+#: cp/typeck.cc:7520
+msgid "in argument to unary !"
+msgstr ""
+
+#: cp/typeck.cc:7569
+msgid "no pre-increment operator for type"
+msgstr ""
+
+#: cp/typeck.cc:7571
+msgid "no post-increment operator for type"
+msgstr ""
+
+#: cp/typeck.cc:7573
+msgid "no pre-decrement operator for type"
+msgstr ""
+
+#: cp/typeck.cc:7575
+msgid "no post-decrement operator for type"
+msgstr ""
+
+#: fortran/arith.cc:1544
+msgid "elemental binary operation"
+msgstr ""
+
+#: fortran/check.cc:70
+msgid " [see %<-fno-allow-invalid-boz%>]"
+msgstr ""
+
+#: fortran/check.cc:3732
+#, c-format
+msgid "arguments 'a%d' and 'a%d' for intrinsic '%s'"
+msgstr ""
+
+#: fortran/check.cc:3941 fortran/check.cc:4023 fortran/check.cc:4088
+#, c-format
+msgid "arguments '%s' and '%s' for intrinsic %s"
+msgstr ""
+
+#: fortran/check.cc:4432 fortran/intrinsic.cc:4831
+#, c-format
+msgid "arguments '%s' and '%s' for intrinsic '%s'"
+msgstr ""
+
+#: fortran/dump-parse-tree.cc:3731
+#, c-format
+msgid ""
+"/* Prototypes for external procedures generated from %s\n"
+"   by GNU Fortran %s%s.\n"
+"\n"
+"   Use of this interface is discouraged, consider using the\n"
+"   BIND(C) feature of standard Fortran instead.  */\n"
+"\n"
+msgstr ""
+
+#: fortran/error.cc:1043
+msgid "Prohibited in Fortran 2023:"
+msgstr ""
+
+#: fortran/error.cc:1045
+msgid "Fortran 2023:"
+msgstr ""
+
+#: fortran/error.cc:1047
+msgid "Fortran 2018 deleted feature:"
+msgstr ""
+
+#: fortran/error.cc:1049
+msgid "Fortran 2018 obsolescent feature:"
+msgstr ""
+
+#: fortran/error.cc:1051
+msgid "Fortran 2018:"
+msgstr ""
+
+#: fortran/error.cc:1053
+msgid "Fortran 2008 obsolescent feature:"
+msgstr ""
+
+#: fortran/error.cc:1059
+msgid "GNU Extension:"
+msgstr ""
+
+#: fortran/error.cc:1061
+msgid "Legacy Extension:"
+msgstr ""
+
+#: fortran/error.cc:1063
+msgid "Obsolescent feature:"
+msgstr ""
+
+#: fortran/error.cc:1065
+msgid "Deleted feature:"
+msgstr ""
+
+#: fortran/expr.cc:3814
+msgid "array assignment"
+msgstr ""
+
+#: fortran/frontend-passes.cc:2387
+msgid "Index variable %qs redefined at %L in procedure %qs called from within DO loop at %L"
+msgstr ""
+
+#. Macros for unified error messages.
+#: fortran/frontend-passes.cc:4082
+#, c-format
+msgid "Incorrect extent in argument B in MATMUL intrinsic in dimension 1: is %ld, should be %ld"
+msgstr ""
+
+#: fortran/frontend-passes.cc:4085
+#, c-format
+msgid "Array bound mismatch for dimension 1 of array (%ld/%ld)"
+msgstr ""
+
+#: fortran/frontend-passes.cc:4088
+#, c-format
+msgid "Array bound mismatch for dimension 2 of array (%ld/%ld)"
+msgstr ""
+
+#: fortran/gfortranspec.cc:427 m2/gm2spec.cc:916
+#, c-format
+msgid "Driving:"
+msgstr ""
+
+#: fortran/interface.cc:3758 fortran/intrinsic.cc:4509
+msgid "actual argument to INTENT = OUT/INOUT"
+msgstr ""
+
+#: fortran/intrinsic.cc:4868
+msgid "available since Fortran 77"
+msgstr ""
+
+#: fortran/intrinsic.cc:4872
+msgid "obsolescent in Fortran 95"
+msgstr ""
+
+#: fortran/intrinsic.cc:4876
+msgid "deleted in Fortran 95"
+msgstr ""
+
+#: fortran/intrinsic.cc:4880
+msgid "new in Fortran 95"
+msgstr ""
+
+#: fortran/intrinsic.cc:4884
+msgid "new in Fortran 2003"
+msgstr ""
+
+#: fortran/intrinsic.cc:4888
+msgid "new in Fortran 2008"
+msgstr ""
+
+#: fortran/intrinsic.cc:4892
+msgid "new in Fortran 2018"
+msgstr ""
+
+#: fortran/intrinsic.cc:4896
+msgid "new in Fortran 2023"
+msgstr ""
+
+#: fortran/intrinsic.cc:4900
+msgid "a GNU Fortran extension"
+msgstr ""
+
+#: fortran/intrinsic.cc:4904
+msgid "for backward compatibility"
+msgstr ""
+
+#: fortran/io.cc:1873
+#, c-format
+msgid "%s tag"
+msgstr ""
+
+#: fortran/io.cc:3364
+msgid "internal unit in WRITE"
+msgstr ""
+
+#. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
+#. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
+#: fortran/io.cc:4725
+#, c-format
+msgid "%s tag with INQUIRE"
+msgstr ""
+
+#: fortran/matchexp.cc:28
+#, c-format
+msgid "Syntax error in expression at %C"
+msgstr ""
+
+#: fortran/module.cc:1259
+msgid "Unexpected EOF"
+msgstr ""
+
+#: fortran/module.cc:1384
+msgid "Name too long"
+msgstr ""
+
+#: fortran/module.cc:1438 fortran/module.cc:1496 fortran/module.cc:1551
+#: fortran/module.cc:1609
+msgid "Bad name"
+msgstr ""
+
+#: fortran/module.cc:1633
+msgid "Expected name"
+msgstr ""
+
+#: fortran/module.cc:1636
+msgid "Expected left parenthesis"
+msgstr ""
+
+#: fortran/module.cc:1639
+msgid "Expected right parenthesis"
+msgstr ""
+
+#: fortran/module.cc:1642
+msgid "Expected integer"
+msgstr ""
+
+#: fortran/module.cc:1645 fortran/module.cc:2869
+msgid "Expected string"
+msgstr ""
+
+#: fortran/module.cc:1670
+msgid "find_enum(): Enum not found"
+msgstr ""
+
+#: fortran/module.cc:2243
+msgid "Unsupported: multiple OpenACC 'routine' levels of parallelism"
+msgstr ""
+
+#: fortran/module.cc:2489
+msgid "Expected attribute bit name"
+msgstr ""
+
+#: fortran/module.cc:3498
+msgid "Expected integer string"
+msgstr ""
+
+#: fortran/module.cc:3502
+msgid "Error converting integer"
+msgstr ""
+
+#: fortran/module.cc:3524
+msgid "Expected real string"
+msgstr ""
+
+#: fortran/module.cc:3749
+msgid "Expected expression type"
+msgstr ""
+
+#: fortran/module.cc:3829
+msgid "Bad operator"
+msgstr ""
+
+#: fortran/module.cc:3946
+msgid "Bad type in constant expression"
+msgstr ""
+
+#: fortran/module.cc:7404
+msgid "Unexpected end of module"
+msgstr ""
+
+#: fortran/parse.cc:2139
+msgid "arithmetic IF"
+msgstr ""
+
+#: fortran/parse.cc:2148
+msgid "attribute declaration"
+msgstr ""
+
+#: fortran/parse.cc:2184
+msgid "data declaration"
+msgstr ""
+
+#: fortran/parse.cc:2202
+msgid "derived type declaration"
+msgstr ""
+
+#: fortran/parse.cc:2329
+msgid "block IF"
+msgstr ""
+
+#: fortran/parse.cc:2338
+msgid "implied END DO"
+msgstr ""
+
+#: fortran/parse.cc:2432 fortran/resolve.cc:12774
+msgid "assignment"
+msgstr "მინიჭება"
+
+#: fortran/parse.cc:2435 fortran/resolve.cc:12840 fortran/resolve.cc:12843
+msgid "pointer assignment"
+msgstr ""
+
+#: fortran/parse.cc:2459
+msgid "simple IF"
+msgstr ""
+
+#: fortran/resolve.cc:2442 fortran/resolve.cc:2637
+msgid "elemental procedure"
+msgstr ""
+
+#: fortran/resolve.cc:2540
+msgid "allocatable argument"
+msgstr ""
+
+#: fortran/resolve.cc:2545
+msgid "asynchronous argument"
+msgstr ""
+
+#: fortran/resolve.cc:2550
+msgid "optional argument"
+msgstr ""
+
+#: fortran/resolve.cc:2555
+msgid "pointer argument"
+msgstr ""
+
+#: fortran/resolve.cc:2560
+msgid "target argument"
+msgstr ""
+
+#: fortran/resolve.cc:2565
+msgid "value argument"
+msgstr ""
+
+#: fortran/resolve.cc:2570
+msgid "volatile argument"
+msgstr ""
+
+#: fortran/resolve.cc:2575
+msgid "assumed-shape argument"
+msgstr ""
+
+#: fortran/resolve.cc:2580
+msgid "assumed-rank argument"
+msgstr ""
+
+#: fortran/resolve.cc:2585
+msgid "coarray argument"
+msgstr ""
+
+#: fortran/resolve.cc:2590
+msgid "parametrized derived type argument"
+msgstr ""
+
+#: fortran/resolve.cc:2595
+msgid "polymorphic argument"
+msgstr ""
+
+#: fortran/resolve.cc:2600
+msgid "NO_ARG_CHECK attribute"
+msgstr ""
+
+#. As assumed-type is unlimited polymorphic (cf. above).
+#. See also TS 29113, Note 6.1.
+#: fortran/resolve.cc:2607
+msgid "assumed-type argument"
+msgstr ""
+
+#: fortran/resolve.cc:2618
+msgid "array result"
+msgstr ""
+
+#: fortran/resolve.cc:2623
+msgid "pointer or allocatable result"
+msgstr ""
+
+#: fortran/resolve.cc:2630
+msgid "result with non-constant character length"
+msgstr ""
+
+#: fortran/resolve.cc:2642
+msgid "bind(c) procedure"
+msgstr ""
+
+#: fortran/resolve.cc:4214
+#, c-format
+msgid "Invalid context for NULL() pointer at %%L"
+msgstr ""
+
+#: fortran/resolve.cc:4231
+#, c-format
+msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
+msgstr ""
+
+#: fortran/resolve.cc:4249 fortran/resolve.cc:4432 fortran/resolve.cc:4587
+#, c-format
+msgid "Inconsistent ranks for operator at %%L and %%L"
+msgstr ""
+
+#: fortran/resolve.cc:4259
+#, c-format
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr ""
+
+#: fortran/resolve.cc:4264
+#, c-format
+msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
+msgstr ""
+
+#: fortran/resolve.cc:4279
+#, c-format
+msgid "Operands of string concatenation operator at %%L are %s/%s"
+msgstr ""
+
+#: fortran/resolve.cc:4322
+#, c-format
+msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
+msgstr ""
+
+#: fortran/resolve.cc:4345
+#, c-format
+msgid "Operand of .not. operator at %%L is %s"
+msgstr ""
+
+#: fortran/resolve.cc:4359
+msgid "COMPLEX quantities cannot be compared at %L"
+msgstr ""
+
+#: fortran/resolve.cc:4468
+#, c-format
+msgid "Logicals at %%L must be compared with %s instead of %s"
+msgstr ""
+
+#: fortran/resolve.cc:4474
+#, c-format
+msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
+msgstr ""
+
+#: fortran/resolve.cc:4488
+#, c-format
+msgid "Unknown operator %%<%s%%> at %%L; did you mean %%<%s%%>?"
+msgstr ""
+
+#: fortran/resolve.cc:4491
+#, c-format
+msgid "Unknown operator %%<%s%%> at %%L"
+msgstr ""
+
+#: fortran/resolve.cc:4496
+#, c-format
+msgid "Operand of user operator %%<%s%%> at %%L is %s"
+msgstr ""
+
+#: fortran/resolve.cc:4501
+#, c-format
+msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
+msgstr ""
+
+#: fortran/resolve.cc:7668
+msgid "Loop variable"
+msgstr ""
+
+#: fortran/resolve.cc:7672
+msgid "iterator variable"
+msgstr ""
+
+#: fortran/resolve.cc:7676
+msgid "Start expression in DO loop"
+msgstr ""
+
+#: fortran/resolve.cc:7680
+msgid "End expression in DO loop"
+msgstr ""
+
+#: fortran/resolve.cc:7684
+msgid "Step expression in DO loop"
+msgstr ""
+
+#: fortran/resolve.cc:7971 fortran/resolve.cc:7974
+msgid "DEALLOCATE object"
+msgstr ""
+
+#: fortran/resolve.cc:8362 fortran/resolve.cc:8365
+msgid "ALLOCATE object"
+msgstr ""
+
+#: fortran/resolve.cc:8602 fortran/resolve.cc:10679 fortran/resolve.cc:10800
+msgid "STAT variable"
+msgstr ""
+
+#: fortran/resolve.cc:8653 fortran/resolve.cc:10691 fortran/resolve.cc:10812
+msgid "ERRMSG variable"
+msgstr ""
+
+#: fortran/resolve.cc:10481
+msgid "item in READ"
+msgstr ""
+
+#: fortran/resolve.cc:10703
+msgid "ACQUIRED_LOCK variable"
+msgstr ""
+
+#: fortran/trans-array.cc:1936
+#, c-format
+msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
+msgstr ""
+
+#: fortran/trans-array.cc:6413
+msgid "Integer overflow when calculating the amount of memory to allocate"
+msgstr ""
+
+#: fortran/trans-array.cc:10525
+#, c-format
+msgid "The value of the PDT LEN parameter '%s' does not agree with that in the dummy declaration"
+msgstr ""
+
+#: fortran/trans-decl.cc:6371
+#, c-format
+msgid "Actual string length does not match the declared one for dummy argument '%s' (%ld/%ld)"
+msgstr ""
+
+#: fortran/trans-decl.cc:6379
+#, c-format
+msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
+msgstr ""
+
+#: fortran/trans-expr.cc:10759
+#, c-format
+msgid "Target of rank remapping is too small (%ld < %ld)"
+msgstr ""
+
+#: fortran/trans-expr.cc:12385
+msgid "Assignment of scalar to unallocated array"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:983
+#, c-format
+msgid "Unequal character lengths (%ld/%ld) in %s"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:6521
+#, c-format
+msgid "POS argument (%ld) out of range 0:%ld in intrinsic BTEST"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:6616
+#, c-format
+msgid "POS argument (%ld) out of range 0:%ld in intrinsic %s"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:6664
+#, c-format
+msgid "POS argument (%ld) out of range 0:%ld in intrinsic IBITS"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:6674
+#, c-format
+msgid "LEN argument (%ld) out of range 0:%ld in intrinsic IBITS"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:6681
+#, c-format
+msgid "POS(%ld)+LEN(%ld)>BIT_SIZE(%ld) in intrinsic IBITS"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:6763
+#, c-format
+msgid "SHIFT argument (%ld) out of range 0:%ld in intrinsic %s"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:6831
+#, c-format
+msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFT"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:6911
+#, c-format
+msgid "SIZE argument (%ld) out of range 1:%ld in intrinsic ISHFTC"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:6919 fortran/trans-intrinsic.cc:6964
+#, c-format
+msgid "SHIFT argument (%ld) out of range -%ld:%ld in intrinsic ISHFTC"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:9359
+#, c-format
+msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:9391
+msgid "Argument NCOPIES of REPEAT intrinsic is too large"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:12556
+#, c-format
+msgid "FROMPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:12568
+#, c-format
+msgid "LEN argument (%ld) out of range 0:%d in intrinsic MVBITS"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:12580
+#, c-format
+msgid "TOPOS argument (%ld) out of range 0:%d in intrinsic MVBITS"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:12592
+#, c-format
+msgid "FROMPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:12600
+#, c-format
+msgid "TOPOS(%ld)+LEN(%ld)>BIT_SIZE(%d) in intrinsic MVBITS"
+msgstr ""
+
+#: fortran/trans-io.cc:587
+msgid "Unit number in I/O statement too small"
+msgstr ""
+
+#: fortran/trans-io.cc:596
+msgid "Unit number in I/O statement too large"
+msgstr ""
+
+#: fortran/trans-stmt.cc:157
+msgid "Assigned label is not a target label"
+msgstr ""
+
+#: fortran/trans-stmt.cc:1291
+#, c-format
+msgid "Invalid image number %d in SYNC IMAGES"
+msgstr ""
+
+#: fortran/trans-stmt.cc:2527
+msgid "Loop iterates infinitely"
+msgstr ""
+
+#: fortran/trans-stmt.cc:2547 fortran/trans-stmt.cc:2803
+msgid "Loop variable has been modified"
+msgstr ""
+
+#: fortran/trans-stmt.cc:2656
+msgid "DO step value is zero"
+msgstr ""
+
+#: fortran/trans.cc:47
+msgid "Array reference out of bounds"
+msgstr ""
+
+#: fortran/trans.cc:770 fortran/trans.cc:854
+#, c-format
+msgid "Error allocating %lu bytes"
+msgstr ""
+
+#: fortran/trans.cc:1067
+#, c-format
+msgid "Attempting to allocate already allocated variable '%s'"
+msgstr ""
+
+#: fortran/trans.cc:1073
+msgid "Attempting to allocate already allocated variable"
+msgstr ""
+
+#: fortran/trans.cc:1866 fortran/trans.cc:2044
+#, c-format
+msgid "Attempt to DEALLOCATE unallocated '%s'"
+msgstr ""
+
+#: fortran/trans.cc:2212
+#, c-format
+msgid "Error reallocating to %lu bytes"
+msgstr ""
+
+#: go/go-backend.cc:166 rust/rust-object-export.cc:147
+msgid "lseek failed while reading export data"
+msgstr ""
+
+#: go/go-backend.cc:173 rust/rust-object-export.cc:154
+msgid "memory allocation failed while reading export data"
+msgstr ""
+
+#: go/go-backend.cc:181 rust/rust-object-export.cc:162
+msgid "read failed while reading export data"
+msgstr ""
+
+#: go/go-backend.cc:187 rust/rust-object-export.cc:168
+msgid "short read while reading export data"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:183 c-family/c-warn.cc:684 cp/cvt.cc:1419
+#: d/toir.cc:225 rust/backend/rust-tree.cc:512
+#, gcc-internal-format
+msgid "value computed is not used"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:1986
+msgid "unexpected reference to package"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:3840 go/gofrontend/expressions.cc:3856
+msgid "constant refers to itself"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:5062 go/gofrontend/expressions.cc:5483
+#: go/gofrontend/expressions.cc:5642
+msgid "expected pointer"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:5600
+msgid "expected numeric type"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:5605
+msgid "expected boolean type"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:5610 c/c-parser.cc:18370 c/c-parser.cc:18377
+#: cp/parser.cc:40919 cp/parser.cc:40926
+#, gcc-internal-format
+msgid "expected integer"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7603
+msgid "invalid comparison of nil with nil"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7609 go/gofrontend/expressions.cc:7627
+msgid "incompatible types in binary expression"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7647 go/gofrontend/statements.cc:1327
+msgid "integer division by zero"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7657 go/gofrontend/statements.cc:1336
+msgid "shift of non-integer operand"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7660 go/gofrontend/expressions.cc:7663
+#: go/gofrontend/expressions.cc:7671 go/gofrontend/statements.cc:1344
+#: go/gofrontend/statements.cc:1354
+msgid "shift count not integer"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:7676 go/gofrontend/statements.cc:1358
+msgid "negative shift count"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:8587
+msgid "object is not a method"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:8604
+msgid "method type does not match object type"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:9382
+msgid "argument of Offsetof implies indirection of an embedded field"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:9922
+msgid "len larger than cap"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11154 go/gofrontend/expressions.cc:11202
+#: go/gofrontend/expressions.cc:11372 go/gofrontend/expressions.cc:11427
+#: go/gofrontend/expressions.cc:11498 go/gofrontend/expressions.cc:11657
+#: go/gofrontend/expressions.cc:11703 go/gofrontend/expressions.cc:11738
+#: go/gofrontend/expressions.cc:11836 go/gofrontend/expressions.cc:13979
+#: go/gofrontend/expressions.cc:14138 go/gofrontend/expressions.cc:14155
+#: go/gofrontend/expressions.cc:14171
+msgid "not enough arguments"
+msgstr "არასაკმარისი არგუმენტები"
+
+#: go/gofrontend/expressions.cc:11159 go/gofrontend/expressions.cc:11207
+#: go/gofrontend/expressions.cc:11377 go/gofrontend/expressions.cc:11500
+#: go/gofrontend/expressions.cc:11627 go/gofrontend/expressions.cc:11662
+#: go/gofrontend/expressions.cc:11743 go/gofrontend/expressions.cc:11838
+#: go/gofrontend/expressions.cc:14014 go/gofrontend/expressions.cc:14143
+#: go/gofrontend/expressions.cc:14157 go/gofrontend/expressions.cc:14178
+#: cp/pt.cc:9381
+#, gcc-internal-format
+msgid "too many arguments"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11449
+msgid "invalid type for make function"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11459
+msgid "length required when allocating a slice"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11488
+msgid "too many arguments to make"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11502
+msgid "argument 1 must be a map"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11543
+msgid "argument must be array or slice or channel"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11553
+msgid "argument must be string or array or slice or map or channel"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11594
+msgid "unsupported argument type to builtin function"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11606
+msgid "argument must be channel"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11608
+msgid "cannot close receive-only channel"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11619
+msgid "argument to builtin has void type"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11645
+msgid "invalid use of method value as argument of Offsetof"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11648
+msgid "argument must be a field reference"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11678
+msgid "left argument must be a slice"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11686
+msgid "element types must be the same"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11691
+msgid "first argument must be []byte"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11694
+msgid "second argument must be slice or string"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11806
+msgid "argument must have complex type"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11822
+msgid "complex arguments must have identical types"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:11824
+msgid "complex arguments must have floating-point type"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:13781 go/gofrontend/expressions.cc:14520
+msgid "expected function"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:14097
+msgid "function result count mismatch"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:14123
+msgid "incompatible type for receiver"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:14529 go/gofrontend/expressions.cc:14543
+msgid "number of results does not match number of values"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:14671
+msgid "invalid 3-index slice of object that is not a slice"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:14674
+msgid "attempt to slice object that is not array, slice, or string"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:14677
+msgid "attempt to index object that is not array, slice, string, or map"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:14730
+msgid "attempt to index type expression"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:14757
+msgid "invalid 3-index slice of string"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:14770
+msgid "invalid slice of map"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:14779 go/gofrontend/expressions.cc:15970
+msgid "incompatible type for map index"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:16481
+msgid "expected interface or pointer to interface"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:18212
+msgid "may only omit types within composite literals of slice, array, or map type"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:18306 go/gofrontend/expressions.cc:18618
+msgid "map composite literal must have keys"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:18651
+msgid "expected struct, slice, array, or map type for composite literal"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:19266 go/gofrontend/statements.cc:2121
+msgid "type assertion only valid for interface types"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:19278
+msgid "impossible type assertion: type does not implement interface"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:19480 go/gofrontend/expressions.cc:19500
+#: go/gofrontend/statements.cc:1936
+msgid "expected channel"
+msgstr ""
+
+#: go/gofrontend/expressions.cc:19505 go/gofrontend/statements.cc:1941
+#: go/gofrontend/statements.cc:6847
+msgid "invalid receive on send-only channel"
+msgstr ""
+
+#: go/gofrontend/parse.cc:3277
+msgid "parentheses required around this composite literal to avoid parsing ambiguity"
+msgstr ""
+
+#: go/gofrontend/parse.cc:4851
+msgid "cannot fallthrough final case in switch"
+msgstr ""
+
+#: go/gofrontend/statements.cc:1288
+msgid "cannot use %<_%> as value"
+msgstr ""
+
+#: go/gofrontend/statements.cc:1300 go/gofrontend/statements.cc:2528
+msgid "invalid left hand side of assignment"
+msgstr ""
+
+#: go/gofrontend/statements.cc:1309
+msgid "incompatible type in binary expression"
+msgstr ""
+
+#: go/gofrontend/statements.cc:1555
+msgid "use of untyped nil"
+msgstr ""
+
+#: go/gofrontend/statements.cc:1689
+msgid "expected map index on right hand side"
+msgstr ""
+
+#: go/gofrontend/statements.cc:2534
+msgid "increment or decrement of non-numeric type"
+msgstr ""
+
+#: go/gofrontend/statements.cc:3449 go/gofrontend/statements.cc:3464
+msgid "not enough arguments to return"
+msgstr ""
+
+#: go/gofrontend/statements.cc:3455
+msgid "return with value in function with no return type"
+msgstr ""
+
+#: go/gofrontend/statements.cc:3470
+msgid "too many values in return statement"
+msgstr ""
+
+#: go/gofrontend/statements.cc:4062
+msgid "expected boolean expression"
+msgstr ""
+
+#: go/gofrontend/statements.cc:5299
+msgid "cannot type switch on non-interface value"
+msgstr ""
+
+#: go/gofrontend/statements.cc:5453
+msgid "incompatible types in send"
+msgstr ""
+
+#: go/gofrontend/statements.cc:5458
+msgid "invalid send on receive-only channel"
+msgstr ""
+
+#: go/gofrontend/statements.cc:6852
+msgid "too many variables for range clause with channel"
+msgstr ""
+
+#: go/gofrontend/statements.cc:6860
+msgid "range clause must have array, slice, string, map, or channel type"
+msgstr ""
+
+#: go/gofrontend/types.cc:552
+msgid "invalid comparison of non-ordered type"
+msgstr ""
+
+#: go/gofrontend/types.cc:568
+msgid "slice can only be compared to nil"
+msgstr ""
+
+#: go/gofrontend/types.cc:570
+msgid "map can only be compared to nil"
+msgstr ""
+
+#: go/gofrontend/types.cc:572
+msgid "func can only be compared to nil"
+msgstr ""
+
+#: go/gofrontend/types.cc:578
+#, c-format
+msgid "invalid operation (%s)"
+msgstr ""
+
+#: go/gofrontend/types.cc:601
+msgid "invalid comparison of non-comparable type"
+msgstr ""
+
+#: go/gofrontend/types.cc:614
+msgid "invalid comparison of generated struct"
+msgstr ""
+
+#: go/gofrontend/types.cc:625
+msgid "invalid comparison of non-comparable struct"
+msgstr ""
+
+#: go/gofrontend/types.cc:635
+msgid "invalid comparison of generated array"
+msgstr ""
+
+#: go/gofrontend/types.cc:642
+msgid "invalid comparison of non-comparable array"
+msgstr ""
+
+#: go/gofrontend/types.cc:670
+msgid "multiple-value function call in single-value context"
+msgstr ""
+
+#: go/gofrontend/types.cc:754
+msgid "need explicit conversion"
+msgstr ""
+
+#: go/gofrontend/types.cc:761
+#, c-format
+msgid "cannot use type %s as type %s"
+msgstr ""
+
+#: go/gofrontend/types.cc:796
+msgid "conversion from normal type to notinheap type"
+msgstr ""
+
+#: go/gofrontend/types.cc:4947
+msgid "different receiver types"
+msgstr ""
+
+#: go/gofrontend/types.cc:4970 go/gofrontend/types.cc:4983
+#: go/gofrontend/types.cc:4997
+msgid "different number of parameters"
+msgstr ""
+
+#: go/gofrontend/types.cc:4990
+msgid "different parameter types"
+msgstr ""
+
+#: go/gofrontend/types.cc:5005
+msgid "different varargs"
+msgstr ""
+
+#: go/gofrontend/types.cc:5018 go/gofrontend/types.cc:5031
+#: go/gofrontend/types.cc:5045
+msgid "different number of results"
+msgstr ""
+
+#: go/gofrontend/types.cc:5038
+msgid "different result types"
+msgstr ""
+
+#: go/gofrontend/types.cc:9611
+#, c-format
+msgid "need explicit conversion; missing method %s%s%s"
+msgstr ""
+
+#: go/gofrontend/types.cc:9629 go/gofrontend/types.cc:9776
+#, c-format
+msgid "incompatible type for method %s%s%s"
+msgstr ""
+
+#: go/gofrontend/types.cc:9633 go/gofrontend/types.cc:9780
+#, c-format
+msgid "incompatible type for method %s%s%s (%s)"
+msgstr ""
+
+#: go/gofrontend/types.cc:9716 go/gofrontend/types.cc:9729
+msgid "pointer to interface type has no methods"
+msgstr ""
+
+#: go/gofrontend/types.cc:9718 go/gofrontend/types.cc:9731
+msgid "type has no methods"
+msgstr ""
+
+#: go/gofrontend/types.cc:9752
+#, c-format
+msgid "ambiguous method %s%s%s"
+msgstr ""
+
+#: go/gofrontend/types.cc:9755
+#, c-format
+msgid "missing method %s%s%s"
+msgstr ""
+
+#: go/gofrontend/types.cc:9797
+#, c-format
+msgid "method %s%s%s requires a pointer receiver"
+msgstr ""
+
+#: go/gofrontend/types.cc:9815
+#, c-format
+msgid "method %s%s%s is marked go:nointerface"
+msgstr ""
+
+#: rust/resolve/rust-ast-resolve-expr.cc:140
+#, c-format
+msgid "You have broken GCC Rust. This is a feature.\n"
+msgstr ""
+
+#: lto-streamer.h:1033
+#, gcc-internal-format, gfc-internal-format
+msgid "bytecode stream: expected tag %s instead of %s"
+msgstr ""
+
+#: lto-streamer.h:1043
+#, gcc-internal-format, gfc-internal-format
+msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
+msgstr ""
+
+#. Mach-O supports 'weak imports', and 'weak definitions' in coalesced
+#. sections.  machopic_select_section ensures that weak variables go in
+#. coalesced sections.  Weak aliases (or any other kind of aliases) are
+#. not supported.  Weak symbols that aren't visible outside the .s file
+#. are not supported.
+#: config/darwin.h:711
+#, gcc-internal-format
+msgid "alias definitions not supported in Mach-O; ignored"
+msgstr ""
+
+#. No profiling.
+#: config/vx-common.h:123
+#, gcc-internal-format
+msgid "profiler support for VxWorks"
+msgstr ""
+
+#: config/arm/freebsd.h:121
+#, gcc-internal-format
+msgid "target OS does not support unaligned accesses"
+msgstr ""
+
+#: config/c6x/c6x.h:346 config/nvptx/nvptx.h:181
+#, gcc-internal-format
+msgid "profiling is not yet implemented for this architecture"
+msgstr ""
+
+#. Definitions for GCC.  Part of the machine description for CRIS.
+#. Copyright (C) 1998-2024 Free Software Foundation, Inc.
+#. Contributed by Axis Communications.  Written by Hans-Peter Nilsson.
+#.
+#. This file is part of GCC.
+#.
+#. GCC is free software; you can redistribute it and/or modify
+#. it under the terms of the GNU General Public License as published by
+#. the Free Software Foundation; either version 3, or (at your option)
+#. any later version.
+#.
+#. GCC is distributed in the hope that it will be useful,
+#. but WITHOUT ANY WARRANTY; without even the implied warranty of
+#. MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#. GNU General Public License for more details.
+#.
+#. You should have received a copy of the GNU General Public License
+#. along with GCC; see the file COPYING3.  If not see
+#. <http://www.gnu.org/licenses/>.
+#. After the first "Node:" comment comes all preprocessor directives and
+#. attached declarations described in the info files, the "Using and
+#. Porting GCC" manual (uapgcc), in the same order as found in the "Target
+#. macros" section in the gcc-2.9x CVS edition of 2000-03-17.  FIXME: Not
+#. really, but needs an update anyway.
+#.
+#. There is no generic copy-of-uapgcc comment, you'll have to see uapgcc
+#. for that.  If applicable, there is a CRIS-specific comment.  The order
+#. of macro definitions follow the order in the manual.  Every section in
+#. the manual (node in the info pages) has an introductory `Node:
+#. <subchapter>' comment.  If no macros are defined for a section, only
+#. the section-comment is present.
+#. Note that other header files (e.g. config/elfos.h, config/linux.h,
+#. and config/cris/linux.h) are responsible for lots of settings not
+#. repeated below.  This file contains general CRIS definitions
+#. and definitions for the cris-*-elf subtarget.
+#. We don't want to use gcc_assert for everything, as that can be
+#. compiled out.
+#: config/cris/cris.h:42
+#, gcc-internal-format, gfc-internal-format
+msgid "CRIS-port assertion failed: %s"
+msgstr ""
+
+#. Node: Caller Saves
+#. (no definitions)
+#. Node: Function entry
+#. See cris.cc for TARGET_ASM_FUNCTION_PROLOGUE and
+#. TARGET_ASM_FUNCTION_EPILOGUE.
+#. Node: Profiling
+#: config/cris/cris.h:661
+#, gcc-internal-format
+msgid "no %<FUNCTION_PROFILER%> for CRIS"
+msgstr ""
+
+#. If the environment variable DJDIR is not defined, then DJGPP is not        installed correctly and GCC will quickly become confused with the        default prefix settings. Report the problem now so the user doesn't        receive deceptive "file not found" error messages later.
+#. DJDIR is automatically defined by the DJGPP environment config            file pointed to by the environment variable DJGPP. Examine DJGPP            to try and figure out what's wrong.
+#: config/i386/xm-djgpp.h:85
+#, gcc-internal-format
+msgid "environment variable DJGPP not defined"
+msgstr ""
+
+#: config/i386/xm-djgpp.h:87
+#, gcc-internal-format
+msgid "environment variable DJGPP points to missing file %qs"
+msgstr ""
+
+#: config/i386/xm-djgpp.h:90
+#, gcc-internal-format
+msgid "environment variable DJGPP points to corrupt file %qs"
+msgstr ""
+
+#: config/pa/som.h:323
+#, gcc-internal-format
+msgid "weak aliases are not supported"
+msgstr ""
+
+#. SPDX-License-Identifier: GPL-3.0-or-later
+#. Definitions of target machine for GNU compiler,
+#. for IBM RS/6000 POWER running AIX V7.1.
+#. Copyright (C) 2002-2024 Free Software Foundation, Inc.
+#. Contributed by David Edelsohn (edelsohn@gnu.org).
+#.
+#. This file is part of GCC.
+#.
+#. GCC is free software; you can redistribute it and/or modify it
+#. under the terms of the GNU General Public License as published
+#. by the Free Software Foundation; either version 3, or (at your
+#. option) any later version.
+#.
+#. GCC is distributed in the hope that it will be useful, but WITHOUT
+#. ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+#. or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
+#. License for more details.
+#.
+#. You should have received a copy of the GNU General Public License
+#. along with GCC; see the file COPYING3.  If not see
+#. <http://www.gnu.org/licenses/>.
+#. The macro SUBTARGET_OVERRIDE_OPTIONS is provided for subtargets, to
+#. get control in TARGET_OPTION_OVERRIDE.
+#. SPDX-License-Identifier: GPL-3.0-or-later
+#. Definitions of target machine for GNU compiler,
+#. for IBM RS/6000 POWER running AIX V7.2.
+#. Copyright (C) 2002-2024 Free Software Foundation, Inc.
+#. Contributed by David Edelsohn (edelsohn@gnu.org).
+#.
+#. This file is part of GCC.
+#.
+#. GCC is free software; you can redistribute it and/or modify it
+#. under the terms of the GNU General Public License as published
+#. by the Free Software Foundation; either version 3, or (at your
+#. option) any later version.
+#.
+#. GCC is distributed in the hope that it will be useful, but WITHOUT
+#. ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+#. or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
+#. License for more details.
+#.
+#. You should have received a copy of the GNU General Public License
+#. along with GCC; see the file COPYING3.  If not see
+#. <http://www.gnu.org/licenses/>.
+#. The macro SUBTARGET_OVERRIDE_OPTIONS is provided for subtargets, to
+#. get control in TARGET_OPTION_OVERRIDE.
+#. SPDX-License-Identifier: GPL-3.0-or-later
+#. Definitions of target machine for GNU compiler,
+#. for IBM RS/6000 POWER running AIX V7.3.
+#. Copyright (C) 2002-2024 Free Software Foundation, Inc.
+#. Contributed by David Edelsohn (edelsohn@gnu.org).
+#.
+#. This file is part of GCC.
+#.
+#. GCC is free software; you can redistribute it and/or modify it
+#. under the terms of the GNU General Public License as published
+#. by the Free Software Foundation; either version 3, or (at your
+#. option) any later version.
+#.
+#. GCC is distributed in the hope that it will be useful, but WITHOUT
+#. ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+#. or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
+#. License for more details.
+#.
+#. You should have received a copy of the GNU General Public License
+#. along with GCC; see the file COPYING3.  If not see
+#. <http://www.gnu.org/licenses/>.
+#. The macro SUBTARGET_OVERRIDE_OPTIONS is provided for subtargets, to
+#. get control in TARGET_OPTION_OVERRIDE.
+#: config/rs6000/aix71.h:31 config/rs6000/aix72.h:31 config/rs6000/aix73.h:31
+#, gcc-internal-format
+msgid "%<-maix64%> requires PowerPC64 architecture remain enabled"
+msgstr ""
+
+#: config/rs6000/aix71.h:37 config/rs6000/aix72.h:37
+#, gcc-internal-format
+msgid "soft-float and long-double-128 are incompatible"
+msgstr ""
+
+#: config/rs6000/aix71.h:41 config/rs6000/aix72.h:41 config/rs6000/aix73.h:41
+#, gcc-internal-format
+msgid "%<-maix64%> required: 64-bit computation with 32-bit addressing not yet supported"
+msgstr ""
+
+#: config/rs6000/aix71.h:48 config/rs6000/aix72.h:48 config/rs6000/aix73.h:48
+#: config/rs6000/rtems.h:128 config/rs6000/rs6000.cc:3479
+#, gcc-internal-format
+msgid "%<-mcmodel%> incompatible with other toc options"
+msgstr ""
+
+#: config/rs6000/aix73.h:37
+#, gcc-internal-format
+msgid "%<soft-float%> and long-double-128 are incompatible"
+msgstr ""
+
+#: config/rs6000/rtems.h:121 config/rs6000/rs6000.cc:3471
+#, gcc-internal-format
+msgid "%<-m64%> requires a PowerPC64 cpu"
+msgstr ""
+
+#. The macro SUBTARGET_OVERRIDE_OPTIONS is provided for subtargets, to
+#. get control in TARGET_OPTION_OVERRIDE.
+#: config/rs6000/sysv4.h:116
+#, gcc-internal-format
+msgid "bad value for %<%s-%s%>"
+msgstr ""
+
+#: config/rs6000/sysv4.h:132
+#, gcc-internal-format
+msgid "bad value for %<%s=%s%>"
+msgstr ""
+
+#: config/rs6000/sysv4.h:149
+#, gcc-internal-format
+msgid "%qs and %<%s=%s%> are incompatible"
+msgstr ""
+
+#: config/rs6000/sysv4.h:158
+#, gcc-internal-format
+msgid "%<-f%s%> and %<%s=%s%> are incompatible"
+msgstr ""
+
+#: config/rs6000/sysv4.h:167
+#, gcc-internal-format
+msgid "%<%s=%s%> and %<%s-%s%> are incompatible"
+msgstr ""
+
+#: config/rs6000/sysv4.h:176 config/rs6000/sysv4.h:210
+#, gcc-internal-format
+msgid "%qs and %qs are incompatible"
+msgstr ""
+
+#: config/rs6000/sysv4.h:183 config/rs6000/sysv4.h:190
+#, gcc-internal-format
+msgid "%qs and %<%s-%s%> are incompatible"
+msgstr ""
+
+#: config/rs6000/sysv4.h:196 config/rs6000/sysv4.h:202
+#, gcc-internal-format
+msgid "%qs not supported by your assembler"
+msgstr ""
+
+#: config/rs6000/sysv4.h:244
+#, gcc-internal-format
+msgid "%<-m%s%> not supported in this configuration"
+msgstr ""
+
+#. The kernel loader cannot handle the relaxation			 relocations, so it cannot load kernel modules			 (which are ET_REL) or RTP executables (which are		 linked with --emit-relocs).  No relaxation relocations		 appear in shared libraries, so relaxation is OK		 for RTP PIC.
+#: config/sh/vxworks.h:43
+#, gcc-internal-format
+msgid "%<-mrelax%> is only supported for RTP PIC"
+msgstr ""
+
+#. A general purpose syntax error.
+#: fortran/gfortran.h:3416 fortran/io.cc:3727 fortran/io.cc:4413
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in %s statement at %C"
+msgstr ""
+
+#: jit/docs/examples/tut05-bf.c:242
+#, gcc-internal-format
+msgid "too many open parens"
+msgstr ""
+
+#: jit/docs/examples/tut05-bf.c:275
+#, gcc-internal-format
+msgid "mismatching parens"
+msgstr ""
+
+#: jit/docs/examples/tut05-bf.c:310
+#, gcc-internal-format
+msgid "unable to open file"
+msgstr ""
+
+#: m2/gm2-gcc/m2assert.h:36 m2/gm2-gcc/m2assert.h:59
+#, gcc-internal-format, gfc-internal-format
+msgid "%s:%d:condition %s failed"
+msgstr ""
+
+#: m2/gm2-gcc/m2assert.h:48
+#, gcc-internal-format, gfc-internal-format
+msgid "%s:%d:the value %s is not a BOOLEAN as the value is %d"
+msgstr ""
+
+#: fortran/lang.opt:432
+#, gcc-internal-format
+msgid "Unrecognized option to endianness value: %qs"
+msgstr ""
+
+#: fortran/lang.opt:654
+#, gcc-internal-format
+msgid "Unrecognized option to floating-point init value: %qs"
+msgstr ""
+
+#: fortran/lang.opt:792
+#, gcc-internal-format
+msgid "Unrecognized option: %qs"
+msgstr ""
+
+#: rust/lang.opt:90
+#, gcc-internal-format
+msgid "unknown crate type: '%qs'"
+msgstr ""
+
+#: rust/lang.opt:118
+#, gcc-internal-format
+msgid "unknown rust mangling option %qs"
+msgstr ""
+
+#: rust/lang.opt:135
+#, gcc-internal-format
+msgid "unknown rust edition %qs"
+msgstr ""
+
+#: rust/lang.opt:163
+#, gcc-internal-format
+msgid "unknown rust compile-until %qs"
+msgstr ""
+
+#: c-family/c.opt:43 c-family/c.opt:46 c-family/c.opt:181
+#, gcc-internal-format
+msgid "assertion missing after %qs"
+msgstr ""
+
+#: c-family/c.opt:55 c-family/c.opt:58 c-family/c.opt:163 c-family/c.opt:166
+#: c-family/c.opt:193 c-family/c.opt:276
+#, gcc-internal-format
+msgid "macro name missing after %qs"
+msgstr ""
+
+#: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
+#: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
+#: c-family/c.opt:236 c-family/c.opt:2373 c-family/c.opt:2381
+#: config/darwin.opt:30 common.opt:329 common.opt:332 common.opt:3680
+#, gcc-internal-format
+msgid "missing filename after %qs"
+msgstr ""
+
+#: c-family/c.opt:85 c-family/c.opt:88 c-family/c.opt:91 c-family/c.opt:94
+#: c-family/c.opt:200 c-family/c.opt:212 c-family/c.opt:268 c-family/c.opt:2369
+#: c-family/c.opt:2389 c-family/c.opt:2393 c-family/c.opt:2397
+#, gcc-internal-format
+msgid "missing path after %qs"
+msgstr ""
+
+#: c-family/c.opt:252 c-family/c.opt:256
+#, gcc-internal-format
+msgid "missing makefile target after %qs"
+msgstr ""
+
+#: c-family/c.opt:260
+#, gcc-internal-format
+msgid "missing format after %qs"
+msgstr ""
+
+#: c-family/c.opt:264
+#, gcc-internal-format
+msgid "missing output path after %qs"
+msgstr ""
+
+#: c-family/c.opt:311
+#, gcc-internal-format
+msgid "argument %qs to %<-Waligned-new%> not recognized"
+msgstr ""
+
+#: c-family/c.opt:406
+#, gcc-internal-format
+msgid "argument %qs to %<-Wbidi-chars%> not recognized"
+msgstr ""
+
+#: c-family/c.opt:1072
+#, gcc-internal-format
+msgid "argument %qs to %<-Wnormalized%> not recognized"
+msgstr ""
+
+#: c-family/c.opt:1736
+#, gcc-internal-format
+msgid "no class name specified with %qs"
+msgstr ""
+
+#: c-family/c.opt:1764
+#, gcc-internal-format
+msgid "argument %qs must be either %<on%> or %<off%>"
+msgstr ""
+
+#: c-family/c.opt:1908
+#, gcc-internal-format
+msgid "%<-fhandle-exceptions%> has been renamed %<-fexceptions%> (and is now on by default)"
+msgstr ""
+
+#: c-family/c.opt:1983
+#, gcc-internal-format
+msgid "missing mapper"
+msgstr ""
+
+#: c-family/c.opt:2011
+#, gcc-internal-format
+msgid "missing header name"
+msgstr ""
+
+#: c-family/c.opt:2019
+#, gcc-internal-format
+msgid "missing module name"
+msgstr ""
+
+#: c-family/c.opt:2066
+#, gcc-internal-format
+msgid "unrecognized ivar visibility value %qs"
+msgstr ""
+
+#: c-family/c.opt:2233
+#, gcc-internal-format
+msgid "unrecognized scalar storage order value %qs"
+msgstr ""
+
+#: d/lang.opt:201
+#, gcc-internal-format
+msgid "unknown array bounds setting %qs"
+msgstr ""
+
+#: d/lang.opt:243
+#, gcc-internal-format
+msgid "unknown checkaction setting %qs"
+msgstr ""
+
+#: d/lang.opt:303
+#, gcc-internal-format
+msgid "unknown C++ standard %qs"
+msgstr ""
+
+#: config/vms/vms.opt:42
+#, gcc-internal-format
+msgid "unknown pointer size model %qs"
+msgstr ""
+
+#: config/aarch64/aarch64.opt:379
+#, gcc-internal-format
+msgid "unknown LDP/STP policy %qs"
+msgstr ""
+
+#: config/i386/i386.opt:340
+#, gcc-internal-format
+msgid "%<-mcpu=%> is deprecated; use %<-mtune=%> or %<-march=%> instead"
+msgstr ""
+
+#: config/i386/i386.opt:400
+#, gcc-internal-format
+msgid "%<-mintel-syntax%> and %<-mno-intel-syntax%> are deprecated; use %<-masm=intel%> and %<-masm=att%> instead"
+msgstr ""
+
+#: config/i386/i386.opt:729
+#, gcc-internal-format
+msgid "%<-msse5%> was removed"
+msgstr ""
+
+#: config/i386/i386.opt:745
+#, gcc-internal-format
+msgid "AVX512PF support will be removed in GCC 15"
+msgstr ""
+
+#: config/i386/i386.opt:749
+#, gcc-internal-format
+msgid "AVX512ER support will be removed in GCC 15"
+msgstr ""
+
+#: config/i386/i386.opt:777
+#, gcc-internal-format
+msgid "AVX5124FMAPS support will be removed in GCC 15"
+msgstr ""
+
+#: config/i386/i386.opt:781
+#, gcc-internal-format
+msgid "AVX5124VNNIW support will be removed in GCC 15"
+msgstr ""
+
+#: config/i386/i386.opt:976
+#, gcc-internal-format
+msgid "PREFETCHWT1 support will be removed in GCC 15"
+msgstr ""
+
+#: config/i386/i386.opt:1290
+#, gcc-internal-format
+msgid "unknown lam type %qs"
+msgstr ""
+
+#: config/avr/avr.opt:26
+#, gcc-internal-format
+msgid "missing device or architecture after %qs"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:308
+#, gcc-internal-format
+msgid "%<-mvrsave=no%> is deprecated; use %<-mno-vrsave%> instead"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:312
+#, gcc-internal-format
+msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:379
+#, gcc-internal-format
+msgid "using darwin64 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:382
+#, gcc-internal-format
+msgid "using old darwin ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.opt:475
+#, gcc-internal-format
+msgid "Do not use %<-mpower8-internal%>; use %<-mcpu=power8%> instead"
+msgstr ""
+
+#: config/fused-madd.opt:22
+#, gcc-internal-format
+msgid "%<-mfused-madd%> is deprecated; use %<-ffp-contract=%> instead"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:87
+#, gcc-internal-format
+msgid "%qs is deprecated; use -fstack-check"
+msgstr ""
+
+#: config/microblaze/microblaze.opt:95
+#, gcc-internal-format
+msgid "%qs is deprecated; use -fno-zero-initialized-in-bss"
+msgstr ""
+
+#: config/arc/arc.opt:169 config/arc/arc.opt:333 config/arc/arc.opt:337
+#: config/arc/arc.opt:341 config/arc/arc.opt:348 config/arc/arc.opt:352
+#: config/arc/arc.opt:356 config/arc/arc.opt:360 config/arc/arc.opt:363
+#: config/arc/arc.opt:366 config/arc/arc.opt:383
+#, gcc-internal-format
+msgid "%qs is deprecated"
+msgstr ""
+
+#: lto/lang.opt:28
+#, gcc-internal-format
+msgid "unknown linker output %qs"
+msgstr ""
+
+#: common.opt:1640
+#, gcc-internal-format
+msgid "unknown excess precision style %qs"
+msgstr ""
+
+#: common.opt:1658
+#, gcc-internal-format
+msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
+msgstr ""
+
+#: common.opt:1702
+#, gcc-internal-format
+msgid "unknown floating point contraction style %qs"
+msgstr ""
+
+#: common.opt:1870
+#, gcc-internal-format
+msgid "unknown hardcfr noreturn checking level %qs"
+msgstr ""
+
+#: common.opt:1905
+#, gcc-internal-format
+msgid "unknown Stack Reuse Level %qs"
+msgstr ""
+
+#: common.opt:1977
+#, gcc-internal-format
+msgid "unavailable stringop for inlining %qs"
+msgstr ""
+
+#: common.opt:2008
+#, gcc-internal-format
+msgid "unknown Control-Flow Protection Level %qs"
+msgstr ""
+
+#: common.opt:2118
+#, gcc-internal-format
+msgid "unknown IRA algorithm %qs"
+msgstr ""
+
+#: common.opt:2131
+#, gcc-internal-format
+msgid "unknown IRA region %qs"
+msgstr ""
+
+#: common.opt:2209
+#, gcc-internal-format
+msgid "unknown LTO partitioning model %qs"
+msgstr ""
+
+#: common.opt:2323
+#, gcc-internal-format
+msgid "targets missing after %qs"
+msgstr ""
+
+#: common.opt:2326
+#, gcc-internal-format
+msgid "options or targets=options missing after %qs"
+msgstr ""
+
+#: common.opt:2334
+#, gcc-internal-format
+msgid "unknown offload ABI %qs"
+msgstr ""
+
+#: common.opt:2502
+#, gcc-internal-format
+msgid "unknown profile reproducibility method %qs"
+msgstr ""
+
+#: common.opt:2518
+#, gcc-internal-format
+msgid "unknown profile update method %qs"
+msgstr ""
+
+#: common.opt:2627
+#, gcc-internal-format
+msgid "unknown Live-Patching Level %qs"
+msgstr ""
+
+#: common.opt:2660
+#, gcc-internal-format
+msgid "unknown basic block reordering algorithm %qs"
+msgstr ""
+
+#: common.opt:2996
+#, gcc-internal-format
+msgid "unknown TLS model %qs"
+msgstr ""
+
+#: common.opt:3029
+#, gcc-internal-format
+msgid "unknown trampoline implementation %qs"
+msgstr ""
+
+#: common.opt:3351
+#, gcc-internal-format
+msgid "unknown vectorizer cost model %qs"
+msgstr ""
+
+#: common.opt:3382
+#, gcc-internal-format
+msgid "unrecognized automatic variable initialization type %qs"
+msgstr ""
+
+#: common.opt:3408
+#, gcc-internal-format
+msgid "unrecognized visibility value %qs"
+msgstr ""
+
+#: common.opt:3427
+#, gcc-internal-format
+msgid "unknown vtable verify initialization priority %qs"
+msgstr ""
+
+#: params.opt:893
+#, gcc-internal-format
+msgid "unknown ranger debug mode %qs"
+msgstr ""
+
+#: params.opt:1072
+#, gcc-internal-format
+msgid "unknown threader debug mode %qs"
+msgstr ""
+
+#: attribs.cc:242 attribs.cc:265 attribs.cc:278
+#, gcc-internal-format
+msgid "wrong argument to ignored attributes"
+msgstr ""
+
+#: attribs.cc:243
+#, gcc-internal-format
+msgid "valid format is %<ns::attr%> or %<ns::%>"
+msgstr ""
+
+#: attribs.cc:524
+#, gcc-internal-format
+msgid "ignoring attribute %qE in declaration of a built-in function %qD because it conflicts with attribute %qs"
+msgstr ""
+
+#: attribs.cc:530 c-family/c-attribs.cc:1271 c-family/c-attribs.cc:1315
+#, gcc-internal-format
+msgid "ignoring attribute %qE because it conflicts with attribute %qs"
+msgstr ""
+
+#: attribs.cc:536 c-family/c-attribs.cc:995 c-family/c-attribs.cc:2690
+#: c-family/c-attribs.cc:3177 c-family/c-attribs.cc:5054
+#: c-family/c-attribs.cc:5147 cp/decl.cc:16450 cp/decl.cc:16500
+#: cp/friend.cc:318 cp/tree.cc:5262
+#, gcc-internal-format
+msgid "previous declaration here"
+msgstr ""
+
+#. Warn about and ignore all others for now, but store them.
+#: attribs.cc:734 c-family/c-attribs.cc:4203 objc/objc-act.cc:5134
+#: objc/objc-act.cc:7125 objc/objc-act.cc:8323 objc/objc-act.cc:8379
+#, gcc-internal-format
+msgid "%qE attribute directive ignored"
+msgstr ""
+
+#: attribs.cc:744
+#, gcc-internal-format
+msgid "%<%E::%E%> scoped attribute directive ignored"
+msgstr ""
+
+#: attribs.cc:757 c/c-parser.cc:2084 cp/cp-gimplify.cc:3677
+#, gcc-internal-format
+msgid "wrong number of arguments specified for %qE attribute"
+msgstr ""
+
+#: attribs.cc:760
+#, gcc-internal-format, gfc-internal-format
+msgid "expected %i or more, found %i"
+msgstr ""
+
+#: attribs.cc:763 c/c-parser.cc:2087 cp/cp-gimplify.cc:3679
+#, gcc-internal-format, gfc-internal-format
+msgid "expected %i, found %i"
+msgstr ""
+
+#: attribs.cc:766
+#, gcc-internal-format, gfc-internal-format
+msgid "expected between %i and %i, found %i"
+msgstr ""
+
+#: attribs.cc:786 c-family/c-attribs.cc:4916
+#, gcc-internal-format
+msgid "%qE attribute does not apply to types"
+msgstr ""
+
+#: attribs.cc:834
+#, gcc-internal-format
+msgid "%qE attribute only applies to function types"
+msgstr ""
+
+#: attribs.cc:844
+#, gcc-internal-format
+msgid "type attributes ignored after type is already defined"
+msgstr ""
+
+#. The specifications of standard attributes in C mean
+#. this is a constraint violation.
+#. The specifications of standard attributes mean this is a
+#. constraint violation.
+#. An attribute with standard syntax and no namespace specified
+#. is a constraint violation if it is not one of the known
+#. standard attributes.  Diagnose it here with a pedwarn and
+#. then discard it to prevent a duplicate warning later.
+#: attribs.cc:938 attribs.cc:1926 attribs.cc:1936 attribs.cc:1946
+#: c-family/c-attribs.cc:1023 c-family/c-attribs.cc:1175
+#: c-family/c-attribs.cc:1194 c-family/c-attribs.cc:1212
+#: c-family/c-attribs.cc:1242 c-family/c-attribs.cc:1286
+#: c-family/c-attribs.cc:1330 c-family/c-attribs.cc:1371
+#: c-family/c-attribs.cc:1402 c-family/c-attribs.cc:1418
+#: c-family/c-attribs.cc:1435 c-family/c-attribs.cc:1451
+#: c-family/c-attribs.cc:1468 c-family/c-attribs.cc:1493
+#: c-family/c-attribs.cc:1509 c-family/c-attribs.cc:1524
+#: c-family/c-attribs.cc:1621 c-family/c-attribs.cc:1638
+#: c-family/c-attribs.cc:1656 c-family/c-attribs.cc:1681
+#: c-family/c-attribs.cc:1706 c-family/c-attribs.cc:1729
+#: c-family/c-attribs.cc:1746 c-family/c-attribs.cc:1775
+#: c-family/c-attribs.cc:1796 c-family/c-attribs.cc:1817
+#: c-family/c-attribs.cc:1844 c-family/c-attribs.cc:1875
+#: c-family/c-attribs.cc:1904 c-family/c-attribs.cc:1958
+#: c-family/c-attribs.cc:2011 c-family/c-attribs.cc:2077
+#: c-family/c-attribs.cc:2135 c-family/c-attribs.cc:2224
+#: c-family/c-attribs.cc:2254 c-family/c-attribs.cc:2305
+#: c-family/c-attribs.cc:2833 c-family/c-attribs.cc:3032
+#: c-family/c-attribs.cc:3093 c-family/c-attribs.cc:3330
+#: c-family/c-attribs.cc:3410 c-family/c-attribs.cc:3562
+#: c-family/c-attribs.cc:4017 c-family/c-attribs.cc:4083
+#: c-family/c-attribs.cc:4119 c-family/c-attribs.cc:4174
+#: c-family/c-attribs.cc:4356 c-family/c-attribs.cc:4377
+#: c-family/c-attribs.cc:4466 c-family/c-attribs.cc:4498
+#: c-family/c-attribs.cc:4563 c-family/c-attribs.cc:4769
+#: c-family/c-attribs.cc:4918 c-family/c-attribs.cc:5682
+#: c-family/c-attribs.cc:5701 c-family/c-attribs.cc:5724
+#: c-family/c-attribs.cc:5763 c-family/c-attribs.cc:5845
+#: c-family/c-attribs.cc:5877 c-family/c-attribs.cc:5919
+#: c-family/c-attribs.cc:5935 c-family/c-attribs.cc:6103
+#: c-family/c-attribs.cc:6115 c-family/c-common.cc:6138
+#: c-family/c-common.cc:6141 config/darwin.cc:2208 config/arm/arm.cc:7519
+#: config/arm/arm.cc:7546 config/arm/arm.cc:7563 config/avr/avr.cc:11255
+#: config/csky/csky.cc:6498 config/csky/csky.cc:6519 config/h8300/h8300.cc:4972
+#: config/h8300/h8300.cc:4996 config/i386/i386-options.cc:3777
+#: config/i386/i386-options.cc:3935 config/i386/i386-options.cc:4167
+#: config/i386/i386-options.cc:4197 config/ia64/ia64.cc:795
+#: config/loongarch/loongarch.cc:8006 config/rs6000/rs6000.cc:20753
+#: ada/gcc-interface/utils.cc:6746 ada/gcc-interface/utils.cc:6762
+#: ada/gcc-interface/utils.cc:6859 ada/gcc-interface/utils.cc:6876
+#: ada/gcc-interface/utils.cc:6893 ada/gcc-interface/utils.cc:6908
+#: ada/gcc-interface/utils.cc:6924 ada/gcc-interface/utils.cc:6950
+#: ada/gcc-interface/utils.cc:7019 ada/gcc-interface/utils.cc:7046
+#: ada/gcc-interface/utils.cc:7067 ada/gcc-interface/utils.cc:7088
+#: ada/gcc-interface/utils.cc:7136 ada/gcc-interface/utils.cc:7152
+#: ada/gcc-interface/utils.cc:7186 c/c-decl.cc:4902 c/c-decl.cc:4905
+#: c/c-decl.cc:4920 c/c-parser.cc:5835 cp/tree.cc:5016 cp/tree.cc:5427
+#: d/d-attribs.cc:483 d/d-attribs.cc:702 d/d-attribs.cc:723 d/d-attribs.cc:739
+#: d/d-attribs.cc:756 d/d-attribs.cc:788 d/d-attribs.cc:917 d/d-attribs.cc:976
+#: d/d-attribs.cc:992 d/d-attribs.cc:1008 d/d-attribs.cc:1157
+#: d/d-attribs.cc:1170 d/d-attribs.cc:1387 d/d-attribs.cc:1405
+#: d/d-attribs.cc:1452 d/d-attribs.cc:1490 d/d-attribs.cc:1506
+#: d/d-attribs.cc:1563 d/d-attribs.cc:1591 jit/dummy-frontend.cc:270
+#: jit/dummy-frontend.cc:304 jit/dummy-frontend.cc:599
+#: jit/dummy-frontend.cc:684 jit/dummy-frontend.cc:705
+#: jit/dummy-frontend.cc:724 jit/dummy-frontend.cc:755
+#: jit/dummy-frontend.cc:769 jit/dummy-frontend.cc:812
+#: jit/dummy-frontend.cc:832 jit/dummy-frontend.cc:893 lto/lto-lang.cc:302
+#: rust/rust-attribs.cc:171
+#, gcc-internal-format
+msgid "%qE attribute ignored"
+msgstr ""
+
+#: attribs.cc:1214
+#, gcc-internal-format
+msgid "missing %<target%> attribute for multi-versioned %qD"
+msgstr ""
+
+#: attribs.cc:1217 cp/decl.cc:1337 cp/decl.cc:2346 cp/decl.cc:2394
+#: cp/decl.cc:2410 cp/decl.cc:3090 cp/decl.cc:3542
+#, gcc-internal-format
+msgid "previous declaration of %qD"
+msgstr ""
+
+#: attribs.cc:1325
+#, gcc-internal-format
+msgid "ignoring attributes applied to %qT after definition"
+msgstr ""
+
+#: attribs.cc:1857
+#, gcc-internal-format
+msgid "%q+D already declared with dllexport attribute: dllimport ignored"
+msgstr ""
+
+#: attribs.cc:1869
+#, gcc-internal-format
+msgid "%q+D redeclared without dllimport attribute after being referenced with dll linkage"
+msgstr ""
+
+#: attribs.cc:1883
+#, gcc-internal-format
+msgid "%q+D redeclared without dllimport attribute: previous dllimport ignored"
+msgstr ""
+
+#: attribs.cc:1964
+#, gcc-internal-format
+msgid "inline function %q+D declared as dllimport: attribute ignored"
+msgstr ""
+
+#: attribs.cc:1972
+#, gcc-internal-format
+msgid "function %q+D definition is marked dllimport"
+msgstr ""
+
+#: attribs.cc:1980
+#, gcc-internal-format
+msgid "variable %q+D definition is marked dllimport"
+msgstr ""
+
+#: attribs.cc:2011
+#, gcc-internal-format
+msgid "external linkage required for symbol %q+D because of %qE attribute"
+msgstr ""
+
+#: attribs.cc:2025
+#, gcc-internal-format
+msgid "%qE implies default visibility, but %qD has already been declared with a different visibility"
+msgstr ""
+
+#: attribs.cc:2327
+#, gcc-internal-format
+msgid "%qD specifies more restrictive attribute than its target %qD: %s"
+msgid_plural "%qD specifies more restrictive attributes than its target %qD: %s"
+msgstr[0] ""
+msgstr[1] ""
+
+#: attribs.cc:2333 attribs.cc:2353
+#, gcc-internal-format
+msgid "%qD target declared here"
+msgstr ""
+
+#: attribs.cc:2347
+#, gcc-internal-format
+msgid "%qD specifies less restrictive attribute than its target %qD: %s"
+msgid_plural "%qD specifies less restrictive attributes than its target %qD: %s"
+msgstr[0] ""
+msgstr[1] ""
+
+#: auto-profile.cc:367
+#, gcc-internal-format
+msgid "offset exceeds 16 bytes"
+msgstr ""
+
+#: auto-profile.cc:864
+#, gcc-internal-format
+msgid "Not expected TAG."
+msgstr ""
+
+#: auto-profile.cc:929
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot open profile file %s"
+msgstr ""
+
+#: auto-profile.cc:935
+#, gcc-internal-format
+msgid "AutoFDO profile magic number does not match"
+msgstr ""
+
+#: auto-profile.cc:943
+#, gcc-internal-format, gfc-internal-format
+msgid "AutoFDO profile version %u does not match %u"
+msgstr ""
+
+#: auto-profile.cc:955
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot read string table from %s"
+msgstr ""
+
+#: auto-profile.cc:963
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot read function profile from %s"
+msgstr ""
+
+#: builtins.cc:703
+#, gcc-internal-format
+msgid "offset %qwi outside bounds of constant string"
+msgstr ""
+
+#: builtins.cc:707 cp/name-lookup.cc:6830
+#, gcc-internal-format
+msgid "%qE declared here"
+msgstr ""
+
+#: builtins.cc:1298
+#, gcc-internal-format
+msgid "second argument to %<__builtin_prefetch%> must be a constant"
+msgstr ""
+
+#: builtins.cc:1305
+#, gcc-internal-format
+msgid "invalid second argument to %<__builtin_prefetch%>; using zero"
+msgstr ""
+
+#: builtins.cc:1313
+#, gcc-internal-format
+msgid "third argument to %<__builtin_prefetch%> must be a constant"
+msgstr ""
+
+#: builtins.cc:1320
+#, gcc-internal-format
+msgid "invalid third argument to %<__builtin_prefetch%>; using zero"
+msgstr ""
+
+#: builtins.cc:4048 gimple-fold.cc:2525 gimple-ssa-warn-access.cc:2567
+#: tree-ssa-strlen.cc:3179
+#, gcc-internal-format
+msgid "%qD specified bound %E equals destination size"
+msgstr ""
+
+#: builtins.cc:5297 gimplify.cc:3922
+#, gcc-internal-format
+msgid "too few arguments to function %<va_start%>"
+msgstr ""
+
+#: builtins.cc:5397
+#, gcc-internal-format
+msgid "invalid argument to %qD"
+msgstr ""
+
+#: builtins.cc:5410
+#, gcc-internal-format
+msgid "unsupported argument to %qD"
+msgstr ""
+
+#. Warn since no effort is made to ensure that any frame
+#. beyond the current one exists or can be safely reached.
+#: builtins.cc:5418
+#, gcc-internal-format
+msgid "calling %qD with a nonzero argument is unsafe"
+msgstr ""
+
+#: builtins.cc:6048
+#, gcc-internal-format
+msgid "both arguments to %<__builtin___clear_cache%> must be pointers"
+msgstr ""
+
+#: builtins.cc:6138
+#, gcc-internal-format
+msgid "trampoline generated for nested function %qD"
+msgstr ""
+
+#: builtins.cc:6512 builtins.cc:6525
+#, gcc-internal-format
+msgid "%qD changed semantics in GCC 4.4"
+msgstr ""
+
+#: builtins.cc:7295
+#, gcc-internal-format
+msgid "non-constant argument 1 to %qs"
+msgstr ""
+
+#: builtins.cc:7337
+#, gcc-internal-format
+msgid "non-integer argument 1 to %qs"
+msgstr ""
+
+#: builtins.cc:7401
+#, gcc-internal-format
+msgid "%<__builtin_thread_pointer%> is not supported on this target"
+msgstr ""
+
+#: builtins.cc:7421
+#, gcc-internal-format
+msgid "%<__builtin_set_thread_pointer%> is not supported on this target"
+msgstr ""
+
+#: builtins.cc:7480
+#, gcc-internal-format
+msgid "%qs only supported in OpenACC code"
+msgstr ""
+
+#: builtins.cc:7487
+#, gcc-internal-format
+msgid "non-constant argument 0 to %qs"
+msgstr ""
+
+#: builtins.cc:7499
+#, gcc-internal-format
+msgid "illegal argument 0 to %qs"
+msgstr ""
+
+#. All valid uses of __builtin_va_arg_pack () are removed during
+#. inlining.
+#: builtins.cc:8018 expr.cc:12326
+#, gcc-internal-format
+msgid "invalid use of %<__builtin_va_arg_pack ()%>"
+msgstr ""
+
+#. All valid uses of __builtin_va_arg_pack_len () are removed during
+#. inlining.
+#: builtins.cc:8024
+#, gcc-internal-format
+msgid "invalid use of %<__builtin_va_arg_pack_len ()%>"
+msgstr ""
+
+#: builtins.cc:8313
+#, gcc-internal-format
+msgid "%<__builtin_longjmp%> second argument must be 1"
+msgstr ""
+
+#: builtins.cc:9216
+#, gcc-internal-format
+msgid "target format does not support infinity"
+msgstr ""
+
+#: builtins.cc:11247
+#, gcc-internal-format
+msgid "%<va_start%> used in function with fixed arguments"
+msgstr ""
+
+#: builtins.cc:11255
+#, gcc-internal-format
+msgid "wrong number of arguments to function %<va_start%>"
+msgstr ""
+
+#: builtins.cc:11270
+#, gcc-internal-format
+msgid "%<__builtin_next_arg%> called without an argument"
+msgstr ""
+
+#: builtins.cc:11275
+#, gcc-internal-format
+msgid "wrong number of arguments to function %<__builtin_next_arg%>"
+msgstr ""
+
+#: builtins.cc:11308
+#, gcc-internal-format
+msgid "second parameter of %<va_start%> not last named argument"
+msgstr ""
+
+#: builtins.cc:11321
+#, gcc-internal-format
+msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
+msgstr ""
+
+#: builtins.cc:11350
+#, gcc-internal-format
+msgid "first argument of %qD must be a pointer, second integer constant"
+msgstr ""
+
+#: builtins.cc:11363
+#, gcc-internal-format
+msgid "last argument of %qD is not integer constant between 0 and 3"
+msgstr ""
+
+#: calls.cc:1251
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot tail-call: %s"
+msgstr ""
+
+#: calls.cc:2779
+#, gcc-internal-format
+msgid "function call has aggregate value"
+msgstr ""
+
+#: calls.cc:3509
+#, gcc-internal-format
+msgid "passing too large argument on stack"
+msgstr ""
+
+#: cfganal.cc:173
+#, gcc-internal-format
+msgid "%<verify_marked_backedges%> failed"
+msgstr ""
+
+#: cfgexpand.cc:1850
+#, gcc-internal-format
+msgid "total size of local objects is too large"
+msgstr ""
+
+#: cfgexpand.cc:1853 function.cc:1016 varasm.cc:2360
+#, gcc-internal-format
+msgid "size of variable %q+D is too large"
+msgstr ""
+
+#: cfgexpand.cc:1865
+#, gcc-internal-format
+msgid "cannot allocate stack for variable %q+D, naked function"
+msgstr ""
+
+#: cfgexpand.cc:2962
+#, gcc-internal-format
+msgid "too many alternatives in %<asm%>"
+msgstr ""
+
+#: cfgexpand.cc:2969
+#, gcc-internal-format
+msgid "operand constraints for %<asm%> differ in number of alternatives"
+msgstr ""
+
+#: cfgexpand.cc:2991
+#, gcc-internal-format
+msgid "%<asm%> specifier for variable %qE conflicts with %<asm%> clobber list"
+msgstr ""
+
+#. ??? Diagnose during gimplification?
+#: cfgexpand.cc:3022
+#, gcc-internal-format
+msgid "PIC register clobbered by %qs in %<asm%>"
+msgstr ""
+
+#. ??? Diagnose during gimplification?
+#: cfgexpand.cc:3029
+#, gcc-internal-format
+msgid "the register %qs cannot be clobbered in %<asm%> for the current target"
+msgstr ""
+
+#: cfgexpand.cc:3042
+#, gcc-internal-format
+msgid "listing the stack pointer register %qs in a clobber list is deprecated"
+msgstr ""
+
+#: cfgexpand.cc:3044
+#, gcc-internal-format
+msgid "the value of the stack pointer after an %<asm%> statement must be the same as it was before the statement"
+msgstr ""
+
+#: cfgexpand.cc:3114
+#, gcc-internal-format
+msgid "more than %d operands in %<asm%>"
+msgstr ""
+
+#. ??? Diagnose during gimplification?
+#: cfgexpand.cc:3167
+#, gcc-internal-format
+msgid "unknown register name %qs in %<asm%>"
+msgstr ""
+
+#: cfgexpand.cc:3233
+#, gcc-internal-format
+msgid "invalid hard register usage between output operands"
+msgstr ""
+
+#: cfgexpand.cc:3260
+#, gcc-internal-format
+msgid "invalid hard register usage between output operand and matching constraint operand"
+msgstr ""
+
+#: cfgexpand.cc:3268
+#, gcc-internal-format
+msgid "invalid hard register usage between earlyclobber operand and input operand"
+msgstr ""
+
+#: cfgexpand.cc:3353
+#, gcc-internal-format, gfc-internal-format
+msgid "output number %d not directly addressable"
+msgstr ""
+
+#: cfgexpand.cc:3449
+#, gcc-internal-format
+msgid "%<asm%> operand %d probably does not match constraints"
+msgstr ""
+
+#: cfgexpand.cc:3642
+#, gcc-internal-format
+msgid "%<asm%> clobber conflict with output operand"
+msgstr ""
+
+#: cfgexpand.cc:3647
+#, gcc-internal-format
+msgid "%<asm%> clobber conflict with input operand"
+msgstr ""
+
+#: cfgexpand.cc:6725
+#, gcc-internal-format
+msgid "stack protector not protecting local variables: variable length buffer"
+msgstr ""
+
+#: cfgexpand.cc:6729
+#, gcc-internal-format, gfc-internal-format
+msgid "stack protector not protecting function: all local arrays are less than %d bytes long"
+msgstr ""
+
+#: cfgexpand.cc:7018
+#, gcc-internal-format
+msgid "patchable function entry %wu exceeds size %wu"
+msgstr ""
+
+#: cfghooks.cc:120
+#, gcc-internal-format, gfc-internal-format
+msgid "bb %d on wrong place"
+msgstr ""
+
+#: cfghooks.cc:126
+#, gcc-internal-format, gfc-internal-format
+msgid "prev_bb of %d should be %d, not %d"
+msgstr ""
+
+#: cfghooks.cc:143
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Block %i has loop_father, but there are no loops"
+msgstr ""
+
+#: cfghooks.cc:149
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Block %i lacks loop_father"
+msgstr ""
+
+#: cfghooks.cc:155
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Wrong count of block %i"
+msgstr ""
+
+#: cfghooks.cc:163
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Missing count of block %i"
+msgstr ""
+
+#: cfghooks.cc:169
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: unallocated flag set on BB %d"
+msgstr ""
+
+#: cfghooks.cc:177
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Duplicate edge %i->%i"
+msgstr ""
+
+#: cfghooks.cc:186
+#, gcc-internal-format, gfc-internal-format
+msgid "Uninitialized probability of edge %i->%i"
+msgstr ""
+
+#: cfghooks.cc:192
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Wrong probability of edge %i->%i"
+msgstr ""
+
+#: cfghooks.cc:204
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Basic block %d succ edge is corrupted"
+msgstr ""
+
+#: cfghooks.cc:216
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: unallocated edge flag set on %d -> %d"
+msgstr ""
+
+#: cfghooks.cc:225
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong amount of branch edges after unconditional jump %i"
+msgstr ""
+
+#: cfghooks.cc:233 cfghooks.cc:244
+#, gcc-internal-format, gfc-internal-format
+msgid "basic block %d pred edge is corrupted"
+msgstr ""
+
+#: cfghooks.cc:245
+#, gcc-internal-format, gfc-internal-format
+msgid "its dest_idx should be %d, not %d"
+msgstr ""
+
+#: cfghooks.cc:274
+#, gcc-internal-format, gfc-internal-format
+msgid "basic block %i edge lists are corrupted"
+msgstr ""
+
+#: cfghooks.cc:287
+#, gcc-internal-format
+msgid "verify_flow_info failed"
+msgstr ""
+
+#: cfghooks.cc:345
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support dump_bb_for_graph"
+msgstr ""
+
+#: cfghooks.cc:388
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support redirect_edge_and_branch"
+msgstr ""
+
+#: cfghooks.cc:408
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support can_remove_branch_p"
+msgstr ""
+
+#: cfghooks.cc:502
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support redirect_edge_and_branch_force"
+msgstr ""
+
+#: cfghooks.cc:540
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support split_block"
+msgstr ""
+
+#: cfghooks.cc:605
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support move_block_after"
+msgstr ""
+
+#: cfghooks.cc:618
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support delete_basic_block"
+msgstr ""
+
+#: cfghooks.cc:665
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support split_edge"
+msgstr ""
+
+#: cfghooks.cc:743
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support create_basic_block"
+msgstr ""
+
+#: cfghooks.cc:784
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support can_merge_blocks_p"
+msgstr ""
+
+#: cfghooks.cc:795
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support predict_edge"
+msgstr ""
+
+#: cfghooks.cc:804
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support predicted_by_p"
+msgstr ""
+
+#: cfghooks.cc:818
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support merge_blocks"
+msgstr ""
+
+#: cfghooks.cc:899
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support make_forwarder_block"
+msgstr ""
+
+#: cfghooks.cc:1048
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support force_nonfallthru"
+msgstr ""
+
+#: cfghooks.cc:1082
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support can_duplicate_block_p"
+msgstr ""
+
+#: cfghooks.cc:1111
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support duplicate_block"
+msgstr ""
+
+#: cfghooks.cc:1186
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support block_ends_with_call_p"
+msgstr ""
+
+#: cfghooks.cc:1197
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support block_ends_with_condjump_p"
+msgstr ""
+
+#: cfghooks.cc:1215
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support flow_call_edges_add"
+msgstr ""
+
+#: cfgloop.cc:1404
+#, gcc-internal-format
+msgid "loop verification on loop tree that needs fixup"
+msgstr ""
+
+#: cfgloop.cc:1420
+#, gcc-internal-format
+msgid "corrupt loop tree root"
+msgstr ""
+
+#: cfgloop.cc:1430
+#, gcc-internal-format, gfc-internal-format
+msgid "loop with header %d marked for removal"
+msgstr ""
+
+#: cfgloop.cc:1435
+#, gcc-internal-format, gfc-internal-format
+msgid "loop with header %d not in loop tree"
+msgstr ""
+
+#: cfgloop.cc:1441
+#, gcc-internal-format, gfc-internal-format
+msgid "non-loop with header %d not marked for removal"
+msgstr ""
+
+#: cfgloop.cc:1455
+#, gcc-internal-format, gfc-internal-format
+msgid "removed loop %d in loop tree"
+msgstr ""
+
+#: cfgloop.cc:1463
+#, gcc-internal-format, gfc-internal-format
+msgid "size of loop %d should be %d, not %d"
+msgstr ""
+
+#: cfgloop.cc:1474
+#, gcc-internal-format, gfc-internal-format
+msgid "bb %d does not belong to loop %d"
+msgstr ""
+
+#: cfgloop.cc:1486
+#, gcc-internal-format, gfc-internal-format
+msgid "bb %d has father loop %d, should be loop %d"
+msgstr ""
+
+#: cfgloop.cc:1502
+#, gcc-internal-format
+msgid "loop %d%'s header is not a loop header"
+msgstr ""
+
+#: cfgloop.cc:1508
+#, gcc-internal-format
+msgid "loop %d%'s header does not have exactly 2 entries"
+msgstr ""
+
+#: cfgloop.cc:1515
+#, gcc-internal-format
+msgid "loop %d%'s latch does not have an edge to its header"
+msgstr ""
+
+#: cfgloop.cc:1520
+#, gcc-internal-format
+msgid "loop %d%'s latch is not dominated by its header"
+msgstr ""
+
+#: cfgloop.cc:1528
+#, gcc-internal-format
+msgid "loop %d%'s latch does not have exactly 1 successor"
+msgstr ""
+
+#: cfgloop.cc:1533
+#, gcc-internal-format
+msgid "loop %d%'s latch does not have header as successor"
+msgstr ""
+
+#: cfgloop.cc:1538
+#, gcc-internal-format
+msgid "loop %d%'s latch does not belong directly to it"
+msgstr ""
+
+#: cfgloop.cc:1544
+#, gcc-internal-format
+msgid "loop %d%'s header does not belong directly to it"
+msgstr ""
+
+#: cfgloop.cc:1554
+#, gcc-internal-format
+msgid "loop %d%'s latch is marked as part of irreducible region"
+msgstr ""
+
+#: cfgloop.cc:1566
+#, gcc-internal-format
+msgid "loop %d%'s number of iterations %qE references the released SSA name %qE"
+msgstr ""
+
+#: cfgloop.cc:1599
+#, gcc-internal-format, gfc-internal-format
+msgid "basic block %d should be marked irreducible"
+msgstr ""
+
+#: cfgloop.cc:1605
+#, gcc-internal-format, gfc-internal-format
+msgid "basic block %d should not be marked irreducible"
+msgstr ""
+
+#: cfgloop.cc:1614
+#, gcc-internal-format, gfc-internal-format
+msgid "edge from %d to %d should be marked irreducible"
+msgstr ""
+
+#: cfgloop.cc:1621
+#, gcc-internal-format, gfc-internal-format
+msgid "edge from %d to %d should not be marked irreducible"
+msgstr ""
+
+#: cfgloop.cc:1635
+#, gcc-internal-format, gfc-internal-format
+msgid "corrupted head of the exits list of loop %d"
+msgstr ""
+
+#: cfgloop.cc:1653
+#, gcc-internal-format, gfc-internal-format
+msgid "corrupted exits list of loop %d"
+msgstr ""
+
+#: cfgloop.cc:1662
+#, gcc-internal-format, gfc-internal-format
+msgid "nonempty exits list of loop %d, but exits are not recorded"
+msgstr ""
+
+#: cfgloop.cc:1689
+#, gcc-internal-format, gfc-internal-format
+msgid "exit %d->%d not recorded"
+msgstr ""
+
+#: cfgloop.cc:1712
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong list of exited loops for edge %d->%d"
+msgstr ""
+
+#: cfgloop.cc:1721
+#, gcc-internal-format
+msgid "too many loop exits recorded"
+msgstr ""
+
+#: cfgloop.cc:1732
+#, gcc-internal-format, gfc-internal-format
+msgid "%d exits recorded for loop %d (having %d exits)"
+msgstr ""
+
+#: cfgrtl.cc:2441
+#, gcc-internal-format, gfc-internal-format
+msgid "non-cold basic block %d reachable only by paths crossing the cold partition"
+msgstr ""
+
+#: cfgrtl.cc:2561
+#, gcc-internal-format, gfc-internal-format
+msgid "multiple hot/cold transitions found (bb %i)"
+msgstr ""
+
+#: cfgrtl.cc:2569
+#, gcc-internal-format
+msgid "partition found but function partition flag not set"
+msgstr ""
+
+#: cfgrtl.cc:2608
+#, gcc-internal-format
+msgid "verify_flow_info: REG_BR_PROB is set but cfg probability is not"
+msgstr ""
+
+#: cfgrtl.cc:2617
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: REG_BR_PROB does not match cfg %i %i"
+msgstr ""
+
+#: cfgrtl.cc:2639
+#, gcc-internal-format
+msgid "EDGE_CROSSING incorrectly set across same section"
+msgstr ""
+
+#: cfgrtl.cc:2644
+#, gcc-internal-format, gfc-internal-format
+msgid "fallthru edge crosses section boundary in bb %i"
+msgstr ""
+
+#: cfgrtl.cc:2650
+#, gcc-internal-format, gfc-internal-format
+msgid "EH edge crosses section boundary in bb %i"
+msgstr ""
+
+#: cfgrtl.cc:2656
+#, gcc-internal-format, gfc-internal-format
+msgid "No region crossing jump at section boundary in bb %i"
+msgstr ""
+
+#: cfgrtl.cc:2663
+#, gcc-internal-format
+msgid "EDGE_CROSSING missing across section boundary"
+msgstr ""
+
+#: cfgrtl.cc:2693
+#, gcc-internal-format, gfc-internal-format
+msgid "Region crossing jump across same section in bb %i"
+msgstr ""
+
+#: cfgrtl.cc:2700
+#, gcc-internal-format, gfc-internal-format
+msgid "missing REG_EH_REGION note at the end of bb %i"
+msgstr ""
+
+#: cfgrtl.cc:2705
+#, gcc-internal-format, gfc-internal-format
+msgid "too many exception handling edges in bb %i"
+msgstr ""
+
+#: cfgrtl.cc:2713
+#, gcc-internal-format, gfc-internal-format
+msgid "too many outgoing branch edges from bb %i"
+msgstr ""
+
+#: cfgrtl.cc:2718
+#, gcc-internal-format, gfc-internal-format
+msgid "fallthru edge after unconditional jump in bb %i"
+msgstr ""
+
+#: cfgrtl.cc:2723
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong number of branch edges after unconditional jump in bb %i"
+msgstr ""
+
+#: cfgrtl.cc:2730
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong amount of branch edges after conditional jump in bb %i"
+msgstr ""
+
+#: cfgrtl.cc:2736
+#, gcc-internal-format, gfc-internal-format
+msgid "abnormal call edges for non-call insn in bb %i"
+msgstr ""
+
+#: cfgrtl.cc:2741
+#, gcc-internal-format, gfc-internal-format
+msgid "sibcall edges for non-call insn in bb %i"
+msgstr ""
+
+#: cfgrtl.cc:2751
+#, gcc-internal-format, gfc-internal-format
+msgid "abnormal edges for no purpose in bb %i"
+msgstr ""
+
+#: cfgrtl.cc:2762
+#, gcc-internal-format, gfc-internal-format
+msgid "EH incoming edge mixed with non-EH incoming edges in bb %i"
+msgstr ""
+
+#: cfgrtl.cc:2803 cfgrtl.cc:2813
+#, gcc-internal-format, gfc-internal-format
+msgid "NOTE_INSN_BASIC_BLOCK is missing for block %d"
+msgstr ""
+
+#: cfgrtl.cc:2826
+#, gcc-internal-format, gfc-internal-format
+msgid "NOTE_INSN_BASIC_BLOCK %d in middle of basic block %d"
+msgstr ""
+
+#: cfgrtl.cc:2836
+#, gcc-internal-format, gfc-internal-format
+msgid "in basic block %d:"
+msgstr ""
+
+#: cfgrtl.cc:2862
+#, gcc-internal-format, gfc-internal-format
+msgid "BB_RTL flag not set for block %d"
+msgstr ""
+
+#: cfgrtl.cc:2869
+#, gcc-internal-format, gfc-internal-format
+msgid "insn %d basic block pointer is %d, should be %d"
+msgstr ""
+
+#: cfgrtl.cc:2880
+#, gcc-internal-format, gfc-internal-format
+msgid "insn %d in header of bb %d has non-NULL basic block"
+msgstr ""
+
+#: cfgrtl.cc:2888
+#, gcc-internal-format, gfc-internal-format
+msgid "insn %d in footer of bb %d has non-NULL basic block"
+msgstr ""
+
+#: cfgrtl.cc:2964 cfgrtl.cc:3012
+#, gcc-internal-format, gfc-internal-format
+msgid "insn %d outside of basic blocks has non-NULL bb field"
+msgstr ""
+
+#: cfgrtl.cc:2972
+#, gcc-internal-format, gfc-internal-format
+msgid "end insn %d for block %d not found in the insn stream"
+msgstr ""
+
+#: cfgrtl.cc:2985
+#, gcc-internal-format, gfc-internal-format
+msgid "insn %d is in multiple basic blocks (%d and %d)"
+msgstr ""
+
+#: cfgrtl.cc:2997
+#, gcc-internal-format, gfc-internal-format
+msgid "head insn %d for block %d not found in the insn stream"
+msgstr ""
+
+#: cfgrtl.cc:3045
+#, gcc-internal-format, gfc-internal-format
+msgid "missing barrier after block %i"
+msgstr ""
+
+#: cfgrtl.cc:3061
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Incorrect blocks for fallthru %i->%i"
+msgstr ""
+
+#: cfgrtl.cc:3070
+#, gcc-internal-format, gfc-internal-format
+msgid "verify_flow_info: Incorrect fallthru %i->%i"
+msgstr ""
+
+#: cfgrtl.cc:3072
+#, gcc-internal-format
+msgid "wrong insn in the fallthru edge"
+msgstr ""
+
+#: cfgrtl.cc:3106
+#, gcc-internal-format
+msgid "basic blocks not laid down consecutively"
+msgstr ""
+
+#: cfgrtl.cc:3145
+#, gcc-internal-format, gfc-internal-format
+msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
+msgstr ""
+
+#: cgraph.cc:3262
+#, gcc-internal-format
+msgid "caller edge count invalid"
+msgstr ""
+
+#: cgraph.cc:3359
+#, gcc-internal-format
+msgid "missing indirect call in speculative call sequence"
+msgstr ""
+
+#: cgraph.cc:3364
+#, gcc-internal-format
+msgid "indirect call in speculative call sequence has no speculative flag"
+msgstr ""
+
+#: cgraph.cc:3394
+#, gcc-internal-format
+msgid "speculative edges are not adjacent"
+msgstr ""
+
+#: cgraph.cc:3400
+#, gcc-internal-format, gfc-internal-format
+msgid "direct call to %s in speculative call sequence has no speculative flag"
+msgstr ""
+
+#: cgraph.cc:3406 cgraph.cc:3436
+#, gcc-internal-format, gfc-internal-format
+msgid "direct call to %s in speculative call sequence has speculative_id %i out of range"
+msgstr ""
+
+#: cgraph.cc:3413
+#, gcc-internal-format, gfc-internal-format
+msgid "duplicate direct call to %s in speculative call sequence with speculative_id %i"
+msgstr ""
+
+#: cgraph.cc:3424
+#, gcc-internal-format
+msgid "call stmt hash does not point to first direct edge of speculative call sequence"
+msgstr ""
+
+#: cgraph.cc:3443
+#, gcc-internal-format, gfc-internal-format
+msgid "duplicate reference %s in speculative call sequence with speculative_id %i"
+msgstr ""
+
+#: cgraph.cc:3456
+#, gcc-internal-format, gfc-internal-format
+msgid "missing direct call for speculation %i"
+msgstr ""
+
+#: cgraph.cc:3461
+#, gcc-internal-format, gfc-internal-format
+msgid "missing ref for speculation %i"
+msgstr ""
+
+#: cgraph.cc:3470
+#, gcc-internal-format, gfc-internal-format
+msgid "number of speculative targets %i mismatched with num_speculative_call_targets %i"
+msgstr ""
+
+#: cgraph.cc:3499
+#, gcc-internal-format, gfc-internal-format
+msgid "aux field set for edge %s->%s"
+msgstr ""
+
+#: cgraph.cc:3506
+#, gcc-internal-format
+msgid "cgraph count invalid"
+msgstr ""
+
+#: cgraph.cc:3511
+#, gcc-internal-format
+msgid "inline clone in same comdat group list"
+msgstr ""
+
+#: cgraph.cc:3516
+#, gcc-internal-format
+msgid "inline clone count is not compatible"
+msgstr ""
+
+#: cgraph.cc:3523
+#, gcc-internal-format
+msgid "tp_first_run must be non-negative"
+msgstr ""
+
+#: cgraph.cc:3528
+#, gcc-internal-format
+msgid "local symbols must be defined"
+msgstr ""
+
+#: cgraph.cc:3533
+#, gcc-internal-format
+msgid "externally visible inline clone"
+msgstr ""
+
+#: cgraph.cc:3538
+#, gcc-internal-format
+msgid "inline clone with address taken"
+msgstr ""
+
+#: cgraph.cc:3543
+#, gcc-internal-format
+msgid "inline clone is forced to output"
+msgstr ""
+
+#: cgraph.cc:3550
+#, gcc-internal-format
+msgid "calls_comdat_local is set outside of a comdat group"
+msgstr ""
+
+#: cgraph.cc:3555
+#, gcc-internal-format
+msgid "invalid calls_comdat_local flag"
+msgstr ""
+
+#: cgraph.cc:3562
+#, gcc-internal-format
+msgid "malloc attribute should be used for a function that returns a pointer"
+msgstr ""
+
+#: cgraph.cc:3574
+#, gcc-internal-format
+msgid "semantic interposition mismatch"
+msgstr ""
+
+#: cgraph.cc:3581
+#, gcc-internal-format, gfc-internal-format
+msgid "aux field set for indirect edge from %s"
+msgstr ""
+
+#: cgraph.cc:3587 cgraph.cc:3647
+#, gcc-internal-format
+msgid "edge count is not compatible with function count"
+msgstr ""
+
+#: cgraph.cc:3595
+#, gcc-internal-format, gfc-internal-format
+msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
+msgstr ""
+
+#: cgraph.cc:3603 cgraph.cc:3675
+#, gcc-internal-format
+msgid "edge has both call_stmt and lto_stmt_uid set"
+msgstr ""
+
+#: cgraph.cc:3615
+#, gcc-internal-format, gfc-internal-format
+msgid "comdat-local function called by %s outside its comdat"
+msgstr ""
+
+#: cgraph.cc:3625
+#, gcc-internal-format
+msgid "inlined_to pointer is wrong"
+msgstr ""
+
+#: cgraph.cc:3630
+#, gcc-internal-format
+msgid "multiple inline callers"
+msgstr ""
+
+#: cgraph.cc:3637
+#, gcc-internal-format
+msgid "inlined_to pointer set for noninline callers"
+msgstr ""
+
+#: cgraph.cc:3665
+#, gcc-internal-format
+msgid "caller edge count does not match BB count"
+msgstr ""
+
+#: cgraph.cc:3696
+#, gcc-internal-format
+msgid "indirect call count does not match BB count"
+msgstr ""
+
+#: cgraph.cc:3713
+#, gcc-internal-format
+msgid "reference has both stmt and lto_stmt_uid set"
+msgstr ""
+
+#: cgraph.cc:3724
+#, gcc-internal-format
+msgid "inlined_to pointer is set but no predecessors found"
+msgstr ""
+
+#: cgraph.cc:3729
+#, gcc-internal-format
+msgid "inlined_to pointer refers to itself"
+msgstr ""
+
+#: cgraph.cc:3740
+#, gcc-internal-format
+msgid "cgraph_node has wrong clone_of"
+msgstr ""
+
+#: cgraph.cc:3753
+#, gcc-internal-format
+msgid "cgraph_node has wrong clone list"
+msgstr ""
+
+#: cgraph.cc:3759
+#, gcc-internal-format
+msgid "cgraph_node is in clone list but it is not clone"
+msgstr ""
+
+#: cgraph.cc:3764
+#, gcc-internal-format
+msgid "cgraph_node has wrong prev_clone pointer"
+msgstr ""
+
+#: cgraph.cc:3769
+#, gcc-internal-format
+msgid "double linked list of clones corrupted"
+msgstr ""
+
+#: cgraph.cc:3781
+#, gcc-internal-format
+msgid "Alias has call edges"
+msgstr ""
+
+#: cgraph.cc:3787
+#, gcc-internal-format
+msgid "Alias has non-alias reference"
+msgstr ""
+
+#: cgraph.cc:3792
+#, gcc-internal-format
+msgid "Alias has more than one alias reference"
+msgstr ""
+
+#: cgraph.cc:3799
+#, gcc-internal-format
+msgid "Analyzed alias has no reference"
+msgstr ""
+
+#: cgraph.cc:3808
+#, gcc-internal-format
+msgid "No edge out of thunk node"
+msgstr ""
+
+#: cgraph.cc:3813
+#, gcc-internal-format
+msgid "More than one edge out of thunk node"
+msgstr ""
+
+#: cgraph.cc:3818
+#, gcc-internal-format
+msgid "Thunk is not supposed to have body"
+msgstr ""
+
+#: cgraph.cc:3854
+#, gcc-internal-format
+msgid "shared call_stmt:"
+msgstr ""
+
+#: cgraph.cc:3862
+#, gcc-internal-format
+msgid "edge points to wrong declaration:"
+msgstr ""
+
+#: cgraph.cc:3871
+#, gcc-internal-format
+msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
+msgstr ""
+
+#: cgraph.cc:3881
+#, gcc-internal-format
+msgid "missing callgraph edge for call stmt:"
+msgstr ""
+
+#: cgraph.cc:3891
+#, gcc-internal-format
+msgid "reference to dead statement"
+msgstr ""
+
+#: cgraph.cc:3904
+#, gcc-internal-format, gfc-internal-format
+msgid "edge %s->%s has no corresponding call_stmt"
+msgstr ""
+
+#: cgraph.cc:3916
+#, gcc-internal-format, gfc-internal-format
+msgid "an indirect edge from %s has no corresponding call_stmt"
+msgstr ""
+
+#: cgraph.cc:3935 cgraph.cc:3948
+#, gcc-internal-format
+msgid "missing origin for a node in a nested list"
+msgstr ""
+
+#: cgraph.cc:3940
+#, gcc-internal-format
+msgid "origin points to a different parent"
+msgstr ""
+
+#: cgraph.cc:3956
+#, gcc-internal-format
+msgid "verify_cgraph_node failed"
+msgstr ""
+
+#: cgraph.cc:4078 varpool.cc:304
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: section %s.%d is missing"
+msgstr ""
+
+#: cgraphunit.cc:755
+#, gcc-internal-format
+msgid "duplicate definition of a symbol version"
+msgstr ""
+
+#: cgraphunit.cc:757
+#, gcc-internal-format
+msgid "same version was previously defined here"
+msgstr ""
+
+#: cgraphunit.cc:763
+#, gcc-internal-format
+msgid "symbol needs to be defined to have a version"
+msgstr ""
+
+#: cgraphunit.cc:769
+#, gcc-internal-format
+msgid "common symbol cannot be versioned"
+msgstr ""
+
+#: cgraphunit.cc:775
+#, gcc-internal-format
+msgid "comdat symbol cannot be versioned"
+msgstr ""
+
+#: cgraphunit.cc:781
+#, gcc-internal-format
+msgid "%<weakref%> cannot be versioned"
+msgstr ""
+
+#: cgraphunit.cc:787
+#, gcc-internal-format
+msgid "versioned symbol must be public"
+msgstr ""
+
+#: cgraphunit.cc:793
+#, gcc-internal-format
+msgid "versioned symbol must have default visibility"
+msgstr ""
+
+#: cgraphunit.cc:826
+#, gcc-internal-format
+msgid "%<weakref%> attribute should be accompanied with an %<alias%> attribute"
+msgstr ""
+
+#: cgraphunit.cc:881
+#, gcc-internal-format
+msgid "%<flatten%> attribute is ignored on aliases"
+msgstr ""
+
+#: cgraphunit.cc:889 cgraphunit.cc:941
+#, gcc-internal-format
+msgid "%<externally_visible%> attribute have effect only on public objects"
+msgstr ""
+
+#: cgraphunit.cc:900
+#, gcc-internal-format
+msgid "%<weakref%> attribute ignored because function is defined"
+msgstr ""
+
+#: cgraphunit.cc:915
+#, gcc-internal-format
+msgid "%<alias%> attribute ignored because function is defined"
+msgstr ""
+
+#: cgraphunit.cc:923
+#, gcc-internal-format
+msgid "%<always_inline%> function might not be inlinable unless also declared %<inline%>"
+msgstr ""
+
+#: cgraphunit.cc:949
+#, gcc-internal-format
+msgid "%<weakref%> attribute ignored because variable is initialized"
+msgstr ""
+
+#. include_self=
+#. TODO: Add OPT_Wundefined-inline.
+#: cgraphunit.cc:1098 c/c-decl.cc:13377
+#, gcc-internal-format
+msgid "%q+F used but never defined"
+msgstr ""
+
+#: cgraphunit.cc:1100 c/c-decl.cc:13387
+#, gcc-internal-format
+msgid "%q+F declared %<static%> but never defined"
+msgstr ""
+
+#: cgraphunit.cc:1144
+#, gcc-internal-format
+msgid "%qD defined but not used"
+msgstr ""
+
+#: cgraphunit.cc:1479
+#, gcc-internal-format
+msgid "%<ifunc%> resolver for %qD must return %qT"
+msgstr ""
+
+#: cgraphunit.cc:1482 cgraphunit.cc:1505
+#, gcc-internal-format
+msgid "resolver indirect function declared here"
+msgstr ""
+
+#: cgraphunit.cc:1502
+#, gcc-internal-format
+msgid "%<ifunc%> resolver for %qD should return %qT"
+msgstr ""
+
+#: cgraphunit.cc:1512
+#, gcc-internal-format
+msgid "%qD alias between functions of incompatible types %qT and %qT"
+msgstr ""
+
+#: cgraphunit.cc:1515 cgraphunit.cc:1597
+#, gcc-internal-format
+msgid "aliased declaration here"
+msgstr ""
+
+#: cgraphunit.cc:1553 c-family/c-pragma.cc:347
+#, gcc-internal-format
+msgid "%q+D aliased to undefined symbol %qE"
+msgstr ""
+
+#: cgraphunit.cc:1569
+#, gcc-internal-format
+msgid "%q+D aliased to external symbol %qE"
+msgstr ""
+
+#: cgraphunit.cc:1594
+#, gcc-internal-format
+msgid "%q+D alias between function and variable is not supported"
+msgstr ""
+
+#: cgraphunit.cc:1668
+#, gcc-internal-format
+msgid "failed to reclaim unneeded function"
+msgstr ""
+
+#: cgraphunit.cc:1696
+#, gcc-internal-format
+msgid "failed to reclaim unneeded function in same comdat group"
+msgstr ""
+
+#: cgraphunit.cc:1872
+#, gcc-internal-format
+msgid "size of return value of %q+D is %u bytes"
+msgstr ""
+
+#: cgraphunit.cc:1876
+#, gcc-internal-format
+msgid "size of return value of %q+D is larger than %wu bytes"
+msgstr ""
+
+#: cgraphunit.cc:2440
+#, gcc-internal-format
+msgid "nodes with unreleased memory found"
+msgstr ""
+
+#: collect-utils.cc:106
+#, gcc-internal-format
+msgid "cannot get program status: %m"
+msgstr ""
+
+#: collect-utils.cc:120
+#, gcc-internal-format, gfc-internal-format
+msgid "%s terminated with signal %d [%s]%s"
+msgstr ""
+
+#: collect-utils.cc:136
+#, gcc-internal-format, gfc-internal-format
+msgid "%s returned %d exit status"
+msgstr ""
+
+#: collect-utils.cc:175
+#, gcc-internal-format, gfc-internal-format
+msgid "could not open response file %s"
+msgstr ""
+
+#: collect-utils.cc:181
+#, gcc-internal-format, gfc-internal-format
+msgid "could not write to response file %s"
+msgstr ""
+
+#: collect-utils.cc:187
+#, gcc-internal-format, gfc-internal-format
+msgid "could not close response file %s"
+msgstr ""
+
+#: collect-utils.cc:221
+#, gcc-internal-format
+msgid "cannot find %qs"
+msgstr ""
+
+#: collect-utils.cc:225 collect2.cc:2389 collect2.cc:2559 gcc.cc:3419
+#: gcc.cc:7825
+#, gcc-internal-format
+msgid "%<pex_init%> failed: %m"
+msgstr ""
+
+#: collect-utils.cc:234 collect2.cc:2398 collect2.cc:2567 gcc.cc:2703
+#, gcc-internal-format
+msgid "%s: %m"
+msgstr "%s: %m"
+
+#: collect2.cc:613
+#, gcc-internal-format
+msgid "environment variable %<COLLECT_LTO_WRAPPER%> must be set"
+msgstr ""
+
+#: collect2.cc:756
+#, gcc-internal-format, gfc-internal-format
+msgid "ld returned %d exit status"
+msgstr ""
+
+#: collect2.cc:916 gcc.cc:8345 config/nvptx/mkoffload.cc:646
+#, gcc-internal-format
+msgid "atexit failed"
+msgstr ""
+
+#: collect2.cc:1046
+#, gcc-internal-format
+msgid "no arguments"
+msgstr ""
+
+#: collect2.cc:1287 opts.cc:1192
+#, gcc-internal-format
+msgid "LTO support has not been enabled in this configuration"
+msgstr ""
+
+#: collect2.cc:1328 graph.cc:55 lto-wrapper.cc:1724 lto-wrapper.cc:1780
+#: toplev.cc:1520 objc/objc-act.cc:462
+#, gcc-internal-format
+msgid "cannot open %s: %m"
+msgstr ""
+
+#: collect2.cc:1448
+#, gcc-internal-format
+msgid "unknown demangling style %qs"
+msgstr ""
+
+#: collect2.cc:1550 collect2.cc:1728 collect2.cc:1768
+#, gcc-internal-format
+msgid "fopen %s: %m"
+msgstr ""
+
+#: collect2.cc:1553 collect2.cc:1733 collect2.cc:1771
+#, gcc-internal-format
+msgid "fclose %s: %m"
+msgstr ""
+
+#: collect2.cc:2323 lto-wrapper.cc:1219 lto-wrapper.cc:1234
+#: lto/lto-object.cc:148 lto/lto-object.cc:182 lto/lto-object.cc:279
+#: lto/lto-object.cc:336 lto/lto-object.cc:360
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: %s"
+msgstr ""
+
+#: collect2.cc:2363
+#, gcc-internal-format
+msgid "cannot find %<nm%>"
+msgstr ""
+
+#: collect2.cc:2411
+#, gcc-internal-format
+msgid "cannot open nm output: %m"
+msgstr ""
+
+#: collect2.cc:2466
+#, gcc-internal-format, gfc-internal-format
+msgid "init function found in object %s"
+msgstr ""
+
+#: collect2.cc:2477
+#, gcc-internal-format, gfc-internal-format
+msgid "fini function found in object %s"
+msgstr ""
+
+#: collect2.cc:2534
+#, gcc-internal-format
+msgid "cannot find %<ldd%>"
+msgstr ""
+
+#: collect2.cc:2580
+#, gcc-internal-format
+msgid "cannot open ldd output: %m"
+msgstr ""
+
+#: collect2.cc:2598
+#, gcc-internal-format, gfc-internal-format
+msgid "dynamic dependency %s not found"
+msgstr ""
+
+#: collect2.cc:2610
+#, gcc-internal-format
+msgid "unable to open dynamic dependency %qs"
+msgstr ""
+
+#: collect2.cc:2762
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: not a COFF file"
+msgstr ""
+
+#: collect2.cc:2921
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: cannot open as COFF file"
+msgstr ""
+
+#: collect2.cc:2980
+#, gcc-internal-format, gfc-internal-format
+msgid "library lib%s not found"
+msgstr ""
+
+#: convert.cc:98
+#, gcc-internal-format
+msgid "cannot convert to a pointer type"
+msgstr ""
+
+#: convert.cc:334
+#, gcc-internal-format
+msgid "pointer value used where a floating-point was expected"
+msgstr ""
+
+#: convert.cc:338
+#, gcc-internal-format
+msgid "vector value used where a floating-point was expected"
+msgstr ""
+
+#: convert.cc:342
+#, gcc-internal-format
+msgid "aggregate value used where a floating-point was expected"
+msgstr ""
+
+#: convert.cc:485
+#, gcc-internal-format
+msgid "conversion to incomplete type"
+msgstr ""
+
+#: convert.cc:959
+#, gcc-internal-format
+msgid "cannot convert a vector of type %qT to type %qT which has different size"
+msgstr ""
+
+#: convert.cc:967
+#, gcc-internal-format
+msgid "aggregate value used where an integer was expected"
+msgstr ""
+
+#: convert.cc:1061
+#, gcc-internal-format
+msgid "pointer value used where a complex was expected"
+msgstr ""
+
+#: convert.cc:1065
+#, gcc-internal-format
+msgid "aggregate value used where a complex was expected"
+msgstr ""
+
+#: convert.cc:1102
+#, gcc-internal-format
+msgid "cannot convert a value of type %qT to vector type %qT which has different size"
+msgstr ""
+
+#: convert.cc:1110
+#, gcc-internal-format
+msgid "cannot convert value to a vector"
+msgstr ""
+
+#: convert.cc:1149
+#, gcc-internal-format
+msgid "aggregate value used where a fixed-point was expected"
+msgstr ""
+
+#: coverage.cc:192
+#, gcc-internal-format
+msgid "%qs is not a gcov data file"
+msgstr ""
+
+#: coverage.cc:203
+#, gcc-internal-format
+msgid "%qs is version %q.*s, expected version %q.*s"
+msgstr ""
+
+#: coverage.cc:267
+#, gcc-internal-format, gfc-internal-format
+msgid "profile data for function %u is corrupted"
+msgstr ""
+
+#: coverage.cc:268
+#, gcc-internal-format
+msgid "checksum is (%x,%x) instead of (%x,%x)"
+msgstr ""
+
+#: coverage.cc:283
+#, gcc-internal-format
+msgid "%qs has overflowed"
+msgstr ""
+
+#: coverage.cc:284
+#, gcc-internal-format
+msgid "%qs is corrupted"
+msgstr "%qs დაზიანებულია"
+
+#: coverage.cc:311
+#, gcc-internal-format
+msgid "%qs profile count data file not found"
+msgstr ""
+
+#: coverage.cc:340
+#, gcc-internal-format
+msgid "profile for function %qD not found in profile data"
+msgstr ""
+
+#: coverage.cc:360
+#, gcc-internal-format
+msgid "number of counters in profile data for function %qD does not match its profile data (counter %qs, expected %i and have %i)"
+msgstr ""
+
+#: coverage.cc:369
+#, gcc-internal-format
+msgid "the control flow of function %qD does not match its profile data (counter %qs)"
+msgstr ""
+
+#: coverage.cc:388
+#, gcc-internal-format
+msgid "execution counts estimated\n"
+msgstr ""
+
+#: coverage.cc:389
+#, gcc-internal-format
+msgid "execution counts assumed to be zero\n"
+msgstr ""
+
+#: coverage.cc:402
+#, gcc-internal-format
+msgid "source locations for function %qD have changed, the profile data may be out of date"
+msgstr ""
+
+#: coverage.cc:666
+#, gcc-internal-format
+msgid "function starts on a higher line number than it ends"
+msgstr ""
+
+#: coverage.cc:688
+#, gcc-internal-format
+msgid "error writing %qs"
+msgstr "%qs-ის ჩაწერის შეცდომა"
+
+#: coverage.cc:1288
+#, gcc-internal-format
+msgid "filename %qs does not start with profile prefix %qs"
+msgstr ""
+
+#: coverage.cc:1333
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot open %s"
+msgstr ""
+
+#: data-streamer-in.cc:55
+#, gcc-internal-format
+msgid "bytecode stream: string too long for the string table"
+msgstr ""
+
+#: data-streamer-in.cc:86 data-streamer-in.cc:115
+#, gcc-internal-format
+msgid "bytecode stream: found non-null terminated string"
+msgstr ""
+
+#: dbgcnt.cc:140
+#, gcc-internal-format
+msgid "Interval overlap of %<-fdbg-cnt=%s%>: [%u, %u] and [%u, %u]"
+msgstr ""
+
+#: dbgcnt.cc:157
+#, gcc-internal-format
+msgid "%<-fdbg-cnt=%s:%d-%d%> has smaller upper limit than the lower"
+msgstr ""
+
+#: dbgcnt.cc:169
+#, gcc-internal-format
+msgid "cannot find a valid counter name %qs of %<-fdbg-cnt=%> option"
+msgstr ""
+
+#: dbgcnt.cc:238
+#, gcc-internal-format
+msgid "counter name"
+msgstr "მთვლელის სახელ"
+
+#: dbgcnt.cc:239
+#, gcc-internal-format
+msgid "counter value"
+msgstr "მთვლელის მნიშვნელობა"
+
+#: dbgcnt.cc:239
+#, gcc-internal-format
+msgid "closed intervals"
+msgstr "დახურული ინტერვალები"
+
+#: diagnostic.cc:2659
+#, gcc-internal-format
+msgid "debug path"
+msgstr ""
+
+#: dominance.cc:1180
+#, gcc-internal-format, gfc-internal-format
+msgid "dominator of %d status unknown"
+msgstr ""
+
+#: dominance.cc:1188
+#, gcc-internal-format, gfc-internal-format
+msgid "dominator of %d should be %d, not %d"
+msgstr ""
+
+#: dumpfile.cc:381
+#, gcc-internal-format
+msgid "could not open dump file %qs: %m"
+msgstr ""
+
+#: dumpfile.cc:1841
+#, gcc-internal-format
+msgid "ignoring unknown option %q.*s"
+msgstr ""
+
+#: dumpfile.cc:1923
+#, gcc-internal-format
+msgid "unrecognized command-line option %<-fdump-%s%>; did you mean %<-fdump-%s%>?"
+msgstr ""
+
+#: dumpfile.cc:1926
+#, gcc-internal-format
+msgid "unrecognized command-line option %<-fdump-%s%>"
+msgstr ""
+
+#: dumpfile.cc:1999
+#, gcc-internal-format
+msgid "unknown option %q.*s in %<-fopt-info-%s%>"
+msgstr ""
+
+#: dumpfile.cc:2031
+#, gcc-internal-format
+msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
+msgstr ""
+
+#: dwarf2out.cc:1138
+#, gcc-internal-format
+msgid "multiple EH personalities are supported only with assemblers supporting %<.cfi_personality%> directive"
+msgstr ""
+
+#: dwarf2out.cc:11196
+#, gcc-internal-format
+msgid "%<-gdwarf-6%> is output as version 5 with incompatibilities"
+msgstr ""
+
+#: dwarf2out.cc:15078
+#, gcc-internal-format, gfc-internal-format
+msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
+msgstr ""
+
+#: emit-rtl.cc:3042
+#, gcc-internal-format
+msgid "invalid rtl sharing found in the insn"
+msgstr ""
+
+#: emit-rtl.cc:3044
+#, gcc-internal-format
+msgid "shared rtx"
+msgstr "გაზიარებული rtx"
+
+#: emit-rtl.cc:3046
+#, gcc-internal-format
+msgid "internal consistency failure"
+msgstr ""
+
+#: emit-rtl.cc:4146
+#, gcc-internal-format
+msgid "ICE: %<emit_insn%> used where %<emit_jump_insn%> needed:"
+msgstr ""
+
+#: errors.cc:133
+#, gcc-internal-format, gfc-internal-format
+msgid "abort in %s, at %s:%d"
+msgstr ""
+
+#: except.cc:2166
+#, gcc-internal-format
+msgid "argument of %<__builtin_eh_return_regno%> must be constant"
+msgstr ""
+
+#: except.cc:2312
+#, gcc-internal-format
+msgid "%<__builtin_eh_return%> not supported on this target"
+msgstr ""
+
+#: except.cc:3448 except.cc:3473
+#, gcc-internal-format
+msgid "%<region_array%> is corrupted for region %i"
+msgstr ""
+
+#: except.cc:3461 except.cc:3492
+#, gcc-internal-format
+msgid "%<lp_array%> is corrupted for lp %i"
+msgstr ""
+
+#: except.cc:3478
+#, gcc-internal-format, gfc-internal-format
+msgid "outer block of region %i is wrong"
+msgstr ""
+
+#: except.cc:3483
+#, gcc-internal-format, gfc-internal-format
+msgid "negative nesting depth of region %i"
+msgstr ""
+
+#: except.cc:3497
+#, gcc-internal-format, gfc-internal-format
+msgid "region of lp %i is wrong"
+msgstr ""
+
+#: except.cc:3524
+#, gcc-internal-format, gfc-internal-format
+msgid "tree list ends on depth %i"
+msgstr ""
+
+#: except.cc:3529
+#, gcc-internal-format
+msgid "%<region_array%> does not match %<region_tree%>"
+msgstr ""
+
+#: except.cc:3534
+#, gcc-internal-format
+msgid "%<lp_array%> does not match %<region_tree%>"
+msgstr ""
+
+#: except.cc:3541 tree.cc:14434 value-prof.cc:529
+#, gcc-internal-format
+msgid "%qs failed"
+msgstr "%qs ჩავარდა"
+
+#: explow.cc:1563
+#, gcc-internal-format
+msgid "stack limits not supported on this target"
+msgstr ""
+
+#: expmed.cc:360
+#, gcc-internal-format
+msgid "reverse scalar storage order"
+msgstr ""
+
+#: expmed.cc:377
+#, gcc-internal-format
+msgid "reverse floating-point scalar storage order"
+msgstr ""
+
+#: expmed.cc:419
+#, gcc-internal-format, gfc-internal-format
+msgid "reverse storage order for %smode"
+msgstr ""
+
+#: expmed.cc:672
+#, gcc-internal-format
+msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
+msgstr ""
+
+#: expr.cc:12338
+#, gcc-internal-format
+msgid "call to %qs declared with attribute error: %s"
+msgstr ""
+
+#: expr.cc:12352
+#, gcc-internal-format
+msgid "call to %qs declared with attribute warning: %s"
+msgstr ""
+
+#: expr.cc:13399
+#, gcc-internal-format
+msgid "assuming signed overflow does not occur when simplifying %<X - Y %s 0%> to %<X %s Y%>"
+msgstr ""
+
+#: file-prefix-map.cc:51
+#, gcc-internal-format
+msgid "invalid argument %qs to %qs"
+msgstr ""
+
+#: final.cc:1769
+#, gcc-internal-format
+msgid "the frame size of %wu bytes is larger than %wu bytes"
+msgstr ""
+
+#: final.cc:4391 toplev.cc:1400 tree-cfgcleanup.cc:1540
+#, gcc-internal-format
+msgid "could not open final insn dump file %qs: %m"
+msgstr ""
+
+#: final.cc:4460 tree-cfgcleanup.cc:1557
+#, gcc-internal-format
+msgid "could not close final insn dump file %qs: %m"
+msgstr ""
+
+#: fixed-value.cc:128
+#, gcc-internal-format
+msgid "large fixed-point constant implicitly truncated to fixed-point type"
+msgstr ""
+
+#: fold-const.cc:4882 fold-const.cc:4892
+#, gcc-internal-format, gfc-internal-format
+msgid "comparison is always %d due to width of bit-field"
+msgstr ""
+
+#: fold-const.cc:6277 tree-ssa-reassoc.cc:2885 tree-ssa-reassoc.cc:3970
+#, gcc-internal-format
+msgid "assuming signed overflow does not occur when simplifying range test"
+msgstr ""
+
+#: fold-const.cc:6742 fold-const.cc:6758
+#, gcc-internal-format, gfc-internal-format
+msgid "comparison is always %d"
+msgstr ""
+
+#: fold-const.cc:6906
+#, gcc-internal-format
+msgid "%<or%> of unmatched not-equal tests is always 1"
+msgstr ""
+
+#: fold-const.cc:6911
+#, gcc-internal-format
+msgid "%<and%> of mutually exclusive equal-tests is always 0"
+msgstr ""
+
+#: fold-const.cc:10128
+#, gcc-internal-format
+msgid "assuming signed overflow does not occur when reducing constant in comparison"
+msgstr ""
+
+#: fold-const.cc:10535
+#, gcc-internal-format
+msgid "assuming signed overflow does not occur when combining constants around a comparison"
+msgstr ""
+
+#: fold-const.cc:13947
+#, gcc-internal-format
+msgid "fold check: original tree changed by fold"
+msgstr ""
+
+#: function.cc:255
+#, gcc-internal-format
+msgid "total size of local objects %wu exceeds maximum %wu"
+msgstr ""
+
+#: function.cc:259
+#, gcc-internal-format
+msgid "total size of local objects exceeds maximum %wu"
+msgstr ""
+
+#: function.cc:1789 gimplify.cc:7018 gimplify.cc:7180
+#, gcc-internal-format
+msgid "impossible constraint in %<asm%>"
+msgstr ""
+
+#: function.cc:4290
+#, gcc-internal-format
+msgid "variable %q+D might be clobbered by %<longjmp%> or %<vfork%>"
+msgstr ""
+
+#: function.cc:4311
+#, gcc-internal-format
+msgid "argument %q+D might be clobbered by %<longjmp%> or %<vfork%>"
+msgstr ""
+
+#: function.cc:4978
+#, gcc-internal-format
+msgid "function returns an aggregate"
+msgstr "ფუნქცია აგრეგატს აბრუნებს"
+
+#: gcc.cc:2213
+#, gcc-internal-format
+msgid "cannot open nested response file"
+msgstr ""
+
+#: gcc.cc:2250
+#, gcc-internal-format
+msgid "cannot close nonexistent response file"
+msgstr ""
+
+#: gcc.cc:2273
+#, gcc-internal-format, gfc-internal-format
+msgid "could not open temporary response file %s"
+msgstr ""
+
+#: gcc.cc:2280
+#, gcc-internal-format, gfc-internal-format
+msgid "could not write to temporary response file %s"
+msgstr ""
+
+#: gcc.cc:2286
+#, gcc-internal-format, gfc-internal-format
+msgid "could not close temporary response file %s"
+msgstr ""
+
+#. This leaves DESC open, but the OS will save us.
+#: gcc.cc:2318
+#, gcc-internal-format
+msgid "cannot read spec file %qs: %m"
+msgstr ""
+
+#: gcc.cc:2412 gcc.cc:2432
+msgid "specs %%include syntax malformed after %td characters"
+msgstr ""
+
+#: gcc.cc:2458 gcc.cc:2467 gcc.cc:2477 gcc.cc:2487
+msgid "specs %%rename syntax malformed after %td characters"
+msgstr ""
+
+#: gcc.cc:2497
+#, gcc-internal-format, gfc-internal-format
+msgid "specs %s spec was not found to be renamed"
+msgstr ""
+
+#: gcc.cc:2505
+#, gcc-internal-format
+msgid "%s: attempt to rename spec %qs to already defined spec %qs"
+msgstr ""
+
+#: gcc.cc:2527
+msgid "specs unknown %% command after %td characters"
+msgstr ""
+
+#: gcc.cc:2539 gcc.cc:2553
+msgid "specs file malformed after %td characters"
+msgstr ""
+
+#: gcc.cc:2608
+#, gcc-internal-format
+msgid "spec file has no spec for linking"
+msgstr ""
+
+#: gcc.cc:3172 gcc.cc:3209
+#, gcc-internal-format
+msgid "system path %qs is not absolute"
+msgstr ""
+
+#: gcc.cc:3298
+#, gcc-internal-format
+msgid "%<-pipe%> not supported"
+msgstr ""
+
+#: gcc.cc:3436 gcc.cc:7834
+#, gcc-internal-format
+msgid "cannot execute %qs: %s: %m"
+msgstr ""
+
+#: gcc.cc:3437 gcc.cc:7835
+#, gcc-internal-format
+msgid "cannot execute %qs: %s"
+msgstr "%qs-ის შესრულება შეუძლებელია: %s"
+
+#: gcc.cc:3456
+#, gcc-internal-format
+msgid "failed to get exit status: %m"
+msgstr "გამოსვლის სტატუსის მიღება ჩავარდა: %m"
+
+#: gcc.cc:3462
+#, gcc-internal-format
+msgid "failed to get process times: %m"
+msgstr "პროცესის დროების მიღება ჩავარდა: %m"
+
+#. The inferior failed to catch the signal.
+#: gcc.cc:3488 gcc.cc:3512
+#, gcc-internal-format, gfc-internal-format
+msgid "%s signal terminated program %s"
+msgstr ""
+
+#: gcc.cc:3956 opts-common.cc:1612 opts-common.cc:1644
+#, gcc-internal-format
+msgid "unrecognized command-line option %qs"
+msgstr ""
+
+#: gcc.cc:3998
+#, gcc-internal-format
+msgid "GCC is not configured to support %qs as %<-foffload=%> argument"
+msgstr ""
+
+#: gcc.cc:4005
+#, gcc-internal-format
+msgid "valid %<-foffload=%> arguments are: %s; did you mean %qs?"
+msgstr ""
+
+#: gcc.cc:4008
+#, gcc-internal-format
+msgid "valid %<-foffload=%> arguments are: %s"
+msgstr ""
+
+#: gcc.cc:4028
+#, gcc-internal-format
+msgid "%<=%>options missing after %<-foffload-options=%>target"
+msgstr ""
+
+#: gcc.cc:4477
+#, gcc-internal-format
+msgid "%qs is an unknown %<-save-temps%> option"
+msgstr ""
+
+#: gcc.cc:5024
+#, gcc-internal-format
+msgid "linker hardening options not enabled by %<-fhardened%> because other link options were specified on the command line"
+msgstr ""
+
+#: gcc.cc:5048 toplev.cc:714
+#, gcc-internal-format
+msgid "input file %qs is the same as output file"
+msgstr ""
+
+#: gcc.cc:5053
+#, gcc-internal-format
+msgid "output filename may not be empty"
+msgstr ""
+
+#: gcc.cc:5438
+#, gcc-internal-format
+msgid "%<-pipe%> ignored because %<-save-temps%> specified"
+msgstr ""
+
+#: gcc.cc:5526
+#, gcc-internal-format
+msgid "%<-x %s%> after last input file has no effect"
+msgstr ""
+
+#: gcc.cc:5729
+#, gcc-internal-format
+msgid "unable to locate default linker script %qs in the library search paths"
+msgstr ""
+
+#: gcc.cc:5936
+#, gcc-internal-format
+msgid "switch %qs does not start with %<-%>"
+msgstr ""
+
+#: gcc.cc:5940
+#, gcc-internal-format
+msgid "spec-generated switch is just %<-%>"
+msgstr ""
+
+#: gcc.cc:6172
+#, gcc-internal-format
+msgid "spec %qs invalid"
+msgstr ""
+
+#: gcc.cc:6349
+#, gcc-internal-format
+msgid "spec %qs has invalid %<%%0%c%>"
+msgstr ""
+
+#: gcc.cc:6641
+#, gcc-internal-format
+msgid "spec %qs has invalid %<%%W%c%>"
+msgstr ""
+
+#: gcc.cc:6657
+#, gcc-internal-format
+msgid "spec %qs has invalid %<%%@%c%>"
+msgstr ""
+
+#: gcc.cc:6676
+#, gcc-internal-format
+msgid "spec %qs has invalid %<%%x%c%>"
+msgstr ""
+
+#. Catch the case where a spec string contains something like
+#. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
+#. hand side of the :.
+#: gcc.cc:6887
+#, gcc-internal-format
+msgid "spec failure: %<%%*%> has not been initialized by pattern match"
+msgstr ""
+
+#: gcc.cc:6938
+#, gcc-internal-format
+msgid "spec failure: unrecognized spec option %qc"
+msgstr ""
+
+#: gcc.cc:7004
+#, gcc-internal-format
+msgid "unknown spec function %qs"
+msgstr ""
+
+#: gcc.cc:7034
+#, gcc-internal-format
+msgid "error in arguments to spec function %qs"
+msgstr ""
+
+#: gcc.cc:7093
+#, gcc-internal-format
+msgid "malformed spec function name"
+msgstr ""
+
+#. )
+#: gcc.cc:7096
+#, gcc-internal-format
+msgid "no arguments for spec function"
+msgstr ""
+
+#: gcc.cc:7115
+#, gcc-internal-format
+msgid "malformed spec function arguments"
+msgstr ""
+
+#: gcc.cc:7294
+#, gcc-internal-format
+msgid "braced spec %qs ends in escape"
+msgstr ""
+
+#: gcc.cc:7429
+#, gcc-internal-format
+msgid "braced spec %qs is invalid at %qc"
+msgstr ""
+
+#: gcc.cc:7524
+#, gcc-internal-format
+msgid "braced spec body %qs is invalid"
+msgstr ""
+
+#: gcc.cc:8133
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: could not determine length of compare-debug file %s"
+msgstr ""
+
+#: gcc.cc:8144
+#, gcc-internal-format
+msgid "%s: %<-fcompare-debug%> failure (length)"
+msgstr ""
+
+#: gcc.cc:8154 gcc.cc:8195
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: could not open compare-debug file %s"
+msgstr ""
+
+#: gcc.cc:8174 gcc.cc:8211
+#, gcc-internal-format
+msgid "%s: %<-fcompare-debug%> failure"
+msgstr ""
+
+#: gcc.cc:8515
+#, gcc-internal-format
+msgid "spec failure: more than one argument to %<SYSROOT_SUFFIX_SPEC%>"
+msgstr ""
+
+#: gcc.cc:8540
+#, gcc-internal-format
+msgid "spec failure: more than one argument to %<SYSROOT_HEADERS_SUFFIX_SPEC%>"
+msgstr ""
+
+#: gcc.cc:8747
+#, gcc-internal-format
+msgid "unrecognized command-line option %<-%s%>; did you mean %<-%s%>?"
+msgstr ""
+
+#: gcc.cc:8751
+#, gcc-internal-format
+msgid "unrecognized command-line option %<-%s%>"
+msgstr ""
+
+#: gcc.cc:8877
+#, gcc-internal-format
+msgid "not configured with sysroot headers suffix"
+msgstr ""
+
+#: gcc.cc:8938
+#, gcc-internal-format
+msgid "no input files"
+msgstr "შეყვანის ფაილების გარეშე"
+
+#: gcc.cc:8989
+#, gcc-internal-format
+msgid "cannot specify %<-o%> with %<-c%>, %<-S%> or %<-E%> with multiple files"
+msgstr ""
+
+#: gcc.cc:9031
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: %s compiler not installed on this system"
+msgstr ""
+
+#: gcc.cc:9056
+#, gcc-internal-format
+msgid "recompiling with %<-fcompare-debug%>"
+msgstr ""
+
+#: gcc.cc:9072
+#, gcc-internal-format
+msgid "during %<-fcompare-debug%> recompilation"
+msgstr ""
+
+#: gcc.cc:9081
+#, gcc-internal-format
+msgid "comparing final insns dumps"
+msgstr ""
+
+#: gcc.cc:9234
+#, gcc-internal-format
+msgid "%<-fuse-linker-plugin%>, but %s not found"
+msgstr ""
+
+#: gcc.cc:9268
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: linker input file unused because linking not done"
+msgstr ""
+
+#. This is can be an indication the user specifed an errorneous
+#. separated option value, (or used the wrong prefix for an
+#. option).
+#: gcc.cc:9274
+#, gcc-internal-format
+msgid "%s: linker input file not found: %m"
+msgstr ""
+
+#: gcc.cc:9341 c-family/c-opts.cc:820
+#, gcc-internal-format
+msgid "cannot use %<-%> as input filename for a precompiled header"
+msgstr ""
+
+#: gcc.cc:9347
+#, gcc-internal-format, gfc-internal-format
+msgid "language %s not recognized"
+msgstr ""
+
+#: gcc.cc:9590
+#, gcc-internal-format
+msgid "multilib spec %qs is invalid"
+msgstr ""
+
+#: gcc.cc:9792
+#, gcc-internal-format
+msgid "multilib exclusions %qs is invalid"
+msgstr ""
+
+#: gcc.cc:9856 common/config/riscv/riscv-common.cc:2130
+#, gcc-internal-format
+msgid "multilib select %qs %qs is invalid"
+msgstr ""
+
+#: gcc.cc:10030
+#, gcc-internal-format
+msgid "multilib select %qs is invalid"
+msgstr ""
+
+#: gcc.cc:10070
+#, gcc-internal-format
+msgid "multilib exclusion %qs is invalid"
+msgstr ""
+
+#: gcc.cc:10321
+#, gcc-internal-format
+msgid "environment variable %qs not defined"
+msgstr ""
+
+#: gcc.cc:10489 gcc.cc:10494
+#, gcc-internal-format
+msgid "invalid version number %qs"
+msgstr ""
+
+#: gcc.cc:10537
+#, gcc-internal-format, gfc-internal-format
+msgid "too few arguments to %%:version-compare"
+msgstr ""
+
+#: gcc.cc:10543
+#, gcc-internal-format, gfc-internal-format
+msgid "too many arguments to %%:version-compare"
+msgstr ""
+
+#: gcc.cc:10585
+#, gcc-internal-format
+msgid "unknown operator %qs in %%:version-compare"
+msgstr ""
+
+#: gcc.cc:10709
+#, gcc-internal-format, gfc-internal-format
+msgid "too many arguments to %%:compare-debug-dump-opt"
+msgstr ""
+
+#: gcc.cc:10777
+#, gcc-internal-format, gfc-internal-format
+msgid "too many arguments to %%:compare-debug-self-opt"
+msgstr ""
+
+#: gcc.cc:10864
+#, gcc-internal-format, gfc-internal-format
+msgid "too many arguments for %%:dumps"
+msgstr ""
+
+#: gcc.cc:10968
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong number of arguments to %%:debug-level-gt"
+msgstr ""
+
+#: gcc.cc:10989
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong number of arguments to %%:dwarf-version-gt"
+msgstr ""
+
+#: gcov-tool.cc:75
+#, gcc-internal-format, gfc-internal-format
+msgid "error in removing %s"
+msgstr ""
+
+#: gcov-tool.cc:106
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot make directory %s"
+msgstr ""
+
+#: gcov-tool.cc:114
+#, gcc-internal-format
+msgid "Cannot get current directory name"
+msgstr "მიმდინარე საქაღალდის სახელის მიღების შეცდომა"
+
+#: gcov-tool.cc:118 gcov-tool.cc:132
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot change directory to %s"
+msgstr ""
+
+#: gcov-tool.cc:125
+#, gcc-internal-format, gfc-internal-format
+msgid "output file %s already exists in folder %s"
+msgstr ""
+
+#: gcov-tool.cc:217 gcov-tool.cc:285
+#, gcc-internal-format
+msgid "weights need to be non-negative"
+msgstr ""
+
+#: gcov-tool.cc:424
+#, gcc-internal-format
+msgid "scale needs to be non-negative"
+msgstr ""
+
+#: gcse.cc:3995
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: %d basic blocks and %d edges/basic block"
+msgstr ""
+
+#: gcse.cc:4007
+#, gcc-internal-format
+msgid "%s: %d basic blocks and %d registers; increase %<--param max-gcse-memory%> above %wu"
+msgstr ""
+
+#: gencfn-macros.cc:195
+#, gcc-internal-format, gfc-internal-format
+msgid "DEF_INTERNAL_FLT_FN (%s) has no associated built-in functions"
+msgstr ""
+
+#: gencfn-macros.cc:202
+#, gcc-internal-format, gfc-internal-format
+msgid "DEF_INTERNAL_INT_FN (%s) has no associated built-in functions"
+msgstr ""
+
+#: gentarget-def.cc:126
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid prototype for '%s'"
+msgstr ""
+
+#: gentarget-def.cc:131
+#, gcc-internal-format, gfc-internal-format
+msgid "prototype for '%s' has required operands after optional operands"
+msgstr ""
+
+#: gentarget-def.cc:148
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %d of '%s' did not have the expected name"
+msgstr ""
+
+#: gentarget-def.cc:168
+#, gcc-internal-format, gfc-internal-format
+msgid "'%s' must have %d operands (excluding match_dups)"
+msgstr ""
+
+#: gentarget-def.cc:172
+#, gcc-internal-format, gfc-internal-format
+msgid "'%s' must have at least %d operands (excluding match_dups)"
+msgstr ""
+
+#: gentarget-def.cc:176
+#, gcc-internal-format, gfc-internal-format
+msgid "'%s' must have no more than %d operands (excluding match_dups)"
+msgstr ""
+
+#: gentarget-def.cc:276
+#, gcc-internal-format, gfc-internal-format
+msgid "duplicate definition of '%s'"
+msgstr ""
+
+#: ggc-common.cc:431 ggc-common.cc:439 ggc-common.cc:567 ggc-common.cc:585
+#: ggc-common.cc:705 ggc-common.cc:716 ggc-common.cc:731 ggc-page.cc:2503
+#: ggc-page.cc:2534 ggc-page.cc:2541
+#, gcc-internal-format
+msgid "cannot write PCH file: %m"
+msgstr ""
+
+#: ggc-common.cc:549
+#, gcc-internal-format
+msgid "cannot write PCH file: required memory segment unavailable"
+msgstr ""
+
+#: ggc-common.cc:578 config/i386/host-cygwin.cc:57
+#, gcc-internal-format
+msgid "cannot get position in PCH file: %m"
+msgstr ""
+
+#: ggc-common.cc:588
+#, gcc-internal-format
+msgid "cannot write padding to PCH file: %m"
+msgstr ""
+
+#: ggc-common.cc:770 ggc-common.cc:786 ggc-common.cc:789 ggc-common.cc:812
+#: ggc-common.cc:815 ggc-common.cc:819 ggc-common.cc:854 ggc-common.cc:883
+#: ggc-common.cc:891 ggc-common.cc:901 ggc-common.cc:912 ggc-page.cc:2605
+#, gcc-internal-format
+msgid "cannot read PCH file: %m"
+msgstr ""
+
+#: ggc-common.cc:799
+#, gcc-internal-format
+msgid "PCH allocation failure"
+msgstr ""
+
+#: ggc-page.cc:1748
+#, gcc-internal-format
+msgid "open /dev/zero: %m"
+msgstr ""
+
+#: ggc-page.cc:2519 ggc-page.cc:2525
+#, gcc-internal-format
+msgid "cannot write PCH file"
+msgstr ""
+
+#: gimple-array-bounds.cc:282
+#, gcc-internal-format
+msgid "array subscript %E is outside array bounds of %qT"
+msgstr ""
+
+#: gimple-array-bounds.cc:301
+#, gcc-internal-format
+msgid "array subscript [%E, %E] is outside array bounds of %qT"
+msgstr ""
+
+#: gimple-array-bounds.cc:315
+#, gcc-internal-format
+msgid "array subscript %E is above array bounds of %qT"
+msgstr ""
+
+#: gimple-array-bounds.cc:324
+#, gcc-internal-format
+msgid "array subscript %E is below array bounds of %qT"
+msgstr ""
+
+#: gimple-array-bounds.cc:399
+#, gcc-internal-format
+msgid "array subscript %E is outside the bounds of an interior zero-length array %qT"
+msgstr ""
+
+#: gimple-array-bounds.cc:401
+#, gcc-internal-format
+msgid "array subscript %qE is outside the bounds of an interior zero-length array %qT"
+msgstr ""
+
+#: gimple-array-bounds.cc:422
+#, gcc-internal-format
+msgid "trailing array %qT should not be used as a flexible array member"
+msgstr ""
+
+#: gimple-array-bounds.cc:459 gimple-array-bounds.cc:726
+#, gcc-internal-format
+msgid "while referencing %qD"
+msgstr ""
+
+#: gimple-array-bounds.cc:461
+#, gcc-internal-format
+msgid "defined here %qD"
+msgstr ""
+
+#: gimple-array-bounds.cc:582
+#, gcc-internal-format
+msgid "array subscript %wi is outside array bounds of %qT"
+msgstr ""
+
+#: gimple-array-bounds.cc:587
+#, gcc-internal-format
+msgid "array subscript [%wi, %wi] is outside array bounds of %qT"
+msgstr ""
+
+#: gimple-array-bounds.cc:602
+#, gcc-internal-format
+msgid "array subscript %<%T[%wi]%> is partly outside array bounds of %qT"
+msgstr ""
+
+#: gimple-array-bounds.cc:625
+#, gcc-internal-format
+msgid "intermediate array offset %wi is outside array bounds of %qT"
+msgstr ""
+
+#: gimple-array-bounds.cc:704
+#, gcc-internal-format
+msgid "array subscript %wi is below array bounds of %qT"
+msgstr ""
+
+#: gimple-array-bounds.cc:718
+#, gcc-internal-format
+msgid "array subscript %wu is above array bounds of %qT"
+msgstr ""
+
+#: gimple-fold.cc:2081 gimple-fold.cc:3133 gimple-ssa-warn-restrict.cc:2080
+#, gcc-internal-format
+msgid "%qD source argument is the same as destination"
+msgstr ""
+
+#: gimple-fold.cc:2147
+#, gcc-internal-format
+msgid "%qD destination unchanged after copying no bytes from a string of length %E"
+msgstr ""
+
+#: gimple-fold.cc:2152
+#, gcc-internal-format
+msgid "%qD destination unchanged after copying no bytes"
+msgstr ""
+
+#: gimple-fold.cc:2527 gimple-ssa-warn-access.cc:859
+#, gcc-internal-format
+msgid "%qD specified bound %E exceeds destination size %E"
+msgstr ""
+
+#: gimple-fold.cc:2546
+#, gcc-internal-format
+msgid "%qD specified bound %E equals source length"
+msgstr ""
+
+#: gimple-fold.cc:4551 gimple-fold.cc:4778
+#, gcc-internal-format
+msgid "flexible array member %qD does not have well defined padding bits for %qs"
+msgstr ""
+
+#: gimple-fold.cc:4727 cp/constexpr.cc:4902
+#, gcc-internal-format
+msgid "PDP11 bit-field handling unsupported in %qs"
+msgstr ""
+
+#: gimple-fold.cc:5009
+#, gcc-internal-format, gfc-internal-format
+msgid "%s not supported for variable length aggregates"
+msgstr ""
+
+#: gimple-fold.cc:5015
+#, gcc-internal-format, gfc-internal-format
+msgid "%s not supported on this target"
+msgstr ""
+
+#: gimple-harden-control-flow.cc:97
+#, gcc-internal-format
+msgid "%qD calls %<setjmp%> or similar, %<-fharden-control-flow-redundancy%> is not supported"
+msgstr ""
+
+#: gimple-harden-control-flow.cc:110
+#, gcc-internal-format
+msgid "%qD receives nonlocal gotos, %<-fharden-control-flow-redundancy%> is not supported"
+msgstr ""
+
+#: gimple-harden-control-flow.cc:121
+#, gcc-internal-format
+msgid "%qD has more than %u blocks, the requested maximum for %<-fharden-control-flow-redundancy%>"
+msgstr ""
+
+#: gimple-ssa-isolate-paths.cc:290
+#, gcc-internal-format
+msgid "potential null pointer dereference"
+msgstr ""
+
+#: gimple-ssa-isolate-paths.cc:330
+#, gcc-internal-format
+msgid "null pointer dereference"
+msgstr ""
+
+#: gimple-ssa-isolate-paths.cc:413
+#, gcc-internal-format
+msgid "function may return address of local variable"
+msgstr ""
+
+#: gimple-ssa-isolate-paths.cc:414 c/c-typeck.cc:11587
+#, gcc-internal-format
+msgid "function returns address of local variable"
+msgstr ""
+
+#: gimple-ssa-isolate-paths.cc:417 gimple-ssa-warn-access.cc:2055
+#: gimple-ssa-warn-access.cc:3713 tree.cc:12481 tree.cc:12518 tree.cc:12559
+#: tree.cc:12592 c/c-parser.cc:20633 c/c-parser.cc:20774 c/c-typeck.cc:3159
+#: c/c-typeck.cc:3254 c/c-typeck.cc:5871 c/c-typeck.cc:11493
+#: c/c-typeck.cc:11510 c/gimple-parser.cc:2574 c/gimple-parser.cc:2582
+#: cp/call.cc:8204 cp/call.cc:10399 cp/class.cc:9399 cp/constexpr.cc:889
+#: cp/constexpr.cc:1316 cp/constexpr.cc:4320 cp/constexpr.cc:5997
+#: cp/constexpr.cc:6368 cp/cvt.cc:1095 cp/cvt.cc:1133 cp/decl.cc:9113
+#: cp/decl2.cc:5890 cp/decl2.cc:5945 cp/method.cc:1234 cp/parser.cc:22475
+#: cp/pt.cc:9189 cp/semantics.cc:2380 cp/semantics.cc:4898 cp/typeck.cc:2139
+#: cp/typeck.cc:2359 cp/typeck.cc:4505 cp/typeck.cc:10690
+#: rust/backend/rust-constexpr.cc:4407 rust/backend/rust-tree.cc:621
+#: rust/backend/rust-tree.cc:3813
+#, gcc-internal-format
+msgid "declared here"
+msgstr "აღწერილია აქ"
+
+#: gimple-ssa-nonnull-compare.cc:102
+#, gcc-internal-format
+msgid "%<nonnull%> argument %qD compared to NULL"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:2838 gimple-ssa-sprintf.cc:2958
+#, gcc-internal-format
+msgid "%qE output may be truncated before the last format character"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:2840 gimple-ssa-sprintf.cc:2960
+#, gcc-internal-format
+msgid "%qE output truncated before the last format character"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:2843 gimple-ssa-sprintf.cc:2963
+#, gcc-internal-format
+msgid "%qE may write a terminating nul past the end of the destination"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:2845 gimple-ssa-sprintf.cc:2965
+#, gcc-internal-format
+msgid "%qE writing a terminating nul past the end of the destination"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:2855
+#, gcc-internal-format
+msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
+msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-sprintf.cc:2862
+#, gcc-internal-format
+msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
+msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-sprintf.cc:2869
+#, gcc-internal-format
+msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
+msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-sprintf.cc:2880
+#, gcc-internal-format
+msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:2883
+#, gcc-internal-format
+msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:2885
+#, gcc-internal-format
+msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:2897
+#, gcc-internal-format
+msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:2900
+#, gcc-internal-format
+msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:2903
+#, gcc-internal-format
+msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:2912
+#, gcc-internal-format
+msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:2915
+#, gcc-internal-format
+msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:2918
+#, gcc-internal-format
+msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:2927
+#, gcc-internal-format
+msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:2930
+#, gcc-internal-format
+msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:2932
+#, gcc-internal-format
+msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:2974
+#, gcc-internal-format
+msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
+msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-sprintf.cc:2981
+#, gcc-internal-format
+msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
+msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-sprintf.cc:2989
+#, gcc-internal-format
+msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
+msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-sprintf.cc:3001
+#, gcc-internal-format
+msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3004
+#, gcc-internal-format
+msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3007
+#, gcc-internal-format
+msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3020
+#, gcc-internal-format
+msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3023
+#, gcc-internal-format
+msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3026
+#, gcc-internal-format
+msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3036
+#, gcc-internal-format
+msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3039
+#, gcc-internal-format
+msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3042
+#, gcc-internal-format
+msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3051
+#, gcc-internal-format
+msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3054
+#, gcc-internal-format
+msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3057
+#, gcc-internal-format
+msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3179
+#, gcc-internal-format
+msgid "%<%.*s%> directive argument is null"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3257
+#, gcc-internal-format
+msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3263
+#, gcc-internal-format
+msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3270
+#, gcc-internal-format
+msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3300
+#, gcc-internal-format
+msgid "%<%.*s%> directive output of %wu bytes exceeds %<INT_MAX%>"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3306
+#, gcc-internal-format
+msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds %<INT_MAX%>"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3317
+#, gcc-internal-format
+msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3323
+#, gcc-internal-format
+msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3334
+#, gcc-internal-format
+msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3344
+#, gcc-internal-format
+msgid "%<%.*s%> directive argument is not a nul-terminated string"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3350 gimple-ssa-warn-access.cc:234
+#, gcc-internal-format
+msgid "referenced argument declared here"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3357
+#, gcc-internal-format
+msgid "assuming directive output of %wu byte"
+msgid_plural "assuming directive output of %wu bytes"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-sprintf.cc:3364
+#, gcc-internal-format
+msgid "directive argument %qE"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3366
+#, gcc-internal-format
+msgid "directive argument in the range [%E, %E]"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3370
+#, gcc-internal-format
+msgid "using the range [%E, %E] for directive argument"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3390
+#, gcc-internal-format
+msgid "%qE output %wu byte into a destination of size %wu"
+msgid_plural "%qE output %wu bytes into a destination of size %wu"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-sprintf.cc:3395
+#, gcc-internal-format
+msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3400
+#, gcc-internal-format
+msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3405
+#, gcc-internal-format
+msgid "%qE output %wu or more bytes into a destination of size %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3416
+#, gcc-internal-format
+msgid "%qE output %wu byte"
+msgid_plural "%qE output %wu bytes"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-sprintf.cc:3420
+#, gcc-internal-format
+msgid "%qE output between %wu and %wu bytes"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3424
+#, gcc-internal-format
+msgid "%qE output %wu or more bytes (assuming %wu)"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3428
+#, gcc-internal-format
+msgid "%qE output %wu or more bytes"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3812
+#, gcc-internal-format
+msgid "%<%.*s%> directive width out of range"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3846
+#, gcc-internal-format
+msgid "%<%.*s%> directive precision out of range"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3979
+msgid "%qE arguments %Z and maybe %Z overlap destination object %qE"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:3991
+msgid "%qE argument %Z overlaps destination object %qE"
+msgid_plural "%qE arguments %Z overlap destination object %qE"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-sprintf.cc:4002
+msgid "%qE argument %Z may overlap destination object %qE"
+msgid_plural "%qE arguments %Z may overlap destination object %qE"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-sprintf.cc:4022
+#, gcc-internal-format
+msgid "destination object referenced by %<restrict%>-qualified argument 1 was declared here"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:4609
+#, gcc-internal-format
+msgid "specified bound %wu exceeds maximum object size %wu"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:4620
+#, gcc-internal-format
+msgid "specified bound %wu exceeds %<INT_MAX%>"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:4646
+#, gcc-internal-format
+msgid "specified bound range [%wu, %wu] exceeds %<INT_MAX%>"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:4690
+#, gcc-internal-format
+msgid "null destination pointer"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:4707
+#, gcc-internal-format
+msgid "specified bound %wu exceeds the size %wu of the destination object"
+msgstr ""
+
+#: gimple-ssa-sprintf.cc:4719
+#, gcc-internal-format
+msgid "null format string"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:174
+#, gcc-internal-format
+msgid "%qD specified bound %s exceeds maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:182
+#, gcc-internal-format
+msgid "%qD specified bound %s exceeds the size %E of unterminated array"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:185
+#, gcc-internal-format
+msgid "%qD specified bound %s may exceed the size of at most %E of unterminated array"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:188
+#, gcc-internal-format
+msgid "%qD specified bound %s exceeds the size of at most %E of unterminated array"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:196
+#, gcc-internal-format
+msgid "%qD argument missing terminating nul"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:205
+#, gcc-internal-format
+msgid "%qs specified bound %s exceeds maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:213
+#, gcc-internal-format
+msgid "%qs specified bound %s exceeds the size %E of unterminated array"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:216
+#, gcc-internal-format
+msgid "%qs specified bound %s may exceed the size of at most %E of unterminated array"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:219
+#, gcc-internal-format
+msgid "%qs specified bound %s exceeds the size of at most %E of unterminated array"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:227
+#, gcc-internal-format
+msgid "%qs argument missing terminating nul"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:490 gimple-ssa-warn-access.cc:732
+#, gcc-internal-format
+msgid "%qD specified bound %E exceeds maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:495 gimple-ssa-warn-access.cc:748
+#, gcc-internal-format
+msgid "%qD specified bound [%E, %E] exceeds maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:643
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:649
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:655
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:665
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%>"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:671
+#, gcc-internal-format
+msgid "argument %qD declared here"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:730
+#, gcc-internal-format
+msgid "%qD specified bound %E may exceed maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:737
+#, gcc-internal-format
+msgid "specified bound %E may exceed maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:739
+#, gcc-internal-format
+msgid "specified bound %E exceeds maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:746
+#, gcc-internal-format
+msgid "%qD specified bound [%E, %E] may exceed maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:754
+#, gcc-internal-format
+msgid "specified bound [%E, %E] may exceed maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:756
+#, gcc-internal-format
+msgid "specified bound [%E, %E] exceeds maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:766
+#, gcc-internal-format
+msgid "%qD specified bound %E may exceed source size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:768
+#, gcc-internal-format
+msgid "%qD specified bound %E exceeds source size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:773
+#, gcc-internal-format
+msgid "specified bound %E may exceed source size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:775
+#, gcc-internal-format
+msgid "specified bound %E exceeds source size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:782
+#, gcc-internal-format
+msgid "%qD specified bound [%E, %E] may exceed source size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:784
+#, gcc-internal-format
+msgid "%qD specified bound [%E, %E] exceeds source size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:789
+#, gcc-internal-format
+msgid "specified bound [%E, %E] may exceed source size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:791
+#, gcc-internal-format
+msgid "specified bound [%E, %E] exceeds source size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:799
+#, gcc-internal-format
+msgid "source object allocated here"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:822
+#, gcc-internal-format
+msgid "%qD specified size %E may exceed maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:824
+#, gcc-internal-format
+msgid "%qD specified size %E exceeds maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:829
+#, gcc-internal-format
+msgid "specified size %E may exceed maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:831
+#, gcc-internal-format
+msgid "specified size %E exceeds maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:838
+#, gcc-internal-format
+msgid "%qD specified size between %E and %E may exceed maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:840
+#, gcc-internal-format
+msgid "%qD specified size between %E and %E exceeds maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:845
+#, gcc-internal-format
+msgid "specified size between %E and %E may exceed maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:847
+#, gcc-internal-format
+msgid "specified size between %E and %E exceeds maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:857
+#, gcc-internal-format
+msgid "%qD specified bound %E may exceed destination size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:864
+#, gcc-internal-format
+msgid "specified bound %E may exceed destination size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:866
+#, gcc-internal-format
+msgid "specified bound %E exceeds destination size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:873
+#, gcc-internal-format
+msgid "%qD specified bound [%E, %E] may exceed destination size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:875
+#, gcc-internal-format
+msgid "%qD specified bound [%E, %E] exceeds destination size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:880 gimple-ssa-warn-access.cc:882
+#, gcc-internal-format
+msgid "specified bound [%E, %E] exceeds destination size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:891
+#, gcc-internal-format
+msgid "destination object allocated here"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:935
+#, gcc-internal-format
+msgid "%qD may access %E byte in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:937
+#, gcc-internal-format
+msgid "%qD accessing %E byte in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:940
+#, gcc-internal-format
+msgid "%qD may access %E bytes in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:942
+#, gcc-internal-format
+msgid "%qD accessing %E bytes in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:947
+#, gcc-internal-format
+msgid "may access %E byte in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:949
+#, gcc-internal-format
+msgid "accessing %E byte in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:952
+#, gcc-internal-format
+msgid "may access %E bytes in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:954
+#, gcc-internal-format
+msgid "accessing %E bytes in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:963
+#, gcc-internal-format
+msgid "%qD may access %E or more bytes in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:965
+#, gcc-internal-format
+msgid "%qD accessing %E or more bytes in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:970
+#, gcc-internal-format
+msgid "may access %E or more bytes in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:972
+#, gcc-internal-format
+msgid "accessing %E or more bytes in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:980
+#, gcc-internal-format
+msgid "%qD may access between %E and %E bytes in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:982
+#, gcc-internal-format
+msgid "%qD accessing between %E and %E bytes in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:987
+#, gcc-internal-format
+msgid "may access between %E and %E bytes in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:989
+#, gcc-internal-format
+msgid "accessing between %E and %E bytes in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1001
+#, gcc-internal-format
+msgid "%qD may write %E byte into a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1003
+#, gcc-internal-format
+msgid "%qD writing %E byte into a region of size %E overflows the destination"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1006
+#, gcc-internal-format
+msgid "%qD may write %E bytes into a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1008
+#, gcc-internal-format
+msgid "%qD writing %E bytes into a region of size %E overflows the destination"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1013
+#, gcc-internal-format
+msgid "may write %E byte into a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1015
+#, gcc-internal-format
+msgid "writing %E byte into a region of size %E overflows the destination"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1018
+#, gcc-internal-format
+msgid "may write %E bytes into a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1020
+#, gcc-internal-format
+msgid "writing %E bytes into a region of size %E overflows the destination"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1029
+#, gcc-internal-format
+msgid "%qD may write %E or more bytes into a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1031 gimple-ssa-warn-access.cc:1408
+#, gcc-internal-format
+msgid "%qD writing %E or more bytes into a region of size %E overflows the destination"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1037
+#, gcc-internal-format
+msgid "may write %E or more bytes into a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1039 gimple-ssa-warn-access.cc:1413
+#, gcc-internal-format
+msgid "writing %E or more bytes into a region of size %E overflows the destination"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1048
+#, gcc-internal-format
+msgid "%qD may write between %E and %E bytes into a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1050
+#, gcc-internal-format
+msgid "%qD writing between %E and %E bytes into a region of size %E overflows the destination"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1056
+#, gcc-internal-format
+msgid "may write between %E and %E bytes into a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1058
+#, gcc-internal-format
+msgid "writing between %E and %E bytes into a region of size %E overflows the destination"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1072
+#, gcc-internal-format
+msgid "%qD may read %E byte from a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1074
+#, gcc-internal-format
+msgid "%qD reading %E byte from a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1077
+#, gcc-internal-format
+msgid "%qD may read %E bytes from a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1079
+#, gcc-internal-format
+msgid "%qD reading %E bytes from a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1085
+#, gcc-internal-format
+msgid "may read %E byte from a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1087
+#, gcc-internal-format
+msgid "reading %E byte from a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1090
+#, gcc-internal-format
+msgid "may read %E bytes from a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1092
+#, gcc-internal-format
+msgid "reading %E bytes from a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1101
+#, gcc-internal-format
+msgid "%qD may read %E or more bytes from a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1103
+#, gcc-internal-format
+msgid "%qD reading %E or more bytes from a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1108
+#, gcc-internal-format
+msgid "may read %E or more bytes from a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1110
+#, gcc-internal-format
+msgid "reading %E or more bytes from a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1118
+#, gcc-internal-format
+msgid "%qD may read between %E and %E bytes from a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1120
+#, gcc-internal-format
+msgid "%qD reading between %E and %E bytes from a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1125
+#, gcc-internal-format
+msgid "may read between %E and %E bytes from a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1127
+#, gcc-internal-format
+msgid "reading between %E and %E bytes from a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1142
+#, gcc-internal-format
+msgid "%qD expecting %E byte in a region of size %E"
+msgid_plural "%qD expecting %E bytes in a region of size %E"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-warn-access.cc:1147
+#, gcc-internal-format
+msgid "expecting %E byte in a region of size %E"
+msgid_plural "expecting %E bytes in a region of size %E"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-warn-access.cc:1155
+#, gcc-internal-format
+msgid "%qD expecting %E or more bytes in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1159
+#, gcc-internal-format
+msgid "expecting %E or more bytes in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1166
+#, gcc-internal-format
+msgid "%qD expecting between %E and %E bytes in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:1170
+#, gcc-internal-format
+msgid "expecting between %E and %E bytes in a region of size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2050
+#, gcc-internal-format
+msgid "%qD called on pointer %qE with nonzero offset%s"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2065 gimple-ssa-warn-access.cc:3790
+#, gcc-internal-format
+msgid "returned from %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2068
+#, gcc-internal-format
+msgid "returned from %qT"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2070
+#, gcc-internal-format
+msgid "obtained here"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2277
+#, gcc-internal-format
+msgid "argument %i value %qE is negative"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2294
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %i value is zero"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2312
+#, gcc-internal-format
+msgid "argument %i value %qE exceeds maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2326
+#, gcc-internal-format
+msgid "argument %i range [%E, %E] is negative"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2333
+#, gcc-internal-format
+msgid "argument %i range [%E, %E] exceeds maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2363
+#, gcc-internal-format
+msgid "product %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2369
+#, gcc-internal-format
+msgid "product %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2380 gimple-ssa-warn-access.cc:2383
+#, gcc-internal-format
+msgid "argument %i in the range [%E, %E]"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2394
+#, gcc-internal-format
+msgid "in a call to built-in allocation function %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2397
+#, gcc-internal-format
+msgid "in a call to allocation function %qD declared here"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2842
+#, gcc-internal-format
+msgid "unknown architecture specifier in memory model %wi for %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2934
+#, gcc-internal-format
+msgid "invalid memory model %qs for %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2938
+#, gcc-internal-format
+msgid "invalid memory model %wi for %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2953 gimple-ssa-warn-access.cc:3007
+#, gcc-internal-format, gfc-internal-format
+msgid "valid models are %s"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2967
+#, gcc-internal-format
+msgid "invalid failure memory model %qs for %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2972
+#, gcc-internal-format
+msgid "valid failure models are %qs, %qs, %qs, %qs"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:2988
+#, gcc-internal-format
+msgid "failure memory model %qs cannot be stronger than success memory model %qs for %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3014
+#, gcc-internal-format
+msgid "failure memory model %wi cannot be stronger than success memory model %wi for %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3458
+#, gcc-internal-format, gfc-internal-format
+msgid "bound argument %i value %s is negative for a variable length array argument %i of type %s"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3466
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %i value %s is negative"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3512
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %i is null but the corresponding size argument %i value is %s"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3576
+#, gcc-internal-format
+msgid "referencing argument %u of type %qT"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3590
+#, gcc-internal-format
+msgid "in a call to function %qD declared with attribute %qs"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3594
+#, gcc-internal-format
+msgid "in a call with type %qT and attribute %qs"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3601
+#, gcc-internal-format
+msgid "in a call to function %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3604
+#, gcc-internal-format
+msgid "in a call with type %qT"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3710
+#, gcc-internal-format
+msgid "%qD called on unallocated object %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3729
+#, gcc-internal-format
+msgid "%qD called on a pointer to an unallocated object %qE"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3738
+#, gcc-internal-format
+msgid "assigned here"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3771
+#, gcc-internal-format
+msgid "%qD called on pointer returned from a mismatched allocation function"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3780
+#, gcc-internal-format
+msgid "%qD called on pointer to an unallocated object"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3928
+#, gcc-internal-format
+msgid "pointer %qE may be used after %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3929
+#, gcc-internal-format
+msgid "pointer %qE used after %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3933
+#, gcc-internal-format
+msgid "pointer may be used after %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3934
+#, gcc-internal-format
+msgid "pointer used after %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3938
+#, gcc-internal-format
+msgid "call to %qD here"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3955
+#, gcc-internal-format
+msgid "dangling pointer %qE to %qD may be used"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3956
+#, gcc-internal-format
+msgid "using dangling pointer %qE to %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3961
+#, gcc-internal-format
+msgid "dangling pointer to %qD may be used"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3962
+#, gcc-internal-format
+msgid "using a dangling pointer to %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3965 gimple-ssa-warn-access.cc:4613
+#: gimple-ssa-warn-access.cc:4616 gimple-ssa-warn-restrict.cc:1830
+#: tree-ssa-uninit.cc:921 tree-ssa-uninit.cc:1120 c/c-decl.cc:4099
+#: c/c-decl.cc:4389 c/c-typeck.cc:9541 c/c-typeck.cc:12295 cp/call.cc:8579
+#: cp/call.cc:8590 cp/class.cc:1718 cp/class.cc:3517 cp/constexpr.cc:1062
+#: cp/decl.cc:4640 cp/decl.cc:12909 cp/decl.cc:13497 cp/decl.cc:13506
+#: cp/decl.cc:14507 cp/friend.cc:406 cp/friend.cc:416 cp/init.cc:2935
+#: cp/parser.cc:3692 cp/parser.cc:3838 cp/parser.cc:3889 cp/parser.cc:7166
+#: cp/parser.cc:25045 cp/typeck.cc:4998
+#, gcc-internal-format
+msgid "%qD declared here"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3973
+#, gcc-internal-format
+msgid "dangling pointer %qE to an unnamed temporary may be used"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3975
+#, gcc-internal-format
+msgid "using dangling pointer %qE to an unnamed temporary"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3981
+#, gcc-internal-format
+msgid "dangling pointer to an unnamed temporary may be used"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3983
+#, gcc-internal-format
+msgid "using a dangling pointer to an unnamed temporary"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:3987
+#, gcc-internal-format
+msgid "unnamed temporary defined here"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:4077
+#, gcc-internal-format
+msgid "%qD called on pointer %qE passed to mismatched allocation function %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:4082
+#, gcc-internal-format
+msgid "%qD called on a pointer passed to mismatched reallocation function %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:4088
+#, gcc-internal-format
+msgid "call to %qD"
+msgstr ""
+
+#: gimple-ssa-warn-access.cc:4607
+#, gcc-internal-format
+msgid "storing the address of local variable %qD in %qE"
+msgstr ""
+
+#: gimple-ssa-warn-alloca.cc:287
+#, gcc-internal-format
+msgid "use of %<alloca%>"
+msgstr ""
+
+#: gimple-ssa-warn-alloca.cc:326
+#, gcc-internal-format
+msgid "argument to variable-length array may be too large"
+msgstr ""
+
+#: gimple-ssa-warn-alloca.cc:328
+#, gcc-internal-format
+msgid "argument to %<alloca%> may be too large"
+msgstr ""
+
+#: gimple-ssa-warn-alloca.cc:334
+#, gcc-internal-format
+msgid "limit is %wu bytes, but argument may be as large as %s"
+msgstr ""
+
+#: gimple-ssa-warn-alloca.cc:346
+#, gcc-internal-format
+msgid "argument to variable-length array is too large"
+msgstr ""
+
+#: gimple-ssa-warn-alloca.cc:348
+#, gcc-internal-format
+msgid "argument to %<alloca%> is too large"
+msgstr ""
+
+#: gimple-ssa-warn-alloca.cc:353
+#, gcc-internal-format
+msgid "limit is %wu bytes, but argument is %s"
+msgstr ""
+
+#: gimple-ssa-warn-alloca.cc:365
+#, gcc-internal-format
+msgid "unbounded use of variable-length array"
+msgstr ""
+
+#: gimple-ssa-warn-alloca.cc:366
+#, gcc-internal-format
+msgid "unbounded use of %<alloca%>"
+msgstr ""
+
+#: gimple-ssa-warn-alloca.cc:371
+#, gcc-internal-format
+msgid "use of %<alloca%> within a loop"
+msgstr ""
+
+#: gimple-ssa-warn-alloca.cc:376
+#, gcc-internal-format
+msgid "argument to variable-length array is zero"
+msgstr ""
+
+#: gimple-ssa-warn-alloca.cc:378
+#, gcc-internal-format
+msgid "argument to %<alloca%> is zero"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1498
+#, gcc-internal-format
+msgid "%qD accessing %wu byte at offsets %s and %s overlaps %wu byte at offset %s"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1500
+#, gcc-internal-format
+msgid "%qD accessing %wu byte at offsets %s and %s overlaps %wu bytes at offset %s"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1504
+#, gcc-internal-format
+msgid "%qD accessing %wu bytes at offsets %s and %s overlaps %wu byte at offset %s"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1506
+#, gcc-internal-format
+msgid "%qD accessing %wu bytes at offsets %s and %s overlaps %wu bytes at offset %s"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1513
+#, gcc-internal-format
+msgid "%qD accessing %wu byte at offsets %s and %s overlaps between %wu and %wu bytes at offset %s"
+msgid_plural "%qD accessing %wu bytes at offsets %s and %s overlaps between %wu and %wu bytes at offset %s"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-warn-restrict.cc:1523
+#, gcc-internal-format
+msgid "%qD accessing %wu byte at offsets %s and %s overlaps %wu or more bytes at offset %s"
+msgid_plural "%qD accessing %wu bytes at offsets %s and %s overlaps %wu or more bytes at offset %s"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-warn-restrict.cc:1536
+#, gcc-internal-format
+msgid "%qD accessing between %wu and %wu bytes at offsets %s and %s overlaps %wu byte at offset %s"
+msgid_plural "%qD accessing between %wu and %wu bytes at offsets %s and %s overlaps %wu bytes at offset %s"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-warn-restrict.cc:1546
+#, gcc-internal-format
+msgid "%qD accessing between %wu and %wu bytes at offsets %s and %s overlaps between %wu and %wu bytes at offset %s"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1554
+#, gcc-internal-format
+msgid "%qD accessing between %wu and %wu bytes at offsets %s and %s overlaps %wu or more bytes at offset %s"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1567
+#, gcc-internal-format
+msgid "%qD accessing %wu or more bytes at offsets %s and %s overlaps %wu byte at offset %s"
+msgid_plural "%qD accessing %wu or more bytes at offsets %s and %s overlaps %wu bytes at offset %s"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-warn-restrict.cc:1575
+#, gcc-internal-format
+msgid "%qD accessing %wu or more bytes at offsets %s and %s overlaps between %wu and %wu bytes at offset %s"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1582
+#, gcc-internal-format
+msgid "%qD accessing %wu or more bytes at offsets %s and %s overlaps %wu or more bytes at offset %s"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1610
+#, gcc-internal-format
+msgid "%qD accessing %wu byte may overlap %wu byte"
+msgid_plural "%qD accessing %wu bytes may overlap %wu byte"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-warn-restrict.cc:1617
+#, gcc-internal-format
+msgid "%qD accessing %wu byte at offsets %s and %s may overlap %wu byte at offset %s"
+msgid_plural "%qD accessing %wu bytes at offsets %s and %s may overlap %wu byte at offset %s"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-warn-restrict.cc:1628
+#, gcc-internal-format
+msgid "%qD accessing %wu byte may overlap up to %wu bytes"
+msgid_plural "%qD accessing %wu bytes may overlap up to %wu bytes"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-warn-restrict.cc:1635
+#, gcc-internal-format
+msgid "%qD accessing %wu byte at offsets %s and %s may overlap up to %wu bytes at offset %s"
+msgid_plural "%qD accessing %wu bytes at offsets %s and %s may overlap up to %wu bytes at offset %s"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-warn-restrict.cc:1648
+#, gcc-internal-format
+msgid "%qD accessing between %wu and %wu bytes may overlap %wu byte"
+msgid_plural "%qD accessing between %wu and %wu bytes may overlap up to %wu bytes"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-warn-restrict.cc:1655
+#, gcc-internal-format
+msgid "%qD accessing between %wu and %wu bytes at offsets %s and %s may overlap %wu byte at offset %s"
+msgid_plural "%qD accessing between %wu and %wu bytes at offsets %s and %s may overlap up to %wu bytes at offset %s"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-warn-restrict.cc:1667
+#, gcc-internal-format
+msgid "%qD accessing %wu or more bytes at offsets %s and %s may overlap %wu byte at offset %s"
+msgid_plural "%qD accessing %wu or more bytes at offsets %s and %s may overlap up to %wu bytes at offset %s"
+msgstr[0] ""
+msgstr[1] ""
+
+#: gimple-ssa-warn-restrict.cc:1713
+#, gcc-internal-format
+msgid "%qD specified bound %wu exceeds maximum object size %wu"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1719
+#, gcc-internal-format
+msgid "%qD specified bound between %wu and %wu exceeds maximum object size %wu"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1780
+#, gcc-internal-format
+msgid "%qD pointer overflow between offset %s and size %s accessing array %qD with type %qT"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1785 c-family/c-warn.cc:3804
+#, gcc-internal-format
+msgid "array %qD declared here"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1790 gimple-ssa-warn-restrict.cc:1796
+#, gcc-internal-format
+msgid "%qD pointer overflow between offset %s and size %s"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1813
+#, gcc-internal-format
+msgid "%qD forming offset %s is out of the bounds [0, %wu] of object %qD with type %qT"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1816
+#, gcc-internal-format
+msgid "%qD offset %s is out of the bounds [0, %wu] of object %qD with type %qT"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1822
+#, gcc-internal-format
+msgid "%qD forming offset %s is out of the bounds of object %qD with type %qT"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1824
+#, gcc-internal-format
+msgid "%qD offset %s is out of the bounds of object %qD with type %qT"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1837
+#, gcc-internal-format
+msgid "%qD forming offset %s is out of the bounds [0, %wu]"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1839
+#, gcc-internal-format
+msgid "%qD offset %s is out of the bounds [0, %wu]"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1845
+#, gcc-internal-format
+msgid "%qD forming offset %s is out of bounds"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1846
+#, gcc-internal-format
+msgid "%qD offset %s is out of bounds"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1858
+#, gcc-internal-format
+msgid "%qD offset %s from the object at %qE is out of the bounds of %qT"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1866 gimple-ssa-warn-restrict.cc:1887
+#, gcc-internal-format
+msgid "subobject %qD declared here"
+msgstr ""
+
+#: gimple-ssa-warn-restrict.cc:1876
+#, gcc-internal-format
+msgid "%qD offset %s from the object at %qE is out of the bounds of referenced subobject %qD with type %qT at offset %wi"
+msgstr ""
+
+#: gimple-streamer-in.cc:207
+#, gcc-internal-format, gfc-internal-format
+msgid "bytecode stream: unknown GIMPLE statement tag %s"
+msgstr ""
+
+#: gimple-warn-recursion.cc:195
+#, gcc-internal-format
+msgid "infinite recursion detected"
+msgstr ""
+
+#: gimple-warn-recursion.cc:202
+#, gcc-internal-format
+msgid "recursive call"
+msgstr ""
+
+#: gimple.cc:1337
+#, gcc-internal-format, gfc-internal-format
+msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
+msgstr ""
+
+#: gimplify.cc:1426
+#, gcc-internal-format
+msgid "%<allocate%> directive for %qD inside a target region must specify an %<allocator%> clause"
+msgstr ""
+
+#: gimplify.cc:2298
+#, gcc-internal-format
+msgid "statement will never be executed"
+msgstr ""
+
+#: gimplify.cc:2362
+#, gcc-internal-format
+msgid "%qs cannot be initialized with%<-ftrivial-auto-var_init%>"
+msgstr ""
+
+#: gimplify.cc:2754 gimplify.cc:2762
+#, gcc-internal-format
+msgid "this statement may fall through"
+msgstr ""
+
+#: gimplify.cc:2764
+#, gcc-internal-format
+msgid "here"
+msgstr "აქ"
+
+#. We've found [[fallthrough]]; at the end of a switch, which the C++
+#. standard says is ill-formed; see [dcl.attr.fallthrough].
+#: gimplify.cc:2835 gimplify.cc:2892 gimplify.cc:2918
+#, gcc-internal-format
+msgid "attribute %<fallthrough%> not preceding a case label or default label"
+msgstr ""
+
+#: gimplify.cc:4092
+#, gcc-internal-format
+msgid "using result of function returning %<void%>"
+msgstr ""
+
+#: gimplify.cc:7019
+#, gcc-internal-format, gfc-internal-format
+msgid "non-memory output %d must stay in memory"
+msgstr ""
+
+#: gimplify.cc:7034
+#, gcc-internal-format
+msgid "invalid lvalue in %<asm%> output %d"
+msgstr ""
+
+#: gimplify.cc:7181
+#, gcc-internal-format, gfc-internal-format
+msgid "non-memory input %d must stay in memory"
+msgstr ""
+
+#: gimplify.cc:7221 gimplify.cc:7231
+#, gcc-internal-format, gfc-internal-format
+msgid "memory input %d is not directly addressable"
+msgstr ""
+
+#: gimplify.cc:7854
+#, gcc-internal-format
+msgid "threadprivate variable %qE used in a region with %<order(concurrent)%> clause"
+msgstr ""
+
+#: gimplify.cc:7856
+#, gcc-internal-format
+msgid "enclosing region"
+msgstr ""
+
+#: gimplify.cc:7860
+#, gcc-internal-format
+msgid "threadprivate variable %qE used in target region"
+msgstr ""
+
+#: gimplify.cc:7862
+#, gcc-internal-format
+msgid "enclosing target region"
+msgstr ""
+
+#: gimplify.cc:7875
+#, gcc-internal-format
+msgid "threadprivate variable %qE used in untied task"
+msgstr ""
+
+#: gimplify.cc:7877
+#, gcc-internal-format
+msgid "enclosing task"
+msgstr ""
+
+#: gimplify.cc:7974
+#, gcc-internal-format
+msgid "%qE not specified in enclosing %qs"
+msgstr ""
+
+#: gimplify.cc:7976
+#, gcc-internal-format
+msgid "enclosing %qs"
+msgstr ""
+
+#: gimplify.cc:8150
+#, gcc-internal-format
+msgid "%qE not specified in enclosing OpenACC %qs construct"
+msgstr ""
+
+#: gimplify.cc:8154
+#, gcc-internal-format
+msgid "enclosing OpenACC %qs construct and"
+msgstr ""
+
+#: gimplify.cc:8157
+#, gcc-internal-format
+msgid "enclosing OpenACC %qs construct with %qs clause"
+msgstr ""
+
+#: gimplify.cc:8227
+#, gcc-internal-format
+msgid "%qE with %<link%> clause used in %<routine%> function"
+msgstr ""
+
+#: gimplify.cc:8235
+#, gcc-internal-format
+msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
+msgstr ""
+
+#: gimplify.cc:8297
+#, gcc-internal-format
+msgid "%qE not specified in enclosing %<target%>"
+msgstr ""
+
+#: gimplify.cc:8299
+#, gcc-internal-format
+msgid "enclosing %<target%>"
+msgstr ""
+
+#: gimplify.cc:8334 gimplify.cc:12428
+#, gcc-internal-format
+msgid "variable %qE declared in enclosing %<host_data%> region"
+msgstr ""
+
+#: gimplify.cc:8355
+#, gcc-internal-format
+msgid "%qD referenced in target region does not have a mappable type"
+msgstr ""
+
+#: gimplify.cc:8499
+#, gcc-internal-format
+msgid "iteration variable %qE is predetermined linear"
+msgstr ""
+
+#: gimplify.cc:8502
+#, gcc-internal-format
+msgid "iteration variable %qE should be private"
+msgstr ""
+
+#: gimplify.cc:8516
+#, gcc-internal-format
+msgid "iteration variable %qE should not be firstprivate"
+msgstr ""
+
+#: gimplify.cc:8519
+#, gcc-internal-format
+msgid "iteration variable %qE should not be reduction"
+msgstr ""
+
+#: gimplify.cc:8522
+#, gcc-internal-format
+msgid "iteration variable %qE should not be linear"
+msgstr ""
+
+#: gimplify.cc:9526 gimplify.cc:9537 gimplify.cc:9549 gimplify.cc:9565
+#: gimplify.cc:9770 gimplify.cc:9793 gimplify.cc:9804 gimplify.cc:9822
+#, gcc-internal-format
+msgid "unexpected mapping node"
+msgstr ""
+
+#: gimplify.cc:9859
+#, gcc-internal-format
+msgid "unexpected pointer mapping node"
+msgstr ""
+
+#: gimplify.cc:10072
+#, gcc-internal-format
+msgid "base pointer cycle detected"
+msgstr ""
+
+#: gimplify.cc:10579
+#, gcc-internal-format
+msgid "data movement for component %qE is not compatible with movement for struct %qE"
+msgstr ""
+
+#: gimplify.cc:10895
+#, gcc-internal-format
+msgid "%qE appears more than once in map clauses"
+msgstr ""
+
+#: gimplify.cc:11851
+#, gcc-internal-format
+msgid "mapping field %qE of variable length structure"
+msgstr ""
+
+#: gimplify.cc:12121 gimplify.cc:12127
+#, gcc-internal-format
+msgid "conditional %<lastprivate%> clause on %qs construct"
+msgstr ""
+
+#: gimplify.cc:12144
+#, gcc-internal-format
+msgid "non-scalar variable %qD in conditional %<lastprivate%> clause"
+msgstr ""
+
+#: gimplify.cc:12166
+#, gcc-internal-format
+msgid "%<task%> reduction modifier on a construct with a %<nowait%> clause"
+msgstr ""
+
+#: gimplify.cc:12174
+#, gcc-internal-format
+msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs, %<sections%> or %<scope%>"
+msgstr ""
+
+#: gimplify.cc:12185 gimplify.cc:12191 gimplify.cc:12197 gimplify.cc:12203
+#: gimplify.cc:12209 gimplify.cc:16423
+#, gcc-internal-format
+msgid "%<inscan%> %<reduction%> clause on %qs construct"
+msgstr ""
+
+#: gimplify.cc:12303
+#, gcc-internal-format
+msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
+msgstr ""
+
+#: gimplify.cc:12928
+#, gcc-internal-format
+msgid "copyprivate variable %qE is not threadprivate or private in outer context"
+msgstr ""
+
+#: gimplify.cc:12985
+#, gcc-internal-format
+msgid "%s variable %qE is private in outer context"
+msgstr ""
+
+#: gimplify.cc:13017
+#, gcc-internal-format
+msgid "expected %qs %<if%> clause modifier rather than %qs"
+msgstr ""
+
+#: gimplify.cc:13056
+#, gcc-internal-format
+msgid "%<device%> clause with %<ancestor%> is only allowed on %<target%> construct"
+msgstr ""
+
+#: gimplify.cc:13072
+#, gcc-internal-format
+msgid "with %<ancestor%>, only the %<device%>, %<firstprivate%>, %<private%>, %<defaultmap%>, and %<map%> clauses may appear on the construct"
+msgstr ""
+
+#: gimplify.cc:13288
+#, gcc-internal-format
+msgid "%qD specified in %qs clause but not in %<inscan%> %<reduction%> clause on the containing construct"
+msgstr ""
+
+#: gimplify.cc:13500
+#, gcc-internal-format
+msgid "%<_Atomic%> %qD in implicit %<map%> clause"
+msgstr ""
+
+#: gimplify.cc:13554
+#, gcc-internal-format
+msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
+msgstr ""
+
+#: gimplify.cc:13892
+#, gcc-internal-format
+msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
+msgstr ""
+
+#: gimplify.cc:13965
+#, gcc-internal-format
+msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
+msgstr ""
+
+#: gimplify.cc:14142
+#, gcc-internal-format
+msgid "incompatible data clause with reduction on %qE; promoting to %<present_or_copy%>"
+msgstr ""
+
+#: gimplify.cc:14440
+#, gcc-internal-format
+msgid "%qD specified in %<inscan%> %<reduction%> clause but not in %<scan%> directive clause"
+msgstr ""
+
+#: gimplify.cc:14459
+#, gcc-internal-format
+msgid "invalid private reduction on %qE"
+msgstr ""
+
+#: gimplify.cc:14626
+#, gcc-internal-format
+msgid "%<inscan%> %<reduction%> clause used together with %<linear%> clause for a variable other than loop iterator"
+msgstr ""
+
+#: gimplify.cc:14970
+#, gcc-internal-format
+msgid "%<mutexinoutset%> kind in %<depend%> clause on a %<taskwait%> construct"
+msgstr ""
+
+#: gimplify.cc:14980
+#, gcc-internal-format
+msgid "%<taskwait%> construct with %<nowait%> clause but no %<depend%> clauses"
+msgstr ""
+
+#: gimplify.cc:15264 gimplify.cc:15268 gimplify.cc:15277 gimplify.cc:15289
+#: gimplify.cc:15294
+#, gcc-internal-format
+msgid "%qs clause may not appear on non-rectangular %qs"
+msgstr ""
+
+#: gimplify.cc:15455
+#, gcc-internal-format
+msgid "%<linear%> clause may not be specified together with %<ordered%> clause if stand-alone %<ordered%> construct is nested in it"
+msgstr ""
+
+#: gimplify.cc:15520
+#, gcc-internal-format
+msgid "threadprivate iteration variable %qD"
+msgstr ""
+
+#: gimplify.cc:15551 gimplify.cc:15659
+#, gcc-internal-format
+msgid "conditional %<lastprivate%> on loop iterator %qD ignored"
+msgstr ""
+
+#: gimplify.cc:16361
+#, gcc-internal-format
+msgid "%<bind%> clause not specified on a %<loop%> construct not nested inside another OpenMP construct"
+msgstr ""
+
+#: gimplify.cc:16385
+#, gcc-internal-format
+msgid "%<bind(parallel)%> on a %<loop%> construct nested inside %<simd%> construct"
+msgstr ""
+
+#: gimplify.cc:16405
+#, gcc-internal-format
+msgid "%<bind(teams)%> on a %<loop%> region not strictly nested inside of a %<teams%> region"
+msgstr ""
+
+#: gimplify.cc:16430
+#, gcc-internal-format
+msgid "invalid %<task%> reduction modifier on construct other than %<parallel%>, %qs or %<sections%>"
+msgstr ""
+
+#: gimplify.cc:16458
+#, gcc-internal-format
+msgid "%<lastprivate%> clause on a %<loop%> construct refers to a variable %qD which is not the loop iterator"
+msgstr ""
+
+#: gimplify.cc:17540
+#, gcc-internal-format
+msgid "%<ordered%> construct with %qs clause must be closely nested inside a loop with %<ordered%> clause"
+msgstr ""
+
+#: gimplify.cc:17561
+#, gcc-internal-format
+msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
+msgstr ""
+
+#: gimplify.cc:17574
+#, gcc-internal-format
+msgid "number of variables in %qs clause with %<sink%> modifier does not match number of iteration variables"
+msgstr ""
+
+#: gimplify.cc:17588
+#, gcc-internal-format
+msgid "more than one %qs clause with %<source%> modifier on an %<ordered%> construct"
+msgstr ""
+
+#: gimplify.cc:17601
+#, gcc-internal-format
+msgid "%qs clause with %<source%> modifier specified together with %qs clauses with %<sink%> modifier on the same construct"
+msgstr ""
+
+#: gimplify.cc:18918
+#, gcc-internal-format
+msgid "gimplification failed"
+msgstr ""
+
+#: gimplify.cc:19519
+#, gcc-internal-format
+msgid "%qT is promoted to %qT when passed through %<...%>"
+msgstr ""
+
+#: gimplify.cc:19524
+#, gcc-internal-format
+msgid "(so you should pass %qT not %qT to %<va_arg%>)"
+msgstr ""
+
+#: gimplify.cc:19531
+#, gcc-internal-format
+msgid "if this code is reached, the program will abort"
+msgstr ""
+
+#: godump.cc:1438
+#, gcc-internal-format
+msgid "could not close Go dump file: %m"
+msgstr ""
+
+#: godump.cc:1450
+#, gcc-internal-format
+msgid "could not open Go dump file %qs: %m"
+msgstr ""
+
+#: graphite.cc:529
+#, gcc-internal-format
+msgid "Graphite loop optimizations cannot be used (isl is not available)."
+msgstr ""
+
+#: input.cc:1482
+#, gcc-internal-format, gfc-internal-format
+msgid "expansion point is location %i"
+msgstr ""
+
+#: input.cc:1512
+#, gcc-internal-format
+msgid "token %u has %<x-location == y-location == %u%>"
+msgstr ""
+
+#: input.cc:1521
+#, gcc-internal-format
+msgid "token %u has %<x-location == %u%>"
+msgstr ""
+
+#: input.cc:1522
+#, gcc-internal-format
+msgid "token %u has %<y-location == %u%>"
+msgstr ""
+
+#: internal-fn.cc:843
+#, gcc-internal-format
+msgid "invalid use of attribute %<fallthrough%>"
+msgstr ""
+
+#: ipa-devirt.cc:679 ipa-devirt.cc:764 ipa-devirt.cc:793 ipa-devirt.cc:835
+#: ipa-devirt.cc:866
+#, gcc-internal-format
+msgid "virtual table of type %qD violates one definition rule"
+msgstr ""
+
+#: ipa-devirt.cc:682
+#, gcc-internal-format
+msgid "variable of same assembler name as the virtual table is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:723
+#, gcc-internal-format
+msgid "virtual table of type %qD contains RTTI information"
+msgstr ""
+
+#: ipa-devirt.cc:729
+#, gcc-internal-format
+msgid "but is prevailed by one without from other translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:733
+#, gcc-internal-format
+msgid "RTTI will not work on this type"
+msgstr ""
+
+#: ipa-devirt.cc:770
+#, gcc-internal-format
+msgid "the conflicting type defined in another translation unit has virtual table of different size"
+msgstr ""
+
+#: ipa-devirt.cc:799
+#, gcc-internal-format
+msgid "the conflicting type defined in another translation unit with different RTTI information"
+msgstr ""
+
+#: ipa-devirt.cc:843 ipa-devirt.cc:874
+#, gcc-internal-format
+msgid "the conflicting type defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:847
+#, gcc-internal-format
+msgid "contains additional virtual method %qD"
+msgstr ""
+
+#: ipa-devirt.cc:854
+#, gcc-internal-format
+msgid "the conflicting type defined in another translation unit has virtual table with more entries"
+msgstr ""
+
+#: ipa-devirt.cc:880
+#, gcc-internal-format
+msgid "virtual method %qD"
+msgstr ""
+
+#: ipa-devirt.cc:884
+#, gcc-internal-format
+msgid "ought to match virtual method %qD but does not"
+msgstr ""
+
+#: ipa-devirt.cc:890
+#, gcc-internal-format
+msgid "the conflicting type defined in another translation unit has virtual table with different contents"
+msgstr ""
+
+#: ipa-devirt.cc:924
+#, gcc-internal-format
+msgid "type %qT (typedef of %qT) violates the C++ One Definition Rule"
+msgstr ""
+
+#: ipa-devirt.cc:932
+#, gcc-internal-format
+msgid "type %qT violates the C++ One Definition Rule"
+msgstr ""
+
+#: ipa-devirt.cc:944 ipa-devirt.cc:959 ipa-devirt.cc:1237 ipa-devirt.cc:1282
+#: ipa-devirt.cc:1321 ipa-devirt.cc:1339
+#, gcc-internal-format
+msgid "a different type is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:951
+#, gcc-internal-format
+msgid "the first difference of corresponding definitions is field %qD"
+msgstr ""
+
+#: ipa-devirt.cc:961
+#, gcc-internal-format
+msgid "the first difference of corresponding definitions is method %qD"
+msgstr ""
+
+#: ipa-devirt.cc:1066
+#, gcc-internal-format
+msgid "type %qT defined in anonymous namespace cannot match type %qT across the translation unit boundary"
+msgstr ""
+
+#: ipa-devirt.cc:1071
+#, gcc-internal-format
+msgid "type %qT defined in anonymous namespace cannot match across the translation unit boundary"
+msgstr ""
+
+#: ipa-devirt.cc:1076
+#, gcc-internal-format
+msgid "the incompatible type defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:1092
+#, gcc-internal-format
+msgid "type name %qs should match type name %qs"
+msgstr ""
+
+#: ipa-devirt.cc:1096 ipa-devirt.cc:1193
+#, gcc-internal-format
+msgid "the incompatible type is defined here"
+msgstr ""
+
+#: ipa-devirt.cc:1124
+#, gcc-internal-format
+msgid "array types have different bounds"
+msgstr ""
+
+#: ipa-devirt.cc:1139
+#, gcc-internal-format
+msgid "return value type mismatch"
+msgstr ""
+
+#: ipa-devirt.cc:1154
+#, gcc-internal-format
+msgid "implicit this pointer type mismatch"
+msgstr ""
+
+#: ipa-devirt.cc:1157
+#, gcc-internal-format, gfc-internal-format
+msgid "type mismatch in parameter %i"
+msgstr ""
+
+#: ipa-devirt.cc:1168
+#, gcc-internal-format
+msgid "types have different parameter counts"
+msgstr ""
+
+#: ipa-devirt.cc:1184
+#, gcc-internal-format
+msgid "type %qT itself violates the C++ One Definition Rule"
+msgstr ""
+
+#: ipa-devirt.cc:1190
+#, gcc-internal-format
+msgid "type %qT should match type %qT"
+msgstr ""
+
+#: ipa-devirt.cc:1265
+#, gcc-internal-format
+msgid "a type with different precision is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:1272
+#, gcc-internal-format
+msgid "a type with different signedness is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:1297
+#, gcc-internal-format
+msgid "it is defined as a pointer in different address space in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:1306
+#, gcc-internal-format
+msgid "it is defined as a pointer to different type in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:1366
+#, gcc-internal-format
+msgid "an array of different size is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:1381
+#, gcc-internal-format
+msgid "has different return value in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:1404 ipa-devirt.cc:1416
+#, gcc-internal-format
+msgid "has different parameters in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:1439
+#, gcc-internal-format
+msgid "a type defined in another translation unit is not polymorphic"
+msgstr ""
+
+#: ipa-devirt.cc:1443
+#, gcc-internal-format
+msgid "a type defined in another translation unit is polymorphic"
+msgstr ""
+
+#: ipa-devirt.cc:1461 ipa-devirt.cc:1525
+#, gcc-internal-format
+msgid "a type with different virtual table pointers is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:1468 ipa-devirt.cc:1530
+#, gcc-internal-format
+msgid "a type with different bases is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:1476
+#, gcc-internal-format
+msgid "a field with different name is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:1490
+#, gcc-internal-format
+msgid "a field of same name but different type is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:1503
+#, gcc-internal-format
+msgid "fields have different layout in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:1510
+#, gcc-internal-format
+msgid "one field is a bitfield while the other is not"
+msgstr ""
+
+#: ipa-devirt.cc:1534
+#, gcc-internal-format
+msgid "a type with different number of fields is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:1557
+#, gcc-internal-format
+msgid "a type with different size is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:1566
+#, gcc-internal-format
+msgid "one type needs to be constructed while the other does not"
+msgstr ""
+
+#: ipa-devirt.cc:1579
+#, gcc-internal-format
+msgid "memory layout mismatch"
+msgstr ""
+
+#: ipa-devirt.cc:1698
+#, gcc-internal-format
+msgid "the extra base is defined here"
+msgstr ""
+
+#: ipa-devirt.cc:3874
+#, gcc-internal-format
+msgid "Declaring type %qD final would enable devirtualization of %i call"
+msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
+msgstr[0] ""
+msgstr[1] ""
+
+#: ipa-devirt.cc:3883
+#, gcc-internal-format
+msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
+msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
+msgstr[0] ""
+msgstr[1] ""
+
+#: ipa-devirt.cc:3913
+#, gcc-internal-format
+msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
+msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
+msgstr[0] ""
+msgstr[1] ""
+
+#: ipa-devirt.cc:3921
+#, gcc-internal-format
+msgid "Declaring method %qD final would enable devirtualization of %i call"
+msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
+msgstr[0] ""
+msgstr[1] ""
+
+#: ipa-devirt.cc:3929
+#, gcc-internal-format
+msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
+msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
+msgstr[0] ""
+msgstr[1] ""
+
+#: ipa-devirt.cc:3940
+#, gcc-internal-format
+msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
+msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
+msgstr[0] ""
+msgstr[1] ""
+
+#: ipa-devirt.cc:4253
+#, gcc-internal-format
+msgid "type %qs violates the C++ One Definition Rule"
+msgstr ""
+
+#: ipa-devirt.cc:4262
+#, gcc-internal-format
+msgid "an enum with different number of values is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:4266
+#, gcc-internal-format
+msgid "an enum with different value name is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:4270
+#, gcc-internal-format
+msgid "an enum with different values is defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:4291
+#, gcc-internal-format
+msgid "name %qs differs from name %qs defined in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:4297
+#, gcc-internal-format
+msgid "name %qs is defined as %u-bit while another translation unit defines it as %u-bit"
+msgstr ""
+
+#: ipa-devirt.cc:4306
+#, gcc-internal-format
+msgid "name %qs is defined to %wd while another translation unit defines it as %wd"
+msgstr ""
+
+#: ipa-devirt.cc:4312
+#, gcc-internal-format
+msgid "name %qs is defined to different value in another translation unit"
+msgstr ""
+
+#: ipa-devirt.cc:4317
+#, gcc-internal-format
+msgid "mismatching definition"
+msgstr ""
+
+#: ipa-fnsummary.cc:4658
+#, gcc-internal-format
+msgid "invalid fnsummary in LTO stream"
+msgstr ""
+
+#: ipa-fnsummary.cc:4759
+#, gcc-internal-format
+msgid "ipa inline summary is missing in input file"
+msgstr ""
+
+#: ipa-modref.cc:4022
+#, gcc-internal-format
+msgid "IPA modref summary is missing in input file"
+msgstr ""
+
+#: ipa-prop.cc:4824 ipa-prop.cc:4866 ipa-prop.cc:4943 ipa-prop.cc:4991
+#, gcc-internal-format
+msgid "invalid jump function in LTO stream"
+msgstr ""
+
+#: ipa-pure-const.cc:220
+#, gcc-internal-format
+msgid "function might be candidate for attribute %qs"
+msgstr ""
+
+#: ipa-pure-const.cc:221
+#, gcc-internal-format
+msgid "function might be candidate for attribute %qs if it is known to return normally"
+msgstr ""
+
+#: ipa-reference.cc:1264
+#, gcc-internal-format
+msgid "ipa reference summary is missing in ltrans unit"
+msgstr ""
+
+#: ipa-sra.cc:1621
+#, gcc-internal-format
+msgid "Access offset before parent offset"
+msgstr ""
+
+#: ipa-sra.cc:1626
+#, gcc-internal-format
+msgid "Access size greater or equal to its parent size"
+msgstr ""
+
+#: ipa-sra.cc:1631
+#, gcc-internal-format
+msgid "Access terminates outside of its parent"
+msgstr ""
+
+#: ipa-sra.cc:1643
+#, gcc-internal-format
+msgid "Access overlaps with its sibling"
+msgstr ""
+
+#: ipa-sra.cc:1662
+#, gcc-internal-format
+msgid "IPA-SRA access verification failed"
+msgstr ""
+
+#: ipa-sra.cc:2747
+#, gcc-internal-format
+msgid "function %qs, parameter %u, has IPA-SRA accesses which overlap"
+msgstr ""
+
+#: ipa-sra.cc:2750
+#, gcc-internal-format
+msgid "function %qs, parameter %u, is used but does not have any certain IPA-SRA access"
+msgstr ""
+
+#: ipa-strub.cc:622
+#, gcc-internal-format
+msgid "at-calls %<strub%> does not support call to %qD"
+msgstr ""
+
+#: ipa-strub.cc:656
+#, gcc-internal-format
+msgid "%qD is not eligible for %<strub%> on the target system"
+msgstr ""
+
+#: ipa-strub.cc:660
+#, gcc-internal-format
+msgid "unsupported %<strub%> call on the target system"
+msgstr ""
+
+#: ipa-strub.cc:686
+#, gcc-internal-format
+msgid "%qD is not eligible for %<strub%> because %<-fsplit-stack%> is enabled"
+msgstr ""
+
+#: ipa-strub.cc:699
+#, gcc-internal-format
+msgid "%qD is not eligible for %<strub%> because of attribute %<noipa%>"
+msgstr ""
+
+#: ipa-strub.cc:714
+#, gcc-internal-format
+msgid "%qD is not eligible for %<strub%> because of attribute %<simd%>"
+msgstr ""
+
+#: ipa-strub.cc:848
+#, gcc-internal-format
+msgid "%qD is not eligible for internal %<strub%> because of attribute %<noclone%>"
+msgstr ""
+
+#: ipa-strub.cc:872
+#, gcc-internal-format
+msgid "%qD is not eligible for internal %<strub%> because it calls %qD"
+msgstr ""
+
+#: ipa-strub.cc:886
+#, gcc-internal-format
+msgid "%qD is not eligible for internal %<strub%> because it contains a non-local goto target"
+msgstr ""
+
+#: ipa-strub.cc:899
+#, gcc-internal-format
+msgid "%qD is not eligible for internal %<strub%> because the address of a local label escapes"
+msgstr ""
+
+#: ipa-strub.cc:938
+#, gcc-internal-format
+msgid "internal %<strub%> does not support forced labels"
+msgstr ""
+
+#: ipa-strub.cc:952
+#, gcc-internal-format
+msgid "%qD has too many arguments for internal %<strub%>"
+msgstr ""
+
+#: ipa-strub.cc:1229
+#, gcc-internal-format
+msgid "%qD requires %<strub%>, but no viable %<strub%> mode was found"
+msgstr ""
+
+#: ipa-strub.cc:1325
+#, gcc-internal-format
+msgid "%<strub%> mode %qE selected for %qD, when %qE was requested"
+msgstr ""
+
+#: ipa-strub.cc:1334
+#, gcc-internal-format
+msgid "the incompatible selection was determined by ultimate alias target %qD"
+msgstr ""
+
+#: ipa-strub.cc:1681
+#, gcc-internal-format
+msgid "indirect non-%<strub%> call in %<strub%> context %qD"
+msgstr ""
+
+#: ipa-strub.cc:1700
+#, gcc-internal-format
+msgid "calling %<always_inline%> %<strub%> %qD in non-%<strub%> context %qD"
+msgstr ""
+
+#: ipa-strub.cc:1710
+#, gcc-internal-format
+msgid "calling non-%<strub%> %qD in %<strub%> context %qD"
+msgstr ""
+
+#: ipa-strub.cc:1714
+#, gcc-internal-format
+msgid "calling %qD using non-%<strub%> type %qT in %<strub%> context %qD"
+msgstr ""
+
+#: ipa-strub.cc:2839
+#, gcc-internal-format
+msgid "failed to split %qD for %<strub%>"
+msgstr ""
+
+#: ira.cc:2441 ira.cc:2463
+#, gcc-internal-format
+msgid "%s cannot be used in %<asm%> here"
+msgstr ""
+
+#: ira.cc:6059
+#, gcc-internal-format
+msgid "frame pointer required, but reserved"
+msgstr ""
+
+#: ira.cc:6060
+#, gcc-internal-format
+msgid "for %qD"
+msgstr ""
+
+#: ira.cc:6076
+#, gcc-internal-format
+msgid "frame size too large for reliable stack checking"
+msgstr ""
+
+#: lra-assigns.cc:1702
+#, gcc-internal-format, gfc-internal-format
+msgid "maximum number of LRA assignment passes is achieved (%d)"
+msgstr ""
+
+#: lra-assigns.cc:1867
+#, gcc-internal-format
+msgid "unable to find a register to spill"
+msgstr ""
+
+#: lra-constraints.cc:4236 reload.cc:3840 reload.cc:4095
+#, gcc-internal-format
+msgid "inconsistent operand constraints in an %<asm%>"
+msgstr ""
+
+#: lra-constraints.cc:5350
+#, gcc-internal-format, gfc-internal-format
+msgid "maximum number of generated reload insns per insn achieved (%d)"
+msgstr ""
+
+#: lra.cc:546
+#, gcc-internal-format
+msgid "%<asm%> operand has impossible constraints or there are not enough registers"
+msgstr ""
+
+#: lto-cgraph.cc:1171
+#, gcc-internal-format
+msgid "function %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
+msgstr ""
+
+#: lto-cgraph.cc:1177
+#, gcc-internal-format
+msgid "variable %qs has been referenced in offloaded code but hasn%'t been marked to be included in the offloaded code"
+msgstr ""
+
+#: lto-cgraph.cc:1346
+#, gcc-internal-format, gfc-internal-format
+msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
+msgstr ""
+
+#: lto-cgraph.cc:1511
+#, gcc-internal-format
+msgid "bytecode stream: no caller found while reading edge"
+msgstr ""
+
+#: lto-cgraph.cc:1517
+#, gcc-internal-format
+msgid "bytecode stream: no callee found while reading edge"
+msgstr ""
+
+#: lto-cgraph.cc:1594
+#, gcc-internal-format
+msgid "bytecode stream: found empty cgraph node"
+msgstr ""
+
+#: lto-cgraph.cc:1713
+#, gcc-internal-format, gfc-internal-format
+msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
+msgstr ""
+
+#: lto-cgraph.cc:1738
+#, gcc-internal-format, gfc-internal-format
+msgid "Profile information in %s corrupted"
+msgstr ""
+
+#: lto-cgraph.cc:1776
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot find LTO cgraph in %s"
+msgstr ""
+
+#: lto-cgraph.cc:1786
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot find LTO section refs in %s"
+msgstr ""
+
+#: lto-cgraph.cc:1944
+#, gcc-internal-format
+msgid "OpenMP %<requires%> directive with non-identical clauses in multiple compilation units: %qs vs. %qs"
+msgstr ""
+
+#: lto-cgraph.cc:1947 lto-cgraph.cc:1948 lto-cgraph.cc:1954
+#, gcc-internal-format
+msgid "%qs has %qs"
+msgstr ""
+
+#: lto-cgraph.cc:1952
+#, gcc-internal-format
+msgid "OpenMP %<requires%> directive with %qs specified only in some compilation units"
+msgstr ""
+
+#: lto-cgraph.cc:1957
+#, gcc-internal-format
+msgid "but %qs has not"
+msgstr ""
+
+#: lto-cgraph.cc:1965
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid offload table in %s"
+msgstr ""
+
+#: lto-cgraph.cc:1976
+#, gcc-internal-format
+msgid "GCC_OFFLOAD_OMP_REQUIRES_FILE unset"
+msgstr ""
+
+#: lto-cgraph.cc:1979
+#, gcc-internal-format
+msgid "Cannot open omp_requires file %qs"
+msgstr ""
+
+#: lto-compress.cc:142 lto-compress.cc:269 lto-compress.cc:277
+#: lto-compress.cc:297 lto-compress.cc:363 lto-compress.cc:371
+#: lto-compress.cc:391
+#, gcc-internal-format, gfc-internal-format
+msgid "compressed stream: %s"
+msgstr ""
+
+#: lto-compress.cc:163
+#, gcc-internal-format
+msgid "original not compressed with zstd"
+msgstr ""
+
+#: lto-compress.cc:165
+#, gcc-internal-format
+msgid "original size unknown"
+msgstr ""
+
+#: lto-compress.cc:171
+#, gcc-internal-format, gfc-internal-format
+msgid "decompressed stream: %s"
+msgstr ""
+
+#: lto-compress.cc:411
+#, gcc-internal-format
+msgid "compiler does not support ZSTD LTO compression"
+msgstr ""
+
+#: lto-section-in.cc:460
+#, gcc-internal-format, gfc-internal-format
+msgid "bytecode stream: trying to read %d bytes after the end of the input buffer"
+msgstr ""
+
+#: lto-section-in.cc:471
+#, gcc-internal-format, gfc-internal-format
+msgid "%s out of range: Range is %i to %i, value is %i"
+msgstr ""
+
+#: lto-streamer-in.cc:125
+#, gcc-internal-format, gfc-internal-format
+msgid "bytecode stream: unexpected tag %s"
+msgstr ""
+
+#: lto-streamer-in.cc:1215 lto-streamer-in.cc:1226
+#, gcc-internal-format
+msgid "Cgraph edge statement index out of range"
+msgstr ""
+
+#: lto-streamer-in.cc:1220 lto-streamer-in.cc:1230
+#, gcc-internal-format
+msgid "Cgraph edge statement index not found"
+msgstr ""
+
+#: lto-streamer-in.cc:1237
+#, gcc-internal-format
+msgid "Reference statement index out of range"
+msgstr ""
+
+#: lto-streamer-in.cc:1241
+#, gcc-internal-format
+msgid "Reference statement index not found"
+msgstr ""
+
+#: lto-streamer-in.cc:2001
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot read LTO mode table from %s"
+msgstr ""
+
+#: lto-streamer-in.cc:2107
+#, gcc-internal-format
+msgid "%s - %u-bit-precision floating-point numbers unsupported (mode %qs)"
+msgstr ""
+
+#: lto-streamer-in.cc:2112
+#, gcc-internal-format
+msgid "%s - %u-bit-precision decimal floating-point numbers unsupported (mode %qs)"
+msgstr ""
+
+#: lto-streamer-in.cc:2117
+#, gcc-internal-format
+msgid "%s - %u-bit-precision complex floating-point numbers unsupported (mode %qs)"
+msgstr ""
+
+#: lto-streamer-in.cc:2122
+#, gcc-internal-format
+msgid "%s - %u-bit integer numbers unsupported (mode %qs)"
+msgstr ""
+
+#: lto-streamer-in.cc:2125
+#, gcc-internal-format
+msgid "%s - unsupported mode %qs"
+msgstr ""
+
+#: lto-streamer-out.cc:561 lto-streamer-out.cc:913
+#, gcc-internal-format
+msgid "tree code %qs is not supported in LTO streams"
+msgstr ""
+
+#: lto-streamer.cc:129
+#, gcc-internal-format, gfc-internal-format
+msgid "bytecode stream: unexpected LTO section %s"
+msgstr ""
+
+#: lto-streamer.cc:261
+#, gcc-internal-format
+msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
+msgstr ""
+
+#: lto-wrapper.cc:159
+#, gcc-internal-format
+msgid "deleting LTRANS file %s: %m"
+msgstr ""
+
+#: lto-wrapper.cc:358
+#, gcc-internal-format, gfc-internal-format
+msgid "option %s with different values"
+msgstr ""
+
+#: lto-wrapper.cc:374
+#, gcc-internal-format
+msgid "option %qs with mismatching values (%s, %s)"
+msgstr ""
+
+#: lto-wrapper.cc:489
+#, gcc-internal-format, gfc-internal-format
+msgid "option %s not used consistently in all LTO input files"
+msgstr ""
+
+#: lto-wrapper.cc:634 lto-wrapper.cc:642
+#, gcc-internal-format
+msgid "Extra option to %<-Xassembler%>: %s, dropping all %<-Xassembler%> and %<-Wa%> options."
+msgstr ""
+
+#: lto-wrapper.cc:650
+#, gcc-internal-format
+msgid "Options to %<-Xassembler%> do not match: %s, %s, dropping all %<-Xassembler%> and %<-Wa%> options."
+msgstr ""
+
+#: lto-wrapper.cc:960
+#, gcc-internal-format
+msgid "could not find %s in %s (consider using %<-B%>)"
+msgstr ""
+
+#: lto-wrapper.cc:1041
+#, gcc-internal-format, gfc-internal-format
+msgid "problem with building target image for %s"
+msgstr ""
+
+#: lto-wrapper.cc:1070
+#, gcc-internal-format
+msgid "reading input file"
+msgstr ""
+
+#: lto-wrapper.cc:1075
+#, gcc-internal-format
+msgid "writing output file"
+msgstr ""
+
+#: lto-wrapper.cc:1111
+#, gcc-internal-format
+msgid "installation error, cannot find %<crtoffloadtable.o%>"
+msgstr ""
+
+#: lto-wrapper.cc:1433
+#, gcc-internal-format
+msgid "environment variable %<COLLECT_GCC%> must be set"
+msgstr ""
+
+#: lto-wrapper.cc:1437 config/gcn/mkoffload.cc:811
+#, gcc-internal-format
+msgid "environment variable %<COLLECT_GCC_OPTIONS%> must be set"
+msgstr ""
+
+#: lto-wrapper.cc:1727 lto-wrapper.cc:1787 c-family/c-pch.cc:213
+#: c-family/c-pch.cc:248 c-family/c-pch.cc:286
+#, gcc-internal-format
+msgid "cannot read %s: %m"
+msgstr ""
+
+#: lto-wrapper.cc:1754
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid format of %s"
+msgstr ""
+
+#: lto-wrapper.cc:1920
+#, gcc-internal-format
+msgid "%<fopen%>: %s: %m"
+msgstr ""
+
+#: lto-wrapper.cc:1937
+#, gcc-internal-format, gfc-internal-format
+msgid "corrupted ltrans output file %s"
+msgstr ""
+
+#: lto-wrapper.cc:1980
+#, gcc-internal-format, gfc-internal-format
+msgid "using serial compilation of %d LTRANS jobs"
+msgstr ""
+
+#: lto-wrapper.cc:2160 config/gcn/mkoffload.cc:936
+#, gcc-internal-format
+msgid "%<atexit%> failed"
+msgstr ""
+
+#: multiple_target.cc:72
+#, gcc-internal-format
+msgid "the call requires %<ifunc%>, which is not supported by this target"
+msgstr ""
+
+#: multiple_target.cc:79
+#, gcc-internal-format
+msgid "target does not support function version dispatcher"
+msgstr ""
+
+#: multiple_target.cc:87
+#, gcc-internal-format
+msgid "default %<target_clones%> attribute was not set"
+msgstr ""
+
+#: multiple_target.cc:322 c-family/c-attribs.cc:5910
+#, gcc-internal-format
+msgid "single %<target_clones%> attribute is ignored"
+msgstr ""
+
+#: multiple_target.cc:331
+#, gcc-internal-format
+msgid "clones for %<target_clones%> attribute cannot be created"
+msgstr ""
+
+#: multiple_target.cc:334
+#, gcc-internal-format
+msgid "function %q+F can never be copied because it has %<noclone%> attribute"
+msgstr ""
+
+#: multiple_target.cc:355
+#, gcc-internal-format
+msgid "%<default%> target was not set"
+msgstr ""
+
+#: multiple_target.cc:359
+#, gcc-internal-format
+msgid "an empty string cannot be in %<target_clones%> attribute"
+msgstr ""
+
+#: multiple_target.cc:363
+#, gcc-internal-format
+msgid "multiple %<default%> targets were set"
+msgstr ""
+
+#: omp-expand.cc:3420
+#, gcc-internal-format
+msgid "%qs clause with %<sink%> modifier waiting for lexically later iteration"
+msgstr ""
+
+#: omp-expand.cc:3560
+#, gcc-internal-format
+msgid "%qs clause with %<sink%> modifier refers to iteration never in the iteration space"
+msgstr ""
+
+#: omp-expand.cc:8186
+#, gcc-internal-format
+msgid "invalid OpenMP non-rectangular loop step; %<(%E - %E) * %E%> is not a multiple of loop %d step %qE"
+msgstr ""
+
+#: omp-general.cc:1283
+#, gcc-internal-format
+msgid "%<target_device%> selector set is not supported yet"
+msgstr ""
+
+#: omp-general.cc:1288
+#, gcc-internal-format
+msgid "selector set %qs specified more than once"
+msgstr ""
+
+#: omp-general.cc:1308
+#, gcc-internal-format
+msgid "selector %qs specified more than once in set %qs"
+msgstr ""
+
+#: omp-general.cc:1332
+#, gcc-internal-format
+msgid "incorrect property %qs of %qs selector"
+msgstr ""
+
+#: omp-general.cc:1340
+#, gcc-internal-format
+msgid "unknown property %qE of %qs selector"
+msgstr ""
+
+#: omp-general.cc:1345 omp-general.cc:1350
+#, gcc-internal-format
+msgid "unknown property %qs of %qs selector"
+msgstr ""
+
+#: omp-general.cc:1402
+#, gcc-internal-format
+msgid "%qD used as a variant with incompatible %<construct%> selector sets"
+msgstr ""
+
+#: omp-general.cc:3005
+#, gcc-internal-format
+msgid "%qs specifies a conflicting level of parallelism"
+msgstr ""
+
+#: omp-general.cc:3008
+#, gcc-internal-format
+msgid "... to the previous %qs clause here"
+msgstr ""
+
+#: omp-general.cc:3043
+#, gcc-internal-format
+msgid "cannot apply %<%s%> to %qD, which has also been marked with an OpenMP 'declare target' directive"
+msgstr ""
+
+#: omp-general.cc:3097
+#, gcc-internal-format
+msgid "incompatible %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
+msgstr ""
+
+#: omp-general.cc:3104
+#, gcc-internal-format
+msgid "missing %qs clause when applying %<%s%> to %qD, which has already been marked with an OpenACC 'routine' directive"
+msgstr ""
+
+#: omp-general.cc:3113
+#, gcc-internal-format
+msgid "... with %qs clause here"
+msgstr ""
+
+#: omp-general.cc:3121
+#, gcc-internal-format
+msgid "... without %qs clause near to here"
+msgstr ""
+
+#: omp-low.cc:1167
+#, gcc-internal-format
+msgid "%<allocate%> clause must specify an allocator here"
+msgstr ""
+
+#: omp-low.cc:2745 omp-offload.cc:1518
+#, gcc-internal-format
+msgid "%<seq%> overrides other OpenACC loop specifiers"
+msgstr ""
+
+#: omp-low.cc:2748 omp-offload.cc:1519
+#, gcc-internal-format
+msgid "%<auto%> conflicts with other OpenACC loop specifiers"
+msgstr ""
+
+#: omp-low.cc:2752 omp-offload.cc:1553
+#, gcc-internal-format
+msgid "inner loop uses same OpenACC parallelism as containing loop"
+msgstr ""
+
+#: omp-low.cc:2803
+#, gcc-internal-format
+msgid "argument not permitted on %qs clause"
+msgstr ""
+
+#: omp-low.cc:2807
+#, gcc-internal-format
+msgid "enclosing parent compute construct"
+msgstr ""
+
+#: omp-low.cc:2810
+#, gcc-internal-format
+msgid "enclosing routine"
+msgstr ""
+
+#: omp-low.cc:2851
+#, gcc-internal-format
+msgid "conflicting reduction operations for %qE"
+msgstr ""
+
+#: omp-low.cc:2855
+#, gcc-internal-format
+msgid "location of the previous reduction for %qE"
+msgstr ""
+
+#: omp-low.cc:2888
+#, gcc-internal-format
+msgid "nested loop in reduction needs reduction clause for %qE"
+msgstr ""
+
+#: omp-low.cc:3145
+#, gcc-internal-format
+msgid "%<target%> construct with nested %<teams%> construct contains directives outside of the %<teams%> construct"
+msgstr ""
+
+#: omp-low.cc:3203
+#, gcc-internal-format
+msgid "non-OpenACC construct inside of OpenACC routine"
+msgstr ""
+
+#: omp-low.cc:3212
+#, gcc-internal-format
+msgid "non-OpenACC construct inside of OpenACC region"
+msgstr ""
+
+#: omp-low.cc:3227
+#, gcc-internal-format
+msgid "OpenMP constructs are not allowed in target region with %<ancestor%>"
+msgstr ""
+
+#: omp-low.cc:3252 omp-low.cc:3319
+#, gcc-internal-format
+msgid "OpenMP constructs other than %<parallel%>, %<loop%> or %<simd%> may not be nested inside a region with the %<order(concurrent)%> clause"
+msgstr ""
+
+#: omp-low.cc:3271
+#, gcc-internal-format
+msgid "%<ordered simd threads%> must be closely nested inside of %<%s simd%> region"
+msgstr ""
+
+#: omp-low.cc:3287
+#, gcc-internal-format
+msgid "OpenMP constructs other than %<ordered simd%>, %<simd%>, %<loop%> or %<atomic%> may not be nested inside %<simd%> region"
+msgstr ""
+
+#: omp-low.cc:3301
+#, gcc-internal-format
+msgid "only %<distribute%>, %<parallel%> or %<loop%> regions are allowed to be strictly nested inside %<teams%> region"
+msgstr ""
+
+#: omp-low.cc:3315
+#, gcc-internal-format
+msgid "OpenMP constructs other than %<parallel%>, %<loop%> or %<simd%> may not be nested inside a %<loop%> region"
+msgstr ""
+
+#: omp-low.cc:3335
+#, gcc-internal-format
+msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
+msgstr ""
+
+#: omp-low.cc:3384
+#, gcc-internal-format
+msgid "OpenACC loop directive must be associated with an OpenACC compute region"
+msgstr ""
+
+#: omp-low.cc:3406
+#, gcc-internal-format
+msgid "orphaned %qs construct"
+msgstr ""
+
+#: omp-low.cc:3435
+#, gcc-internal-format
+msgid "%<cancel for%> inside %<nowait%> for construct"
+msgstr ""
+
+#: omp-low.cc:3440
+#, gcc-internal-format
+msgid "%<cancel for%> inside %<ordered%> for construct"
+msgstr ""
+
+#: omp-low.cc:3460 omp-low.cc:3473
+#, gcc-internal-format
+msgid "%<cancel sections%> inside %<nowait%> sections construct"
+msgstr ""
+
+#: omp-low.cc:3502
+#, gcc-internal-format
+msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
+msgstr ""
+
+#: omp-low.cc:3527
+#, gcc-internal-format
+msgid "invalid arguments"
+msgstr ""
+
+#: omp-low.cc:3533
+#, gcc-internal-format
+msgid "%<%s %s%> construct not closely nested inside of %qs"
+msgstr ""
+
+#: omp-low.cc:3562
+#, gcc-internal-format
+msgid "barrier region may not be closely nested inside of work-sharing, %<loop%>, %<critical%>, %<ordered%>, %<master%>, %<masked%>, explicit %<task%> or %<taskloop%> region"
+msgstr ""
+
+#: omp-low.cc:3569
+#, gcc-internal-format
+msgid "work-sharing region may not be closely nested inside of work-sharing, %<loop%>, %<critical%>, %<ordered%>, %<master%>, %<masked%>, explicit %<task%> or %<taskloop%> region"
+msgstr ""
+
+#: omp-low.cc:3600
+#, gcc-internal-format
+msgid "%qs region may not be closely nested inside of work-sharing, %<loop%>, explicit %<task%> or %<taskloop%> region"
+msgstr ""
+
+#: omp-low.cc:3635
+#, gcc-internal-format
+msgid "%<scope%> region may not be closely nested inside of work-sharing, %<loop%>, explicit %<task%>, %<taskloop%>, %<critical%>, %<ordered%>, %<master%>, or %<masked%> region"
+msgstr ""
+
+#: omp-low.cc:3658
+#, gcc-internal-format
+msgid "%<%s(%s)%> is only allowed in %<omp ordered%>"
+msgstr ""
+
+#: omp-low.cc:3673
+#, gcc-internal-format
+msgid "invalid depend kind in omp %<ordered%> %<depend%>"
+msgstr ""
+
+#: omp-low.cc:3690
+#, gcc-internal-format
+msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
+msgstr ""
+
+#: omp-low.cc:3706
+#, gcc-internal-format
+msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
+msgstr ""
+
+#: omp-low.cc:3719
+#, gcc-internal-format
+msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
+msgstr ""
+
+#: omp-low.cc:3732 omp-low.cc:3777
+#, gcc-internal-format
+msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
+msgstr ""
+
+#: omp-low.cc:3741
+#, gcc-internal-format
+msgid "%<ordered%> construct without %<doacross%> or %<depend%> clauses must not have the same binding region as %<ordered%> construct with those clauses"
+msgstr ""
+
+#: omp-low.cc:3760
+#, gcc-internal-format
+msgid "%<ordered%> construct without %<doacross%> or %<depend%> clauses binds to loop where %<collapse%> argument %wd is different from %<ordered%> argument %wd"
+msgstr ""
+
+#: omp-low.cc:3794
+#, gcc-internal-format
+msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
+msgstr ""
+
+#: omp-low.cc:3812
+#, gcc-internal-format
+msgid "%<teams%> construct must be closely nested inside of %<target%> construct or not nested in any OpenMP construct"
+msgstr ""
+
+#: omp-low.cc:3824 c-family/c-omp.cc:721
+#, gcc-internal-format
+msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
+msgstr ""
+
+#: omp-low.cc:3832
+#, gcc-internal-format
+msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
+msgstr ""
+
+#: omp-low.cc:3845
+#, gcc-internal-format
+msgid "OpenACC construct inside of non-OpenACC region"
+msgstr ""
+
+#: omp-low.cc:3906
+#, gcc-internal-format
+msgid "%s %qs construct inside of %s %qs region"
+msgstr ""
+
+#: omp-low.cc:3919 omp-low.cc:3936
+#, gcc-internal-format
+msgid "%qs construct inside of %qs region"
+msgstr ""
+
+#: omp-low.cc:4076
+#, gcc-internal-format
+msgid "setjmp/longjmp inside %<simd%> construct"
+msgstr ""
+
+#: omp-low.cc:4102
+#, gcc-internal-format
+msgid "OpenMP runtime API call %qD in a region with %<order(concurrent)%> clause"
+msgstr ""
+
+#: omp-low.cc:4118
+#, gcc-internal-format
+msgid "OpenMP runtime API call %qD strictly nested in a %<teams%> region"
+msgstr ""
+
+#: omp-low.cc:4130
+#, gcc-internal-format
+msgid "OpenMP runtime API call %qD in a region with %<device(ancestor)%> clause"
+msgstr ""
+
+#: omp-low.cc:9791
+#, gcc-internal-format
+msgid "ignoring %<sink%> clause with offset that is not a multiple of the loop step"
+msgstr ""
+
+#: omp-low.cc:9814
+#, gcc-internal-format
+msgid "first offset must be in opposite direction of loop iterations"
+msgstr ""
+
+#: omp-low.cc:14761
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid exit from %s structured block"
+msgstr ""
+
+#: omp-low.cc:14763 omp-low.cc:14768
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid entry to %s structured block"
+msgstr ""
+
+#. Otherwise, be vague and lazy, but efficient.
+#: omp-low.cc:14772
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid branch to/from %s structured block"
+msgstr ""
+
+#. ..., but due to bugs (PR100400), we may actually come here.
+#. Reliably catch this, regardless of checking level.
+#: omp-oacc-kernels-decompose.cc:248
+#, gcc-internal-format
+msgid "PR100400"
+msgstr ""
+
+#: omp-oacc-kernels-decompose.cc:261
+#, gcc-internal-format
+msgid "conditionally executed loop in %<kernels%> region will be executed by a single gang; ignoring %<gang%> clause"
+msgstr ""
+
+#. No need to recurse into nested statements; no loop nested inside
+#. this loop can be gang-partitioned.
+#: omp-oacc-kernels-decompose.cc:277
+#, gcc-internal-format
+msgid "%<gang%> loop in %<gang-single%> region"
+msgstr ""
+
+#: omp-oacc-kernels-decompose.cc:487
+#, gcc-internal-format
+msgid "cannot honor conflicting %qs clause"
+msgstr ""
+
+#: omp-oacc-kernels-decompose.cc:490
+#, gcc-internal-format
+msgid "location of the previous clause in the same loop nest"
+msgstr ""
+
+#: omp-oacc-kernels-decompose.cc:569
+#, gcc-internal-format
+msgid "argument not permitted on %qs clause in OpenACC %<kernels%> region with a %qs clause"
+msgstr ""
+
+#: omp-oacc-kernels-decompose.cc:573
+#, gcc-internal-format
+msgid "location of OpenACC %<kernels%>"
+msgstr ""
+
+#: omp-oacc-kernels-decompose.cc:1295
+#, gcc-internal-format
+msgid "%qs not yet supported"
+msgstr ""
+
+#: omp-oacc-neuter-broadcast.cc:1764
+#, gcc-internal-format
+msgid "shared-memory region overflow"
+msgstr ""
+
+#: omp-offload.cc:316
+#, gcc-internal-format
+msgid "%qD specified both in declare target %<link%> and implicitly in %<to%> clauses"
+msgstr ""
+
+#: omp-offload.cc:929
+#, gcc-internal-format
+msgid "%<-fopenacc-dim%> operand is malformed at %qs"
+msgstr ""
+
+#: omp-offload.cc:981
+#, gcc-internal-format, gfc-internal-format
+msgid "region contains %s partitioned code but is not %s partitioned"
+msgstr ""
+
+#: omp-offload.cc:987
+#, gcc-internal-format, gfc-internal-format
+msgid "region is %s partitioned but does not contain %s partitioned code"
+msgstr ""
+
+#: omp-offload.cc:1477
+#, gcc-internal-format
+msgid "gang reduction on an orphan loop"
+msgstr ""
+
+#: omp-offload.cc:1551
+#, gcc-internal-format
+msgid "routine call uses same OpenACC parallelism as containing loop"
+msgstr ""
+
+#: omp-offload.cc:1555 omp-offload.cc:1587
+#, gcc-internal-format
+msgid "containing loop here"
+msgstr ""
+
+#: omp-offload.cc:1560
+#, gcc-internal-format
+msgid "routine call uses OpenACC parallelism disallowed by containing routine"
+msgstr ""
+
+#: omp-offload.cc:1562
+#, gcc-internal-format
+msgid "loop uses OpenACC parallelism disallowed by containing routine"
+msgstr ""
+
+#: omp-offload.cc:1567
+#, gcc-internal-format
+msgid "routine %qD declared here"
+msgstr ""
+
+#: omp-offload.cc:1580
+#, gcc-internal-format
+msgid "incorrectly nested OpenACC loop parallelism"
+msgstr ""
+
+#: omp-offload.cc:1721
+#, gcc-internal-format
+msgid "insufficient partitioning available to parallelize element loop"
+msgstr ""
+
+#: omp-offload.cc:1729
+#, gcc-internal-format
+msgid "insufficient partitioning available to parallelize tile loop"
+msgstr ""
+
+#: omp-offload.cc:1731
+#, gcc-internal-format
+msgid "insufficient partitioning available to parallelize loop"
+msgstr ""
+
+#: omp-simd-clone.cc:391
+#, gcc-internal-format
+msgid "ignoring large linear step"
+msgstr ""
+
+#: omp-simd-clone.cc:397
+#, gcc-internal-format
+msgid "ignoring zero linear step"
+msgstr ""
+
+#: omp-simd-clone.cc:459
+#, gcc-internal-format
+msgid "ignoring %<#pragma omp declare simd%> on function with %<_Atomic%> qualified return type"
+msgstr ""
+
+#: omp-simd-clone.cc:469
+#, gcc-internal-format
+msgid "ignoring %<#pragma omp declare simd%> on function with %<_Atomic%> qualified non-%<uniform%> argument"
+msgstr ""
+
+#: optabs.cc:5020
+#, gcc-internal-format
+msgid "indirect jumps are not available on this target"
+msgstr ""
+
+#: optinfo-emit-json.cc:113
+#, gcc-internal-format
+msgid "cannot open file %qs for writing optimization records"
+msgstr ""
+
+#: optinfo-emit-json.cc:121
+#, gcc-internal-format
+msgid "error writing optimization records to %qs: %s"
+msgstr ""
+
+#: optinfo-emit-json.cc:130
+#, gcc-internal-format
+msgid "error closing optimization records %qs"
+msgstr ""
+
+#: opts-common.cc:1447
+#, gcc-internal-format
+msgid "command-line option %qs is not supported by this configuration"
+msgstr ""
+
+#: opts-common.cc:1457 opts.cc:2576
+#, gcc-internal-format
+msgid "missing argument to %qs"
+msgstr ""
+
+#: opts-common.cc:1464
+#, gcc-internal-format
+msgid "argument to %qs should be a non-negative integer optionally followed by a size unit"
+msgstr ""
+
+#: opts-common.cc:1468
+#, gcc-internal-format
+msgid "argument to %qs should be a non-negative integer"
+msgstr ""
+
+#: opts-common.cc:1475
+#, gcc-internal-format
+msgid "argument to %qs is not between %d and %d"
+msgstr ""
+
+#: opts-common.cc:1539
+#, gcc-internal-format
+msgid "invalid argument in option %qs"
+msgstr ""
+
+#: opts-common.cc:1541
+#, gcc-internal-format
+msgid "%qs specified multiple times in the same option"
+msgstr ""
+
+#: opts-common.cc:1544
+#, gcc-internal-format
+msgid "%qs is mutually exclusive with %qs and cannot be specified together"
+msgstr ""
+
+#: opts-common.cc:1566
+#, gcc-internal-format
+msgid "unrecognized argument in option %qs"
+msgstr ""
+
+#: opts-common.cc:1577 config/i386/i386-options.cc:1703
+#, gcc-internal-format
+msgid "valid arguments to %qs are: %s; did you mean %qs?"
+msgstr ""
+
+#: opts-common.cc:1580 config/i386/i386-options.cc:1706
+#, gcc-internal-format
+msgid "valid arguments to %qs are: %s"
+msgstr ""
+
+#: opts-common.cc:1623 c-family/c-opts.cc:471
+#, gcc-internal-format
+msgid "switch %qs is no longer supported"
+msgstr ""
+
+#: opts-common.cc:1683
+#, gcc-internal-format
+msgid "argument to %qs is bigger than %d"
+msgstr ""
+
+#: opts-common.cc:2030
+#, gcc-internal-format
+msgid "malformed %<COLLECT_GCC_OPTIONS%>"
+msgstr ""
+
+#: opts-global.cc:107
+#, gcc-internal-format
+msgid "command-line option %qs is valid for the driver but not for %s"
+msgstr ""
+
+#. Eventually this should become a hard error IMO.
+#: opts-global.cc:113
+#, gcc-internal-format
+msgid "command-line option %qs is valid for %s but not for %s"
+msgstr ""
+
+#. Happens for -Werror=warning_name.
+#: opts-global.cc:117
+#, gcc-internal-format
+msgid "%<-Werror=%> argument %qs is not valid for %s"
+msgstr ""
+
+#: opts-global.cc:149
+#, gcc-internal-format
+msgid "unrecognized command-line option %qs may have been intended to silence earlier diagnostics"
+msgstr ""
+
+#: opts-global.cc:409
+#, gcc-internal-format
+msgid "unrecognized command-line option %<-fopt-info-%s%>"
+msgstr ""
+
+#: opts-global.cc:430 opts-global.cc:439 m2/gm2spec.cc:544
+#, gcc-internal-format
+msgid "plugin support is disabled; configure with %<--enable-plugin%>"
+msgstr ""
+
+#: opts-global.cc:464
+#, gcc-internal-format
+msgid "unrecognized register name %qs"
+msgstr ""
+
+#: opts-global.cc:482
+#, gcc-internal-format
+msgid "%<-fasan-shadow-offset%> should only be used with %<-fsanitize=kernel-address%>"
+msgstr ""
+
+#: opts-global.cc:485
+#, gcc-internal-format
+msgid "unrecognized shadow offset %qs"
+msgstr ""
+
+#: opts.cc:234
+#, gcc-internal-format
+msgid "argument %qs to %<-femit-struct-debug-detailed%> not recognized"
+msgstr ""
+
+#: opts.cc:270
+#, gcc-internal-format
+msgid "argument %qs to %<-femit-struct-debug-detailed%> unknown"
+msgstr ""
+
+#: opts.cc:277
+#, gcc-internal-format
+msgid "%<-femit-struct-debug-detailed=dir:...%> must allow at least as much as %<-femit-struct-debug-detailed=ind:...%>"
+msgstr ""
+
+#: opts.cc:743
+#, gcc-internal-format
+msgid "argument to %<-O%> should be a non-negative integer, %<g%>, %<s%>, %<z%> or %<fast%>"
+msgstr ""
+
+#: opts.cc:849 opts.cc:855 opts.cc:861 opts.cc:867 opts.cc:878 opts.cc:888
+#: opts.cc:894 opts.cc:900 opts.cc:906 opts.cc:912 opts.cc:918 opts.cc:924
+#: opts.cc:930 opts.cc:936 opts.cc:953 opts.cc:961 config/mips/mips.cc:20420
+#: config/mips/mips.cc:20422 config/mips/mips.cc:20435
+#, gcc-internal-format
+msgid "%qs is incompatible with %qs"
+msgstr ""
+
+#: opts.cc:943
+#, gcc-internal-format
+msgid "%<-fipa-modref%> is incompatible with %qs"
+msgstr ""
+
+#: opts.cc:1023
+#, gcc-internal-format
+msgid "%<-fsanitize=%s%> is incompatible with %<-fsanitize=%s%>"
+msgstr ""
+
+#: opts.cc:1061
+#, gcc-internal-format
+msgid "section anchors must be disabled when unit-at-a-time is disabled"
+msgstr ""
+
+#: opts.cc:1065
+#, gcc-internal-format
+msgid "toplevel reorder must be disabled when unit-at-a-time is disabled"
+msgstr ""
+
+#: opts.cc:1079
+#, gcc-internal-format
+msgid "transactional memory is not supported with non-call exceptions"
+msgstr ""
+
+#: opts.cc:1094
+#, gcc-internal-format
+msgid "section anchors must be disabled when toplevel reorder is disabled"
+msgstr ""
+
+#: opts.cc:1105
+#, gcc-internal-format
+msgid "%<-ftrivial-auto-var-init=zero%> is not enabled by %<-fhardened%> because it was specified on the command line"
+msgstr ""
+
+#: opts.cc:1155
+#, gcc-internal-format
+msgid "%<-fstack-protector-strong%> is not enabled by %<-fhardened%> because it was specified on the command line"
+msgstr ""
+
+#: opts.cc:1200
+#, gcc-internal-format
+msgid "%<-fno-fat-lto-objects%> are supported only with linker plugin"
+msgstr ""
+
+#: opts.cc:1208
+#, gcc-internal-format
+msgid "%<-gsplit-dwarf%> is not supported with LTO, disabling"
+msgstr ""
+
+#: opts.cc:1222
+#, gcc-internal-format
+msgid "%<-fsplit-stack%> is not supported by this compiler configuration"
+msgstr ""
+
+#: opts.cc:1249
+#, gcc-internal-format
+msgid "%<-fsanitize=pointer-compare%> must be combined with %<-fsanitize=address%> or %<-fsanitize=kernel-address%>"
+msgstr ""
+
+#: opts.cc:1253
+#, gcc-internal-format
+msgid "%<-fsanitize=pointer-subtract%> must be combined with %<-fsanitize=address%> or %<-fsanitize=kernel-address%>"
+msgstr ""
+
+#: opts.cc:1280
+#, gcc-internal-format
+msgid "%<-fsanitize-recover=%s%> is not supported"
+msgstr ""
+
+#: opts.cc:1292 opts.cc:2288
+#, gcc-internal-format
+msgid "%<-fsanitize-trap=%s%> is not supported"
+msgstr ""
+
+#: opts.cc:1319
+#, gcc-internal-format
+msgid "%<-fsanitize-address-use-after-scope%> requires %<-fstack-reuse=none%> option"
+msgstr ""
+
+#: opts.cc:1326
+#, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr ""
+
+#: opts.cc:1329
+#, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr ""
+
+#: opts.cc:1334
+#, gcc-internal-format
+msgid "live patching (with %qs) is not supported with LTO"
+msgstr ""
+
+#: opts.cc:1339
+#, gcc-internal-format
+msgid "vtable verification is not supported with LTO"
+msgstr ""
+
+#: opts.cc:1414
+#, gcc-internal-format
+msgid "variable tracking requested, but useless unless producing debug info"
+msgstr ""
+
+#: opts.cc:1418
+#, gcc-internal-format
+msgid "variable tracking requested, but not supported by this debug format"
+msgstr ""
+
+#: opts.cc:1447
+#, gcc-internal-format
+msgid "var-tracking-assignments changes selective scheduling"
+msgstr ""
+
+#: opts.cc:1460
+#, gcc-internal-format
+msgid "%<-Wstrict-flex-arrays%> is ignored when %<-fstrict-flex-arrays%> is not present"
+msgstr ""
+
+#: opts.cc:1490 config/darwin.cc:3484
+#, gcc-internal-format
+msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
+msgstr ""
+
+#: opts.cc:1506
+#, gcc-internal-format
+msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
+msgstr ""
+
+#: opts.cc:1524 config/pa/pa.cc:576
+#, gcc-internal-format
+msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
+msgstr ""
+
+#: opts.cc:2033
+#, gcc-internal-format
+msgid "unrecognized %<include_flags 0x%x%> passed to %<print_specific_help%>"
+msgstr ""
+
+#: opts.cc:2267
+#, gcc-internal-format
+msgid "%<-fsanitize=all%> option is not valid"
+msgstr ""
+
+#: opts.cc:2322
+#, gcc-internal-format
+msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s; did you mean %qs?"
+msgstr ""
+
+#: opts.cc:2328
+#, gcc-internal-format
+msgid "unrecognized argument to %<-f%ssanitize%s=%> option: %q.*s"
+msgstr ""
+
+#: opts.cc:2363
+#, gcc-internal-format
+msgid "%qs attribute directive ignored"
+msgstr ""
+
+#: opts.cc:2387
+#, gcc-internal-format
+msgid "unrecognized argument to %<-fzero-call-used-regs=%>: %qs"
+msgstr ""
+
+#: opts.cc:2411
+#, gcc-internal-format
+msgid "invalid arguments for %<-falign-%s%> option: %qs"
+msgstr ""
+
+#: opts.cc:2426
+#, gcc-internal-format
+msgid "invalid number of arguments for %<-falign-%s%> option: %qs"
+msgstr ""
+
+#: opts.cc:2435
+#, gcc-internal-format
+msgid "%<-falign-%s%> is not between 0 and %d"
+msgstr ""
+
+#: opts.cc:2494
+#, gcc-internal-format
+msgid "invalid arguments for %<-fpatchable-function-entry%>"
+msgstr ""
+
+#: opts.cc:2631
+#, gcc-internal-format
+msgid "%<--help%> argument %q.*s is ambiguous, please be more specific"
+msgstr ""
+
+#: opts.cc:2642
+#, gcc-internal-format
+msgid "unrecognized argument to %<--help=%> option: %q.*s"
+msgstr ""
+
+#: opts.cc:2822
+#, gcc-internal-format
+msgid "arguments ignored for %<-Wattributes=%>; use %<-Wno-attributes=%> instead"
+msgstr ""
+
+#: opts.cc:2828
+#, gcc-internal-format
+msgid "trailing %<,%> in arguments for %<-Wno-attributes=%>"
+msgstr ""
+
+#: opts.cc:3054
+#, gcc-internal-format
+msgid "%<-foffload-abi%> option can be specified only for offload compiler"
+msgstr ""
+
+#: opts.cc:3062
+#, gcc-internal-format
+msgid "structure alignment must be a small power of two, not %wu"
+msgstr ""
+
+#: opts.cc:3183
+#, gcc-internal-format
+msgid "unknown stack check parameter %qs"
+msgstr ""
+
+#: opts.cc:3232
+#, gcc-internal-format
+msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf%> %<-g%s%> for debug level"
+msgstr ""
+
+#: opts.cc:3243
+#, gcc-internal-format
+msgid "dwarf version %wu is not supported"
+msgstr ""
+
+#: opts.cc:3280
+#, gcc-internal-format
+msgid "unrecognized argument to %<-flto=%> option: %qs"
+msgstr ""
+
+#: opts.cc:3480
+#, gcc-internal-format
+msgid "target system does not support debug output"
+msgstr ""
+
+#: opts.cc:3518
+#, gcc-internal-format
+msgid "debug format %qs conflicts with prior selection"
+msgstr ""
+
+#: opts.cc:3542
+#, gcc-internal-format
+msgid "unrecognized debug output level %qs"
+msgstr ""
+
+#: opts.cc:3544
+#, gcc-internal-format
+msgid "debug output level %qs is too high"
+msgstr ""
+
+#: opts.cc:3556
+#, gcc-internal-format
+msgid "unrecognized btf debug output level %qs"
+msgstr ""
+
+#: opts.cc:3573
+#, gcc-internal-format
+msgid "getting core file size maximum limit: %m"
+msgstr ""
+
+#: opts.cc:3577
+#, gcc-internal-format
+msgid "setting core file size limit to maximum: %m"
+msgstr ""
+
+#: opts.cc:3622
+#, gcc-internal-format, gfc-internal-format
+msgid "unrecognized gcc debugging option: %c"
+msgstr ""
+
+#: opts.cc:3651
+#, gcc-internal-format
+msgid "%<-W%serror=%s%>: no option %<-%s%>; did you mean %<-%s%>?"
+msgstr ""
+
+#: opts.cc:3655
+#, gcc-internal-format
+msgid "%<-W%serror=%s%>: no option %<-%s%>"
+msgstr ""
+
+#: opts.cc:3659
+#, gcc-internal-format
+msgid "%<-Werror=%s%>: %<-%s%> is not an option that controls warnings"
+msgstr ""
+
+#: passes.cc:84
+#, gcc-internal-format, gfc-internal-format
+msgid "pass %s does not support cloning"
+msgstr ""
+
+#: passes.cc:90
+#, gcc-internal-format
+msgid "pass %s needs a %<set_pass_param%> implementation to handle the extra argument in %<NEXT_PASS%>"
+msgstr ""
+
+#: passes.cc:1073
+#, gcc-internal-format
+msgid "unrecognized option %<-fenable%>"
+msgstr ""
+
+#: passes.cc:1075
+#, gcc-internal-format
+msgid "unrecognized option %<-fdisable%>"
+msgstr ""
+
+#: passes.cc:1083
+#, gcc-internal-format
+msgid "unknown pass %s specified in %<-fenable%>"
+msgstr ""
+
+#: passes.cc:1085
+#, gcc-internal-format
+msgid "unknown pass %s specified in %<-fdisable%>"
+msgstr ""
+
+#: passes.cc:1110 passes.cc:1199
+#, gcc-internal-format, gfc-internal-format
+msgid "enable pass %s for functions in the range of [%u, %u]"
+msgstr ""
+
+#: passes.cc:1113 passes.cc:1210
+#, gcc-internal-format, gfc-internal-format
+msgid "disable pass %s for functions in the range of [%u, %u]"
+msgstr ""
+
+#: passes.cc:1149 passes.cc:1177
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid range %s in option %s"
+msgstr ""
+
+#: passes.cc:1195
+#, gcc-internal-format, gfc-internal-format
+msgid "enable pass %s for function %s"
+msgstr ""
+
+#: passes.cc:1206
+#, gcc-internal-format, gfc-internal-format
+msgid "disable pass %s for function %s"
+msgstr ""
+
+#: passes.cc:1435
+#, gcc-internal-format
+msgid "invalid pass positioning operation"
+msgstr ""
+
+#: passes.cc:1496
+#, gcc-internal-format
+msgid "plugin cannot register a missing pass"
+msgstr ""
+
+#: passes.cc:1499
+#, gcc-internal-format
+msgid "plugin cannot register an unnamed pass"
+msgstr ""
+
+#: passes.cc:1504
+#, gcc-internal-format
+msgid "plugin cannot register pass %qs without reference pass name"
+msgstr ""
+
+#: passes.cc:1523
+#, gcc-internal-format
+msgid "pass %qs not found but is referenced by new pass %qs"
+msgstr ""
+
+#: plugin.cc:213
+#, gcc-internal-format
+msgid "inaccessible plugin file %s expanded from short plugin name %s: %m"
+msgstr ""
+
+#: plugin.cc:235
+#, gcc-internal-format
+msgid "plugin %qs was specified with different paths: %qs and %qs"
+msgstr ""
+
+#: plugin.cc:294
+#, gcc-internal-format
+msgid "malformed option %<-fplugin-arg-%s%>: missing %<-<key>[=<value>]%>"
+msgstr ""
+
+#: plugin.cc:358
+#, gcc-internal-format
+msgid "plugin %s should be specified before %<-fplugin-arg-%s%> in the command line"
+msgstr ""
+
+#: plugin.cc:377
+#, gcc-internal-format
+msgid "unable to register info for plugin %qs - plugin name not found"
+msgstr ""
+
+#: plugin.cc:473
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown callback event registered by plugin %s"
+msgstr ""
+
+#: plugin.cc:506
+#, gcc-internal-format, gfc-internal-format
+msgid "plugin %s registered a null callback function for event %s"
+msgstr ""
+
+#: plugin.cc:640
+#, gcc-internal-format, gfc-internal-format
+msgid ""
+"cannot load plugin %s\n"
+"%s"
+msgstr ""
+
+#: plugin.cc:651
+#, gcc-internal-format, gfc-internal-format
+msgid ""
+"plugin %s is not licensed under a GPL-compatible license\n"
+"%s"
+msgstr ""
+
+#: plugin.cc:664
+#, gcc-internal-format, gfc-internal-format
+msgid ""
+"cannot find %s in plugin %s\n"
+"%s"
+msgstr ""
+
+#: plugin.cc:674
+#, gcc-internal-format, gfc-internal-format
+msgid "fail to initialize plugin %s"
+msgstr ""
+
+#: plugin.cc:707
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot load plugin %s: %s"
+msgstr ""
+
+#: plugin.cc:717
+#, gcc-internal-format, gfc-internal-format
+msgid "plugin %s is not licensed under a GPL-compatible license %s"
+msgstr ""
+
+#: plugin.cc:727
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot find %s in plugin %s: %s"
+msgstr ""
+
+#: plugin.cc:736
+#, gcc-internal-format, gfc-internal-format
+msgid "failed to initialize plugin %s"
+msgstr ""
+
+#: plugin.cc:1048
+#, gcc-internal-format
+msgid "%<-iplugindir%> option not passed from the gcc driver"
+msgstr ""
+
+#: pointer-query.cc:1201
+#, gcc-internal-format
+msgid "destination object is likely at address zero"
+msgstr ""
+
+#: pointer-query.cc:1203
+#, gcc-internal-format
+msgid "source object is likely at address zero"
+msgstr ""
+
+#: pointer-query.cc:1213
+#, gcc-internal-format
+msgid "at offset %s into destination object %qE of size %s"
+msgstr ""
+
+#: pointer-query.cc:1216
+#, gcc-internal-format
+msgid "destination object %qE of size %s"
+msgstr ""
+
+#: pointer-query.cc:1222
+#, gcc-internal-format
+msgid "at offset %s into destination object of size %s allocated by %qE"
+msgstr ""
+
+#: pointer-query.cc:1225
+#, gcc-internal-format
+msgid "destination object of size %s allocated by %qE"
+msgstr ""
+
+#: pointer-query.cc:1235
+#, gcc-internal-format
+msgid "at offset %s into source object %qE of size %s"
+msgstr ""
+
+#: pointer-query.cc:1238
+#, gcc-internal-format
+msgid "source object %qE of size %s"
+msgstr ""
+
+#: pointer-query.cc:1245
+#, gcc-internal-format
+msgid "at offset %s into source object of size %s allocated by %qE"
+msgstr ""
+
+#: pointer-query.cc:1248
+#, gcc-internal-format
+msgid "source object of size %s allocated by %qE"
+msgstr ""
+
+#: pointer-query.cc:1256
+#, gcc-internal-format
+msgid "at offset %s into object %qE of size %s"
+msgstr ""
+
+#: pointer-query.cc:1259
+#, gcc-internal-format
+msgid "object %qE of size %s"
+msgstr ""
+
+#: pointer-query.cc:1266
+#, gcc-internal-format
+msgid "at offset %s into object of size %s allocated by %qE"
+msgstr ""
+
+#: pointer-query.cc:1269
+#, gcc-internal-format
+msgid "object of size %s allocated by %qE"
+msgstr ""
+
+#: predict.cc:2566
+#, gcc-internal-format
+msgid "probability %qE must be constant floating-point expression"
+msgstr ""
+
+#: predict.cc:2579
+#, gcc-internal-format
+msgid "probability %qE is outside the range [0.0, 1.0]"
+msgstr ""
+
+#: predict.cc:3640
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing counts for called function %s"
+msgstr ""
+
+#: profile.cc:628
+#, gcc-internal-format
+msgid "corrupted profile info: profile data is not flow-consistent"
+msgstr ""
+
+#: profile.cc:645
+#, gcc-internal-format, gfc-internal-format
+msgid "corrupted profile info: number of iterations for basic block %d thought to be %i"
+msgstr ""
+
+#: profile.cc:668
+#, gcc-internal-format, gfc-internal-format
+msgid "corrupted profile info: number of executions for edge %d-%d thought to be %i"
+msgstr ""
+
+#: profile.cc:977
+#, gcc-internal-format
+msgid "corrupted profile info: invalid time profile"
+msgstr ""
+
+#: read-rtl-function.cc:265
+#, gcc-internal-format, gfc-internal-format
+msgid "insn with UID %i not found for operand %i (`%s') of insn %i"
+msgstr ""
+
+#: read-rtl-function.cc:269
+#, gcc-internal-format, gfc-internal-format
+msgid "insn with UID %i not found for operand %i of insn %i"
+msgstr ""
+
+#: read-rtl-function.cc:412
+#, gcc-internal-format
+msgid "%<__RTL%> function cannot be compiled with %<-flto%>"
+msgstr ""
+
+#: read-rtl-function.cc:714
+#, gcc-internal-format
+msgid "unrecognized edge flag: %qs"
+msgstr ""
+
+#: read-rtl-function.cc:857
+#, gcc-internal-format
+msgid "more than one 'crtl' directive"
+msgstr ""
+
+#: read-rtl-function.cc:986
+#, gcc-internal-format
+msgid "unrecognized enum value: %qs"
+msgstr ""
+
+#: read-rtl-function.cc:1142 read-rtl-function.cc:1201
+#, gcc-internal-format, gfc-internal-format
+msgid "was expecting `%s'"
+msgstr ""
+
+#: read-rtl-function.cc:1595
+#, gcc-internal-format, gfc-internal-format
+msgid "duplicate insn UID: %i"
+msgstr ""
+
+#: read-rtl-function.cc:1656
+#, gcc-internal-format
+msgid "start/end of RTL fragment are in different files"
+msgstr ""
+
+#: read-rtl-function.cc:1662
+#, gcc-internal-format
+msgid "start of RTL fragment must be on an earlier line than end"
+msgstr ""
+
+#: read-rtl.cc:490 read-rtl.cc:521
+#, gcc-internal-format, gfc-internal-format
+msgid "ambiguous attribute '%s'; could be '%s' (via '%s:%s') or '%s' (via '%s:%s')"
+msgstr ""
+
+#: reg-stack.cc:545
+#, gcc-internal-format, gfc-internal-format
+msgid "output constraint %d must specify a single register"
+msgstr ""
+
+#: reg-stack.cc:555
+#, gcc-internal-format
+msgid "output constraint %d cannot be specified together with %qs clobber"
+msgstr ""
+
+#: reg-stack.cc:579
+#, gcc-internal-format
+msgid "output registers must be grouped at top of stack"
+msgstr ""
+
+#: reg-stack.cc:619
+#, gcc-internal-format
+msgid "implicitly popped registers must be grouped at top of stack"
+msgstr ""
+
+#: reg-stack.cc:637
+#, gcc-internal-format
+msgid "explicitly used registers must be grouped at top of stack"
+msgstr ""
+
+#: reg-stack.cc:657
+#, gcc-internal-format
+msgid "output operand %d must use %<&%> constraint"
+msgstr ""
+
+#: regcprop.cc:1254
+#, gcc-internal-format
+msgid "%qs: [%u] bad %<next_regno%> for empty chain (%u)"
+msgstr ""
+
+#: regcprop.cc:1266
+#, gcc-internal-format
+msgid "%qs: loop in %<next_regno%> chain (%u)"
+msgstr ""
+
+#: regcprop.cc:1269
+#, gcc-internal-format
+msgid "%qs: [%u] bad %<oldest_regno%> (%u)"
+msgstr ""
+
+#: regcprop.cc:1281
+#, gcc-internal-format
+msgid "%qs: [%u] non-empty register in chain (%s %u %i)"
+msgstr ""
+
+#: reginfo.cc:679
+#, gcc-internal-format
+msgid "cannot use %qs as a call-saved register"
+msgstr ""
+
+#: reginfo.cc:683
+#, gcc-internal-format
+msgid "cannot use %qs as a call-used register"
+msgstr ""
+
+#: reginfo.cc:695
+#, gcc-internal-format
+msgid "cannot use %qs as a fixed register"
+msgstr ""
+
+#: reginfo.cc:722 config/arc/arc.cc:1086 config/arc/arc.cc:1128
+#: config/ia64/ia64.cc:6047 config/ia64/ia64.cc:6054 config/pa/pa.cc:473
+#: config/pa/pa.cc:480 config/sh/sh.cc:8278 config/sh/sh.cc:8285
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown register name: %s"
+msgstr ""
+
+#: reginfo.cc:735
+#, gcc-internal-format
+msgid "stack register used for global register variable"
+msgstr ""
+
+#: reginfo.cc:741
+#, gcc-internal-format
+msgid "global register variable follows a function definition"
+msgstr ""
+
+#: reginfo.cc:747
+#, gcc-internal-format
+msgid "register of %qD used for multiple global register variables"
+msgstr ""
+
+#: reginfo.cc:750 config/rs6000/rs6000-logue.cc:5567
+#, gcc-internal-format
+msgid "conflicts with %qD"
+msgstr ""
+
+#: reginfo.cc:755
+#, gcc-internal-format
+msgid "call-clobbered register used for global register variable"
+msgstr ""
+
+#: reload.cc:1312
+#, gcc-internal-format
+msgid "cannot reload integer constant operand in %<asm%>"
+msgstr ""
+
+#: reload.cc:1326
+#, gcc-internal-format
+msgid "impossible register constraint in %<asm%>"
+msgstr ""
+
+#: reload.cc:2672
+#, gcc-internal-format
+msgid "the target does not support %<asm goto%> with outputs in %<asm%>"
+msgstr ""
+
+#: reload.cc:3697
+#, gcc-internal-format
+msgid "%<&%> constraint used with no register class"
+msgstr ""
+
+#: reload1.cc:1242
+#, gcc-internal-format
+msgid "%<asm%> operand has impossible constraints"
+msgstr ""
+
+#: reload1.cc:2060
+#, gcc-internal-format
+msgid "cannot find a register in class %qs while reloading %<asm%>"
+msgstr ""
+
+#: reload1.cc:2065
+#, gcc-internal-format
+msgid "unable to find a register to spill in class %qs"
+msgstr ""
+
+#: reload1.cc:4582
+#, gcc-internal-format
+msgid "%<asm%> operand requires impossible reload"
+msgstr ""
+
+#: reload1.cc:5999
+#, gcc-internal-format
+msgid "%<asm%> operand constraint incompatible with operand size"
+msgstr ""
+
+#: reload1.cc:7877
+#, gcc-internal-format
+msgid "output operand is constant in %<asm%>"
+msgstr ""
+
+#: rtl.cc:741
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL check: access of elt %d of '%s' with last elt %d in %s, at %s:%d"
+msgstr ""
+
+#: rtl.cc:751
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL check: expected elt %d type '%c', have '%c' (rtx %s) in %s, at %s:%d"
+msgstr ""
+
+#: rtl.cc:761
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL check: expected elt %d type '%c' or '%c', have '%c' (rtx %s) in %s, at %s:%d"
+msgstr ""
+
+#: rtl.cc:770
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL check: expected code '%s', have '%s' in %s, at %s:%d"
+msgstr ""
+
+#: rtl.cc:780
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL check: expected code '%s' or '%s', have '%s' in %s, at %s:%d"
+msgstr ""
+
+#: rtl.cc:791
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL check: expected code '%s', '%s' or '%s', have '%s' in %s, at %s:%d"
+msgstr ""
+
+#: rtl.cc:822
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL check: attempt to treat non-block symbol as a block symbol in %s, at %s:%d"
+msgstr ""
+
+#: rtl.cc:832
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
+msgstr ""
+
+#: rtl.cc:842
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
+msgstr ""
+
+#: rtl.cc:853
+#, gcc-internal-format, gfc-internal-format
+msgid "RTL flag check: %s used with unexpected rtx code '%s' in %s, at %s:%d"
+msgstr ""
+
+#: stmt.cc:215
+#, gcc-internal-format
+msgid "output operand constraint lacks %<=%>"
+msgstr ""
+
+#: stmt.cc:230
+#, gcc-internal-format
+msgid "output constraint %qc for operand %d is not at the beginning"
+msgstr ""
+
+#: stmt.cc:254
+#, gcc-internal-format
+msgid "operand constraint contains incorrectly positioned %<+%> or %<=%>"
+msgstr ""
+
+#: stmt.cc:261 stmt.cc:350
+#, gcc-internal-format
+msgid "%<%%%> constraint used with last operand"
+msgstr ""
+
+#: stmt.cc:277
+#, gcc-internal-format
+msgid "matching constraint not valid in output operand"
+msgstr ""
+
+#: stmt.cc:341
+#, gcc-internal-format
+msgid "input operand constraint contains %qc"
+msgstr ""
+
+#: stmt.cc:380
+#, gcc-internal-format
+msgid "matching constraint references invalid operand number"
+msgstr ""
+
+#: stmt.cc:414
+#, gcc-internal-format
+msgid "invalid punctuation %qc in constraint"
+msgstr ""
+
+#: stmt.cc:431
+#, gcc-internal-format
+msgid "matching constraint does not allow a register"
+msgstr ""
+
+#: stmt.cc:525
+#, gcc-internal-format
+msgid "duplicate %<asm%> operand name %qs"
+msgstr ""
+
+#: stmt.cc:622
+#, gcc-internal-format
+msgid "missing close brace for named operand"
+msgstr ""
+
+#: stmt.cc:651
+#, gcc-internal-format
+msgid "undefined named operand %qs"
+msgstr ""
+
+#: stor-layout.cc:830
+#, gcc-internal-format
+msgid "size of %q+D %E bytes exceeds maximum object size %wu"
+msgstr ""
+
+#: stor-layout.cc:1211
+#, gcc-internal-format
+msgid "alignment %u of %qT is less than %u"
+msgstr ""
+
+#: stor-layout.cc:1218
+#, gcc-internal-format
+msgid "%q+D offset %E in %qT isn%'t aligned to %u"
+msgstr ""
+
+#: stor-layout.cc:1221
+#, gcc-internal-format
+msgid "%q+D offset %E in %qT may not be aligned to %u"
+msgstr ""
+
+#: stor-layout.cc:1353
+#, gcc-internal-format
+msgid "packed attribute causes inefficient alignment for %q+D"
+msgstr ""
+
+#: stor-layout.cc:1357
+#, gcc-internal-format
+msgid "packed attribute is unnecessary for %q+D"
+msgstr ""
+
+#: stor-layout.cc:1377
+#, gcc-internal-format
+msgid "padding struct to align %q+D"
+msgstr ""
+
+#: stor-layout.cc:1436
+#, gcc-internal-format
+msgid "offset of packed bit-field %qD has changed in GCC 4.4"
+msgstr ""
+
+#: stor-layout.cc:1816
+#, gcc-internal-format
+msgid "padding struct size to alignment boundary with %E bytes"
+msgstr ""
+
+#: stor-layout.cc:1845
+#, gcc-internal-format
+msgid "packed attribute causes inefficient alignment for %qE"
+msgstr ""
+
+#: stor-layout.cc:1849
+#, gcc-internal-format
+msgid "packed attribute is unnecessary for %qE"
+msgstr ""
+
+#: stor-layout.cc:1855
+#, gcc-internal-format
+msgid "packed attribute causes inefficient alignment"
+msgstr ""
+
+#: stor-layout.cc:1857
+#, gcc-internal-format
+msgid "packed attribute is unnecessary"
+msgstr ""
+
+#: stor-layout.cc:2738
+#, gcc-internal-format
+msgid "alignment of array elements is greater than element size"
+msgstr ""
+
+#: stor-layout.cc:2744
+#, gcc-internal-format
+msgid "size of array element is not a multiple of its alignment"
+msgstr ""
+
+#: substring-locations.cc:229
+#, gcc-internal-format
+msgid "format string is defined here"
+msgstr ""
+
+#: symtab-thunks.cc:400
+#, gcc-internal-format
+msgid "generic thunk code fails for method %qD which uses %<...%>"
+msgstr ""
+
+#: symtab.cc:303
+#, gcc-internal-format
+msgid "%qD renamed after being referenced in assembly"
+msgstr ""
+
+#: symtab.cc:1109
+#, gcc-internal-format
+msgid "function symbol is not function"
+msgstr ""
+
+#: symtab.cc:1116
+#, gcc-internal-format
+msgid "inconsistent %<ifunc%> attribute"
+msgstr ""
+
+#: symtab.cc:1124
+#, gcc-internal-format
+msgid "variable symbol is not variable"
+msgstr ""
+
+#: symtab.cc:1130
+#, gcc-internal-format
+msgid "node has unknown type"
+msgstr ""
+
+#: symtab.cc:1135
+#, gcc-internal-format, gfc-internal-format
+msgid "node has invalid order %i"
+msgstr ""
+
+#: symtab.cc:1144
+#, gcc-internal-format
+msgid "node not found node->decl->decl_with_vis.symtab_node"
+msgstr ""
+
+#: symtab.cc:1152
+#, gcc-internal-format
+msgid "node differs from node->decl->decl_with_vis.symtab_node"
+msgstr ""
+
+#: symtab.cc:1163 symtab.cc:1170
+#, gcc-internal-format
+msgid "assembler name hash list corrupted"
+msgstr ""
+
+#: symtab.cc:1179
+#, gcc-internal-format
+msgid "node not found in symtab assembler name hash"
+msgstr ""
+
+#: symtab.cc:1188
+#, gcc-internal-format
+msgid "double linked list of assembler names corrupted"
+msgstr ""
+
+#: symtab.cc:1193
+#, gcc-internal-format
+msgid "node has body_removed but is definition"
+msgstr ""
+
+#: symtab.cc:1198
+#, gcc-internal-format
+msgid "node is analyzed but it is not a definition"
+msgstr ""
+
+#: symtab.cc:1203
+#, gcc-internal-format
+msgid "node is alias but not implicit alias"
+msgstr ""
+
+#: symtab.cc:1208
+#, gcc-internal-format
+msgid "node is alias but not definition"
+msgstr ""
+
+#: symtab.cc:1213
+#, gcc-internal-format
+msgid "node is weakref but not an transparent_alias"
+msgstr ""
+
+#: symtab.cc:1218
+#, gcc-internal-format
+msgid "node is transparent_alias but not an alias"
+msgstr ""
+
+#: symtab.cc:1223
+#, gcc-internal-format
+msgid "node is symver but not alias"
+msgstr ""
+
+#: symtab.cc:1232
+#, gcc-internal-format
+msgid "symver target is not exported with default visibility"
+msgstr ""
+
+#: symtab.cc:1239
+#, gcc-internal-format
+msgid "symver is not exported with default visibility"
+msgstr ""
+
+#: symtab.cc:1248
+#, gcc-internal-format
+msgid "node is in same_comdat_group list but has no comdat_group"
+msgstr ""
+
+#: symtab.cc:1253
+#, gcc-internal-format
+msgid "same_comdat_group list across different groups"
+msgstr ""
+
+#: symtab.cc:1258
+#, gcc-internal-format
+msgid "mixing different types of symbol in same comdat groups is not supported"
+msgstr ""
+
+#: symtab.cc:1263
+#, gcc-internal-format
+msgid "node is alone in a comdat group"
+msgstr ""
+
+#: symtab.cc:1270
+#, gcc-internal-format
+msgid "same_comdat_group is not a circular list"
+msgstr ""
+
+#: symtab.cc:1285
+#, gcc-internal-format, gfc-internal-format
+msgid "comdat-local symbol referred to by %s outside its comdat"
+msgstr ""
+
+#: symtab.cc:1295
+#, gcc-internal-format
+msgid "implicit_section flag is set but section isn%'t"
+msgstr ""
+
+#: symtab.cc:1302
+#, gcc-internal-format
+msgid "Both section and comdat group is set"
+msgstr ""
+
+#: symtab.cc:1314
+#, gcc-internal-format
+msgid "Alias and target%'s section differs"
+msgstr ""
+
+#: symtab.cc:1321
+#, gcc-internal-format
+msgid "Alias and target%'s comdat groups differs"
+msgstr ""
+
+#: symtab.cc:1336
+#, gcc-internal-format
+msgid "Transparent alias and target%'s assembler names differs"
+msgstr ""
+
+#: symtab.cc:1344
+#, gcc-internal-format
+msgid "Chained transparent aliases"
+msgstr ""
+
+#: symtab.cc:1367 symtab.cc:1477 symtab.cc:1504
+#, gcc-internal-format
+msgid "symtab_node::verify failed"
+msgstr ""
+
+#: symtab.cc:1476
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid order in asm node %i"
+msgstr ""
+
+#: symtab.cc:1500
+#, gcc-internal-format
+msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
+msgstr ""
+
+#: symtab.cc:1938
+#, gcc-internal-format
+msgid "function %q+D part of alias cycle"
+msgstr ""
+
+#: symtab.cc:1940
+#, gcc-internal-format
+msgid "variable %q+D part of alias cycle"
+msgstr ""
+
+#: symtab.cc:1968
+#, gcc-internal-format
+msgid "section of alias %q+D must match section of its target"
+msgstr ""
+
+#: targhooks.cc:204
+#, gcc-internal-format
+msgid "%<__builtin_saveregs%> not supported by this target"
+msgstr ""
+
+#: targhooks.cc:1223
+#, gcc-internal-format
+msgid "argument %qs is not supported for %qs on this target"
+msgstr ""
+
+#: targhooks.cc:1265
+#, gcc-internal-format
+msgid "nested functions not supported on this target"
+msgstr ""
+
+#: targhooks.cc:1278
+#, gcc-internal-format
+msgid "nested function trampolines not supported on this target"
+msgstr ""
+
+#: targhooks.cc:1441
+#, gcc-internal-format
+msgid "global constructors not supported on this target"
+msgstr ""
+
+#: targhooks.cc:1450
+#, gcc-internal-format
+msgid "global destructors not supported on this target"
+msgstr ""
+
+#: targhooks.cc:1810
+#, gcc-internal-format
+msgid "%<target%> attribute is not supported on this machine"
+msgstr ""
+
+#: targhooks.cc:1822
+#, gcc-internal-format
+msgid "%<target_version%> attribute is not supported on this machine"
+msgstr ""
+
+#: targhooks.cc:1836
+#, gcc-internal-format
+msgid "%<#pragma GCC target%> is not supported for this machine"
+msgstr ""
+
+#: toplev.cc:718
+#, gcc-internal-format
+msgid "cannot open %qs for writing: %m"
+msgstr ""
+
+#: toplev.cc:737
+#, gcc-internal-format
+msgid "%<-frecord-gcc-switches%> is not supported by the current target"
+msgstr ""
+
+#: toplev.cc:789
+#, gcc-internal-format
+msgid "stack usage computation not supported for this target"
+msgstr ""
+
+#: toplev.cc:848
+#, gcc-internal-format
+msgid "stack usage might be unbounded"
+msgstr ""
+
+#: toplev.cc:853
+#, gcc-internal-format
+msgid "stack usage might be %wu bytes"
+msgstr ""
+
+#: toplev.cc:856
+#, gcc-internal-format
+msgid "stack usage is %wu bytes"
+msgstr ""
+
+#: toplev.cc:973
+#, gcc-internal-format
+msgid "cannot open %s for writing: %m"
+msgstr ""
+
+#: toplev.cc:1252
+#, gcc-internal-format
+msgid "this target does not support %qs"
+msgstr ""
+
+#: toplev.cc:1286
+#, gcc-internal-format
+msgid "Graphite loop optimizations cannot be used (isl is not available) (%<-fgraphite%>, %<-fgraphite-identity%>, %<-floop-nest-optimize%>, %<-floop-parallelize-all%>)"
+msgstr ""
+
+#: toplev.cc:1297
+#, gcc-internal-format
+msgid "%<-fcf-protection=full%> is not supported for this target"
+msgstr ""
+
+#: toplev.cc:1304
+#, gcc-internal-format
+msgid "%<-fcf-protection=branch%> is not supported for this target"
+msgstr ""
+
+#: toplev.cc:1311
+#, gcc-internal-format
+msgid "%<-fcf-protection=return%> is not supported for this target"
+msgstr ""
+
+#: toplev.cc:1326
+#, gcc-internal-format
+msgid "%<-fabi-version=1%> is no longer supported"
+msgstr ""
+
+#: toplev.cc:1342
+#, gcc-internal-format
+msgid "instruction scheduling not supported on this target machine"
+msgstr ""
+
+#: toplev.cc:1346
+#, gcc-internal-format
+msgid "this target machine does not have delayed branches"
+msgstr ""
+
+#: toplev.cc:1360
+#, gcc-internal-format
+msgid "%<-f%sleading-underscore%> not supported on this target machine"
+msgstr ""
+
+#: toplev.cc:1389
+#, gcc-internal-format
+msgid "CTF debug info requested, but not supported for %qs frontend"
+msgstr ""
+
+#: toplev.cc:1407
+#, gcc-internal-format
+msgid "could not close zeroed insn dump file %qs: %m"
+msgstr ""
+
+#: toplev.cc:1445
+#, gcc-internal-format
+msgid "target system does not support the %qs debug format"
+msgstr ""
+
+#: toplev.cc:1473
+#, gcc-internal-format
+msgid "without %<-gdwarf-5%>, %<-gvariable-location-views=incompat5%> is equivalent to %<-gvariable-location-views%>"
+msgstr ""
+
+#: toplev.cc:1489
+#, gcc-internal-format
+msgid "%<-ginternal-reset-location-views%> is forced disabled without %<-gvariable-location-views%>"
+msgstr ""
+
+#: toplev.cc:1499
+#, gcc-internal-format
+msgid "%<-ginline-points%> is forced disabled without %<-gstatement-frontiers%>"
+msgstr ""
+
+#: toplev.cc:1528
+#, gcc-internal-format
+msgid "%<-ffunction-sections%> not supported for this target"
+msgstr ""
+
+#: toplev.cc:1534
+#, gcc-internal-format
+msgid "%<-fdata-sections%> not supported for this target"
+msgstr ""
+
+#: toplev.cc:1542
+#, gcc-internal-format
+msgid "%<-fprefetch-loop-arrays%> not supported for this target"
+msgstr ""
+
+#: toplev.cc:1548
+#, gcc-internal-format
+msgid "%<-fprefetch-loop-arrays%> not supported for this target (try %<-march%> switches)"
+msgstr ""
+
+#: toplev.cc:1558
+#, gcc-internal-format
+msgid "%<-fprefetch-loop-arrays%> is not supported with %<-Os%>"
+msgstr ""
+
+#: toplev.cc:1570
+#, gcc-internal-format
+msgid "%<-fassociative-math%> disabled; other options take precedence"
+msgstr ""
+
+#: toplev.cc:1578
+#, gcc-internal-format
+msgid "%<-fhardened%> not supported for this target"
+msgstr ""
+
+#: toplev.cc:1587
+#, gcc-internal-format
+msgid "%<-fstack-clash-protection%> is not supported on targets where the stack grows from lower to higher addresses"
+msgstr ""
+
+#: toplev.cc:1600
+#, gcc-internal-format
+msgid "%<-fstack-clash-protection%> is not enabled by %<-fhardened%> because %<-fstack-check%> was specified on the command line"
+msgstr ""
+
+#: toplev.cc:1610
+#, gcc-internal-format
+msgid "%<-fstack-check=%> and %<-fstack-clash-protection%> are mutually exclusive; disabling %<-fstack-check=%>"
+msgstr ""
+
+#: toplev.cc:1621
+#, gcc-internal-format
+msgid "%<-fstack-protector%> not supported for this target"
+msgstr ""
+
+#: toplev.cc:1633
+#, gcc-internal-format
+msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are not supported for this target"
+msgstr ""
+
+#: toplev.cc:1643
+#, gcc-internal-format
+msgid "%<-fsanitize=address%> not supported for this target"
+msgstr ""
+
+#: toplev.cc:1652
+#, gcc-internal-format
+msgid "%<-fsanitize=kernel-address%> with stack protection is not supported without %<-fasan-shadow-offset=%> for this target"
+msgstr ""
+
+#: toplev.cc:1662
+#, gcc-internal-format
+msgid "%qs is not supported for this target"
+msgstr ""
+
+#: toplev.cc:1670
+#, gcc-internal-format
+msgid "%<-fsanitize=shadow-call-stack%> not supported in current platform"
+msgstr ""
+
+#: toplev.cc:1673
+#, gcc-internal-format
+msgid "%<-fsanitize=shadow-call-stack%> requires %<-fno-exceptions%>"
+msgstr ""
+
+#: toplev.cc:2012
+#, gcc-internal-format
+msgid "error writing to %s: %m"
+msgstr ""
+
+#: toplev.cc:2014
+#, gcc-internal-format
+msgid "error closing %s: %m"
+msgstr ""
+
+#: toplev.cc:2132
+#, gcc-internal-format
+msgid "mpfr not configured to handle all floating modes"
+msgstr ""
+
+#: toplev.cc:2218
+#, gcc-internal-format
+msgid "self-tests are not enabled in this build"
+msgstr ""
+
+#: toplev.cc:2315
+#, gcc-internal-format
+msgid "self-tests incompatible with %<-E%>"
+msgstr ""
+
+#: trans-mem.cc:610
+#, gcc-internal-format
+msgid "invalid use of volatile lvalue inside transaction"
+msgstr ""
+
+#: trans-mem.cc:613
+#, gcc-internal-format
+msgid "invalid use of volatile lvalue inside %<transaction_safe%> function"
+msgstr ""
+
+#: trans-mem.cc:648
+#, gcc-internal-format
+msgid "%<transaction_may_cancel_outer%> function call not within outer transaction or %<transaction_may_cancel_outer%>"
+msgstr ""
+
+#: trans-mem.cc:717 trans-mem.cc:4834
+#, gcc-internal-format
+msgid "unsafe function call %qD within atomic transaction"
+msgstr ""
+
+#: trans-mem.cc:724
+#, gcc-internal-format
+msgid "unsafe function call %qE within atomic transaction"
+msgstr ""
+
+#: trans-mem.cc:728
+#, gcc-internal-format
+msgid "unsafe indirect function call within atomic transaction"
+msgstr ""
+
+#: trans-mem.cc:736 trans-mem.cc:4766
+#, gcc-internal-format
+msgid "unsafe function call %qD within %<transaction_safe%> function"
+msgstr ""
+
+#: trans-mem.cc:743
+#, gcc-internal-format
+msgid "unsafe function call %qE within %<transaction_safe%> function"
+msgstr ""
+
+#: trans-mem.cc:747
+#, gcc-internal-format
+msgid "unsafe indirect function call within %<transaction_safe%> function"
+msgstr ""
+
+#: trans-mem.cc:762 trans-mem.cc:4806
+#, gcc-internal-format
+msgid "%<asm%> not allowed in atomic transaction"
+msgstr ""
+
+#: trans-mem.cc:765 trans-mem.cc:4432
+#, gcc-internal-format
+msgid "%<asm%> not allowed in %<transaction_safe%> function"
+msgstr ""
+
+#: trans-mem.cc:777
+#, gcc-internal-format
+msgid "relaxed transaction in atomic transaction"
+msgstr ""
+
+#: trans-mem.cc:780
+#, gcc-internal-format
+msgid "relaxed transaction in %<transaction_safe%> function"
+msgstr ""
+
+#: trans-mem.cc:787
+#, gcc-internal-format
+msgid "outer transaction in transaction"
+msgstr ""
+
+#: trans-mem.cc:790
+#, gcc-internal-format
+msgid "outer transaction in %<transaction_may_cancel_outer%> function"
+msgstr ""
+
+#: trans-mem.cc:794
+#, gcc-internal-format
+msgid "outer transaction in %<transaction_safe%> function"
+msgstr ""
+
+#: tree-cfg.cc:359
+#, gcc-internal-format
+msgid "ignoring loop annotation"
+msgstr ""
+
+#: tree-cfg.cc:3088
+#, gcc-internal-format
+msgid "constant not recomputed when %<ADDR_EXPR%> changed"
+msgstr ""
+
+#: tree-cfg.cc:3093
+#, gcc-internal-format
+msgid "side effects not recomputed when %<ADDR_EXPR%> changed"
+msgstr ""
+
+#: tree-cfg.cc:3108
+#, gcc-internal-format
+msgid "address taken but %<TREE_ADDRESSABLE%> bit not set"
+msgstr ""
+
+#: tree-cfg.cc:3134
+#, gcc-internal-format
+msgid "non-scalar %qs"
+msgstr ""
+
+#: tree-cfg.cc:3148
+#, gcc-internal-format
+msgid "invalid position or size operand to %qs"
+msgstr ""
+
+#: tree-cfg.cc:3154
+#, gcc-internal-format
+msgid "integral result type precision does not match field size of %qs"
+msgstr ""
+
+#: tree-cfg.cc:3163
+#, gcc-internal-format
+msgid "mode size of non-integral result does not match field size of %qs"
+msgstr ""
+
+#: tree-cfg.cc:3171
+#, gcc-internal-format
+msgid "%qs of non-mode-precision operand"
+msgstr ""
+
+#: tree-cfg.cc:3178
+#, gcc-internal-format
+msgid "position plus size exceeds size of referenced object in %qs"
+msgstr ""
+
+#: tree-cfg.cc:3189
+#, gcc-internal-format
+msgid "type mismatch in %qs reference"
+msgstr ""
+
+#: tree-cfg.cc:3205
+#, gcc-internal-format
+msgid "conversion of %qs on the left hand side of %qs"
+msgstr ""
+
+#: tree-cfg.cc:3213
+#, gcc-internal-format
+msgid "conversion of register to a different size in %qs"
+msgstr ""
+
+#: tree-cfg.cc:3233
+#, gcc-internal-format
+msgid "non-top-level %qs"
+msgstr ""
+
+#: tree-cfg.cc:3248
+#, gcc-internal-format
+msgid "invalid operands to %qs"
+msgstr ""
+
+#: tree-cfg.cc:3259 tree-cfg.cc:3268 tree-cfg.cc:3285 tree-cfg.cc:3964
+#: tree-cfg.cc:3993 tree-cfg.cc:4010 tree-cfg.cc:4031 tree-cfg.cc:4077
+#: tree-cfg.cc:4098 tree-cfg.cc:4152 tree-cfg.cc:4172 tree-cfg.cc:4208
+#: tree-cfg.cc:4229 tree-cfg.cc:4290 tree-cfg.cc:4365 tree-cfg.cc:4391
+#: tree-cfg.cc:4427 tree-cfg.cc:4476 tree-cfg.cc:4501 tree-cfg.cc:4576
+#: tree-cfg.cc:4662
+#, gcc-internal-format
+msgid "type mismatch in %qs"
+msgstr ""
+
+#: tree-cfg.cc:3279
+#, gcc-internal-format
+msgid "invalid %qs offset operator"
+msgstr ""
+
+#: tree-cfg.cc:3303 tree-cfg.cc:3329
+#, gcc-internal-format
+msgid "invalid address operand in %qs"
+msgstr ""
+
+#: tree-cfg.cc:3310 tree-cfg.cc:3336
+#, gcc-internal-format
+msgid "invalid offset operand in %qs"
+msgstr ""
+
+#: tree-cfg.cc:3317 tree-cfg.cc:3343
+#, gcc-internal-format
+msgid "invalid clique in %qs"
+msgstr ""
+
+#: tree-cfg.cc:3350 tree-cfg.cc:4674
+#, gcc-internal-format
+msgid "%qs in gimple IL"
+msgstr ""
+
+#: tree-cfg.cc:3361
+#, gcc-internal-format
+msgid "%qs as base where non-register is required"
+msgstr ""
+
+#: tree-cfg.cc:3376
+#, gcc-internal-format
+msgid "invalid expression for min lvalue"
+msgstr ""
+
+#: tree-cfg.cc:3427
+#, gcc-internal-format
+msgid "gimple call has two targets"
+msgstr ""
+
+#: tree-cfg.cc:3436
+#, gcc-internal-format
+msgid "gimple call has no target"
+msgstr ""
+
+#: tree-cfg.cc:3443
+#, gcc-internal-format
+msgid "invalid function in gimple call"
+msgstr ""
+
+#: tree-cfg.cc:3453
+#, gcc-internal-format
+msgid "non-function in gimple call"
+msgstr ""
+
+#: tree-cfg.cc:3464
+#, gcc-internal-format
+msgid "invalid pure const state for function"
+msgstr ""
+
+#: tree-cfg.cc:3476
+#, gcc-internal-format
+msgid "invalid LHS in gimple call"
+msgstr ""
+
+#: tree-cfg.cc:3484
+#, gcc-internal-format
+msgid "LHS in %<noreturn%> call"
+msgstr ""
+
+#: tree-cfg.cc:3498
+#, gcc-internal-format
+msgid "invalid conversion in gimple call"
+msgstr ""
+
+#: tree-cfg.cc:3507
+#, gcc-internal-format
+msgid "invalid static chain in gimple call"
+msgstr ""
+
+#: tree-cfg.cc:3518
+#, gcc-internal-format
+msgid "static chain with function that doesn%'t use one"
+msgstr ""
+
+#. Built-in unreachable with parameters might not be caught by
+#. undefined behavior sanitizer.  Front-ends do check users do not
+#. call them that way but we also produce calls to
+#. __builtin_unreachable internally, for example when IPA figures
+#. out a call cannot happen in a legal program.  In such cases,
+#. we must make sure arguments are stripped off.
+#: tree-cfg.cc:3537
+#, gcc-internal-format
+msgid "%<__builtin_unreachable%> or %<__builtin_trap%> call with arguments"
+msgstr ""
+
+#: tree-cfg.cc:3568
+#, gcc-internal-format
+msgid "%<DEFERRED_INIT%> calls should have same constant size for the first argument and LHS"
+msgstr ""
+
+#: tree-cfg.cc:3586
+#, gcc-internal-format
+msgid "invalid argument to gimple call"
+msgstr ""
+
+#: tree-cfg.cc:3613
+#, gcc-internal-format
+msgid "invalid operands in gimple comparison"
+msgstr ""
+
+#: tree-cfg.cc:3624
+#, gcc-internal-format
+msgid "mismatching comparison operand types"
+msgstr ""
+
+#: tree-cfg.cc:3641
+#, gcc-internal-format
+msgid "unsupported operation or type for vector comparison returning a boolean"
+msgstr ""
+
+#: tree-cfg.cc:3656
+#, gcc-internal-format
+msgid "non-vector operands in vector comparison"
+msgstr ""
+
+#: tree-cfg.cc:3665
+#, gcc-internal-format
+msgid "invalid vector comparison resulting type"
+msgstr ""
+
+#: tree-cfg.cc:3672
+#, gcc-internal-format
+msgid "bogus comparison result type"
+msgstr ""
+
+#: tree-cfg.cc:3694
+#, gcc-internal-format
+msgid "non-register as LHS of unary operation"
+msgstr ""
+
+#: tree-cfg.cc:3700
+#, gcc-internal-format
+msgid "invalid operand in unary operation"
+msgstr ""
+
+#: tree-cfg.cc:3723
+#, gcc-internal-format
+msgid "invalid vector types in nop conversion"
+msgstr ""
+
+#: tree-cfg.cc:3760
+#, gcc-internal-format
+msgid "invalid types in nop conversion"
+msgstr ""
+
+#: tree-cfg.cc:3775
+#, gcc-internal-format
+msgid "invalid types in address space conversion"
+msgstr ""
+
+#: tree-cfg.cc:3789
+#, gcc-internal-format
+msgid "invalid types in fixed-point conversion"
+msgstr ""
+
+#: tree-cfg.cc:3804
+#, gcc-internal-format
+msgid "invalid types in conversion to floating-point"
+msgstr ""
+
+#: tree-cfg.cc:3819
+#, gcc-internal-format
+msgid "invalid types in conversion to integer"
+msgstr ""
+
+#: tree-cfg.cc:3859
+#, gcc-internal-format
+msgid "type mismatch in %qs expression"
+msgstr ""
+
+#: tree-cfg.cc:3876 tree-cfg.cc:3890 tree-cfg.cc:4256 tree-cfg.cc:4278
+#, gcc-internal-format
+msgid "invalid types for %qs"
+msgstr ""
+
+#: tree-cfg.cc:3901
+#, gcc-internal-format
+msgid "%qs should be from a scalar to a like vector"
+msgstr ""
+
+#: tree-cfg.cc:3915
+#, gcc-internal-format
+msgid "non-trivial conversion in unary operation"
+msgstr ""
+
+#: tree-cfg.cc:3940
+#, gcc-internal-format
+msgid "non-register as LHS of binary operation"
+msgstr ""
+
+#: tree-cfg.cc:3947
+#, gcc-internal-format
+msgid "invalid operands in binary operation"
+msgstr ""
+
+#: tree-cfg.cc:4052
+#, gcc-internal-format
+msgid "invalid non-vector operands to %qs"
+msgstr ""
+
+#: tree-cfg.cc:4063
+#, gcc-internal-format
+msgid "invalid (pointer) operands %qs"
+msgstr ""
+
+#: tree-cfg.cc:4298
+#, gcc-internal-format
+msgid "vector type expected in %qs"
+msgstr ""
+
+#: tree-cfg.cc:4311
+#, gcc-internal-format
+msgid "type mismatch in binary expression"
+msgstr ""
+
+#: tree-cfg.cc:4339
+#, gcc-internal-format
+msgid "non-register as LHS of ternary operation"
+msgstr ""
+
+#: tree-cfg.cc:4347
+#, gcc-internal-format
+msgid "invalid operands in ternary operation"
+msgstr ""
+
+#: tree-cfg.cc:4379
+#, gcc-internal-format
+msgid "the first argument of a %qs must be of a boolean vector type of the same number of elements as the result"
+msgstr ""
+
+#: tree-cfg.cc:4411 tree-cfg.cc:4488
+#, gcc-internal-format
+msgid "vector types expected in %qs"
+msgstr ""
+
+#: tree-cfg.cc:4444
+#, gcc-internal-format
+msgid "vectors with different element number found in %qs"
+msgstr ""
+
+#: tree-cfg.cc:4460
+#, gcc-internal-format
+msgid "invalid mask type in %qs"
+msgstr ""
+
+#: tree-cfg.cc:4521
+#, gcc-internal-format
+msgid "not allowed type combination in %qs"
+msgstr ""
+
+#: tree-cfg.cc:4530
+#, gcc-internal-format
+msgid "invalid position or size in %qs"
+msgstr ""
+
+#: tree-cfg.cc:4536
+#, gcc-internal-format
+msgid "%qs into non-mode-precision operand"
+msgstr ""
+
+#: tree-cfg.cc:4546
+#, gcc-internal-format
+msgid "insertion out of range in %qs"
+msgstr ""
+
+#: tree-cfg.cc:4556
+#, gcc-internal-format
+msgid "%qs not at element boundary"
+msgstr ""
+
+#: tree-cfg.cc:4612
+#, gcc-internal-format
+msgid "non-trivial conversion in %qs"
+msgstr ""
+
+#: tree-cfg.cc:4621
+#, gcc-internal-format
+msgid "%qs LHS in clobber statement"
+msgstr ""
+
+#: tree-cfg.cc:4629
+#, gcc-internal-format
+msgid "%qs LHS in assignment statement"
+msgstr ""
+
+#: tree-cfg.cc:4648
+#, gcc-internal-format
+msgid "invalid operand in %qs"
+msgstr ""
+
+#: tree-cfg.cc:4680
+#, gcc-internal-format
+msgid "invalid %qs size argument in load"
+msgstr ""
+
+#: tree-cfg.cc:4699 tree-cfg.cc:4725
+#, gcc-internal-format
+msgid "invalid RHS for gimple memory store: %qs"
+msgstr ""
+
+#: tree-cfg.cc:4759 tree-cfg.cc:4777
+#, gcc-internal-format
+msgid "incorrect type of vector %qs elements"
+msgstr ""
+
+#: tree-cfg.cc:4768 tree-cfg.cc:4785
+#, gcc-internal-format
+msgid "incorrect number of vector %qs elements"
+msgstr ""
+
+#: tree-cfg.cc:4793
+#, gcc-internal-format
+msgid "incorrect type of vector CONSTRUCTOR elements"
+msgstr ""
+
+#: tree-cfg.cc:4802
+#, gcc-internal-format
+msgid "vector %qs with non-NULL element index"
+msgstr ""
+
+#: tree-cfg.cc:4809
+#, gcc-internal-format
+msgid "vector %qs element is not a GIMPLE value"
+msgstr ""
+
+#: tree-cfg.cc:4818
+#, gcc-internal-format
+msgid "non-vector %qs with elements"
+msgstr ""
+
+#: tree-cfg.cc:4876
+#, gcc-internal-format
+msgid "invalid operand in return statement"
+msgstr ""
+
+#: tree-cfg.cc:4891 c/gimple-parser.cc:2580
+#, gcc-internal-format
+msgid "invalid conversion in return statement"
+msgstr ""
+
+#: tree-cfg.cc:4915
+#, gcc-internal-format
+msgid "goto destination is neither a label nor a pointer"
+msgstr ""
+
+#: tree-cfg.cc:4934
+#, gcc-internal-format
+msgid "invalid operand to switch statement"
+msgstr ""
+
+#: tree-cfg.cc:4942
+#, gcc-internal-format
+msgid "non-integral type switch statement"
+msgstr ""
+
+#: tree-cfg.cc:4952
+#, gcc-internal-format
+msgid "invalid default case label in switch statement"
+msgstr ""
+
+#: tree-cfg.cc:4964
+#, gcc-internal-format
+msgid "invalid %<CASE_CHAIN%>"
+msgstr ""
+
+#: tree-cfg.cc:4970
+#, gcc-internal-format
+msgid "invalid case label in switch statement"
+msgstr ""
+
+#: tree-cfg.cc:4977
+#, gcc-internal-format
+msgid "invalid case range in switch statement"
+msgstr ""
+
+#: tree-cfg.cc:4987
+#, gcc-internal-format
+msgid "type precision mismatch in switch statement"
+msgstr ""
+
+#: tree-cfg.cc:4994
+#, gcc-internal-format
+msgid "type mismatch for case label in switch statement"
+msgstr ""
+
+#: tree-cfg.cc:5003
+#, gcc-internal-format
+msgid "case labels not sorted in switch statement"
+msgstr ""
+
+#: tree-cfg.cc:5046
+#, gcc-internal-format
+msgid "label context is not the current function declaration"
+msgstr ""
+
+#: tree-cfg.cc:5055
+#, gcc-internal-format
+msgid "incorrect entry in %<label_to_block_map%>"
+msgstr ""
+
+#: tree-cfg.cc:5065
+#, gcc-internal-format
+msgid "incorrect setting of landing pad number"
+msgstr ""
+
+#: tree-cfg.cc:5081
+#, gcc-internal-format
+msgid "invalid comparison code in gimple cond"
+msgstr ""
+
+#: tree-cfg.cc:5089
+#, gcc-internal-format
+msgid "invalid labels in gimple cond"
+msgstr ""
+
+#: tree-cfg.cc:5175 tree-cfg.cc:5184
+#, gcc-internal-format
+msgid "invalid %<PHI%> result"
+msgstr ""
+
+#: tree-cfg.cc:5194
+#, gcc-internal-format
+msgid "missing %<PHI%> def"
+msgstr ""
+
+#: tree-cfg.cc:5208
+#, gcc-internal-format
+msgid "invalid %<PHI%> argument"
+msgstr ""
+
+#: tree-cfg.cc:5215
+#, gcc-internal-format
+msgid "incompatible types in %<PHI%> argument %u"
+msgstr ""
+
+#: tree-cfg.cc:5318
+#, gcc-internal-format
+msgid "%<verify_gimple%> failed"
+msgstr ""
+
+#: tree-cfg.cc:5376
+#, gcc-internal-format
+msgid "dead statement in EH table"
+msgstr ""
+
+#: tree-cfg.cc:5392
+#, gcc-internal-format
+msgid "location references block not in block tree"
+msgstr ""
+
+#: tree-cfg.cc:5441
+#, gcc-internal-format
+msgid "local declaration from a different function"
+msgstr ""
+
+#: tree-cfg.cc:5544
+#, gcc-internal-format
+msgid "gimple_bb (phi) is set to a wrong basic block"
+msgstr ""
+
+#: tree-cfg.cc:5553
+#, gcc-internal-format
+msgid "PHI node with location"
+msgstr ""
+
+#: tree-cfg.cc:5564 tree-cfg.cc:5611
+#, gcc-internal-format
+msgid "incorrect sharing of tree nodes"
+msgstr ""
+
+#: tree-cfg.cc:5572
+#, gcc-internal-format
+msgid "virtual PHI with argument locations"
+msgstr ""
+
+#: tree-cfg.cc:5599
+#, gcc-internal-format
+msgid "gimple_bb (stmt) is set to a wrong basic block"
+msgstr ""
+
+#: tree-cfg.cc:5639
+#, gcc-internal-format
+msgid "statement marked for throw, but doesn%'t"
+msgstr ""
+
+#: tree-cfg.cc:5645
+#, gcc-internal-format
+msgid "statement marked for throw in middle of block"
+msgstr ""
+
+#: tree-cfg.cc:5667
+#, gcc-internal-format
+msgid "verify_gimple failed"
+msgstr ""
+
+#: tree-cfg.cc:5691
+#, gcc-internal-format
+msgid "ENTRY_BLOCK has IL associated with it"
+msgstr ""
+
+#: tree-cfg.cc:5698
+#, gcc-internal-format
+msgid "EXIT_BLOCK has IL associated with it"
+msgstr ""
+
+#: tree-cfg.cc:5705
+#, gcc-internal-format, gfc-internal-format
+msgid "fallthru to exit from bb %d"
+msgstr ""
+
+#: tree-cfg.cc:5711
+#, gcc-internal-format
+msgid "entry block count not initialized"
+msgstr ""
+
+#: tree-cfg.cc:5717
+#, gcc-internal-format
+msgid "exit block count not initialized"
+msgstr ""
+
+#: tree-cfg.cc:5724
+#, gcc-internal-format
+msgid "probability of edge from entry block not initialized"
+msgstr ""
+
+#: tree-cfg.cc:5739
+#, gcc-internal-format, gfc-internal-format
+msgid "count of bb %d not initialized"
+msgstr ""
+
+#: tree-cfg.cc:5745
+#, gcc-internal-format, gfc-internal-format
+msgid "probability of edge %d->%d not initialized"
+msgstr ""
+
+#: tree-cfg.cc:5765
+#, gcc-internal-format
+msgid "nonlocal label %qD is not first in a sequence of labels in bb %d"
+msgstr ""
+
+#: tree-cfg.cc:5772
+#, gcc-internal-format
+msgid "EH landing pad label %qD is not first in a sequence of labels in bb %d"
+msgstr ""
+
+#: tree-cfg.cc:5779
+#, gcc-internal-format
+msgid "label %qD to block does not match in bb %d"
+msgstr ""
+
+#: tree-cfg.cc:5786
+#, gcc-internal-format
+msgid "label %qD has incorrect context in bb %d"
+msgstr ""
+
+#: tree-cfg.cc:5801
+#, gcc-internal-format, gfc-internal-format
+msgid "control flow in the middle of basic block %d"
+msgstr ""
+
+#: tree-cfg.cc:5811
+#, gcc-internal-format
+msgid "label %qD in the middle of basic block %d"
+msgstr ""
+
+#: tree-cfg.cc:5830
+#, gcc-internal-format, gfc-internal-format
+msgid "returns_twice call is not last in basic block %d"
+msgstr ""
+
+#: tree-cfg.cc:5839
+#, gcc-internal-format, gfc-internal-format
+msgid "returns_twice call is not first in basic block %d"
+msgstr ""
+
+#: tree-cfg.cc:5871
+#, gcc-internal-format, gfc-internal-format
+msgid "fallthru edge after a control statement in bb %d"
+msgstr ""
+
+#: tree-cfg.cc:5884
+#, gcc-internal-format, gfc-internal-format
+msgid "true/false edge after a non-GIMPLE_COND in bb %d"
+msgstr ""
+
+#: tree-cfg.cc:5907 tree-cfg.cc:5929 tree-cfg.cc:5946 tree-cfg.cc:6015
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong outgoing edge flags at end of bb %d"
+msgstr ""
+
+#: tree-cfg.cc:5917
+#, gcc-internal-format, gfc-internal-format
+msgid "explicit goto at end of bb %d"
+msgstr ""
+
+#: tree-cfg.cc:5951
+#, gcc-internal-format, gfc-internal-format
+msgid "return edge does not point to exit in bb %d"
+msgstr ""
+
+#: tree-cfg.cc:5981
+#, gcc-internal-format
+msgid "found default case not at the start of case vector"
+msgstr ""
+
+#: tree-cfg.cc:5989
+#, gcc-internal-format
+msgid "case labels not sorted: "
+msgstr ""
+
+#: tree-cfg.cc:6006
+#, gcc-internal-format, gfc-internal-format
+msgid "extra outgoing edge %d->%d"
+msgstr ""
+
+#: tree-cfg.cc:6029
+#, gcc-internal-format, gfc-internal-format
+msgid "missing edge %i->%i"
+msgstr ""
+
+#: tree-cfg.cc:9805
+#, gcc-internal-format
+msgid "%<noreturn%> function does return"
+msgstr ""
+
+#: tree-cfg.cc:9825 tree-cfg.cc:9860
+#, gcc-internal-format
+msgid "control reaches end of non-void function"
+msgstr ""
+
+#: tree-cfg.cc:9926
+#, gcc-internal-format
+msgid "ignoring return value of %qD declared with attribute %<warn_unused_result%>"
+msgstr ""
+
+#: tree-cfg.cc:9931 cp/cvt.cc:1137
+#, gcc-internal-format
+msgid "ignoring return value of function declared with attribute %<warn_unused_result%>"
+msgstr ""
+
+#: tree-complex.cc:1639
+#, gcc-internal-format
+msgid "%<asm goto%> with complex typed outputs"
+msgstr ""
+
+#: tree-diagnostic-path.cc:626
+msgid "%@ %s (fndecl %qD, depth %i)"
+msgstr ""
+
+#: tree-diagnostic-path.cc:631
+msgid "%@ %s (depth %i)"
+msgstr ""
+
+#: tree-diagnostic-path.cc:637
+msgid "%@ %s"
+msgstr ""
+
+#: tree-diagnostic.cc:207
+#, gcc-internal-format
+msgid "in definition of macro %qs"
+msgstr ""
+
+#: tree-diagnostic.cc:224
+#, gcc-internal-format
+msgid "in expansion of macro %qs"
+msgstr ""
+
+#: tree-eh.cc:4946
+#, gcc-internal-format, gfc-internal-format
+msgid "BB %i has multiple EH edges"
+msgstr ""
+
+#: tree-eh.cc:4958
+#, gcc-internal-format, gfc-internal-format
+msgid "BB %i cannot throw but has an EH edge"
+msgstr ""
+
+#: tree-eh.cc:4966
+#, gcc-internal-format, gfc-internal-format
+msgid "BB %i last statement has incorrectly set lp"
+msgstr ""
+
+#: tree-eh.cc:4972
+#, gcc-internal-format, gfc-internal-format
+msgid "BB %i is missing an EH edge"
+msgstr ""
+
+#: tree-eh.cc:4978
+#, gcc-internal-format, gfc-internal-format
+msgid "Incorrect EH edge %i->%i"
+msgstr ""
+
+#: tree-eh.cc:5012 tree-eh.cc:5031
+#, gcc-internal-format, gfc-internal-format
+msgid "BB %i is missing an edge"
+msgstr ""
+
+#: tree-eh.cc:5048
+#, gcc-internal-format, gfc-internal-format
+msgid "BB %i too many fallthru edges"
+msgstr ""
+
+#: tree-eh.cc:5057
+#, gcc-internal-format, gfc-internal-format
+msgid "BB %i has incorrect edge"
+msgstr ""
+
+#: tree-eh.cc:5063
+#, gcc-internal-format, gfc-internal-format
+msgid "BB %i has incorrect fallthru edge"
+msgstr ""
+
+#: tree-inline.cc:3939
+#, gcc-internal-format
+msgid "function %q+F can never be copied because it receives a non-local goto"
+msgstr ""
+
+#: tree-inline.cc:3946
+#, gcc-internal-format
+msgid "function %q+F can never be copied because it saves address of local label in a static variable"
+msgstr ""
+
+#: tree-inline.cc:3986
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it uses alloca (override using the always_inline attribute)"
+msgstr ""
+
+#: tree-inline.cc:4000
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it uses setjmp"
+msgstr ""
+
+#: tree-inline.cc:4014
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it uses variable argument lists"
+msgstr ""
+
+#: tree-inline.cc:4026
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it uses setjmp-longjmp exception handling"
+msgstr ""
+
+#: tree-inline.cc:4034
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it uses non-local goto"
+msgstr ""
+
+#: tree-inline.cc:4046
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it uses %<__builtin_return%> or %<__builtin_apply_args%>"
+msgstr ""
+
+#: tree-inline.cc:4066
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it contains a computed goto"
+msgstr ""
+
+#: tree-inline.cc:4112
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it has a VLA argument"
+msgstr ""
+
+#: tree-inline.cc:4179
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it is suppressed using %<-fno-inline%>"
+msgstr ""
+
+#: tree-inline.cc:4187
+#, gcc-internal-format
+msgid "function %q+F can never be inlined because it uses attributes conflicting with inlining"
+msgstr ""
+
+#: tree-inline.cc:4868
+#, gcc-internal-format
+msgid "inlining failed in call to %<always_inline%> %q+F: %s"
+msgstr ""
+
+#: tree-inline.cc:4871 tree-inline.cc:4892
+#, gcc-internal-format
+msgid "called from here"
+msgstr ""
+
+#: tree-inline.cc:4874 tree-inline.cc:4895
+#, gcc-internal-format
+msgid "called from this function"
+msgstr ""
+
+#: tree-inline.cc:4888
+#, gcc-internal-format
+msgid "inlining failed in call to %q+F: %s"
+msgstr ""
+
+#: tree-into-ssa.cc:3433
+#, gcc-internal-format
+msgid "statement uses released SSA name"
+msgstr ""
+
+#: tree-into-ssa.cc:3445
+#, gcc-internal-format
+msgid "cannot update SSA form"
+msgstr ""
+
+#: tree-into-ssa.cc:3538 tree-outof-ssa.cc:902 tree-ssa-coalesce.cc:1012
+#, gcc-internal-format
+msgid "SSA corruption"
+msgstr ""
+
+#: tree-nested.cc:1190
+#, gcc-internal-format, gfc-internal-format
+msgid "%s from %s referenced in %s"
+msgstr ""
+
+#: tree-nested.cc:2985
+#, gcc-internal-format, gfc-internal-format
+msgid "%s from %s called in %s"
+msgstr ""
+
+#: tree-profile.cc:899
+#, gcc-internal-format, gfc-internal-format
+msgid "Too many conditions (found %u); giving up coverage"
+msgstr ""
+
+#: tree-profile.cc:1757
+#, gcc-internal-format
+msgid "invalid regular expression %qs in %qs"
+msgstr ""
+
+#: tree-profile.cc:1856
+#, gcc-internal-format
+msgid "target does not support atomic profile update, single mode is selected"
+msgstr ""
+
+#: tree-ssa-alias.cc:4070
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid fn spec attribute \"%s\""
+msgstr ""
+
+#: tree-ssa-alias.cc:4109
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid fn spec attribute \"%s\" arg %i"
+msgstr ""
+
+#: tree-ssa-ccp.cc:4685 c-family/c-common.cc:5912
+#, gcc-internal-format
+msgid "%qs pointer is null"
+msgstr ""
+
+#: tree-ssa-ccp.cc:4688 c-family/c-common.cc:5915
+#, gcc-internal-format
+msgid "in a call to non-static member function %qD"
+msgstr ""
+
+#: tree-ssa-ccp.cc:4694 c-family/c-common.cc:5921
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %u null where non-null expected"
+msgstr ""
+
+#: tree-ssa-ccp.cc:4700
+#, gcc-internal-format
+msgid "in a call to built-in function %qD"
+msgstr ""
+
+#: tree-ssa-ccp.cc:4704 c-family/c-common.cc:5925
+#, gcc-internal-format
+msgid "in a call to function %qD declared %qs"
+msgstr ""
+
+#: tree-ssa-loop-niter.cc:3889
+#, gcc-internal-format, gfc-internal-format
+msgid "iteration %s invokes undefined behavior"
+msgstr ""
+
+#: tree-ssa-loop-niter.cc:3890
+#, gcc-internal-format
+msgid "within this loop"
+msgstr ""
+
+#: tree-ssa-loop-prefetch.cc:2102
+#, gcc-internal-format
+msgid "%<l1-cache-size%> parameter is not a power of two %d"
+msgstr ""
+
+#: tree-ssa-operands.cc:1032
+#, gcc-internal-format
+msgid "virtual definition of statement not up to date"
+msgstr ""
+
+#: tree-ssa-operands.cc:1039
+#, gcc-internal-format
+msgid "virtual def operand missing for statement"
+msgstr ""
+
+#: tree-ssa-operands.cc:1049
+#, gcc-internal-format
+msgid "virtual use of statement not up to date"
+msgstr ""
+
+#: tree-ssa-operands.cc:1056
+#, gcc-internal-format
+msgid "virtual use operand missing for statement"
+msgstr ""
+
+#: tree-ssa-operands.cc:1073
+#, gcc-internal-format
+msgid "excess use operand for statement"
+msgstr ""
+
+#: tree-ssa-operands.cc:1083
+#, gcc-internal-format
+msgid "use operand missing for statement"
+msgstr ""
+
+#: tree-ssa-operands.cc:1090
+#, gcc-internal-format
+msgid "statement volatile flag not up to date"
+msgstr ""
+
+#: tree-ssa-strlen.cc:2127
+#, gcc-internal-format
+msgid "%qD writing one too many bytes into a region of a size that depends on %<strlen%>"
+msgstr ""
+
+#: tree-ssa-strlen.cc:2131
+#, gcc-internal-format
+msgid "writing one too many bytes into a region of a size that depends on %<strlen%>"
+msgstr ""
+
+#: tree-ssa-strlen.cc:2140
+#, gcc-internal-format
+msgid "%qD writing %wu byte into a region of size %wu"
+msgid_plural "%qD writing %wu bytes into a region of size %wu"
+msgstr[0] ""
+msgstr[1] ""
+
+#: tree-ssa-strlen.cc:2148
+#, gcc-internal-format
+msgid "writing %wu byte into a region of size %wu"
+msgid_plural "writing %wu bytes into a region of size %wu"
+msgstr[0] ""
+msgstr[1] ""
+
+#: tree-ssa-strlen.cc:2158
+#, gcc-internal-format
+msgid "%qD writing %wu byte into a region of size between %wu and %wu"
+msgid_plural "%qD writing %wu bytes into a region of size between %wu and %wu"
+msgstr[0] ""
+msgstr[1] ""
+
+#: tree-ssa-strlen.cc:2166
+#, gcc-internal-format
+msgid "writing %wu byte into a region of size between %wu and %wu"
+msgid_plural "writing %wu bytes into a region of size between %wu and %wu"
+msgstr[0] ""
+msgstr[1] ""
+
+#: tree-ssa-strlen.cc:2176
+#, gcc-internal-format
+msgid "%qD writing between %wu and %wu bytes into a region of size %wu"
+msgstr ""
+
+#: tree-ssa-strlen.cc:2182
+#, gcc-internal-format
+msgid "writing between %wu and %wu bytes into a region of size %wu"
+msgstr ""
+
+#: tree-ssa-strlen.cc:2190
+#, gcc-internal-format
+msgid "%qD writing between %wu and %wu bytes into a region of size between %wu and %wu"
+msgstr ""
+
+#: tree-ssa-strlen.cc:2196
+#, gcc-internal-format
+msgid "writing between %wu and %wu bytes into a region of size between %wu and %wu"
+msgstr ""
+
+#: tree-ssa-strlen.cc:3092
+#, gcc-internal-format
+msgid "%qD output truncated before terminating nul copying %E byte from a string of the same length"
+msgid_plural "%qD output truncated before terminating nul copying %E bytes from a string of the same length"
+msgstr[0] ""
+msgstr[1] ""
+
+#: tree-ssa-strlen.cc:3108
+#, gcc-internal-format
+msgid "%qD output truncated copying %E byte from a string of length %wu"
+msgid_plural "%qD output truncated copying %E bytes from a string of length %wu"
+msgstr[0] ""
+msgstr[1] ""
+
+#: tree-ssa-strlen.cc:3115
+#, gcc-internal-format
+msgid "%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
+msgstr ""
+
+#: tree-ssa-strlen.cc:3127
+#, gcc-internal-format
+msgid "%qD output may be truncated copying %E byte from a string of length %wu"
+msgid_plural "%qD output may be truncated copying %E bytes from a string of length %wu"
+msgstr[0] ""
+msgstr[1] ""
+
+#: tree-ssa-strlen.cc:3134 tree-ssa-strlen.cc:3150
+#, gcc-internal-format
+msgid "%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
+msgstr ""
+
+#: tree-ssa-strlen.cc:3304
+#, gcc-internal-format
+msgid "%qD output truncated before terminating nul copying as many bytes from a string as its length"
+msgstr ""
+
+#: tree-ssa-strlen.cc:3317
+#, gcc-internal-format
+msgid "%qD specified bound depends on the length of the source argument"
+msgstr ""
+
+#: tree-ssa-strlen.cc:3325
+#, gcc-internal-format
+msgid "length computed here"
+msgstr ""
+
+#: tree-ssa-strlen.cc:4282
+#, gcc-internal-format
+msgid "%qD of a string of length %wu or more and an array of size %wu evaluates to nonzero"
+msgstr ""
+
+#: tree-ssa-strlen.cc:4284
+#, gcc-internal-format
+msgid "%qD of a string of length %wu and an array of size %wu evaluates to nonzero"
+msgstr ""
+
+#: tree-ssa-strlen.cc:4291
+#, gcc-internal-format
+msgid "%qD of strings of length %wu and %wu and bound of %wu evaluates to nonzero"
+msgstr ""
+
+#: tree-ssa-strlen.cc:4296
+#, gcc-internal-format
+msgid "%qD of a string of length %wu, an array of size %wu and bound of %wu evaluates to nonzero"
+msgstr ""
+
+#: tree-ssa-strlen.cc:4307
+#, gcc-internal-format
+msgid "in this expression"
+msgstr ""
+
+#: tree-ssa-uninit.cc:306
+#, gcc-internal-format
+msgid "%qD is used uninitialized"
+msgstr ""
+
+#: tree-ssa-uninit.cc:308
+#, gcc-internal-format
+msgid "%qD may be used uninitialized"
+msgstr ""
+
+#: tree-ssa-uninit.cc:315
+#, gcc-internal-format
+msgid "%qs is used uninitialized"
+msgstr ""
+
+#: tree-ssa-uninit.cc:318
+#, gcc-internal-format
+msgid "%qs may be used uninitialized"
+msgstr ""
+
+#: tree-ssa-uninit.cc:337 varasm.cc:363 varasm.cc:8021
+#, gcc-internal-format
+msgid "%qD was declared here"
+msgstr ""
+
+#: tree-ssa-uninit.cc:339
+#, gcc-internal-format
+msgid "%qs was declared here"
+msgstr ""
+
+#: tree-ssa-uninit.cc:450 tree-ssa-uninit.cc:760
+#, gcc-internal-format
+msgid "%qE may be used uninitialized"
+msgstr ""
+
+#: tree-ssa-uninit.cc:459
+#, gcc-internal-format
+msgid "accessing argument %u of a function declared with attribute %<%s%>"
+msgstr ""
+
+#: tree-ssa-uninit.cc:747
+#, gcc-internal-format
+msgid "%qE is used uninitialized"
+msgstr ""
+
+#: tree-ssa-uninit.cc:882
+#, gcc-internal-format
+msgid "in a call to %qD declared with attribute %<%s%> here"
+msgstr ""
+
+#: tree-ssa-uninit.cc:889
+#, gcc-internal-format
+msgid "in a call to %qT declared with attribute %<%s%>"
+msgstr ""
+
+#: tree-ssa-uninit.cc:905
+#, gcc-internal-format
+msgid "by argument %u of type %s to %qD declared here"
+msgstr ""
+
+#: tree-ssa-uninit.cc:913
+#, gcc-internal-format
+msgid "by argument %u of type %s to %qT"
+msgstr ""
+
+#: tree-ssa.cc:656
+#, gcc-internal-format, gfc-internal-format
+msgid "multiple virtual PHI nodes in BB %d"
+msgstr ""
+
+#: tree-ssa.cc:670 tree-ssa.cc:699
+#, gcc-internal-format
+msgid "virtual definition is not an SSA name"
+msgstr ""
+
+#: tree-ssa.cc:686
+#, gcc-internal-format
+msgid "stmt with wrong VUSE"
+msgstr ""
+
+#: tree-ssa.cc:716
+#, gcc-internal-format, gfc-internal-format
+msgid "PHI node with wrong VUSE on edge from BB %d"
+msgstr ""
+
+#: tree-ssa.cc:742
+#, gcc-internal-format
+msgid "expected an SSA_NAME object"
+msgstr ""
+
+#: tree-ssa.cc:748
+#, gcc-internal-format
+msgid "found an SSA_NAME that had been released into the free pool"
+msgstr ""
+
+#: tree-ssa.cc:755
+#, gcc-internal-format
+msgid "type mismatch between an SSA_NAME and its symbol"
+msgstr ""
+
+#: tree-ssa.cc:761
+#, gcc-internal-format
+msgid "found a virtual definition for a GIMPLE register"
+msgstr ""
+
+#: tree-ssa.cc:767
+#, gcc-internal-format
+msgid "virtual SSA name for non-VOP decl"
+msgstr ""
+
+#: tree-ssa.cc:773
+#, gcc-internal-format
+msgid "found a real definition for a non-register"
+msgstr ""
+
+#: tree-ssa.cc:780
+#, gcc-internal-format
+msgid "found a default name with a non-empty defining statement"
+msgstr ""
+
+#: tree-ssa.cc:810
+#, gcc-internal-format
+msgid "RESULT_DECL should be read only when DECL_BY_REFERENCE is set"
+msgstr ""
+
+#: tree-ssa.cc:816
+#, gcc-internal-format, gfc-internal-format
+msgid "SSA_NAME created in two different blocks %i and %i"
+msgstr ""
+
+#: tree-ssa.cc:825 tree-ssa.cc:1165
+#, gcc-internal-format
+msgid "SSA_NAME_DEF_STMT is wrong"
+msgstr ""
+
+#: tree-ssa.cc:877
+#, gcc-internal-format
+msgid "missing definition"
+msgstr ""
+
+#: tree-ssa.cc:883
+#, gcc-internal-format, gfc-internal-format
+msgid "definition in block %i does not dominate use in block %i"
+msgstr ""
+
+#: tree-ssa.cc:891
+#, gcc-internal-format, gfc-internal-format
+msgid "definition in block %i follows the use"
+msgstr ""
+
+#: tree-ssa.cc:898
+#, gcc-internal-format
+msgid "SSA_NAME_OCCURS_IN_ABNORMAL_PHI should be set"
+msgstr ""
+
+#: tree-ssa.cc:906
+#, gcc-internal-format
+msgid "no immediate_use list"
+msgstr ""
+
+#: tree-ssa.cc:918
+#, gcc-internal-format
+msgid "wrong immediate use list"
+msgstr ""
+
+#: tree-ssa.cc:952
+#, gcc-internal-format
+msgid "incoming edge count does not match number of PHI arguments"
+msgstr ""
+
+#: tree-ssa.cc:966
+#, gcc-internal-format, gfc-internal-format
+msgid "PHI argument is missing for edge %d->%d"
+msgstr ""
+
+#: tree-ssa.cc:975
+#, gcc-internal-format
+msgid "PHI argument is not SSA_NAME, or invariant"
+msgstr ""
+
+#: tree-ssa.cc:981
+#, gcc-internal-format
+msgid "PHI argument on abnormal edge is not SSA_NAME"
+msgstr ""
+
+#: tree-ssa.cc:1002
+#, gcc-internal-format
+msgid "address taken, but ADDRESSABLE bit not set"
+msgstr ""
+
+#: tree-ssa.cc:1009
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong edge %d->%d for PHI argument"
+msgstr ""
+
+#: tree-ssa.cc:1084
+#, gcc-internal-format
+msgid "shared SSA name info"
+msgstr ""
+
+#: tree-ssa.cc:1111
+#, gcc-internal-format, gfc-internal-format
+msgid "AUX pointer initialized for edge %d->%d"
+msgstr ""
+
+#: tree-ssa.cc:1137
+#, gcc-internal-format
+msgid "stmt (%p) marked modified after optimization pass: "
+msgstr ""
+
+#: tree-ssa.cc:1203
+#, gcc-internal-format
+msgid "verify_ssa failed"
+msgstr ""
+
+#: tree-streamer-in.cc:346
+#, gcc-internal-format
+msgid "machine independent builtin code out of range"
+msgstr ""
+
+#: tree-streamer-in.cc:352
+#, gcc-internal-format
+msgid "target specific builtin not available"
+msgstr ""
+
+#: tree-vect-generic.cc:300 tree-vect-generic.cc:470 tree-vect-generic.cc:2042
+#, gcc-internal-format
+msgid "vector operation will be expanded piecewise"
+msgstr ""
+
+#: tree-vect-generic.cc:303
+#, gcc-internal-format
+msgid "vector operation will be expanded in parallel"
+msgstr ""
+
+#: tree-vect-generic.cc:360
+#, gcc-internal-format
+msgid "vector operation will be expanded with a single scalar operation"
+msgstr ""
+
+#: tree-vect-generic.cc:1091
+#, gcc-internal-format
+msgid "vector condition will be expanded piecewise"
+msgstr ""
+
+#: tree-vect-generic.cc:1602
+#, gcc-internal-format
+msgid "vector shuffling operation will be expanded piecewise"
+msgstr ""
+
+#: tree-vect-loop.cc:5069
+#, gcc-internal-format
+msgid "vectorization did not happen for a simd loop"
+msgstr ""
+
+#: tree.cc:2244
+#, gcc-internal-format
+msgid "non-constant element in constant CONSTRUCTOR"
+msgstr ""
+
+#: tree.cc:2246
+#, gcc-internal-format
+msgid "side-effects element in no-side-effects CONSTRUCTOR"
+msgstr ""
+
+#: tree.cc:7347 m2/gm2-gcc/m2type.cc:215
+#, gcc-internal-format
+msgid "arrays of functions are not meaningful"
+msgstr ""
+
+#: tree.cc:7513
+#, gcc-internal-format
+msgid "function return type cannot be function"
+msgstr ""
+
+#: tree.cc:8995 tree.cc:9080 tree.cc:9143
+#, gcc-internal-format, gfc-internal-format
+msgid "tree check: %s, have %s in %s, at %s:%d"
+msgstr ""
+
+#: tree.cc:9032
+#, gcc-internal-format, gfc-internal-format
+msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
+msgstr ""
+
+#: tree.cc:9045
+#, gcc-internal-format
+msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
+msgstr ""
+
+#: tree.cc:9094
+#, gcc-internal-format
+msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
+msgstr ""
+
+#: tree.cc:9107
+#, gcc-internal-format
+msgid "tree check: expected %<omp_clause %s%>, have %qs in %s, at %s:%d"
+msgstr ""
+
+#: tree.cc:9169
+#, gcc-internal-format
+msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
+msgstr ""
+
+#: tree.cc:9183
+#, gcc-internal-format
+msgid "tree check: accessed elt %d of %<tree_int_cst%> with %d elts in %s, at %s:%d"
+msgstr ""
+
+#: tree.cc:9196
+#, gcc-internal-format
+msgid "tree check: accessed elt %d of %<tree_vec%> with %d elts in %s, at %s:%d"
+msgstr ""
+
+#: tree.cc:9209
+#, gcc-internal-format, gfc-internal-format
+msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
+msgstr ""
+
+#: tree.cc:9222
+#, gcc-internal-format
+msgid "tree check: accessed operand %d of %<omp_clause %s%> with %d operands in %s, at %s:%d"
+msgstr ""
+
+#: tree.cc:12476
+#, gcc-internal-format
+msgid "%qD is deprecated: %s"
+msgstr ""
+
+#: tree.cc:12479
+#, gcc-internal-format
+msgid "%qD is deprecated"
+msgstr ""
+
+#: tree.cc:12502
+#, gcc-internal-format
+msgid "%qE is deprecated: %s"
+msgstr ""
+
+#: tree.cc:12505
+#, gcc-internal-format
+msgid "%qE is deprecated"
+msgstr ""
+
+#: tree.cc:12511
+#, gcc-internal-format, gfc-internal-format
+msgid "type is deprecated: %s"
+msgstr ""
+
+#: tree.cc:12514
+#, gcc-internal-format
+msgid "type is deprecated"
+msgstr ""
+
+#: tree.cc:12556
+#, gcc-internal-format
+msgid "%qD is unavailable: %s"
+msgstr ""
+
+#: tree.cc:12558
+#, gcc-internal-format
+msgid "%qD is unavailable"
+msgstr ""
+
+#: tree.cc:12579
+#, gcc-internal-format
+msgid "%qE is unavailable: %s"
+msgstr ""
+
+#: tree.cc:12581
+#, gcc-internal-format
+msgid "%qE is unavailable"
+msgstr ""
+
+#: tree.cc:12586
+#, gcc-internal-format, gfc-internal-format
+msgid "type is unavailable: %s"
+msgstr ""
+
+#: tree.cc:12588
+#, gcc-internal-format
+msgid "type is unavailable"
+msgstr ""
+
+#. Type variant can differ by:
+#.
+#. - TYPE_QUALS: TYPE_READONLY, TYPE_VOLATILE, TYPE_ATOMIC, TYPE_RESTRICT,
+#. ENCODE_QUAL_ADDR_SPACE.
+#. - main variant may be TYPE_COMPLETE_P and variant types !TYPE_COMPLETE_P
+#. in this case some values may not be set in the variant types
+#. (see TYPE_COMPLETE_P checks).
+#. - it is possible to have TYPE_ARTIFICIAL variant of non-artifical type
+#. - by TYPE_NAME and attributes (i.e. when variant originate by typedef)
+#. - TYPE_CANONICAL (TYPE_ALIAS_SET is the same among variants)
+#. - by the alignment: TYPE_ALIGN and TYPE_USER_ALIGN
+#. - during LTO by TYPE_CONTEXT if type is TYPE_FILE_SCOPE_P
+#. this is necessary to make it possible to merge types form different TUs
+#. - arrays, pointers and references may have TREE_TYPE that is a variant
+#. of TREE_TYPE of their main variants.
+#. - aggregates may have new TYPE_FIELDS list that list variants of
+#. the main variant TYPE_FIELDS.
+#. - vector types may differ by TYPE_VECTOR_OPAQUE
+#.
+#. Convenience macro for matching individual fields.
+#: tree.cc:13516
+#, gcc-internal-format, gfc-internal-format
+msgid "type variant differs by %s"
+msgstr ""
+
+#: tree.cc:13561
+#, gcc-internal-format
+msgid "type variant has different %<TYPE_SIZE_UNIT%>"
+msgstr ""
+
+#: tree.cc:13563
+#, gcc-internal-format
+msgid "type variant%'s %<TYPE_SIZE_UNIT%>"
+msgstr ""
+
+#: tree.cc:13565
+#, gcc-internal-format
+msgid "type%'s %<TYPE_SIZE_UNIT%>"
+msgstr ""
+
+#: tree.cc:13590
+#, gcc-internal-format
+msgid "type variant with %<TYPE_ALIAS_SET_KNOWN_P%>"
+msgstr ""
+
+#: tree.cc:13603
+#, gcc-internal-format
+msgid "type variant has different %<TYPE_VFIELD%>"
+msgstr ""
+
+#: tree.cc:13640
+#, gcc-internal-format
+msgid "type variant has different %<TYPE_BINFO%>"
+msgstr ""
+
+#: tree.cc:13642
+#, gcc-internal-format
+msgid "type variant%'s %<TYPE_BINFO%>"
+msgstr ""
+
+#: tree.cc:13644
+#, gcc-internal-format
+msgid "type%'s %<TYPE_BINFO%>"
+msgstr ""
+
+#: tree.cc:13683
+#, gcc-internal-format
+msgid "type variant has different %<TYPE_FIELDS%>"
+msgstr ""
+
+#: tree.cc:13685
+#, gcc-internal-format
+msgid "first mismatch is field"
+msgstr ""
+
+#: tree.cc:13687
+#, gcc-internal-format
+msgid "and field"
+msgstr ""
+
+#: tree.cc:13704
+#, gcc-internal-format
+msgid "type variant has different %<TREE_TYPE%>"
+msgstr ""
+
+#: tree.cc:13706 tree.cc:13717
+#, gcc-internal-format
+msgid "type variant%'s %<TREE_TYPE%>"
+msgstr ""
+
+#: tree.cc:13708 tree.cc:13719
+#, gcc-internal-format
+msgid "type%'s %<TREE_TYPE%>"
+msgstr ""
+
+#: tree.cc:13715
+#, gcc-internal-format
+msgid "type is not compatible with its variant"
+msgstr ""
+
+#: tree.cc:14040
+#, gcc-internal-format, gfc-internal-format
+msgid "type %s is not an opaque type"
+msgstr ""
+
+#: tree.cc:14046
+#, gcc-internal-format, gfc-internal-format
+msgid "type %s is not with opaque mode"
+msgstr ""
+
+#: tree.cc:14052
+#, gcc-internal-format
+msgid "type %s differs by %<TYPE_MODE%>"
+msgstr ""
+
+#: tree.cc:14060
+#, gcc-internal-format
+msgid "type %s differs by %<TYPE_SIZE%>"
+msgstr ""
+
+#: tree.cc:14066
+#, gcc-internal-format
+msgid "type %s differs by %<TYPE_ALIGN%>"
+msgstr ""
+
+#: tree.cc:14072
+#, gcc-internal-format
+msgid "type %s differs by %<TYPE_USER_ALIGN%>"
+msgstr ""
+
+#: tree.cc:14102
+#, gcc-internal-format
+msgid "main variant is not defined"
+msgstr ""
+
+#: tree.cc:14107
+#, gcc-internal-format
+msgid "%<TYPE_MAIN_VARIANT%> has different %<TYPE_MAIN_VARIANT%>"
+msgstr ""
+
+#: tree.cc:14118
+#, gcc-internal-format
+msgid "%<TYPE_CANONICAL%> has different %<TYPE_CANONICAL%>"
+msgstr ""
+
+#: tree.cc:14137
+#, gcc-internal-format
+msgid "%<TYPE_CANONICAL%> is not compatible"
+msgstr ""
+
+#: tree.cc:14145
+#, gcc-internal-format
+msgid "%<TYPE_MODE%> of %<TYPE_CANONICAL%> is not compatible"
+msgstr ""
+
+#: tree.cc:14151
+#, gcc-internal-format
+msgid "%<TYPE_CANONICAL%> of main variant is not main variant"
+msgstr ""
+
+#: tree.cc:14167
+#, gcc-internal-format
+msgid "%<TYPE_VFIELD%> is not %<FIELD_DECL%> nor %<TREE_LIST%>"
+msgstr ""
+
+#: tree.cc:14177
+#, gcc-internal-format
+msgid "%<TYPE_NEXT_PTR_TO%> is not %<POINTER_TYPE%>"
+msgstr ""
+
+#: tree.cc:14187
+#, gcc-internal-format
+msgid "%<TYPE_NEXT_REF_TO%> is not %<REFERENCE_TYPE%>"
+msgstr ""
+
+#: tree.cc:14208
+#, gcc-internal-format
+msgid "%<TYPE_BINFO%> is not %<TREE_BINFO%>"
+msgstr ""
+
+#: tree.cc:14214
+#, gcc-internal-format
+msgid "%<TYPE_BINFO%> type is not %<TYPE_MAIN_VARIANT%>"
+msgstr ""
+
+#: tree.cc:14225
+#, gcc-internal-format
+msgid "%<TYPE_METHOD_BASETYPE%> is not record nor union"
+msgstr ""
+
+#: tree.cc:14236
+#, gcc-internal-format
+msgid "%<TYPE_OFFSET_BASETYPE%> is not record nor union"
+msgstr ""
+
+#: tree.cc:14254
+#, gcc-internal-format
+msgid "%<TYPE_ARRAY_MAX_SIZE%> not %<INTEGER_CST%>"
+msgstr ""
+
+#: tree.cc:14261
+#, gcc-internal-format
+msgid "%<TYPE_MAX_VALUE_RAW%> non-NULL"
+msgstr ""
+
+#: tree.cc:14268
+#, gcc-internal-format
+msgid "%<TYPE_LANG_SLOT_1 (binfo)%> field is non-NULL"
+msgstr ""
+
+#: tree.cc:14284
+#, gcc-internal-format
+msgid "enum value is not %<CONST_DECL%> or %<INTEGER_CST%>"
+msgstr ""
+
+#: tree.cc:14293
+#, gcc-internal-format
+msgid "enum value type is not %<INTEGER_TYPE%> nor convertible to the enum"
+msgstr ""
+
+#: tree.cc:14301
+#, gcc-internal-format
+msgid "enum value name is not %<IDENTIFIER_NODE%>"
+msgstr ""
+
+#: tree.cc:14311
+#, gcc-internal-format
+msgid "array %<TYPE_DOMAIN%> is not integer type"
+msgstr ""
+
+#: tree.cc:14320
+#, gcc-internal-format
+msgid "%<TYPE_FIELDS%> defined in incomplete type"
+msgstr ""
+
+#: tree.cc:14342
+#, gcc-internal-format
+msgid "wrong tree in %<TYPE_FIELDS%> list"
+msgstr ""
+
+#: tree.cc:14358
+#, gcc-internal-format
+msgid "%<TYPE_CACHED_VALUES_P%> is %i while %<TYPE_CACHED_VALUES%> is %p"
+msgstr ""
+
+#: tree.cc:14365
+#, gcc-internal-format
+msgid "%<TYPE_CACHED_VALUES%> is not %<TREE_VEC%>"
+msgstr ""
+
+#: tree.cc:14378
+#, gcc-internal-format
+msgid "wrong %<TYPE_CACHED_VALUES%> entry"
+msgstr ""
+
+#: tree.cc:14391
+#, gcc-internal-format
+msgid "%<TREE_PURPOSE%> is non-NULL in %<TYPE_ARG_TYPES%> list"
+msgstr ""
+
+#: tree.cc:14397
+#, gcc-internal-format
+msgid "wrong entry in %<TYPE_ARG_TYPES%> list"
+msgstr ""
+
+#: tree.cc:14404
+#, gcc-internal-format
+msgid "%<TYPE_VALUES_RAW%> field is non-NULL"
+msgstr ""
+
+#: tree.cc:14417
+#, gcc-internal-format
+msgid "%<TYPE_CACHED_VALUES_P%> is set while it should not be"
+msgstr ""
+
+#: tree.cc:14427
+#, gcc-internal-format
+msgid "%<TYPE_METHOD_BASETYPE%> is not main variant"
+msgstr ""
+
+#: tsan.cc:509
+#, gcc-internal-format
+msgid "%qs is not supported with %qs"
+msgstr ""
+
+#: value-prof.cc:488
+#, gcc-internal-format
+msgid "dead histogram"
+msgstr ""
+
+#: value-prof.cc:517
+#, gcc-internal-format
+msgid "histogram value statement does not correspond to the statement it is associated with"
+msgstr ""
+
+#: value-prof.cc:586
+#, gcc-internal-format, gfc-internal-format
+msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
+msgstr ""
+
+#: var-tracking.cc:7194
+#, gcc-internal-format
+msgid "variable tracking size limit exceeded with %<-fvar-tracking-assignments%>, retrying without"
+msgstr ""
+
+#: var-tracking.cc:7198
+#, gcc-internal-format
+msgid "variable tracking size limit exceeded"
+msgstr ""
+
+#: varasm.cc:312
+#, gcc-internal-format
+msgid "section already exists: %qs"
+msgstr ""
+
+#: varasm.cc:358
+#, gcc-internal-format
+msgid "%+qD causes a section type conflict with %qD"
+msgstr ""
+
+#: varasm.cc:361
+#, gcc-internal-format
+msgid "section type conflict with %qD"
+msgstr ""
+
+#: varasm.cc:366
+#, gcc-internal-format
+msgid "%+qD causes a section type conflict"
+msgstr ""
+
+#: varasm.cc:368
+#, gcc-internal-format
+msgid "section type conflict"
+msgstr ""
+
+#: varasm.cc:1101
+#, gcc-internal-format
+msgid "alignment of %q+D is greater than maximum object file alignment %d"
+msgstr ""
+
+#: varasm.cc:1269
+#, gcc-internal-format
+msgid "only zero initializers are allowed in section %qs"
+msgstr ""
+
+#: varasm.cc:1499 varasm.cc:1508 d/d-attribs.cc:1463
+#, gcc-internal-format
+msgid "register name not specified for %q+D"
+msgstr ""
+
+#: varasm.cc:1510
+#, gcc-internal-format
+msgid "invalid register name for %q+D"
+msgstr ""
+
+#: varasm.cc:1512
+#, gcc-internal-format
+msgid "data type of %q+D isn%'t suitable for a register"
+msgstr ""
+
+#: varasm.cc:1515
+#, gcc-internal-format
+msgid "the register specified for %q+D cannot be accessed by the current target"
+msgstr ""
+
+#: varasm.cc:1518
+#, gcc-internal-format
+msgid "the register specified for %q+D is not general enough to be used as a register variable"
+msgstr ""
+
+#: varasm.cc:1521
+#, gcc-internal-format
+msgid "register specified for %q+D isn%'t suitable for data type"
+msgstr ""
+
+#: varasm.cc:1530
+#, gcc-internal-format
+msgid "register specified for %q+D is an internal GCC implementation detail"
+msgstr ""
+
+#: varasm.cc:1540
+#, gcc-internal-format
+msgid "global register variable has initial value"
+msgstr ""
+
+#: varasm.cc:1544
+#, gcc-internal-format
+msgid "optimization may eliminate reads and/or writes to register variables"
+msgstr ""
+
+#: varasm.cc:1590
+#, gcc-internal-format
+msgid "register name given for non-register variable %q+D"
+msgstr ""
+
+#: varasm.cc:2198
+#, gcc-internal-format
+msgid "thread-local COMMON data not implemented"
+msgstr ""
+
+#: varasm.cc:2231
+#, gcc-internal-format
+msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
+msgstr ""
+
+#: varasm.cc:2334 c/c-decl.cc:5903 c/c-parser.cc:1910 m2/gm2-gcc/m2type.cc:1240
+#, gcc-internal-format
+msgid "storage size of %q+D isn%'t known"
+msgstr ""
+
+#: varasm.cc:5319 varasm.cc:5358
+#, gcc-internal-format
+msgid "initializer for integer/fixed-point value is too complicated"
+msgstr ""
+
+#: varasm.cc:5325
+#, gcc-internal-format
+msgid "initializer for floating value is not a floating constant"
+msgstr ""
+
+#: varasm.cc:5342
+#, gcc-internal-format
+msgid "initializer for %<_BitInt(%d)%> value is not an integer constant"
+msgstr ""
+
+#: varasm.cc:5725
+#, gcc-internal-format
+msgid "invalid initial value for member %qE"
+msgstr ""
+
+#: varasm.cc:5981
+#, gcc-internal-format
+msgid "%qD declared weak after being used"
+msgstr ""
+
+#: varasm.cc:6033
+#, gcc-internal-format
+msgid "weak declaration of %q+D being applied to a already existing, static definition"
+msgstr ""
+
+#: varasm.cc:6074
+#, gcc-internal-format
+msgid "weak declaration of %q+D must be public"
+msgstr ""
+
+#: varasm.cc:6078
+#, gcc-internal-format
+msgid "weak declaration of %q+D not supported"
+msgstr ""
+
+#: varasm.cc:6107 varasm.cc:6430
+#, gcc-internal-format
+msgid "only weak aliases are supported in this configuration"
+msgstr ""
+
+#: varasm.cc:6302 varasm.cc:6427
+#, gcc-internal-format
+msgid "%qs is not supported in this configuration"
+msgstr ""
+
+#: varasm.cc:6330
+#, gcc-internal-format
+msgid "%qs is not supported on this target"
+msgstr ""
+
+#: varasm.cc:6390
+#, gcc-internal-format
+msgid "symver is only supported on ELF platforms"
+msgstr ""
+
+#: varasm.cc:6409
+#, gcc-internal-format
+msgid "%qs symbol %q+D ultimately targets itself"
+msgstr ""
+
+#: varasm.cc:6411
+#, gcc-internal-format
+msgid "%qs symbol %q+D must have static linkage"
+msgstr ""
+
+#: varasm.cc:6417 config/nvptx/nvptx.cc:7592
+#, gcc-internal-format
+msgid "alias definitions not supported in this configuration"
+msgstr ""
+
+#: varasm.cc:6645 config/sol2.cc:160 config/i386/winnt.cc:265
+#, gcc-internal-format
+msgid "visibility attribute not supported in this configuration; ignored"
+msgstr ""
+
+#: varasm.cc:8017
+#, gcc-internal-format
+msgid "%+qD without %<retain%> attribute and %qD with %<retain%> attribute are placed in a section with the same name"
+msgstr ""
+
+#: vec.cc:190
+#, gcc-internal-format, gfc-internal-format
+msgid "qsort comparator not anti-symmetric: %d, %d"
+msgstr ""
+
+#: vec.cc:195
+#, gcc-internal-format, gfc-internal-format
+msgid "qsort comparator non-negative on sorted output: %d"
+msgstr ""
+
+#: vec.cc:202
+#, gcc-internal-format, gfc-internal-format
+msgid "qsort comparator not transitive: %d, %d, %d"
+msgstr ""
+
+#: vec.cc:204
+#, gcc-internal-format
+msgid "qsort checking failed"
+msgstr ""
+
+#: c-family/c-ada-spec.cc:2946
+#, gcc-internal-format
+msgid "packed layout"
+msgstr ""
+
+#: c-family/c-attribs.cc:696 d/d-attribs.cc:1195
+#, gcc-internal-format
+msgid "%qE attribute argument is invalid"
+msgstr ""
+
+#: c-family/c-attribs.cc:699 d/d-attribs.cc:1198
+#, gcc-internal-format
+msgid "%qE attribute argument %i is invalid"
+msgstr ""
+
+#: c-family/c-attribs.cc:711 d/d-attribs.cc:1210
+#, gcc-internal-format
+msgid "%qE attribute argument has type %qT"
+msgstr ""
+
+#: c-family/c-attribs.cc:715 d/d-attribs.cc:1214
+#, gcc-internal-format
+msgid "%qE attribute argument %i has type %qT"
+msgstr ""
+
+#: c-family/c-attribs.cc:726 c-family/c-attribs.cc:4646
+#: c-family/c-attribs.cc:4650 d/d-attribs.cc:1225
+#, gcc-internal-format
+msgid "%qE attribute argument value %qE is not an integer constant"
+msgstr ""
+
+#: c-family/c-attribs.cc:731 d/d-attribs.cc:1230
+#, gcc-internal-format
+msgid "%qE attribute argument %i value %qE is not an integer constant"
+msgstr ""
+
+#: c-family/c-attribs.cc:747 d/d-attribs.cc:1244
+#, gcc-internal-format
+msgid "%qE attribute argument value %qE does not refer to a function parameter"
+msgstr ""
+
+#: c-family/c-attribs.cc:752 d/d-attribs.cc:1249
+#, gcc-internal-format
+msgid "%qE attribute argument %i value %qE does not refer to a function parameter"
+msgstr ""
+
+#: c-family/c-attribs.cc:780 d/d-attribs.cc:1272
+#, gcc-internal-format
+msgid "%qE attribute argument value %qE exceeds the number of function parameters %u"
+msgstr ""
+
+#: c-family/c-attribs.cc:785 d/d-attribs.cc:1277
+#, gcc-internal-format
+msgid "%qE attribute argument %i value %qE exceeds the number of function parameters %u"
+msgstr ""
+
+#: c-family/c-attribs.cc:807
+#, gcc-internal-format
+msgid "%qE attribute argument value %qE does not refer to a variable argument list"
+msgstr ""
+
+#: c-family/c-attribs.cc:811
+#, gcc-internal-format
+msgid "%qE attribute argument %i value %qE does not refer to a variable argument list"
+msgstr ""
+
+#: c-family/c-attribs.cc:838 c-family/c-attribs.cc:851 d/d-attribs.cc:1298
+#, gcc-internal-format
+msgid "%qE attribute argument value %qE refers to parameter type %qT"
+msgstr ""
+
+#: c-family/c-attribs.cc:842 c-family/c-attribs.cc:856 d/d-attribs.cc:1303
+#, gcc-internal-format
+msgid "%qE attribute argument %i value %qE refers to parameter type %qT"
+msgstr ""
+
+#: c-family/c-attribs.cc:866
+#, gcc-internal-format
+msgid "%qE attribute argument value %qE refers to a variadic function parameter of unknown type"
+msgstr ""
+
+#: c-family/c-attribs.cc:871
+#, gcc-internal-format
+msgid "%qE attribute argument %i value %qE refers to a variadic function parameter of unknown type"
+msgstr ""
+
+#: c-family/c-attribs.cc:991
+#, gcc-internal-format
+msgid "ignoring attribute %qs because it conflicts with previous %qs"
+msgstr ""
+
+#: c-family/c-attribs.cc:1029
+#, gcc-internal-format
+msgid "%qE attribute only supported on boolean types"
+msgstr ""
+
+#: c-family/c-attribs.cc:1039
+#, gcc-internal-format
+msgid "%qE attribute with unsupported boolean precision"
+msgstr ""
+
+#: c-family/c-attribs.cc:1059
+#, gcc-internal-format
+msgid "%qE attribute only supported in C"
+msgstr ""
+
+#: c-family/c-attribs.cc:1066
+#, gcc-internal-format
+msgid "%qE attribute only supported on integral types"
+msgstr ""
+
+#: c-family/c-attribs.cc:1087 c-family/c-attribs.cc:1103
+#, gcc-internal-format
+msgid "overflows in conversion from %qT to %qT changes value from %qE to %qE"
+msgstr ""
+
+#: c-family/c-attribs.cc:1112
+#, gcc-internal-format
+msgid "%qE attribute requires different values for %<false%> and %<true%> for type %qT"
+msgstr ""
+
+#: c-family/c-attribs.cc:1152
+#, gcc-internal-format
+msgid "%qE attribute ignored for type %qT"
+msgstr ""
+
+#: c-family/c-attribs.cc:1164
+#, gcc-internal-format
+msgid "%qE attribute ignored for field of type %qT"
+msgstr ""
+
+#: c-family/c-attribs.cc:1380 c-family/c-attribs.cc:3509
+#: c-family/c-attribs.cc:6039 ada/gcc-interface/utils.cc:7283
+#, gcc-internal-format
+msgid "%qE argument not a string"
+msgstr ""
+
+#: c-family/c-attribs.cc:1555 ada/gcc-interface/utils.cc:6793
+#, gcc-internal-format
+msgid "%qE attribute ignored because of argument %qE"
+msgstr ""
+
+#: c-family/c-attribs.cc:1576 ada/gcc-interface/utils.cc:6814
+#, gcc-internal-format
+msgid "ignoring attribute %qE because of excess arguments starting at %qE"
+msgstr ""
+
+#: c-family/c-attribs.cc:1590 ada/gcc-interface/utils.cc:6828
+#, gcc-internal-format
+msgid "attribute %qE does not apply to elements of non-scalar type %qT"
+msgstr ""
+
+#: c-family/c-attribs.cc:1595 ada/gcc-interface/utils.cc:6833
+#, gcc-internal-format
+msgid "attribute %qE does not apply to fields of aggregate type %qT"
+msgstr ""
+
+#: c-family/c-attribs.cc:1661
+#, gcc-internal-format
+msgid "%qE attribute ignored. Use %<-fcf-protection%> option to enable it"
+msgstr ""
+
+#: c-family/c-attribs.cc:1751 jit/dummy-frontend.cc:275 lto/lto-lang.cc:307
+#, gcc-internal-format
+msgid "%qE attribute has no effect on unit local functions"
+msgstr ""
+
+#: c-family/c-attribs.cc:1921 c-family/c-attribs.cc:3492
+#, gcc-internal-format
+msgid "%qE attribute ignored because %qD is not a variable"
+msgstr ""
+
+#: c-family/c-attribs.cc:1927
+#, gcc-internal-format
+msgid "%qE attribute ignored because %qD is not a local variable"
+msgstr ""
+
+#: c-family/c-attribs.cc:1952 config/i386/i386-options.cc:4191
+#, gcc-internal-format
+msgid "%qE attribute have effect only on public objects"
+msgstr ""
+
+#: c-family/c-attribs.cc:1981
+#, gcc-internal-format
+msgid "%qE attribute only affects top level objects"
+msgstr ""
+
+#: c-family/c-attribs.cc:2020 c-family/c-attribs.cc:4166
+#, gcc-internal-format
+msgid "%qE attribute on function returning %<void%>"
+msgstr ""
+
+#: c-family/c-attribs.cc:2043
+#, gcc-internal-format
+msgid "%qE attribute is not supported because endianness is not uniform"
+msgstr ""
+
+#: c-family/c-attribs.cc:2060
+#, gcc-internal-format
+msgid "attribute %qE argument must be one of %qs or %qs"
+msgstr ""
+
+#: c-family/c-attribs.cc:2156
+#, gcc-internal-format
+msgid "destructor priorities are not supported"
+msgstr ""
+
+#: c-family/c-attribs.cc:2158
+#, gcc-internal-format
+msgid "constructor priorities are not supported"
+msgstr ""
+
+#: c-family/c-attribs.cc:2180
+#, gcc-internal-format, gfc-internal-format
+msgid "destructor priorities from 0 to %d are reserved for the implementation"
+msgstr ""
+
+#: c-family/c-attribs.cc:2185
+#, gcc-internal-format, gfc-internal-format
+msgid "constructor priorities from 0 to %d are reserved for the implementation"
+msgstr ""
+
+#: c-family/c-attribs.cc:2193
+#, gcc-internal-format, gfc-internal-format
+msgid "destructor priorities must be integers from 0 to %d inclusive"
+msgstr ""
+
+#: c-family/c-attribs.cc:2196
+#, gcc-internal-format, gfc-internal-format
+msgid "constructor priorities must be integers from 0 to %d inclusive"
+msgstr ""
+
+#: c-family/c-attribs.cc:2349
+#, gcc-internal-format
+msgid "unknown machine mode %qE"
+msgstr ""
+
+#: c-family/c-attribs.cc:2383
+#, gcc-internal-format
+msgid "specifying vector types with %<__attribute__ ((mode))%> is deprecated"
+msgstr ""
+
+#: c-family/c-attribs.cc:2386
+#, gcc-internal-format
+msgid "use %<__attribute__ ((vector_size))%> instead"
+msgstr ""
+
+#: c-family/c-attribs.cc:2395
+#, gcc-internal-format
+msgid "unable to emulate %qs"
+msgstr ""
+
+#: c-family/c-attribs.cc:2408
+#, gcc-internal-format
+msgid "invalid pointer mode %qs"
+msgstr ""
+
+#: c-family/c-attribs.cc:2425
+#, gcc-internal-format
+msgid "signedness of type and machine mode %qs don%'t match"
+msgstr ""
+
+#: c-family/c-attribs.cc:2436
+#, gcc-internal-format
+msgid "no data type for mode %qs"
+msgstr ""
+
+#: c-family/c-attribs.cc:2446
+#, gcc-internal-format
+msgid "cannot use mode %qs for enumerated types"
+msgstr ""
+
+#: c-family/c-attribs.cc:2474
+#, gcc-internal-format
+msgid "mode %qs applied to inappropriate type"
+msgstr ""
+
+#: c-family/c-attribs.cc:2503 c-family/c-attribs.cc:2860 d/d-attribs.cc:1024
+#, gcc-internal-format
+msgid "section attributes are not supported for this target"
+msgstr ""
+
+#: c-family/c-attribs.cc:2509 d/d-attribs.cc:1031
+#, gcc-internal-format
+msgid "section attribute not allowed for %q+D"
+msgstr ""
+
+#: c-family/c-attribs.cc:2515
+#, gcc-internal-format
+msgid "section attribute argument not a string constant"
+msgstr ""
+
+#: c-family/c-attribs.cc:2524 d/d-attribs.cc:1047
+#, gcc-internal-format
+msgid "section attribute cannot be specified for local variables"
+msgstr ""
+
+#: c-family/c-attribs.cc:2535 config/bfin/bfin.cc:4797 config/bfin/bfin.cc:4848
+#: config/bfin/bfin.cc:4874 config/bfin/bfin.cc:4887 d/d-attribs.cc:1058
+#, gcc-internal-format
+msgid "section of %q+D conflicts with previous declaration"
+msgstr ""
+
+#: c-family/c-attribs.cc:2544 c-family/c-attribs.cc:2886 d/d-attribs.cc:1067
+#, gcc-internal-format
+msgid "section of %q+D cannot be overridden"
+msgstr ""
+
+#: c-family/c-attribs.cc:2660
+#, gcc-internal-format
+msgid "alignment may not be specified for %q+D"
+msgstr ""
+
+#: c-family/c-attribs.cc:2685
+#, gcc-internal-format
+msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
+msgstr ""
+
+#: c-family/c-attribs.cc:2730
+#, gcc-internal-format
+msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
+msgstr ""
+
+#: c-family/c-attribs.cc:2781
+#, gcc-internal-format
+msgid "%qE attribute may not be specified for %q+D"
+msgstr ""
+
+#: c-family/c-attribs.cc:2788
+#, gcc-internal-format
+msgid "%qE attribute may not be specified for a non-array field"
+msgstr ""
+
+#: c-family/c-attribs.cc:2795
+#, gcc-internal-format
+msgid "%qE attribute argument not an integer"
+msgstr ""
+
+#: c-family/c-attribs.cc:2801 c-family/c-attribs.cc:6235
+#, gcc-internal-format
+msgid "%qE attribute argument %qE is not an integer constant between 0 and 3"
+msgstr ""
+
+#: c-family/c-attribs.cc:2821 d/d-attribs.cc:1146 jit/dummy-frontend.cc:743
+#, gcc-internal-format
+msgid "inline function %q+D declared weak"
+msgstr ""
+
+#: c-family/c-attribs.cc:2826 jit/dummy-frontend.cc:748
+#, gcc-internal-format
+msgid "indirect function %q+D cannot be declared weak"
+msgstr ""
+
+#: c-family/c-attribs.cc:2867
+#, gcc-internal-format
+msgid "ignoring %qE attribute not set on a variable"
+msgstr ""
+
+#: c-family/c-attribs.cc:2877 config/bfin/bfin.cc:4825
+#: config/loongarch/loongarch.cc:7963
+#, gcc-internal-format
+msgid "%qE attribute cannot be specified for local variables"
+msgstr ""
+
+#: c-family/c-attribs.cc:2892
+#, gcc-internal-format
+msgid "%qE attribute is specific to ELF targets"
+msgstr ""
+
+#: c-family/c-attribs.cc:2899
+#, gcc-internal-format
+msgid "ignoring %qE attribute set on const variable"
+msgstr ""
+
+#: c-family/c-attribs.cc:2910
+#, gcc-internal-format
+msgid "ignoring %qE attribute set on initialized variable"
+msgstr ""
+
+#: c-family/c-attribs.cc:2923
+#, gcc-internal-format
+msgid "ignoring %qE attribute set on uninitialized variable"
+msgstr ""
+
+#: c-family/c-attribs.cc:2956
+#, gcc-internal-format
+msgid "%qE attribute is only applicable on functions"
+msgstr ""
+
+#: c-family/c-attribs.cc:2975 d/d-attribs.cc:1094
+#, gcc-internal-format
+msgid "%<symver%> attribute only applies to functions and variables"
+msgstr ""
+
+#: c-family/c-attribs.cc:2983 d/d-attribs.cc:1102
+#, gcc-internal-format
+msgid "%<symver%> attribute is only applicable to symbols"
+msgstr ""
+
+#: c-family/c-attribs.cc:2993
+#, gcc-internal-format
+msgid "%<symver%> attribute argument not a string constant"
+msgstr ""
+
+#: c-family/c-attribs.cc:3007 d/d-attribs.cc:1126
+#, gcc-internal-format
+msgid "symver attribute argument must have format %<name@nodename%>"
+msgstr ""
+
+#: c-family/c-attribs.cc:3008 d/d-attribs.cc:1127
+#, gcc-internal-format
+msgid "%<symver%> attribute argument %qs must contain one or two %<@%>"
+msgstr ""
+
+#: c-family/c-attribs.cc:3043 jit/dummy-frontend.cc:843
+#, gcc-internal-format
+msgid "%q+D defined both normally and as %qE attribute"
+msgstr ""
+
+#: c-family/c-attribs.cc:3051 jit/dummy-frontend.cc:851
+#, gcc-internal-format
+msgid "weak %q+D cannot be defined %qE"
+msgstr ""
+
+#: c-family/c-attribs.cc:3068 c-family/c-attribs.cc:4057
+#: ada/gcc-interface/utils.cc:7110 jit/dummy-frontend.cc:868
+#, gcc-internal-format
+msgid "attribute %qE argument not a string"
+msgstr ""
+
+#: c-family/c-attribs.cc:3101 jit/dummy-frontend.cc:901
+#, gcc-internal-format
+msgid "%+qD declared %qs after being used"
+msgstr ""
+
+#. Explicitly handle this case since using a string literal
+#. as an argument is a likely mistake.
+#: c-family/c-attribs.cc:3153
+#, gcc-internal-format
+msgid "%qE attribute argument cannot be a string"
+msgstr ""
+
+#. Similar to the string case, since some function attributes
+#. accept literal numbers as arguments (e.g., alloc_size or
+#. nonnull) using one here is a likely mistake.
+#: c-family/c-attribs.cc:3164
+#, gcc-internal-format
+msgid "%qE attribute argument cannot be a constant arithmetic expression"
+msgstr ""
+
+#: c-family/c-attribs.cc:3174
+#, gcc-internal-format
+msgid "%qE attribute ignored on a redeclaration of the referenced symbol"
+msgstr ""
+
+#: c-family/c-attribs.cc:3229
+#, gcc-internal-format
+msgid "%qE attribute ignored on a declaration of a different kind than referenced symbol"
+msgstr ""
+
+#: c-family/c-attribs.cc:3233
+#, gcc-internal-format
+msgid "symbol %qD referenced by %qD declared here"
+msgstr ""
+
+#: c-family/c-attribs.cc:3280
+#, gcc-internal-format
+msgid "%qE attribute must apply to a declaration"
+msgstr ""
+
+#: c-family/c-attribs.cc:3337
+#, gcc-internal-format
+msgid "indirect function %q+D cannot be declared %qE"
+msgstr ""
+
+#: c-family/c-attribs.cc:3360
+#, gcc-internal-format
+msgid "%qE attribute must appear before %qs attribute"
+msgstr ""
+
+#: c-family/c-attribs.cc:3373
+#, gcc-internal-format
+msgid "%+qD declared %qE after being used"
+msgstr ""
+
+#: c-family/c-attribs.cc:3397 jit/dummy-frontend.cc:586
+#, gcc-internal-format
+msgid "%qE attribute ignored on non-class types"
+msgstr ""
+
+#: c-family/c-attribs.cc:3403 jit/dummy-frontend.cc:592
+#, gcc-internal-format
+msgid "%qE attribute ignored because %qT is already defined"
+msgstr ""
+
+#: c-family/c-attribs.cc:3416 jit/dummy-frontend.cc:605
+#, gcc-internal-format
+msgid "visibility argument not a string"
+msgstr ""
+
+#: c-family/c-attribs.cc:3428 d/d-attribs.cc:1584 jit/dummy-frontend.cc:617
+#, gcc-internal-format
+msgid "%qE attribute ignored on types"
+msgstr ""
+
+#: c-family/c-attribs.cc:3444 d/d-attribs.cc:1613 jit/dummy-frontend.cc:633
+#, gcc-internal-format
+msgid "attribute %qE argument must be one of %qs, %qs, %qs, or %qs"
+msgstr ""
+
+#: c-family/c-attribs.cc:3456 d/d-attribs.cc:1624 jit/dummy-frontend.cc:645
+#, gcc-internal-format
+msgid "%qD redeclared with different visibility"
+msgstr ""
+
+#: c-family/c-attribs.cc:3459 c-family/c-attribs.cc:3463 d/d-attribs.cc:1627
+#: d/d-attribs.cc:1631 jit/dummy-frontend.cc:648 jit/dummy-frontend.cc:652
+#, gcc-internal-format
+msgid "%qD was declared %qs which implies default visibility"
+msgstr ""
+
+#: c-family/c-attribs.cc:3500
+#, gcc-internal-format
+msgid "%qE attribute ignored because %qD does not have thread storage duration"
+msgstr ""
+
+#: c-family/c-attribs.cc:3522
+#, gcc-internal-format
+msgid "%qE argument must be one of %qs, %qs, %qs, or %qs"
+msgstr ""
+
+#: c-family/c-attribs.cc:3544 c-family/c-attribs.cc:4140
+#: c-family/c-attribs.cc:6004 c-family/c-attribs.cc:6031
+#: config/m32c/m32c.cc:2942 ada/gcc-interface/utils.cc:7269
+#, gcc-internal-format
+msgid "%qE attribute applies only to functions"
+msgstr ""
+
+#: c-family/c-attribs.cc:3590
+#, gcc-internal-format
+msgid "%<%E (%E)%> attribute ignored on functions declared %qs"
+msgstr ""
+
+#: c-family/c-attribs.cc:3600
+#, gcc-internal-format
+msgid "%<%E (%E)%> attribute ignored with deallocation functions declared %qs"
+msgstr ""
+
+#: c-family/c-attribs.cc:3604
+#, gcc-internal-format
+msgid "deallocation function declared here"
+msgstr ""
+
+#: c-family/c-attribs.cc:3631
+#, gcc-internal-format
+msgid "%qE attribute ignored; valid only for functions"
+msgstr ""
+
+#: c-family/c-attribs.cc:3641
+#, gcc-internal-format
+msgid "%qE attribute ignored on functions returning %qT; valid only for pointer return types"
+msgstr ""
+
+#. Handle specially the common case of specifying one of a number
+#. of overloads, such as operator delete.
+#: c-family/c-attribs.cc:3687
+#, gcc-internal-format
+msgid "%qE attribute argument 1 is ambiguous"
+msgstr ""
+
+#: c-family/c-attribs.cc:3689
+#, gcc-internal-format
+msgid "use a cast to the expected type to disambiguate"
+msgstr ""
+
+#: c-family/c-attribs.cc:3694
+#, gcc-internal-format
+msgid "%qE attribute argument 1 does not name a function"
+msgstr ""
+
+#: c-family/c-attribs.cc:3697
+#, gcc-internal-format
+msgid "argument references a symbol declared here"
+msgstr ""
+
+#. Reject functions without a prototype.
+#: c-family/c-attribs.cc:3713
+#, gcc-internal-format
+msgid "%qE attribute argument 1 must take a pointer type as its first argument"
+msgstr ""
+
+#: c-family/c-attribs.cc:3716 c-family/c-attribs.cc:3729
+#, gcc-internal-format
+msgid "referenced symbol declared here"
+msgstr ""
+
+#. Reject functions that don't take a pointer as their first
+#. argument.
+#: c-family/c-attribs.cc:3726
+#, gcc-internal-format
+msgid "%qE attribute argument 1 must take a pointer type as its first argument; have %qT"
+msgstr ""
+
+#: c-family/c-attribs.cc:3840 c-family/c-attribs.cc:3888
+#: c-family/c-attribs.cc:3915 d/d-attribs.cc:1329
+#, gcc-internal-format
+msgid "%qE attribute ignored on a function returning %qT"
+msgstr ""
+
+#: c-family/c-attribs.cc:3934
+#, gcc-internal-format
+msgid "%qE attribute argument %E is not an integer constant"
+msgstr ""
+
+#: c-family/c-attribs.cc:3942
+#, gcc-internal-format
+msgid "%qE attribute argument %E is not positive"
+msgstr ""
+
+#: c-family/c-attribs.cc:3953
+#, gcc-internal-format
+msgid "%qE attribute argument %E is not a power of 2"
+msgstr ""
+
+#: c-family/c-attribs.cc:3966
+#, gcc-internal-format
+msgid "%qE attribute argument %E is not in the range [0, %wu]"
+msgstr ""
+
+#: c-family/c-attribs.cc:4070 ada/gcc-interface/utils.cc:7123
+#, gcc-internal-format
+msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
+msgstr ""
+
+#: c-family/c-attribs.cc:4146 c-family/c-attribs.cc:6010
+#, gcc-internal-format
+msgid "cannot set %qE attribute after definition"
+msgstr ""
+
+#: c-family/c-attribs.cc:4213
+#, gcc-internal-format
+msgid "%qE attribute duplicated"
+msgstr ""
+
+#: c-family/c-attribs.cc:4215
+#, gcc-internal-format
+msgid "%qE attribute follows %qE"
+msgstr ""
+
+#: c-family/c-attribs.cc:4314
+#, gcc-internal-format
+msgid "type was previously declared %qE"
+msgstr ""
+
+#: c-family/c-attribs.cc:4327 cp/class.cc:5054
+#, gcc-internal-format
+msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
+msgstr ""
+
+#: c-family/c-attribs.cc:4385
+#, gcc-internal-format
+msgid "%qE argument not an identifier"
+msgstr ""
+
+#: c-family/c-attribs.cc:4396
+#, gcc-internal-format
+msgid "%qD is not compatible with %qD"
+msgstr ""
+
+#: c-family/c-attribs.cc:4399
+#, gcc-internal-format
+msgid "%qE argument is not a function"
+msgstr ""
+
+#: c-family/c-attribs.cc:4447 cp/name-lookup.cc:6468
+#, gcc-internal-format
+msgid "deprecated message is not a string"
+msgstr ""
+
+#: c-family/c-attribs.cc:4496 c-family/c-attribs.cc:4561
+#, gcc-internal-format
+msgid "%qE attribute ignored for %qE"
+msgstr ""
+
+#: c-family/c-attribs.cc:4520
+#, gcc-internal-format
+msgid "the message attached to %<unavailable%> is not a string"
+msgstr ""
+
+#: c-family/c-attribs.cc:4622 c-family/c-attribs.cc:4624
+#, gcc-internal-format
+msgid "invalid vector type for attribute %qE"
+msgstr ""
+
+#: c-family/c-attribs.cc:4659 c-family/c-attribs.cc:4663
+#, gcc-internal-format
+msgid "%qE attribute argument value %qE is negative"
+msgstr ""
+
+#: c-family/c-attribs.cc:4676 c-family/c-attribs.cc:4680
+#, gcc-internal-format
+msgid "%qE attribute argument value %qE exceeds %wu"
+msgstr ""
+
+#: c-family/c-attribs.cc:4688 ada/gcc-interface/utils.cc:4300
+#, gcc-internal-format
+msgid "vector size not an integral multiple of component size"
+msgstr ""
+
+#: c-family/c-attribs.cc:4694 ada/gcc-interface/utils.cc:4307
+#, gcc-internal-format
+msgid "zero vector size"
+msgstr ""
+
+#: c-family/c-attribs.cc:4703 c-family/c-attribs.cc:4706
+#, gcc-internal-format
+msgid "number of vector components %wu not a power of two"
+msgstr ""
+
+#: c-family/c-attribs.cc:4713 c-family/c-attribs.cc:4717
+#, gcc-internal-format
+msgid "number of vector components %wu exceeds %d"
+msgstr ""
+
+#: c-family/c-attribs.cc:4777
+#, gcc-internal-format
+msgid "%qE attribute only supported on non-mask vector types"
+msgstr ""
+
+#: c-family/c-attribs.cc:4810 c-family/c-attribs.cc:4850
+#, gcc-internal-format
+msgid "%qE attribute without arguments on a non-prototype"
+msgstr ""
+
+#: c-family/c-attribs.cc:4905
+#, gcc-internal-format
+msgid "%qE attribute ignored on objects of type %qT"
+msgstr ""
+
+#: c-family/c-attribs.cc:4913
+#, gcc-internal-format
+msgid "%qE attribute does not apply to functions"
+msgstr ""
+
+#: c-family/c-attribs.cc:5051
+#, gcc-internal-format
+msgid "attribute %qs mismatch with mode %qs"
+msgstr ""
+
+#: c-family/c-attribs.cc:5100
+#, gcc-internal-format
+msgid "attribute %qs missing positional argument 2 provided in previous designation by argument %u"
+msgstr ""
+
+#: c-family/c-attribs.cc:5106
+#, gcc-internal-format
+msgid "attribute %qs positional argument 2 missing in previous designation"
+msgstr ""
+
+#: c-family/c-attribs.cc:5112
+#, gcc-internal-format
+msgid "attribute %qs positional argument 2 conflicts with previous designation by argument %u"
+msgstr ""
+
+#: c-family/c-attribs.cc:5120
+#, gcc-internal-format
+msgid "attribute %qs mismatched positional argument values %i and %i"
+msgstr ""
+
+#: c-family/c-attribs.cc:5142
+#, gcc-internal-format, gfc-internal-format
+msgid "designating the bound of variable length array argument %u"
+msgstr ""
+
+#: c-family/c-attribs.cc:5225
+#, gcc-internal-format
+msgid "attribute %qE without arguments on a non-prototype"
+msgstr ""
+
+#: c-family/c-attribs.cc:5275
+#, gcc-internal-format
+msgid "attribute %qE invalid mode"
+msgstr ""
+
+#: c-family/c-attribs.cc:5284
+#, gcc-internal-format
+msgid "attribute %qE mode %qE is not an identifier; expected one of %qs, %qs, %qs, or %qs"
+msgstr ""
+
+#: c-family/c-attribs.cc:5311
+#, gcc-internal-format
+msgid "attribute %qE invalid mode %qs; expected one of %qs, %qs, %qs, or %qs"
+msgstr ""
+
+#: c-family/c-attribs.cc:5322
+#, gcc-internal-format
+msgid "attribute %qE unexpected %<(%> after mode %qs; expected a positional argument or %<)%>"
+msgstr ""
+
+#. The first positional argument is required.  It may be worth
+#. dropping the requirement at some point and having read_only
+#. apply to all const-qualified pointers and read_write or
+#. write_only to the rest.
+#: c-family/c-attribs.cc:5335
+#, gcc-internal-format
+msgid "attribute %<%E(%s)%> missing an argument"
+msgstr ""
+
+#: c-family/c-attribs.cc:5376
+#, gcc-internal-format
+msgid "attribute %<%E(%s, %E, %E)%> invalid positional argument %i"
+msgstr ""
+
+#: c-family/c-attribs.cc:5379
+#, gcc-internal-format
+msgid "attribute %<%E(%s, %E)%> invalid positional argument %i"
+msgstr ""
+
+#: c-family/c-attribs.cc:5404
+#, gcc-internal-format
+msgid "attribute %qs positional argument %i invalid value %wi"
+msgstr ""
+
+#: c-family/c-attribs.cc:5408
+#, gcc-internal-format
+msgid "attribute %qs positional argument %i value %wi exceeds number of function arguments %u"
+msgstr ""
+
+#: c-family/c-attribs.cc:5415
+#, gcc-internal-format
+msgid "attribute %qs invalid positional argument"
+msgstr ""
+
+#. The first argument must have a pointer or reference type.
+#: c-family/c-attribs.cc:5423
+#, gcc-internal-format
+msgid "attribute %qs positional argument 1 references non-pointer argument type %qT"
+msgstr ""
+
+#: c-family/c-attribs.cc:5434
+#, gcc-internal-format
+msgid "attribute %qs positional argument 1 references argument of function type %qT"
+msgstr ""
+
+#: c-family/c-attribs.cc:5447
+#, gcc-internal-format
+msgid "attribute %qs positional argument 1 references %qs-qualified argument type %qT"
+msgstr ""
+
+#: c-family/c-attribs.cc:5465
+#, gcc-internal-format
+msgid "attribute %qs positional argument 2 references non-integer argument type %qT"
+msgstr ""
+
+#: c-family/c-attribs.cc:5735
+#, gcc-internal-format
+msgid "cleanup argument not an identifier"
+msgstr ""
+
+#: c-family/c-attribs.cc:5742
+#, gcc-internal-format
+msgid "cleanup argument not a function"
+msgstr ""
+
+#: c-family/c-attribs.cc:5779
+#, gcc-internal-format
+msgid "%qE attribute requires prototypes with named arguments"
+msgstr ""
+
+#: c-family/c-attribs.cc:5787
+#, gcc-internal-format
+msgid "%qE attribute only applies to variadic functions"
+msgstr ""
+
+#: c-family/c-attribs.cc:5803 ada/gcc-interface/utils.cc:6694
+#, gcc-internal-format
+msgid "requested position is not an integer constant"
+msgstr ""
+
+#: c-family/c-attribs.cc:5811 ada/gcc-interface/utils.cc:6701
+#, gcc-internal-format
+msgid "requested position is less than zero"
+msgstr ""
+
+#: c-family/c-attribs.cc:5860 ada/gcc-interface/utils.cc:7166
+#: d/d-attribs.cc:771 jit/dummy-frontend.cc:784
+#, gcc-internal-format
+msgid "empty string in attribute %<target%>"
+msgstr ""
+
+#. The argument must be a constant string.
+#: c-family/c-attribs.cc:5901 config/sh/sh.cc:8549 d/d-attribs.cc:1038
+#: d/d-attribs.cc:1112 d/d-attribs.cc:1415 d/d-attribs.cc:1457
+#: d/d-attribs.cc:1519 d/d-attribs.cc:1598
+#, gcc-internal-format
+msgid "%qE attribute argument not a string constant"
+msgstr ""
+
+#: c-family/c-attribs.cc:6056 ada/gcc-interface/utils.cc:7300
+#, gcc-internal-format
+msgid "unrecognized %qE attribute argument %qs"
+msgstr ""
+
+#: c-family/c-attribs.cc:6074
+#, gcc-internal-format
+msgid "%qE attribute on a function not returning a pointer"
+msgstr ""
+
+#: c-family/c-attribs.cc:6089
+#, gcc-internal-format
+msgid "%qE attribute is only valid on %<struct%> type"
+msgstr ""
+
+#: c-family/c-attribs.cc:6137
+#, gcc-internal-format
+msgid "%qE attribute argument %qE is not an integer constant"
+msgstr ""
+
+#: c-family/c-attribs.cc:6146
+#, gcc-internal-format
+msgid "%qE attribute argument %qE exceeds %u"
+msgstr ""
+
+#: c-family/c-attribs.cc:6168
+#, gcc-internal-format
+msgid "%qE attribute may be put on a typedef only; attribute is ignored"
+msgstr ""
+
+#: c-family/c-attribs.cc:6180
+#, gcc-internal-format
+msgid "%qE attribute is for pointer types only"
+msgstr ""
+
+#: c-family/c-attribs.cc:6199
+#, gcc-internal-format
+msgid "%qE is only applicable to Objective-C class interfaces, attribute ignored"
+msgstr ""
+
+#: c-family/c-attribs.cc:6222
+#, gcc-internal-format
+msgid "%qE cannot be applied to non-pointer type %qT"
+msgstr ""
+
+#: c-family/c-attribs.cc:6247
+#, gcc-internal-format
+msgid "%qE attribute argument %qE is not recognized"
+msgstr ""
+
+#: c-family/c-attribs.cc:6262
+#, gcc-internal-format
+msgid "%qE attribute ignored; valid only for functions and function pointer fields"
+msgstr ""
+
+#: c-family/c-attribs.cc:6273
+#, gcc-internal-format
+msgid "%qE attribute ignored; field must be a function pointer"
+msgstr ""
+
+#: c-family/c-attribs.cc:6297
+#, gcc-internal-format
+msgid "unknown attribute %qE"
+msgstr ""
+
+#: c-family/c-attribs.cc:6324
+#, gcc-internal-format
+msgid "invalid operand type %qT for %qs"
+msgstr ""
+
+#: c-family/c-attribs.cc:6428
+#, gcc-internal-format
+msgid "%qs attribute not supported for %qT in %<__builtin_has_attribute%>"
+msgstr ""
+
+#: c-family/c-attribs.cc:6430
+#, gcc-internal-format
+msgid "%qs attribute not supported for %qE in %<__builtin_has_attribute%>"
+msgstr ""
+
+#: c-family/c-attribs.cc:6607
+#, gcc-internal-format
+msgid "%qs attribute not supported in %<__builtin_has_attribute%>"
+msgstr ""
+
+#: c-family/c-common.cc:787
+#, gcc-internal-format
+msgid "%qD is not defined outside of function scope"
+msgstr ""
+
+#: c-family/c-common.cc:832
+#, gcc-internal-format
+msgid "size of string literal is too large"
+msgstr ""
+
+#: c-family/c-common.cc:855
+#, gcc-internal-format
+msgid "string length %qd is greater than the length %qd ISO C%d compilers are required to support"
+msgstr ""
+
+#: c-family/c-common.cc:1030
+#, gcc-internal-format
+msgid "use %<-flax-vector-conversions%> to permit conversions between vectors with differing element types or numbers of subparts"
+msgstr ""
+
+#: c-family/c-common.cc:1071
+#, gcc-internal-format
+msgid "%<__builtin_shuffle%> last argument must be an integer vector"
+msgstr ""
+
+#: c-family/c-common.cc:1080
+#, gcc-internal-format
+msgid "%<__builtin_shuffle%> arguments must be vectors"
+msgstr ""
+
+#: c-family/c-common.cc:1087
+#, gcc-internal-format
+msgid "%<__builtin_shuffle%> argument vectors must be of the same type"
+msgstr ""
+
+#: c-family/c-common.cc:1098
+#, gcc-internal-format
+msgid "%<__builtin_shuffle%> number of elements of the argument vector(s) and the mask vector should be the same"
+msgstr ""
+
+#: c-family/c-common.cc:1108
+#, gcc-internal-format
+msgid "%<__builtin_shuffle%> argument vector(s) inner type must have the same size as inner type of the mask"
+msgstr ""
+
+#: c-family/c-common.cc:1159
+#, gcc-internal-format
+msgid "%<__builtin_shufflevector%> arguments must be vectors"
+msgstr ""
+
+#: c-family/c-common.cc:1170
+#, gcc-internal-format
+msgid "%<__builtin_shufflevector%> arguments must be constant size vectors"
+msgstr ""
+
+#: c-family/c-common.cc:1179
+#, gcc-internal-format
+msgid "%<__builtin_shufflevector%> argument vectors must have the same element type"
+msgstr ""
+
+#: c-family/c-common.cc:1187
+#, gcc-internal-format
+msgid "%<__builtin_shufflevector%> must specify a result with a power of two number of elements"
+msgstr ""
+
+#: c-family/c-common.cc:1212 c-family/c-common.cc:1222
+#, gcc-internal-format
+msgid "invalid element index %qE to %<__builtin_shufflevector%>"
+msgstr ""
+
+#: c-family/c-common.cc:1300
+#, gcc-internal-format
+msgid "%<__builtin_convertvector%> first argument must be an integer or floating vector"
+msgstr ""
+
+#: c-family/c-common.cc:1309
+#, gcc-internal-format
+msgid "%<__builtin_convertvector%> second argument must be an integer or floating vector type"
+msgstr ""
+
+#: c-family/c-common.cc:1318
+#, gcc-internal-format
+msgid "%<__builtin_convertvector%> number of elements of the first argument vector and the second argument vector type should be the same"
+msgstr ""
+
+#: c-family/c-common.cc:1958
+#, gcc-internal-format
+msgid "operation on %qE may be undefined"
+msgstr ""
+
+#: c-family/c-common.cc:2315
+#, gcc-internal-format
+msgid "case label does not reduce to an integer constant"
+msgstr ""
+
+#: c-family/c-common.cc:2411
+#, gcc-internal-format
+msgid "GCC cannot support operators with integer types and fixed-point types that have too many integral and fractional bits together"
+msgstr ""
+
+#: c-family/c-common.cc:2961
+#, gcc-internal-format
+msgid "invalid operands to binary %s (have %qT and %qT)"
+msgstr ""
+
+#: c-family/c-common.cc:3210
+#, gcc-internal-format
+msgid "comparison is always false due to limited range of data type"
+msgstr ""
+
+#: c-family/c-common.cc:3213
+#, gcc-internal-format
+msgid "comparison is always true due to limited range of data type"
+msgstr ""
+
+#: c-family/c-common.cc:3315
+#, gcc-internal-format
+msgid "comparison of unsigned expression in %<>= 0%> is always true"
+msgstr ""
+
+#: c-family/c-common.cc:3323
+#, gcc-internal-format
+msgid "comparison of unsigned expression in %<< 0%> is always false"
+msgstr ""
+
+#: c-family/c-common.cc:3367
+#, gcc-internal-format
+msgid "pointer of type %<void *%> used in arithmetic"
+msgstr ""
+
+#: c-family/c-common.cc:3376
+#, gcc-internal-format
+msgid "pointer to a function used in arithmetic"
+msgstr ""
+
+#: c-family/c-common.cc:3593
+#, gcc-internal-format
+msgid "enum constant in boolean context"
+msgstr ""
+
+#: c-family/c-common.cc:3623 d/d-convert.cc:149
+#, gcc-internal-format
+msgid "the address of %qD will always evaluate as %<true%>"
+msgstr ""
+
+#: c-family/c-common.cc:3668
+#, gcc-internal-format
+msgid "%<*%> in boolean context, suggest %<&&%> instead"
+msgstr ""
+
+#: c-family/c-common.cc:3681
+#, gcc-internal-format
+msgid "%<<<%> in boolean context, did you mean %<<%>?"
+msgstr ""
+
+#: c-family/c-common.cc:3697
+#, gcc-internal-format
+msgid "%<?:%> using integer constants in boolean context, the expression will always evaluate to %<true%>"
+msgstr ""
+
+#: c-family/c-common.cc:3706
+#, gcc-internal-format
+msgid "%<?:%> using integer constants in boolean context"
+msgstr ""
+
+#: c-family/c-common.cc:3742
+#, gcc-internal-format
+msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
+msgstr ""
+
+#: c-family/c-common.cc:3778 cp/semantics.cc:949
+#, gcc-internal-format
+msgid "suggest parentheses around assignment used as truth value"
+msgstr ""
+
+#: c-family/c-common.cc:3865 c/c-decl.cc:4966 c/c-decl.cc:7657
+#: c/c-parser.cc:3739 c/c-typeck.cc:16506
+#, gcc-internal-format
+msgid "invalid use of %<restrict%>"
+msgstr ""
+
+#: c-family/c-common.cc:3941
+#, gcc-internal-format
+msgid "invalid application of %<sizeof%> to a function type"
+msgstr ""
+
+#: c-family/c-common.cc:3951
+#, gcc-internal-format
+msgid "ISO C++ does not permit %<alignof%> applied to a function type"
+msgstr ""
+
+#: c-family/c-common.cc:3954
+#, gcc-internal-format
+msgid "ISO C does not permit %<_Alignof%> applied to a function type"
+msgstr ""
+
+#: c-family/c-common.cc:3965 cp/typeck.cc:2060
+#, gcc-internal-format
+msgid "invalid application of %qs to a void type"
+msgstr ""
+
+#: c-family/c-common.cc:3974
+#, gcc-internal-format
+msgid "invalid application of %qs to incomplete type %qT"
+msgstr ""
+
+#: c-family/c-common.cc:3982
+#, gcc-internal-format
+msgid "invalid application of %qs to array type %qT of incomplete element type"
+msgstr ""
+
+#: c-family/c-common.cc:4034
+#, gcc-internal-format
+msgid "%<__alignof%> applied to a bit-field"
+msgstr ""
+
+#: c-family/c-common.cc:4858
+#, gcc-internal-format
+msgid "first argument to %<va_arg%> not of type %<va_list%>"
+msgstr ""
+
+#: c-family/c-common.cc:4978
+#, gcc-internal-format
+msgid "cannot disable built-in function %qs"
+msgstr ""
+
+#: c-family/c-common.cc:5170
+#, gcc-internal-format
+msgid "pointers are not permitted as case values"
+msgstr ""
+
+#: c-family/c-common.cc:5177
+#, gcc-internal-format
+msgid "range expressions in switch statements are non-standard"
+msgstr ""
+
+#: c-family/c-common.cc:5205
+#, gcc-internal-format
+msgid "empty range specified"
+msgstr ""
+
+#: c-family/c-common.cc:5257
+#, gcc-internal-format
+msgid "duplicate (or overlapping) case value"
+msgstr ""
+
+#: c-family/c-common.cc:5259
+#, gcc-internal-format
+msgid "this is the first entry overlapping that value"
+msgstr ""
+
+#: c-family/c-common.cc:5263
+#, gcc-internal-format
+msgid "duplicate case value"
+msgstr ""
+
+#: c-family/c-common.cc:5264 c-family/c-warn.cc:2651
+#, gcc-internal-format
+msgid "previously used here"
+msgstr ""
+
+#: c-family/c-common.cc:5268
+#, gcc-internal-format
+msgid "multiple default labels in one switch"
+msgstr ""
+
+#: c-family/c-common.cc:5270
+#, gcc-internal-format
+msgid "this is the first default label"
+msgstr ""
+
+#: c-family/c-common.cc:5382
+#, gcc-internal-format
+msgid "taking the address of a label is non-standard"
+msgstr ""
+
+#: c-family/c-common.cc:5567
+#, gcc-internal-format
+msgid "requested alignment is not an integer constant"
+msgstr ""
+
+#: c-family/c-common.cc:5575 c-family/c-common.cc:5585
+#, gcc-internal-format
+msgid "requested alignment %qE is not a positive power of 2"
+msgstr ""
+
+#: c-family/c-common.cc:5595
+#, gcc-internal-format
+msgid "requested alignment %qE exceeds object file maximum %u"
+msgstr ""
+
+#: c-family/c-common.cc:5603
+#, gcc-internal-format
+msgid "requested alignment %qE exceeds maximum %u"
+msgstr ""
+
+#: c-family/c-common.cc:5778
+#, gcc-internal-format
+msgid "not enough variable arguments to fit a sentinel"
+msgstr ""
+
+#: c-family/c-common.cc:5793
+#, gcc-internal-format
+msgid "missing sentinel in function call"
+msgstr ""
+
+#: c-family/c-common.cc:6020 c-family/c-common.cc:6070 d/d-attribs.cc:837
+#: d/d-attribs.cc:887
+#, gcc-internal-format
+msgid "bad option %qs to attribute %<optimize%>"
+msgstr ""
+
+#: c-family/c-common.cc:6023 c-family/c-common.cc:6074
+#, gcc-internal-format
+msgid "bad option %qs to pragma %<optimize%>"
+msgstr ""
+
+#: c-family/c-common.cc:6122
+#, gcc-internal-format
+msgid "attribute %<fallthrough%> specified multiple times"
+msgstr ""
+
+#: c-family/c-common.cc:6126
+#, gcc-internal-format
+msgid "%<fallthrough%> attribute specified with a parameter"
+msgstr ""
+
+#: c-family/c-common.cc:6307 c-family/c-common.cc:7234
+#: c-family/c-common.cc:7281 c-family/c-common.cc:7360
+#: c-family/c-common.cc:7443 c-family/c-common.cc:8086
+#: config/aarch64/aarch64-sve-builtins.cc:3026
+#: config/arm/arm-mve-builtins.cc:1570 c/c-typeck.cc:3920
+#, gcc-internal-format
+msgid "too few arguments to function %qE"
+msgstr ""
+
+#: c-family/c-common.cc:6312 c-family/c-common.cc:7287
+#: c-family/c-common.cc:7469 c-family/c-common.cc:8088
+#: config/aarch64/aarch64-sve-builtins.cc:3028
+#: config/arm/arm-mve-builtins.cc:1572 c/c-typeck.cc:3779
+#, gcc-internal-format
+msgid "too many arguments to function %qE"
+msgstr ""
+
+#: c-family/c-common.cc:6354
+#, gcc-internal-format
+msgid "third argument to function %qE must be a constant integer"
+msgstr ""
+
+#: c-family/c-common.cc:6379
+#, gcc-internal-format
+msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
+msgstr ""
+
+#: c-family/c-common.cc:6401 c-family/c-common.cc:6448
+#, gcc-internal-format
+msgid "non-floating-point argument in call to function %qE"
+msgstr ""
+
+#: c-family/c-common.cc:6427
+#, gcc-internal-format
+msgid "non-floating-point arguments in call to function %qE"
+msgstr ""
+
+#: c-family/c-common.cc:6441
+#, gcc-internal-format
+msgid "non-const integer argument %u in call to function %qE"
+msgstr ""
+
+#: c-family/c-common.cc:6463
+#, gcc-internal-format
+msgid "non-integer argument 3 in call to function %qE"
+msgstr ""
+
+#: c-family/c-common.cc:6480 c-family/c-common.cc:6530
+#: c-family/c-common.cc:6595 c-family/c-common.cc:6615
+#, gcc-internal-format
+msgid "argument %u in call to function %qE does not have integral type"
+msgstr ""
+
+#: c-family/c-common.cc:6487
+#, gcc-internal-format
+msgid "argument 3 in call to function %qE does not have pointer to integral type"
+msgstr ""
+
+#: c-family/c-common.cc:6493
+#, gcc-internal-format
+msgid "argument 3 in call to function %qE has pointer to enumerated type"
+msgstr ""
+
+#: c-family/c-common.cc:6499
+#, gcc-internal-format
+msgid "argument 3 in call to function %qE has pointer to boolean type"
+msgstr ""
+
+#: c-family/c-common.cc:6505 c-family/c-common.cc:6512
+#: c-family/c-common.cc:6567 c-family/c-common.cc:6574
+#, gcc-internal-format
+msgid "argument %u in call to function %qE has pointer to %qs type (%qT)"
+msgstr ""
+
+#: c-family/c-common.cc:6536 c-family/c-common.cc:6621
+#, gcc-internal-format
+msgid "argument %u in call to function %qE has enumerated type"
+msgstr ""
+
+#: c-family/c-common.cc:6542 c-family/c-common.cc:6627
+#, gcc-internal-format
+msgid "argument %u in call to function %qE has boolean type"
+msgstr ""
+
+#: c-family/c-common.cc:6555
+#, gcc-internal-format
+msgid "argument %u in call to function %qE does not have pointer type"
+msgstr ""
+
+#: c-family/c-common.cc:6561
+#, gcc-internal-format
+msgid "argument %u in call to function %qE points to incomplete type"
+msgstr ""
+
+#: c-family/c-common.cc:6605
+#, gcc-internal-format
+msgid "argument %u in call to function %qE does not have %<int%> type"
+msgstr ""
+
+#: c-family/c-common.cc:6636
+#, gcc-internal-format
+msgid "argument 1 in call to function %qE has unsigned type"
+msgstr ""
+
+#: c-family/c-common.cc:6643
+#, gcc-internal-format
+msgid "argument 1 in call to function %qE has signed type"
+msgstr ""
+
+#: c-family/c-common.cc:6906 rust/backend/rust-tree.cc:3601
+#, gcc-internal-format
+msgid "cannot apply %<offsetof%> to static data member %qD"
+msgstr ""
+
+#: c-family/c-common.cc:6911 rust/backend/rust-tree.cc:3606
+#, gcc-internal-format
+msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
+msgstr ""
+
+#: c-family/c-common.cc:6918 rust/backend/rust-tree.cc:3613
+#, gcc-internal-format
+msgid "cannot apply %<offsetof%> to a non constant address"
+msgstr ""
+
+#: c-family/c-common.cc:6931 rust/backend/rust-tree.cc:3626
+#, gcc-internal-format
+msgid "attempt to take address of bit-field structure member %qD"
+msgstr ""
+
+#: c-family/c-common.cc:6984 rust/backend/rust-tree.cc:3678
+#, gcc-internal-format
+msgid "index %E denotes an offset greater than size of %qT"
+msgstr ""
+
+#: c-family/c-common.cc:7150
+#, gcc-internal-format
+msgid "size of array is too large"
+msgstr ""
+
+#: c-family/c-common.cc:7264 c-family/c-common.cc:7402
+#, gcc-internal-format
+msgid "operand type %qT is incompatible with argument %d of %qE"
+msgstr ""
+
+#: c-family/c-common.cc:7298
+#, gcc-internal-format
+msgid "expecting argument of type pointer or of type integer for argument 1"
+msgstr ""
+
+#: c-family/c-common.cc:7314
+#, gcc-internal-format
+msgid "both arguments must be compatible"
+msgstr ""
+
+#: c-family/c-common.cc:7544
+#, gcc-internal-format
+msgid "incorrect number of arguments to function %qE"
+msgstr ""
+
+#: c-family/c-common.cc:7558
+#, gcc-internal-format
+msgid "argument 1 of %qE must be a non-void pointer type"
+msgstr ""
+
+#: c-family/c-common.cc:7565
+#, gcc-internal-format
+msgid "argument 1 of %qE must be a pointer to a complete type"
+msgstr ""
+
+#: c-family/c-common.cc:7574
+#, gcc-internal-format
+msgid "argument 1 of %qE must be a pointer to a constant size type"
+msgstr ""
+
+#: c-family/c-common.cc:7585
+#, gcc-internal-format
+msgid "argument 1 of %qE must be a pointer to a nonzero size object"
+msgstr ""
+
+#: c-family/c-common.cc:7606
+#, gcc-internal-format
+msgid "argument %d of %qE must be a pointer type"
+msgstr ""
+
+#: c-family/c-common.cc:7614
+#, gcc-internal-format
+msgid "argument %d of %qE must be a pointer to a constant size type"
+msgstr ""
+
+#: c-family/c-common.cc:7620
+#, gcc-internal-format
+msgid "argument %d of %qE must not be a pointer to a function"
+msgstr ""
+
+#: c-family/c-common.cc:7628
+#, gcc-internal-format
+msgid "size mismatch in argument %d of %qE"
+msgstr ""
+
+#: c-family/c-common.cc:7641
+#, gcc-internal-format
+msgid "argument %d of %qE must not be a pointer to a %<const%> type"
+msgstr ""
+
+#: c-family/c-common.cc:7646
+#, gcc-internal-format
+msgid "argument %d of %qE discards %<const%> qualifier"
+msgstr ""
+
+#: c-family/c-common.cc:7655
+#, gcc-internal-format
+msgid "argument %d of %qE must not be a pointer to a %<volatile%> type"
+msgstr ""
+
+#: c-family/c-common.cc:7660
+#, gcc-internal-format
+msgid "argument %d of %qE discards %<volatile%> qualifier"
+msgstr ""
+
+#: c-family/c-common.cc:7673
+#, gcc-internal-format
+msgid "non-integer memory model argument %d of %qE"
+msgstr ""
+
+#: c-family/c-common.cc:7686
+#, gcc-internal-format
+msgid "invalid memory model argument %d of %qE"
+msgstr ""
+
+#: c-family/c-common.cc:8320
+#, gcc-internal-format
+msgid "this target does not define a speculation barrier; your program will still execute correctly, but incorrect speculation may not be restricted"
+msgstr ""
+
+#: c-family/c-common.cc:8975
+#, gcc-internal-format
+msgid "index value is out of bound"
+msgstr ""
+
+#: c-family/c-common.cc:9021 c-family/c-common.cc:9070
+#: c-family/c-common.cc:9086
+#, gcc-internal-format
+msgid "conversion of scalar %qT to vector %qT involves truncation"
+msgstr ""
+
+#. Reject arguments that are built-in functions with
+#. no library fallback.
+#: c-family/c-common.cc:9174 d/intrinsics.cc:1459
+#: rust/backend/rust-tree.cc:3497
+#, gcc-internal-format
+msgid "built-in function %qE must be directly called"
+msgstr ""
+
+#: c-family/c-common.cc:9194
+#, gcc-internal-format
+msgid "size of array %qE is not a constant expression"
+msgstr ""
+
+#: c-family/c-common.cc:9197
+#, gcc-internal-format
+msgid "size of array is not a constant expression"
+msgstr ""
+
+#: c-family/c-common.cc:9201
+#, gcc-internal-format
+msgid "size %qE of array %qE is negative"
+msgstr ""
+
+#: c-family/c-common.cc:9204
+#, gcc-internal-format
+msgid "size %qE of array is negative"
+msgstr ""
+
+#: c-family/c-common.cc:9209
+#, gcc-internal-format
+msgid "size %qE of array %qE exceeds maximum object size %qE"
+msgstr ""
+
+#: c-family/c-common.cc:9212
+#, gcc-internal-format
+msgid "size %qE of array exceeds maximum object size %qE"
+msgstr ""
+
+#: c-family/c-common.cc:9217
+#, gcc-internal-format
+msgid "size of array %qE exceeds maximum object size %qE"
+msgstr ""
+
+#: c-family/c-common.cc:9220
+#, gcc-internal-format
+msgid "size of array exceeds maximum object size %qE"
+msgstr ""
+
+#: c-family/c-common.cc:9291
+#, gcc-internal-format
+msgid "environment variable %qs must expand to a non-negative integer less than or equal to %wd"
+msgstr ""
+
+#: c-family/c-format.cc:197
+#, gcc-internal-format
+msgid "function does not return string type"
+msgstr ""
+
+#: c-family/c-format.cc:231
+#, gcc-internal-format
+msgid "format string argument is not a string type"
+msgstr ""
+
+#: c-family/c-format.cc:257
+#, gcc-internal-format
+msgid "found a %qs reference but the format argument should be a string"
+msgstr ""
+
+#: c-family/c-format.cc:260
+#, gcc-internal-format
+msgid "found a %qT but the format argument should be a string"
+msgstr ""
+
+#: c-family/c-format.cc:270
+#, gcc-internal-format
+msgid "format argument should be a %qs reference but a string was found"
+msgstr ""
+
+#: c-family/c-format.cc:292
+#, gcc-internal-format
+msgid "format argument should be a %qs reference"
+msgstr ""
+
+#: c-family/c-format.cc:346
+#, gcc-internal-format
+msgid "unrecognized format specifier"
+msgstr ""
+
+#: c-family/c-format.cc:359
+#, gcc-internal-format
+msgid "%qE is only allowed in Objective-C dialects"
+msgstr ""
+
+#: c-family/c-format.cc:368
+#, gcc-internal-format
+msgid "%qE is an unrecognized format function type"
+msgstr ""
+
+#: c-family/c-format.cc:386
+#, gcc-internal-format
+msgid "format string argument follows the arguments to be formatted"
+msgstr ""
+
+#: c-family/c-format.cc:1274
+#, gcc-internal-format
+msgid "function %qD might be a candidate for %qs format attribute"
+msgstr ""
+
+#: c-family/c-format.cc:1365 c-family/c-format.cc:1386
+#: c-family/c-format.cc:2821
+#, gcc-internal-format
+msgid "missing $ operand number in format"
+msgstr ""
+
+#: c-family/c-format.cc:1395
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support %%n$ operand number formats"
+msgstr ""
+
+#: c-family/c-format.cc:1402
+#, gcc-internal-format
+msgid "operand number out of range in format"
+msgstr ""
+
+#: c-family/c-format.cc:1425
+#, gcc-internal-format, gfc-internal-format
+msgid "format argument %d used more than once in %s format"
+msgstr ""
+
+#: c-family/c-format.cc:1458
+#, gcc-internal-format
+msgid "%<$%>operand number used after format without operand number"
+msgstr ""
+
+#: c-family/c-format.cc:1489
+#, gcc-internal-format
+msgid "format argument %d unused before used argument %d in %<$%>-style format"
+msgstr ""
+
+#: c-family/c-format.cc:1592
+#, gcc-internal-format
+msgid "format not a string literal, format string not checked"
+msgstr ""
+
+#: c-family/c-format.cc:1607 c-family/c-format.cc:1610
+#, gcc-internal-format
+msgid "format not a string literal and no format arguments"
+msgstr ""
+
+#: c-family/c-format.cc:1613
+#, gcc-internal-format
+msgid "format not a string literal, argument types not checked"
+msgstr ""
+
+#: c-family/c-format.cc:1630
+#, gcc-internal-format
+msgid "too many arguments for format"
+msgstr ""
+
+#: c-family/c-format.cc:1635
+#, gcc-internal-format
+msgid "unused arguments in %<$%>-style format"
+msgstr ""
+
+#: c-family/c-format.cc:1638
+#, gcc-internal-format, gfc-internal-format
+msgid "zero-length %s format string"
+msgstr ""
+
+#: c-family/c-format.cc:1642
+#, gcc-internal-format
+msgid "format is a wide character string"
+msgstr ""
+
+#: c-family/c-format.cc:1646
+#, gcc-internal-format
+msgid "format string is not an array of type %qs"
+msgstr ""
+
+#: c-family/c-format.cc:1649
+#, gcc-internal-format
+msgid "unterminated format string"
+msgstr ""
+
+#: c-family/c-format.cc:2064
+#, gcc-internal-format
+msgid "%s used with %<%%%c%> %s format"
+msgstr ""
+
+#: c-family/c-format.cc:2074
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not support %s"
+msgstr "%s -ს %s-ის მხარდაჭერა არ გააჩნია"
+
+#: c-family/c-format.cc:2084
+#, gcc-internal-format
+msgid "%s does not support %s with the %<%%%c%> %s format"
+msgstr ""
+
+#: c-family/c-format.cc:2098
+#, gcc-internal-format, gfc-internal-format
+msgid "%s used within a quoted sequence"
+msgstr ""
+
+#: c-family/c-format.cc:2111
+#, gcc-internal-format
+msgid "%qc conversion used unquoted"
+msgstr ""
+
+#: c-family/c-format.cc:2229 c-family/c-format.cc:2560
+#, gcc-internal-format, gfc-internal-format
+msgid "repeated %s in format"
+msgstr ""
+
+#: c-family/c-format.cc:2240
+#, gcc-internal-format
+msgid "missing fill character at end of strfmon format"
+msgstr ""
+
+#: c-family/c-format.cc:2342
+#, gcc-internal-format, gfc-internal-format
+msgid "zero width in %s format"
+msgstr ""
+
+#: c-family/c-format.cc:2365
+#, gcc-internal-format, gfc-internal-format
+msgid "empty left precision in %s format"
+msgstr ""
+
+#: c-family/c-format.cc:2456
+#, gcc-internal-format, gfc-internal-format
+msgid "empty precision in %s format"
+msgstr ""
+
+#: c-family/c-format.cc:2534
+#, gcc-internal-format
+msgid "%s does not support the %qs %s length modifier"
+msgstr ""
+
+#: c-family/c-format.cc:2590
+#, gcc-internal-format
+msgid "unknown conversion type character %qc in format"
+msgstr ""
+
+#: c-family/c-format.cc:2602
+#, gcc-internal-format
+msgid "%s does not support the %<%%%c%> %s format"
+msgstr ""
+
+#: c-family/c-format.cc:2634
+#, gcc-internal-format
+msgid "%s ignored with %s and %<%%%c%> %s format"
+msgstr ""
+
+#: c-family/c-format.cc:2639
+#, gcc-internal-format, gfc-internal-format
+msgid "%s ignored with %s in %s format"
+msgstr ""
+
+#: c-family/c-format.cc:2646
+#, gcc-internal-format
+msgid "use of %s and %s together with %<%%%c%> %s format"
+msgstr ""
+
+#: c-family/c-format.cc:2651
+#, gcc-internal-format, gfc-internal-format
+msgid "use of %s and %s together in %s format"
+msgstr ""
+
+#: c-family/c-format.cc:2678
+#, gcc-internal-format
+msgid "%<%%%c%> yields only last 2 digits of year in some locales"
+msgstr ""
+
+#: c-family/c-format.cc:2682
+#, gcc-internal-format
+msgid "%<%%%c%> yields only last 2 digits of year"
+msgstr ""
+
+#: c-family/c-format.cc:2709
+#, gcc-internal-format
+msgid "no closing %<]%> for %<%%[%> format"
+msgstr ""
+
+#: c-family/c-format.cc:2738
+#, gcc-internal-format
+msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
+msgstr ""
+
+#: c-family/c-format.cc:2760
+#, gcc-internal-format
+msgid "%s does not support the %<%%%s%c%> %s format"
+msgstr ""
+
+#: c-family/c-format.cc:2798
+#, gcc-internal-format
+msgid "operand number specified with suppressed assignment"
+msgstr ""
+
+#: c-family/c-format.cc:2802
+#, gcc-internal-format
+msgid "operand number specified for format taking no argument"
+msgstr ""
+
+#: c-family/c-format.cc:3152
+#, gcc-internal-format
+msgid "unquoted type name %<%.*s%> in format"
+msgstr ""
+
+#: c-family/c-format.cc:3154
+#, gcc-internal-format
+msgid "unquoted operator %<%.*s%> in format"
+msgstr ""
+
+#: c-family/c-format.cc:3155
+#, gcc-internal-format
+msgid "unquoted keyword %<%.*s%> in format"
+msgstr ""
+
+#: c-family/c-format.cc:3158
+#, gcc-internal-format
+msgid "use %qs instead"
+msgstr ""
+
+#: c-family/c-format.cc:3210
+#, gcc-internal-format
+msgid "unquoted attribute in format"
+msgstr ""
+
+#: c-family/c-format.cc:3223
+#, gcc-internal-format
+msgid "unquoted name of built-in function %<%.*s%> in format"
+msgstr ""
+
+#: c-family/c-format.cc:3237
+#, gcc-internal-format
+msgid "unquoted identifier or keyword %<%.*s%> in format"
+msgstr ""
+
+#: c-family/c-format.cc:3271
+#, gcc-internal-format
+msgid "misspelled term %<%.*s%> in format; use %<%s%s%> instead"
+msgstr ""
+
+#: c-family/c-format.cc:3315
+#, gcc-internal-format
+msgid "quoted %qs directive in format; use %qs instead"
+msgstr ""
+
+#: c-family/c-format.cc:3322 c-family/c-format.cc:3593
+#, gcc-internal-format
+msgid "contraction %<%.*s%> in format; use %qs instead"
+msgstr ""
+
+#: c-family/c-format.cc:3362
+#, gcc-internal-format
+msgid "unquoted whitespace character %qc in format"
+msgstr ""
+
+#: c-family/c-format.cc:3375
+#, gcc-internal-format
+msgid "spurious trailing space in format"
+msgstr ""
+
+#: c-family/c-format.cc:3396
+#, gcc-internal-format
+msgid "inconsistent capitalization in format"
+msgstr ""
+
+#: c-family/c-format.cc:3403
+#, gcc-internal-format, gfc-internal-format
+msgid "unquoted sequence of %i consecutive space characters in format"
+msgstr ""
+
+#: c-family/c-format.cc:3423
+#, gcc-internal-format
+msgid "unquoted control characters in format"
+msgstr ""
+
+#: c-family/c-format.cc:3430
+#, gcc-internal-format
+msgid "unquoted control character %qc in format"
+msgstr ""
+
+#: c-family/c-format.cc:3488
+#, gcc-internal-format
+msgid "unquoted option name %<%.*s%> in format"
+msgstr ""
+
+#: c-family/c-format.cc:3548
+#, gcc-internal-format
+msgid "unbalanced punctuation character %qc in format"
+msgstr ""
+
+#: c-family/c-format.cc:3567
+#, gcc-internal-format
+msgid "unquoted preprocessing directive %<%.*s%> in format"
+msgstr ""
+
+#: c-family/c-format.cc:3603
+#, gcc-internal-format
+msgid "bare apostrophe %<'%> in format"
+msgstr ""
+
+#: c-family/c-format.cc:3605
+#, gcc-internal-format
+msgid "if avoiding the apostrophe is not feasible, enclose it in a pair of %qs and %qs directives instead"
+msgstr ""
+
+#: c-family/c-format.cc:3617
+#, gcc-internal-format
+msgid "grave accent %<`%> in format"
+msgstr ""
+
+#: c-family/c-format.cc:3619
+#, gcc-internal-format
+msgid "use the apostrophe directive %qs instead"
+msgstr ""
+
+#: c-family/c-format.cc:3631
+#, gcc-internal-format
+msgid "space followed by punctuation character %<%c%>"
+msgstr ""
+
+#: c-family/c-format.cc:3642
+#, gcc-internal-format
+msgid "quoted %qs directive in format"
+msgstr ""
+
+#: c-family/c-format.cc:3644
+#, gcc-internal-format
+msgid "if using %qs is not feasible, use %qs instead"
+msgstr ""
+
+#: c-family/c-format.cc:3673
+#, gcc-internal-format
+msgid "spurious leading punctuation sequence %<%.*s%> in format"
+msgstr ""
+
+#: c-family/c-format.cc:3713
+#, gcc-internal-format
+msgid "spurious trailing punctuation sequence %<%.*s%> in format"
+msgstr ""
+
+#: c-family/c-format.cc:3730
+#, gcc-internal-format
+msgid "unquoted sequence of %i consecutive punctuation characters %q.*s in format"
+msgstr ""
+
+#: c-family/c-format.cc:3750
+#, gcc-internal-format
+msgid "unquoted non-graph characters in format"
+msgstr ""
+
+#: c-family/c-format.cc:3757
+#, gcc-internal-format
+msgid "unquoted non-graph character %qc in format"
+msgstr ""
+
+#: c-family/c-format.cc:3789
+#, gcc-internal-format
+msgid "unbalanced punctuation character %<%c%> in format"
+msgstr ""
+
+#: c-family/c-format.cc:3796
+#, gcc-internal-format
+msgid "unterminated quoting directive"
+msgstr ""
+
+#: c-family/c-format.cc:3805
+#, gcc-internal-format
+msgid "unterminated quote character %<%c%> in format"
+msgstr ""
+
+#: c-family/c-format.cc:3875
+#, gcc-internal-format
+msgid "spurious trailing %<%%%> in format"
+msgstr ""
+
+#: c-family/c-format.cc:3935
+#, gcc-internal-format
+msgid "conversion lacks type at end of format"
+msgstr ""
+
+#: c-family/c-format.cc:3964
+#, gcc-internal-format
+msgid "nested quoting directive"
+msgstr ""
+
+#: c-family/c-format.cc:3975
+#, gcc-internal-format
+msgid "unmatched quoting directive"
+msgstr ""
+
+#: c-family/c-format.cc:3990
+#, gcc-internal-format
+msgid "%qc directive redundant after prior occurence of the same"
+msgstr ""
+
+#: c-family/c-format.cc:3996
+#, gcc-internal-format
+msgid "unmatched color reset directive"
+msgstr ""
+
+#: c-family/c-format.cc:4008
+#, gcc-internal-format
+msgid "%qc conversion used within a quoted sequence"
+msgstr ""
+
+#: c-family/c-format.cc:4048
+#, gcc-internal-format
+msgid "embedded %<\\0%> in format"
+msgstr ""
+
+#: c-family/c-format.cc:4064
+#, gcc-internal-format
+msgid "unterminated color directive"
+msgstr ""
+
+#: c-family/c-format.cc:4186
+#, gcc-internal-format, gfc-internal-format
+msgid "writing through null pointer (argument %d)"
+msgstr ""
+
+#: c-family/c-format.cc:4197
+#, gcc-internal-format, gfc-internal-format
+msgid "reading through null pointer (argument %d)"
+msgstr ""
+
+#: c-family/c-format.cc:4217
+#, gcc-internal-format, gfc-internal-format
+msgid "writing into constant object (argument %d)"
+msgstr ""
+
+#: c-family/c-format.cc:4229
+#, gcc-internal-format, gfc-internal-format
+msgid "extra type qualifiers in format argument (argument %d)"
+msgstr ""
+
+#: c-family/c-format.cc:4771
+#, gcc-internal-format
+msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
+msgstr ""
+
+#: c-family/c-format.cc:4780
+#, gcc-internal-format
+msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
+msgstr ""
+
+#: c-family/c-format.cc:4790
+#, gcc-internal-format
+msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
+msgstr ""
+
+#: c-family/c-format.cc:4799
+#, gcc-internal-format
+msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
+msgstr ""
+
+#: c-family/c-format.cc:4861 c-family/c-format.cc:4867
+#: c-family/c-format.cc:4921
+#, gcc-internal-format
+msgid "%<__gcc_host_wide_int__%> is not defined as a type"
+msgstr ""
+
+#: c-family/c-format.cc:4874 c-family/c-format.cc:4931
+#, gcc-internal-format
+msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
+msgstr ""
+
+#: c-family/c-format.cc:4983
+#, gcc-internal-format
+msgid "%<locus%> is not defined as a type"
+msgstr ""
+
+#: c-family/c-format.cc:5027
+#, gcc-internal-format
+msgid "%qs is not defined as a type"
+msgstr ""
+
+#: c-family/c-format.cc:5053
+#, gcc-internal-format
+msgid "%<location_t%> is not defined as a type"
+msgstr ""
+
+#: c-family/c-format.cc:5070
+#, gcc-internal-format
+msgid "%<tree%> is not defined as a type"
+msgstr ""
+
+#: c-family/c-format.cc:5076
+#, gcc-internal-format
+msgid "%<tree%> is not defined as a pointer type"
+msgstr ""
+
+#: c-family/c-format.cc:5259
+#, gcc-internal-format
+msgid "argument to be formatted is not %<...%>"
+msgstr ""
+
+#: c-family/c-format.cc:5271
+#, gcc-internal-format
+msgid "strftime formats cannot format arguments"
+msgstr ""
+
+#: c-family/c-indentation.cc:321
+#, gcc-internal-format
+msgid "%<-Wmisleading-indentation%> is disabled from this point onwards, since column-tracking was disabled due to the size of the code/headers"
+msgstr ""
+
+#: c-family/c-indentation.cc:326
+#, gcc-internal-format
+msgid "adding %<-flarge-source-files%> will allow for more column-tracking support, at the expense of compilation time and memory"
+msgstr ""
+
+#: c-family/c-indentation.cc:661
+#, gcc-internal-format
+msgid "this %qs clause does not guard..."
+msgstr ""
+
+#: c-family/c-indentation.cc:664
+#, gcc-internal-format
+msgid "...this statement, but the latter is misleadingly indented as if it were guarded by the %qs"
+msgstr ""
+
+#: c-family/c-lex.cc:228
+#, gcc-internal-format
+msgid "badly nested C headers from preprocessor"
+msgstr ""
+
+#: c-family/c-lex.cc:267
+#, gcc-internal-format
+msgid "ignoring %<#pragma %s %s%>"
+msgstr ""
+
+#. ... or not.
+#: c-family/c-lex.cc:683 c-family/c-lex.cc:1622
+#, gcc-internal-format
+msgid "stray %<@%> in program"
+msgstr ""
+
+#: c-family/c-lex.cc:698
+#, gcc-internal-format
+msgid "stray %qs in program"
+msgstr ""
+
+#: c-family/c-lex.cc:708
+#, gcc-internal-format, gfc-internal-format
+msgid "missing terminating %c character"
+msgstr "დამაბოლოებელი %c სიმბოლო აღმოჩენილი არაა"
+
+#: c-family/c-lex.cc:710
+#, gcc-internal-format
+msgid "stray %qc in program"
+msgstr ""
+
+#: c-family/c-lex.cc:715
+#, gcc-internal-format
+msgid "stray %<\\%o%> in program"
+msgstr ""
+
+#: c-family/c-lex.cc:1034
+#, gcc-internal-format
+msgid "integer constant is too large for %<unsigned _BitInt(%d)%> type"
+msgstr ""
+
+#: c-family/c-lex.cc:1037
+#, gcc-internal-format
+msgid "integer constant is too large for %<_BitInt(%d)%> type"
+msgstr ""
+
+#: c-family/c-lex.cc:1045 c/c-decl.cc:12737
+#, gcc-internal-format
+msgid "%<_BitInt(%d)%> is not supported on this target"
+msgstr ""
+
+#: c-family/c-lex.cc:1097
+#, gcc-internal-format
+msgid "this decimal constant is unsigned only in ISO C90"
+msgstr ""
+
+#: c-family/c-lex.cc:1101
+#, gcc-internal-format
+msgid "this decimal constant would be unsigned in ISO C90"
+msgstr ""
+
+#: c-family/c-lex.cc:1129
+#, gcc-internal-format
+msgid "integer constant is too large for %<unsigned long%> type"
+msgstr ""
+
+#: c-family/c-lex.cc:1169
+#, gcc-internal-format
+msgid "unsuffixed floating constant"
+msgstr ""
+
+#: c-family/c-lex.cc:1183
+#, gcc-internal-format
+msgid "decimal floating-point not supported for this target"
+msgstr ""
+
+#: c-family/c-lex.cc:1206 c-family/c-lex.cc:1234 c-family/c-lex.cc:1272
+#, gcc-internal-format
+msgid "unsupported non-standard suffix on floating constant"
+msgstr ""
+
+#: c-family/c-lex.cc:1211 c-family/c-lex.cc:1265 c-family/c-lex.cc:1277
+#, gcc-internal-format
+msgid "non-standard suffix on floating constant"
+msgstr ""
+
+#: c-family/c-lex.cc:1243 c-family/c-lex.cc:1247 c-family/c-lex.cc:1252
+#, gcc-internal-format
+msgid "non-standard suffix on floating constant before C23"
+msgstr ""
+
+#: c-family/c-lex.cc:1259
+#, gcc-internal-format
+msgid "%<f%d%> or %<F%d%> suffix on floating constant only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
+msgstr ""
+
+#: c-family/c-lex.cc:1280
+#, gcc-internal-format
+msgid "%<bf16%> or %<BF16%> suffix on floating constant only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
+msgstr ""
+
+#: c-family/c-lex.cc:1360 c-family/c-lex.cc:1363
+#, gcc-internal-format
+msgid "floating constant exceeds range of %qT"
+msgstr ""
+
+#: c-family/c-lex.cc:1378
+#, gcc-internal-format
+msgid "floating constant truncated to zero"
+msgstr ""
+
+#: c-family/c-lex.cc:1579
+#, gcc-internal-format
+msgid "repeated %<@%> before Objective-C string"
+msgstr ""
+
+#: c-family/c-lex.cc:1598 c/c-parser.cc:8926
+#, gcc-internal-format
+msgid "unsupported non-standard concatenation of string literals"
+msgstr ""
+
+#: c-family/c-lex.cc:1634 c/c-parser.cc:8947
+#, gcc-internal-format
+msgid "traditional C rejects string constant concatenation"
+msgstr ""
+
+#: c-family/c-omp.cc:131 cp/pt.cc:19196
+#, gcc-internal-format
+msgid "%<#pragma omp critical%> with %<hint%> clause requires a name, except when %<omp_sync_hint_none%> is used"
+msgstr ""
+
+#: c-family/c-omp.cc:241
+#, gcc-internal-format
+msgid "invalid expression type for %<#pragma omp atomic%>"
+msgstr ""
+
+#: c-family/c-omp.cc:246
+#, gcc-internal-format
+msgid "%<_Atomic%> expression in %<#pragma omp atomic%>"
+msgstr ""
+
+#: c-family/c-omp.cc:251
+#, gcc-internal-format
+msgid "%<#pragma omp atomic compare capture%> with non-integral comparison result"
+msgstr ""
+
+#: c-family/c-omp.cc:540
+#, gcc-internal-format
+msgid "%<#pragma omp atomic update%> uses two different variables for memory"
+msgstr ""
+
+#: c-family/c-omp.cc:543 c-family/c-omp.cc:581
+#, gcc-internal-format
+msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
+msgstr ""
+
+#: c-family/c-omp.cc:699
+#, gcc-internal-format
+msgid "type of %<depobj%> expression is not %<omp_depend_t%>"
+msgstr ""
+
+#: c-family/c-omp.cc:705
+#, gcc-internal-format
+msgid "%<const%> qualified %<depobj%> expression"
+msgstr ""
+
+#: c-family/c-omp.cc:730
+#, gcc-internal-format
+msgid "more than one locator in %<depend%> clause on %<depobj%> construct"
+msgstr ""
+
+#: c-family/c-omp.cc:736
+#, gcc-internal-format
+msgid "%<depobj%> dependence type specified in %<depend%> clause on %<depobj%> construct"
+msgstr ""
+
+#: c-family/c-omp.cc:752
+#, gcc-internal-format
+msgid "%<iterator%> modifier may not be specified on %<depobj%> construct"
+msgstr ""
+
+#: c-family/c-omp.cc:969 cp/semantics.cc:10923
+#, gcc-internal-format
+msgid "invalid type for iteration variable %qE"
+msgstr ""
+
+#: c-family/c-omp.cc:974
+#, gcc-internal-format
+msgid "%<_Atomic%> iteration variable %qE"
+msgstr ""
+
+#: c-family/c-omp.cc:990
+#, gcc-internal-format
+msgid "%qE is not initialized"
+msgstr ""
+
+#: c-family/c-omp.cc:1011 cp/semantics.cc:10815
+#, gcc-internal-format
+msgid "missing controlling predicate"
+msgstr ""
+
+#: c-family/c-omp.cc:1117 cp/semantics.cc:10411
+#, gcc-internal-format
+msgid "invalid controlling predicate"
+msgstr ""
+
+#: c-family/c-omp.cc:1124 cp/semantics.cc:10821
+#, gcc-internal-format
+msgid "missing increment expression"
+msgstr ""
+
+#: c-family/c-omp.cc:1224 c-family/c-omp.cc:1242
+#, gcc-internal-format
+msgid "increment is not constant 1 or -1 for %<!=%> condition"
+msgstr ""
+
+#: c-family/c-omp.cc:1255 cp/semantics.cc:10528
+#, gcc-internal-format
+msgid "invalid increment expression"
+msgstr ""
+
+#: c-family/c-omp.cc:1353
+#, gcc-internal-format
+msgid "initializer expression refers to iteration variable %qD"
+msgstr ""
+
+#: c-family/c-omp.cc:1357
+#, gcc-internal-format
+msgid "condition expression refers to iteration variable %qD"
+msgstr ""
+
+#: c-family/c-omp.cc:1361
+#, gcc-internal-format
+msgid "increment expression refers to iteration variable %qD"
+msgstr ""
+
+#: c-family/c-omp.cc:1539
+#, gcc-internal-format
+msgid "outer iteration variable %qD used in initializer expression has type other than %qT"
+msgstr ""
+
+#: c-family/c-omp.cc:1543
+#, gcc-internal-format
+msgid "outer iteration variable %qD used in condition expression has type other than %qT"
+msgstr ""
+
+#: c-family/c-omp.cc:1550
+#, gcc-internal-format
+msgid "outer iteration variable %qD multiplier expression %qE is not integral"
+msgstr ""
+
+#: c-family/c-omp.cc:1556
+#, gcc-internal-format
+msgid "outer iteration variable %qD addend expression %qE is not integral"
+msgstr ""
+
+#: c-family/c-omp.cc:1621 c-family/c-omp.cc:1706
+#, gcc-internal-format
+msgid "the same loop iteration variables %qD used in multiple associated loops"
+msgstr ""
+
+#: c-family/c-omp.cc:1656
+#, gcc-internal-format
+msgid "two different outer iteration variables %qD and %qD used in a single loop"
+msgstr ""
+
+#: c-family/c-omp.cc:1820
+#, gcc-internal-format
+msgid "variable %qD used as loop variable is bound in intervening code"
+msgstr ""
+
+#: c-family/c-omp.cc:1824
+#, gcc-internal-format
+msgid "variable %qD used in initializer is bound in intervening code"
+msgstr ""
+
+#: c-family/c-omp.cc:1828
+#, gcc-internal-format
+msgid "variable %qD used in end test is bound in intervening code"
+msgstr ""
+
+#: c-family/c-omp.cc:1832
+#, gcc-internal-format
+msgid "variable %qD used in increment expression is bound in intervening code"
+msgstr ""
+
+#: c-family/c-omp.cc:2436
+#, gcc-internal-format
+msgid "invalid %<task%> reduction modifier on construct combined with %<simd%> or %<loop%>"
+msgstr ""
+
+#: c-family/c-omp.cc:2447
+#, gcc-internal-format
+msgid "invalid %<task%> reduction modifier on construct not combined with %<parallel%>, %<for%> or %<sections%>"
+msgstr ""
+
+#: c-family/c-omp.cc:2460
+#, gcc-internal-format
+msgid "%<inscan%> %<reduction%> clause on construct other than %<for%>, %<simd%>, %<for simd%>, %<parallel for%>, %<parallel for simd%>"
+msgstr ""
+
+#: c-family/c-omp.cc:2947 c/c-typeck.cc:16318 cp/semantics.cc:9515
+#, gcc-internal-format
+msgid "%qD specified in %<allocate%> clause but not in an explicit privatization clause"
+msgstr ""
+
+#: c-family/c-omp.cc:3039 c-family/c-omp.cc:3054
+#, gcc-internal-format
+msgid "%qD is not a function argument"
+msgstr ""
+
+#: c-family/c-omp.cc:3335 c/c-typeck.cc:15466 cp/semantics.cc:8254
+#, gcc-internal-format
+msgid "bit-field %qE in %qs clause"
+msgstr ""
+
+#: c-family/c-omp.cc:3343
+#, gcc-internal-format
+msgid "%qE does not have a mappable type in %qs clause"
+msgstr ""
+
+#: c-family/c-omp.cc:3351 c/c-typeck.cc:13876 c/c-typeck.cc:15555
+#: c/c-typeck.cc:15743
+#, gcc-internal-format
+msgid "%<_Atomic%> %qE in %qs clause"
+msgstr ""
+
+#: c-family/c-omp.cc:3376
+#, gcc-internal-format
+msgid "%qE is a member of a union"
+msgstr ""
+
+#: c-family/c-opts.cc:343
+#, gcc-internal-format
+msgid "%<-I-%> specified twice"
+msgstr ""
+
+#: c-family/c-opts.cc:346
+#, gcc-internal-format
+msgid "obsolete option %<-I-%> used, please use %<-iquote%> instead"
+msgstr ""
+
+#: c-family/c-opts.cc:373
+#, gcc-internal-format
+msgid "%<-fdeps-format=%> unknown format %<%s%>"
+msgstr ""
+
+#: c-family/c-opts.cc:455
+#, gcc-internal-format
+msgid "%<-Wabi=1%> is not supported, using =2"
+msgstr ""
+
+#: c-family/c-opts.cc:642 fortran/cpp.cc:370
+#, gcc-internal-format
+msgid "output filename specified twice"
+msgstr ""
+
+#: c-family/c-opts.cc:895
+#, gcc-internal-format
+msgid "%<-fno-gnu89-inline%> is only supported in GNU99 or C99 mode"
+msgstr ""
+
+#: c-family/c-opts.cc:941
+#, gcc-internal-format
+msgid "%<-Wformat-y2k%> ignored without %<-Wformat%>"
+msgstr ""
+
+#: c-family/c-opts.cc:943
+#, gcc-internal-format
+msgid "%<-Wformat-extra-args%> ignored without %<-Wformat%>"
+msgstr ""
+
+#: c-family/c-opts.cc:945
+#, gcc-internal-format
+msgid "%<-Wformat-zero-length%> ignored without %<-Wformat%>"
+msgstr ""
+
+#: c-family/c-opts.cc:947
+#, gcc-internal-format
+msgid "%<-Wformat-nonliteral%> ignored without %<-Wformat%>"
+msgstr ""
+
+#: c-family/c-opts.cc:949
+#, gcc-internal-format
+msgid "%<-Wformat-contains-nul%> ignored without %<-Wformat%>"
+msgstr ""
+
+#: c-family/c-opts.cc:951
+#, gcc-internal-format
+msgid "%<-Wformat-security%> ignored without %<-Wformat%>"
+msgstr ""
+
+#: c-family/c-opts.cc:1012
+#, gcc-internal-format
+msgid "%<-fabi-compat-version=1%> is not supported, using =2"
+msgstr ""
+
+#: c-family/c-opts.cc:1039
+#, gcc-internal-format
+msgid "%<-Wabi%> won%'t warn about anything"
+msgstr ""
+
+#: c-family/c-opts.cc:1041
+#, gcc-internal-format
+msgid "%<-Wabi%> warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr ""
+
+#: c-family/c-opts.cc:1044
+#, gcc-internal-format
+msgid "use e.g. %<-Wabi=11%> to warn about changes from GCC 7"
+msgstr ""
+
+#: c-family/c-opts.cc:1127
+#, gcc-internal-format
+msgid "external TLS initialization functions not supported on this target"
+msgstr ""
+
+#: c-family/c-opts.cc:1149
+#, gcc-internal-format
+msgid "%<-fconcepts-ts%> is deprecated and will be removed in GCC 15; please convert your code to C++20 concepts"
+msgstr ""
+
+#: c-family/c-opts.cc:1158
+#, gcc-internal-format
+msgid "too many filenames given; type %<%s %s%> for usage"
+msgstr ""
+
+#: c-family/c-opts.cc:1172
+#, gcc-internal-format
+msgid "opening output file %s: %m"
+msgstr ""
+
+#: c-family/c-opts.cc:1190
+#, gcc-internal-format
+msgid "the %qs debug info cannot be used with pre-compiled headers"
+msgstr ""
+
+#: c-family/c-opts.cc:1356 c-family/c-opts.cc:1377
+#, gcc-internal-format
+msgid "opening dependency file %s: %m"
+msgstr ""
+
+#: c-family/c-opts.cc:1381
+#, gcc-internal-format
+msgid "%<-MF%> and %<-fdeps-file=%> cannot share an output file %s: %m"
+msgstr ""
+
+#: c-family/c-opts.cc:1391
+#, gcc-internal-format
+msgid "closing dependency file %s: %m"
+msgstr ""
+
+#: c-family/c-opts.cc:1394
+#, gcc-internal-format
+msgid "when writing output to %s: %m"
+msgstr ""
+
+#: c-family/c-opts.cc:1472
+#, gcc-internal-format
+msgid "to generate dependencies you must specify either %<-M%> or %<-MM%>"
+msgstr ""
+
+#: c-family/c-opts.cc:1496
+#, gcc-internal-format
+msgid "%<-MG%> may only be used with %<-M%> or %<-MM%>"
+msgstr ""
+
+#: c-family/c-opts.cc:1529
+#, gcc-internal-format
+msgid "%<-fdirectives-only%> is incompatible with %<-Wunused-macros%>"
+msgstr ""
+
+#: c-family/c-opts.cc:1532
+#, gcc-internal-format
+msgid "%<-fdirectives-only%> is incompatible with %<-traditional%>"
+msgstr ""
+
+#: c-family/c-opts.cc:1634
+#, gcc-internal-format
+msgid "%<_FORTIFY_SOURCE%> is not enabled by %<-fhardened%> because optimizations are turned off"
+msgstr ""
+
+#: c-family/c-opts.cc:1638
+#, gcc-internal-format
+msgid "%<_FORTIFY_SOURCE%> is not enabled by %<-fhardened%> because it was specified in %<-D%> or %<-U%>"
+msgstr ""
+
+#: c-family/c-opts.cc:1644
+#, gcc-internal-format
+msgid "%<_GLIBCXX_ASSERTIONS%> is not enabled by %<-fhardened%> because it was specified in %<-D%> or %<-U%>"
+msgstr ""
+
+#: c-family/c-opts.cc:1768
+#, gcc-internal-format
+msgid "too late for # directive to set debug directory"
+msgstr ""
+
+#: c-family/c-pch.cc:105
+#, gcc-internal-format
+msgid "cannot create precompiled header %s: %m"
+msgstr ""
+
+#: c-family/c-pch.cc:125
+#, gcc-internal-format
+msgid "cannot write to %s: %m"
+msgstr ""
+
+#: c-family/c-pch.cc:183
+#, gcc-internal-format
+msgid "cannot write %s: %m"
+msgstr ""
+
+#: c-family/c-pch.cc:398
+#, gcc-internal-format
+msgid "%<pch_preprocess%> pragma should only be used with %<-fpreprocessed%>"
+msgstr ""
+
+#: c-family/c-pch.cc:400
+#, gcc-internal-format
+msgid "use %<#include%> instead"
+msgstr ""
+
+#: c-family/c-pch.cc:406
+#, gcc-internal-format
+msgid "%s: couldn%'t open PCH file: %m"
+msgstr ""
+
+#: c-family/c-pch.cc:411
+#, gcc-internal-format
+msgid "use %<-Winvalid-pch%> for more information"
+msgstr ""
+
+#: c-family/c-pch.cc:412
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: PCH file was invalid"
+msgstr ""
+
+#: c-family/c-pragma.cc:98
+#, gcc-internal-format
+msgid "%<#pragma pack (pop)%> encountered without matching %<#pragma pack (push)%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:113
+#, gcc-internal-format
+msgid "%<#pragma pack(pop, %E)%> encountered without matching %<#pragma pack(push, %E)%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:144
+#, gcc-internal-format
+msgid "missing %<(%> after %<#pragma pack%> - ignored"
+msgstr ""
+
+#: c-family/c-pragma.cc:155 c-family/c-pragma.cc:189
+#, gcc-internal-format
+msgid "invalid constant in %<#pragma pack%> - ignored"
+msgstr ""
+
+#: c-family/c-pragma.cc:159 c-family/c-pragma.cc:203
+#, gcc-internal-format
+msgid "malformed %<#pragma pack%> - ignored"
+msgstr ""
+
+#: c-family/c-pragma.cc:164
+#, gcc-internal-format
+msgid "malformed %<#pragma pack(push[, id][, <n>])%> - ignored"
+msgstr ""
+
+#: c-family/c-pragma.cc:166
+#, gcc-internal-format
+msgid "malformed %<#pragma pack(pop[, id])%> - ignored"
+msgstr ""
+
+#: c-family/c-pragma.cc:175
+#, gcc-internal-format
+msgid "unknown action %qE for %<#pragma pack%> - ignored"
+msgstr ""
+
+#: c-family/c-pragma.cc:206
+#, gcc-internal-format
+msgid "junk at end of %<#pragma pack%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:209
+#, gcc-internal-format
+msgid "%<#pragma pack%> has no effect with %<-fpack-struct%> - ignored"
+msgstr ""
+
+#: c-family/c-pragma.cc:230
+#, gcc-internal-format, gfc-internal-format
+msgid "alignment must be a small power of two, not %d"
+msgstr ""
+
+#: c-family/c-pragma.cc:269
+#, gcc-internal-format
+msgid "applying %<#pragma weak %+D%> after first use results in unspecified behavior"
+msgstr ""
+
+#: c-family/c-pragma.cc:366 c-family/c-pragma.cc:371
+#, gcc-internal-format
+msgid "malformed %<#pragma weak%>, ignored"
+msgstr ""
+
+#: c-family/c-pragma.cc:375
+#, gcc-internal-format
+msgid "junk at end of %<#pragma weak%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:381
+#, gcc-internal-format
+msgid "%<#pragma weak%> declaration of %q+D not allowed, ignored"
+msgstr ""
+
+#: c-family/c-pragma.cc:429
+#, gcc-internal-format
+msgid "%<scalar_storage_order%> is not supported because endianness is not uniform"
+msgstr ""
+
+#: c-family/c-pragma.cc:438
+#, gcc-internal-format
+msgid "%<#pragma scalar_storage_order%> is not supported for C++"
+msgstr ""
+
+#: c-family/c-pragma.cc:444
+#, gcc-internal-format
+msgid "missing %<big-endian%>, %<little-endian%>, or %<default%> after %<#pragma scalar_storage_order%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:454
+#, gcc-internal-format
+msgid "expected %<big-endian%>, %<little-endian%>, or %<default%> after %<#pragma scalar_storage_order%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:509 c-family/c-pragma.cc:511
+#, gcc-internal-format
+msgid "malformed %<#pragma redefine_extname%>, ignored"
+msgstr ""
+
+#: c-family/c-pragma.cc:514
+#, gcc-internal-format
+msgid "junk at end of %<#pragma redefine_extname%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:542 c-family/c-pragma.cc:615
+#, gcc-internal-format
+msgid "%<#pragma redefine_extname%> ignored due to conflict with previous rename"
+msgstr ""
+
+#: c-family/c-pragma.cc:570
+#, gcc-internal-format
+msgid "%<#pragma redefine_extname%> ignored due to conflict with previous %<#pragma redefine_extname%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:606
+#, gcc-internal-format
+msgid "%<asm%> declaration ignored due to conflict with previous rename"
+msgstr ""
+
+#: c-family/c-pragma.cc:637
+#, gcc-internal-format
+msgid "%<#pragma redefine_extname%> ignored due to conflict with %<asm%> declaration"
+msgstr ""
+
+#: c-family/c-pragma.cc:698
+#, gcc-internal-format
+msgid "%<#pragma GCC visibility push()%> must specify %<default%>, %<internal%>, %<hidden%> or %<protected%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:741
+#, gcc-internal-format
+msgid "%<#pragma GCC visibility%> must be followed by %<push%> or %<pop%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:748
+#, gcc-internal-format
+msgid "no matching push for %<#pragma GCC visibility pop%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:753 c-family/c-pragma.cc:760
+#, gcc-internal-format
+msgid "missing %<(%> after %<#pragma GCC visibility push%> - ignored"
+msgstr ""
+
+#: c-family/c-pragma.cc:756
+#, gcc-internal-format
+msgid "malformed %<#pragma GCC visibility push%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:764
+#, gcc-internal-format
+msgid "junk at end of %<#pragma GCC visibility%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:885
+#, gcc-internal-format
+msgid "missing %<error%>, %<warning%>, %<ignored%>, %<push%>, %<pop%>, or %<ignored_attributes%> after %<#pragma GCC diagnostic%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:909
+#, gcc-internal-format
+msgid "missing attribute name after %<#pragma GCC diagnostic ignored_attributes%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:918
+#, gcc-internal-format
+msgid "missing argument to %<#pragma GCC diagnostic ignored_attributes%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:926
+#, gcc-internal-format
+msgid "trailing %<,%> in arguments for %<#pragma GCC diagnostic ignored_attributes%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:944
+#, gcc-internal-format
+msgid "missing option after %<#pragma GCC diagnostic%> kind"
+msgstr ""
+
+#: c-family/c-pragma.cc:952
+#, gcc-internal-format
+msgid "expected %<error%>, %<warning%>, %<ignored%>, %<push%>, %<pop%>, %<ignored_attributes%> after %<#pragma GCC diagnostic%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:976
+#, gcc-internal-format
+msgid "unknown option after %<#pragma GCC diagnostic%> kind"
+msgstr ""
+
+#: c-family/c-pragma.cc:981
+#, gcc-internal-format
+msgid "did you mean %<-%s%>?"
+msgstr ""
+
+#: c-family/c-pragma.cc:990
+#, gcc-internal-format
+msgid "%qs is not an option that controls warnings"
+msgstr ""
+
+#: c-family/c-pragma.cc:1001
+#, gcc-internal-format
+msgid "option %qs is valid for %s but not for %s"
+msgstr ""
+
+#: c-family/c-pragma.cc:1054
+#, gcc-internal-format
+msgid "%<#pragma GCC option%> is not allowed inside functions"
+msgstr ""
+
+#: c-family/c-pragma.cc:1066
+#, gcc-internal-format
+msgid "%<#pragma GCC option%> is not a string"
+msgstr ""
+
+#: c-family/c-pragma.cc:1091
+#, gcc-internal-format
+msgid "%<#pragma GCC target (string [,string]...)%> does not have a final %<)%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:1097
+#, gcc-internal-format
+msgid "%<#pragma GCC target%> string is badly formed"
+msgstr ""
+
+#: c-family/c-pragma.cc:1126
+#, gcc-internal-format
+msgid "%<#pragma GCC optimize%> is not allowed inside functions"
+msgstr ""
+
+#: c-family/c-pragma.cc:1138
+#, gcc-internal-format
+msgid "%<#pragma GCC optimize%> is not a string or number"
+msgstr ""
+
+#: c-family/c-pragma.cc:1162
+#, gcc-internal-format
+msgid "%<#pragma GCC optimize (string [,string]...)%> does not have a final %<)%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:1168
+#, gcc-internal-format
+msgid "%<#pragma GCC optimize%> string is badly formed"
+msgstr ""
+
+#: c-family/c-pragma.cc:1211
+#, gcc-internal-format
+msgid "junk at end of %<#pragma GCC push_options%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:1248
+#, gcc-internal-format
+msgid "junk at end of %<#pragma GCC pop_options%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:1255
+#, gcc-internal-format
+msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:1329
+#, gcc-internal-format
+msgid "junk at end of %<#pragma reset_options%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:1350 c-family/c-pragma.cc:1360
+#, gcc-internal-format
+msgid "expected a string after %<#pragma message%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:1352
+#, gcc-internal-format
+msgid "malformed %<#pragma message%>, ignored"
+msgstr ""
+
+#: c-family/c-pragma.cc:1357 cp/parser.cc:4583 cp/parser.cc:4679
+#, gcc-internal-format
+msgid "string literal with user-defined suffix is invalid in this context"
+msgstr ""
+
+#: c-family/c-pragma.cc:1365
+#, gcc-internal-format
+msgid "junk at end of %<#pragma message%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:1368
+#, gcc-internal-format
+msgid "%<#pragma message: %s%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:1412
+#, gcc-internal-format
+msgid "invalid location for %<pragma %s%>, ignored"
+msgstr ""
+
+#: c-family/c-pragma.cc:1419 c-family/c-pragma.cc:1433
+#, gcc-internal-format
+msgid "malformed %<#pragma %s%>, ignored"
+msgstr ""
+
+#: c-family/c-pragma.cc:1439 cp/lex.cc:637
+#, gcc-internal-format
+msgid "junk at end of %<#pragma %s%>"
+msgstr ""
+
+#: c-family/c-pragma.cc:1457
+#, gcc-internal-format
+msgid "%<#pragma STDC FLOAT_CONST_DECIMAL64%> is not supported for C++"
+msgstr ""
+
+#: c-family/c-pragma.cc:1466
+#, gcc-internal-format
+msgid "%<#pragma STDC FLOAT_CONST_DECIMAL64%> is not supported on this target"
+msgstr ""
+
+#: c-family/c-pragma.cc:1472
+#, gcc-internal-format
+msgid "ISO C does not support %<#pragma STDC FLOAT_CONST_DECIMAL64%>"
+msgstr ""
+
+#: c-family/c-pretty-print.cc:344
+#, gcc-internal-format
+msgid "<type-error>"
+msgstr ""
+
+#: c-family/c-pretty-print.cc:387
+#, gcc-internal-format
+msgid "<unnamed-unsigned:"
+msgstr ""
+
+#: c-family/c-pretty-print.cc:391
+#, gcc-internal-format
+msgid "<unnamed-float:"
+msgstr ""
+
+#: c-family/c-pretty-print.cc:394
+#, gcc-internal-format
+msgid "<unnamed-fixed:"
+msgstr ""
+
+#: c-family/c-pretty-print.cc:426
+#, gcc-internal-format
+msgid "<typedef-error>"
+msgstr ""
+
+#: c-family/c-pretty-print.cc:441
+#, gcc-internal-format
+msgid "<tag-error>"
+msgstr ""
+
+#: c-family/c-pretty-print.cc:1360
+#, gcc-internal-format
+msgid "<erroneous-expression>"
+msgstr ""
+
+#: c-family/c-pretty-print.cc:1364 cp/cxx-pretty-print.cc:133
+#, gcc-internal-format
+msgid "<return-value>"
+msgstr ""
+
+#: c-family/c-semantics.cc:197
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong type argument to %s"
+msgstr ""
+
+#: c-family/c-warn.cc:59 c-family/c-warn.cc:72 cp/constexpr.cc:3599
+#: cp/constexpr.cc:7371 m2/gm2-gcc/m2expr.cc:964
+#: rust/backend/rust-constexpr.cc:1908 rust/backend/rust-constexpr.cc:4331
+#, gcc-internal-format
+msgid "overflow in constant expression"
+msgstr ""
+
+#: c-family/c-warn.cc:99
+#, gcc-internal-format
+msgid "integer overflow in expression %qE of type %qT results in %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:101
+#, gcc-internal-format
+msgid "integer overflow in expression of type %qT results in %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:107
+#, gcc-internal-format
+msgid "floating point overflow in expression %qE of type %qT results in %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:109
+#, gcc-internal-format
+msgid "floating point overflow in expression of type %qT results in %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:115
+#, gcc-internal-format
+msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:117
+#, gcc-internal-format
+msgid "fixed-point overflow in expression of type %qT results in %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:123
+#, gcc-internal-format
+msgid "vector overflow in expression %qE of type %qT results in %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:125
+#, gcc-internal-format
+msgid "vector overflow in expression of type %qT results in %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:132
+#, gcc-internal-format
+msgid "complex integer overflow in expression %qE of type %qT results in %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:134
+#, gcc-internal-format
+msgid "complex integer overflow in expression of type %qT results in %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:138
+#, gcc-internal-format
+msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:140
+#, gcc-internal-format
+msgid "complex floating point overflow in expression of type %qT results in %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:232
+#, gcc-internal-format
+msgid "logical %<or%> applied to non-boolean constant"
+msgstr ""
+
+#: c-family/c-warn.cc:236
+#, gcc-internal-format
+msgid "logical %<and%> applied to non-boolean constant"
+msgstr ""
+
+#: c-family/c-warn.cc:306
+#, gcc-internal-format
+msgid "logical %<or%> of collectively exhaustive tests is always true"
+msgstr ""
+
+#: c-family/c-warn.cc:310
+#, gcc-internal-format
+msgid "logical %<and%> of mutually exclusive tests is always false"
+msgstr ""
+
+#: c-family/c-warn.cc:320
+#, gcc-internal-format
+msgid "logical %<or%> of equal expressions"
+msgstr ""
+
+#: c-family/c-warn.cc:323
+#, gcc-internal-format
+msgid "logical %<and%> of equal expressions"
+msgstr ""
+
+#: c-family/c-warn.cc:409
+#, gcc-internal-format
+msgid "bitwise comparison always evaluates to false"
+msgstr ""
+
+#: c-family/c-warn.cc:412
+#, gcc-internal-format
+msgid "bitwise comparison always evaluates to true"
+msgstr ""
+
+#: c-family/c-warn.cc:517
+#, gcc-internal-format
+msgid "self-comparison always evaluates to true"
+msgstr ""
+
+#: c-family/c-warn.cc:520
+#, gcc-internal-format
+msgid "self-comparison always evaluates to false"
+msgstr ""
+
+#: c-family/c-warn.cc:571
+#, gcc-internal-format
+msgid "logical not is only applied to the left hand side of comparison"
+msgstr ""
+
+#: c-family/c-warn.cc:579
+#, gcc-internal-format
+msgid "add parentheses around left hand side expression to silence this warning"
+msgstr ""
+
+#: c-family/c-warn.cc:722
+#, gcc-internal-format
+msgid "type-punning to incomplete type might break strict-aliasing rules"
+msgstr ""
+
+#: c-family/c-warn.cc:740
+#, gcc-internal-format
+msgid "dereferencing type-punned pointer will break strict-aliasing rules"
+msgstr ""
+
+#: c-family/c-warn.cc:748 c-family/c-warn.cc:766
+#, gcc-internal-format
+msgid "dereferencing type-punned pointer might break strict-aliasing rules"
+msgstr ""
+
+#: c-family/c-warn.cc:913
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
+msgstr ""
+
+#: c-family/c-warn.cc:944
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
+msgstr ""
+
+#: c-family/c-warn.cc:951
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
+msgstr ""
+
+#: c-family/c-warn.cc:956
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
+msgstr ""
+
+#: c-family/c-warn.cc:968
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
+msgstr ""
+
+#: c-family/c-warn.cc:984
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
+msgstr ""
+
+#: c-family/c-warn.cc:991
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
+msgstr ""
+
+#: c-family/c-warn.cc:996
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
+msgstr ""
+
+#: c-family/c-warn.cc:1008
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
+msgstr ""
+
+#: c-family/c-warn.cc:1024
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
+msgstr ""
+
+#: c-family/c-warn.cc:1031
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
+msgstr ""
+
+#: c-family/c-warn.cc:1036
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
+msgstr ""
+
+#: c-family/c-warn.cc:1048
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
+msgstr ""
+
+#: c-family/c-warn.cc:1064
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
+msgstr ""
+
+#: c-family/c-warn.cc:1071
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
+msgstr ""
+
+#: c-family/c-warn.cc:1076
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
+msgstr ""
+
+#: c-family/c-warn.cc:1088
+#, gcc-internal-format
+msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
+msgstr ""
+
+#: c-family/c-warn.cc:1117 c-family/c-warn.cc:1124
+#, gcc-internal-format
+msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
+msgstr ""
+
+#: c-family/c-warn.cc:1134
+#, gcc-internal-format
+msgid "first argument of %q+D should be %<int%>"
+msgstr ""
+
+#: c-family/c-warn.cc:1143
+#, gcc-internal-format
+msgid "second argument of %q+D should be %<char **%>"
+msgstr ""
+
+#: c-family/c-warn.cc:1152
+#, gcc-internal-format
+msgid "third argument of %q+D should probably be %<char **%>"
+msgstr ""
+
+#: c-family/c-warn.cc:1163
+#, gcc-internal-format
+msgid "%q+D takes only zero or two arguments"
+msgstr ""
+
+#: c-family/c-warn.cc:1167
+#, gcc-internal-format
+msgid "%q+D declared as variadic function"
+msgstr ""
+
+#: c-family/c-warn.cc:1210 m2/gm2-gcc/m2convert.cc:191
+#, gcc-internal-format
+msgid "conversion to %qT from boolean expression"
+msgstr ""
+
+#: c-family/c-warn.cc:1235 c-family/c-warn.cc:1440
+#, gcc-internal-format
+msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:1240 c-family/c-warn.cc:1448
+#, gcc-internal-format
+msgid "unsigned conversion from %qT to %qT changes the value of %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:1248
+#, gcc-internal-format
+msgid "signed conversion from %qT to %qT changes value from %qE to %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:1253
+#, gcc-internal-format
+msgid "signed conversion from %qT to %qT changes the value of %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:1260 c-family/c-warn.cc:1438
+#, gcc-internal-format
+msgid "conversion from %qT to %qT changes value from %qE to %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:1264 c-family/c-warn.cc:1446
+#, gcc-internal-format
+msgid "conversion from %qT to %qT changes the value of %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:1375
+#, gcc-internal-format
+msgid "conversion to %qT from %qT may change the sign of the result"
+msgstr ""
+
+#: c-family/c-warn.cc:1380
+#, gcc-internal-format
+msgid "conversion from %qT to %qT discards imaginary component"
+msgstr ""
+
+#: c-family/c-warn.cc:1384
+#, gcc-internal-format
+msgid "conversion from %qT to %qT may change value"
+msgstr ""
+
+#: c-family/c-warn.cc:1459 c-family/c-warn.cc:1477 c-family/c-warn.cc:1494
+#, gcc-internal-format
+msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:1464 c-family/c-warn.cc:1482 c-family/c-warn.cc:1499
+#, gcc-internal-format
+msgid "overflow in conversion from %qT to %qT changes the value of %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:1531
+#, gcc-internal-format
+msgid "case value %qs not in enumerated type"
+msgstr ""
+
+#: c-family/c-warn.cc:1536
+#, gcc-internal-format
+msgid "case value %qs not in enumerated type %qT"
+msgstr ""
+
+#: c-family/c-warn.cc:1616
+#, gcc-internal-format
+msgid "lower value in case label range less than minimum value for type"
+msgstr ""
+
+#: c-family/c-warn.cc:1630
+#, gcc-internal-format
+msgid "case label value is less than minimum value for type"
+msgstr ""
+
+#: c-family/c-warn.cc:1647
+#, gcc-internal-format
+msgid "upper value in case label range exceeds maximum value for type"
+msgstr ""
+
+#: c-family/c-warn.cc:1660
+#, gcc-internal-format
+msgid "case label value exceeds maximum value for type"
+msgstr ""
+
+#: c-family/c-warn.cc:1673
+#, gcc-internal-format
+msgid "switch missing default case"
+msgstr ""
+
+#: c-family/c-warn.cc:1718
+#, gcc-internal-format
+msgid "switch condition has boolean value"
+msgstr ""
+
+#: c-family/c-warn.cc:1807
+#, gcc-internal-format
+msgid "enumeration value %qE not handled in switch"
+msgstr ""
+
+#: c-family/c-warn.cc:1835
+#, gcc-internal-format
+msgid "the omitted middle operand in %<?:%> will always be %<true%>, suggest explicit middle operand"
+msgstr ""
+
+#: c-family/c-warn.cc:1857 rust/checks/errors/rust-readonly-check.cc:44
+#, gcc-internal-format
+msgid "assignment of member %qD in read-only object"
+msgstr ""
+
+#: c-family/c-warn.cc:1859 rust/checks/errors/rust-readonly-check.cc:46
+#, gcc-internal-format
+msgid "increment of member %qD in read-only object"
+msgstr ""
+
+#: c-family/c-warn.cc:1861 rust/checks/errors/rust-readonly-check.cc:48
+#, gcc-internal-format
+msgid "decrement of member %qD in read-only object"
+msgstr ""
+
+#: c-family/c-warn.cc:1863 rust/checks/errors/rust-readonly-check.cc:50
+#, gcc-internal-format
+msgid "member %qD in read-only object used as %<asm%> output"
+msgstr ""
+
+#: c-family/c-warn.cc:1867 rust/checks/errors/rust-readonly-check.cc:56
+#, gcc-internal-format
+msgid "assignment of read-only member %qD"
+msgstr ""
+
+#: c-family/c-warn.cc:1868 rust/checks/errors/rust-readonly-check.cc:57
+#, gcc-internal-format
+msgid "increment of read-only member %qD"
+msgstr ""
+
+#: c-family/c-warn.cc:1869 rust/checks/errors/rust-readonly-check.cc:58
+#, gcc-internal-format
+msgid "decrement of read-only member %qD"
+msgstr ""
+
+#: c-family/c-warn.cc:1870 rust/checks/errors/rust-readonly-check.cc:59
+#, gcc-internal-format
+msgid "read-only member %qD used as %<asm%> output"
+msgstr ""
+
+#: c-family/c-warn.cc:1874 rust/checks/errors/rust-readonly-check.cc:64
+#, gcc-internal-format
+msgid "assignment of read-only variable %qD"
+msgstr ""
+
+#: c-family/c-warn.cc:1875 rust/checks/errors/rust-readonly-check.cc:65
+#, gcc-internal-format
+msgid "increment of read-only variable %qD"
+msgstr ""
+
+#: c-family/c-warn.cc:1876 rust/checks/errors/rust-readonly-check.cc:66
+#, gcc-internal-format
+msgid "decrement of read-only variable %qD"
+msgstr ""
+
+#: c-family/c-warn.cc:1877 rust/checks/errors/rust-readonly-check.cc:68
+#, gcc-internal-format
+msgid "read-only variable %qD used as %<asm%> output"
+msgstr ""
+
+#: c-family/c-warn.cc:1880 rust/checks/errors/rust-readonly-check.cc:72
+#, gcc-internal-format
+msgid "assignment of read-only parameter %qD"
+msgstr ""
+
+#: c-family/c-warn.cc:1881 rust/checks/errors/rust-readonly-check.cc:73
+#, gcc-internal-format
+msgid "increment of read-only parameter %qD"
+msgstr ""
+
+#: c-family/c-warn.cc:1882 rust/checks/errors/rust-readonly-check.cc:74
+#, gcc-internal-format
+msgid "decrement of read-only parameter %qD"
+msgstr ""
+
+#: c-family/c-warn.cc:1883 rust/checks/errors/rust-readonly-check.cc:76
+#, gcc-internal-format
+msgid "read-only parameter %qD use as %<asm%> output"
+msgstr ""
+
+#: c-family/c-warn.cc:1888 rust/checks/errors/rust-readonly-check.cc:81
+#, gcc-internal-format
+msgid "assignment of read-only named return value %qD"
+msgstr ""
+
+#: c-family/c-warn.cc:1890 rust/checks/errors/rust-readonly-check.cc:83
+#, gcc-internal-format
+msgid "increment of read-only named return value %qD"
+msgstr ""
+
+#: c-family/c-warn.cc:1892 rust/checks/errors/rust-readonly-check.cc:85
+#, gcc-internal-format
+msgid "decrement of read-only named return value %qD"
+msgstr ""
+
+#: c-family/c-warn.cc:1894 rust/checks/errors/rust-readonly-check.cc:87
+#, gcc-internal-format
+msgid "read-only named return value %qD used as %<asm%>output"
+msgstr ""
+
+#: c-family/c-warn.cc:1899 rust/checks/errors/rust-readonly-check.cc:93
+#, gcc-internal-format
+msgid "assignment of function %qD"
+msgstr ""
+
+#: c-family/c-warn.cc:1900 rust/checks/errors/rust-readonly-check.cc:94
+#, gcc-internal-format
+msgid "increment of function %qD"
+msgstr ""
+
+#: c-family/c-warn.cc:1901 rust/checks/errors/rust-readonly-check.cc:95
+#, gcc-internal-format
+msgid "decrement of function %qD"
+msgstr ""
+
+#: c-family/c-warn.cc:1902 rust/checks/errors/rust-readonly-check.cc:96
+#, gcc-internal-format
+msgid "function %qD used as %<asm%> output"
+msgstr ""
+
+#: c-family/c-warn.cc:1905 c/c-typeck.cc:5215
+#: rust/checks/errors/rust-readonly-check.cc:100
+#, gcc-internal-format
+msgid "assignment of read-only location %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:1906 c/c-typeck.cc:5218
+#: rust/checks/errors/rust-readonly-check.cc:101
+#, gcc-internal-format
+msgid "increment of read-only location %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:1907 c/c-typeck.cc:5221
+#: rust/checks/errors/rust-readonly-check.cc:102
+#, gcc-internal-format
+msgid "decrement of read-only location %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:1908 rust/checks/errors/rust-readonly-check.cc:104
+#, gcc-internal-format
+msgid "read-only location %qE used as %<asm%> output"
+msgstr ""
+
+#: c-family/c-warn.cc:1922 rust/backend/rust-tree.cc:5983
+#, gcc-internal-format
+msgid "lvalue required as left operand of assignment"
+msgstr ""
+
+#: c-family/c-warn.cc:1925 rust/backend/rust-tree.cc:5986
+#, gcc-internal-format
+msgid "lvalue required as increment operand"
+msgstr ""
+
+#: c-family/c-warn.cc:1928 rust/backend/rust-tree.cc:5989
+#, gcc-internal-format
+msgid "lvalue required as decrement operand"
+msgstr ""
+
+#: c-family/c-warn.cc:1931 rust/backend/rust-tree.cc:5992
+#, gcc-internal-format
+msgid "lvalue required as unary %<&%> operand"
+msgstr ""
+
+#: c-family/c-warn.cc:1934 rust/backend/rust-tree.cc:5995
+#, gcc-internal-format
+msgid "lvalue required in %<asm%> statement"
+msgstr ""
+
+#: c-family/c-warn.cc:1951
+#, gcc-internal-format
+msgid "invalid type argument (have %qT)"
+msgstr ""
+
+#: c-family/c-warn.cc:1955
+#, gcc-internal-format
+msgid "invalid type argument of array indexing (have %qT)"
+msgstr ""
+
+#: c-family/c-warn.cc:1960
+#, gcc-internal-format
+msgid "invalid type argument of unary %<*%> (have %qT)"
+msgstr ""
+
+#: c-family/c-warn.cc:1965
+#, gcc-internal-format
+msgid "invalid type argument of %<->%> (have %qT)"
+msgstr ""
+
+#: c-family/c-warn.cc:1970
+#, gcc-internal-format
+msgid "invalid type argument of %<->*%> (have %qT)"
+msgstr ""
+
+#: c-family/c-warn.cc:1975
+#, gcc-internal-format
+msgid "invalid type argument of implicit conversion (have %qT)"
+msgstr ""
+
+#: c-family/c-warn.cc:2002
+#, gcc-internal-format
+msgid "array subscript has type %<char%>"
+msgstr ""
+
+#: c-family/c-warn.cc:2038 c-family/c-warn.cc:2041
+#, gcc-internal-format
+msgid "suggest parentheses around %<+%> inside %<<<%>"
+msgstr ""
+
+#: c-family/c-warn.cc:2044 c-family/c-warn.cc:2047
+#, gcc-internal-format
+msgid "suggest parentheses around %<-%> inside %<<<%>"
+msgstr ""
+
+#: c-family/c-warn.cc:2053 c-family/c-warn.cc:2056
+#, gcc-internal-format
+msgid "suggest parentheses around %<+%> inside %<>>%>"
+msgstr ""
+
+#: c-family/c-warn.cc:2059 c-family/c-warn.cc:2062
+#, gcc-internal-format
+msgid "suggest parentheses around %<-%> inside %<>>%>"
+msgstr ""
+
+#: c-family/c-warn.cc:2068 c-family/c-warn.cc:2071
+#, gcc-internal-format
+msgid "suggest parentheses around %<&&%> within %<||%>"
+msgstr ""
+
+#: c-family/c-warn.cc:2078 c-family/c-warn.cc:2082
+#, gcc-internal-format
+msgid "suggest parentheses around arithmetic in operand of %<|%>"
+msgstr ""
+
+#: c-family/c-warn.cc:2086 c-family/c-warn.cc:2089
+#, gcc-internal-format
+msgid "suggest parentheses around comparison in operand of %<|%>"
+msgstr ""
+
+#: c-family/c-warn.cc:2094
+#, gcc-internal-format
+msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
+msgstr ""
+
+#: c-family/c-warn.cc:2102 c-family/c-warn.cc:2106
+#, gcc-internal-format
+msgid "suggest parentheses around arithmetic in operand of %<^%>"
+msgstr ""
+
+#: c-family/c-warn.cc:2110 c-family/c-warn.cc:2113
+#, gcc-internal-format
+msgid "suggest parentheses around comparison in operand of %<^%>"
+msgstr ""
+
+#: c-family/c-warn.cc:2119 c-family/c-warn.cc:2122
+#, gcc-internal-format
+msgid "suggest parentheses around %<+%> in operand of %<&%>"
+msgstr ""
+
+#: c-family/c-warn.cc:2125 c-family/c-warn.cc:2128
+#, gcc-internal-format
+msgid "suggest parentheses around %<-%> in operand of %<&%>"
+msgstr ""
+
+#: c-family/c-warn.cc:2132 c-family/c-warn.cc:2135
+#, gcc-internal-format
+msgid "suggest parentheses around comparison in operand of %<&%>"
+msgstr ""
+
+#: c-family/c-warn.cc:2140
+#, gcc-internal-format
+msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
+msgstr ""
+
+#: c-family/c-warn.cc:2147 c-family/c-warn.cc:2150
+#, gcc-internal-format
+msgid "suggest parentheses around comparison in operand of %<==%>"
+msgstr ""
+
+#: c-family/c-warn.cc:2155 c-family/c-warn.cc:2158
+#, gcc-internal-format
+msgid "suggest parentheses around comparison in operand of %<!=%>"
+msgstr ""
+
+#: c-family/c-warn.cc:2168 c-family/c-warn.cc:2174
+#, gcc-internal-format
+msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
+msgstr ""
+
+#: c-family/c-warn.cc:2189
+#, gcc-internal-format
+msgid "label %q+D defined but not used"
+msgstr ""
+
+#: c-family/c-warn.cc:2191
+#, gcc-internal-format
+msgid "label %q+D declared but not defined"
+msgstr ""
+
+#: c-family/c-warn.cc:2214
+#, gcc-internal-format
+msgid "division by zero"
+msgstr "ნულზე გაყოფა"
+
+#: c-family/c-warn.cc:2234
+#, gcc-internal-format
+msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
+msgstr ""
+
+#: c-family/c-warn.cc:2258
+#, gcc-internal-format
+msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
+msgstr ""
+
+#: c-family/c-warn.cc:2290
+#, gcc-internal-format
+msgid "%qD sizes specified with %<sizeof%> in the earlier argument and not in the later argument"
+msgstr ""
+
+#: c-family/c-warn.cc:2292
+#, gcc-internal-format
+msgid "earlier argument should specify number of elements, later size of each element"
+msgstr ""
+
+#: c-family/c-warn.cc:2331
+#, gcc-internal-format
+msgid "allocation of insufficient size %qE for type %qT with size %qE"
+msgstr ""
+
+#: c-family/c-warn.cc:2408
+#, gcc-internal-format
+msgid "comparison of integer expressions of different signedness: %qT and %qT"
+msgstr ""
+
+#: c-family/c-warn.cc:2482
+#, gcc-internal-format
+msgid "promoted bitwise complement of an unsigned value is always nonzero"
+msgstr ""
+
+#: c-family/c-warn.cc:2486
+#, gcc-internal-format
+msgid "comparison of promoted bitwise complement of an unsigned value with constant"
+msgstr ""
+
+#: c-family/c-warn.cc:2497
+#, gcc-internal-format
+msgid "comparison of promoted bitwise complement of an unsigned value with unsigned"
+msgstr ""
+
+#: c-family/c-warn.cc:2552
+#, gcc-internal-format
+msgid "unused parameter %qD"
+msgstr ""
+
+#: c-family/c-warn.cc:2614
+#, gcc-internal-format
+msgid "typedef %qD locally defined but not used"
+msgstr ""
+
+#: c-family/c-warn.cc:2650
+#, gcc-internal-format
+msgid "duplicated %<if%> condition"
+msgstr ""
+
+#: c-family/c-warn.cc:2679
+#, gcc-internal-format
+msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
+msgstr ""
+
+#: c-family/c-warn.cc:2687
+#, gcc-internal-format
+msgid "inline declaration of %qD follows declaration with attribute %<noinline%>"
+msgstr ""
+
+#: c-family/c-warn.cc:2692
+#, gcc-internal-format
+msgid "declaration of %q+D with attribute %<noinline%> follows inline declaration"
+msgstr ""
+
+#: c-family/c-warn.cc:2746
+#, gcc-internal-format
+msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
+msgstr ""
+
+#: c-family/c-warn.cc:2785 c-family/c-warn.cc:2809
+#, gcc-internal-format
+msgid "comparison of constant %qE with boolean expression is always false"
+msgstr ""
+
+#: c-family/c-warn.cc:2788 c-family/c-warn.cc:2806
+#, gcc-internal-format
+msgid "comparison of constant %qE with boolean expression is always true"
+msgstr ""
+
+#: c-family/c-warn.cc:2856
+msgid "passing argument %i to %qs-qualified parameter aliases with argument %Z"
+msgid_plural "passing argument %i to %qs-qualified parameter aliases with arguments %Z"
+msgstr[0] ""
+msgstr[1] ""
+
+#: c-family/c-warn.cc:2922 c/c-typeck.cc:5825 cp/call.cc:6385
+#, gcc-internal-format
+msgid "this condition has identical branches"
+msgstr ""
+
+#: c-family/c-warn.cc:3029
+#, gcc-internal-format
+msgid "macro expands to multiple statements"
+msgstr ""
+
+#: c-family/c-warn.cc:3030
+#, gcc-internal-format
+msgid "some parts of macro expansion are not guarded by this %qs clause"
+msgstr ""
+
+#: c-family/c-warn.cc:3170
+#, gcc-internal-format
+msgid "taking address of packed member of %qT may result in an unaligned pointer value"
+msgstr ""
+
+#: c-family/c-warn.cc:3396
+msgid "mismatch in bound %Z of argument %u declared as %s"
+msgid_plural "mismatch in bounds %Z of argument %u declared as %s"
+msgstr[0] ""
+msgstr[1] ""
+
+#: c-family/c-warn.cc:3399 c-family/c-warn.cc:3758
+#, gcc-internal-format, gfc-internal-format
+msgid "previously declared as %s"
+msgstr ""
+
+#: c-family/c-warn.cc:3533
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %u of type %s declared as a variable length array"
+msgstr ""
+
+#: c-family/c-warn.cc:3538
+#, gcc-internal-format, gfc-internal-format
+msgid "previously declared as a pointer %s"
+msgstr ""
+
+#: c-family/c-warn.cc:3539
+#, gcc-internal-format, gfc-internal-format
+msgid "previously declared as an ordinary array %s"
+msgstr ""
+
+#: c-family/c-warn.cc:3552 c-family/c-warn.cc:3566
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %u of type %s declared as a pointer"
+msgstr ""
+
+#: c-family/c-warn.cc:3556 c-family/c-warn.cc:3582
+#, gcc-internal-format, gfc-internal-format
+msgid "previously declared as a variable length array %s"
+msgstr ""
+
+#: c-family/c-warn.cc:3569
+#, gcc-internal-format, gfc-internal-format
+msgid "previously declared as an array %s"
+msgstr ""
+
+#: c-family/c-warn.cc:3578
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %u of type %s declared as an ordinary array"
+msgstr ""
+
+#: c-family/c-warn.cc:3606
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %u of type %s declared with %u variable bound"
+msgid_plural "argument %u of type %s declared with %u variable bounds"
+msgstr[0] ""
+msgstr[1] ""
+
+#: c-family/c-warn.cc:3613
+#, gcc-internal-format, gfc-internal-format
+msgid "previously declared as %s with %u variable bound"
+msgid_plural "previously declared as %s with %u variable bounds"
+msgstr[0] ""
+msgstr[1] ""
+
+#: c-family/c-warn.cc:3627
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %u of type %s declared with %u unspecified variable bound"
+msgid_plural "argument %u of type %s declared with %u unspecified variable bounds"
+msgstr[0] ""
+msgstr[1] ""
+
+#: c-family/c-warn.cc:3635
+#, gcc-internal-format, gfc-internal-format
+msgid "previously declared as %s with %u unspecified variable bound"
+msgid_plural "previously declared as %s with %u unspecified variable bounds"
+msgstr[0] ""
+msgstr[1] ""
+
+#: c-family/c-warn.cc:3642
+#, gcc-internal-format, gfc-internal-format
+msgid "subsequently declared as %s with %u unspecified variable bound"
+msgid_plural "subsequently declared as %s with %u unspecified variable bounds"
+msgstr[0] ""
+msgstr[1] ""
+
+#: c-family/c-warn.cc:3693
+#, gcc-internal-format
+msgid "argument %u of type %s declared with mismatched bound argument %E"
+msgstr ""
+
+#: c-family/c-warn.cc:3700 c-family/c-warn.cc:3734
+#, gcc-internal-format
+msgid "argument %u of type %s declared with mismatched bound %<%s%>"
+msgstr ""
+
+#: c-family/c-warn.cc:3712
+#, gcc-internal-format
+msgid "previously declared as %s with bound argument %E"
+msgstr ""
+
+#: c-family/c-warn.cc:3717
+#, gcc-internal-format
+msgid "previously declared as %s with bound %<%s%>"
+msgstr ""
+
+#: c-family/c-warn.cc:3737
+#, gcc-internal-format
+msgid "previously declared as %s with bound %qs"
+msgstr ""
+
+#: c-family/c-warn.cc:3756
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %u of type %s with mismatched bound"
+msgstr ""
+
+#: c-family/c-warn.cc:3787
+#, gcc-internal-format
+msgid "expression does not compute the number of elements in this array; element type is %qT, not %qT"
+msgstr ""
+
+#: c-family/c-warn.cc:3797
+#, gcc-internal-format
+msgid "add parentheses around %qE to silence this warning"
+msgstr ""
+
+#: c-family/c-warn.cc:3801
+#, gcc-internal-format
+msgid "add parentheses around the second %<sizeof%> to silence this warning"
+msgstr ""
+
+#: c-family/c-warn.cc:3827
+#, gcc-internal-format
+msgid "comparison between two arrays is deprecated in C++20"
+msgstr ""
+
+#: c-family/c-warn.cc:3828
+#, gcc-internal-format
+msgid "comparison between two arrays"
+msgstr ""
+
+#: c-family/c-warn.cc:3832
+#, gcc-internal-format
+msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
+msgstr ""
+
+#: c-family/c-warn.cc:3839
+#, gcc-internal-format
+msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
+msgstr ""
+
+#: c-family/c-warn.cc:3901
+#, gcc-internal-format
+msgid "result of %<%wu^%wu%> is %wu; did you mean %<1 << %wu%> (%wu)?"
+msgstr ""
+
+#: c-family/c-warn.cc:3911
+#, gcc-internal-format
+msgid "result of %<%wu^%wu%> is %wu; did you mean %<1LL << %wu%>?"
+msgstr ""
+
+#: c-family/c-warn.cc:3918
+#, gcc-internal-format
+msgid "result of %<%wu^%wu%> is %wu; did you mean exponentiation?"
+msgstr ""
+
+#: c-family/c-warn.cc:3929
+#, gcc-internal-format
+msgid "result of %<%wu^%wu%> is %wu; did you mean %<1e%wu%>?"
+msgstr ""
+
+#: c-family/c-warn.cc:3946
+#, gcc-internal-format
+msgid "you can silence this warning by using a hexadecimal constant (%wx rather than %wd)"
+msgstr ""
+
+#: c-family/cppspec.cc:94
+#, gcc-internal-format
+msgid "%qs is not a valid option to the preprocessor"
+msgstr ""
+
+#: c-family/cppspec.cc:113
+#, gcc-internal-format
+msgid "too many input files"
+msgstr ""
+
+#: c-family/known-headers.cc:322
+#, gcc-internal-format
+msgid "%qs is defined in header %qs; this is probably fixable by adding %<#include %s%>"
+msgstr ""
+
+#: common/config/aarch64/aarch64-common.cc:415 config/aarch64/aarch64.cc:18539
+#, gcc-internal-format
+msgid "unknown value %qs for %<-mcpu%>"
+msgstr ""
+
+#: common/config/alpha/alpha-common.cc:75
+#, gcc-internal-format
+msgid "bad value %qs for %<-mtls-size%> switch"
+msgstr ""
+
+#: common/config/arc/arc-common.cc:80
+#, gcc-internal-format
+msgid "multiple %<-mcpu=%> options specified"
+msgstr ""
+
+#: common/config/arc/arc-common.cc:86
+#, gcc-internal-format
+msgid "Unsupported value for mmpy-option"
+msgstr ""
+
+#: common/config/arm/arm-common.cc:289
+#, gcc-internal-format
+msgid "%%:%<target_mode_check%> takes an even number of parameters"
+msgstr ""
+
+#: common/config/arm/arm-common.cc:298
+#, gcc-internal-format
+msgid "unrecognized option passed to %%:%<target_mode_check%>"
+msgstr ""
+
+#: common/config/arm/arm-common.cc:378 common/config/arm/arm-common.cc:442
+#: common/config/arm/arm-common.cc:489 config/aarch64/aarch64.cc:18471
+#: config/aarch64/aarch64.cc:18509
+#, gcc-internal-format
+msgid "valid arguments are: %s; did you mean %qs?"
+msgstr ""
+
+#: common/config/arm/arm-common.cc:381 common/config/arm/arm-common.cc:445
+#: common/config/arm/arm-common.cc:492 config/aarch64/aarch64.cc:18474
+#: config/aarch64/aarch64.cc:18512
+#, gcc-internal-format, gfc-internal-format
+msgid "valid arguments are: %s"
+msgstr ""
+
+#: common/config/arm/arm-common.cc:418 common/config/arm/arm-common.cc:472
+#, gcc-internal-format, gfc-internal-format
+msgid "unrecognized %s target: %s"
+msgstr ""
+
+#: common/config/arm/arm-common.cc:508
+#, gcc-internal-format
+msgid "unrecognized %<-mfpu%> target: %s"
+msgstr ""
+
+#: common/config/arm/arm-common.cc:536
+#, gcc-internal-format
+msgid "%qs does not support feature %qs"
+msgstr ""
+
+#: common/config/arm/arm-common.cc:547
+#, gcc-internal-format
+msgid "valid feature names are: %s; did you mean %qs?"
+msgstr ""
+
+#: common/config/arm/arm-common.cc:550
+#, gcc-internal-format, gfc-internal-format
+msgid "valid feature names are: %s"
+msgstr ""
+
+#: common/config/arm/arm-common.cc:568
+#, gcc-internal-format, gfc-internal-format
+msgid "%s does not take any feature options"
+msgstr ""
+
+#: common/config/arm/arm-common.cc:665
+#, gcc-internal-format
+msgid "%%:%<canon_for_mlib%> takes 1 or more pairs of parameters"
+msgstr ""
+
+#: common/config/arm/arm-common.cc:679
+#, gcc-internal-format
+msgid "unrecognized operand to %%:%<canon_for_mlib%>"
+msgstr ""
+
+#: common/config/arm/arm-common.cc:1038
+#, gcc-internal-format
+msgid "unrecognized operand to %%:%<asm_auto_mfpu%>"
+msgstr ""
+
+#: common/config/avr/avr-common.cc:87
+#, gcc-internal-format
+msgid "option %<-mdouble=64%> is only available if configured %<--with-double={64|64,32|32,64}%>"
+msgstr ""
+
+#: common/config/avr/avr-common.cc:95
+#, gcc-internal-format
+msgid "option %<-mdouble=32%> is only available if configured %<--with-double={32|32,64|64,32}%>"
+msgstr ""
+
+#: common/config/avr/avr-common.cc:111
+#, gcc-internal-format
+msgid "option %<-mlong-double=64%> is only available if configured %<--with-long-double={64|64,32|32,64}%>, or %<--with-long-double=double%> together with %<--with-double={64|64,32|32,64}%>"
+msgstr ""
+
+#: common/config/avr/avr-common.cc:120
+#, gcc-internal-format
+msgid "option %<-mlong-double=32%> is only available if configured %<--with-long-double={32|32,64|64,32}%>, or %<--with-long-double=double%> together with %<--with-double={32|32,64|64,32}%>"
+msgstr ""
+
+#: common/config/bfin/bfin-common.cc:304 common/config/m68k/m68k-common.cc:60
+#, gcc-internal-format
+msgid "%<-mshared-library-id=%s%> is not between 0 and %d"
+msgstr ""
+
+#: common/config/bfin/bfin-common.cc:323
+#, gcc-internal-format
+msgid "%<-mcpu=%s%> is not valid"
+msgstr ""
+
+#: common/config/bfin/bfin-common.cc:359
+#, gcc-internal-format
+msgid "%<-mcpu=%s%> has invalid silicon revision"
+msgstr ""
+
+#: common/config/i386/i386-common.cc:1954
+#, gcc-internal-format
+msgid "%<-malign-loops%> is obsolete, use %<-falign-loops%>"
+msgstr ""
+
+#: common/config/i386/i386-common.cc:1957
+#, gcc-internal-format
+msgid "%<-malign-loops=%d%> is not between 0 and %d"
+msgstr ""
+
+#: common/config/i386/i386-common.cc:1964
+#, gcc-internal-format
+msgid "%<-malign-jumps%> is obsolete, use %<-falign-jumps%>"
+msgstr ""
+
+#: common/config/i386/i386-common.cc:1967
+#, gcc-internal-format
+msgid "%<-malign-jumps=%d%> is not between 0 and %d"
+msgstr ""
+
+#: common/config/i386/i386-common.cc:1975
+#, gcc-internal-format
+msgid "%<-malign-functions%> is obsolete, use %<-falign-functions%>"
+msgstr ""
+
+#: common/config/i386/i386-common.cc:1978
+#, gcc-internal-format
+msgid "%<-malign-functions=%d%> is not between 0 and %d"
+msgstr ""
+
+#: common/config/i386/i386-common.cc:1987
+#, gcc-internal-format
+msgid "%<-mbranch-cost=%d%> is not between 0 and 5"
+msgstr ""
+
+#: common/config/i386/i386-common.cc:2051 common/config/s390/s390-common.cc:137
+#, gcc-internal-format
+msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
+msgstr ""
+
+#: common/config/i386/i386-common.cc:2061
+#, gcc-internal-format
+msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
+msgstr ""
+
+#: common/config/ia64/ia64-common.cc:65
+#, gcc-internal-format
+msgid "bad value %<%s%> for %<-mtls-size=%> switch"
+msgstr ""
+
+#: common/config/nds32/nds32-common.cc:49
+#, gcc-internal-format
+msgid "%<-misr-vector-size=%d%> argument must be 4 or 16"
+msgstr ""
+
+#: common/config/nds32/nds32-common.cc:59
+#, gcc-internal-format
+msgid "%<-misr-secure=%d%> argument not in between 0 and 3"
+msgstr ""
+
+#: common/config/nds32/nds32-common.cc:69
+#, gcc-internal-format
+msgid "for the option %<-mcache-block-size=X%>, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:674
+#, gcc-internal-format
+msgid "%<-march=%s%>: extension %qs appear more than one time"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:683
+#, gcc-internal-format
+msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:691
+#, gcc-internal-format
+msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:699
+#, gcc-internal-format
+msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:707
+#, gcc-internal-format
+msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:955
+#, gcc-internal-format
+msgid "%<-march=%s%>: expect number after %<%dp%>"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:961
+#, gcc-internal-format
+msgid "%<-march=%s%>: for %<%s%dp%dp?%>, version number with more than 2 level is not supported"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:1019
+#, gcc-internal-format
+msgid "%<-march=%s%>: ISA string must begin with rv32 or rv64"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:1043
+#, gcc-internal-format
+msgid "%<-march=%s%>: rv%de is not a valid base ISA"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:1055
+#, gcc-internal-format
+msgid "version of %<g%> will be omitted, please specify version for individual extension"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:1074
+#, gcc-internal-format
+msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:1097
+#, gcc-internal-format
+msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:1228
+#, gcc-internal-format
+msgid "%<-march=%s%>: zcf extension supports in rv32 only"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:1233
+#, gcc-internal-format
+msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:1239
+#, gcc-internal-format
+msgid "%<-march=%s%>: h extension requires i extension"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:1244
+#, gcc-internal-format
+msgid "%<-march=%s%>: zcd conflicts with zcmt"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:1246
+#, gcc-internal-format
+msgid "%<-march=%s%>: zcd conflicts with zcmp"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:1255
+#, gcc-internal-format
+msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:1352
+#, gcc-internal-format
+msgid "%<-march=%s%>: name of %s must be more than 1 letter"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:1364
+#, gcc-internal-format
+msgid "%<-march=%s%>: %s must separate with %<_%>"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:1426
+#, gcc-internal-format
+msgid "%<-march=%s%>: i, e or g must be the first extension"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:1759
+#, gcc-internal-format
+msgid "%<-mcpu=%s%>: unknown CPU"
+msgstr ""
+
+#: common/config/riscv/riscv-common.cc:1838
+#, gcc-internal-format
+msgid "Cannot find suitable multilib set for %<-march=%s%>/%<-mabi=%s%>"
+msgstr ""
+
+#: common/config/rs6000/rs6000-common.cc:175 config/sparc/sparc.cc:1807
+#, gcc-internal-format
+msgid "unknown %<-mdebug-%s%> switch"
+msgstr ""
+
+#: common/config/rs6000/rs6000-common.cc:214
+#, gcc-internal-format
+msgid "unknown switch %<-mlong-double-%s%>"
+msgstr ""
+
+#: common/config/rs6000/rs6000-common.cc:225
+#, gcc-internal-format
+msgid "option %<%s%> requires %<-mlong-double-128%>"
+msgstr ""
+
+#: common/config/rs6000/rs6000-common.cc:259
+#, gcc-internal-format
+msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
+msgstr ""
+
+#: common/config/rx/rx-common.cc:61
+#, gcc-internal-format
+msgid "the RX200 cpu does not have FPU hardware"
+msgstr ""
+
+#: common/config/rx/rx-common.cc:63
+#, gcc-internal-format
+msgid "the RX100 cpu does not have FPU hardware"
+msgstr ""
+
+#: common/config/s390/s390-common.cc:109
+#, gcc-internal-format
+msgid "stack guard value must be an exact power of 2"
+msgstr ""
+
+#: common/config/s390/s390-common.cc:114
+#, gcc-internal-format
+msgid "stack size must be an exact power of 2"
+msgstr ""
+
+#: common/config/v850/v850-common.cc:47
+#, gcc-internal-format
+msgid "value passed in %qs is too large"
+msgstr ""
+
+#: config/darwin-c.cc:81
+#, gcc-internal-format
+msgid "too many %<#pragma options align=reset%>"
+msgstr ""
+
+#: config/darwin-c.cc:101 config/darwin-c.cc:104 config/darwin-c.cc:106
+#: config/darwin-c.cc:108
+#, gcc-internal-format
+msgid "malformed %<#pragma options%>, ignoring"
+msgstr ""
+
+#: config/darwin-c.cc:111
+#, gcc-internal-format
+msgid "junk at end of %<#pragma options%>"
+msgstr ""
+
+#: config/darwin-c.cc:121
+#, gcc-internal-format
+msgid "malformed %<#pragma options align={mac68k|power|reset}%>, ignoring"
+msgstr ""
+
+#: config/darwin-c.cc:133
+#, gcc-internal-format
+msgid "missing %<(%> after %<#pragma unused%>, ignoring"
+msgstr ""
+
+#: config/darwin-c.cc:154
+#, gcc-internal-format
+msgid "missing %<)%> after %<#pragma unused%>, ignoring"
+msgstr ""
+
+#: config/darwin-c.cc:157
+#, gcc-internal-format
+msgid "junk at end of %<#pragma unused%>"
+msgstr ""
+
+#: config/darwin-c.cc:168
+#, gcc-internal-format
+msgid "malformed %<#pragma ms_struct%>, ignoring"
+msgstr ""
+
+#: config/darwin-c.cc:176
+#, gcc-internal-format
+msgid "malformed %<#pragma ms_struct {on|off|reset}%>, ignoring"
+msgstr ""
+
+#: config/darwin-c.cc:179
+#, gcc-internal-format
+msgid "junk at end of %<#pragma ms_struct%>"
+msgstr ""
+
+#: config/darwin-c.cc:405
+#, gcc-internal-format, gfc-internal-format
+msgid "subframework include %s conflicts with framework include"
+msgstr ""
+
+#: config/darwin-c.cc:709
+#, gcc-internal-format
+msgid "unknown value %qs of %<-mmacosx-version-min%>"
+msgstr ""
+
+#: config/darwin-driver.cc:147
+#, gcc-internal-format
+msgid "%<sysctl%> for %<kern.osversion%> failed: %m"
+msgstr ""
+
+#: config/darwin-driver.cc:186
+#, gcc-internal-format
+msgid "could not understand %<kern.osversion%> %q.*s"
+msgstr ""
+
+#: config/darwin-driver.cc:226
+#, gcc-internal-format
+msgid "could not understand version %qs"
+msgstr ""
+
+#: config/darwin-driver.cc:300
+#, gcc-internal-format
+msgid "this compiler does not support %qs"
+msgstr ""
+
+#: config/darwin-driver.cc:326
+#, gcc-internal-format
+msgid "%qs is not valid for %<-mmacosx-version-min%>"
+msgstr ""
+
+#: config/darwin-driver.cc:367
+#, gcc-internal-format
+msgid "this compiler does not support PowerPC (%<-arch%> option ignored)"
+msgstr ""
+
+#: config/darwin-driver.cc:374
+#, gcc-internal-format
+msgid "%qs conflicts with %<-arch i386%> (%qs ignored)"
+msgstr ""
+
+#: config/darwin-driver.cc:383
+#, gcc-internal-format
+msgid "%<-m32%> conflicts with %<-arch x86_64%> (%<-m32%> ignored)"
+msgstr ""
+
+#: config/darwin-driver.cc:390
+#, gcc-internal-format
+msgid "this compiler does not support x86 (%<-arch%> option ignored)"
+msgstr ""
+
+#: config/darwin-driver.cc:397
+#, gcc-internal-format
+msgid "%qs conflicts with %<-arch ppc%> (%qs ignored)"
+msgstr ""
+
+#: config/darwin-driver.cc:406
+#, gcc-internal-format
+msgid "%<-m32%> conflicts with %<-arch ppc64%> (%<-m32%> ignored)"
+msgstr ""
+
+#: config/darwin.cc:2089
+#, gcc-internal-format, gfc-internal-format
+msgid "failed to open temporary file %s for LTO output"
+msgstr ""
+
+#: config/darwin.cc:2181
+#, gcc-internal-format
+msgid "%qE 2.95 vtable-compatibility attribute applies only when compiling a kext"
+msgstr ""
+
+#: config/darwin.cc:2188
+#, gcc-internal-format
+msgid "%qE 2.95 vtable-compatibility attribute applies only to C++ classes"
+msgstr ""
+
+#: config/darwin.cc:2781 config/darwin.cc:2845
+#, gcc-internal-format
+msgid "common variables must have an alignment of 32678 or less"
+msgstr ""
+
+#: config/darwin.cc:2935
+#, gcc-internal-format
+msgid "protected visibility attribute not supported in this configuration; ignored"
+msgstr ""
+
+#: config/darwin.cc:3178
+#, gcc-internal-format, gfc-internal-format
+msgid "failed to open temporary file %s with LTO output"
+msgstr ""
+
+#: config/darwin.cc:3408
+#, gcc-internal-format
+msgid "%<-fobjc-abi-version%> 2 must be used for 64 bit targets with %<-fnext-runtime%>"
+msgstr ""
+
+#: config/darwin.cc:3413
+#, gcc-internal-format
+msgid "%<-fobjc-abi-version%> %d is not supported for 32 bit targets with %<-fnext-runtime%>"
+msgstr ""
+
+#: config/darwin.cc:3435
+#, gcc-internal-format
+msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
+msgstr ""
+
+#: config/darwin.cc:3449
+#, gcc-internal-format
+msgid "%<-g3%> is not supported by the debug linker in use (set to 2)"
+msgstr ""
+
+#: config/darwin.cc:3541
+#, gcc-internal-format
+msgid "%<-mdynamic-no-pic%> overrides %<-fpic%>, %<-fPIC%>, %<-fpie%> or %<-fPIE%>"
+msgstr ""
+
+#: config/darwin.cc:3584
+#, gcc-internal-format
+msgid "%<-mpic-symbol-stubs%> is not required for 64-bit code (ignored)"
+msgstr ""
+
+#: config/darwin.cc:3787
+#, gcc-internal-format
+msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
+msgstr ""
+
+#: config/darwin.cc:3794
+#, gcc-internal-format
+msgid "built-in function %qD takes one argument only"
+msgstr ""
+
+#: config/darwin.cc:3838
+#, gcc-internal-format
+msgid "CFString literal is missing"
+msgstr ""
+
+#: config/darwin.cc:3849
+#, gcc-internal-format
+msgid "CFString literal expression is not a string constant"
+msgstr ""
+
+#: config/darwin.cc:3873
+#, gcc-internal-format
+msgid "non-ASCII character in CFString literal"
+msgstr ""
+
+#: config/darwin.cc:3874
+#, gcc-internal-format
+msgid "embedded NUL in CFString literal"
+msgstr ""
+
+#: config/host-darwin.cc:107
+#, gcc-internal-format
+msgid "PCH memory is not available: %m"
+msgstr ""
+
+#: config/sol2-c.cc:91 config/sol2-c.cc:107
+#, gcc-internal-format
+msgid "malformed %<#pragma align%>, ignoring"
+msgstr ""
+
+#: config/sol2-c.cc:100
+#, gcc-internal-format
+msgid "invalid alignment for %<#pragma align%>, ignoring"
+msgstr ""
+
+#: config/sol2-c.cc:115
+#, gcc-internal-format
+msgid "%<#pragma align%> must appear before the declaration of %qD, ignoring"
+msgstr ""
+
+#: config/sol2-c.cc:127 config/sol2-c.cc:139
+#, gcc-internal-format
+msgid "malformed %<#pragma align%>"
+msgstr ""
+
+#: config/sol2-c.cc:134
+#, gcc-internal-format
+msgid "junk at end of %<#pragma align%>"
+msgstr ""
+
+#: config/sol2-c.cc:155 config/sol2-c.cc:162
+#, gcc-internal-format
+msgid "malformed %<#pragma init%>, ignoring"
+msgstr ""
+
+#: config/sol2-c.cc:186 config/sol2-c.cc:198
+#, gcc-internal-format
+msgid "malformed %<#pragma init%>"
+msgstr ""
+
+#: config/sol2-c.cc:193
+#, gcc-internal-format
+msgid "junk at end of %<#pragma init%>"
+msgstr ""
+
+#: config/sol2-c.cc:214 config/sol2-c.cc:221
+#, gcc-internal-format
+msgid "malformed %<#pragma fini%>, ignoring"
+msgstr ""
+
+#: config/sol2-c.cc:245 config/sol2-c.cc:257
+#, gcc-internal-format
+msgid "malformed %<#pragma fini%>"
+msgstr ""
+
+#: config/sol2-c.cc:252
+#, gcc-internal-format
+msgid "junk at end of %<#pragma fini%>"
+msgstr ""
+
+#: config/sol2.cc:58
+#, gcc-internal-format
+msgid "ignoring %<#pragma align%> for explicitly aligned %q+D"
+msgstr ""
+
+#: config/vxworks.cc:165
+#, gcc-internal-format
+msgid "PIC is only supported for RTPs"
+msgstr ""
+
+#: config/aarch64/aarch64-builtins.cc:2123
+#, gcc-internal-format
+msgid "first argument to %qD must be a string literal"
+msgstr ""
+
+#: config/aarch64/aarch64-builtins.cc:2254
+#: config/aarch64/aarch64-builtins.cc:2488 config/arm/arm-builtins.cc:3146
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %d must be a constant immediate"
+msgstr ""
+
+#: config/aarch64/aarch64-builtins.cc:2326 config/arm/arm-builtins.cc:3494
+#, gcc-internal-format
+msgid "lane index must be a constant immediate"
+msgstr ""
+
+#: config/aarch64/aarch64-builtins.cc:2330
+#, gcc-internal-format
+msgid "total size and element size must be a nonzero constant immediate"
+msgstr ""
+
+#: config/aarch64/aarch64-builtins.cc:2578
+#, gcc-internal-format
+msgid "argument must be a 16-bit constant immediate"
+msgstr ""
+
+#: config/aarch64/aarch64-builtins.cc:2701
+#, gcc-internal-format
+msgid "128-bit system register support requires the %<d128%> extension"
+msgstr ""
+
+#: config/aarch64/aarch64-builtins.cc:2716
+#, gcc-internal-format
+msgid "invalid system register name provided"
+msgstr ""
+
+#: config/aarch64/aarch64-builtins.cc:2730
+#, gcc-internal-format
+msgid "invalid system register name %qs"
+msgstr ""
+
+#: config/aarch64/aarch64-builtins.cc:2810
+#, gcc-internal-format
+msgid "Constant-type argument expected"
+msgstr ""
+
+#: config/aarch64/aarch64-builtins.cc:2816
+#, gcc-internal-format
+msgid "argument %d must be a constant immediate in range [%wd,%wd]"
+msgstr ""
+
+#: config/aarch64/aarch64-builtins.cc:2895
+#, gcc-internal-format
+msgid "Memory Tagging Extension does not support %<-mabi=ilp32%>"
+msgstr ""
+
+#: config/aarch64/aarch64-builtins.cc:2930
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %d must be a constant immediate in range [0,15]"
+msgstr ""
+
+#: config/aarch64/aarch64-builtins.cc:3728
+#: config/aarch64/aarch64-builtins.cc:3748
+#, gcc-internal-format, gfc-internal-format
+msgid "expected 64-bit address but argument 1 is %d-bit"
+msgstr ""
+
+#: config/aarch64/aarch64-builtins.cc:3732
+#, gcc-internal-format, gfc-internal-format
+msgid "expected 64-bit address but argument 2 is %d-bit"
+msgstr ""
+
+#: config/aarch64/aarch64-c.cc:347
+#, gcc-internal-format
+msgid "%<#pragma GCC aarch64%> requires a string parameter"
+msgstr ""
+
+#: config/aarch64/aarch64-c.cc:363
+#, gcc-internal-format
+msgid "unknown %<#pragma GCC aarch64%> option %qs"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1089
+#: config/arm/arm-mve-builtins.cc:558
+#, gcc-internal-format
+msgid "ACLE function %qD requires ISA extension %qs"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1091 config/aarch64/aarch64.cc:11151
+#: config/aarch64/aarch64.cc:18314 config/aarch64/aarch64.cc:19086
+#, gcc-internal-format
+msgid "you can enable %qs using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1111
+#, gcc-internal-format
+msgid "ACLE function %qD is incompatible with the use of %qs"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1133
+#, gcc-internal-format
+msgid "ACLE function %qD cannot be called when SME streaming mode is enabled"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1140
+#, gcc-internal-format
+msgid "ACLE function %qD can only be called when SME streaming mode is enabled"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1147
+#, gcc-internal-format
+msgid "ACLE function %qD can only be called from a function that has %qs state"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1175
+#: config/arm/arm-mve-builtins.cc:571
+#: config/riscv/riscv-vector-builtins.cc:4246
+#, gcc-internal-format
+msgid "argument %d of %qE must be an integer constant expression"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1188
+#, gcc-internal-format
+msgid "passing %wd to argument %d of %qE, which expects the value %wd"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1191
+#: config/arm/arm-mve-builtins.cc:583
+#: config/riscv/riscv-vector-builtins.cc:4260
+#, gcc-internal-format
+msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1204
+#, gcc-internal-format
+msgid "passing %wd to argument %d of %qE, which expects either %wd or %wd"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1217
+#, gcc-internal-format
+msgid "passing %wd to argument %d of %qE, which expects %wd, %wd, %wd or %wd"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1229
+#: config/arm/arm-mve-builtins.cc:595
+#, gcc-internal-format
+msgid "passing %wd to argument %d of %qE, which expects a valid %qT value"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1762
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects a single SVE vector rather than a tuple"
+msgstr ""
+
+#. num_vectors is always != 1, so the singular isn't needed.
+#: config/aarch64/aarch64-sve-builtins.cc:1768
+#: config/aarch64/aarch64-sve-builtins.cc:1774
+#: config/arm/arm-mve-builtins.cc:1205 config/arm/arm-mve-builtins.cc:1211
+#, gcc-internal-format
+msgid "%qT%d%qE%d"
+msgid_plural "passing single vector %qT to argument %d of %qE, which expects a tuple of %d vectors"
+msgstr[0] ""
+msgstr[1] ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1806
+#, gcc-internal-format
+msgid "passing tuple %qT to argument %d of %qE after passing single vector %qT to argument %d"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1811
+#, gcc-internal-format
+msgid "passing single vector %qT to argument %d of %qE after passing tuple %qT to argument %d"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1816
+#, gcc-internal-format
+msgid "passing mismatched tuple types %qT and %qT to arguments %d and %d of %qE"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1827
+#: config/arm/arm-mve-builtins.cc:1104
+#, gcc-internal-format
+msgid "%qE has no form that takes %qT arguments"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1888
+#, gcc-internal-format
+msgid "%qE has no form that takes %qT and %qT arguments"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1950
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects an %qs or %qs"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:1981
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects a 32-bit or 64-bit integer type"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2000
+#, gcc-internal-format
+msgid "passing %qT and %qT to arguments %d and %d of %qE, which expects a pair of 64-bit integers"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2024
+#, gcc-internal-format
+msgid "passing mismatched integer types %qT and %qT to arguments %d and %d of %qE"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2045
+#: config/arm/arm-mve-builtins.cc:1157
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects a pointer type"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2048
+#, gcc-internal-format
+msgid "an explicit type suffix is needed when using a vector of base addresses"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2057
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, but %qT is not a valid SVE element type"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2065
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects a pointer to 32-bit or 64-bit elements"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2107
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects an SVE type rather than a scalar type"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2111
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects an SVE type"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2156
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects a vector of integers"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2186
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects a 128 bit NEON vector type"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2203
+#: config/aarch64/aarch64-sve-builtins.cc:2501
+#: config/arm/arm-mve-builtins.cc:1403
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects a vector of unsigned integers"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2224
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects a vector of 32-bit or 64-bit elements"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2266
+#, gcc-internal-format
+msgid "operations on multiple vectors must be predicated by %qs rather than %qs"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2269
+#, gcc-internal-format
+msgid "operations on single vectors must be predicated by %qs rather than %qs"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2285
+#: config/arm/arm-mve-builtins.cc:1248
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects a vector or scalar type"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2307
+#: config/aarch64/aarch64-sve-builtins.cc:2958
+#: config/arm/arm-mve-builtins.cc:1270
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects %qT"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2334
+#: config/aarch64/aarch64-sve-builtins.cc:2450
+#: config/aarch64/aarch64-sve-builtins.cc:2579
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, but argument %d had type %qT"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2445
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, but argument %d was a tuple of %qT"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2469
+#: config/arm/arm-mve-builtins.cc:1384
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects a vector of %d-bit elements"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2474
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects vectors of %d-bit elements"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2487
+#: config/arm/arm-mve-builtins.cc:1396
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects a vector of signed integers"
+msgstr ""
+
+#. Translation note: could also be written "expects a tuple of
+#. signed integer vectors".
+#: config/aarch64/aarch64-sve-builtins.cc:2493
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects vectors of signed integers"
+msgstr ""
+
+#. Translation note: could also be written "expects a tuple of
+#. unsigned integer vectors".
+#: config/aarch64/aarch64-sve-builtins.cc:2507
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects vectors of unsigned integers"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2527
+#: config/arm/arm-mve-builtins.cc:1423
+#, gcc-internal-format
+msgid "arguments %d and %d of %qE must have the same element size, but the values passed here have type %qT and %qT respectively"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2547
+#: config/arm/arm-mve-builtins.cc:1444
+#, gcc-internal-format
+msgid "arguments %d and %d of %qE must have the same signedness, but the values passed here have type %qT and %qT respectively"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2558
+#: config/arm/arm-mve-builtins.cc:1455
+#, gcc-internal-format
+msgid "passing %qT instead of the expected %qT to argument %d of %qE, after passing %qT to argument %d"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2598
+#: config/arm/arm-mve-builtins.cc:1540
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects %qs"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2616
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which does not accept scalars for this combination of arguments"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2632
+#: config/arm/arm-mve-builtins.cc:1556
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects a scalar pointer"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2655
+#, gcc-internal-format
+msgid "call to %qE is ambiguous; argument %d has type %qs but argument %d has type %qs"
+msgstr ""
+
+#. It doesn't really matter whether the element is expected to be
+#. the same size as type suffix 0.
+#: config/aarch64/aarch64-sve-builtins.cc:2700
+#: config/arm/arm-mve-builtins.cc:1501
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects a scalar element"
+msgstr ""
+
+#. It doesn't seem useful to distinguish between signed and unsigned
+#. scalars here.
+#: config/aarch64/aarch64-sve-builtins.cc:2706
+#: config/arm/arm-mve-builtins.cc:1507
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects a scalar integer"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2742
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects %qs or %qs"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2762
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects a vector of 32-bit or 64-bit integers"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2812
+#, gcc-internal-format
+msgid "when storing %qT, %qE requires a vector base and a scalar index"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2817
+#, gcc-internal-format
+msgid "%qE requires a vector base and a scalar index"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2821
+#, gcc-internal-format
+msgid "%qE does not support 32-bit vector type %qT"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2849
+#, gcc-internal-format
+msgid "%qE does not support 32-bit sign-extended offsets"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2852
+#, gcc-internal-format
+msgid "%qE does not support sign-extended offsets"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2865
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which when loading %qT expects a vector of %d-bit integers"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2870
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which when storing %qT expects a vector of %d-bit integers"
+msgstr ""
+
+#. TYPE is part of the function name.
+#: config/aarch64/aarch64-sve-builtins.cc:2877
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects a vector of %d-bit integers"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:2925
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects a vector or pointer base address"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:3009
+#, gcc-internal-format
+msgid "cannot combine a base of type %qT with an offset of type %qT"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:3013
+#, gcc-internal-format
+msgid "cannot combine a base of type %qT with an index of type %qT"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:3102
+#: config/arm/arm-mve-builtins.cc:1666
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, but its %qT form does not accept scalars"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:3166
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, but its %qT form does not accept single vectors"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:4660
+#: config/arm/arm-mve-builtins.cc:466 config/arm/arm-mve-builtins.cc:491
+#: config/riscv/riscv-vector-builtins.cc:4589
+#, gcc-internal-format
+msgid "duplicate definition of %qs"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:4717
+#, gcc-internal-format
+msgid "%qs defined without first defining %qs"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:4868
+#, gcc-internal-format
+msgid "%qs applied to non-SVE type %qT"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:4874
+#, gcc-internal-format
+msgid "%qs applied to non-vector type %qT"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:4881
+#, gcc-internal-format
+msgid "%qs applied to type %qT, which already has a size"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:4889
+#, gcc-internal-format
+msgid "%qs requires an integer constant expression"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:4897
+#, gcc-internal-format
+msgid "unsupported SVE vector size"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:5011
+#, gcc-internal-format
+msgid "SVE type %qT does not have a fixed size"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:5016
+#, gcc-internal-format
+msgid "SVE type %qT does not have a defined alignment"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:5021
+#: config/riscv/riscv-vector-builtins.cc:4501
+#, gcc-internal-format
+msgid "variables of type %qT cannot have thread-local storage duration"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:5027
+#, gcc-internal-format
+msgid "arithmetic on pointer to SVE type %qT"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:5034
+#, gcc-internal-format
+msgid "member variables cannot have SVE type %qT"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:5036
+#, gcc-internal-format
+msgid "fields cannot have SVE type %qT"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:5041
+#, gcc-internal-format
+msgid "array elements cannot have SVE type %qT"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:5046
+#, gcc-internal-format
+msgid "cannot allocate objects with SVE type %qT"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:5051
+#, gcc-internal-format
+msgid "cannot delete objects with SVE type %qT"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:5056
+#, gcc-internal-format
+msgid "cannot throw or catch SVE type %qT"
+msgstr ""
+
+#: config/aarch64/aarch64-sve-builtins.cc:5061
+#, gcc-internal-format
+msgid "capture by copy of SVE type %qT"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:637
+#, gcc-internal-format
+msgid "the arguments to %qE must be constant strings"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:645
+#, gcc-internal-format
+msgid "unrecognized state string %qs"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:729
+#, gcc-internal-format
+msgid "the %qE attribute cannot be applied to an SVE function type"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:756
+#, gcc-internal-format
+msgid "cannot create a new %qs scope since %qs is shared with callers"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:772
+#, gcc-internal-format
+msgid "%qE attribute applies only to function definitions"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:818
+#, gcc-internal-format
+msgid "inconsistent attributes for state %qs"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:1307
+#, gcc-internal-format
+msgid "%qs is incompatible with the use of floating-point types"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:1310
+#, gcc-internal-format
+msgid "%qs is incompatible with the use of vector types"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:1314
+#, gcc-internal-format
+msgid "%qs feature modifier is incompatible with the use of floating-point types"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:1317
+#, gcc-internal-format
+msgid "%qs feature modifier is incompatible with the use of vector types"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:1333
+#, gcc-internal-format
+msgid "this operation requires the SVE ISA extension"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:1334
+#, gcc-internal-format
+msgid "you can enable SVE using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
+msgstr ""
+
+#. We can't gracefully recover at this point, so make this a
+#. fatal error.
+#: config/aarch64/aarch64.cc:6403
+#, gcc-internal-format
+msgid "arguments of type %qT require the SVE ISA extension"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:6880
+#, gcc-internal-format
+msgid "SVE type %qT cannot be passed to an unprototyped function"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:7021 config/aarch64/aarch64.cc:7100
+#: config/aarch64/aarch64.cc:21321
+#, gcc-internal-format
+msgid "parameter passing for argument of type %qT changed in GCC 13.1"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:7028 config/aarch64/aarch64.cc:7107
+#: config/aarch64/aarch64.cc:21328
+#, gcc-internal-format
+msgid "parameter passing for argument of type %qT changed in GCC 14.1"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
+#: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
+#: config/arm/arm.cc:7372 config/arm/arm.cc:29548
+#, gcc-internal-format
+msgid "parameter passing for argument of type %qT changed in GCC 9.1"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:7240
+#, gcc-internal-format
+msgid "%qE requires the SVE ISA extension"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:7243
+#, gcc-internal-format
+msgid "calls to functions of type %qT require the SVE ISA extension"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:7431
+#, gcc-internal-format
+msgid "stack probes for SVE frames"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:11149
+#, gcc-internal-format
+msgid "calling a streaming function requires the ISA extension %qs"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:11158 config/aarch64/aarch64.cc:11162
+#, gcc-internal-format
+msgid "call to a function that shares %qs state from a function that has no %qs state"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:11165
+#, gcc-internal-format
+msgid "call to a function that shares SME state from a function that has no SME state"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:11223
+#, gcc-internal-format
+msgid "call to a function that shares state other than %qs from a function that has %qs state"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:11225
+#, gcc-internal-format
+msgid "use %<__arm_preserves(\"za\")%> if the callee preserves ZA"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:17932
+#, gcc-internal-format
+msgid "unknown flag passed in %<-moverride=%s%> (%s)"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:17976
+#, gcc-internal-format
+msgid "%qs string ill-formed"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18032
+#, gcc-internal-format
+msgid "invalid format for %<sve_width%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18044
+#, gcc-internal-format
+msgid "invalid %<sve_width%> value: %d"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18064
+#, gcc-internal-format, gfc-internal-format
+msgid "tuning string missing in option (%s)"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18082
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown tuning option (%s)"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18270 config/arm/arm.cc:3227
+#: config/riscv/riscv.cc:9369
+#, gcc-internal-format
+msgid "incompatible options %<-mstack-protector-guard=global%> and %<-mstack-protector-guard-offset=%s%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18279 config/riscv/riscv.cc:9378
+#, gcc-internal-format
+msgid "both %<-mstack-protector-guard-offset%> and %<-mstack-protector-guard-reg%> must be used with %<-mstack-protector-guard=sysreg%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18287
+#, gcc-internal-format
+msgid "specify a system register with a small string length"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18297 config/arm/arm.cc:3239
+#: config/riscv/riscv.cc:9407 config/rs6000/rs6000.cc:4497
+#, gcc-internal-format
+msgid "%qs is not a valid offset in %qs"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18304
+#, gcc-internal-format
+msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18310
+#, gcc-internal-format
+msgid "streaming functions require the ISA extension %qs"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18312
+#, gcc-internal-format
+msgid "functions with SME state require the ISA extension %qs"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18406
+#, gcc-internal-format
+msgid "only values 12 (4 KB) and 16 (64 KB) are supported for guard size.  Given value %d (%llu KB) is out of range"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18422
+#, gcc-internal-format
+msgid "stack clash guard size %<%d%> must be equal to probing interval %<%d%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18536
+#, gcc-internal-format
+msgid "missing cpu name in %<-mcpu=%s%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18546
+#, gcc-internal-format
+msgid "did you mean %<-march=%s%>?"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18549
+#, gcc-internal-format
+msgid "invalid feature modifier %qs in %<-mcpu=%s%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18608
+#, gcc-internal-format
+msgid "invalid argument given to %<-mharden-sls=%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18619
+#, gcc-internal-format
+msgid "%qs must be by itself for %<-mharden-sls=%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18624
+#, gcc-internal-format
+msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18652
+#, gcc-internal-format
+msgid "missing arch name in %<-march=%s%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18655
+#, gcc-internal-format
+msgid "unknown value %qs for %<-march%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18661
+#, gcc-internal-format
+msgid "did you mean %<-mcpu=%s%>?"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18664
+#, gcc-internal-format
+msgid "invalid feature modifier %qs in %<-march=%s%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18692
+#, gcc-internal-format
+msgid "missing cpu name in %<-mtune=%s%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18695
+#, gcc-internal-format
+msgid "unknown value %qs for %<-mtune%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18847
+#, gcc-internal-format
+msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch and resulted in options %<%s%> being added"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18903
+#, gcc-internal-format
+msgid "assembler does not support %<-mabi=ilp32%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18910
+#, gcc-internal-format
+msgid "return address signing is only supported for %<-mabi=lp64%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18983
+#, gcc-internal-format
+msgid "code model %qs with %<-f%s%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:18986
+#, gcc-internal-format
+msgid "code model %qs not supported in ilp32 mode"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19084
+#, gcc-internal-format
+msgid "functions with %qs state require the ISA extension %qs"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19187
+#, gcc-internal-format
+msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19190
+#, gcc-internal-format
+msgid "invalid name %qs in %<target(\"arch=\")%> pragma or attribute"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19194
+#, gcc-internal-format
+msgid "invalid feature modifier %s of value %qs in %<target()%> pragma or attribute"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19228
+#, gcc-internal-format
+msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19231
+#, gcc-internal-format
+msgid "invalid name %qs in %<target(\"cpu=\")%> pragma or attribute"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19235 config/aarch64/aarch64.cc:19319
+#, gcc-internal-format
+msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19274
+#, gcc-internal-format
+msgid "invalid name %qs in %<target(\"tune=\")%> pragma or attribute"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19315
+#, gcc-internal-format
+msgid "missing value in %<target()%> pragma or attribute"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19373 config/aarch64/aarch64.cc:19546
+#, gcc-internal-format
+msgid "malformed %<target()%> pragma or attribute"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19417
+#, gcc-internal-format
+msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19425 config/i386/i386-options.cc:1303
+#, gcc-internal-format
+msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19479
+#, gcc-internal-format
+msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19536 config/arm/arm.cc:33805
+#: config/riscv/riscv-target-attr.cc:331 config/rs6000/rs6000.cc:24699
+#: config/s390/s390.cc:16422
+#, gcc-internal-format
+msgid "attribute %<target%> argument not a string"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19571
+#, gcc-internal-format
+msgid "arch extension %<%s%> should be prefixed by %<+%>"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19574
+#, gcc-internal-format
+msgid "pragma or attribute %<target(\"%s\")%> is not valid"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19583
+#, gcc-internal-format
+msgid "malformed %<target(\"%s\")%> pragma or attribute"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19801
+#, gcc-internal-format
+msgid "attribute %<target_version%> has multiple values"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19809
+#, gcc-internal-format
+msgid "attribute %<target_version%> argument not a string"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19831
+#, gcc-internal-format
+msgid "missing value in %<target_version%> attribute"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19835
+#, gcc-internal-format
+msgid "invalid feature modifier %qs of value %qs in %<target_version%> attribute"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:19841
+#, gcc-internal-format
+msgid "duplicate feature modifier %qs of value %qs in %<target_version%> attribute"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:20420 config/i386/i386-features.cc:3521
+#: config/i386/i386-features.cc:3790
+#, gcc-internal-format
+msgid "virtual function multiversioning not supported"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:20541 config/i386/i386-features.cc:3654
+#: config/rs6000/rs6000.cc:25389
+#, gcc-internal-format
+msgid "multiversioning needs %<ifunc%> which is not supported on this target"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:22089 config/arm/arm.cc:6690
+#: config/rs6000/rs6000-call.cc:366 config/s390/s390.cc:12779
+msgid "parameter passing for argument of type %qT with %<[[no_unique_address]]%> members changed %{in GCC 10.1%}"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:22094 config/arm/arm.cc:6695
+#: config/rs6000/rs6000-call.cc:361 config/s390/s390.cc:12774
+msgid "parameter passing for argument of type %qT when C++17 is enabled changed to match C++14 %{in GCC 10.1%}"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:22099 config/arm/arm.cc:6700
+msgid "parameter passing for argument of type %qT changed %{in GCC 12.1%}"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:23323 config/aarch64/aarch64.cc:23326
+#, gcc-internal-format
+msgid "lane %wd out of range %wd - %wd"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:28749 config/i386/i386.cc:25293
+#: config/i386/i386.cc:25424
+#, gcc-internal-format
+msgid "unsupported simdlen %wd"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:28763
+#, gcc-internal-format
+msgid "GCC does not currently support return type %qT for simd"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
+#, gcc-internal-format
+msgid "unsupported return type %qT for simd"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:28797
+#, gcc-internal-format
+msgid "GCC does not currently support argument type %qT for simd"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
+#, gcc-internal-format
+msgid "unsupported argument type %qT for simd"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:28850
+#, gcc-internal-format
+msgid "GCC does not currently support simdlen %wd for type %qT"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:28871
+#, gcc-internal-format
+msgid "GCC does not currently support a simdclone with simdlens %wd and %wd for these types."
+msgstr ""
+
+#: config/aarch64/aarch64.cc:28961
+#, gcc-internal-format
+msgid "cannot apply attribute %qs to %q+D after the function has been defined"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:28963
+#, gcc-internal-format
+msgid "%q+D defined here"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:29421
+#, gcc-internal-format
+msgid "non-local gotos in functions with SME state"
+msgstr ""
+
+#: config/aarch64/aarch64.cc:29730
+#, gcc-internal-format
+msgid "catching non-call exceptions in functions with SME state"
+msgstr ""
+
+#: config/alpha/alpha.cc:420
+#, gcc-internal-format
+msgid "bad value %qs for %<-mtrap-precision%> switch"
+msgstr ""
+
+#: config/alpha/alpha.cc:435
+#, gcc-internal-format
+msgid "bad value %qs for %<-mfp-rounding-mode%> switch"
+msgstr ""
+
+#: config/alpha/alpha.cc:450
+#, gcc-internal-format
+msgid "bad value %qs for %<-mfp-trap-mode%> switch"
+msgstr ""
+
+#: config/alpha/alpha.cc:468
+#, gcc-internal-format
+msgid "bad value %qs for %<-mcpu%> switch"
+msgstr ""
+
+#: config/alpha/alpha.cc:483
+#, gcc-internal-format
+msgid "bad value %qs for %<-mtune%> switch"
+msgstr ""
+
+#: config/alpha/alpha.cc:501
+#, gcc-internal-format
+msgid "fp software completion requires %<-mtrap-precision=i%>"
+msgstr ""
+
+#: config/alpha/alpha.cc:517
+#, gcc-internal-format
+msgid "rounding mode not supported for VAX floats"
+msgstr ""
+
+#: config/alpha/alpha.cc:522
+#, gcc-internal-format
+msgid "trap mode not supported for VAX floats"
+msgstr ""
+
+#: config/alpha/alpha.cc:526
+#, gcc-internal-format
+msgid "128-bit %<long double%> not supported for VAX floats"
+msgstr ""
+
+#: config/alpha/alpha.cc:554
+#, gcc-internal-format, gfc-internal-format
+msgid "L%d cache latency unknown for %s"
+msgstr ""
+
+#: config/alpha/alpha.cc:569
+#, gcc-internal-format
+msgid "bad value %qs for %<-mmemory-latency%>"
+msgstr ""
+
+#: config/alpha/alpha.cc:6671 config/alpha/alpha.cc:6674 config/arc/arc.cc:6981
+#: config/arc/arc.cc:7255 config/s390/s390.cc:960
+#, gcc-internal-format
+msgid "bad builtin fcode"
+msgstr ""
+
+#: config/arc/arc.cc:1003
+#, gcc-internal-format
+msgid "%<-mno-mpy%> supported only for ARC700 or ARCv2"
+msgstr ""
+
+#: config/arc/arc.cc:1006
+#, gcc-internal-format
+msgid "%<-mno-dpfp-lrsr%> supported only with %<-mdpfp%>"
+msgstr ""
+
+#: config/arc/arc.cc:1011
+#, gcc-internal-format
+msgid "FPX fast and compact options cannot be specified together"
+msgstr ""
+
+#: config/arc/arc.cc:1015
+#, gcc-internal-format
+msgid "%<-mspfp_fast%> not available on ARC600 or ARC601"
+msgstr ""
+
+#: config/arc/arc.cc:1020
+#, gcc-internal-format
+msgid "no FPX/FPU mixing allowed"
+msgstr ""
+
+#: config/arc/arc.cc:1025
+#, gcc-internal-format
+msgid "PIC is not supported for %qs"
+msgstr ""
+
+#: config/arc/arc.cc:1061
+#, gcc-internal-format
+msgid "missing dash"
+msgstr ""
+
+#: config/arc/arc.cc:1073
+#, gcc-internal-format
+msgid "first register must be R0"
+msgstr ""
+
+#: config/arc/arc.cc:1093
+#, gcc-internal-format, gfc-internal-format
+msgid "last register name %s must be an odd register"
+msgstr ""
+
+#: config/arc/arc.cc:1102 config/ia64/ia64.cc:6062 config/pa/pa.cc:488
+#: config/sh/sh.cc:8293
+#, gcc-internal-format, gfc-internal-format
+msgid "%s-%s is an empty range"
+msgstr ""
+
+#: config/arc/arc.cc:1152
+#, gcc-internal-format
+msgid "invalid number in %<-mrgf-banked-regs=%s%> valid values are 0, 4, 8, 16, or 32"
+msgstr ""
+
+#: config/arc/arc.cc:1214
+#, gcc-internal-format
+msgid "option %<-mirq-ctrl-saved%> valid only for ARC v2 processors"
+msgstr ""
+
+#: config/arc/arc.cc:1223
+#, gcc-internal-format
+msgid "option %<-mrgf-banked-regs%> valid only for ARC v2 processors"
+msgstr ""
+
+#. Check options against architecture options.  Throw an error if
+#. option is not allowed.  Extra, check options against default
+#. architecture/cpu flags and throw an warning if we find a
+#. mismatch.
+#. TRANSLATORS: the DOC/DOC0/DOC1 are strings which shouldn't be
+#. translated.  They are like keywords which one can relate with the
+#. architectural choices taken for an ARC CPU implementation.
+#: config/arc/arc.cc:1267
+#, gcc-internal-format
+msgid "option %<%s=%s%> is not available for %qs CPU"
+msgstr ""
+
+#: config/arc/arc.cc:1272
+#, gcc-internal-format
+msgid "option %qs is ignored, the default value %qs is considered for %qs CPU"
+msgstr ""
+
+#: config/arc/arc.cc:1280
+#, gcc-internal-format
+msgid "option %qs is not available for %qs CPU"
+msgstr ""
+
+#: config/arc/arc.cc:1285
+#, gcc-internal-format
+msgid "unset option %qs is ignored, it is always enabled for %qs CPU"
+msgstr ""
+
+#: config/arc/arc.cc:1857
+#, gcc-internal-format, gfc-internal-format
+msgid "multiply option implies r%d is fixed"
+msgstr ""
+
+#: config/arc/arc.cc:2005 config/epiphany/epiphany.cc:505
+#: config/epiphany/epiphany.cc:547
+#, gcc-internal-format
+msgid "argument of %qE attribute is not a string constant"
+msgstr ""
+
+#: config/arc/arc.cc:2014
+#, gcc-internal-format
+msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
+msgstr ""
+
+#: config/arc/arc.cc:2023
+#, gcc-internal-format
+msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
+msgstr ""
+
+#: config/arc/arc.cc:2037 config/arm/arm.cc:7483 config/arm/arm.cc:7501
+#: config/arm/arm.cc:7680 config/avr/avr.cc:11273 config/avr/avr.cc:11287
+#: config/bfin/bfin.cc:4695 config/bfin/bfin.cc:4756 config/bfin/bfin.cc:4786
+#: config/bpf/bpf.cc:93 config/csky/csky.cc:6459 config/csky/csky.cc:6487
+#: config/epiphany/epiphany.cc:488 config/gcn/gcn.cc:379
+#: config/h8300/h8300.cc:4948 config/i386/i386-options.cc:3732
+#: config/i386/i386-options.cc:3909 config/i386/i386-options.cc:3965
+#: config/i386/i386-options.cc:4016 config/i386/i386-options.cc:4053
+#: config/m68k/m68k.cc:796 config/mcore/mcore.cc:3067
+#: config/nvptx/nvptx.cc:5801 config/riscv/riscv.cc:5784
+#: config/rl78/rl78.cc:820 config/rl78/rl78.cc:889
+#: config/rs6000/rs6000.cc:20650 config/rx/rx.cc:2728 config/rx/rx.cc:2754
+#: config/s390/s390.cc:1175 config/s390/s390.cc:1262 config/sh/sh.cc:8429
+#: config/sh/sh.cc:8447 config/sh/sh.cc:8471 config/sh/sh.cc:8542
+#: config/sh/sh.cc:8565 config/stormy16/stormy16.cc:2403
+#: config/v850/v850.cc:2010 config/visium/visium.cc:724
+#, gcc-internal-format
+msgid "%qE attribute only applies to functions"
+msgstr ""
+
+#: config/arc/arc.cc:6880
+#, gcc-internal-format
+msgid "%<__builtin_arc_aligned%> with non-constant alignment"
+msgstr ""
+
+#: config/arc/arc.cc:6888
+#, gcc-internal-format
+msgid "invalid alignment value for %<__builtin_arc_aligned%>"
+msgstr ""
+
+#: config/arc/arc.cc:7051
+#, gcc-internal-format
+msgid "operand 1 should be an unsigned 3-bit immediate"
+msgstr ""
+
+#: config/arc/arc.cc:7092 config/arc/arc.cc:7189
+#, gcc-internal-format
+msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
+msgstr ""
+
+#: config/arc/arc.cc:7125 config/arc/arc.cc:7157
+#, gcc-internal-format
+msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
+msgstr ""
+
+#: config/arc/arc.cc:7129 config/arc/arc.cc:7161
+#, gcc-internal-format
+msgid "operand 2 should be an unsigned 8-bit value"
+msgstr ""
+
+#: config/arc/arc.cc:7193
+#, gcc-internal-format
+msgid "operand 3 should be an unsigned 8-bit value"
+msgstr ""
+
+#: config/arc/arc.cc:7226
+#, gcc-internal-format
+msgid "operand 4 should be an unsigned 8-bit value (0-255)"
+msgstr ""
+
+#: config/arc/arc.cc:7230
+#, gcc-internal-format
+msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
+msgstr ""
+
+#: config/arc/arc.cc:7237
+#, gcc-internal-format
+msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
+msgstr ""
+
+#: config/arc/arc.cc:7240
+#, gcc-internal-format
+msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
+msgstr ""
+
+#: config/arc/arc.cc:7287
+#, gcc-internal-format, gfc-internal-format
+msgid "builtin requires an immediate for operand %d"
+msgstr ""
+
+#: config/arc/arc.cc:7292
+#, gcc-internal-format, gfc-internal-format
+msgid "operand %d should be a 6 bit unsigned immediate"
+msgstr ""
+
+#: config/arc/arc.cc:7296
+#, gcc-internal-format, gfc-internal-format
+msgid "operand %d should be a 8 bit unsigned immediate"
+msgstr ""
+
+#: config/arc/arc.cc:7300
+#, gcc-internal-format, gfc-internal-format
+msgid "operand %d should be a 3 bit unsigned immediate"
+msgstr ""
+
+#: config/arc/arc.cc:7303
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown builtin immediate operand type for operand %d"
+msgstr ""
+
+#: config/arc/arc.cc:7394
+#, gcc-internal-format
+msgid "register number must be a compile-time constant.  Try giving higher optimization levels"
+msgstr ""
+
+#: config/arc/arc.cc:8467
+#, gcc-internal-format
+msgid "insn addresses not set after shorten branches"
+msgstr ""
+
+#: config/arc/arc.cc:8682
+#, gcc-internal-format
+msgid "insn addresses not freed"
+msgstr ""
+
+#: config/arc/arc.cc:10838
+#, gcc-internal-format
+msgid "%qE attribute only valid for ARCv2 architecture"
+msgstr ""
+
+#: config/arc/arc.cc:10846 config/arc/arc.cc:10885
+#, gcc-internal-format
+msgid "argument of %qE attribute is missing"
+msgstr ""
+
+#: config/arc/arc.cc:10857 config/arc/arc.cc:10896 config/arc/arc.cc:11022
+#: config/avr/avr.cc:11347
+#, gcc-internal-format
+msgid "%qE attribute allows only an integer constant argument"
+msgstr ""
+
+#: config/arc/arc.cc:10877
+#, gcc-internal-format
+msgid "%qE attribute only valid for ARC EM architecture"
+msgstr ""
+
+#: config/arc/arc.cc:10932
+#, gcc-internal-format
+msgid "%qE attribute only applies to types"
+msgstr ""
+
+#: config/arc/arc.cc:10938
+#, gcc-internal-format
+msgid "argument of %qE attribute ignored"
+msgstr ""
+
+#: config/arc/arc.cc:11012 config/avr/avr.cc:11334 config/bfin/bfin.cc:4818
+#: config/i386/winnt.cc:63 config/nvptx/nvptx.cc:5824
+#, gcc-internal-format
+msgid "%qE attribute only applies to variables"
+msgstr ""
+
+#: config/arm/aarch-common.cc:553 config/i386/i386.cc:24044
+#, gcc-internal-format
+msgid "alternatives not allowed in %<asm%> flag output"
+msgstr ""
+
+#: config/arm/aarch-common.cc:614 config/i386/i386.cc:24108
+#, gcc-internal-format
+msgid "unknown %<asm%> flag output %qs"
+msgstr ""
+
+#: config/arm/aarch-common.cc:624 config/i386/i386.cc:24137
+#, gcc-internal-format
+msgid "invalid type for %<asm%> flag output"
+msgstr ""
+
+#: config/arm/aarch-common.cc:714
+#, gcc-internal-format
+msgid "missing feature or flag for %<%s%>"
+msgstr ""
+
+#: config/arm/aarch-common.cc:716
+#, gcc-internal-format
+msgid "invalid argument %<%s%> for %<%s%>"
+msgstr ""
+
+#: config/arm/aarch-common.cc:727
+#, gcc-internal-format
+msgid "argument %<%s%> can only appear alone in %<%s%>"
+msgstr ""
+
+#: config/arm/arm-builtins.cc:3125
+#, gcc-internal-format, gfc-internal-format
+msgid "coprocessor %d is not enabled with +cdecp%d"
+msgstr ""
+
+#: config/arm/arm-builtins.cc:3129
+#, gcc-internal-format
+msgid "coproc must be a constant immediate in range [0-%d] enabled with %<+cdecp<N>%>"
+msgstr ""
+
+#: config/arm/arm-builtins.cc:3138
+#, gcc-internal-format
+msgid "argument %d to %qE must be a constant immediate in range [0-%d]"
+msgstr ""
+
+#: config/arm/arm-builtins.cc:3257
+#, gcc-internal-format
+msgid "this builtin is not supported for this target"
+msgstr ""
+
+#: config/arm/arm-builtins.cc:3372
+#, gcc-internal-format
+msgid "saturation bit range must be in the range [%wd, %wd]"
+msgstr ""
+
+#: config/arm/arm-builtins.cc:3377
+#, gcc-internal-format
+msgid "saturation bit range must be a constant immediate"
+msgstr ""
+
+#: config/arm/arm-builtins.cc:3401
+#, gcc-internal-format
+msgid "You must enable MVE instructions to use these intrinsics"
+msgstr ""
+
+#: config/arm/arm-builtins.cc:3423
+#, gcc-internal-format
+msgid "You must enable NEON instructions (e.g. %<-mfloat-abi=softfp%> %<-mfpu=neon%>) to use these intrinsics."
+msgstr ""
+
+#: config/arm/arm-builtins.cc:3445
+#, gcc-internal-format
+msgid "You must enable VFP instructions to use these intrinsics."
+msgstr ""
+
+#: config/arm/arm-builtins.cc:3516
+#, gcc-internal-format
+msgid "You must enable crypto instructions (e.g. include %<-mfloat-abi=softfp%> %<-mfpu=crypto-neon%>) to use these intrinsics."
+msgstr ""
+
+#. @@@ better error message
+#: config/arm/arm-builtins.cc:3594 config/arm/arm-builtins.cc:3698
+#, gcc-internal-format
+msgid "selector must be an immediate"
+msgstr ""
+
+#: config/arm/arm-builtins.cc:3602 config/arm/arm-builtins.cc:3647
+#: config/arm/arm-builtins.cc:3705 config/arm/arm-builtins.cc:3714
+#, gcc-internal-format
+msgid "the range of selector should be in 0 to 7"
+msgstr ""
+
+#: config/arm/arm-builtins.cc:3607 config/arm/arm-builtins.cc:3716
+#, gcc-internal-format
+msgid "the range of selector should be in 0 to 3"
+msgstr ""
+
+#: config/arm/arm-builtins.cc:3612 config/arm/arm-builtins.cc:3718
+#, gcc-internal-format
+msgid "the range of selector should be in 0 to 1"
+msgstr ""
+
+#: config/arm/arm-builtins.cc:3784
+#, gcc-internal-format
+msgid "mask must be an immediate"
+msgstr ""
+
+#: config/arm/arm-builtins.cc:3789
+#, gcc-internal-format
+msgid "the range of mask should be in 0 to 255"
+msgstr ""
+
+#: config/arm/arm-builtins.cc:3977
+#, gcc-internal-format
+msgid "the range of count should be in 0 to 32; please check the intrinsic %qs in code"
+msgstr ""
+
+#: config/arm/arm-builtins.cc:3985
+#, gcc-internal-format
+msgid "the range of count should be in 0 to 16; please check the intrinsic %qs in code"
+msgstr ""
+
+#: config/arm/arm-builtins.cc:3993
+#, gcc-internal-format
+msgid "the range of count should be in 0 to 64; please check the intrinsic %qs in code"
+msgstr ""
+
+#: config/arm/arm-builtins.cc:4056
+#, gcc-internal-format
+msgid "the count should be no less than 0; please check the intrinsic %qs in code"
+msgstr ""
+
+#: config/arm/arm-c.cc:108
+#, gcc-internal-format
+msgid "argument %u to function %qE is of type %qT which is not known to be 128 bits wide"
+msgstr ""
+
+#: config/arm/arm-c.cc:140
+#, gcc-internal-format
+msgid "%<#pragma GCC arm%> requires a string parameter"
+msgstr ""
+
+#: config/arm/arm-c.cc:156
+#, gcc-internal-format
+msgid "%<#pragma GCC arm \"arm_mve.h\"%> requires a boolean parameter"
+msgstr ""
+
+#: config/arm/arm-c.cc:160
+#, gcc-internal-format
+msgid "unknown %<#pragma GCC arm%> option %qs"
+msgstr ""
+
+#: config/arm/arm-mve-builtins.cc:472
+#, gcc-internal-format
+msgid "this definition requires the MVE ISA extension"
+msgstr ""
+
+#: config/arm/arm-mve-builtins.cc:560
+#, gcc-internal-format
+msgid "you can enable mve.fp by using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
+msgstr ""
+
+#: config/arm/arm-mve-builtins.cc:1166
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, but %qT is not a valid MVE element type"
+msgstr ""
+
+#: config/arm/arm-mve-builtins.cc:1200
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects a single MVE vector rather than a tuple"
+msgstr ""
+
+#: config/arm/arm-mve-builtins.cc:1220
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects an MVE vector type"
+msgstr ""
+
+#: config/arm/arm-mve-builtins.cc:1223
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, which expects an MVE tuple type"
+msgstr ""
+
+#: config/arm/arm-mve-builtins.cc:1290
+#, gcc-internal-format
+msgid "passing %qT to argument %d of %qE, but previous arguments had type %qT"
+msgstr ""
+
+#: config/arm/arm.cc:2980
+#, gcc-internal-format
+msgid "iWMMXt and NEON are incompatible"
+msgstr ""
+
+#: config/arm/arm.cc:2986
+#, gcc-internal-format
+msgid "target CPU does not support ARM mode"
+msgstr ""
+
+#: config/arm/arm.cc:2990
+#, gcc-internal-format
+msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
+msgstr ""
+
+#: config/arm/arm.cc:2993
+#, gcc-internal-format
+msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
+msgstr ""
+
+#: config/arm/arm.cc:3001
+#, gcc-internal-format
+msgid "%<-g%> with %<-mno-apcs-frame%> may not give sensible debugging"
+msgstr ""
+
+#: config/arm/arm.cc:3006
+#, gcc-internal-format
+msgid "iWMMXt unsupported under Thumb mode"
+msgstr ""
+
+#: config/arm/arm.cc:3009
+#, gcc-internal-format
+msgid "cannot use %<-mtp=cp15%> with 16-bit Thumb"
+msgstr ""
+
+#: config/arm/arm.cc:3013
+#, gcc-internal-format
+msgid "RTP PIC is incompatible with Thumb"
+msgstr ""
+
+#: config/arm/arm.cc:3026
+#, gcc-internal-format, gfc-internal-format
+msgid "%s only supports non-pic code on M-profile targets with the MOVT instruction"
+msgstr ""
+
+#: config/arm/arm.cc:3031
+#, gcc-internal-format, gfc-internal-format
+msgid "%s only supports non-pic code on M-profile targets"
+msgstr ""
+
+#: config/arm/arm.cc:3036
+#, gcc-internal-format
+msgid "%s incompatible with %<-mword-relocations%>"
+msgstr ""
+
+#: config/arm/arm.cc:3138
+#, gcc-internal-format
+msgid "target CPU does not support THUMB instructions"
+msgstr ""
+
+#: config/arm/arm.cc:3188
+#, gcc-internal-format
+msgid "target CPU does not support unaligned accesses"
+msgstr ""
+
+#: config/arm/arm.cc:3247 config/arm/arm.cc:33478
+#, gcc-internal-format
+msgid "This architecture does not support branch protection instructions"
+msgstr ""
+
+#: config/arm/arm.cc:3250
+#, gcc-internal-format
+msgid "Return address signing is not supported with %<-mtpcs-frame%>."
+msgstr ""
+
+#: config/arm/arm.cc:3388
+#, gcc-internal-format
+msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+msgstr ""
+
+#: config/arm/arm.cc:3643
+#, gcc-internal-format
+msgid "%<-mapcs-stack-check%> incompatible with %<-mno-apcs-frame%>"
+msgstr ""
+
+#: config/arm/arm.cc:3652
+#, gcc-internal-format
+msgid "%<-fpic%> and %<-mapcs-reent%> are incompatible"
+msgstr ""
+
+#: config/arm/arm.cc:3655
+#, gcc-internal-format
+msgid "APCS reentrant code not supported.  Ignored"
+msgstr ""
+
+#: config/arm/arm.cc:3678
+#, gcc-internal-format
+msgid "option %<-mstructure-size-boundary%> is deprecated"
+msgstr ""
+
+#: config/arm/arm.cc:3686
+#, gcc-internal-format
+msgid "structure size boundary can only be set to 8, 32 or 64"
+msgstr ""
+
+#: config/arm/arm.cc:3688
+#, gcc-internal-format
+msgid "structure size boundary can only be set to 8 or 32"
+msgstr ""
+
+#: config/arm/arm.cc:3713
+#, gcc-internal-format
+msgid "RTP PIC is incompatible with %<-msingle-pic-base%>"
+msgstr ""
+
+#: config/arm/arm.cc:3725 config/arm/arm.cc:33819
+#, gcc-internal-format
+msgid "FDPIC mode is not supported in Thumb-1 mode"
+msgstr ""
+
+#: config/arm/arm.cc:3733
+#, gcc-internal-format
+msgid "%<-mpic-register=%> is useless without %<-fpic%>"
+msgstr ""
+
+#: config/arm/arm.cc:3742
+#, gcc-internal-format
+msgid "unable to use %qs for PIC register"
+msgstr ""
+
+#: config/arm/arm.cc:3782 config/pru/pru.cc:612
+#, gcc-internal-format
+msgid "%<-freorder-blocks-and-partition%> not supported on this architecture"
+msgstr ""
+
+#: config/arm/arm.cc:3950
+#, gcc-internal-format
+msgid "selected fp16 options are incompatible"
+msgstr ""
+
+#: config/arm/arm.cc:3985
+#, gcc-internal-format
+msgid "%<-mstack-protector-guard=tls%> needs a hardware TLS register"
+msgstr ""
+
+#: config/arm/arm.cc:4005
+#, gcc-internal-format
+msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
+msgstr ""
+
+#: config/arm/arm.cc:4008
+#, gcc-internal-format
+msgid "iwmmxt abi requires an iwmmxt capable cpu"
+msgstr ""
+
+#: config/arm/arm.cc:4016
+#, gcc-internal-format
+msgid "target CPU does not support interworking"
+msgstr ""
+
+#: config/arm/arm.cc:4029
+#, gcc-internal-format
+msgid "AAPCS does not support %<-mcaller-super-interworking%>"
+msgstr ""
+
+#: config/arm/arm.cc:4032
+#, gcc-internal-format
+msgid "AAPCS does not support %<-mcallee-super-interworking%>"
+msgstr ""
+
+#: config/arm/arm.cc:4037
+#, gcc-internal-format
+msgid "%<__fp16%> and no ldrh"
+msgstr ""
+
+#: config/arm/arm.cc:4040
+#, gcc-internal-format
+msgid "target CPU does not support ARMv8-M Security Extensions"
+msgstr ""
+
+#: config/arm/arm.cc:4045
+#, gcc-internal-format
+msgid "ARMv8-M Security Extensions incompatible with selected FPU"
+msgstr ""
+
+#: config/arm/arm.cc:4057
+#, gcc-internal-format
+msgid "%<-mfloat-abi=hard%>: selected architecture lacks an FPU"
+msgstr ""
+
+#: config/arm/arm.cc:4065
+#, gcc-internal-format
+msgid "%<-mfloat-abi=hard%> and VFP"
+msgstr ""
+
+#: config/arm/arm.cc:6330
+#, gcc-internal-format
+msgid "non-AAPCS derived PCS variant"
+msgstr ""
+
+#: config/arm/arm.cc:6332
+#, gcc-internal-format
+msgid "variadic functions must use the base AAPCS variant"
+msgstr ""
+
+#: config/arm/arm.cc:6361
+#, gcc-internal-format
+msgid "PCS variant"
+msgstr ""
+
+#: config/arm/arm.cc:6636
+#, gcc-internal-format
+msgid "Thumb-1 %<hard-float%> VFP ABI"
+msgstr ""
+
+#: config/arm/arm.cc:6731
+#, gcc-internal-format
+msgid "argument of type %qT not permitted with %<-mgeneral-regs-only%>"
+msgstr ""
+
+#: config/arm/arm.cc:7115 config/arm/arm.cc:7336 config/arm/arm.cc:7369
+#: config/arm/arm.cc:29541
+#, gcc-internal-format
+msgid "parameter passing for argument of type %qT changed in GCC 7.1"
+msgstr ""
+
+#: config/arm/arm.cc:7507
+#, gcc-internal-format
+msgid "FP registers might be clobbered despite %qE attribute: compile with %<-mgeneral-regs-only%>"
+msgstr ""
+
+#: config/arm/arm.cc:7629
+#, gcc-internal-format
+msgid "%qE attribute not available to functions with arguments passed on the stack"
+msgstr ""
+
+#: config/arm/arm.cc:7641
+#, gcc-internal-format
+msgid "%qE attribute not available to functions with variable number of arguments"
+msgstr ""
+
+#: config/arm/arm.cc:7650
+#, gcc-internal-format
+msgid "%qE attribute not available to functions that return value on the stack"
+msgstr ""
+
+#: config/arm/arm.cc:7672 config/arm/arm.cc:7724
+#, gcc-internal-format
+msgid "%qE attribute ignored without %<-mcmse%> option"
+msgstr ""
+
+#: config/arm/arm.cc:7691
+#, gcc-internal-format
+msgid "%qE attribute has no effect on functions with static linkage"
+msgstr ""
+
+#: config/arm/arm.cc:7744
+#, gcc-internal-format
+msgid "%qE attribute only applies to base type of a function pointer"
+msgstr ""
+
+#: config/arm/arm.cc:9739
+#, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with %<-mpure-code%> or %<-mslow-flash-data%>"
+msgstr ""
+
+#: config/arm/arm.cc:13590 config/arm/arm.cc:13592
+#, gcc-internal-format
+msgid "%s %wd out of range %wd - %wd"
+msgstr ""
+
+#: config/arm/arm.cc:26076
+#, gcc-internal-format
+msgid "unable to compute real location of stacked parameter"
+msgstr ""
+
+#: config/arm/arm.cc:26739
+#, gcc-internal-format
+msgid "Unexpected thumb1 far jump"
+msgstr ""
+
+#: config/arm/arm.cc:26998
+#, gcc-internal-format
+msgid "no low registers available for popping high registers"
+msgstr ""
+
+#: config/arm/arm.cc:27251
+#, gcc-internal-format
+msgid "Interrupt Service Routines cannot be coded in Thumb-1 mode"
+msgstr ""
+
+#: config/arm/arm.cc:27549
+#, gcc-internal-format
+msgid "%<-fstack-check=specific%> for Thumb-1"
+msgstr ""
+
+#: config/arm/arm.cc:33834
+#, gcc-internal-format
+msgid "invalid fpu for target attribute or pragma %qs"
+msgstr ""
+
+#. This doesn't really make sense until we support
+#. general dynamic selection of the architecture and all
+#. sub-features.
+#: config/arm/arm.cc:33842
+#, gcc-internal-format
+msgid "auto fpu selection not currently permitted here"
+msgstr ""
+
+#: config/arm/arm.cc:33855
+#, gcc-internal-format
+msgid "invalid architecture for target attribute or pragma %qs"
+msgstr ""
+
+#: config/arm/arm.cc:33869
+#, gcc-internal-format
+msgid "unknown target attribute or pragma %qs"
+msgstr ""
+
+#: config/arm/arm.cc:34832
+#, gcc-internal-format
+msgid "%<asm%> flags not supported in thumb1 mode"
+msgstr ""
+
+#: config/avr/avr-c.cc:65 config/avr/avr-c.cc:190
+#, gcc-internal-format
+msgid "%qs expects 1 argument but %d given"
+msgstr ""
+
+#: config/avr/avr-c.cc:76
+#, gcc-internal-format
+msgid "%qs expects a fixed-point value as argument"
+msgstr ""
+
+#: config/avr/avr-c.cc:102
+#, gcc-internal-format
+msgid "using %qs with unsigned type has no effect"
+msgstr ""
+
+#: config/avr/avr-c.cc:107 config/avr/avr-c.cc:173 config/avr/avr-c.cc:230
+#, gcc-internal-format
+msgid "no matching fixed-point overload found for %qs"
+msgstr ""
+
+#: config/avr/avr-c.cc:124
+#, gcc-internal-format
+msgid "%qs expects 2 arguments but %d given"
+msgstr ""
+
+#: config/avr/avr-c.cc:136 config/avr/avr-c.cc:201
+#, gcc-internal-format
+msgid "%qs expects a fixed-point value as first argument"
+msgstr ""
+
+#: config/avr/avr-c.cc:144
+#, gcc-internal-format
+msgid "%qs expects an integer value as second argument"
+msgstr ""
+
+#: config/avr/avr-devices.cc:152
+#, gcc-internal-format, gfc-internal-format
+msgid "supported core architectures:%s"
+msgstr ""
+
+#. Reached the end of `avr_mcu_types'.  This should actually never
+#. happen as options are provided by device-specs.  It could be a
+#. typo in a device-specs or calling the compiler proper directly
+#. with -mmcu=<device>.
+#: config/avr/avr.cc:1090
+#, gcc-internal-format
+msgid "unknown core architecture %qs specified with %qs"
+msgstr ""
+
+#: config/avr/avr.cc:1150 config/pru/pru.cc:601 config/visium/visium.cc:422
+#, gcc-internal-format
+msgid "%<-fpic%> is not supported"
+msgstr ""
+
+#: config/avr/avr.cc:1152 config/pru/pru.cc:603 config/visium/visium.cc:424
+#, gcc-internal-format
+msgid "%<-fPIC%> is not supported"
+msgstr ""
+
+#: config/avr/avr.cc:1154 config/pru/pru.cc:605
+#, gcc-internal-format
+msgid "%<-fpie%> is not supported"
+msgstr ""
+
+#: config/avr/avr.cc:1156 config/pru/pru.cc:607
+#, gcc-internal-format
+msgid "%<-fPIE%> is not supported"
+msgstr ""
+
+#: config/avr/avr.cc:1452 config/avr/avr.cc:1457 config/riscv/riscv.cc:9730
+#, gcc-internal-format
+msgid "function attributes %qs and %qs are mutually exclusive"
+msgstr ""
+
+#: config/avr/avr.cc:1478 config/riscv/riscv.cc:9742
+#, gcc-internal-format
+msgid "%qs function cannot have arguments"
+msgstr ""
+
+#: config/avr/avr.cc:1481 config/riscv/riscv.cc:9739
+#, gcc-internal-format
+msgid "%qs function cannot return a value"
+msgstr ""
+
+#: config/avr/avr.cc:1495
+#, gcc-internal-format
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
+msgstr ""
+
+#: config/avr/avr.cc:1506
+#, gcc-internal-format
+msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.cc:1513
+#, gcc-internal-format
+msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.cc:1734
+#, gcc-internal-format
+msgid "%<builtin_return_address%> contains only 2 bytes of address"
+msgstr ""
+
+#: config/avr/avr.cc:3722
+#, gcc-internal-format
+msgid "pointer offset from symbol maybe incorrect"
+msgstr ""
+
+#: config/avr/avr.cc:3861
+#, gcc-internal-format
+msgid "accessing data memory with program memory address"
+msgstr ""
+
+#: config/avr/avr.cc:3922
+#, gcc-internal-format
+msgid "accessing program memory with data memory address"
+msgstr ""
+
+#: config/avr/avr.cc:4264
+#, gcc-internal-format, gfc-internal-format
+msgid "fixed register %s used to pass parameter to function"
+msgstr ""
+
+#: config/avr/avr.cc:4524
+#, gcc-internal-format
+msgid "writing to address space %qs not supported"
+msgstr ""
+
+#: config/avr/avr.cc:11306
+#, gcc-internal-format
+msgid "%qE attribute only applies to variables in static storage"
+msgstr ""
+
+#: config/avr/avr.cc:11313
+#, gcc-internal-format
+msgid "%qE attribute only supported for reduced Tiny cores"
+msgstr ""
+
+#: config/avr/avr.cc:11355
+#, gcc-internal-format
+msgid "%qE attribute address out of range 0x%x%s0x%x"
+msgstr ""
+
+#: config/avr/avr.cc:11369
+#, gcc-internal-format
+msgid "both %s and %qE attribute provide address"
+msgstr ""
+
+#: config/avr/avr.cc:11379
+#, gcc-internal-format
+msgid "%qE attribute on non-volatile variable"
+msgstr ""
+
+#: config/avr/avr.cc:11455
+#, gcc-internal-format
+msgid "address spaces are not supported for reduced Tiny devices"
+msgstr ""
+
+#: config/avr/avr.cc:11462
+#, gcc-internal-format
+msgid "address space %qs not supported for devices with flash size up to %d KiB"
+msgstr ""
+
+#: config/avr/avr.cc:11642
+#, gcc-internal-format
+msgid "pointer targeting address space %qs must be const in %qT"
+msgstr ""
+
+#: config/avr/avr.cc:11645
+#, gcc-internal-format
+msgid "pointer targeting address space %qs must be const in %s %q+D"
+msgstr ""
+
+#: config/avr/avr.cc:11666
+#, gcc-internal-format
+msgid "variable %q+D with attribute %qs must be located in static storage"
+msgstr ""
+
+#: config/avr/avr.cc:11717
+#, gcc-internal-format
+msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
+msgstr ""
+
+#: config/avr/avr.cc:11878
+#, gcc-internal-format
+msgid "static attribute %qs declaration for %q+D needs an address"
+msgstr ""
+
+#: config/avr/avr.cc:11967
+#, gcc-internal-format
+msgid "only uninitialized variables can be placed in the %<.noinit%> section"
+msgstr ""
+
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.cc:12044
+#, gcc-internal-format
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr ""
+
+#: config/avr/avr.cc:12055
+#, gcc-internal-format
+msgid "uninitialized variable %q+D put into program memory area"
+msgstr ""
+
+#. Initializers are not yet parsed in TARGET_INSERT_ATTRIBUTES,
+#. hence deny initializers now.  The values of symbols with an
+#. address attribute are determined by the attribute, not by
+#. some initializer.
+#: config/avr/avr.cc:12120
+#, gcc-internal-format
+msgid "variable %q+D with attribute %qs must not have an initializer"
+msgstr ""
+
+#: config/avr/avr.cc:12173
+#, gcc-internal-format
+msgid "%q+D has incompatible attributes %qs and %qs"
+msgstr ""
+
+#: config/avr/avr.cc:12236
+#, gcc-internal-format
+msgid "architecture %qs supported for assembler only"
+msgstr ""
+
+#: config/avr/avr.cc:14796
+#, gcc-internal-format
+msgid "conversion from address space %qs to address space %qs"
+msgstr ""
+
+#: config/avr/avr.cc:15877 config/avr/avr.cc:15890
+#, gcc-internal-format, gfc-internal-format
+msgid "%s expects a compile time integer constant"
+msgstr ""
+
+#: config/avr/avr.cc:15904
+#, gcc-internal-format, gfc-internal-format
+msgid "%s expects a compile time long integer constant as first argument"
+msgstr ""
+
+#: config/avr/avr.cc:15932
+#, gcc-internal-format, gfc-internal-format
+msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
+msgstr ""
+
+#: config/avr/avr.cc:15941
+#, gcc-internal-format
+msgid "rounding result will always be 0"
+msgstr ""
+
+#: config/avr/driver-avr.cc:58
+#, gcc-internal-format
+msgid "bad usage of spec function %qs"
+msgstr ""
+
+#: config/avr/driver-avr.cc:86
+#, gcc-internal-format
+msgid "specified option %qs more than once"
+msgstr ""
+
+#: config/avr/driver-avr.cc:100
+#, gcc-internal-format
+msgid "strange device name %qs after %qs: bad character %qc"
+msgstr ""
+
+#: config/bfin/bfin.cc:2368
+#, gcc-internal-format
+msgid "%<-mfdpic%> is not supported, please use a bfin-linux-uclibc target"
+msgstr ""
+
+#: config/bfin/bfin.cc:2374
+#, gcc-internal-format
+msgid "%<-mshared-library-id=%> specified without %<-mid-shared-library%>"
+msgstr ""
+
+#: config/bfin/bfin.cc:2379
+#, gcc-internal-format
+msgid "%<-fstack-limit-%> options are ignored with %<-mfdpic%>; use %<-mstack-check-l1%>"
+msgstr ""
+
+#: config/bfin/bfin.cc:2385
+#, gcc-internal-format
+msgid "cannot use multiple stack checking methods together"
+msgstr ""
+
+#: config/bfin/bfin.cc:2388
+#, gcc-internal-format
+msgid "ID shared libraries and FD-PIC mode cannot be used together"
+msgstr ""
+
+#: config/bfin/bfin.cc:2393 config/m68k/m68k.cc:594
+#, gcc-internal-format
+msgid "cannot specify both %<-msep-data%> and %<-mid-shared-library%>"
+msgstr ""
+
+#: config/bfin/bfin.cc:2413
+#, gcc-internal-format
+msgid "%<-mmulticore%> can only be used with BF561"
+msgstr ""
+
+#: config/bfin/bfin.cc:2416
+#, gcc-internal-format
+msgid "%<-mcorea%> should be used with %<-mmulticore%>"
+msgstr ""
+
+#: config/bfin/bfin.cc:2419
+#, gcc-internal-format
+msgid "%<-mcoreb%> should be used with %<-mmulticore%>"
+msgstr ""
+
+#: config/bfin/bfin.cc:2422
+#, gcc-internal-format
+msgid "%<-mcorea%> and %<-mcoreb%> cannot be used together"
+msgstr ""
+
+#: config/bfin/bfin.cc:4700
+#, gcc-internal-format
+msgid "multiple function type attributes specified"
+msgstr ""
+
+#: config/bfin/bfin.cc:4767
+#, gcc-internal-format
+msgid "cannot apply both %<longcall%> and %<shortcall%> attributes to the same function"
+msgstr ""
+
+#: config/bpf/bpf.cc:105
+#, gcc-internal-format
+msgid "%qE attribute requires an integer argument"
+msgstr ""
+
+#: config/bpf/bpf.cc:112
+#, gcc-internal-format
+msgid "%qE requires an argument"
+msgstr ""
+
+#: config/bpf/bpf.cc:133
+#, gcc-internal-format
+msgid "%qE attribute only applies to structure, union and class types"
+msgstr ""
+
+#: config/bpf/bpf.cc:197
+#, gcc-internal-format
+msgid "BPF CO-RE requires BTF debugging information, use %<-gbtf%>"
+msgstr ""
+
+#: config/bpf/bpf.cc:215
+#, gcc-internal-format
+msgid "BPF CO-RE does not support LTO"
+msgstr ""
+
+#: config/bpf/bpf.cc:251
+#, gcc-internal-format
+msgid "%<-fstack-protector%> does not work on this architecture"
+msgstr ""
+
+#: config/bpf/bpf.cc:366
+#, gcc-internal-format
+msgid "eBPF stack limit exceeded"
+msgstr ""
+
+#: config/bpf/bpf.cc:685
+#, gcc-internal-format
+msgid "too many function arguments for eBPF"
+msgstr ""
+
+#: config/bpf/bpf.cc:704 config/bpf/bpf.cc:706
+#, gcc-internal-format
+msgid "no constructors"
+msgstr ""
+
+#: config/bpf/bpf.cc:722 config/bpf/bpf.cc:724
+#, gcc-internal-format
+msgid "no destructors"
+msgstr ""
+
+#: config/bpf/bpf.cc:776
+#, gcc-internal-format
+msgid "indirect call in function, which are not supported by eBPF"
+msgstr ""
+
+#: config/bpf/bpf.cc:1051 config/loongarch/loongarch-builtins.cc:3005
+#: config/mips/mips.cc:17403 config/nios2/nios2.cc:3602
+#: config/riscv/riscv-builtins.cc:344
+#: config/riscv/riscv-vector-builtins.cc:4226
+#, gcc-internal-format
+msgid "invalid argument to built-in function"
+msgstr ""
+
+#: config/bpf/bpf.cc:1065
+#, gcc-internal-format
+msgid "invalid built-in function at expansion"
+msgstr ""
+
+#: config/bpf/bpf.cc:1287 config/bpf/bpf.cc:1290
+#, gcc-internal-format
+msgid "could not inline call to %<__builtin_%s%>: size must be constant"
+msgstr ""
+
+#: config/bpf/bpf.cc:1318 config/bpf/bpf.cc:1321
+#, gcc-internal-format
+msgid "could not inline call to %<__builtin_%s%>: too many bytes, use %<-minline-memops-threshold%>"
+msgstr ""
+
+#: config/bpf/bpf.cc:1371 config/bpf/bpf.cc:1374
+#, gcc-internal-format
+msgid "could not inline call to %<__builtin_memset%>: size must be constant"
+msgstr ""
+
+#: config/bpf/bpf.cc:1402 config/bpf/bpf.cc:1405
+#, gcc-internal-format
+msgid "could not inline call to %<__builtin_memset%>: too many bytes, use %<-minline-memops-threshold%>"
+msgstr ""
+
+#: config/c6x/c6x.cc:245
+#, gcc-internal-format
+msgid "%<-fpic%> and %<-fPIC%> not supported without %<-mdsbt%> on this target"
+msgstr ""
+
+#. This function is for retrieving a part of an instruction name for
+#. an operator, for immediate output.  If that ever happens for
+#. MULT, we need to apply TARGET_MUL_BUG in the caller.  Make sure
+#. we notice.
+#: config/cris/cris.cc:732
+#, gcc-internal-format
+msgid "MULT case in %<cris_op_str%>"
+msgstr ""
+
+#: config/cris/cris.cc:1249 config/moxie/moxie.cc:186 config/or1k/or1k.cc:1294
+#, gcc-internal-format, gfc-internal-format
+msgid "internal error: bad register: %d"
+msgstr ""
+
+#. If we get here, the caller got its initial tests wrong.
+#: config/cris/cris.cc:2272
+#, gcc-internal-format
+msgid "internal error: %<cris_side_effect_mode_ok%> with bad operands"
+msgstr ""
+
+#: config/cris/cris.cc:2325
+#, gcc-internal-format
+msgid "%<-max-stackframe=%d%> is not usable, not between 0 and %d"
+msgstr ""
+
+#: config/cris/cris.cc:2354
+#, gcc-internal-format
+msgid "unknown CRIS version specification in %<-march=%> or %<-mcpu=%>: %s"
+msgstr ""
+
+#: config/cris/cris.cc:2390
+#, gcc-internal-format
+msgid "unknown CRIS cpu version specification in %<-mtune=%>: %s"
+msgstr ""
+
+#. Use error rather than warning, so invalid use is easily
+#. detectable.  Still change to the values we expect, to avoid
+#. further errors.
+#: config/cris/cris.cc:2406
+#, gcc-internal-format
+msgid "%<-fPIC%> and %<-fpic%> are not supported on this target"
+msgstr ""
+
+#: config/cris/cris.cc:2607
+#, gcc-internal-format
+msgid "unknown src"
+msgstr ""
+
+#: config/cris/cris.cc:2657
+#, gcc-internal-format
+msgid "unknown dest"
+msgstr ""
+
+#: config/cris/cris.cc:3059
+#, gcc-internal-format, gfc-internal-format
+msgid "stackframe too big: %d bytes"
+msgstr ""
+
+#: config/csky/csky.cc:2544
+#, gcc-internal-format, gfc-internal-format
+msgid "cpu %s is not based on arch %s, ignoring the arch"
+msgstr ""
+
+#: config/csky/csky.cc:2610 config/csky/csky.cc:2648 config/csky/csky.cc:2713
+#: config/csky/csky.cc:2736 config/csky/csky.cc:2753
+#, gcc-internal-format
+msgid "%qs is not supported by arch %s"
+msgstr ""
+
+#: config/csky/csky.cc:2651
+#, gcc-internal-format
+msgid "%<-mhard-float%> is not supported by the selected CPU"
+msgstr ""
+
+#: config/csky/csky.cc:2667
+#, gcc-internal-format
+msgid "%<-mdouble-float%> ignored without %<-mhard-float%>"
+msgstr ""
+
+#: config/csky/csky.cc:2670
+#, gcc-internal-format
+msgid "%<-mfdivdu%> ignored without %<-mhard-float%>"
+msgstr ""
+
+#: config/csky/csky.cc:2725
+#, gcc-internal-format
+msgid "%<-msmart%> is incompatible with %<-mhigh-registers%>"
+msgstr ""
+
+#. It's hard to provide general support for trampolines on this
+#. core.  We need a register other than the one holding the
+#. static chain (r13) to hold the function pointer for the
+#. indirect jump to it.  But ck801 has such a limited register set
+#. there is no other call-clobbered scratch register available -- in
+#. particular, this core does not have r12, which we use for the
+#. ck802 case below.  If we use a callee-saved register like r4,
+#. saving the old value on the stack screws up the stack frame
+#. if there are overflow arguments pushed on the stack
+#. by the caller.  In theory we could test for that and handle
+#. limited cases with parameters that all fit in r0-r3 with no
+#. stack overflow, but punt for now.
+#: config/csky/csky.cc:6281
+#, gcc-internal-format
+msgid "Nested function trampolines not supported on CK801."
+msgstr ""
+
+#: config/csky/csky.cc:6477
+#, gcc-internal-format
+msgid "%qE attribute ignored without %<-mistack%>"
+msgstr ""
+
+#: config/epiphany/epiphany.cc:496
+#, gcc-internal-format
+msgid "interrupt handlers cannot have arguments"
+msgstr ""
+
+#: config/epiphany/epiphany.cc:520
+#, gcc-internal-format
+msgid "argument of %qE attribute is not %qs, %qs %qs, %qs, %qs, %qs, %qs, %qs, %qs or %qs"
+msgstr ""
+
+#: config/epiphany/epiphany.cc:1543
+#, gcc-internal-format
+msgid "%<stack_offset%> must be at least 4"
+msgstr ""
+
+#: config/epiphany/epiphany.cc:1545
+#, gcc-internal-format
+msgid "%<stack_offset%> must be a multiple of 4"
+msgstr ""
+
+#: config/frv/frv.cc:8479
+#, gcc-internal-format
+msgid "accumulator is not a constant integer"
+msgstr ""
+
+#: config/frv/frv.cc:8484
+#, gcc-internal-format
+msgid "accumulator number is out of bounds"
+msgstr ""
+
+#: config/frv/frv.cc:8495
+#, gcc-internal-format
+msgid "inappropriate accumulator for %qs"
+msgstr ""
+
+#: config/frv/frv.cc:8571
+#, gcc-internal-format
+msgid "invalid IACC argument"
+msgstr ""
+
+#: config/frv/frv.cc:8594 config/sparc/sparc.cc:11033
+#, gcc-internal-format
+msgid "%qs expects a constant argument"
+msgstr ""
+
+#: config/frv/frv.cc:8599 config/sparc/sparc.cc:11039
+#, gcc-internal-format
+msgid "constant argument out of range for %qs"
+msgstr ""
+
+#: config/frv/frv.cc:9080
+#, gcc-internal-format
+msgid "media functions are not available unless %<-mmedia%> is used"
+msgstr ""
+
+#: config/frv/frv.cc:9092
+#, gcc-internal-format
+msgid "this media function is only available on the fr500"
+msgstr ""
+
+#: config/frv/frv.cc:9120
+#, gcc-internal-format
+msgid "this media function is only available on the fr400 and fr550"
+msgstr ""
+
+#: config/frv/frv.cc:9139
+#, gcc-internal-format
+msgid "this built-in function is only available on the fr405 and fr450"
+msgstr ""
+
+#: config/frv/frv.cc:9148
+#, gcc-internal-format
+msgid "this built-in function is only available on the fr500 and fr550"
+msgstr ""
+
+#: config/frv/frv.cc:9160
+#, gcc-internal-format
+msgid "this built-in function is only available on the fr450"
+msgstr ""
+
+#: config/ft32/ft32.cc:181
+#, gcc-internal-format
+msgid "%<h%> applied to non-register operand"
+msgstr ""
+
+#: config/ft32/ft32.cc:206
+#, gcc-internal-format, gfc-internal-format
+msgid "bad alignment: %d"
+msgstr ""
+
+#: config/ft32/ft32.cc:502
+#, gcc-internal-format
+msgid "stack frame must be smaller than 64K"
+msgstr ""
+
+#: config/gcn/gcn.cc:175
+#, gcc-internal-format
+msgid "%<-mxnack=on%> is incompatible with %<-march=%s%>"
+msgstr ""
+
+#: config/gcn/gcn.cc:292
+#, gcc-internal-format
+msgid "%<amdgpu_hsa_kernel%> attribute requires string constant arguments"
+msgstr ""
+
+#: config/gcn/gcn.cc:305
+#, gcc-internal-format
+msgid "unknown specifier %qs in %<amdgpu_hsa_kernel%> attribute"
+msgstr ""
+
+#: config/gcn/gcn.cc:312
+#, gcc-internal-format
+msgid "duplicated parameter specifier %qs in %<amdgpu_hsa_kernel%> attribute"
+msgstr ""
+
+#: config/gcn/gcn.cc:364
+#, gcc-internal-format
+msgid "too many arguments passed in sgpr registers"
+msgstr ""
+
+#: config/gcn/gcn.cc:2523
+#, gcc-internal-format
+msgid "A non-default set of initial values has been requested, which violates the ABI"
+msgstr ""
+
+#: config/gcn/gcn.cc:2791
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong type of argument %s"
+msgstr ""
+
+#: config/gcn/gcn.cc:3802
+#, gcc-internal-format
+msgid "nested function trampolines not supported on GCN5 due to non-executable stacks"
+msgstr ""
+
+#: config/gcn/gcn.cc:3954
+#, gcc-internal-format
+msgid "TLS is not implemented for GCN."
+msgstr ""
+
+#: config/gcn/gcn.cc:5046
+#, gcc-internal-format
+msgid "Builtin not implemented"
+msgstr ""
+
+#: config/gcn/gcn.cc:5692
+#, gcc-internal-format
+msgid "unsupported simdlen %wd (amdgcn)"
+msgstr ""
+
+#: config/gcn/gcn.cc:6402
+#, gcc-internal-format
+msgid "using %<vector_length (64)%>, ignoring %d"
+msgstr ""
+
+#: config/gcn/gcn.cc:6403
+#, gcc-internal-format
+msgid "using %<vector_length (64)%>, ignoring runtime setting"
+msgstr ""
+
+#: config/gcn/gcn.cc:6415 config/nvptx/nvptx.cc:6607
+#, gcc-internal-format
+msgid "using %<num_workers (%d)%>, ignoring %d"
+msgstr ""
+
+#: config/gcn/gcn.cc:6442 config/gcn/gcn.cc:6471
+#, gcc-internal-format, gfc-internal-format
+msgid "offload dimension out of range (%d)"
+msgstr ""
+
+#: config/gcn/gcn.cc:6980
+#, gcc-internal-format
+msgid "%d bytes of gang-private data-share memory exhausted (increase with %<-mgang-private-size=%d%>, for example)"
+msgstr ""
+
+#: config/gcn/mkoffload.cc:168
+#, gcc-internal-format
+msgid "deleting file %qs: %m"
+msgstr ""
+
+#: config/gcn/mkoffload.cc:877
+#, gcc-internal-format
+msgid "unrecognized argument in option %<-march=%s%>"
+msgstr ""
+
+#: config/gcn/mkoffload.cc:901
+#, gcc-internal-format
+msgid "valid arguments to %<-march=%> are: %s"
+msgstr ""
+
+#: config/gcn/mkoffload.cc:904
+#, gcc-internal-format
+msgid "valid argument to %<-march=%> is %qs"
+msgstr ""
+
+#: config/gcn/mkoffload.cc:940
+#, gcc-internal-format
+msgid "%<COLLECT_GCC%> must be set"
+msgstr ""
+
+#: config/gcn/mkoffload.cc:986
+#, gcc-internal-format
+msgid "offload compiler %qs not found"
+msgstr ""
+
+#: config/gcn/mkoffload.cc:1008
+#, gcc-internal-format
+msgid "unrecognizable argument of option %<"
+msgstr ""
+
+#: config/gcn/mkoffload.cc:1060 config/nvptx/mkoffload.cc:753
+#, gcc-internal-format
+msgid "either %<-fopenacc%> or %<-fopenmp%> must be set"
+msgstr ""
+
+#: config/gcn/mkoffload.cc:1112
+#, gcc-internal-format
+msgid "unhandled architecture"
+msgstr ""
+
+#: config/gcn/mkoffload.cc:1152 config/gcn/mkoffload.cc:1304
+#, gcc-internal-format
+msgid "cannot open %qs"
+msgstr ""
+
+#: config/gcn/mkoffload.cc:1290 config/nvptx/mkoffload.cc:843
+#, gcc-internal-format
+msgid "cannot open omp_requires file %qs"
+msgstr ""
+
+#: config/gcn/mkoffload.cc:1294 config/nvptx/mkoffload.cc:847
+#, gcc-internal-format
+msgid "cannot read omp_requires file %qs"
+msgstr ""
+
+#: config/gcn/mkoffload.cc:1300
+#, gcc-internal-format
+msgid "cannot open intermediate gcn asm file"
+msgstr ""
+
+#: config/gcn/mkoffload.cc:1317
+#, gcc-internal-format
+msgid "cannot open intermediate gcn obj file"
+msgstr ""
+
+#: config/h8300/h8300.cc:298
+#, gcc-internal-format
+msgid "%<-ms2600%> is used without %<-ms%>"
+msgstr ""
+
+#: config/h8300/h8300.cc:304
+#, gcc-internal-format
+msgid "%<-mexr%> is used without %<-ms%>"
+msgstr ""
+
+#: config/h8300/h8300.cc:310
+#, gcc-internal-format
+msgid "%<-mexr%> is used without %<-ms%> or %<-msx%>"
+msgstr ""
+
+#: config/h8300/h8300.cc:316
+#, gcc-internal-format
+msgid "%<-mno-exr%> is valid only with %<-ms%> or %<-msx%> - option ignored"
+msgstr ""
+
+#: config/h8300/h8300.cc:323
+#, gcc-internal-format
+msgid "%<-mn%> is not supported for linux targets"
+msgstr ""
+
+#: config/i386/host-cygwin.cc:64
+#, gcc-internal-format
+msgid "cannot extend PCH file: %m"
+msgstr ""
+
+#: config/i386/host-cygwin.cc:75
+#, gcc-internal-format
+msgid "cannot set position in PCH file: %m"
+msgstr ""
+
+#: config/i386/i386-builtins.cc:1962
+#, gcc-internal-format
+msgid "no dispatcher found for the versioning attributes"
+msgstr ""
+
+#: config/i386/i386-builtins.cc:2012
+#, gcc-internal-format
+msgid "ISA %qs is not supported in %<target%> attribute, use %<arch=%> syntax"
+msgstr ""
+
+#: config/i386/i386-builtins.cc:2023
+#, gcc-internal-format, gfc-internal-format
+msgid "no dispatcher found for the versioning attributes: %s"
+msgstr ""
+
+#: config/i386/i386-builtins.cc:2133
+#, gcc-internal-format
+msgid "parameter to builtin must be a string constant or literal"
+msgstr ""
+
+#: config/i386/i386-builtins.cc:2157 config/i386/i386-builtins.cc:2206
+#, gcc-internal-format, gfc-internal-format
+msgid "parameter to builtin not valid: %s"
+msgstr ""
+
+#: config/i386/i386-expand.cc:9752
+#, gcc-internal-format
+msgid "interrupt service routine cannot be called directly"
+msgstr ""
+
+#: config/i386/i386-expand.cc:10223 config/i386/i386-expand.cc:11810
+#, gcc-internal-format
+msgid "the last argument must be a 2-bit immediate"
+msgstr ""
+
+#: config/i386/i386-expand.cc:10697
+#, gcc-internal-format
+msgid "the fifth argument must be an 8-bit immediate"
+msgstr ""
+
+#: config/i386/i386-expand.cc:10792
+#, gcc-internal-format
+msgid "the third argument must be an 8-bit immediate"
+msgstr ""
+
+#: config/i386/i386-expand.cc:11739
+#, gcc-internal-format
+msgid "the last argument must be an 1-bit immediate"
+msgstr ""
+
+#: config/i386/i386-expand.cc:11754
+#, gcc-internal-format
+msgid "the last argument must be a 3-bit immediate"
+msgstr ""
+
+#: config/i386/i386-expand.cc:11789
+#, gcc-internal-format
+msgid "the last argument must be a 4-bit immediate"
+msgstr ""
+
+#: config/i386/i386-expand.cc:11829
+#, gcc-internal-format
+msgid "the last argument must be a 1-bit immediate"
+msgstr ""
+
+#: config/i386/i386-expand.cc:11845
+#, gcc-internal-format
+msgid "the last argument must be a 5-bit immediate"
+msgstr ""
+
+#: config/i386/i386-expand.cc:11855
+#, gcc-internal-format
+msgid "the next to last argument must be an 8-bit immediate"
+msgstr ""
+
+#: config/i386/i386-expand.cc:11860
+#, gcc-internal-format
+msgid "the last argument must be an 8-bit immediate"
+msgstr ""
+
+#: config/i386/i386-expand.cc:11997
+#, gcc-internal-format
+msgid "the third argument must be comparison constant"
+msgstr ""
+
+#: config/i386/i386-expand.cc:12002
+#, gcc-internal-format
+msgid "incorrect comparison mode"
+msgstr ""
+
+#: config/i386/i386-expand.cc:12008 config/i386/i386-expand.cc:12332
+#, gcc-internal-format
+msgid "incorrect rounding operand"
+msgstr ""
+
+#: config/i386/i386-expand.cc:12312
+#, gcc-internal-format
+msgid "the immediate argument must be a 4-bit immediate"
+msgstr ""
+
+#: config/i386/i386-expand.cc:12320
+#, gcc-internal-format
+msgid "the immediate argument must be a 5-bit immediate"
+msgstr ""
+
+#: config/i386/i386-expand.cc:12323
+#, gcc-internal-format
+msgid "the immediate argument must be an 8-bit immediate"
+msgstr ""
+
+#: config/i386/i386-expand.cc:12799
+#, gcc-internal-format
+msgid "the fourth argument must be one of enum %qs"
+msgstr ""
+
+#: config/i386/i386-expand.cc:12869 config/rs6000/rs6000-builtin.cc:2378
+#, gcc-internal-format
+msgid "selector must be an integer constant in the range [0, %wi]"
+msgstr ""
+
+#: config/i386/i386-expand.cc:13120
+#, gcc-internal-format
+msgid "%qE needs unknown isa option"
+msgstr ""
+
+#: config/i386/i386-expand.cc:13124
+#, gcc-internal-format
+msgid "%qE needs isa option %s"
+msgstr ""
+
+#: config/i386/i386-expand.cc:13612
+#, gcc-internal-format
+msgid "second, third and fourth argument must be a const"
+msgstr ""
+
+#: config/i386/i386-expand.cc:13620
+#, gcc-internal-format
+msgid "invalid third argument"
+msgstr ""
+
+#. Ignore the hint.
+#: config/i386/i386-expand.cc:13629 config/i386/i386-expand.cc:13684
+#, gcc-internal-format
+msgid "instruction prefetch applies when in 64-bit mode with RIP-relative addressing and option %<-mprefetchi%>; they stay NOPs otherwise"
+msgstr ""
+
+#: config/i386/i386-expand.cc:13646
+#, gcc-internal-format
+msgid "invalid third argument to %<__builtin_ia32_prefetch%>; using zero"
+msgstr ""
+
+#: config/i386/i386-expand.cc:13672
+#, gcc-internal-format
+msgid "second argument must be a const"
+msgstr ""
+
+#: config/i386/i386-expand.cc:14218
+#, gcc-internal-format
+msgid "the last argument must be a 32-bit immediate"
+msgstr ""
+
+#: config/i386/i386-expand.cc:14251
+#, gcc-internal-format
+msgid "last argument must be an immediate"
+msgstr ""
+
+#: config/i386/i386-expand.cc:15013 config/i386/i386-expand.cc:15225
+#, gcc-internal-format
+msgid "the last argument must be scale 1, 2, 4, 8"
+msgstr ""
+
+#: config/i386/i386-expand.cc:15278
+#, gcc-internal-format
+msgid "the forth argument must be scale 1, 2, 4, 8"
+msgstr ""
+
+#: config/i386/i386-expand.cc:15284
+#, gcc-internal-format
+msgid "incorrect hint operand"
+msgstr ""
+
+#: config/i386/i386-expand.cc:15303
+#, gcc-internal-format
+msgid "the argument to %<xabort%> intrinsic must be an 8-bit immediate"
+msgstr ""
+
+#: config/i386/i386-features.cc:3516
+#, gcc-internal-format
+msgid "function versions cannot be marked as %<gnu_inline%>, bodies have to be generated"
+msgstr ""
+
+#: config/i386/i386-options.cc:925 config/i386/i386-options.cc:2273
+#: config/i386/i386-options.cc:2282
+#, gcc-internal-format, gfc-internal-format
+msgid "code model %s does not support PIC mode"
+msgstr ""
+
+#: config/i386/i386-options.cc:1208
+#, gcc-internal-format
+msgid "attribute %qs argument is not a string"
+msgstr ""
+
+#: config/i386/i386-options.cc:1272
+#, gcc-internal-format
+msgid "attribute %qs argument %qs is unknown"
+msgstr ""
+
+#: config/i386/i386-options.cc:1335
+#, gcc-internal-format
+msgid "attribute value %qs was already specified in %qs attribute"
+msgstr ""
+
+#: config/i386/i386-options.cc:1373
+#, gcc-internal-format
+msgid "attribute value %qs is unknown in %qs attribute"
+msgstr ""
+
+#: config/i386/i386-options.cc:1674
+#, gcc-internal-format
+msgid "wrong argument %qs to option %qs"
+msgstr ""
+
+#: config/i386/i386-options.cc:1680
+#, gcc-internal-format
+msgid "size ranges of option %qs should be increasing"
+msgstr ""
+
+#: config/i386/i386-options.cc:1690
+#, gcc-internal-format
+msgid "wrong strategy name %qs specified for option %qs"
+msgstr ""
+
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386-options.cc:1716
+#, gcc-internal-format
+msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
+msgstr ""
+
+#: config/i386/i386-options.cc:1729
+#, gcc-internal-format
+msgid "unknown alignment %qs specified for option %qs"
+msgstr ""
+
+#: config/i386/i386-options.cc:1739
+#, gcc-internal-format
+msgid "the max value for the last size range should be -1 for option %qs"
+msgstr ""
+
+#: config/i386/i386-options.cc:1746
+#, gcc-internal-format
+msgid "too many size ranges specified in option %qs"
+msgstr ""
+
+#: config/i386/i386-options.cc:1824
+#, gcc-internal-format
+msgid "unknown parameter to option %<-mtune-ctrl%>: %s"
+msgstr ""
+
+#: config/i386/i386-options.cc:2069
+#, gcc-internal-format
+msgid "Intel MCU psABI isn%'t supported in %s mode"
+msgstr ""
+
+#: config/i386/i386-options.cc:2123
+#, gcc-internal-format
+msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
+msgstr ""
+
+#: config/i386/i386-options.cc:2125
+#, gcc-internal-format
+msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
+msgstr ""
+
+#: config/i386/i386-options.cc:2131
+#, gcc-internal-format
+msgid "%<-mtune=knl%> support will be removed in GCC 15"
+msgstr ""
+
+#: config/i386/i386-options.cc:2132
+#, gcc-internal-format
+msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
+msgstr ""
+
+#: config/i386/i386-options.cc:2137
+#, gcc-internal-format
+msgid "%<-mtune=knm%> support will be removed in GCC 15"
+msgstr ""
+
+#: config/i386/i386-options.cc:2138
+#, gcc-internal-format
+msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
+msgstr ""
+
+#. rep; movq isn't available in 32-bit code.
+#: config/i386/i386-options.cc:2165
+#, gcc-internal-format
+msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
+msgstr ""
+
+#: config/i386/i386-options.cc:2170
+#, gcc-internal-format
+msgid "%<-mapxf%> is not supported for 32-bit code"
+msgstr ""
+
+#: config/i386/i386-options.cc:2172
+#, gcc-internal-format
+msgid "%<-mapx-features=%> option is not supported for 32-bit code"
+msgstr ""
+
+#: config/i386/i386-options.cc:2175
+#, gcc-internal-format
+msgid "%<-muintr%> not supported for 32-bit code"
+msgstr ""
+
+#: config/i386/i386-options.cc:2178
+#, gcc-internal-format
+msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
+msgstr ""
+
+#: config/i386/i386-options.cc:2193
+#, gcc-internal-format
+msgid "address mode %qs not supported in the %s bit mode"
+msgstr ""
+
+#: config/i386/i386-options.cc:2204
+#, gcc-internal-format
+msgid "%<-mabi=ms%> not supported with X32 ABI"
+msgstr ""
+
+#: config/i386/i386-options.cc:2210
+#, gcc-internal-format
+msgid "%<-mabi=%s%> not supported with %<-fsanitize=address%>"
+msgstr ""
+
+#: config/i386/i386-options.cc:2213
+#, gcc-internal-format
+msgid "%<-mabi=%s%> not supported with %<-fsanitize=kernel-address%>"
+msgstr ""
+
+#: config/i386/i386-options.cc:2217
+#, gcc-internal-format
+msgid "%<-mabi=%s%> not supported with %<-fsanitize=thread%>"
+msgstr ""
+
+#: config/i386/i386-options.cc:2223
+#, gcc-internal-format
+msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
+msgstr ""
+
+#: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
+#: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
+#: config/i386/i386-options.cc:2286
+#, gcc-internal-format
+msgid "code model %qs not supported in the %s bit mode"
+msgstr ""
+
+#: config/i386/i386-options.cc:2255 config/i386/i386-options.cc:2267
+#, gcc-internal-format
+msgid "code model %qs not supported in x32 mode"
+msgstr ""
+
+#: config/i386/i386-options.cc:2310
+#, gcc-internal-format
+msgid "%<-masm=intel%> not supported in this configuration"
+msgstr ""
+
+#: config/i386/i386-options.cc:2315
+#, gcc-internal-format, gfc-internal-format
+msgid "%i-bit mode not compiled in"
+msgstr ""
+
+#: config/i386/i386-options.cc:2327
+#, gcc-internal-format
+msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
+msgstr ""
+
+#: config/i386/i386-options.cc:2329
+#, gcc-internal-format
+msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
+msgstr ""
+
+#: config/i386/i386-options.cc:2336
+#, gcc-internal-format
+msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
+msgstr ""
+
+#: config/i386/i386-options.cc:2338
+#, gcc-internal-format
+msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
+msgstr ""
+
+#: config/i386/i386-options.cc:2346 config/i386/i386-options.cc:2499
+#, gcc-internal-format
+msgid "CPU you selected does not support x86-64 instruction set"
+msgstr ""
+
+#: config/i386/i386-options.cc:2354
+#, gcc-internal-format
+msgid "%<-march=knl%> support will be removed in GCC 15"
+msgstr ""
+
+#: config/i386/i386-options.cc:2355
+#, gcc-internal-format
+msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
+msgstr ""
+
+#: config/i386/i386-options.cc:2360
+#, gcc-internal-format
+msgid "%<-march=knm%> support will be removed in GCC 15"
+msgstr ""
+
+#: config/i386/i386-options.cc:2361
+#, gcc-internal-format
+msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
+msgstr ""
+
+#: config/i386/i386-options.cc:2438
+#, gcc-internal-format
+msgid "bad value %qs for %<-march=%> switch"
+msgstr ""
+
+#: config/i386/i386-options.cc:2439
+#, gcc-internal-format
+msgid "bad value %qs for %<target(\"arch=\")%> attribute"
+msgstr ""
+
+#: config/i386/i386-options.cc:2461
+#, gcc-internal-format
+msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
+msgstr ""
+
+#: config/i386/i386-options.cc:2463
+#, gcc-internal-format
+msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
+msgstr ""
+
+#: config/i386/i386-options.cc:2468
+#, gcc-internal-format
+msgid "valid arguments to %<-march=%> switch are: %s"
+msgstr ""
+
+#: config/i386/i386-options.cc:2469
+#, gcc-internal-format
+msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
+msgstr ""
+
+#: config/i386/i386-options.cc:2518
+#, gcc-internal-format
+msgid "bad value %qs for %<-mtune=%> switch"
+msgstr ""
+
+#: config/i386/i386-options.cc:2519
+#, gcc-internal-format
+msgid "bad value %qs for %<target(\"tune=\")%> attribute"
+msgstr ""
+
+#: config/i386/i386-options.cc:2540
+#, gcc-internal-format
+msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
+msgstr ""
+
+#: config/i386/i386-options.cc:2542
+#, gcc-internal-format
+msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
+msgstr ""
+
+#: config/i386/i386-options.cc:2547
+#, gcc-internal-format
+msgid "valid arguments to %<-mtune=%> switch are: %s"
+msgstr ""
+
+#: config/i386/i386-options.cc:2548
+#, gcc-internal-format
+msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
+msgstr ""
+
+#: config/i386/i386-options.cc:2578
+#, gcc-internal-format
+msgid "%<-mregparm%> is ignored in 64-bit mode"
+msgstr ""
+
+#: config/i386/i386-options.cc:2580
+#, gcc-internal-format
+msgid "%<-mregparm%> is ignored for Intel MCU psABI"
+msgstr ""
+
+#: config/i386/i386-options.cc:2583
+#, gcc-internal-format
+msgid "%<-mregparm=%d%> is not between 0 and %d"
+msgstr ""
+
+#: config/i386/i386-options.cc:2609
+#, gcc-internal-format
+msgid "%<-m96bit-long-double%> is not compatible with this target"
+msgstr ""
+
+#: config/i386/i386-options.cc:2614
+#, gcc-internal-format
+msgid "%<-mrtd%> is ignored in 64bit mode"
+msgstr ""
+
+#: config/i386/i386-options.cc:2615
+#, gcc-internal-format
+msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
+msgstr ""
+
+#: config/i386/i386-options.cc:2702
+#, gcc-internal-format
+msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
+msgstr ""
+
+#. We should not emit 512 bit instructions under AVX10.1-256
+#. when EVEX512 is enabled w/o any AVX512 features enabled.
+#. Disable EVEX512 bit for this.
+#: config/i386/i386-options.cc:2716
+#, gcc-internal-format
+msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
+msgstr ""
+
+#: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
+#, gcc-internal-format
+msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
+msgstr ""
+
+#: config/i386/i386-options.cc:2737
+#, gcc-internal-format
+msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
+msgstr ""
+
+#: config/i386/i386-options.cc:2747
+#, gcc-internal-format
+msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
+msgstr ""
+
+#: config/i386/i386-options.cc:2802
+#, gcc-internal-format
+msgid "%<-mpreferred-stack-boundary%> is not supported for this target"
+msgstr ""
+
+#: config/i386/i386-options.cc:2805
+#, gcc-internal-format
+msgid "%<-mpreferred-stack-boundary=%d%> is not between %d and %d"
+msgstr ""
+
+#: config/i386/i386-options.cc:2828
+#, gcc-internal-format
+msgid "%<-mincoming-stack-boundary=%d%> is not between %d and 12"
+msgstr ""
+
+#: config/i386/i386-options.cc:2841
+#, gcc-internal-format
+msgid "%<-mnop-mcount%> is not compatible with this target"
+msgstr ""
+
+#: config/i386/i386-options.cc:2844
+#, gcc-internal-format
+msgid "%<-mnop-mcount%> is not implemented for %<-fPIC%>"
+msgstr ""
+
+#: config/i386/i386-options.cc:2850
+#, gcc-internal-format
+msgid "%<-msseregparm%> used without SSE enabled"
+msgstr ""
+
+#: config/i386/i386-options.cc:2851
+#, gcc-internal-format
+msgid "%<target(\"sseregparm\")%> used without SSE enabled"
+msgstr ""
+
+#: config/i386/i386-options.cc:2861
+#, gcc-internal-format
+msgid "SSE instruction set disabled, using 387 arithmetics"
+msgstr ""
+
+#: config/i386/i386-options.cc:2868
+#, gcc-internal-format
+msgid "387 instruction set disabled, using SSE arithmetics"
+msgstr ""
+
+#: config/i386/i386-options.cc:2918
+#, gcc-internal-format
+msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
+msgstr ""
+
+#: config/i386/i386-options.cc:2920
+#, gcc-internal-format
+msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
+msgstr ""
+
+#: config/i386/i386-options.cc:2934
+#, gcc-internal-format
+msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
+msgstr ""
+
+#: config/i386/i386-options.cc:2936
+#, gcc-internal-format
+msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
+msgstr ""
+
+#: config/i386/i386-options.cc:2996
+#, gcc-internal-format
+msgid "%<-mfentry%> isn%'t supported for 32-bit in combination with %<-fpic%>"
+msgstr ""
+
+#: config/i386/i386-options.cc:2999
+#, gcc-internal-format
+msgid "%<-mno-fentry%> isn%'t compatible with SEH"
+msgstr ""
+
+#: config/i386/i386-options.cc:3003
+#, gcc-internal-format
+msgid "%<-mcall-ms2sysv-xlogues%> isn%'t currently supported with SEH"
+msgstr ""
+
+#: config/i386/i386-options.cc:3125 config/loongarch/loongarch-opts.cc:898
+#, gcc-internal-format
+msgid "unknown option for %<-mrecip=%s%>"
+msgstr ""
+
+#: config/i386/i386-options.cc:3184
+#, gcc-internal-format
+msgid "%qs is not a valid number in %<-mstack-protector-guard-offset=%>"
+msgstr ""
+
+#: config/i386/i386-options.cc:3189
+#, gcc-internal-format
+msgid "%qs is not a valid offset in %<-mstack-protector-guard-offset=%>"
+msgstr ""
+
+#: config/i386/i386-options.cc:3217
+#, gcc-internal-format
+msgid "%qs is not a valid base register in %<-mstack-protector-guard-reg=%>"
+msgstr ""
+
+#: config/i386/i386-options.cc:3271
+#, gcc-internal-format
+msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
+msgstr ""
+
+#: config/i386/i386-options.cc:3280
+#, gcc-internal-format
+msgid "%<-fcf-protection%> is not compatible with this target"
+msgstr ""
+
+#: config/i386/i386-options.cc:3447
+#, gcc-internal-format
+msgid "interrupt and naked attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386-options.cc:3451 config/i386/i386-options.cc:3483
+#: config/i386/i386-options.cc:4027 config/i386/i386-options.cc:4037
+#, gcc-internal-format
+msgid "%qs and %qs attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386-options.cc:3468
+#, gcc-internal-format
+msgid "only DWARF debug format is supported for interrupt service routine"
+msgstr ""
+
+#: config/i386/i386-options.cc:3529
+#, gcc-internal-format
+msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
+msgstr ""
+
+#: config/i386/i386-options.cc:3539
+#, gcc-internal-format
+msgid "%<-mindirect-branch%> and %<-fcf-protection%> are not compatible"
+msgstr ""
+
+#: config/i386/i386-options.cc:3574
+#, gcc-internal-format
+msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
+msgstr ""
+
+#: config/i386/i386-options.cc:3584
+#, gcc-internal-format
+msgid "%<-mfunction-return%> and %<-fcf-protection%> are not compatible"
+msgstr ""
+
+#: config/i386/i386-options.cc:3692
+#, gcc-internal-format
+msgid "%s instructions aren%'t allowed in an exception service routine"
+msgstr ""
+
+#: config/i386/i386-options.cc:3694
+#, gcc-internal-format
+msgid "%s instructions aren%'t allowed in an interrupt service routine"
+msgstr ""
+
+#: config/i386/i386-options.cc:3698
+#, gcc-internal-format
+msgid "%s instructions aren%'t allowed in a function with the %<no_caller_saved_registers%> attribute"
+msgstr ""
+
+#: config/i386/i386-options.cc:3745 config/i386/i386-options.cc:3796
+#, gcc-internal-format
+msgid "fastcall and regparm attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386-options.cc:3750
+#, gcc-internal-format
+msgid "regparam and thiscall attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386-options.cc:3757 config/i386/i386-options.cc:3985
+#, gcc-internal-format
+msgid "%qE attribute requires an integer constant argument"
+msgstr ""
+
+#: config/i386/i386-options.cc:3763
+#, gcc-internal-format
+msgid "argument to %qE attribute larger than %d"
+msgstr ""
+
+#: config/i386/i386-options.cc:3788 config/i386/i386-options.cc:3831
+#, gcc-internal-format
+msgid "fastcall and cdecl attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386-options.cc:3792
+#, gcc-internal-format
+msgid "fastcall and stdcall attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386-options.cc:3800 config/i386/i386-options.cc:3849
+#, gcc-internal-format
+msgid "fastcall and thiscall attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386-options.cc:3810 config/i386/i386-options.cc:3827
+#, gcc-internal-format
+msgid "stdcall and cdecl attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386-options.cc:3814
+#, gcc-internal-format
+msgid "stdcall and fastcall attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386-options.cc:3818 config/i386/i386-options.cc:3845
+#, gcc-internal-format
+msgid "stdcall and thiscall attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386-options.cc:3835 config/i386/i386-options.cc:3853
+#, gcc-internal-format
+msgid "cdecl and thiscall attributes are not compatible"
+msgstr ""
+
+#: config/i386/i386-options.cc:3841
+#, gcc-internal-format
+msgid "%qE attribute is used for non-class method"
+msgstr ""
+
+#: config/i386/i386-options.cc:3945 config/rs6000/rs6000.cc:20762
+#, gcc-internal-format
+msgid "%qE incompatible attribute ignored"
+msgstr ""
+
+#: config/i386/i386-options.cc:3972
+#, gcc-internal-format
+msgid "%qE attribute only available for 32-bit"
+msgstr ""
+
+#: config/i386/i386-options.cc:3993
+#, gcc-internal-format
+msgid "argument to %qE attribute is neither zero, nor one"
+msgstr ""
+
+#: config/i386/i386-options.cc:4064 config/i386/i386-options.cc:4086
+#: config/ia64/ia64.cc:822 config/s390/s390.cc:1272
+#, gcc-internal-format
+msgid "%qE attribute requires a string constant argument"
+msgstr ""
+
+#: config/i386/i386-options.cc:4074 config/i386/i386-options.cc:4096
+#: config/s390/s390.cc:1301
+#, gcc-internal-format
+msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
+msgstr ""
+
+#: config/i386/i386-options.cc:4128
+#, gcc-internal-format
+msgid "interrupt service routine should have a pointer as the first argument"
+msgstr ""
+
+#: config/i386/i386-options.cc:4135
+#, gcc-internal-format
+msgid "interrupt service routine should have %qs as the second argument"
+msgstr ""
+
+#: config/i386/i386-options.cc:4146
+#, gcc-internal-format
+msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
+msgstr ""
+
+#: config/i386/i386-options.cc:4149
+#, gcc-internal-format
+msgid "interrupt service routine must return %<void%>"
+msgstr ""
+
+#: config/i386/i386.cc:1281
+#, gcc-internal-format
+msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.cc:1284
+#, gcc-internal-format
+msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.cc:1588
+#, gcc-internal-format
+msgid "X32 does not support %<ms_abi%> attribute"
+msgstr ""
+
+#: config/i386/i386.cc:1622
+#, gcc-internal-format
+msgid "%<ms_hook_prologue%> attribute is not compatible with nested function"
+msgstr ""
+
+#: config/i386/i386.cc:1974
+#, gcc-internal-format
+msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
+msgstr ""
+
+#: config/i386/i386.cc:1980
+#, gcc-internal-format
+msgid "AVX512F vector return without AVX512F enabled changes the ABI"
+msgstr ""
+
+#: config/i386/i386.cc:1994
+#, gcc-internal-format
+msgid "AVX vector argument without AVX enabled changes the ABI"
+msgstr ""
+
+#: config/i386/i386.cc:2000
+#, gcc-internal-format
+msgid "AVX vector return without AVX enabled changes the ABI"
+msgstr ""
+
+#: config/i386/i386.cc:2016
+#, gcc-internal-format
+msgid "SSE vector argument without SSE enabled changes the ABI"
+msgstr ""
+
+#: config/i386/i386.cc:2022
+#, gcc-internal-format
+msgid "SSE vector return without SSE enabled changes the ABI"
+msgstr ""
+
+#: config/i386/i386.cc:2038
+#, gcc-internal-format
+msgid "MMX vector argument without MMX enabled changes the ABI"
+msgstr ""
+
+#: config/i386/i386.cc:2044
+#, gcc-internal-format
+msgid "MMX vector return without MMX enabled changes the ABI"
+msgstr ""
+
+#: config/i386/i386.cc:2243
+#, gcc-internal-format
+msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
+msgstr ""
+
+#: config/i386/i386.cc:2372
+#, gcc-internal-format
+msgid "the ABI of passing union with %<long double%> has changed in GCC 4.4"
+msgstr ""
+
+#: config/i386/i386.cc:2507
+#, gcc-internal-format
+msgid "the ABI of passing structure with %<complex float%> member has changed in GCC 4.4"
+msgstr ""
+
+#: config/i386/i386.cc:2628
+msgid "the ABI of passing C structures with zero-width bit-fields has changed in GCC %{12.1%}"
+msgstr ""
+
+#: config/i386/i386.cc:2725 config/i386/i386.cc:4094 config/i386/i386.cc:4104
+#, gcc-internal-format
+msgid "SSE register return with SSE2 disabled"
+msgstr ""
+
+#: config/i386/i386.cc:2727
+#, gcc-internal-format
+msgid "SSE register return with SSE disabled"
+msgstr ""
+
+#: config/i386/i386.cc:2734
+#, gcc-internal-format
+msgid "SSE register argument with SSE2 disabled"
+msgstr ""
+
+#: config/i386/i386.cc:2736
+#, gcc-internal-format
+msgid "SSE register argument with SSE disabled"
+msgstr ""
+
+#: config/i386/i386.cc:2756
+#, gcc-internal-format
+msgid "x87 register return with x87 disabled"
+msgstr ""
+
+#: config/i386/i386.cc:3084 config/i386/i386.cc:3329 config/i386/i386.cc:4122
+#, gcc-internal-format
+msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
+msgstr ""
+
+#: config/i386/i386.cc:3086 config/i386/i386.cc:3331 config/i386/i386.cc:4124
+#, gcc-internal-format
+msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
+msgstr ""
+
+#: config/i386/i386.cc:3734
+#, gcc-internal-format, gfc-internal-format
+msgid "the ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
+msgstr ""
+
+#: config/i386/i386.cc:6790
+#, gcc-internal-format
+msgid "%<-mcall-ms2sysv-xlogues%> is not compatible with %s"
+msgstr ""
+
+#: config/i386/i386.cc:8808
+#, gcc-internal-format
+msgid "%<ms_hook_prologue%> attribute is not compatible with %<-mfentry%> for 32-bit"
+msgstr ""
+
+#: config/i386/i386.cc:8898
+#, gcc-internal-format
+msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
+msgstr ""
+
+#: config/i386/i386.cc:9951
+#, gcc-internal-format
+msgid "Stack realignment not supported with %<__builtin_eh_return%>"
+msgstr ""
+
+#: config/i386/i386.cc:9956
+#, gcc-internal-format
+msgid "regparm nested function not supported with %<__builtin_eh_return%>"
+msgstr ""
+
+#: config/i386/i386.cc:10347
+#, gcc-internal-format
+msgid "%<-fsplit-stack%> does not support fastcall with nested function"
+msgstr ""
+
+#: config/i386/i386.cc:10367
+#, gcc-internal-format
+msgid "%<-fsplit-stack%> does not support 2 register parameters for a nested function"
+msgstr ""
+
+#. FIXME: We could make this work by pushing a register
+#. around the addition and comparison.
+#: config/i386/i386.cc:10378
+#, gcc-internal-format
+msgid "%<-fsplit-stack%> does not support 3 register parameters"
+msgstr ""
+
+#: config/i386/i386.cc:13564
+#, gcc-internal-format
+msgid "%<V%> modifier on non-integer register"
+msgstr ""
+
+#: config/i386/i386.cc:13575 config/i386/i386.cc:13589
+#, gcc-internal-format
+msgid "unsupported size for integer register"
+msgstr ""
+
+#: config/i386/i386.cc:13621
+#, gcc-internal-format
+msgid "extended registers have no high halves"
+msgstr ""
+
+#: config/i386/i386.cc:13636
+#, gcc-internal-format
+msgid "unsupported operand size for extended register"
+msgstr ""
+
+#: config/i386/i386.cc:13833 config/i386/i386.cc:13835
+#, gcc-internal-format
+msgid "non-integer operand used with operand code %<z%>"
+msgstr ""
+
+#: config/i386/i386.cc:17985
+#, gcc-internal-format
+msgid "empty class %qT parameter passing ABI changes in %<-fabi-version=12%> (GCC 8)"
+msgstr ""
+
+#: config/i386/i386.cc:22766
+msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
+msgstr ""
+
+#: config/i386/i386.cc:22847
+#, gcc-internal-format
+msgid "no register available for profiling %<-mcmodel=large%s%>"
+msgstr ""
+
+#: config/i386/i386.cc:22943
+#, gcc-internal-format
+msgid "profiling %<-mcmodel=large%> with PIC is not supported"
+msgstr ""
+
+#: config/i386/i386.cc:23802
+#, gcc-internal-format
+msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
+msgstr ""
+
+#: config/i386/i386.cc:25252
+#, gcc-internal-format
+msgid "unknown architecture specific memory model"
+msgstr ""
+
+#: config/i386/i386.cc:25259
+#, gcc-internal-format
+msgid "%<HLE_ACQUIRE%> not used with %<ACQUIRE%> or stronger memory model"
+msgstr ""
+
+#: config/i386/i386.cc:25266
+#, gcc-internal-format
+msgid "%<HLE_RELEASE%> not used with %<RELEASE%> or stronger memory model"
+msgstr ""
+
+#: config/i386/i386.cc:25953
+#, gcc-internal-format
+msgid "%<-fexcess-precision=16%> is not compatible with %<-mfpmath=387%>"
+msgstr ""
+
+#: config/i386/winnt.cc:83
+#, gcc-internal-format
+msgid "%qE attribute applies only to initialized variables with external linkage"
+msgstr ""
+
+#: config/i386/winnt.cc:156
+#, gcc-internal-format
+msgid "definition of static data member %q+D of dllimport%'d class"
+msgstr ""
+
+#: config/ia64/ia64-c.cc:50
+#, gcc-internal-format
+msgid "malformed %<#pragma builtin%>"
+msgstr ""
+
+#: config/ia64/ia64.cc:761 config/loongarch/loongarch.cc:7981
+#: config/loongarch/loongarch.cc:7991
+#, gcc-internal-format
+msgid "invalid argument of %qE attribute"
+msgstr ""
+
+#: config/ia64/ia64.cc:774
+#, gcc-internal-format
+msgid "an address area attribute cannot be specified for local variables"
+msgstr ""
+
+#: config/ia64/ia64.cc:781
+#, gcc-internal-format
+msgid "address area of %q+D conflicts with previous declaration"
+msgstr ""
+
+#: config/ia64/ia64.cc:789
+#, gcc-internal-format
+msgid "address area attribute cannot be specified for functions"
+msgstr ""
+
+#: config/ia64/ia64.cc:6035 config/pa/pa.cc:461 config/sh/sh.cc:8267
+#, gcc-internal-format
+msgid "value of %<-mfixed-range%> must have form REG1-REG2"
+msgstr ""
+
+#: config/ia64/ia64.cc:11312
+#, gcc-internal-format
+msgid "version attribute is not a string"
+msgstr ""
+
+#: config/iq2000/iq2000.cc:1864
+#, gcc-internal-format
+msgid "%<gp_offset%> (%ld) or %<end_offset%> (%ld) is less than zero"
+msgstr ""
+
+#: config/iq2000/iq2000.cc:2587
+#, gcc-internal-format
+msgid "argument %qd is not a constant"
+msgstr ""
+
+#: config/iq2000/iq2000.cc:2890 config/xtensa/xtensa.cc:3158
+#, gcc-internal-format
+msgid "%<PRINT_OPERAND_ADDRESS%>, null pointer"
+msgstr ""
+
+#: config/iq2000/iq2000.cc:3045
+#, gcc-internal-format
+msgid "%<PRINT_OPERAND%>: Unknown punctuation %<%c%>"
+msgstr ""
+
+#: config/iq2000/iq2000.cc:3054 config/xtensa/xtensa.cc:3007
+#, gcc-internal-format
+msgid "%<PRINT_OPERAND%> null pointer"
+msgstr ""
+
+#: config/loongarch/loongarch-builtins.cc:2999 config/mips/mips.cc:17397
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %d to the built-in must be a constant in range %d to %d"
+msgstr ""
+
+#: config/loongarch/loongarch-builtins.cc:3077 config/mips/mips.cc:17517
+#, gcc-internal-format
+msgid "failed to expand built-in function"
+msgstr ""
+
+#: config/loongarch/loongarch-builtins.cc:3116
+#, gcc-internal-format
+msgid "built-in function %qD is not enabled"
+msgstr ""
+
+#: config/loongarch/loongarch-cpu.cc:115
+#, gcc-internal-format
+msgid "unknown processor ID %<0x%x%>, some tuning parameters will fall back to default"
+msgstr ""
+
+#: config/loongarch/loongarch-cpu.cc:144
+#, gcc-internal-format
+msgid "unknown native base architecture %<0x%x%>, %qs failed"
+msgstr ""
+
+#: config/loongarch/loongarch-cpu.cc:173
+#, gcc-internal-format
+msgid "unknown native FPU type %<0x%x%>, %qs failed"
+msgstr ""
+
+#: config/loongarch/loongarch-cpu.cc:180
+#, gcc-internal-format
+msgid "floating-point unit %qs differs from PRID preset %qs"
+msgstr ""
+
+#: config/loongarch/loongarch-cpu.cc:204
+#, gcc-internal-format
+msgid "unknown SIMD extension (%qs disabled while %qs is enabled), disabling SIMD"
+msgstr ""
+
+#: config/loongarch/loongarch-cpu.cc:242
+#, gcc-internal-format
+msgid "detected base architecture %qs, but some of its features are not detected; the detected base architecture may be unreliable, only detected features will be enabled"
+msgstr ""
+
+#: config/loongarch/loongarch-opts.cc:235
+#, gcc-internal-format
+msgid "%<-m%s%> overrides %<-m%s=%s%>, adjusting ABI to %qs"
+msgstr ""
+
+#: config/loongarch/loongarch-opts.cc:252
+#, gcc-internal-format
+msgid "ABI changed (%qs to %qs) while multilib is disabled"
+msgstr ""
+
+#: config/loongarch/loongarch-opts.cc:281
+#: config/loongarch/loongarch-opts.cc:286
+#, gcc-internal-format
+msgid "%qs does not work on a cross compiler"
+msgstr ""
+
+#: config/loongarch/loongarch-opts.cc:375
+#, gcc-internal-format
+msgid "enabling %qs promotes %<%s%s%> to %<%s%s%>"
+msgstr ""
+
+#: config/loongarch/loongarch-opts.cc:387
+#, gcc-internal-format
+msgid "%qs is disabled by %<-m%s%>, because it requires %<%s%s%>"
+msgstr ""
+
+#: config/loongarch/loongarch-opts.cc:399
+#, gcc-internal-format
+msgid "%<-m%s=%s%> conflicts with %qs, which requires %<%s%s%>"
+msgstr ""
+
+#: config/loongarch/loongarch-opts.cc:443
+#, gcc-internal-format
+msgid "your native CPU architecture (%qs) does not support %qs ABI, falling back to %<-m%s=%s%>"
+msgstr ""
+
+#: config/loongarch/loongarch-opts.cc:448
+#, gcc-internal-format
+msgid "default CPU architecture (%qs) does not support %qs ABI, falling back to %<-m%s=%s%>"
+msgstr ""
+
+#: config/loongarch/loongarch-opts.cc:479
+#, gcc-internal-format
+msgid "unable to implement ABI %qs with instruction set %qs"
+msgstr ""
+
+#: config/loongarch/loongarch-opts.cc:501
+#, gcc-internal-format
+msgid "ABI %qs cannot be implemented due to limited instruction set %qs, falling back to %qs"
+msgstr ""
+
+#: config/loongarch/loongarch-opts.cc:512
+#, gcc-internal-format
+msgid "instruction set %qs cannot implement default ABI %qs, falling back to %qs"
+msgstr ""
+
+#: config/loongarch/loongarch-opts.cc:517
+#, gcc-internal-format
+msgid "no multilib-enabled ABI (%qs) can be implemented with instruction set %qs, falling back to %qs"
+msgstr ""
+
+#: config/loongarch/loongarch-opts.cc:533
+#, gcc-internal-format
+msgid "ABI %qs is not enabled at configure-time, the linker might report an error"
+msgstr ""
+
+#: config/loongarch/loongarch-opts.cc:536
+#, gcc-internal-format, gfc-internal-format
+msgid "ABI with startfiles: %s"
+msgstr ""
+
+#: config/loongarch/loongarch-opts.cc:550
+#, gcc-internal-format
+msgid "%qs is not supported, now cmodel is set to %qs"
+msgstr ""
+
+#: config/loongarch/loongarch-opts.cc:1023
+#, gcc-internal-format
+msgid "code model %qs is not compatible with %s"
+msgstr ""
+
+#: config/loongarch/loongarch-opts.cc:1089
+#, gcc-internal-format
+msgid "%qs cannot be used for compiling a shared library"
+msgstr ""
+
+#: config/loongarch/loongarch.cc:7953
+#, gcc-internal-format
+msgid "%qE attribute cannot be specified for thread-local variables"
+msgstr ""
+
+#: config/loongarch/loongarch.cc:7971
+#, gcc-internal-format
+msgid "%qE attribute cannot be specified for register variables"
+msgstr ""
+
+#: config/loongarch/loongarch.cc:7999
+#, gcc-internal-format
+msgid "multiple %qE attribute"
+msgstr ""
+
+#: config/m32c/m32c-pragma.cc:54
+#, gcc-internal-format
+msgid "junk at end of %<#pragma GCC memregs%> [0-16]"
+msgstr ""
+
+#: config/m32c/m32c-pragma.cc:61
+#, gcc-internal-format
+msgid "%<#pragma GCC memregs%> must precede any function declarations"
+msgstr ""
+
+#: config/m32c/m32c-pragma.cc:69 config/m32c/m32c-pragma.cc:76
+#, gcc-internal-format
+msgid "%<#pragma GCC memregs%> takes a number [0-16]"
+msgstr ""
+
+#: config/m32c/m32c-pragma.cc:104
+#, gcc-internal-format
+msgid "junk at end of %<#pragma ADDRESS%>"
+msgstr ""
+
+#: config/m32c/m32c-pragma.cc:109
+#, gcc-internal-format
+msgid "malformed %<#pragma ADDRESS%> variable address"
+msgstr ""
+
+#: config/m32c/m32c.cc:422
+#, gcc-internal-format
+msgid "invalid target memregs value %<%d%>"
+msgstr ""
+
+#: config/m32c/m32c.cc:2934
+#, gcc-internal-format
+msgid "%qE attribute is not supported for R8C target"
+msgstr ""
+
+#. The argument must be a constant integer.
+#: config/m32c/m32c.cc:2950 config/sh/sh.cc:8479 config/sh/sh.cc:8574
+#, gcc-internal-format
+msgid "%qE attribute argument not an integer constant"
+msgstr ""
+
+#: config/m32c/m32c.cc:2959
+#, gcc-internal-format
+msgid "%qE attribute argument should be between 18 to 255"
+msgstr ""
+
+#: config/m32c/m32c.cc:4082
+#, gcc-internal-format
+msgid "%<bank_switch%> has no effect on non-interrupt functions"
+msgstr ""
+
+#: config/m32c/m32c.cc:4189
+#, gcc-internal-format
+msgid "%<fast_interrupt%> attribute directive ignored"
+msgstr ""
+
+#: config/m32r/m32r.cc:412
+#, gcc-internal-format
+msgid "invalid argument of %qs attribute"
+msgstr ""
+
+#: config/m68k/m68k.cc:535
+#, gcc-internal-format
+msgid "%<-mcpu=%s%> conflicts with %<-march=%s%>"
+msgstr ""
+
+#: config/m68k/m68k.cc:606
+#, gcc-internal-format
+msgid "%<-mpcrel%> %<-fPIC%> is not currently supported on selected cpu"
+msgstr ""
+
+#: config/m68k/m68k.cc:670
+#, gcc-internal-format
+msgid "%<-falign-labels=%d%> is not supported"
+msgstr ""
+
+#: config/m68k/m68k.cc:677
+#, gcc-internal-format
+msgid "%<-falign-loops=%d%> is not supported"
+msgstr ""
+
+#: config/m68k/m68k.cc:685
+#, gcc-internal-format
+msgid "%<-fstack-limit-%> options are not supported on this cpu"
+msgstr ""
+
+#: config/m68k/m68k.cc:803
+#, gcc-internal-format
+msgid "multiple interrupt attributes not allowed"
+msgstr ""
+
+#: config/m68k/m68k.cc:810
+#, gcc-internal-format
+msgid "%<interrupt_thread%> is available only on fido"
+msgstr ""
+
+#: config/m68k/m68k.cc:1144 config/rs6000/rs6000-logue.cc:1742
+#, gcc-internal-format
+msgid "stack limit expression is not supported"
+msgstr ""
+
+#: config/m68k/m68k.cc:7138 config/s390/s390.cc:17178
+#, gcc-internal-format
+msgid "%<-fexcess-precision=16%> is not supported on this target"
+msgstr ""
+
+#: config/mcore/mcore.cc:2960
+#, gcc-internal-format
+msgid "initialized variable %q+D is marked dllimport"
+msgstr ""
+
+#: config/microblaze/microblaze.cc:1760
+#, gcc-internal-format
+msgid "%<-fPIC%>/%<-fpic%> not supported for this target"
+msgstr ""
+
+#: config/microblaze/microblaze.cc:1772
+#, gcc-internal-format
+msgid "%qs is an invalid argument to %<-mcpu=%>"
+msgstr ""
+
+#: config/microblaze/microblaze.cc:1821
+#, gcc-internal-format
+msgid "%<-mxl-multiply-high%> can be used only with %<-mcpu=v6.00.a%> or greater"
+msgstr ""
+
+#: config/microblaze/microblaze.cc:1838
+#, gcc-internal-format
+msgid "%<-mxl-reorder%> can be used only with %<-mcpu=v8.30.a%> or greater"
+msgstr ""
+
+#: config/microblaze/microblaze.cc:1845
+#, gcc-internal-format
+msgid "%<-mxl-reorder%> requires %<-mxl-pattern-compare%> for %<-mcpu=v8.30.a%>"
+msgstr ""
+
+#: config/microblaze/microblaze.cc:1851
+#, gcc-internal-format
+msgid "%<-mxl-multiply-high%> requires %<-mno-xl-soft-mul%>"
+msgstr ""
+
+#: config/mips/mips.cc:1332 config/mips/mips.cc:1593 config/mips/mips.cc:1647
+#: config/riscv/riscv.cc:5812
+#, gcc-internal-format
+msgid "%qE attribute requires a string argument"
+msgstr ""
+
+#: config/mips/mips.cc:1340
+#, gcc-internal-format
+msgid "argument to %qE attribute is neither no, pcrel nor yes"
+msgstr ""
+
+#: config/mips/mips.cc:1506 config/mips/mips.cc:1510
+#, gcc-internal-format
+msgid "%qs attribute only applies to functions"
+msgstr ""
+
+#: config/mips/mips.cc:1520 config/mips/mips.cc:1526
+#, gcc-internal-format
+msgid "%qE cannot have both %qs and %qs attributes"
+msgstr ""
+
+#: config/mips/mips.cc:1555 config/mips/mips.cc:1561 config/nios2/nios2.cc:4489
+#, gcc-internal-format
+msgid "%qE redeclared with conflicting %qs attributes"
+msgstr ""
+
+#: config/mips/mips.cc:1601
+#, gcc-internal-format
+msgid "argument to %qE attribute is neither eic, nor %<vector=<line>%>"
+msgstr ""
+
+#: config/mips/mips.cc:1617
+#, gcc-internal-format
+msgid "interrupt vector to %qE attribute is not %<vector=(sw0|sw1|hw0|hw1|hw2|hw3|hw4|hw5)%>"
+msgstr ""
+
+#: config/mips/mips.cc:1654
+#, gcc-internal-format
+msgid "argument to %qE attribute is not intstack"
+msgstr ""
+
+#: config/mips/mips.cc:6232
+msgid "the ABI for passing a value containing zero-width fields before an adjacent 64-bit floating-point field was changed in GCC %{12.1%}"
+msgstr ""
+
+#: config/mips/mips.cc:6677
+msgid "the ABI for returning a value containing zero-width bit-fields but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
+msgstr ""
+
+#: config/mips/mips.cc:6701
+msgid "the ABI for returning a value with C++17 empty bases but otherwise an aggregate with only one or two floating-point fields was changed in GCC %{12.1%}"
+msgstr ""
+
+#: config/mips/mips.cc:8048
+#, gcc-internal-format
+msgid "cannot handle inconsistent calls to %qs"
+msgstr ""
+
+#: config/mips/mips.cc:11304
+#, gcc-internal-format
+msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
+msgstr ""
+
+#: config/mips/mips.cc:11306
+#, gcc-internal-format
+msgid "interrupt handlers cannot be MIPS16 functions"
+msgstr ""
+
+#: config/mips/mips.cc:12310
+#, gcc-internal-format
+msgid "%<-fstack-check=specific%> not implemented for MIPS16"
+msgstr ""
+
+#: config/mips/mips.cc:17649
+#, gcc-internal-format
+msgid "built-in function %qE not supported for MIPS16"
+msgstr ""
+
+#: config/mips/mips.cc:18257
+#, gcc-internal-format
+msgid "%qs does not support MIPS16 code"
+msgstr ""
+
+#: config/mips/mips.cc:20070
+#, gcc-internal-format
+msgid "MIPS16 PIC for ABIs other than o32 and o64"
+msgstr ""
+
+#: config/mips/mips.cc:20073
+#, gcc-internal-format
+msgid "MIPS16 %<-mxgot%> code"
+msgstr ""
+
+#: config/mips/mips.cc:20076
+#, gcc-internal-format
+msgid "%<hard-float%> MIPS16 code for ABIs other than o32 and o64"
+msgstr ""
+
+#: config/mips/mips.cc:20079
+#, gcc-internal-format
+msgid "MSA MIPS16 code"
+msgstr ""
+
+#: config/mips/mips.cc:20082
+#, gcc-internal-format
+msgid "MIPS16 requires %<-mexplicit-relocs%>"
+msgstr ""
+
+#: config/mips/mips.cc:20273 config/mips/mips.cc:20278
+#: config/mips/mips.cc:20368 config/mips/mips.cc:20370
+#: config/mips/mips.cc:20400 config/mips/mips.cc:20410
+#: config/mips/mips.cc:20516 config/mips/mips.cc:20540
+#, gcc-internal-format, gfc-internal-format
+msgid "unsupported combination: %s"
+msgstr ""
+
+#: config/mips/mips.cc:20313
+#, gcc-internal-format
+msgid "%<-%s%> conflicts with the other architecture options, which specify a %s processor"
+msgstr ""
+
+#: config/mips/mips.cc:20323
+#, gcc-internal-format
+msgid "%<-march=%s%> is not compatible with the selected ABI"
+msgstr ""
+
+#: config/mips/mips.cc:20338
+#, gcc-internal-format
+msgid "%<-mgp64%> used with a 32-bit processor"
+msgstr ""
+
+#: config/mips/mips.cc:20340
+#, gcc-internal-format
+msgid "%<-mgp32%> used with a 64-bit ABI"
+msgstr ""
+
+#: config/mips/mips.cc:20342
+#, gcc-internal-format
+msgid "%<-mgp64%> used with a 32-bit ABI"
+msgstr ""
+
+#: config/mips/mips.cc:20365
+#, gcc-internal-format
+msgid "the %qs architecture does not support %<-mfp32%>"
+msgstr ""
+
+#: config/mips/mips.cc:20374
+#, gcc-internal-format
+msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
+msgstr ""
+
+#: config/mips/mips.cc:20377
+#, gcc-internal-format
+msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
+msgstr ""
+
+#: config/mips/mips.cc:20398
+#, gcc-internal-format
+msgid "%<-mfpxx%> can only be used with the o32 ABI"
+msgstr ""
+
+#: config/mips/mips.cc:20402
+#, gcc-internal-format
+msgid "%<-march=%s%> requires %<-mfp32%>"
+msgstr ""
+
+#: config/mips/mips.cc:20404
+#, gcc-internal-format
+msgid "%<-mfpxx%> requires %<-mlra%>"
+msgstr ""
+
+#. We have traditionally allowed non-abicalls code to use
+#. an LP64 form of o64.  However, it would take a bit more
+#. effort to support the combination of 32-bit GOT entries
+#. and 64-bit pointers, so we treat the abicalls case as
+#. an error.
+#: config/mips/mips.cc:20429
+#, gcc-internal-format
+msgid "the combination of %qs and %qs is incompatible with %qs"
+msgstr ""
+
+#: config/mips/mips.cc:20482
+#, gcc-internal-format
+msgid "the %qs architecture does not support branch-likely instructions"
+msgstr ""
+
+#: config/mips/mips.cc:20497
+#, gcc-internal-format
+msgid "the %qs architecture does not support madd or msub instructions"
+msgstr ""
+
+#: config/mips/mips.cc:20511
+#, gcc-internal-format
+msgid "the %qs architecture does not support odd single-precision registers"
+msgstr ""
+
+#: config/mips/mips.cc:20524
+#, gcc-internal-format
+msgid "unsupported combination: %qs%s %s"
+msgstr ""
+
+#: config/mips/mips.cc:20533
+#, gcc-internal-format
+msgid "unsupported combination: %qs %s"
+msgstr ""
+
+#: config/mips/mips.cc:20548
+#, gcc-internal-format
+msgid "cannot generate position-independent code for %qs"
+msgstr ""
+
+#: config/mips/mips.cc:20551
+#, gcc-internal-format
+msgid "position-independent code requires %qs"
+msgstr ""
+
+#: config/mips/mips.cc:20584
+#, gcc-internal-format
+msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
+msgstr ""
+
+#: config/mips/mips.cc:20592 config/mips/mips.cc:20595
+#, gcc-internal-format
+msgid "cannot use small-data accesses for %qs"
+msgstr ""
+
+#: config/mips/mips.cc:20612
+#, gcc-internal-format
+msgid "the %qs architecture does not support %<-m%s=legacy%>"
+msgstr ""
+
+#: config/mips/mips.cc:20619
+#, gcc-internal-format
+msgid "the %qs architecture does not support %<-m%s=2008%>"
+msgstr ""
+
+#: config/mips/mips.cc:20637
+#, gcc-internal-format
+msgid "%<-mips3d%> requires %<-mpaired-single%>"
+msgstr ""
+
+#: config/mips/mips.cc:20647
+#, gcc-internal-format
+msgid "%qs must be used with %qs"
+msgstr ""
+
+#: config/mips/mips.cc:20657
+#, gcc-internal-format
+msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
+msgstr ""
+
+#: config/mips/mips.cc:20664
+#, gcc-internal-format
+msgid "the %qs architecture does not support paired-single instructions"
+msgstr ""
+
+#: config/mips/mips.cc:20673
+#, gcc-internal-format
+msgid "%qs requires a target that provides the %qs instruction"
+msgstr ""
+
+#: config/mips/mips.cc:20684
+#, gcc-internal-format
+msgid "the %qs architecture does not support DSP instructions"
+msgstr ""
+
+#: config/mips/mips.cc:20694
+#, gcc-internal-format
+msgid "%<-mloongson-mmi%> must be used with %<-mhard-float%>"
+msgstr ""
+
+#: config/mips/mips.cc:20704
+#, gcc-internal-format
+msgid "%<-mloongson-ext2%> must be used with %<-mloongson-ext%>"
+msgstr ""
+
+#: config/mips/mips.cc:20799
+#, gcc-internal-format
+msgid "%qs requires branch-likely instructions"
+msgstr ""
+
+#: config/mips/mips.cc:20803
+#, gcc-internal-format
+msgid "the %qs architecture does not support the synci instruction"
+msgstr ""
+
+#: config/mips/mips.cc:21639
+#, gcc-internal-format
+msgid "mips16 function profiling"
+msgstr ""
+
+#: config/mmix/mmix.cc:318
+#, gcc-internal-format
+msgid "%<-f%s%> not supported: ignored"
+msgstr ""
+
+#: config/mmix/mmix.cc:783
+#, gcc-internal-format
+msgid "support for mode %qs"
+msgstr ""
+
+#: config/mmix/mmix.cc:797
+#, gcc-internal-format, gfc-internal-format
+msgid "too large function value type, needs %d registers, have only %d registers for this"
+msgstr ""
+
+#: config/mmix/mmix.cc:978
+#, gcc-internal-format
+msgid "%<function_profiler%> support for MMIX"
+msgstr ""
+
+#: config/mmix/mmix.cc:1002
+#, gcc-internal-format
+msgid "MMIX Internal: Last named vararg would not fit in a register"
+msgstr ""
+
+#: config/mmix/mmix.cc:1643 config/mmix/mmix.cc:1667 config/mmix/mmix.cc:1774
+#, gcc-internal-format, gfc-internal-format
+msgid "MMIX Internal: Bad register: %d"
+msgstr ""
+
+#. Presumably there's a missing case above if we get here.
+#: config/mmix/mmix.cc:1766
+#, gcc-internal-format
+msgid "MMIX Internal: Missing %qc case in %<mmix_print_operand%>"
+msgstr ""
+
+#: config/mmix/mmix.cc:2055
+#, gcc-internal-format
+msgid "stack frame not a multiple of 8 bytes: %wd"
+msgstr ""
+
+#: config/mmix/mmix.cc:2308
+#, gcc-internal-format
+msgid "stack frame not a multiple of octabyte: %wd"
+msgstr ""
+
+#: config/mmix/mmix.cc:2594 config/mmix/mmix.cc:2653
+#, gcc-internal-format, gfc-internal-format
+msgid "MMIX Internal: %s is not a shiftable integer"
+msgstr ""
+
+#: config/mn10300/mn10300.cc:107
+#, gcc-internal-format
+msgid "%<-mtune=%> expects mn10300, am33, am33-2, or am34"
+msgstr ""
+
+#: config/msp430/driver-msp430.cc:38
+#, gcc-internal-format
+msgid "expected an argument to %<msp430_select_cpu%>"
+msgstr ""
+
+#: config/msp430/driver-msp430.cc:69
+#, gcc-internal-format
+msgid "%<msp430_set_driver_var%> expects 2 arguments"
+msgstr ""
+
+#: config/msp430/driver-msp430.cc:75
+#, gcc-internal-format
+msgid "unhandled arguments %qs and %qs to %<msp430_set_driver_var%>"
+msgstr ""
+
+#: config/msp430/driver-msp430.cc:92
+#, gcc-internal-format
+msgid "unexpected argument to %<msp430_select_hwmult_lib%>: %s"
+msgstr ""
+
+#: config/msp430/driver-msp430.cc:141
+#, gcc-internal-format
+msgid "unexpected first argument to %<msp430_select_hwmult_lib%>: %s"
+msgstr ""
+
+#: config/msp430/driver-msp430.cc:146
+#, gcc-internal-format
+msgid "%<msp430_select_hwmult_lib%> needs one or more arguments"
+msgstr ""
+
+#: config/msp430/msp430-devices.cc:258
+#, gcc-internal-format
+msgid "unexpected error opening %<devices.csv%>"
+msgstr ""
+
+#: config/msp430/msp430-devices.cc:297
+#, gcc-internal-format
+msgid "%<CPU_TYPE%> column heading is missing from %<devices.csv%>"
+msgstr ""
+
+#: config/msp430/msp430-devices.cc:300
+#, gcc-internal-format
+msgid "%<MPY_TYPE%> column heading is missing from %<devices.csv%>"
+msgstr ""
+
+#: config/msp430/msp430-devices.cc:303
+#, gcc-internal-format
+msgid "%<CPU_TYPE%> and %<MPY_TYPE%> column headings are missing from %<devices.csv%>"
+msgstr ""
+
+#: config/msp430/msp430-devices.cc:315
+#, gcc-internal-format
+msgid "format of column headings in %<devices.csv%> is incorrect"
+msgstr ""
+
+#: config/msp430/msp430-devices.cc:348
+#, gcc-internal-format
+msgid "invalid %<CPU_TYPE%> value of %qs read from %<devices.csv%> for %qs"
+msgstr ""
+
+#: config/msp430/msp430-devices.cc:368
+#, gcc-internal-format
+msgid "invalid %<MPY_TYPE%> value of %qs read from %<devices.csv%> for %qs"
+msgstr ""
+
+#: config/msp430/msp430-devices.cc:384
+#, gcc-internal-format
+msgid "unknown error reading %s from %<devices.csv%>"
+msgstr ""
+
+#: config/msp430/msp430-devices.cc:471
+#, gcc-internal-format
+msgid "unrecognized %<hwmpy%> field in %<hard_msp430_mcu_data[%d]%>: %qd"
+msgstr ""
+
+#: config/msp430/msp430-devices.cc:482
+#, gcc-internal-format
+msgid "unrecognized %<revision%> field in %<hard_msp430_mcu_data[%d]%>: %qd"
+msgstr ""
+
+#: config/msp430/msp430-devices.cc:488
+#, gcc-internal-format
+msgid "could not locate MCU data file %<devices.csv%>"
+msgstr ""
+
+#: config/msp430/msp430.cc:181
+#, gcc-internal-format
+msgid "MCU %qs supports %s ISA but %<-mcpu%> option is set to %s"
+msgstr ""
+
+#: config/msp430/msp430.cc:189
+#, gcc-internal-format
+msgid "MCU %qs does not have hardware multiply support, but %<-mhwmult%> is set to %s"
+msgstr ""
+
+#: config/msp430/msp430.cc:198
+#, gcc-internal-format
+msgid "MCU %qs supports %s hardware multiply, but %<-mhwmult%> is set to 16-bit"
+msgstr ""
+
+#: config/msp430/msp430.cc:203
+#, gcc-internal-format
+msgid "MCU %qs supports %s hardware multiply, but %<-mhwmult%> is set to 32-bit"
+msgstr ""
+
+#: config/msp430/msp430.cc:208
+#, gcc-internal-format
+msgid "MCU %qs supports %s hardware multiply, but %<-mhwmult%> is set to f5series"
+msgstr ""
+
+#: config/msp430/msp430.cc:225
+#, gcc-internal-format
+msgid "unrecognized MCU name %qs, assuming that it is just a MSP430X with no hardware multiply; use the %<-mcpu%> and %<-mhwmult%> options to set these explicitly"
+msgstr ""
+
+#: config/msp430/msp430.cc:232
+#, gcc-internal-format
+msgid "unrecognized MCU name %qs, assuming that it has no hardware multiply; use the %<-mhwmult%> option to set this explicitly"
+msgstr ""
+
+#: config/msp430/msp430.cc:244
+#, gcc-internal-format
+msgid "unrecognized MCU name %qs, assuming that it just supports the MSP430X ISA; use the %<-mcpu%> option to set the ISA explicitly"
+msgstr ""
+
+#: config/msp430/msp430.cc:250
+#, gcc-internal-format
+msgid "Unrecognized MCU name %qs."
+msgstr ""
+
+#: config/msp430/msp430.cc:255
+#, gcc-internal-format
+msgid "%<-mlarge%> requires a 430X-compatible %<-mmcu=%>"
+msgstr ""
+
+#: config/msp430/msp430.cc:258
+#, gcc-internal-format
+msgid "%<-mcode-region=either%> requires the large memory model (%<-mlarge%>)"
+msgstr ""
+
+#: config/msp430/msp430.cc:261
+#, gcc-internal-format
+msgid "%<-mcode-region=upper%> requires the large memory model (%<-mlarge%>)"
+msgstr ""
+
+#: config/msp430/msp430.cc:265
+#, gcc-internal-format
+msgid "%<-mdata-region=either%> requires the large memory model (%<-mlarge%>)"
+msgstr ""
+
+#: config/msp430/msp430.cc:268
+#, gcc-internal-format
+msgid "%<-mdata-region=upper%> requires the large memory model (%<-mlarge%>)"
+msgstr ""
+
+#: config/msp430/msp430.cc:291
+#, gcc-internal-format
+msgid "%<-fuse-cxa-atexit%> is not supported for msp430-elf"
+msgstr ""
+
+#: config/msp430/msp430.cc:296
+#, gcc-internal-format
+msgid "GCC must be configured with %<--enable-newlib-nano-formatted-io%> to use %<-mtiny-printf%>"
+msgstr ""
+
+#: config/msp430/msp430.cc:1897
+#, gcc-internal-format
+msgid "unrecognized interrupt vector argument of %qE attribute"
+msgstr ""
+
+#: config/msp430/msp430.cc:1906
+#, gcc-internal-format
+msgid "numeric argument of %qE attribute must be in range [0-63]"
+msgstr ""
+
+#: config/msp430/msp430.cc:1912
+#, gcc-internal-format
+msgid "argument of %qE attribute is not a string constant or number"
+msgstr ""
+
+#: config/msp430/msp430.cc:1941
+#, gcc-internal-format
+msgid "critical attribute has no effect on interrupt functions"
+msgstr ""
+
+#: config/msp430/msp430.cc:1977
+#, gcc-internal-format
+msgid "ignoring attribute %qE because it conflicts with attribute %<noinit%>"
+msgstr ""
+
+#: config/msp430/msp430.cc:1980
+#, gcc-internal-format
+msgid "ignoring attribute %qE because it conflicts with attribute %<section%>"
+msgstr ""
+
+#: config/msp430/msp430.cc:1983
+#, gcc-internal-format
+msgid "ignoring attribute %qE because it conflicts with attribute %<persistent%>"
+msgstr ""
+
+#: config/msp430/msp430.cc:1993
+#, gcc-internal-format
+msgid "%qE attribute ignored.  Large memory model (%<-mlarge%>) is required."
+msgstr ""
+
+#: config/msp430/msp430.cc:2101
+#, gcc-internal-format
+msgid "ignoring attribute %qE because it conflicts with attribute %<lower%>"
+msgstr ""
+
+#: config/msp430/msp430.cc:2104
+#, gcc-internal-format
+msgid "ignoring attribute %qE because it conflicts with attribute %<upper%>"
+msgstr ""
+
+#: config/msp430/msp430.cc:2107
+#, gcc-internal-format
+msgid "ignoring attribute %qE because it conflicts with attribute %<either%>"
+msgstr ""
+
+#: config/msp430/msp430.cc:2267
+#, gcc-internal-format
+msgid "argument to interrupt attribute is unsupported for weak functions"
+msgstr ""
+
+#: config/msp430/msp430.cc:2747 config/pru/pru.cc:2989
+#, gcc-internal-format
+msgid "%<__delay_cycles%> only takes constant arguments"
+msgstr ""
+
+#: config/msp430/msp430.cc:2757 config/pru/pru.cc:2998
+#, gcc-internal-format
+msgid "%<__delay_cycles%> only takes non-negative cycle counts"
+msgstr ""
+
+#: config/msp430/msp430.cc:2778 config/pru/pru.cc:3011
+#, gcc-internal-format
+msgid "%<__delay_cycles%> is limited to 32-bit loop counts"
+msgstr ""
+
+#: config/msp430/msp430.cc:2849
+#, gcc-internal-format
+msgid "MSP430 built-in functions only work inside interrupt handlers"
+msgstr ""
+
+#: config/msp430/msp430.cc:2861 config/pru/pru.cc:3082 config/rx/rx.cc:2667
+#: config/xtensa/xtensa.cc:4214 config/xtensa/xtensa.cc:4240
+#, gcc-internal-format
+msgid "bad builtin code"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.cc:126 config/nios2/nios2.cc:3840
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid argument to built-in function %s"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.cc:131
+#, gcc-internal-format, gfc-internal-format
+msgid "constant argument out of range for %s"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.cc:1003
+#, gcc-internal-format
+msgid "don%'t support DSP extension instructions"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.cc:1016
+#, gcc-internal-format
+msgid "this built-in function is only available on the v3s or v3f toolchain"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.cc:1028
+#, gcc-internal-format
+msgid "this built-in function is only available on the v3f toolchain"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.cc:1043
+#, gcc-internal-format
+msgid "this built-in function not support on the v3m toolchain"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.cc:1062
+#, gcc-internal-format
+msgid "don%'t support performance extension instructions"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.cc:1074
+#, gcc-internal-format
+msgid "don%'t support performance extension version 2 instructions"
+msgstr ""
+
+#: config/nds32/nds32-intrinsic.cc:1086
+#, gcc-internal-format
+msgid "don%'t support string extension instructions"
+msgstr ""
+
+#: config/nds32/nds32-isr.cc:116 config/nds32/nds32-isr.cc:207
+#, gcc-internal-format
+msgid "require id argument in the string"
+msgstr ""
+
+#: config/nds32/nds32-isr.cc:131
+#, gcc-internal-format
+msgid "invalid id value for interrupt attribute"
+msgstr ""
+
+#: config/nds32/nds32-isr.cc:221
+#, gcc-internal-format
+msgid "invalid id value for exception attribute"
+msgstr ""
+
+#: config/nds32/nds32-isr.cc:617
+#, gcc-internal-format
+msgid "multiple save register attributes to function %qD"
+msgstr ""
+
+#: config/nds32/nds32-isr.cc:630
+#, gcc-internal-format
+msgid "multiple nested types attributes to function %qD"
+msgstr ""
+
+#: config/nds32/nds32-isr.cc:642
+#, gcc-internal-format
+msgid "multiple interrupt attributes to function %qD"
+msgstr ""
+
+#: config/nds32/nds32-isr.cc:646
+#, gcc-internal-format
+msgid "cannot use interrupt attributes to function %qD under linux toolchain"
+msgstr ""
+
+#: config/nds32/nds32-isr.cc:649
+#, gcc-internal-format
+msgid "cannot use exception attributes to function %qD under linux toolchain"
+msgstr ""
+
+#: config/nds32/nds32-isr.cc:652
+#, gcc-internal-format
+msgid "cannot use reset attributes to function %qD under linux toolchain"
+msgstr ""
+
+#. Trampoline is not supported on reduced-set registers yet.
+#: config/nds32/nds32.cc:2408 config/nds32/nds32.cc:2462
+#: config/nds32/nds32.cc:3574 config/nds32/nds32.cc:3671
+#: config/nds32/nds32.cc:3686 config/nds32/nds32.cc:3692
+#: config/nds32/nds32.cc:3768 config/nds32/nds32.cc:3774
+#: config/nds32/nds32.cc:3806
+#, gcc-internal-format
+msgid "a nested function is not supported for reduced registers"
+msgstr ""
+
+#. The enum index value for array size is out of range.
+#: config/nds32/nds32.cc:3465
+#, gcc-internal-format
+msgid "intrinsic register index is out of range"
+msgstr ""
+
+#: config/nds32/nds32.cc:3481 config/nds32/nds32.cc:3488
+#: config/nds32/nds32.cc:3495 config/nds32/nds32.cc:3502
+#: config/nds32/nds32.cc:3509
+#, gcc-internal-format
+msgid "CCTL intrinsic function subtype out of range"
+msgstr ""
+
+#: config/nds32/nds32.cc:3946
+#, gcc-internal-format
+msgid "cannot use %<indirect_call%> attribute under linux toolchain"
+msgstr ""
+
+#: config/nds32/nds32.cc:3954
+#, gcc-internal-format
+msgid "%<indirect_call%> attribute cannot apply for static function"
+msgstr ""
+
+#: config/nds32/nds32.cc:4043
+#, gcc-internal-format
+msgid "invalid id value for interrupt/exception attribute"
+msgstr ""
+
+#: config/nds32/nds32.cc:4071
+#, gcc-internal-format
+msgid "invalid id value for reset attribute"
+msgstr ""
+
+#: config/nds32/nds32.cc:4087
+#, gcc-internal-format
+msgid "invalid nmi function for reset attribute"
+msgstr ""
+
+#: config/nds32/nds32.cc:4100
+#, gcc-internal-format
+msgid "invalid warm function for reset attribute"
+msgstr ""
+
+#: config/nds32/nds32.cc:4151
+#, gcc-internal-format
+msgid "not support %<-fpic%> option for v3m toolchain"
+msgstr ""
+
+#: config/nds32/nds32.cc:4184
+#, gcc-internal-format
+msgid "Disable FPU ISA, the ABI option must be enable %<-mfloat-abi=soft%>"
+msgstr ""
+
+#: config/nds32/nds32.cc:4187
+#, gcc-internal-format
+msgid "%<-mabi=2fp+%> option only support when FPU available, must be enable %<-mext-fpu-sp%> or %<-mext-fpu-dp%>"
+msgstr ""
+
+#: config/nios2/nios2.cc:574
+#, gcc-internal-format
+msgid "Unknown form for stack limit expression"
+msgstr ""
+
+#: config/nios2/nios2.cc:1183
+#, gcc-internal-format
+msgid "switch %<-mcustom-%s%> is required for double-precision floating-point"
+msgstr ""
+
+#: config/nios2/nios2.cc:1192
+#, gcc-internal-format
+msgid "conflicting use of %<-mcustom%> switches, target attributes, and/or %<__builtin_custom_%> functions"
+msgstr ""
+
+#: config/nios2/nios2.cc:1316
+#, gcc-internal-format
+msgid "ignoring unrecognized switch %<-mcustom-fpu-cfg%> value %<%s%>"
+msgstr ""
+
+#: config/nios2/nios2.cc:1335
+#, gcc-internal-format
+msgid "switch %<-mcustom-%s%> value %d must be between 0 and 255"
+msgstr ""
+
+#: config/nios2/nios2.cc:1358
+#, gcc-internal-format
+msgid "position-independent code requires the Linux ABI"
+msgstr ""
+
+#: config/nios2/nios2.cc:1361
+#, gcc-internal-format
+msgid "PIC support for %<-fstack-limit-symbol%>"
+msgstr ""
+
+#: config/nios2/nios2.cc:1383
+#, gcc-internal-format
+msgid "%<-mgpopt%> not supported with PIC"
+msgstr ""
+
+#: config/nios2/nios2.cc:1385
+#, gcc-internal-format
+msgid "%<-mgprel-sec=%> not supported with PIC"
+msgstr ""
+
+#: config/nios2/nios2.cc:1387
+#, gcc-internal-format
+msgid "%<-mr0rel-sec=%> not supported with PIC"
+msgstr ""
+
+#: config/nios2/nios2.cc:1395
+#, gcc-internal-format
+msgid "%<-mgprel-sec=%> argument is not a valid regular expression"
+msgstr ""
+
+#: config/nios2/nios2.cc:1401
+#, gcc-internal-format
+msgid "%<-mr0rel-sec=%> argument is not a valid regular expression"
+msgstr ""
+
+#: config/nios2/nios2.cc:1412
+#, gcc-internal-format
+msgid "BMX instructions are only supported with R2 architecture"
+msgstr ""
+
+#: config/nios2/nios2.cc:1414
+#, gcc-internal-format
+msgid "CDX instructions are only supported with R2 architecture"
+msgstr ""
+
+#: config/nios2/nios2.cc:1419
+#, gcc-internal-format
+msgid "R2 architecture is little-endian only"
+msgstr ""
+
+#: config/nios2/nios2.cc:3585
+#, gcc-internal-format
+msgid "cannot call %<__builtin_custom_%s%> without specifying switch %<-mcustom-%s%>"
+msgstr ""
+
+#: config/nios2/nios2.cc:3694
+#, gcc-internal-format
+msgid "custom instruction opcode must be a compile-time constant in the range 0-255 for %<__builtin_custom_%s%>"
+msgstr ""
+
+#: config/nios2/nios2.cc:3899
+#, gcc-internal-format, gfc-internal-format
+msgid "control register number must be in range 0-31 for %s"
+msgstr ""
+
+#: config/nios2/nios2.cc:3927
+#, gcc-internal-format, gfc-internal-format
+msgid "register number must be in range 0-31 for %s"
+msgstr ""
+
+#: config/nios2/nios2.cc:3934
+#, gcc-internal-format, gfc-internal-format
+msgid "immediate value must fit into a %d-bit integer for %s"
+msgstr ""
+
+#: config/nios2/nios2.cc:3984
+#, gcc-internal-format
+msgid "the ENI instruction operand must be either 0 or 1"
+msgstr ""
+
+#: config/nios2/nios2.cc:4012
+#, gcc-internal-format, gfc-internal-format
+msgid "built-in function %s requires Nios II R%d"
+msgstr ""
+
+#: config/nios2/nios2.cc:4092
+#, gcc-internal-format
+msgid "switch %<-mcustom-%s%> conflicts with switch %<-mcustom-%s%>"
+msgstr ""
+
+#: config/nios2/nios2.cc:4099 config/nios2/nios2.cc:4110
+#, gcc-internal-format
+msgid "call to %<__builtin_custom_%s%> conflicts with switch %<-mcustom-%s%>"
+msgstr ""
+
+#: config/nios2/nios2.cc:4253
+#, gcc-internal-format
+msgid "%<custom-fpu-cfg%> option does not support %<no-%>"
+msgstr ""
+
+#: config/nios2/nios2.cc:4258
+#, gcc-internal-format
+msgid "%<custom-fpu-cfg%> option requires configuration argument"
+msgstr ""
+
+#: config/nios2/nios2.cc:4286
+#, gcc-internal-format
+msgid "%<no-custom-%s%> does not accept arguments"
+msgstr ""
+
+#: config/nios2/nios2.cc:4301
+#, gcc-internal-format
+msgid "%<custom-%s=%> requires argument"
+msgstr ""
+
+#: config/nios2/nios2.cc:4311
+#, gcc-internal-format
+msgid "%<custom-%s=%> argument should be a non-negative integer"
+msgstr ""
+
+#: config/nios2/nios2.cc:4323
+#, gcc-internal-format
+msgid "%<custom-%s=%> is not recognized as FPU instruction"
+msgstr ""
+
+#: config/nios2/nios2.cc:4330
+#, gcc-internal-format
+msgid "invalid custom instruction option %qs"
+msgstr ""
+
+#: config/nvptx/mkoffload.cc:93
+#, gcc-internal-format
+msgid "deleting file %s: %m"
+msgstr ""
+
+#: config/nvptx/mkoffload.cc:118
+#, gcc-internal-format
+msgid "malformed ptx file"
+msgstr ""
+
+#: config/nvptx/mkoffload.cc:335
+#, gcc-internal-format
+msgid "%<omp requires reverse_offload%> requires at least %<sm_35%> for %<-foffload-options=nvptx-none=-march=%> - disabling offload-code generation for this device type"
+msgstr ""
+
+#: config/nvptx/mkoffload.cc:419 config/nvptx/mkoffload.cc:491
+#, gcc-internal-format
+msgid "Cannot find function declaration for %qs"
+msgstr ""
+
+#: config/nvptx/mkoffload.cc:591
+#, gcc-internal-format
+msgid "environment variable COLLECT_GCC_OPTIONS must be set"
+msgstr ""
+
+#: config/nvptx/mkoffload.cc:650
+#, gcc-internal-format
+msgid "COLLECT_GCC must be set."
+msgstr ""
+
+#: config/nvptx/mkoffload.cc:698
+#, gcc-internal-format
+msgid "offload compiler %s not found (consider using %<-B%>)"
+msgstr ""
+
+#: config/nvptx/mkoffload.cc:721
+#, gcc-internal-format
+msgid "unrecognizable argument of option "
+msgstr ""
+
+#: config/nvptx/mkoffload.cc:797
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot open '%s'"
+msgstr ""
+
+#: config/nvptx/mkoffload.cc:853
+#, gcc-internal-format
+msgid "cannot open intermediate ptx file"
+msgstr ""
+
+#: config/nvptx/nvptx.cc:206
+#, gcc-internal-format
+msgid "option %s is not supported together with %<-fopenacc%>"
+msgstr ""
+
+#: config/nvptx/nvptx.cc:325
+#, gcc-internal-format
+msgid "PTX version (%<-mptx%>) needs to be at least %s to support selected %<-misa%> (sm_%s)"
+msgstr ""
+
+#: config/nvptx/nvptx.cc:340
+#, gcc-internal-format
+msgid "%<-march=%> must be specified"
+msgstr ""
+
+#: config/nvptx/nvptx.cc:363
+#, gcc-internal-format
+msgid "not generating patch area, nops not supported"
+msgstr ""
+
+#: config/nvptx/nvptx.cc:462
+#, gcc-internal-format
+msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
+msgstr ""
+
+#: config/nvptx/nvptx.cc:2340
+#, gcc-internal-format
+msgid "cannot emit unaligned pointers in ptx assembly"
+msgstr ""
+
+#: config/nvptx/nvptx.cc:2565
+#, gcc-internal-format
+msgid "PTX does not support weak declarations (only weak definitions)"
+msgstr ""
+
+#: config/nvptx/nvptx.cc:5806
+#, gcc-internal-format
+msgid "%qE attribute requires a void return type"
+msgstr ""
+
+#: config/nvptx/nvptx.cc:5829
+#, gcc-internal-format
+msgid "%qE attribute not allowed with auto storage class"
+msgstr ""
+
+#: config/nvptx/nvptx.cc:6227
+#, gcc-internal-format
+msgid "barrier value must be within [0,15]"
+msgstr ""
+
+#: config/nvptx/nvptx.cc:6240
+#, gcc-internal-format
+msgid "complement argument must be constant"
+msgstr ""
+
+#: config/nvptx/nvptx.cc:6580
+#, gcc-internal-format
+msgid "using %<vector_length (%d)%> due to call to vector-partitionable routine, ignoring %d"
+msgstr ""
+
+#: config/nvptx/nvptx.cc:6588
+#, gcc-internal-format
+msgid "using %<vector_length (%d)%>, ignoring runtime setting"
+msgstr ""
+
+#: config/nvptx/nvptx.cc:6602
+#, gcc-internal-format
+msgid "using %<vector_length (%d)%>, ignoring %d"
+msgstr ""
+
+#: config/nvptx/nvptx.cc:7488
+#, gcc-internal-format
+msgid "variable %qD adjusted for OpenACC privatization level: %qs"
+msgstr ""
+
+#: config/nvptx/nvptx.cc:7602
+#, gcc-internal-format
+msgid "weak alias definitions not supported in this configuration"
+msgstr ""
+
+#: config/nvptx/nvptx.cc:7615
+#, gcc-internal-format
+msgid "non-function alias definitions not supported in this configuration"
+msgstr ""
+
+#: config/or1k/or1k.cc:1314
+#, gcc-internal-format, gfc-internal-format
+msgid "unexpected operand: %d"
+msgstr ""
+
+#: config/pa/pa.cc:537
+#, gcc-internal-format
+msgid "PIC code generation is not supported in the portable runtime model"
+msgstr ""
+
+#: config/pa/pa.cc:542
+#, gcc-internal-format
+msgid "PIC code generation is not compatible with fast indirect calls"
+msgstr ""
+
+#: config/pa/pa.cc:547
+#, gcc-internal-format
+msgid "%<-g%> is only supported when using GAS on this processor"
+msgstr ""
+
+#: config/pa/pa.cc:548
+#, gcc-internal-format
+msgid "%<-g%> option disabled"
+msgstr ""
+
+#: config/pru/pru-passes.cc:111
+#, gcc-internal-format
+msgid "large return values not supported with %<-mabi=ti%> option"
+msgstr ""
+
+#: config/pru/pru-passes.cc:119 config/pru/pru-passes.cc:163
+#: config/pru/pru-passes.cc:176
+#, gcc-internal-format
+msgid "function pointers not supported with %<-mabi=ti%> option"
+msgstr ""
+
+#: config/pru/pru-pragma.cc:59
+#, gcc-internal-format
+msgid "junk at end of %<#pragma CTABLE_ENTRY%>"
+msgstr ""
+
+#: config/pru/pru-pragma.cc:61
+msgid "%<CTABLE_ENTRY%> index %"
+msgstr ""
+
+#: config/pru/pru-pragma.cc:64
+msgid "redefinition of %<CTABLE_ENTRY %"
+msgstr ""
+
+#: config/pru/pru-pragma.cc:69
+#, gcc-internal-format
+msgid "%<CTABLE_ENTRY%> base address is not a multiple of 256"
+msgstr ""
+
+#: config/pru/pru-pragma.cc:77
+#, gcc-internal-format
+msgid "malformed %<#pragma CTABLE_ENTRY%> variable address"
+msgstr ""
+
+#: config/pru/pru.cc:2168
+#, gcc-internal-format
+msgid "aggregate types are prohibited in %<__regio_symbol%> address space"
+msgstr ""
+
+#: config/pru/pru.cc:2175
+#, gcc-internal-format
+msgid "variables in %<__regio_symbol%> address space cannot have initial value"
+msgstr ""
+
+#: config/pru/pru.cc:2178
+#, gcc-internal-format
+msgid "variables in %<__regio_symbol%> address space cannot be declared %<register%>"
+msgstr ""
+
+#: config/pru/pru.cc:2181
+#, gcc-internal-format
+msgid "variables in %<__regio_symbol%> address space must be declared %<volatile%>"
+msgstr ""
+
+#: config/pru/pru.cc:2184
+#, gcc-internal-format
+msgid "variables in %<__regio_symbol%> address space must be declared %<extern%>"
+msgstr ""
+
+#: config/pru/pru.cc:2187
+#, gcc-internal-format
+msgid "only 32-bit access is supported for %<__regio_symbol%> address space"
+msgstr ""
+
+#: config/pru/pru.cc:2190
+#, gcc-internal-format
+msgid "register name %<%s%> not recognized in %<__regio_symbol%> address space"
+msgstr ""
+
+#: config/pru/pru.cc:2215
+#, gcc-internal-format
+msgid "pointers to %<__regio_symbol%> address space are prohibited"
+msgstr ""
+
+#: config/riscv/riscv-c.cc:261
+#, gcc-internal-format
+msgid "%<#pragma riscv intrinsic%> requires a string parameter"
+msgstr ""
+
+#: config/riscv/riscv-c.cc:286
+#, gcc-internal-format
+msgid "unknown %<#pragma riscv intrinsic%> option %qs"
+msgstr ""
+
+#: config/riscv/riscv-target-attr.cc:121
+#, gcc-internal-format
+msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
+msgstr ""
+
+#: config/riscv/riscv-target-attr.cc:132
+#, gcc-internal-format
+msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
+msgstr ""
+
+#: config/riscv/riscv-target-attr.cc:159
+#, gcc-internal-format
+msgid "%<target()%> attribute: arch appears more than once"
+msgstr ""
+
+#: config/riscv/riscv-target-attr.cc:170
+#, gcc-internal-format
+msgid "%<target()%> attribute: cpu appears more than once"
+msgstr ""
+
+#: config/riscv/riscv-target-attr.cc:177
+#, gcc-internal-format
+msgid "%<target()%> attribute: unknown CPU %qs"
+msgstr ""
+
+#: config/riscv/riscv-target-attr.cc:198
+#, gcc-internal-format
+msgid "%<target()%> attribute: tune appears more than once"
+msgstr ""
+
+#: config/riscv/riscv-target-attr.cc:204
+#, gcc-internal-format
+msgid "%<target()%> attribute: unknown TUNE %qs"
+msgstr ""
+
+#: config/riscv/riscv-target-attr.cc:253
+#, gcc-internal-format
+msgid "malformed %<target()%> attribute"
+msgstr ""
+
+#: config/riscv/riscv-target-attr.cc:267
+#, gcc-internal-format
+msgid "attribute %<target(\"%s\")%> does not accept an argument"
+msgstr ""
+
+#: config/riscv/riscv-target-attr.cc:285
+#, gcc-internal-format
+msgid "Got unknown attribute %<target(\"%s\")%>"
+msgstr ""
+
+#: config/riscv/riscv-target-attr.cc:368
+#, gcc-internal-format
+msgid "malformed %<target(\"%s\")%> attribute"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4276
+#, gcc-internal-format
+msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd] or %wd"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4488
+#, gcc-internal-format
+msgid "RVV type %qT does not have a fixed size"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4494
+#, gcc-internal-format
+msgid "RVV type %qT does not have a defined alignment"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4509
+#, gcc-internal-format
+msgid "arithmetic on pointer to RVV type %qT"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4517
+#, gcc-internal-format
+msgid "member variables cannot have RVV type %qT"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4519
+#, gcc-internal-format
+msgid "fields cannot have RVV type %qT"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4525
+#, gcc-internal-format
+msgid "array elements cannot have RVV type %qT"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4531
+#, gcc-internal-format
+msgid "cannot allocate objects with RVV type %qT"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4537
+#, gcc-internal-format
+msgid "cannot delete objects with RVV type %qT"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4543
+#, gcc-internal-format
+msgid "cannot throw or catch RVV type %qT"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4549
+#, gcc-internal-format
+msgid "capture by copy of RVV type %qT"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4645
+#, gcc-internal-format
+msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4655
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4665
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4674
+#, gcc-internal-format
+msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4694
+#, gcc-internal-format
+msgid "built-in function %qE requires the %qs ISA extension"
+msgstr ""
+
+#: config/riscv/riscv-vector-builtins.cc:4747
+#, gcc-internal-format
+msgid "no matching function call to %qE with empty arguments"
+msgstr ""
+
+#: config/riscv/riscv.cc:723
+#, gcc-internal-format
+msgid "unknown cpu %qs for %<-mtune%>"
+msgstr ""
+
+#: config/riscv/riscv.cc:2548
+#, gcc-internal-format
+msgid "this operation requires the RVV ISA extension"
+msgstr ""
+
+#: config/riscv/riscv.cc:2549
+#, gcc-internal-format
+msgid "you can enable RVV using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
+msgstr ""
+
+#: config/riscv/riscv.cc:4981 config/riscv/riscv.cc:5023
+#, gcc-internal-format
+msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
+msgstr ""
+
+#: config/riscv/riscv.cc:5370
+#, gcc-internal-format
+msgid "RVV type %qT cannot be passed to an unprototyped function"
+msgstr ""
+
+#: config/riscv/riscv.cc:5623
+#, gcc-internal-format
+msgid "%s %qT requires the V ISA extension"
+msgstr ""
+
+#: config/riscv/riscv.cc:5635
+#, gcc-internal-format
+msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv.cc:5646
+#, gcc-internal-format
+msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
+msgstr ""
+
+#: config/riscv/riscv.cc:5655
+#, gcc-internal-format
+msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv.cc:5664
+#, gcc-internal-format
+msgid "%s %qT requires the zve64d or v ISA extension"
+msgstr ""
+
+#: config/riscv/riscv.cc:5674
+#, gcc-internal-format
+msgid "%s %qT requires the minimal vector length %qd but %qd is given"
+msgstr ""
+
+#: config/riscv/riscv.cc:5729
+#, gcc-internal-format
+msgid "function attribute %qs requires the V ISA extension"
+msgstr ""
+
+#: config/riscv/riscv.cc:5823
+#, gcc-internal-format
+msgid "argument to %qE attribute is not %<\"user\"%>, %<\"supervisor\"%>, or %<\"machine\"%>"
+msgstr ""
+
+#: config/riscv/riscv.cc:5846
+#, gcc-internal-format
+msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
+msgstr ""
+
+#: config/riscv/riscv.cc:5855
+#, gcc-internal-format
+msgid "%qs applied to non-RVV type %qT"
+msgstr ""
+
+#: config/riscv/riscv.cc:5863
+#, gcc-internal-format
+msgid "%qs requires an integer constant"
+msgstr ""
+
+#: config/riscv/riscv.cc:5873
+#, gcc-internal-format
+msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
+msgstr ""
+
+#: config/riscv/riscv.cc:9213
+#, gcc-internal-format
+msgid "%<-mdiv%> requires %<-march%> to subsume the %<M%> extension"
+msgstr ""
+
+#: config/riscv/riscv.cc:9255
+#, gcc-internal-format
+msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
+msgstr ""
+
+#: config/riscv/riscv.cc:9261
+#, gcc-internal-format
+msgid "Current RISC-V GCC does not support RVV in big-endian mode"
+msgstr ""
+
+#: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
+#, gcc-internal-format
+msgid "code model %qs with %qs"
+msgstr ""
+
+#: config/riscv/riscv.cc:9319
+#, gcc-internal-format
+msgid "requested ABI requires %<-march%> to subsume the %qc extension"
+msgstr ""
+
+#: config/riscv/riscv.cc:9326
+#, gcc-internal-format
+msgid "rv32e requires ilp32e ABI"
+msgstr ""
+
+#: config/riscv/riscv.cc:9328
+#, gcc-internal-format
+msgid "rv64e requires lp64e ABI"
+msgstr ""
+
+#: config/riscv/riscv.cc:9335
+#, gcc-internal-format
+msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
+msgstr ""
+
+#: config/riscv/riscv.cc:9339
+#, gcc-internal-format
+msgid "ABI requires %<-march=rv%d%>"
+msgstr ""
+
+#: config/riscv/riscv.cc:9349
+#, gcc-internal-format
+msgid "%<-mpreferred-stack-boundary=%d%> must be between %d and %d"
+msgstr ""
+
+#: config/riscv/riscv.cc:9362
+#, gcc-internal-format
+msgid "%<-mriscv-attribute%> RISC-V ELF attribute requires GNU as 2.32 [%<-mriscv-attribute%>]"
+msgstr ""
+
+#: config/riscv/riscv.cc:9389 config/rs6000/rs6000.cc:4509
+#, gcc-internal-format
+msgid "%qs is not a valid base register in %qs"
+msgstr ""
+
+#: config/riscv/riscv.cc:9403 config/rs6000/rs6000.cc:4492
+#, gcc-internal-format
+msgid "%qs is not a valid number in %qs"
+msgstr ""
+
+#: config/riscv/riscv.cc:9801
+#, gcc-internal-format
+msgid "%qs function cannot have different interrupt type"
+msgstr ""
+
+#: config/riscv/riscv.cc:10327
+#, gcc-internal-format
+msgid "cannot allocate vl register for %qs on this target"
+msgstr ""
+
+#. Address spaces are currently only supported by C.
+#: config/rl78/rl78.cc:375
+#, gcc-internal-format
+msgid "%<-mes0%> can only be used with C"
+msgstr ""
+
+#: config/rl78/rl78.cc:378
+#, gcc-internal-format
+msgid "mduc registers only saved for G13 target"
+msgstr ""
+
+#: config/rl78/rl78.cc:393
+#, gcc-internal-format
+msgid "%<-mmul=g13%> cannot be used with %<-mcpu=g10%>"
+msgstr ""
+
+#: config/rl78/rl78.cc:395
+#, gcc-internal-format
+msgid "%<-mmul=g14%> cannot be used with %<-mcpu=g10%>"
+msgstr ""
+
+#. The S2 core does not have mul/div instructions.
+#: config/rl78/rl78.cc:407
+#, gcc-internal-format
+msgid "%<-mmul=g14%> cannot be used with %<-mcpu=g13%>"
+msgstr ""
+
+#. The G14 core does not have the hardware multiply peripheral used by the
+#. G13 core, hence you cannot use G13 multipliy routines on G14 hardware.
+#: config/rl78/rl78.cc:420
+#, gcc-internal-format
+msgid "%<-mmul=g13%> cannot be used with %<-mcpu=g14%>"
+msgstr ""
+
+#: config/rl78/rl78.cc:843
+#, gcc-internal-format
+msgid "naked attribute only applies to functions"
+msgstr ""
+
+#: config/rl78/rl78.cc:867
+#, gcc-internal-format
+msgid "%qE attribute doesn%'t apply to functions"
+msgstr ""
+
+#. This is unpredictable, as we're truncating off usable address
+#. bits.
+#: config/rl78/rl78.cc:1233
+#, gcc-internal-format
+msgid "converting far pointer to near pointer"
+msgstr ""
+
+#: config/rs6000/driver-rs6000.cc:266
+#, gcc-internal-format
+msgid "unsupported cpu name returned from kernel for %<-mcpu=native%>: %s"
+msgstr ""
+
+#: config/rs6000/driver-rs6000.cc:268
+#, gcc-internal-format, gfc-internal-format
+msgid "please use an explicit cpu name; valid cpu names are: %s"
+msgstr ""
+
+#: config/rs6000/host-darwin.cc:61
+#, gcc-internal-format
+msgid "segmentation fault (code)"
+msgstr ""
+
+#: config/rs6000/host-darwin.cc:131
+#, gcc-internal-format
+msgid "segmentation fault"
+msgstr ""
+
+#: config/rs6000/host-darwin.cc:145
+#, gcc-internal-format
+msgid "While setting up signal stack: %m"
+msgstr ""
+
+#: config/rs6000/host-darwin.cc:151
+#, gcc-internal-format
+msgid "While setting up signal handler: %m"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:77 config/rs6000/rs6000-builtin.cc:80
+#: config/rs6000/rs6000-builtin.cc:87 config/rs6000/rs6000-builtin.cc:90
+#: config/rs6000/rs6000-builtin.cc:93 config/rs6000/rs6000-builtin.cc:96
+#: config/rs6000/rs6000-builtin.cc:103 config/rs6000/rs6000-builtin.cc:110
+#: config/rs6000/rs6000-builtin.cc:124 config/rs6000/rs6000-builtin.cc:127
+#: config/rs6000/rs6000-builtin.cc:130 config/rs6000/rs6000-builtin.cc:133
+#: config/rs6000/rs6000-builtin.cc:140
+#, gcc-internal-format
+msgid "%qs requires the %qs option"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:83 config/rs6000/rs6000-builtin.cc:99
+#: config/rs6000/rs6000-builtin.cc:113 config/rs6000/rs6000-builtin.cc:136
+#, gcc-internal-format
+msgid "%qs requires the %qs option and either the %qs or %qs option"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:106 config/rs6000/rs6000-builtin.cc:117
+#, gcc-internal-format
+msgid "%qs requires the %qs and %qs options"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:121
+#, gcc-internal-format
+msgid "%qs requires quad-precision floating-point arithmetic"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:2264
+#, gcc-internal-format
+msgid "argument 1 of %qs must be a constant"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:2322
+#, gcc-internal-format
+msgid "argument 1 of %qs is out of range"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:2594
+#, gcc-internal-format
+msgid "builtin %qs only accepts a string argument"
+msgstr ""
+
+#. Invalid CPU argument.
+#: config/rs6000/rs6000-builtin.cc:2613
+#, gcc-internal-format
+msgid "cpu %qs is an invalid argument to builtin %qs"
+msgstr ""
+
+#. Invalid HWCAP argument.
+#: config/rs6000/rs6000-builtin.cc:2641
+#, gcc-internal-format
+msgid "%s %qs is an invalid argument to builtin %qs"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:2670
+#, gcc-internal-format
+msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:3017 config/rs6000/rs6000-builtin.cc:3171
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %d must be an unsigned literal"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:3019 config/rs6000/rs6000-builtin.cc:3173
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %d is an unsigned literal that is out of range"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:3124
+#, gcc-internal-format
+msgid "builtin %qs is only valid in 64-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:3287
+#, gcc-internal-format
+msgid "unresolved overload for builtin %qF"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:3390
+#, gcc-internal-format
+msgid "%qs not supported with %<-msoft-float%>"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:3397
+#, gcc-internal-format
+msgid "%qs is not supported in 32-bit mode"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:3403
+#, gcc-internal-format
+msgid "%qs requires %<long double%> to be IBM 128-bit format"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:3410
+#, gcc-internal-format
+msgid "%qs requires %<__ibm128%> type support"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:3565
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %d must be a literal between 0 and %d, inclusive"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:3581
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %d must be a literal between %d and %d, inclusive"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:3598
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %d must be a variable or a literal between %d and %d, inclusive"
+msgstr ""
+
+#: config/rs6000/rs6000-builtin.cc:3614
+#, gcc-internal-format, gfc-internal-format
+msgid "argument %d must be either a literal %d or a literal %d"
+msgstr ""
+
+#: config/rs6000/rs6000-c.cc:55
+#, gcc-internal-format
+msgid "ignoring malformed %<#pragma longcall%>"
+msgstr ""
+
+#: config/rs6000/rs6000-c.cc:67
+#, gcc-internal-format
+msgid "missing open paren"
+msgstr ""
+
+#: config/rs6000/rs6000-c.cc:69
+#, gcc-internal-format
+msgid "missing number"
+msgstr ""
+
+#: config/rs6000/rs6000-c.cc:71
+#, gcc-internal-format
+msgid "missing close paren"
+msgstr ""
+
+#: config/rs6000/rs6000-c.cc:74
+#, gcc-internal-format
+msgid "number must be 0 or 1"
+msgstr ""
+
+#: config/rs6000/rs6000-c.cc:77
+#, gcc-internal-format
+msgid "junk at end of %<#pragma longcall%>"
+msgstr ""
+
+#: config/rs6000/rs6000-c.cc:1237 config/rs6000/rs6000-c.cc:1638
+#, gcc-internal-format
+msgid "builtin %qs only accepts 1 argument"
+msgstr ""
+
+#: config/rs6000/rs6000-c.cc:1244 config/rs6000/rs6000-c.cc:1330
+#, gcc-internal-format
+msgid "builtin %qs only accepts 2 arguments"
+msgstr ""
+
+#: config/rs6000/rs6000-c.cc:1508
+#, gcc-internal-format
+msgid "builtin %qs only accepts 3 arguments"
+msgstr ""
+
+#: config/rs6000/rs6000-c.cc:1737
+#, gcc-internal-format
+msgid "%<vec_lvsl%> is deprecated for little endian; use assignment for unaligned loads and stores"
+msgstr ""
+
+#: config/rs6000/rs6000-c.cc:1741
+#, gcc-internal-format
+msgid "%<vec_lvsr%> is deprecated for little endian; use assignment for unaligned loads and stores"
+msgstr ""
+
+#: config/rs6000/rs6000-c.cc:1827
+#, gcc-internal-format
+msgid "passing argument %d of %qE discards %qs qualifier from pointer target type"
+msgstr ""
+
+#: config/rs6000/rs6000-c.cc:1883 config/rs6000/rs6000-c.cc:2067
+#, gcc-internal-format
+msgid "invalid parameter combination for AltiVec intrinsic %qs"
+msgstr ""
+
+#: config/rs6000/rs6000-c.cc:2056
+#, gcc-internal-format
+msgid "overloaded builtin %qs is implemented by builtin %qs"
+msgstr ""
+
+#: config/rs6000/rs6000-c.cc:2060
+#, gcc-internal-format
+msgid "%qs is not supported in this compiler configuration"
+msgstr ""
+
+#: config/rs6000/rs6000-call.cc:379
+#, gcc-internal-format
+msgid "ELFv2 parameter passing for an argument containing zero-width bit fields but that is otherwise a homogeneous aggregate was corrected in GCC 12"
+msgstr ""
+
+#: config/rs6000/rs6000-call.cc:447
+#, gcc-internal-format
+msgid "invalid use of MMA type %qs as a function return value"
+msgstr ""
+
+#: config/rs6000/rs6000-call.cc:499
+#, gcc-internal-format
+msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
+msgstr ""
+
+#: config/rs6000/rs6000-call.cc:683
+#, gcc-internal-format
+msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
+msgstr ""
+
+#: config/rs6000/rs6000-call.cc:1113
+#, gcc-internal-format
+msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
+msgstr ""
+
+#: config/rs6000/rs6000-call.cc:1639
+#, gcc-internal-format
+msgid "invalid use of MMA operand of type %qs as a function parameter"
+msgstr ""
+
+#: config/rs6000/rs6000-call.cc:2028
+#, gcc-internal-format
+msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
+msgstr ""
+
+#: config/rs6000/rs6000-logue.cc:1705
+#, gcc-internal-format
+msgid "stack frame too large"
+msgstr ""
+
+#: config/rs6000/rs6000-logue.cc:4021
+#, gcc-internal-format, gfc-internal-format
+msgid "unsupported number of nops before function entry (%u)"
+msgstr ""
+
+#: config/rs6000/rs6000-logue.cc:5565
+#, gcc-internal-format
+msgid "%qs uses register r29"
+msgstr ""
+
+#: config/rs6000/rs6000-logue.cc:5573
+#, gcc-internal-format
+msgid "Stack frame larger than 2G is not supported for %<-fsplit-stack%>"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:3228 config/rs6000/rs6000.cc:3231
+#: config/rs6000/rs6000.cc:3234
+#, gcc-internal-format
+msgid "%qs requires %qs or %qs"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:3335
+#, gcc-internal-format
+msgid "%qs requires PowerPC64 architecture, enabling"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:3451
+#, gcc-internal-format
+msgid "%<-mcall-aixdesc%> incompatible with %<-mabi=elfv2%>"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:3500
+#, gcc-internal-format
+msgid "%qs unsupported for this ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:3628
+#, gcc-internal-format
+msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:3789
+#, gcc-internal-format
+msgid "AltiVec not supported in this target"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:3806
+#, gcc-internal-format
+msgid "%qs is not supported on little endian systems"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:3886
+#, gcc-internal-format
+msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
+msgstr ""
+
+#. Enforce that none of the ISA_3_0_MASKS_SERVER flags
+#. were explicitly cleared.
+#: config/rs6000/rs6000.cc:3894
+#, gcc-internal-format
+msgid "%qs incompatible with explicitly disabled options"
+msgstr ""
+
+#. TARGET_VSX = 1 implies Power 7 and newer
+#: config/rs6000/rs6000.cc:3928 config/rs6000/rs6000.cc:3936
+#: config/rs6000/rs6000.cc:3949 config/rs6000/rs6000.cc:4011
+#: config/rs6000/rs6000.cc:4044 config/rs6000/rs6000.cc:4059
+#: config/rs6000/rs6000.cc:4067 config/rs6000/rs6000.cc:4191
+#: config/rs6000/rs6000.cc:4204 config/rs6000/rs6000.cc:4213
+#: config/rs6000/rs6000.cc:4351 config/rs6000/rs6000.cc:4364
+#: config/rs6000/rs6000.cc:4385
+#, gcc-internal-format
+msgid "%qs requires %qs"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4095
+#, gcc-internal-format
+msgid "target attribute or pragma changes %<long double%> size"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4116
+#, gcc-internal-format
+msgid "%qs requires full ISA 2.06 support"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4129
+#, gcc-internal-format
+msgid "Using IEEE extended precision %<long double%>"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4132
+#, gcc-internal-format
+msgid "Using IBM extended precision %<long double%>"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4151
+#, gcc-internal-format
+msgid "%qs requires VSX support"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4160
+#, gcc-internal-format
+msgid "The %<-mfloat128%> option may not be fully supported"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4183
+#, gcc-internal-format
+msgid "%qs requires full ISA 3.0 support"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4270
+#, gcc-internal-format
+msgid "unknown vectorization library ABI type in %<-mveclibabi=%s%>"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4283 config/rs6000/rs6000.cc:4298
+#, gcc-internal-format
+msgid "target attribute or pragma changes AltiVec ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4311
+#, gcc-internal-format
+msgid "target attribute or pragma changes darwin64 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4517
+#, gcc-internal-format
+msgid "%qs needs a valid base register"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4814
+#, gcc-internal-format
+msgid "unknown option for %<%s=%s%>"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4833
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4837
+#, gcc-internal-format
+msgid "%<-mrop-protect%> requires the ELFv2 ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:4855
+#, gcc-internal-format
+msgid "%qs is deprecated and not recommended in any circumstances"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:11184
+#, gcc-internal-format
+msgid "%qs is an opaque type, and you cannot set it to other values"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:18029
+#, gcc-internal-format
+msgid "no profiling of 64-bit code for this ABI"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:20425
+#, gcc-internal-format
+msgid "you cannot take the address of a nested function if you use the %qs option"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:20507
+#, gcc-internal-format
+msgid "use of %<long double%> in AltiVec types is invalid"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:20509
+#, gcc-internal-format
+msgid "use of boolean types in AltiVec types is invalid"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:20511
+#, gcc-internal-format
+msgid "use of %<complex%> in AltiVec types is invalid"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:20513
+#, gcc-internal-format
+msgid "use of decimal floating-point types in AltiVec types is invalid"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:20519
+#, gcc-internal-format
+msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:20522
+#, gcc-internal-format
+msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:20527
+#, gcc-internal-format
+msgid "use of %<long long%> in AltiVec types is invalid without %qs"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:20530
+#, gcc-internal-format
+msgid "use of %<double%> in AltiVec types is invalid without %qs"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:24671
+#, gcc-internal-format
+msgid "invalid cpu %qs for %s%qs%s"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:24674
+#, gcc-internal-format
+msgid "%s%qs%s is not allowed"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:24676
+#, gcc-internal-format
+msgid "%s%qs%s is invalid"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:25197
+#, gcc-internal-format
+msgid "%<-mno-%s%> turns off %<-m%s%>"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:25356
+#, gcc-internal-format
+msgid "%<target_clones%> attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:25645
+#, gcc-internal-format
+msgid "Virtual function multiversioning not supported"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:28783
+#, gcc-internal-format
+msgid "the result for the xxspltidp instruction is undefined for subnormal input values"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:29261
+#, gcc-internal-format
+msgid "type %<__vector_quad%> requires the %qs option"
+msgstr ""
+
+#: config/rs6000/rs6000.cc:29266
+#, gcc-internal-format
+msgid "type %<__vector_pair%> requires the %qs option"
+msgstr ""
+
+#: config/rx/rx.cc:652
+#, gcc-internal-format
+msgid "unrecognized control register number: %d - using %<psw%>"
+msgstr ""
+
+#: config/rx/rx.cc:1385
+#, gcc-internal-format
+msgid "multiple fast interrupt routines seen: %qE and %qE"
+msgstr ""
+
+#: config/rx/rx.cc:2481
+#, gcc-internal-format
+msgid "invalid control register %d for mvtc; using %<psw%>"
+msgstr ""
+
+#: config/rx/rx.cc:2603
+#, gcc-internal-format
+msgid "%<__builtin_rx_%s%> takes %<C%>, %<Z%>, %<S%>, %<O%>, %<I%>, or %<U%>"
+msgstr ""
+
+#: config/rx/rx.cc:2606
+#, gcc-internal-format
+msgid "use %<__builtin_rx_mvtc (0, ... )%> to write arbitrary values to PSW"
+msgstr ""
+
+#: config/rx/rx.cc:2653
+#, gcc-internal-format
+msgid "%<-mno-allow-string-insns%> forbids the generation of the RMPA instruction"
+msgstr ""
+
+#: config/rx/rx.cc:2800
+#, gcc-internal-format
+msgid "RX FPU instructions do not support NaNs and infinities"
+msgstr ""
+
+#: config/s390/s390-c.cc:488
+#, gcc-internal-format
+msgid "builtin %qs can only be used on vector types"
+msgstr ""
+
+#: config/s390/s390-c.cc:720 config/s390/s390.cc:1000
+#, gcc-internal-format
+msgid "constant value required for builtin %qF argument %d"
+msgstr ""
+
+#: config/s390/s390-c.cc:735
+#, gcc-internal-format
+msgid "valid values for builtin %qF argument %d are 64, 128, 256, 512, 1024, 2048, and 4096"
+msgstr ""
+
+#: config/s390/s390-c.cc:915
+#, gcc-internal-format
+msgid "builtin %qF is for GCC internal use only"
+msgstr ""
+
+#: config/s390/s390-c.cc:923
+#, gcc-internal-format
+msgid "builtin %qF is deprecated"
+msgstr ""
+
+#: config/s390/s390-c.cc:927
+#, gcc-internal-format
+msgid "%qF requires %<-mvx%>"
+msgstr ""
+
+#: config/s390/s390-c.cc:933
+#, gcc-internal-format
+msgid "%qF requires z14 or higher"
+msgstr ""
+
+#: config/s390/s390-c.cc:939
+#, gcc-internal-format
+msgid "%qF requires z15 or higher"
+msgstr ""
+
+#: config/s390/s390-c.cc:953
+#, gcc-internal-format
+msgid "mismatch in number of arguments for builtin %qF. Expected: %d got %d"
+msgstr ""
+
+#: config/s390/s390-c.cc:1002
+#, gcc-internal-format
+msgid "invalid parameter combination for intrinsic %qs"
+msgstr ""
+
+#: config/s390/s390-c.cc:1008
+#, gcc-internal-format
+msgid "ambiguous overload for intrinsic %qs"
+msgstr ""
+
+#: config/s390/s390-c.cc:1016
+#, gcc-internal-format
+msgid "%qs matching variant requires z14 or higher"
+msgstr ""
+
+#: config/s390/s390-c.cc:1025
+#, gcc-internal-format
+msgid "%qs matching variant requires z15 or higher"
+msgstr ""
+
+#: config/s390/s390-c.cc:1031
+#, gcc-internal-format
+msgid "%qs matching variant is deprecated"
+msgstr ""
+
+#: config/s390/s390-c.cc:1071
+#, gcc-internal-format
+msgid "constant argument %d for builtin %qF is out of range for target type"
+msgstr ""
+
+#: config/s390/s390.cc:849
+#, gcc-internal-format
+msgid "constant argument %d for builtin %qF is invalid (%s)"
+msgstr ""
+
+#: config/s390/s390.cc:853
+#, gcc-internal-format
+msgid "constant argument %d for builtin %qF is out of range (0-%wu)"
+msgstr ""
+
+#: config/s390/s390.cc:869
+#, gcc-internal-format
+msgid "constant argument %d for builtin %qF is out of range (%wd-%wd)"
+msgstr ""
+
+#: config/s390/s390.cc:918
+#, gcc-internal-format
+msgid "builtin %qF is not supported without %<-mhtm%> (default with %<-march=zEC12%> and higher)"
+msgstr ""
+
+#: config/s390/s390.cc:924
+#, gcc-internal-format
+msgid "builtin %qF requires %<-mvx%> (default with %<-march=z13%> and higher)"
+msgstr ""
+
+#: config/s390/s390.cc:931
+#, gcc-internal-format
+msgid "Builtin %qF requires z14 or higher"
+msgstr ""
+
+#: config/s390/s390.cc:937
+#, gcc-internal-format
+msgid "Builtin %qF requires z15 or higher"
+msgstr ""
+
+#: config/s390/s390.cc:956
+#, gcc-internal-format
+msgid "unresolved overloaded builtin"
+msgstr ""
+
+#: config/s390/s390.cc:963
+#, gcc-internal-format
+msgid "bad builtin icode"
+msgstr ""
+
+#: config/s390/s390.cc:1097
+#, gcc-internal-format
+msgid "invalid argument %d for builtin %qF"
+msgstr ""
+
+#: config/s390/s390.cc:1198
+#, gcc-internal-format
+msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
+msgstr ""
+
+#: config/s390/s390.cc:1288
+#, gcc-internal-format
+msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
+msgstr ""
+
+#: config/s390/s390.cc:10594
+#, gcc-internal-format
+msgid "total size of local variables exceeds architecture limit"
+msgstr ""
+
+#: config/s390/s390.cc:12001
+#, gcc-internal-format
+msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes; an unconditional trap is added"
+msgstr ""
+
+#: config/s390/s390.cc:12017
+#, gcc-internal-format
+msgid "frame size of function %qs is %wd bytes which is more than half the stack size; the dynamic check would not be reliable; no check emitted for this function"
+msgstr ""
+
+#: config/s390/s390.cc:12045
+#, gcc-internal-format
+msgid "frame size of %qs is %wd bytes"
+msgstr ""
+
+#: config/s390/s390.cc:12049
+#, gcc-internal-format
+msgid "%qs uses dynamic stack allocation"
+msgstr ""
+
+#: config/s390/s390.cc:12796
+#, gcc-internal-format
+msgid "parameter passing for argument of type %qT with zero-width bit fields members changed in GCC 12"
+msgstr ""
+
+#: config/s390/s390.cc:13755
+#, gcc-internal-format
+msgid "nested functions cannot be profiled with %<-mfentry%> on s390"
+msgstr ""
+
+#: config/s390/s390.cc:16057
+#, gcc-internal-format
+msgid "64-bit ABI not supported in ESA/390 mode"
+msgstr ""
+
+#: config/s390/s390.cc:16064
+#, gcc-internal-format
+msgid "thunk-inline is only supported with %<-mindirect-branch-jump%>"
+msgstr ""
+
+#: config/s390/s390.cc:16099
+#, gcc-internal-format, gfc-internal-format
+msgid "hardware vector support not available on %s"
+msgstr ""
+
+#: config/s390/s390.cc:16102
+#, gcc-internal-format
+msgid "hardware vector support not available with %<-msoft-float%>"
+msgstr ""
+
+#: config/s390/s390.cc:16131
+#, gcc-internal-format, gfc-internal-format
+msgid "hardware decimal floating-point instructions not available on %s"
+msgstr ""
+
+#: config/s390/s390.cc:16135
+#, gcc-internal-format
+msgid "hardware decimal floating-point instructions not available in ESA/390 mode"
+msgstr ""
+
+#: config/s390/s390.cc:16147
+#, gcc-internal-format
+msgid "%<-mhard-dfp%> cannot be used in conjunction with %<-msoft-float%>"
+msgstr ""
+
+#: config/s390/s390.cc:16156
+#, gcc-internal-format
+msgid "%<-mbackchain%> %<-mpacked-stack%> %<-mhard-float%> are not supported in combination"
+msgstr ""
+
+#: config/s390/s390.cc:16162
+#, gcc-internal-format
+msgid "stack size must be greater than the stack guard value"
+msgstr ""
+
+#: config/s390/s390.cc:16164
+#, gcc-internal-format
+msgid "stack size must not be greater than 64k"
+msgstr ""
+
+#: config/s390/s390.cc:16167
+#, gcc-internal-format
+msgid "%<-mstack-guard%> implies use of %<-mstack-size%>"
+msgstr ""
+
+#: config/s390/s390.cc:16180
+#, gcc-internal-format
+msgid "%<-mtpf-trace-hook-prologue-check%> requires integer in range 0-4095"
+msgstr ""
+
+#: config/s390/s390.cc:16183
+#, gcc-internal-format
+msgid "%<-mtpf-trace-hook-prologue-target%> requires integer in range 0-4095"
+msgstr ""
+
+#: config/s390/s390.cc:16186
+#, gcc-internal-format
+msgid "%<-mtpf-trace-hook-epilogue-check%> requires integer in range 0-4095"
+msgstr ""
+
+#: config/s390/s390.cc:16189
+#, gcc-internal-format
+msgid "%<-mtpf-trace-hook-epilogue-target%> requires integer in range 0-4095"
+msgstr ""
+
+#: config/s390/s390.cc:16253
+#, gcc-internal-format
+msgid "%<-mfentry%> is supported only for 64-bit CPUs"
+msgstr ""
+
+#. argument is not a plain number
+#: config/s390/s390.cc:16289
+#, gcc-internal-format
+msgid "arguments to %qs should be non-negative integers"
+msgstr ""
+
+#: config/s390/s390.cc:16296
+#, gcc-internal-format
+msgid "argument to %qs is too large (max. %d)"
+msgstr ""
+
+#: config/s390/s390.cc:16327
+#, gcc-internal-format
+msgid "%<-mno-pic-data-is-text-relative%> cannot be used without %<-fpic%>/%<-fPIC%>"
+msgstr ""
+
+#: config/s390/s390.cc:16488 config/s390/s390.cc:16538
+#: config/s390/s390.cc:16555
+#, gcc-internal-format
+msgid "attribute %<target%> argument %qs is unknown"
+msgstr ""
+
+#. Value is not allowed for the target attribute.
+#: config/s390/s390.cc:16494
+#, gcc-internal-format
+msgid "value %qs is not supported by attribute %<target%>"
+msgstr ""
+
+#: config/s390/s390.cc:17553
+#, gcc-internal-format
+msgid "invalid cc output constraint: %qs"
+msgstr ""
+
+#: config/s390/s390.cc:17558
+#, gcc-internal-format
+msgid "multiple cc output constraints not supported"
+msgstr ""
+
+#: config/s390/s390.cc:17563
+#, gcc-internal-format
+msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
+msgstr ""
+
+#: config/s390/s390.cc:17569
+#, gcc-internal-format
+msgid "invalid type for cc output constraint"
+msgstr ""
+
+#: config/sh/sh.cc:936
+#, gcc-internal-format
+msgid "ignoring %<-fschedule-insns%> because of exception handling bug"
+msgstr ""
+
+#: config/sh/sh.cc:953
+#, gcc-internal-format
+msgid "unwind tables currently require either a frame pointer or %<-maccumulate-outgoing-args%> for correctness"
+msgstr ""
+
+#: config/sh/sh.cc:7416
+#, gcc-internal-format
+msgid "%<__builtin_saveregs%> not supported by this subtarget"
+msgstr ""
+
+#: config/sh/sh.cc:8353
+#, gcc-internal-format
+msgid "%qE attribute only applies to interrupt functions"
+msgstr ""
+
+#: config/sh/sh.cc:8423
+#, gcc-internal-format
+msgid "%qE attribute is supported only for SH2A"
+msgstr ""
+
+#: config/sh/sh.cc:8465
+#, gcc-internal-format
+msgid "%qE attribute only applies to SH2A"
+msgstr ""
+
+#: config/sh/sh.cc:8487
+#, gcc-internal-format
+msgid "%qE attribute argument should be between 0 to 255"
+msgstr ""
+
+#: config/sh/sh.cc:10832
+#, gcc-internal-format
+msgid "r0 needs to be available as a call-clobbered register"
+msgstr ""
+
+#: config/sparc/sparc.cc:1834
+#, gcc-internal-format, gfc-internal-format
+msgid "%s is not supported by this configuration"
+msgstr ""
+
+#: config/sparc/sparc.cc:1841
+#, gcc-internal-format
+msgid "%<-mlong-double-64%> not allowed with %<-m64%>"
+msgstr ""
+
+#: config/sparc/sparc.cc:1849
+#, gcc-internal-format
+msgid "%<-fcall-saved-REG%> is not supported for out registers"
+msgstr ""
+
+#: config/sparc/sparc.cc:1973
+#, gcc-internal-format
+msgid "%<-mcmodel=%> is not supported in 32-bit mode"
+msgstr ""
+
+#: config/stormy16/stormy16.cc:1202
+#, gcc-internal-format
+msgid "local variable memory requirements exceed capacity"
+msgstr ""
+
+#: config/stormy16/stormy16.cc:1359
+#, gcc-internal-format
+msgid "%<function_profiler%> support"
+msgstr ""
+
+#: config/stormy16/stormy16.cc:1453
+#, gcc-internal-format
+msgid "cannot use %<va_start%> in interrupt function"
+msgstr ""
+
+#: config/stormy16/stormy16.cc:2032
+#, gcc-internal-format, gfc-internal-format
+msgid "switch statement of size %lu entries too large"
+msgstr ""
+
+#: config/stormy16/stormy16.cc:2426
+#, gcc-internal-format
+msgid "%<__BELOW100__%> attribute only applies to variables"
+msgstr ""
+
+#: config/stormy16/stormy16.cc:2433
+#, gcc-internal-format
+msgid "%<__BELOW100__%> attribute not allowed with auto storage class"
+msgstr ""
+
+#: config/v850/v850-c.cc:67
+#, gcc-internal-format
+msgid "%<#pragma%> GHS endXXX found without previous startXXX"
+msgstr ""
+
+#: config/v850/v850-c.cc:70
+#, gcc-internal-format
+msgid "%<#pragma%> GHS endXXX does not match previous startXXX"
+msgstr ""
+
+#: config/v850/v850-c.cc:96
+#, gcc-internal-format
+msgid "cannot set interrupt attribute: no current function"
+msgstr ""
+
+#: config/v850/v850-c.cc:104
+#, gcc-internal-format
+msgid "cannot set interrupt attribute: no such identifier"
+msgstr ""
+
+#: config/v850/v850-c.cc:153
+#, gcc-internal-format
+msgid "junk at end of %<#pragma%> ghs section"
+msgstr ""
+
+#: config/v850/v850-c.cc:170
+#, gcc-internal-format
+msgid "unrecognized section name %qE"
+msgstr ""
+
+#: config/v850/v850-c.cc:184
+#, gcc-internal-format
+msgid "malformed %<#pragma%> ghs section"
+msgstr ""
+
+#: config/v850/v850-c.cc:203
+#, gcc-internal-format
+msgid "junk at end of %<#pragma%> ghs interrupt"
+msgstr ""
+
+#: config/v850/v850-c.cc:214
+#, gcc-internal-format
+msgid "junk at end of %<#pragma%> ghs starttda"
+msgstr ""
+
+#: config/v850/v850-c.cc:225
+#, gcc-internal-format
+msgid "junk at end of %<#pragma%> ghs startsda"
+msgstr ""
+
+#: config/v850/v850-c.cc:236
+#, gcc-internal-format
+msgid "junk at end of %<#pragma%> ghs startzda"
+msgstr ""
+
+#: config/v850/v850-c.cc:247
+#, gcc-internal-format
+msgid "junk at end of %<#pragma%> ghs endtda"
+msgstr ""
+
+#: config/v850/v850-c.cc:258
+#, gcc-internal-format
+msgid "junk at end of %<#pragma%> ghs endsda"
+msgstr ""
+
+#: config/v850/v850-c.cc:269
+#, gcc-internal-format
+msgid "junk at end of %<#pragma%> ghs endzda"
+msgstr ""
+
+#: config/v850/v850.cc:2046
+#, gcc-internal-format
+msgid "data area attributes cannot be specified for local variables"
+msgstr ""
+
+#: config/v850/v850.cc:2057
+#, gcc-internal-format
+msgid "data area of %q+D conflicts with previous declaration"
+msgstr ""
+
+#: config/v850/v850.cc:2188
+#, gcc-internal-format, gfc-internal-format
+msgid "bogus JR construction: %d"
+msgstr ""
+
+#: config/v850/v850.cc:2206 config/v850/v850.cc:2313
+#, gcc-internal-format, gfc-internal-format
+msgid "bad amount of stack space removal: %d"
+msgstr ""
+
+#: config/v850/v850.cc:2293
+#, gcc-internal-format, gfc-internal-format
+msgid "bogus JARL construction: %d"
+msgstr ""
+
+#: config/v850/v850.cc:2591
+#, gcc-internal-format, gfc-internal-format
+msgid "bogus DISPOSE construction: %d"
+msgstr ""
+
+#: config/v850/v850.cc:2610
+#, gcc-internal-format, gfc-internal-format
+msgid "too much stack space to dispose of: %d"
+msgstr ""
+
+#: config/v850/v850.cc:2712
+#, gcc-internal-format, gfc-internal-format
+msgid "bogus PREPEARE construction: %d"
+msgstr ""
+
+#: config/v850/v850.cc:2729
+#, gcc-internal-format, gfc-internal-format
+msgid "too much stack space to prepare: %d"
+msgstr ""
+
+#: config/visium/visium.cc:730
+#, gcc-internal-format
+msgid "an interrupt handler cannot be compiled with %<-muser-mode%>"
+msgstr ""
+
+#: config/vms/vms-c.cc:44
+#, gcc-internal-format
+msgid "junk at end of %<#pragma __nostandard%>"
+msgstr ""
+
+#: config/vms/vms-c.cc:55
+#, gcc-internal-format
+msgid "junk at end of %<#pragma __standard%>"
+msgstr ""
+
+#: config/vms/vms-c.cc:81
+#, gcc-internal-format
+msgid "malformed %<#pragma member_alignment%>, ignoring"
+msgstr ""
+
+#: config/vms/vms-c.cc:96
+#, gcc-internal-format
+msgid "unknown %<#pragma member_alignment%> name %s"
+msgstr ""
+
+#: config/vms/vms-c.cc:101
+#, gcc-internal-format
+msgid "malformed %<#pragma member_alignment%>"
+msgstr ""
+
+#: config/vms/vms-c.cc:135
+#, gcc-internal-format
+msgid "unhandled alignment for %<#pragma nomember_alignment%>"
+msgstr ""
+
+#: config/vms/vms-c.cc:148
+#, gcc-internal-format
+msgid "garbage at end of %<#pragma nomember_alignment%>"
+msgstr ""
+
+#: config/vms/vms-c.cc:203
+#, gcc-internal-format
+msgid "malformed %<#pragma extern_model%>, ignoring"
+msgstr ""
+
+#: config/vms/vms-c.cc:224
+#, gcc-internal-format
+msgid "extern model globalvalue"
+msgstr ""
+
+#: config/vms/vms-c.cc:229
+#, gcc-internal-format
+msgid "unknown %<#pragma extern_model%> model %qs"
+msgstr ""
+
+#: config/vms/vms-c.cc:235
+#, gcc-internal-format
+msgid "junk at end of '#pragma extern_model'"
+msgstr ""
+
+#: config/vms/vms-c.cc:249
+#, gcc-internal-format
+msgid "vms '#pragma __message' is ignored"
+msgstr ""
+
+#: config/vms/vms-c.cc:274 config/vms/vms-c.cc:280
+#, gcc-internal-format
+msgid "malformed %<#pragma __extern_prefix%>, ignoring"
+msgstr ""
+
+#: config/vms/vms-c.cc:313 config/vms/vms-c.cc:333
+#, gcc-internal-format
+msgid "malformed %<#pragma %s%>, ignoring"
+msgstr ""
+
+#: config/vms/vms-c.cc:329
+#, gcc-internal-format
+msgid "invalid constant in %<#pragma %s%>"
+msgstr ""
+
+#: config/xtensa/xtensa-dynconfig.cc:90
+#, gcc-internal-format
+msgid "%qs is defined but could not be loaded: %s"
+msgstr ""
+
+#: config/xtensa/xtensa-dynconfig.cc:97
+#, gcc-internal-format
+msgid "%qs plugin is not licensed under a GPL-compatible license"
+msgstr ""
+
+#: config/xtensa/xtensa-dynconfig.cc:114
+#, gcc-internal-format
+msgid "%qs is loaded but symbol %qs is not found: %s"
+msgstr ""
+
+#: config/xtensa/xtensa-dynconfig.cc:128
+#, gcc-internal-format
+msgid "%qs is defined but plugin support is disabled"
+msgstr ""
+
+#: config/xtensa/xtensa.cc:2864
+#, gcc-internal-format
+msgid "boolean registers required for the floating-point option"
+msgstr ""
+
+#: config/xtensa/xtensa.cc:2899
+#, gcc-internal-format
+msgid "%<-f%s%> is not supported with CONST16 instructions"
+msgstr ""
+
+#: config/xtensa/xtensa.cc:2906
+#, gcc-internal-format
+msgid "PIC is required but not supported with CONST16 instructions"
+msgstr ""
+
+#: config/xtensa/xtensa.cc:4349
+#, gcc-internal-format
+msgid "only uninitialized variables can be placed in a %<.bss%> section"
+msgstr ""
+
+#: ada/gcc-interface/misc.cc:155
+#, gcc-internal-format
+msgid "%<-gnat%> misspelled as %<-gant%>"
+msgstr ""
+
+#: ada/gcc-interface/misc.cc:258
+#, gcc-internal-format
+msgid "%<-fexcess-precision=standard%> for Ada"
+msgstr ""
+
+#: ada/gcc-interface/misc.cc:260
+#, gcc-internal-format
+msgid "%<-fexcess-precision=16%> for Ada"
+msgstr ""
+
+#: ada/gcc-interface/trans.cc:348
+#, gcc-internal-format, gfc-internal-format
+msgid "%s contains too many lines"
+msgstr ""
+
+#: ada/gcc-interface/trans.cc:1640
+#, gcc-internal-format
+msgid "subprogram %q+F not marked %<Inline_Always%>"
+msgstr ""
+
+#: ada/gcc-interface/trans.cc:1642 ada/gcc-interface/trans.cc:1648
+#, gcc-internal-format
+msgid "parent subprogram cannot be inlined"
+msgstr ""
+
+#: ada/gcc-interface/trans.cc:1646
+#, gcc-internal-format
+msgid "subprogram %q+F not marked %<Inline%>"
+msgstr ""
+
+#: ada/gcc-interface/utils.cc:4291
+#, gcc-internal-format
+msgid "invalid element type for attribute %qs"
+msgstr ""
+
+#: ada/gcc-interface/utils.cc:4315
+#, gcc-internal-format
+msgid "number of components of vector not a power of two"
+msgstr ""
+
+#: ada/gcc-interface/utils.cc:6551 ada/gcc-interface/utils.cc:6729
+#: ada/gcc-interface/utils.cc:6969
+#, gcc-internal-format
+msgid "%qs attribute ignored"
+msgstr ""
+
+#: ada/gcc-interface/utils.cc:6606
+#, gcc-internal-format
+msgid "%qs attribute without arguments on a non-prototype"
+msgstr ""
+
+#: ada/gcc-interface/utils.cc:6621
+#, gcc-internal-format
+msgid "%qs argument has invalid operand number (argument %lu)"
+msgstr ""
+
+#: ada/gcc-interface/utils.cc:6643
+#, gcc-internal-format
+msgid "%qs argument with out-of-range operand number (argument %lu, operand %lu)"
+msgstr ""
+
+#: ada/gcc-interface/utils.cc:6652
+#, gcc-internal-format
+msgid "%qs argument references non-pointer operand (argument %lu, operand %lu)"
+msgstr ""
+
+#: ada/gcc-interface/utils.cc:6673
+#, gcc-internal-format
+msgid "%qs attribute requires prototypes with named arguments"
+msgstr ""
+
+#: ada/gcc-interface/utils.cc:6682
+#, gcc-internal-format
+msgid "%qs attribute only applies to variadic functions"
+msgstr ""
+
+#: ada/gcc-interface/utils.cc:6929 d/d-attribs.cc:362 d/d-attribs.cc:488
+#: rust/rust-attribs.cc:176
+#, gcc-internal-format
+msgid "%qE attribute has no effect"
+msgstr ""
+
+#: ada/gcc-interface/utils.cc:7240
+#, gcc-internal-format
+msgid "attribute %qs applies to array types only"
+msgstr ""
+
+#: c/c-convert.cc:104 c/c-typeck.cc:2353 c/c-typeck.cc:13558 cp/typeck.cc:2494
+#: cp/typeck.cc:9508 cp/typeck.cc:10296 d/d-convert.cc:262
+#, gcc-internal-format
+msgid "void value not ignored as it ought to be"
+msgstr ""
+
+#: c/c-convert.cc:235
+#, gcc-internal-format
+msgid "conversion from %qT to %qT"
+msgstr ""
+
+#: c/c-convert.cc:237
+#, gcc-internal-format
+msgid "only %qT or a null pointer constant can be converted to %qT"
+msgstr ""
+
+#: c/c-convert.cc:241 d/d-convert.cc:322
+#, gcc-internal-format
+msgid "conversion to non-scalar type requested"
+msgstr ""
+
+#: c/c-decl.cc:915
+#, gcc-internal-format
+msgid "array %q+D assumed to have one element"
+msgstr ""
+
+#: c/c-decl.cc:956
+#, gcc-internal-format
+msgid "%qD is static but used in inline function %qD which is not static"
+msgstr ""
+
+#: c/c-decl.cc:961
+#, gcc-internal-format
+msgid "%q+D is static but declared in inline function %qD which is not static"
+msgstr ""
+
+#: c/c-decl.cc:1157
+#, gcc-internal-format, gfc-internal-format
+msgid "GCC supports only %u nested scopes"
+msgstr ""
+
+#: c/c-decl.cc:1299 cp/decl.cc:378
+#, gcc-internal-format
+msgid "label %q+D used but not defined"
+msgstr ""
+
+#: c/c-decl.cc:1344
+#, gcc-internal-format
+msgid "nested function %q+D declared but never defined"
+msgstr ""
+
+#: c/c-decl.cc:1358
+#, gcc-internal-format
+msgid "inline function %q+D declared but never defined"
+msgstr ""
+
+#: c/c-decl.cc:1376
+#, gcc-internal-format
+msgid "unused variable %q+D"
+msgstr ""
+
+#: c/c-decl.cc:1382 cp/decl.cc:733
+#, gcc-internal-format
+msgid "variable %qD set but not used"
+msgstr ""
+
+#: c/c-decl.cc:1387
+#, gcc-internal-format
+msgid "type of array %q+D completed incompatibly with implicit initialization"
+msgstr ""
+
+#: c/c-decl.cc:1562
+#, gcc-internal-format
+msgid "underspecified declaration of %qE, which is already declared in this scope"
+msgstr ""
+
+#: c/c-decl.cc:1733 c/c-decl.cc:7890 c/c-decl.cc:8894 c/c-decl.cc:9985
+#, gcc-internal-format
+msgid "originally defined here"
+msgstr ""
+
+#: c/c-decl.cc:1956
+#, gcc-internal-format
+msgid "a parameter list with an ellipsis cannot match an empty parameter name list declaration"
+msgstr ""
+
+#: c/c-decl.cc:1964
+#, gcc-internal-format
+msgid "an argument type that has a default promotion cannot match an empty parameter name list declaration"
+msgstr ""
+
+#: c/c-decl.cc:2012
+#, gcc-internal-format
+msgid "prototype for %q+D declares more arguments than previous old-style definition"
+msgstr ""
+
+#: c/c-decl.cc:2018
+#, gcc-internal-format
+msgid "prototype for %q+D declares fewer arguments than previous old-style definition"
+msgstr ""
+
+#: c/c-decl.cc:2027
+#, gcc-internal-format
+msgid "prototype for %q+D declares argument %d with incompatible type"
+msgstr ""
+
+#. If we get here, no errors were found, but do issue a warning
+#. for this poor-style construct.
+#: c/c-decl.cc:2040
+#, gcc-internal-format
+msgid "prototype for %q+D follows non-prototype definition"
+msgstr ""
+
+#: c/c-decl.cc:2058
+#, gcc-internal-format
+msgid "previous definition of %q+D with type %qT"
+msgstr ""
+
+#: c/c-decl.cc:2062
+#, gcc-internal-format
+msgid "previous implicit declaration of %q+D with type %qT"
+msgstr ""
+
+#: c/c-decl.cc:2066
+#, gcc-internal-format
+msgid "previous declaration of %q+D with type %qT"
+msgstr ""
+
+#: c/c-decl.cc:2128
+#, gcc-internal-format
+msgid "%q+D redeclared as different kind of symbol"
+msgstr ""
+
+#: c/c-decl.cc:2133
+#, gcc-internal-format
+msgid "built-in function %q+D declared as non-function"
+msgstr ""
+
+#: c/c-decl.cc:2136 c/c-decl.cc:3273
+#, gcc-internal-format
+msgid "declaration of %q+D shadows a built-in function"
+msgstr ""
+
+#: c/c-decl.cc:2153
+#, gcc-internal-format
+msgid "conflicting redeclaration of enumerator %q+D"
+msgstr ""
+
+#: c/c-decl.cc:2160
+#, gcc-internal-format
+msgid "redeclaration of enumerator %q+D"
+msgstr ""
+
+#: c/c-decl.cc:2200
+#, gcc-internal-format
+msgid "conflicting types for built-in function %q+D; expected %qT"
+msgstr ""
+
+#: c/c-decl.cc:2210 c/c-decl.cc:2235
+#, gcc-internal-format
+msgid "%qD is declared in header %qs"
+msgstr ""
+
+#: c/c-decl.cc:2221
+#, gcc-internal-format
+msgid "mismatch in argument %u type of built-in function %qD; expected %qT"
+msgstr ""
+
+#: c/c-decl.cc:2226
+#, gcc-internal-format
+msgid "mismatch in return type of built-in function %qD; expected %qT"
+msgstr ""
+
+#: c/c-decl.cc:2259
+#, gcc-internal-format
+msgid "conflicting types for %q+D"
+msgstr ""
+
+#: c/c-decl.cc:2272 c/c-decl.cc:2309
+#, gcc-internal-format
+msgid "conflicting types for %q+D; have %qT"
+msgstr ""
+
+#: c/c-decl.cc:2289
+#, gcc-internal-format
+msgid "conflicting named address spaces (generic vs %s) for %q+D"
+msgstr ""
+
+#: c/c-decl.cc:2293
+#, gcc-internal-format
+msgid "conflicting named address spaces (%s vs generic) for %q+D"
+msgstr ""
+
+#: c/c-decl.cc:2297
+#, gcc-internal-format
+msgid "conflicting named address spaces (%s vs %s) for %q+D"
+msgstr ""
+
+#: c/c-decl.cc:2306
+#, gcc-internal-format
+msgid "conflicting type qualifiers for %q+D"
+msgstr ""
+
+#: c/c-decl.cc:2327
+#, gcc-internal-format
+msgid "conflicting types for %q+D due to enum/integer mismatch; have %qT"
+msgstr ""
+
+#: c/c-decl.cc:2344
+#, gcc-internal-format
+msgid "redefinition of typedef %q+D with different type"
+msgstr ""
+
+#: c/c-decl.cc:2357
+#, gcc-internal-format
+msgid "redefinition of typedef %q+D with variably modified type"
+msgstr ""
+
+#: c/c-decl.cc:2362
+#, gcc-internal-format
+msgid "redefinition of typedef %q+D"
+msgstr ""
+
+#: c/c-decl.cc:2390
+#, gcc-internal-format
+msgid "declaration of %qD shadows a built-in function"
+msgstr ""
+
+#: c/c-decl.cc:2406
+#, gcc-internal-format
+msgid "declaration of built-in function %qD without a prototype; expected %qT"
+msgstr ""
+
+#: c/c-decl.cc:2430 c/c-decl.cc:2553
+#, gcc-internal-format
+msgid "redefinition of %q+D"
+msgstr ""
+
+#: c/c-decl.cc:2469 c/c-decl.cc:2593
+#, gcc-internal-format
+msgid "static declaration of %q+D follows non-static declaration"
+msgstr ""
+
+#: c/c-decl.cc:2480 c/c-decl.cc:2488 c/c-decl.cc:2582 c/c-decl.cc:2590
+#, gcc-internal-format
+msgid "non-static declaration of %q+D follows static declaration"
+msgstr ""
+
+#: c/c-decl.cc:2505
+#, gcc-internal-format
+msgid "%<gnu_inline%> attribute present on %q+D"
+msgstr ""
+
+#: c/c-decl.cc:2508
+#, gcc-internal-format
+msgid "but not here"
+msgstr ""
+
+#: c/c-decl.cc:2527
+#, gcc-internal-format
+msgid "thread-local declaration of %q+D follows non-thread-local declaration"
+msgstr ""
+
+#: c/c-decl.cc:2530
+#, gcc-internal-format
+msgid "non-thread-local declaration of %q+D follows thread-local declaration"
+msgstr ""
+
+#: c/c-decl.cc:2574
+#, gcc-internal-format
+msgid "extern declaration of %q+D follows declaration with no linkage"
+msgstr ""
+
+#: c/c-decl.cc:2612
+#, gcc-internal-format
+msgid "declaration of %q+D with no linkage follows extern declaration"
+msgstr ""
+
+#: c/c-decl.cc:2619
+#, gcc-internal-format
+msgid "redeclaration of %q+D with no linkage"
+msgstr ""
+
+#: c/c-decl.cc:2645
+#, gcc-internal-format
+msgid "redeclaration of %q+D with different visibility (old visibility preserved)"
+msgstr ""
+
+#: c/c-decl.cc:2666
+#, gcc-internal-format
+msgid "redefinition of parameter %q+D"
+msgstr ""
+
+#: c/c-decl.cc:2693
+#, gcc-internal-format
+msgid "redundant redeclaration of %q+D"
+msgstr ""
+
+#: c/c-decl.cc:3231
+#, gcc-internal-format
+msgid "declaration of %q+D shadows previous non-variable"
+msgstr ""
+
+#: c/c-decl.cc:3253
+#, gcc-internal-format
+msgid "declaration of %qD shadows a parameter"
+msgstr ""
+
+#: c/c-decl.cc:3266 cp/name-lookup.cc:3551
+#, gcc-internal-format
+msgid "declaration of %qD shadows a global declaration"
+msgstr ""
+
+#: c/c-decl.cc:3292
+#, gcc-internal-format
+msgid "declaration of %qD shadows a previous local"
+msgstr ""
+
+#: c/c-decl.cc:3298 cp/name-lookup.cc:3268
+#, gcc-internal-format
+msgid "shadowed declaration is here"
+msgstr ""
+
+#: c/c-decl.cc:3431
+#, gcc-internal-format
+msgid "nested extern declaration of %qD"
+msgstr ""
+
+#: c/c-decl.cc:3587 c/c-decl.cc:3601
+#, gcc-internal-format
+msgid "implicit declaration of function %qE; did you mean %qs?"
+msgstr ""
+
+#: c/c-decl.cc:3593 c/c-decl.cc:3606
+#, gcc-internal-format
+msgid "implicit declaration of function %qE"
+msgstr ""
+
+#: c/c-decl.cc:3625
+#, gcc-internal-format
+msgid "include %qs or provide a declaration of %qE"
+msgstr ""
+
+#: c/c-decl.cc:3896
+#, gcc-internal-format
+msgid "incompatible implicit declaration of built-in function %qD"
+msgstr ""
+
+#: c/c-decl.cc:3906
+#, gcc-internal-format
+msgid "include %qs or provide a declaration of %qD"
+msgstr ""
+
+#: c/c-decl.cc:3917
+#, gcc-internal-format
+msgid "incompatible implicit declaration of function %qD"
+msgstr ""
+
+#: c/c-decl.cc:3978
+#, gcc-internal-format
+msgid "%qE undeclared here (not in a function); did you mean %qs?"
+msgstr ""
+
+#: c/c-decl.cc:3983
+#, gcc-internal-format
+msgid "%qE undeclared here (not in a function)"
+msgstr ""
+
+#: c/c-decl.cc:3996
+#, gcc-internal-format
+msgid "%qE undeclared (first use in this function); did you mean %qs?"
+msgstr ""
+
+#: c/c-decl.cc:4001
+#, gcc-internal-format
+msgid "%qE undeclared (first use in this function)"
+msgstr ""
+
+#: c/c-decl.cc:4005
+#, gcc-internal-format
+msgid "each undeclared identifier is reported only once for each function it appears in"
+msgstr ""
+
+#: c/c-decl.cc:4053 cp/decl.cc:3588
+#, gcc-internal-format
+msgid "label %qE referenced outside of any function"
+msgstr ""
+
+#: c/c-decl.cc:4090
+#, gcc-internal-format
+msgid "jump into scope of identifier with variably modified type"
+msgstr ""
+
+#: c/c-decl.cc:4093
+#, gcc-internal-format
+msgid "jump skips OpenMP %<allocate%> allocation"
+msgstr ""
+
+#: c/c-decl.cc:4096
+#, gcc-internal-format
+msgid "jump skips variable initialization"
+msgstr ""
+
+#: c/c-decl.cc:4098 c/c-decl.cc:4154 c/c-decl.cc:4245
+#, gcc-internal-format
+msgid "label %qD defined here"
+msgstr ""
+
+#: c/c-decl.cc:4153 c/c-decl.cc:4244
+#, gcc-internal-format
+msgid "jump into statement expression"
+msgstr ""
+
+#: c/c-decl.cc:4176
+#, gcc-internal-format
+msgid "duplicate label declaration %qE"
+msgstr ""
+
+#: c/c-decl.cc:4276 cp/decl.cc:4089
+#, gcc-internal-format
+msgid "duplicate label %qD"
+msgstr ""
+
+#: c/c-decl.cc:4307
+#, gcc-internal-format
+msgid "traditional C lacks a separate namespace for labels, identifier %qE conflicts"
+msgstr ""
+
+#: c/c-decl.cc:4379
+#, gcc-internal-format
+msgid "switch jumps over OpenMP %<allocate%> allocation"
+msgstr ""
+
+#: c/c-decl.cc:4385
+#, gcc-internal-format
+msgid "switch jumps over variable initialization"
+msgstr ""
+
+#: c/c-decl.cc:4388 c/c-decl.cc:4401
+#, gcc-internal-format
+msgid "switch starts here"
+msgstr ""
+
+#: c/c-decl.cc:4400
+#, gcc-internal-format
+msgid "switch jumps into statement expression"
+msgstr ""
+
+#: c/c-decl.cc:4483
+#, gcc-internal-format
+msgid "%qE defined as wrong kind of tag"
+msgstr ""
+
+#: c/c-decl.cc:4669 cp/tree.cc:5039
+#, gcc-internal-format
+msgid "%qE attribute applied to %qD with void return type"
+msgstr ""
+
+#: c/c-decl.cc:4678
+#, gcc-internal-format
+msgid "%qE attribute can only be applied to functions or to structure, union or enumeration types"
+msgstr ""
+
+#: c/c-decl.cc:4698
+#, gcc-internal-format
+msgid "standard %qE attribute can only be applied to functions"
+msgstr ""
+
+#. This can only occur with extensions such as statement
+#. expressions, but is still appropriate as an error to
+#. avoid types declared in such a context escaping to
+#. the type of an auto variable.
+#: c/c-decl.cc:4976 c/c-decl.cc:8833
+#, gcc-internal-format
+msgid "%qT declared in underspecified object initializer"
+msgstr ""
+
+#: c/c-decl.cc:4987
+#, gcc-internal-format
+msgid "unnamed struct/union that defines no instances"
+msgstr ""
+
+#: c/c-decl.cc:4998
+#, gcc-internal-format
+msgid "empty declaration with storage class specifier does not redeclare tag"
+msgstr ""
+
+#: c/c-decl.cc:5014
+#, gcc-internal-format
+msgid "empty declaration with type qualifier does not redeclare tag"
+msgstr ""
+
+#: c/c-decl.cc:5026
+#, gcc-internal-format
+msgid "empty declaration with %<_Alignas%> does not redeclare tag"
+msgstr ""
+
+#: c/c-decl.cc:5040
+#, gcc-internal-format
+msgid "empty declaration of %<enum%> type does not redeclare tag"
+msgstr ""
+
+#: c/c-decl.cc:5065 c/c-decl.cc:5073
+#, gcc-internal-format
+msgid "useless type name in empty declaration"
+msgstr ""
+
+#: c/c-decl.cc:5081
+#, gcc-internal-format
+msgid "%<inline%> in empty declaration"
+msgstr ""
+
+#: c/c-decl.cc:5087
+#, gcc-internal-format
+msgid "%<_Noreturn%> in empty declaration"
+msgstr ""
+
+#: c/c-decl.cc:5093
+#, gcc-internal-format
+msgid "%<constexpr%> in empty declaration"
+msgstr ""
+
+#: c/c-decl.cc:5099
+#, gcc-internal-format
+msgid "%<auto%> in file-scope empty declaration"
+msgstr ""
+
+#: c/c-decl.cc:5105
+#, gcc-internal-format
+msgid "%<register%> in file-scope empty declaration"
+msgstr ""
+
+#: c/c-decl.cc:5113
+#, gcc-internal-format
+msgid "storage class specifier in empty declaration with %<enum%> underlying type"
+msgstr ""
+
+#: c/c-decl.cc:5119
+#, gcc-internal-format
+msgid "%qs in empty declaration with %<enum%> underlying type"
+msgstr ""
+
+#: c/c-decl.cc:5129
+#, gcc-internal-format
+msgid "type qualifier in empty declaration with %<enum%> underlying type"
+msgstr ""
+
+#: c/c-decl.cc:5135
+#, gcc-internal-format
+msgid "%<alignas%> in empty declaration with %<enum%> underlying type"
+msgstr ""
+
+#: c/c-decl.cc:5144
+#, gcc-internal-format
+msgid "useless storage class specifier in empty declaration"
+msgstr ""
+
+#: c/c-decl.cc:5150
+#, gcc-internal-format
+msgid "useless %qs in empty declaration"
+msgstr ""
+
+#: c/c-decl.cc:5163
+#, gcc-internal-format
+msgid "useless type qualifier in empty declaration"
+msgstr ""
+
+#: c/c-decl.cc:5170
+#, gcc-internal-format
+msgid "useless %<_Alignas%> in empty declaration"
+msgstr ""
+
+#: c/c-decl.cc:5188
+#, gcc-internal-format
+msgid "invalid use of attributes in empty declaration"
+msgstr ""
+
+#: c/c-decl.cc:5202 c/c-parser.cc:2403
+#, gcc-internal-format
+msgid "empty declaration"
+msgstr ""
+
+#: c/c-decl.cc:5274
+#, gcc-internal-format
+msgid "ISO C90 does not support %<static%> or type qualifiers in parameter array declarators"
+msgstr ""
+
+#: c/c-decl.cc:5278
+#, gcc-internal-format
+msgid "ISO C90 does not support %<[*]%> array declarators"
+msgstr ""
+
+#. C99 6.7.5.2p4
+#. A function definition isn't function prototype scope C99 6.2.1p4.
+#. C99 6.7.5.2p4
+#: c/c-decl.cc:5284 c/c-decl.cc:8413 c/c-decl.cc:10830
+#, gcc-internal-format
+msgid "%<[*]%> not allowed in other than function prototype scope"
+msgstr ""
+
+#: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
+#, gcc-internal-format
+msgid "%<omp::%s%> not allowed to be specified in this context"
+msgstr ""
+
+#: c/c-decl.cc:5557
+#, gcc-internal-format
+msgid "%q+D is usually a function"
+msgstr ""
+
+#: c/c-decl.cc:5562 c/c-decl.cc:10661 cp/decl.cc:17947
+#, gcc-internal-format
+msgid "no previous declaration for %qD"
+msgstr ""
+
+#: c/c-decl.cc:5571
+#, gcc-internal-format
+msgid "typedef %qD is initialized (use %<__typeof__%> instead)"
+msgstr ""
+
+#: c/c-decl.cc:5576
+#, gcc-internal-format
+msgid "function %qD is initialized like a variable"
+msgstr ""
+
+#. DECL_INITIAL in a PARM_DECL is really DECL_ARG_TYPE.
+#: c/c-decl.cc:5582
+#, gcc-internal-format
+msgid "parameter %qD is initialized"
+msgstr ""
+
+#: c/c-decl.cc:5602
+#, gcc-internal-format
+msgid "variable %qD has initializer but incomplete type"
+msgstr ""
+
+#: c/c-decl.cc:5682
+#, gcc-internal-format
+msgid "inline function %q+D given attribute %qs"
+msgstr ""
+
+#: c/c-decl.cc:5738
+#, gcc-internal-format
+msgid "uninitialized const member in %qT is invalid in C++"
+msgstr ""
+
+#: c/c-decl.cc:5740
+#, gcc-internal-format
+msgid "%qD should be initialized"
+msgstr ""
+
+#: c/c-decl.cc:5821
+#, gcc-internal-format
+msgid "initializer fails to determine size of %q+D"
+msgstr ""
+
+#: c/c-decl.cc:5826
+#, gcc-internal-format
+msgid "array size missing in %q+D"
+msgstr ""
+
+#: c/c-decl.cc:5830
+#, gcc-internal-format
+msgid "zero or negative size array %q+D"
+msgstr ""
+
+#: c/c-decl.cc:5921 m2/gm2-gcc/m2type.cc:1250
+#, gcc-internal-format
+msgid "storage size of %q+D isn%'t constant"
+msgstr ""
+
+#: c/c-decl.cc:5971
+#, gcc-internal-format
+msgid "ignoring %<asm%> specifier for non-static local variable %q+D"
+msgstr ""
+
+#: c/c-decl.cc:6009
+#, gcc-internal-format
+msgid "cannot put object with volatile field into register"
+msgstr ""
+
+#: c/c-decl.cc:6095
+#, gcc-internal-format
+msgid "uninitialized %<const %D%> is invalid in C++"
+msgstr ""
+
+#: c/c-decl.cc:6110 cp/decl.cc:9052
+#, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr ""
+
+#: c/c-decl.cc:6373
+#, gcc-internal-format
+msgid "ISO C forbids forward parameter declarations"
+msgstr ""
+
+#: c/c-decl.cc:6413
+#, gcc-internal-format
+msgid "file-scope compound literal specifies %<register%>"
+msgstr ""
+
+#: c/c-decl.cc:6419
+#, gcc-internal-format
+msgid "compound literal implicitly auto and declared %qs"
+msgstr ""
+
+#: c/c-decl.cc:6519
+#, gcc-internal-format
+msgid "defining a type in a compound literal is invalid in C++"
+msgstr ""
+
+#: c/c-decl.cc:6540 c/c-decl.cc:6555
+#, gcc-internal-format
+msgid "bit-field %qs width not an integer constant"
+msgstr ""
+
+#: c/c-decl.cc:6550
+#, gcc-internal-format
+msgid "bit-field %qs width not an integer constant expression"
+msgstr ""
+
+#: c/c-decl.cc:6561
+#, gcc-internal-format
+msgid "negative width in bit-field %qs"
+msgstr ""
+
+#: c/c-decl.cc:6566
+#, gcc-internal-format
+msgid "zero width for bit-field %qs"
+msgstr ""
+
+#: c/c-decl.cc:6577
+#, gcc-internal-format
+msgid "bit-field %qs has invalid type"
+msgstr ""
+
+#: c/c-decl.cc:6583
+#, gcc-internal-format
+msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
+msgstr ""
+
+#: c/c-decl.cc:6594
+#, gcc-internal-format
+msgid "type of bit-field %qs is a GCC extension"
+msgstr ""
+
+#: c/c-decl.cc:6600
+#, gcc-internal-format
+msgid "width of %qs exceeds its type"
+msgstr ""
+
+#: c/c-decl.cc:6619
+#, gcc-internal-format
+msgid "%qs is narrower than values of its type"
+msgstr ""
+
+#: c/c-decl.cc:6634
+#, gcc-internal-format
+msgid "ISO C90 forbids array %qE whose size cannot be evaluated"
+msgstr ""
+
+#: c/c-decl.cc:6637
+#, gcc-internal-format
+msgid "ISO C90 forbids array whose size cannot be evaluated"
+msgstr ""
+
+#: c/c-decl.cc:6644
+#, gcc-internal-format
+msgid "ISO C90 forbids variable length array %qE"
+msgstr ""
+
+#: c/c-decl.cc:6646
+#, gcc-internal-format
+msgid "ISO C90 forbids variable length array"
+msgstr ""
+
+#: c/c-decl.cc:6889
+#, gcc-internal-format
+msgid "%<enum%> underlying type may not be specified here"
+msgstr ""
+
+#: c/c-decl.cc:6917 c/c-decl.cc:7326 c/c-decl.cc:7336
+#, gcc-internal-format
+msgid "variably modified %qE at file scope"
+msgstr ""
+
+#: c/c-decl.cc:6919
+#, gcc-internal-format
+msgid "variably modified field at file scope"
+msgstr ""
+
+#: c/c-decl.cc:6939
+#, gcc-internal-format
+msgid "type defaults to %<int%> in declaration of %qE"
+msgstr ""
+
+#: c/c-decl.cc:6943
+#, gcc-internal-format
+msgid "type defaults to %<int%> in type name"
+msgstr ""
+
+#: c/c-decl.cc:6975
+#, gcc-internal-format
+msgid "duplicate %<const%>"
+msgstr ""
+
+#: c/c-decl.cc:6977
+#, gcc-internal-format
+msgid "duplicate %<restrict%>"
+msgstr ""
+
+#: c/c-decl.cc:6979
+#, gcc-internal-format
+msgid "duplicate %<volatile%>"
+msgstr ""
+
+#: c/c-decl.cc:6981
+#, gcc-internal-format
+msgid "duplicate %<_Atomic%>"
+msgstr ""
+
+#: c/c-decl.cc:6984
+#, gcc-internal-format, gfc-internal-format
+msgid "conflicting named address spaces (%s vs %s)"
+msgstr ""
+
+#: c/c-decl.cc:7007 c/c-parser.cc:3573
+#, gcc-internal-format
+msgid "%<_Atomic%>-qualified array type"
+msgstr ""
+
+#: c/c-decl.cc:7022
+#, gcc-internal-format
+msgid "function definition declared %<auto%>"
+msgstr ""
+
+#: c/c-decl.cc:7024
+#, gcc-internal-format
+msgid "function definition declared %<register%>"
+msgstr ""
+
+#: c/c-decl.cc:7026
+#, gcc-internal-format
+msgid "function definition declared %<typedef%>"
+msgstr ""
+
+#: c/c-decl.cc:7028
+#, gcc-internal-format
+msgid "function definition declared %qs"
+msgstr ""
+
+#: c/c-decl.cc:7055
+#, gcc-internal-format
+msgid "storage class specified for structure field %qE"
+msgstr ""
+
+#: c/c-decl.cc:7058
+#, gcc-internal-format
+msgid "storage class specified for structure field"
+msgstr ""
+
+#: c/c-decl.cc:7062
+#, gcc-internal-format
+msgid "storage class specified for parameter %qE"
+msgstr ""
+
+#: c/c-decl.cc:7065
+#, gcc-internal-format
+msgid "storage class specified for unnamed parameter"
+msgstr ""
+
+#: c/c-decl.cc:7068 cp/decl.cc:13150
+#, gcc-internal-format
+msgid "storage class specified for typename"
+msgstr ""
+
+#: c/c-decl.cc:7086
+#, gcc-internal-format
+msgid "%qE initialized and declared %<extern%>"
+msgstr ""
+
+#: c/c-decl.cc:7090
+#, gcc-internal-format
+msgid "%qE has both %<extern%> and initializer"
+msgstr ""
+
+#: c/c-decl.cc:7095
+#, gcc-internal-format
+msgid "file-scope declaration of %qE specifies %<auto%>"
+msgstr ""
+
+#: c/c-decl.cc:7099
+#, gcc-internal-format
+msgid "file-scope declaration of %qE specifies %<register%>"
+msgstr ""
+
+#: c/c-decl.cc:7104
+#, gcc-internal-format
+msgid "nested function %qE declared %<extern%>"
+msgstr ""
+
+#: c/c-decl.cc:7107
+#, gcc-internal-format
+msgid "function-scope %qE implicitly auto and declared %qs"
+msgstr ""
+
+#. Only the innermost declarator (making a parameter be of
+#. array type which is converted to pointer type)
+#. may have static or type qualifiers.
+#: c/c-decl.cc:7154 c/c-decl.cc:7550
+#, gcc-internal-format
+msgid "static or type qualifiers in non-parameter array declarator"
+msgstr ""
+
+#: c/c-decl.cc:7217
+#, gcc-internal-format
+msgid "declaration of %qE as array of voids"
+msgstr ""
+
+#: c/c-decl.cc:7219
+#, gcc-internal-format
+msgid "declaration of type name as array of voids"
+msgstr ""
+
+#: c/c-decl.cc:7226
+#, gcc-internal-format
+msgid "declaration of %qE as array of functions"
+msgstr ""
+
+#: c/c-decl.cc:7229
+#, gcc-internal-format
+msgid "declaration of type name as array of functions"
+msgstr ""
+
+#: c/c-decl.cc:7237 c/c-decl.cc:9577
+#, gcc-internal-format
+msgid "invalid use of structure with flexible array member"
+msgstr ""
+
+#: c/c-decl.cc:7269
+#, gcc-internal-format
+msgid "size of array %qE has non-integer type"
+msgstr ""
+
+#: c/c-decl.cc:7273
+#, gcc-internal-format
+msgid "size of unnamed array has non-integer type"
+msgstr ""
+
+#: c/c-decl.cc:7281
+#, gcc-internal-format
+msgid "size of array %qE has incomplete type"
+msgstr ""
+
+#: c/c-decl.cc:7284
+#, gcc-internal-format
+msgid "size of unnamed array has incomplete type"
+msgstr ""
+
+#: c/c-decl.cc:7296
+#, gcc-internal-format
+msgid "ISO C forbids zero-size array %qE"
+msgstr ""
+
+#: c/c-decl.cc:7299
+#, gcc-internal-format
+msgid "ISO C forbids zero-size array"
+msgstr ""
+
+#: c/c-decl.cc:7308
+#, gcc-internal-format
+msgid "size of array %qE is negative"
+msgstr ""
+
+#: c/c-decl.cc:7310
+#, gcc-internal-format
+msgid "size of unnamed array is negative"
+msgstr ""
+
+#: c/c-decl.cc:7396
+#, gcc-internal-format
+msgid "size of array %qE is too large"
+msgstr ""
+
+#: c/c-decl.cc:7399
+#, gcc-internal-format
+msgid "size of unnamed array is too large"
+msgstr ""
+
+#: c/c-decl.cc:7438 c/c-decl.cc:8070
+#, gcc-internal-format
+msgid "ISO C90 does not support flexible array members"
+msgstr ""
+
+#. C99 6.7.5.2p4
+#: c/c-decl.cc:7460
+#, gcc-internal-format
+msgid "%<[*]%> not in a declaration"
+msgstr ""
+
+#: c/c-decl.cc:7474
+#, gcc-internal-format
+msgid "array type has incomplete element type %qT"
+msgstr ""
+
+#: c/c-decl.cc:7480
+#, gcc-internal-format
+msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
+msgstr ""
+
+#: c/c-decl.cc:7484
+#, gcc-internal-format
+msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
+msgstr ""
+
+#: c/c-decl.cc:7586
+#, gcc-internal-format
+msgid "%qE declared as function returning a function"
+msgstr ""
+
+#: c/c-decl.cc:7589
+#, gcc-internal-format
+msgid "type name declared as function returning a function"
+msgstr ""
+
+#: c/c-decl.cc:7596
+#, gcc-internal-format
+msgid "%qE declared as function returning an array"
+msgstr ""
+
+#: c/c-decl.cc:7599
+#, gcc-internal-format
+msgid "type name declared as function returning an array"
+msgstr ""
+
+#: c/c-decl.cc:7643
+#, gcc-internal-format
+msgid "function definition has qualified void return type"
+msgstr ""
+
+#: c/c-decl.cc:7647 cp/decl.cc:13559
+#, gcc-internal-format
+msgid "type qualifiers ignored on function return type"
+msgstr ""
+
+#: c/c-decl.cc:7686 c/c-decl.cc:7856 c/c-decl.cc:7910 c/c-decl.cc:8004
+#: c/c-decl.cc:8126 c/c-parser.cc:3575
+#, gcc-internal-format
+msgid "%<_Atomic%>-qualified function type"
+msgstr ""
+
+#: c/c-decl.cc:7692 c/c-decl.cc:7862 c/c-decl.cc:8009 c/c-decl.cc:8131
+#, gcc-internal-format
+msgid "ISO C forbids qualified function types"
+msgstr ""
+
+#: c/c-decl.cc:7747
+#, gcc-internal-format
+msgid "%qs combined with %<auto%> qualifier for %qE"
+msgstr ""
+
+#: c/c-decl.cc:7751
+#, gcc-internal-format
+msgid "%qs combined with %<register%> qualifier for %qE"
+msgstr ""
+
+#: c/c-decl.cc:7757
+#, gcc-internal-format
+msgid "%qs specified for auto variable %qE"
+msgstr ""
+
+#: c/c-decl.cc:7773
+#, gcc-internal-format
+msgid "%qs specified for parameter %qE"
+msgstr ""
+
+#: c/c-decl.cc:7776
+#, gcc-internal-format
+msgid "%qs specified for unnamed parameter"
+msgstr ""
+
+#: c/c-decl.cc:7782
+#, gcc-internal-format
+msgid "%qs specified for structure field %qE"
+msgstr ""
+
+#: c/c-decl.cc:7785
+#, gcc-internal-format
+msgid "%qs specified for structure field"
+msgstr ""
+
+#: c/c-decl.cc:7800
+#, gcc-internal-format
+msgid "bit-field %qE has atomic type"
+msgstr ""
+
+#: c/c-decl.cc:7802
+#, gcc-internal-format
+msgid "bit-field has atomic type"
+msgstr ""
+
+#: c/c-decl.cc:7811
+#, gcc-internal-format
+msgid "alignment specified for typedef %qE"
+msgstr ""
+
+#: c/c-decl.cc:7813
+#, gcc-internal-format
+msgid "alignment specified for %<register%> object %qE"
+msgstr ""
+
+#: c/c-decl.cc:7818
+#, gcc-internal-format
+msgid "alignment specified for parameter %qE"
+msgstr ""
+
+#: c/c-decl.cc:7820
+#, gcc-internal-format
+msgid "alignment specified for unnamed parameter"
+msgstr ""
+
+#: c/c-decl.cc:7825
+#, gcc-internal-format
+msgid "alignment specified for bit-field %qE"
+msgstr ""
+
+#: c/c-decl.cc:7827
+#, gcc-internal-format
+msgid "alignment specified for unnamed bit-field"
+msgstr ""
+
+#: c/c-decl.cc:7830
+#, gcc-internal-format
+msgid "alignment specified for function %qE"
+msgstr ""
+
+#: c/c-decl.cc:7837
+#, gcc-internal-format
+msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
+msgstr ""
+
+#: c/c-decl.cc:7840
+#, gcc-internal-format
+msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
+msgstr ""
+
+#: c/c-decl.cc:7871
+#, gcc-internal-format
+msgid "typedef %q+D declared %<inline%>"
+msgstr ""
+
+#: c/c-decl.cc:7873
+#, gcc-internal-format
+msgid "typedef %q+D declared %<_Noreturn%>"
+msgstr ""
+
+#: c/c-decl.cc:7916
+#, gcc-internal-format
+msgid "ISO C forbids const or volatile function types"
+msgstr ""
+
+#. C99 6.7.2.1p8
+#: c/c-decl.cc:7927
+#, gcc-internal-format
+msgid "a member of a structure or union cannot have a variably modified type"
+msgstr ""
+
+#: c/c-decl.cc:7944 cp/decl.cc:12030
+#, gcc-internal-format
+msgid "variable or field %qE declared void"
+msgstr ""
+
+#: c/c-decl.cc:7994
+#, gcc-internal-format
+msgid "attributes in parameter array declarator ignored"
+msgstr ""
+
+#: c/c-decl.cc:8036
+#, gcc-internal-format
+msgid "parameter %q+D declared %<inline%>"
+msgstr ""
+
+#: c/c-decl.cc:8038
+#, gcc-internal-format
+msgid "parameter %q+D declared %<_Noreturn%>"
+msgstr ""
+
+#: c/c-decl.cc:8051
+#, gcc-internal-format
+msgid "field %qE declared as a function"
+msgstr ""
+
+#: c/c-decl.cc:8058
+#, gcc-internal-format
+msgid "field %qE has incomplete type"
+msgstr ""
+
+#: c/c-decl.cc:8060
+#, gcc-internal-format
+msgid "unnamed field has incomplete type"
+msgstr ""
+
+#: c/c-decl.cc:8097 c/c-decl.cc:8108 c/c-decl.cc:8111
+#, gcc-internal-format
+msgid "invalid storage class for function %qE"
+msgstr ""
+
+#: c/c-decl.cc:8168
+#, gcc-internal-format
+msgid "cannot inline function %<main%>"
+msgstr ""
+
+#: c/c-decl.cc:8170
+#, gcc-internal-format
+msgid "%<main%> declared %<_Noreturn%>"
+msgstr ""
+
+#: c/c-decl.cc:8181
+#, gcc-internal-format
+msgid "ISO C99 does not support %<_Noreturn%>"
+msgstr ""
+
+#: c/c-decl.cc:8184
+#, gcc-internal-format
+msgid "ISO C90 does not support %<_Noreturn%>"
+msgstr ""
+
+#: c/c-decl.cc:8206
+#, gcc-internal-format
+msgid "function previously declared %<static%> redeclared %<extern%>"
+msgstr ""
+
+#: c/c-decl.cc:8224
+#, gcc-internal-format
+msgid "%<constexpr%> object has variably modified type"
+msgstr ""
+
+#: c/c-decl.cc:8228 c/c-parser.cc:12277
+#, gcc-internal-format
+msgid "invalid qualifiers for %<constexpr%> object"
+msgstr ""
+
+#: c/c-decl.cc:8234 c/c-parser.cc:12280
+#, gcc-internal-format
+msgid "invalid qualifiers for field of %<constexpr%> object"
+msgstr ""
+
+#: c/c-decl.cc:8260
+#, gcc-internal-format
+msgid "variable previously declared %<static%> redeclared %<extern%>"
+msgstr ""
+
+#: c/c-decl.cc:8272
+#, gcc-internal-format
+msgid "variable %q+D declared %<inline%>"
+msgstr ""
+
+#: c/c-decl.cc:8274
+#, gcc-internal-format
+msgid "variable %q+D declared %<_Noreturn%>"
+msgstr ""
+
+#: c/c-decl.cc:8309
+#, gcc-internal-format
+msgid "non-nested function with variably modified type"
+msgstr ""
+
+#: c/c-decl.cc:8311
+#, gcc-internal-format
+msgid "object with variably modified type must have no linkage"
+msgstr ""
+
+#: c/c-decl.cc:8419 c/c-decl.cc:10635
+#, gcc-internal-format
+msgid "function declaration isn%'t a prototype"
+msgstr ""
+
+#: c/c-decl.cc:8431
+#, gcc-internal-format
+msgid "parameter names (without types) in function declaration"
+msgstr ""
+
+#: c/c-decl.cc:8476
+#, gcc-internal-format
+msgid "parameter %u (%q+D) has incomplete type"
+msgstr ""
+
+#: c/c-decl.cc:8480
+#, gcc-internal-format, gfc-internal-format
+msgid "parameter %u has incomplete type"
+msgstr ""
+
+#: c/c-decl.cc:8491
+#, gcc-internal-format
+msgid "parameter %u (%q+D) has void type"
+msgstr ""
+
+#: c/c-decl.cc:8495
+#, gcc-internal-format, gfc-internal-format
+msgid "parameter %u has void type"
+msgstr ""
+
+#: c/c-decl.cc:8570
+#, gcc-internal-format
+msgid "%<void%> as only parameter may not be qualified"
+msgstr ""
+
+#: c/c-decl.cc:8574 c/c-decl.cc:8610
+#, gcc-internal-format
+msgid "%<void%> must be the only parameter"
+msgstr ""
+
+#: c/c-decl.cc:8604
+#, gcc-internal-format
+msgid "parameter %q+D has just a forward declaration"
+msgstr ""
+
+#: c/c-decl.cc:8652
+#, gcc-internal-format
+msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
+msgstr ""
+
+#: c/c-decl.cc:8659
+#, gcc-internal-format, gfc-internal-format
+msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
+msgstr ""
+
+#: c/c-decl.cc:8785
+#, gcc-internal-format
+msgid "enum type defined here"
+msgstr ""
+
+#: c/c-decl.cc:8791
+#, gcc-internal-format
+msgid "struct defined here"
+msgstr ""
+
+#: c/c-decl.cc:8797
+#, gcc-internal-format
+msgid "union defined here"
+msgstr ""
+
+#: c/c-decl.cc:8890
+#, gcc-internal-format
+msgid "redefinition of %<union %E%>"
+msgstr ""
+
+#: c/c-decl.cc:8892
+#, gcc-internal-format
+msgid "redefinition of %<struct %E%>"
+msgstr ""
+
+#: c/c-decl.cc:8901
+#, gcc-internal-format
+msgid "nested redefinition of %<union %E%>"
+msgstr ""
+
+#: c/c-decl.cc:8903
+#, gcc-internal-format
+msgid "nested redefinition of %<struct %E%>"
+msgstr ""
+
+#: c/c-decl.cc:8935 c/c-decl.cc:10013
+#, gcc-internal-format
+msgid "defining type in %qs expression is invalid in C++"
+msgstr ""
+
+#: c/c-decl.cc:8941 c/c-decl.cc:10019
+#, gcc-internal-format
+msgid "%qT defined in underspecified object initializer"
+msgstr ""
+
+#: c/c-decl.cc:9005 cp/decl.cc:5670
+#, gcc-internal-format
+msgid "declaration does not declare anything"
+msgstr ""
+
+#: c/c-decl.cc:9010
+#, gcc-internal-format
+msgid "ISO C99 doesn%'t support unnamed structs/unions"
+msgstr ""
+
+#: c/c-decl.cc:9013
+#, gcc-internal-format
+msgid "ISO C90 doesn%'t support unnamed structs/unions"
+msgstr ""
+
+#: c/c-decl.cc:9106 c/c-decl.cc:9124 c/c-decl.cc:9185
+#, gcc-internal-format
+msgid "duplicate member %q+D"
+msgstr ""
+
+#: c/c-decl.cc:9211
+#, gcc-internal-format
+msgid "empty struct has size 0 in C, size 1 in C++"
+msgstr ""
+
+#: c/c-decl.cc:9214
+#, gcc-internal-format
+msgid "empty union has size 0 in C, size 1 in C++"
+msgstr ""
+
+#: c/c-decl.cc:9469
+#, gcc-internal-format
+msgid "union has no named members"
+msgstr ""
+
+#: c/c-decl.cc:9471
+#, gcc-internal-format
+msgid "union has no members"
+msgstr ""
+
+#: c/c-decl.cc:9476
+#, gcc-internal-format
+msgid "struct has no named members"
+msgstr ""
+
+#: c/c-decl.cc:9478
+#, gcc-internal-format
+msgid "struct has no members"
+msgstr ""
+
+#: c/c-decl.cc:9556 cp/decl.cc:14592
+#, gcc-internal-format
+msgid "flexible array member in union"
+msgstr ""
+
+#: c/c-decl.cc:9562
+#, gcc-internal-format
+msgid "flexible array member not at end of struct"
+msgstr ""
+
+#: c/c-decl.cc:9568
+#, gcc-internal-format
+msgid "flexible array member in a struct with no named members"
+msgstr ""
+
+#: c/c-decl.cc:9599
+#, gcc-internal-format
+msgid "structure containing a flexible array member is not at the end of another structure"
+msgstr ""
+
+#: c/c-decl.cc:9622
+#, gcc-internal-format
+msgid "type %qT is too large"
+msgstr ""
+
+#: c/c-decl.cc:9686
+#, gcc-internal-format
+msgid "type punning toggles scalar storage order"
+msgstr ""
+
+#: c/c-decl.cc:9753
+#, gcc-internal-format
+msgid "union cannot be made transparent"
+msgstr ""
+
+#: c/c-decl.cc:9766
+#, gcc-internal-format
+msgid "redefinition of struct or union %qT with variably modified type"
+msgstr ""
+
+#: c/c-decl.cc:9769
+#, gcc-internal-format
+msgid "redefinition of struct or union %qT"
+msgstr ""
+
+#: c/c-decl.cc:9938
+#, gcc-internal-format
+msgid "nested redefinition of %<enum %E%>"
+msgstr ""
+
+#: c/c-decl.cc:9983
+#, gcc-internal-format
+msgid "redeclaration of %<enum %E%>"
+msgstr ""
+
+#: c/c-decl.cc:9995
+#, gcc-internal-format
+msgid "%<enum%> declared with but defined without fixed underlying type"
+msgstr ""
+
+#: c/c-decl.cc:10082 cp/decl.cc:17221 m2/gm2-gcc/m2type.cc:2073
+#, gcc-internal-format
+msgid "specified mode too small for enumerated values"
+msgstr ""
+
+#: c/c-decl.cc:10101
+#, gcc-internal-format
+msgid "enumeration values exceed range of largest integer"
+msgstr ""
+
+#: c/c-decl.cc:10110
+#, gcc-internal-format
+msgid "enumeration values exceed range of %qs"
+msgstr ""
+
+#: c/c-decl.cc:10219
+#, gcc-internal-format
+msgid "conflicting redefinition of enum %qT"
+msgstr ""
+
+#: c/c-decl.cc:10251 c/c-decl.cc:10267
+#, gcc-internal-format
+msgid "enumerator value for %qE is not an integer constant"
+msgstr ""
+
+#: c/c-decl.cc:10262
+#, gcc-internal-format
+msgid "enumerator value for %qE is not an integer constant expression"
+msgstr ""
+
+#: c/c-decl.cc:10286
+#, gcc-internal-format
+msgid "overflow in enumeration values"
+msgstr ""
+
+#: c/c-decl.cc:10293
+#, gcc-internal-format
+msgid "enumerator value outside the range of underlying type"
+msgstr ""
+
+#: c/c-decl.cc:10321
+#, gcc-internal-format
+msgid "enumerator value outside the range of %qs"
+msgstr ""
+
+#: c/c-decl.cc:10327
+#, gcc-internal-format
+msgid "ISO C restricts enumerator values to range of %<int%> before C23"
+msgstr ""
+
+#: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
+#, gcc-internal-format
+msgid "inline function %qD given attribute %qs"
+msgstr ""
+
+#: c/c-decl.cc:10546
+#, gcc-internal-format
+msgid "return type is an incomplete type"
+msgstr ""
+
+#: c/c-decl.cc:10558
+#, gcc-internal-format
+msgid "return type defaults to %<int%>"
+msgstr ""
+
+#: c/c-decl.cc:10586
+#, gcc-internal-format
+msgid "%q+D defined as variadic function without prototype"
+msgstr ""
+
+#: c/c-decl.cc:10644
+#, gcc-internal-format
+msgid "no previous prototype for %qD"
+msgstr ""
+
+#: c/c-decl.cc:10653
+#, gcc-internal-format
+msgid "%qD was used with no prototype before its definition"
+msgstr ""
+
+#: c/c-decl.cc:10671
+#, gcc-internal-format
+msgid "%qD was used with no declaration before its definition"
+msgstr ""
+
+#: c/c-decl.cc:10690
+#, gcc-internal-format
+msgid "return type of %qD is not %<int%>"
+msgstr ""
+
+#: c/c-decl.cc:10692
+#, gcc-internal-format
+msgid "%<_Atomic%>-qualified return type of %qD"
+msgstr ""
+
+#: c/c-decl.cc:10699
+#, gcc-internal-format
+msgid "%qD is normally a non-static function"
+msgstr ""
+
+#: c/c-decl.cc:10750
+#, gcc-internal-format
+msgid "old-style parameter declarations in prototyped function definition"
+msgstr ""
+
+#: c/c-decl.cc:10765
+#, gcc-internal-format
+msgid "traditional C rejects ISO C style function definitions"
+msgstr ""
+
+#: c/c-decl.cc:10782
+#, gcc-internal-format
+msgid "ISO C does not support omitting parameter names in function definitions before C23"
+msgstr ""
+
+#: c/c-decl.cc:10822 c/c-decl.cc:10826
+#, gcc-internal-format
+msgid "old-style function definition"
+msgstr ""
+
+#: c/c-decl.cc:10839
+#, gcc-internal-format
+msgid "parameter name missing from parameter list"
+msgstr ""
+
+#: c/c-decl.cc:10855
+#, gcc-internal-format
+msgid "%qD declared as a non-parameter"
+msgstr ""
+
+#: c/c-decl.cc:10863
+#, gcc-internal-format
+msgid "multiple parameters named %qD"
+msgstr ""
+
+#: c/c-decl.cc:10872
+#, gcc-internal-format
+msgid "parameter %qD declared with void type"
+msgstr ""
+
+#: c/c-decl.cc:10901 c/c-decl.cc:10906
+#, gcc-internal-format
+msgid "type of %qD defaults to %<int%>"
+msgstr ""
+
+#: c/c-decl.cc:10926
+#, gcc-internal-format
+msgid "parameter %qD has incomplete type"
+msgstr ""
+
+#: c/c-decl.cc:10933
+#, gcc-internal-format
+msgid "declaration for parameter %qD but no such parameter"
+msgstr ""
+
+#: c/c-decl.cc:10986
+#, gcc-internal-format
+msgid "number of arguments doesn%'t match built-in prototype"
+msgstr ""
+
+#: c/c-decl.cc:10997
+#, gcc-internal-format
+msgid "number of arguments doesn%'t match prototype"
+msgstr ""
+
+#: c/c-decl.cc:11000 c/c-decl.cc:11047 c/c-decl.cc:11061
+#, gcc-internal-format
+msgid "prototype declaration"
+msgstr ""
+
+#: c/c-decl.cc:11039
+#, gcc-internal-format
+msgid "promoted argument %qD doesn%'t match built-in prototype"
+msgstr ""
+
+#: c/c-decl.cc:11044
+#, gcc-internal-format
+msgid "promoted argument %qD doesn%'t match prototype"
+msgstr ""
+
+#: c/c-decl.cc:11054
+#, gcc-internal-format
+msgid "argument %qD doesn%'t match built-in prototype"
+msgstr ""
+
+#: c/c-decl.cc:11059
+#, gcc-internal-format
+msgid "argument %qD doesn%'t match prototype"
+msgstr ""
+
+#: c/c-decl.cc:11317 cp/decl.cc:18743
+#, gcc-internal-format
+msgid "no return statement in function returning non-void"
+msgstr ""
+
+#: c/c-decl.cc:11336 cp/decl.cc:18814
+#, gcc-internal-format
+msgid "parameter %qD set but not used"
+msgstr ""
+
+#: c/c-decl.cc:11433
+#, gcc-internal-format
+msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
+msgstr ""
+
+#: c/c-decl.cc:11438
+#, gcc-internal-format
+msgid "use option %<-std=c99%>, %<-std=gnu99%>, %<-std=c11%> or %<-std=gnu11%> to compile your code"
+msgstr ""
+
+#: c/c-decl.cc:11445
+#, gcc-internal-format
+msgid "ISO C90 does not support %<for%> loop initial declarations"
+msgstr ""
+
+#: c/c-decl.cc:11479
+#, gcc-internal-format
+msgid "declaration of static variable %qD in %<for%> loop initial declaration"
+msgstr ""
+
+#: c/c-decl.cc:11483
+#, gcc-internal-format
+msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
+msgstr ""
+
+#: c/c-decl.cc:11490
+#, gcc-internal-format
+msgid "%<struct %E%> declared in %<for%> loop initial declaration"
+msgstr ""
+
+#: c/c-decl.cc:11495
+#, gcc-internal-format
+msgid "%<union %E%> declared in %<for%> loop initial declaration"
+msgstr ""
+
+#: c/c-decl.cc:11501
+#, gcc-internal-format
+msgid "%<enum %E%> declared in %<for%> loop initial declaration"
+msgstr ""
+
+#: c/c-decl.cc:11505
+#, gcc-internal-format
+msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
+msgstr ""
+
+#: c/c-decl.cc:11792
+#, gcc-internal-format
+msgid "incompatible address space qualifiers %qs and %qs"
+msgstr ""
+
+#: c/c-decl.cc:11851 c/c-decl.cc:11858
+#, gcc-internal-format
+msgid "duplicate %qE declaration specifier"
+msgstr ""
+
+#: c/c-decl.cc:11886 c/c-decl.cc:12964
+#, gcc-internal-format
+msgid "multiple storage classes in declaration specifiers"
+msgstr ""
+
+#: c/c-decl.cc:11888
+#, gcc-internal-format
+msgid "%qs used with %<auto%>"
+msgstr ""
+
+#. auto may only be used with another storage class specifier,
+#. such as constexpr, if the type is inferred.
+#: c/c-decl.cc:11893
+#, gcc-internal-format
+msgid "%<auto%> used with %<constexpr%>"
+msgstr ""
+
+#: c/c-decl.cc:11906 c/c-decl.cc:12306 c/c-decl.cc:12759
+#, gcc-internal-format
+msgid "two or more data types in declaration specifiers"
+msgstr ""
+
+#: c/c-decl.cc:11918 cp/parser.cc:34268
+#, gcc-internal-format
+msgid "%<long long long%> is too long for GCC"
+msgstr ""
+
+#: c/c-decl.cc:11931
+#, gcc-internal-format
+msgid "ISO C90 does not support %<long long%>"
+msgstr ""
+
+#: c/c-decl.cc:12168 c/c-parser.cc:11619
+#, gcc-internal-format
+msgid "ISO C90 does not support complex types"
+msgstr ""
+
+#: c/c-decl.cc:12218
+#, gcc-internal-format
+msgid "ISO C does not support saturating types"
+msgstr ""
+
+#: c/c-decl.cc:12293 c/c-decl.cc:12899 c/c-decl.cc:12958
+#, gcc-internal-format
+msgid "duplicate %qE"
+msgstr ""
+
+#: c/c-decl.cc:12353
+#, gcc-internal-format
+msgid "ISO C does not support %<__int%d%> types"
+msgstr ""
+
+#: c/c-decl.cc:12375
+#, gcc-internal-format
+msgid "%<__int%d%> is not supported on this target"
+msgstr ""
+
+#: c/c-decl.cc:12418
+#, gcc-internal-format
+msgid "ISO C90 does not support boolean types"
+msgstr ""
+
+#: c/c-decl.cc:12537
+#, gcc-internal-format
+msgid "ISO C does not support the %<_Float%d%s%> type before C23"
+msgstr ""
+
+#: c/c-decl.cc:12588 cp/parser.cc:20288
+#, gcc-internal-format
+msgid "%<_Float%d%s%> is not supported on this target"
+msgstr ""
+
+#: c/c-decl.cc:12659
+#, gcc-internal-format
+msgid "ISO C does not support decimal floating-point before C23"
+msgstr ""
+
+#: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
+#, gcc-internal-format
+msgid "fixed-point types not supported for this target"
+msgstr ""
+
+#: c/c-decl.cc:12685
+#, gcc-internal-format
+msgid "ISO C does not support fixed-point types"
+msgstr ""
+
+#: c/c-decl.cc:12714
+#, gcc-internal-format
+msgid "%<_BitInt%> argument is not an integer constant expression"
+msgstr ""
+
+#: c/c-decl.cc:12720
+#, gcc-internal-format
+msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
+msgstr ""
+
+#: c/c-decl.cc:12727
+#, gcc-internal-format
+msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
+msgstr ""
+
+#: c/c-decl.cc:12775
+#, gcc-internal-format
+msgid "C++ lookup of %qD would return a field, not a type"
+msgstr ""
+
+#: c/c-decl.cc:12788
+#, gcc-internal-format
+msgid "%qE fails to be a typedef or built in type"
+msgstr ""
+
+#: c/c-decl.cc:12843
+#, gcc-internal-format
+msgid "%qE is not at beginning of declaration"
+msgstr ""
+
+#. auto may only be used with another storage class specifier,
+#. such as constexpr, if the type is inferred.
+#: c/c-decl.cc:12864 c/c-decl.cc:12941
+#, gcc-internal-format
+msgid "%qE used with %<auto%>"
+msgstr ""
+
+#: c/c-decl.cc:12866
+#, gcc-internal-format
+msgid "%qE used with %<register%>"
+msgstr ""
+
+#: c/c-decl.cc:12868 c/c-decl.cc:12937
+#, gcc-internal-format
+msgid "%qE used with %<typedef%>"
+msgstr ""
+
+#: c/c-decl.cc:12870 c/c-decl.cc:12907
+#, gcc-internal-format
+msgid "%qE used with %<constexpr%>"
+msgstr ""
+
+#: c/c-decl.cc:12884 c/c-parser.cc:3100 c/c-parser.cc:4427 c/c-parser.cc:9960
+#, gcc-internal-format
+msgid "ISO C99 does not support %qE"
+msgstr ""
+
+#: c/c-decl.cc:12887 c/c-parser.cc:3103 c/c-parser.cc:4430 c/c-parser.cc:9963
+#, gcc-internal-format
+msgid "ISO C90 does not support %qE"
+msgstr ""
+
+#: c/c-decl.cc:12913
+#, gcc-internal-format
+msgid "%<__thread%> before %<extern%>"
+msgstr ""
+
+#: c/c-decl.cc:12922
+#, gcc-internal-format
+msgid "%<__thread%> before %<static%>"
+msgstr ""
+
+#: c/c-decl.cc:12928
+#, gcc-internal-format
+msgid "%<typedef%> used with %<auto%>"
+msgstr ""
+
+#: c/c-decl.cc:12935
+#, gcc-internal-format
+msgid "%qE used with %<extern%>"
+msgstr ""
+
+#: c/c-decl.cc:12943
+#, gcc-internal-format
+msgid "%qE used with %qs"
+msgstr ""
+
+#: c/c-decl.cc:12956
+#, gcc-internal-format
+msgid "duplicate %<_Thread_local%> or %<__thread%>"
+msgstr ""
+
+#: c/c-decl.cc:12972
+#, gcc-internal-format
+msgid "%qs used with %qE"
+msgstr ""
+
+#: c/c-decl.cc:12980
+#, gcc-internal-format
+msgid "%<constexpr%> used with %qE"
+msgstr ""
+
+#: c/c-decl.cc:13057
+#, gcc-internal-format
+msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
+msgstr ""
+
+#: c/c-decl.cc:13072
+#, gcc-internal-format
+msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
+msgstr ""
+
+#: c/c-decl.cc:13083
+#, gcc-internal-format
+msgid "ISO C does not support %<auto%> type deduction before C23"
+msgstr ""
+
+#: c/c-decl.cc:13112
+#, gcc-internal-format
+msgid "%<__auto_type%> followed by %<[[]]%> attributes"
+msgstr ""
+
+#: c/c-decl.cc:13138 c/c-decl.cc:13154 c/c-decl.cc:13180
+#, gcc-internal-format
+msgid "ISO C does not support complex integer types"
+msgstr ""
+
+#: c/c-decl.cc:13323
+#, gcc-internal-format
+msgid "%<signed _BitInt%> argument must be at least 2"
+msgstr ""
+
+#: c/c-decl.cc:13332
+#, gcc-internal-format
+msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
+msgstr ""
+
+#: c/c-decl.cc:13631 cp/semantics.cc:6387
+#, gcc-internal-format
+msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
+msgstr ""
+
+#: c/c-decl.cc:13635 cp/semantics.cc:6391
+#, gcc-internal-format
+msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
+msgstr ""
+
+#: c/c-fold.cc:389 c/c-typeck.cc:12832 cp/typeck.cc:5732
+#, gcc-internal-format
+msgid "left shift of negative value"
+msgstr ""
+
+#: c/c-fold.cc:399 c/c-typeck.cc:12841 cp/typeck.cc:5740
+#, gcc-internal-format
+msgid "left shift count is negative"
+msgstr ""
+
+#: c/c-fold.cc:400 c/c-typeck.cc:12768 cp/typeck.cc:5679
+#, gcc-internal-format
+msgid "right shift count is negative"
+msgstr ""
+
+#: c/c-fold.cc:409 c/c-typeck.cc:12860 cp/typeck.cc:5748
+#, gcc-internal-format
+msgid "left shift count >= width of type"
+msgstr ""
+
+#: c/c-fold.cc:410 c/c-typeck.cc:12792 cp/typeck.cc:5690
+#, gcc-internal-format
+msgid "right shift count >= width of type"
+msgstr ""
+
+#: c/c-fold.cc:417 c/c-typeck.cc:12852
+#, gcc-internal-format
+msgid "left shift count >= width of vector element"
+msgstr ""
+
+#: c/c-fold.cc:418 c/c-typeck.cc:12779
+#, gcc-internal-format
+msgid "right shift count >= width of vector element"
+msgstr ""
+
+#: c/c-parser.cc:353
+#, gcc-internal-format
+msgid "identifier %qE conflicts with C++ keyword"
+msgstr ""
+
+#: c/c-parser.cc:1036 cp/parser.cc:3239
+#, gcc-internal-format
+msgid "version control conflict marker in file"
+msgstr ""
+
+#: c/c-parser.cc:1257 cp/parser.cc:3320
+#, gcc-internal-format
+msgid "to match this %qs"
+msgstr ""
+
+#: c/c-parser.cc:1409 cp/parser.cc:34505
+#, gcc-internal-format
+msgid "expected end of line"
+msgstr ""
+
+#: c/c-parser.cc:1891
+#, gcc-internal-format
+msgid "ISO C forbids an empty translation unit"
+msgstr ""
+
+#: c/c-parser.cc:1917 c/c-parser.cc:1926 c/c-parser.cc:25403 cp/parser.cc:49091
+#: cp/semantics.cc:3635 cp/semantics.cc:3644
+#, gcc-internal-format
+msgid "%qs without corresponding %qs"
+msgstr ""
+
+#: c/c-parser.cc:2022 c/c-parser.cc:13395
+#, gcc-internal-format
+msgid "ISO C does not allow extra %<;%> outside of a function"
+msgstr ""
+
+#: c/c-parser.cc:2105
+#, gcc-internal-format
+msgid "%<assume%> attribute at top level"
+msgstr ""
+
+#: c/c-parser.cc:2255
+#, gcc-internal-format
+msgid "unknown type name %qE; use %<struct%> keyword to refer to the type"
+msgstr ""
+
+#: c/c-parser.cc:2263
+#, gcc-internal-format
+msgid "unknown type name %qE; use %<union%> keyword to refer to the type"
+msgstr ""
+
+#: c/c-parser.cc:2271
+#, gcc-internal-format
+msgid "unknown type name %qE; use %<enum%> keyword to refer to the type"
+msgstr ""
+
+#: c/c-parser.cc:2284 c/c-parser.cc:3368 c/c-parser.cc:5034
+#, gcc-internal-format
+msgid "unknown type name %qE; did you mean %qs?"
+msgstr ""
+
+#: c/c-parser.cc:2288 c/c-parser.cc:3372 c/c-parser.cc:5038
+#, gcc-internal-format
+msgid "unknown type name %qE"
+msgstr ""
+
+#: c/c-parser.cc:2315 c/c-parser.cc:14755 c/c-parser.cc:23033
+#: c/c-parser.cc:23632 c/c-parser.cc:24218 cp/parser.cc:46429
+#: cp/parser.cc:51177
+#, gcc-internal-format
+msgid "expected declaration specifiers"
+msgstr ""
+
+#: c/c-parser.cc:2339
+#, gcc-internal-format
+msgid "%qT declared in underspecified object declaration"
+msgstr ""
+
+#: c/c-parser.cc:2344
+#, gcc-internal-format
+msgid "%qT defined in underspecified object declaration"
+msgstr ""
+
+#: c/c-parser.cc:2379
+#, gcc-internal-format
+msgid "%qs in empty declaration"
+msgstr ""
+
+#: c/c-parser.cc:2393
+#, gcc-internal-format
+msgid "%<fallthrough%> attribute at top level"
+msgstr ""
+
+#: c/c-parser.cc:2421 c/c-parser.cc:4230
+#, gcc-internal-format
+msgid "expected %<;%>, identifier or %<(%>"
+msgstr ""
+
+#: c/c-parser.cc:2439 cp/parser.cc:36759 cp/parser.cc:36831
+#, gcc-internal-format
+msgid "prefix attributes are ignored for methods"
+msgstr ""
+
+#: c/c-parser.cc:2474
+#, gcc-internal-format
+msgid "prefix attributes are ignored for implementations"
+msgstr ""
+
+#: c/c-parser.cc:2495
+#, gcc-internal-format
+msgid "unexpected attribute"
+msgstr ""
+
+#: c/c-parser.cc:2505 c/c-parser.cc:7725 cp/parser.cc:12966 cp/parser.cc:13190
+#, gcc-internal-format
+msgid "%<fallthrough%> attribute not followed by %<;%>"
+msgstr ""
+
+#: c/c-parser.cc:2508 c/c-parser.cc:7708 cp/cp-gimplify.cc:3657
+#, gcc-internal-format
+msgid "%<assume%> attribute not followed by %<;%>"
+msgstr ""
+
+#: c/c-parser.cc:2555
+#, gcc-internal-format
+msgid "%<__auto_type%> requires a plain identifier as declarator"
+msgstr ""
+
+#: c/c-parser.cc:2568
+#, gcc-internal-format
+msgid "%<auto%> requires a plain identifier, possibly with attributes, as declarator"
+msgstr ""
+
+#: c/c-parser.cc:2594
+#, gcc-internal-format
+msgid "data definition has no type or storage class"
+msgstr ""
+
+#. This means there is an attribute specifier after
+#. the declarator in a function definition.  Provide
+#. some more information for the user.
+#: c/c-parser.cc:2609
+#, gcc-internal-format
+msgid "attributes should be specified before the declarator in a function definition"
+msgstr ""
+
+#: c/c-parser.cc:2648
+#, gcc-internal-format
+msgid "%<__auto_type%> used with a bit-field initializer"
+msgstr ""
+
+#: c/c-parser.cc:2758 c/c-parser.cc:2894
+#, gcc-internal-format
+msgid "%qs requires an initialized data declaration"
+msgstr ""
+
+#: c/c-parser.cc:2857
+#, gcc-internal-format
+msgid "%qs may only be used with a single declarator"
+msgstr ""
+
+#: c/c-parser.cc:2886 cp/parser.cc:16007
+#, gcc-internal-format
+msgid "expected %<,%> or %<;%>"
+msgstr ""
+
+#. This can appear in many cases looking nothing like a
+#. function definition, so we don't give a more specific
+#. error suggesting there was one.
+#: c/c-parser.cc:2901 c/c-parser.cc:2942
+#, gcc-internal-format
+msgid "expected %<=%>, %<,%>, %<;%>, %<asm%> or %<__attribute__%>"
+msgstr ""
+
+#: c/c-parser.cc:2909
+#, gcc-internal-format
+msgid "ISO C forbids nested functions"
+msgstr ""
+
+#: c/c-parser.cc:3126 c/c-parser.cc:8887 c/c-parser.cc:14828
+#, gcc-internal-format
+msgid "expected string literal"
+msgstr ""
+
+#: c/c-parser.cc:3135
+#, gcc-internal-format
+msgid "ISO C11 does not support omitting the string in %qE"
+msgstr ""
+
+#: c/c-parser.cc:3141
+#, gcc-internal-format
+msgid "expression in static assertion is not an integer"
+msgstr ""
+
+#: c/c-parser.cc:3150
+#, gcc-internal-format
+msgid "expression in static assertion is not an integer constant expression"
+msgstr ""
+
+#: c/c-parser.cc:3155
+#, gcc-internal-format
+msgid "expression in static assertion is not constant"
+msgstr ""
+
+#: c/c-parser.cc:3162
+#, gcc-internal-format
+msgid "static assertion failed: %E"
+msgstr ""
+
+#: c/c-parser.cc:3164 cp/semantics.cc:11749
+#, gcc-internal-format
+msgid "static assertion failed"
+msgstr ""
+
+#: c/c-parser.cc:3543
+#, gcc-internal-format
+msgid "%<_Atomic%> in Objective-C"
+msgstr ""
+
+#: c/c-parser.cc:3546
+#, gcc-internal-format
+msgid "ISO C99 does not support the %<_Atomic%> qualifier"
+msgstr ""
+
+#: c/c-parser.cc:3549
+#, gcc-internal-format
+msgid "ISO C90 does not support the %<_Atomic%> qualifier"
+msgstr ""
+
+#: c/c-parser.cc:3577
+#, gcc-internal-format
+msgid "%<_Atomic%> applied to a qualified type"
+msgstr ""
+
+#: c/c-parser.cc:3607
+#, gcc-internal-format
+msgid "%<__GIMPLE%> only valid with %<-fgimple%>"
+msgstr ""
+
+#: c/c-parser.cc:3699
+#, gcc-internal-format
+msgid "ISO C does not support specifying %<enum%> underlying types before C23"
+msgstr ""
+
+#: c/c-parser.cc:3708
+#, gcc-internal-format
+msgid "%<enum%> declared both with and without fixed underlying type"
+msgstr ""
+
+#: c/c-parser.cc:3731
+#, gcc-internal-format
+msgid "no %<enum%> underlying type specified"
+msgstr ""
+
+#: c/c-parser.cc:3735
+#, gcc-internal-format
+msgid "invalid %<enum%> underlying type"
+msgstr ""
+
+#: c/c-parser.cc:3765
+#, gcc-internal-format
+msgid "%<enum%> underlying type incompatible with previous declaration"
+msgstr ""
+
+#: c/c-parser.cc:3801
+#, gcc-internal-format
+msgid "empty enum is invalid"
+msgstr ""
+
+#: c/c-parser.cc:3805 c/c-parser.cc:4859 c/c-parser.cc:5716 c/c-parser.cc:5733
+#: c/c-parser.cc:6261 c/c-parser.cc:6993 c/c-parser.cc:8754 c/c-parser.cc:8837
+#: c/c-parser.cc:9817 c/c-parser.cc:10134 c/c-parser.cc:10143
+#: c/c-parser.cc:10686 c/c-parser.cc:10876 c/c-parser.cc:10904
+#: c/c-parser.cc:12098 c/c-parser.cc:12671 c/c-parser.cc:12709
+#: c/c-parser.cc:12977 c/c-parser.cc:13028 c/c-parser.cc:13188
+#: c/c-parser.cc:13218 c/c-parser.cc:13226 c/c-parser.cc:13255
+#: c/c-parser.cc:13268 c/c-parser.cc:13574 c/c-parser.cc:13698
+#: c/c-parser.cc:14283 c/c-parser.cc:14336 c/c-parser.cc:14352
+#: c/c-parser.cc:14398 c/c-parser.cc:15386 c/c-parser.cc:15431
+#: c/c-parser.cc:18314 c/c-parser.cc:18451 c/c-parser.cc:19208
+#: c/c-parser.cc:21828 c/c-parser.cc:24696 c/c-parser.cc:24885
+#: c/gimple-parser.cc:1895 c/gimple-parser.cc:1942 cp/parser.cc:9524
+#: cp/parser.cc:34508 cp/parser.cc:37736 cp/parser.cc:40863 cp/parser.cc:41055
+#: cp/parser.cc:48024 cp/parser.cc:50443
+#, gcc-internal-format
+msgid "expected identifier"
+msgstr ""
+
+#: c/c-parser.cc:3850 cp/parser.cc:21836
+#, gcc-internal-format
+msgid "comma at end of enumerator list"
+msgstr ""
+
+#: c/c-parser.cc:3856 go/gofrontend/embed.cc:424
+#, gcc-internal-format
+msgid "expected %<,%> or %<}%>"
+msgstr ""
+
+#: c/c-parser.cc:3899
+#, gcc-internal-format
+msgid "ISO C forbids forward references to %<enum%> types"
+msgstr ""
+
+#: c/c-parser.cc:4024
+#, gcc-internal-format
+msgid "expected class name"
+msgstr ""
+
+#: c/c-parser.cc:4046
+#, gcc-internal-format
+msgid "extra semicolon in struct or union specified"
+msgstr ""
+
+#: c/c-parser.cc:4075
+#, gcc-internal-format
+msgid "no semicolon at end of struct or union"
+msgstr ""
+
+#: c/c-parser.cc:4192 c/c-parser.cc:6027
+#, gcc-internal-format
+msgid "expected specifier-qualifier-list"
+msgstr ""
+
+#: c/c-parser.cc:4203
+#, gcc-internal-format
+msgid "ISO C forbids member declarations with no members"
+msgstr ""
+
+#: c/c-parser.cc:4297
+#, gcc-internal-format
+msgid "expected %<,%>, %<;%> or %<}%>"
+msgstr ""
+
+#: c/c-parser.cc:4304
+#, gcc-internal-format
+msgid "expected %<:%>, %<,%>, %<;%>, %<}%> or %<__attribute__%>"
+msgstr ""
+
+#: c/c-parser.cc:4376
+#, gcc-internal-format
+msgid "%<typeof%> applied to a bit-field"
+msgstr ""
+
+#: c/c-parser.cc:4687
+#, gcc-internal-format
+msgid "expected identifier or %<(%>"
+msgstr ""
+
+#: c/c-parser.cc:4920
+#, gcc-internal-format
+msgid "ISO C requires a named argument before %<...%> before C23"
+msgstr ""
+
+#: c/c-parser.cc:5045
+#, gcc-internal-format
+msgid "expected declaration specifiers or %<...%>"
+msgstr ""
+
+#: c/c-parser.cc:5274
+#, gcc-internal-format
+msgid "parentheses must be omitted if attribute argument list is empty"
+msgstr ""
+
+#: c/c-parser.cc:5562 cp/parser.cc:29829
+#, gcc-internal-format
+msgid "expected OpenMP directive name"
+msgstr ""
+
+#: c/c-parser.cc:5609 cp/parser.cc:29885
+#, gcc-internal-format
+msgid "expected %<directive%> or %<sequence%>"
+msgstr ""
+
+#: c/c-parser.cc:5754 cp/parser.cc:30054
+#, gcc-internal-format
+msgid "%<omp::%E%> attribute requires argument"
+msgstr ""
+
+#: c/c-parser.cc:5770 cp/parser.cc:30070
+#, gcc-internal-format
+msgid "%qE attribute does not take any arguments"
+msgstr ""
+
+#: c/c-parser.cc:5891
+#, gcc-internal-format
+msgid "ISO C does not support %<[[]]%> attributes before C23"
+msgstr ""
+
+#: c/c-parser.cc:6104 c/c-parser.cc:6167 c/c-typeck.cc:8824
+#, gcc-internal-format
+msgid "variable-sized object may not be initialized except with an empty initializer"
+msgstr ""
+
+#: c/c-parser.cc:6161
+#, gcc-internal-format
+msgid "ISO C forbids empty initializer braces before C23"
+msgstr ""
+
+#: c/c-parser.cc:6225
+#, gcc-internal-format
+msgid "obsolete use of designated initializer with %<:%>"
+msgstr ""
+
+#: c/c-parser.cc:6381
+#, gcc-internal-format
+msgid "ISO C forbids specifying range of elements to initialize"
+msgstr ""
+
+#: c/c-parser.cc:6393
+#, gcc-internal-format
+msgid "ISO C90 forbids specifying subobject to initialize"
+msgstr ""
+
+#: c/c-parser.cc:6401
+#, gcc-internal-format
+msgid "obsolete use of designated initializer without %<=%>"
+msgstr ""
+
+#: c/c-parser.cc:6565 cp/parser.cc:13308
+#, gcc-internal-format
+msgid "inner loops must be perfectly nested in %<#pragma acc loop%>"
+msgstr ""
+
+#: c/c-parser.cc:6572 cp/parser.cc:13315
+#, gcc-internal-format
+msgid "inner loops must be perfectly nested with %<ordered%> clause"
+msgstr ""
+
+#: c/c-parser.cc:6579 cp/parser.cc:13322
+#, gcc-internal-format
+msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause"
+msgstr ""
+
+#: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
+#: cp/parser.cc:48620
+#, gcc-internal-format
+msgid "mixing OpenMP directives with attribute and pragma syntax on the same statement"
+msgstr ""
+
+#: c/c-parser.cc:6644 cp/parser.cc:12248
+#, gcc-internal-format
+msgid "OpenMP %<omp::decl%> attribute on a statement"
+msgstr ""
+
+#: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
+#: cp/parser.cc:48600 cp/parser.cc:48740
+#, gcc-internal-format
+msgid "unknown OpenMP directive name in %qs attribute argument"
+msgstr ""
+
+#: c/c-parser.cc:6760 cp/parser.cc:12359
+#, gcc-internal-format
+msgid "OpenMP construct among %<omp::directive%> attributes requires all %<omp::directive%> attributes on the same statement to be in the same %<omp::sequence%>"
+msgstr ""
+
+#: c/c-parser.cc:6768 cp/parser.cc:12367
+#, gcc-internal-format
+msgid "multiple OpenMP standalone directives among %<omp::directive%> attributes must be all within the same %<omp::sequence%>"
+msgstr ""
+
+#: c/c-parser.cc:6780 cp/parser.cc:12379
+#, gcc-internal-format
+msgid "standalone OpenMP directives in %<omp::directive%> attribute can only appear on an empty statement"
+msgstr ""
+
+#: c/c-parser.cc:6899 cp/parser.cc:12509
+#, gcc-internal-format
+msgid "mixing OpenMP directives with attribute and pragma syntax on the same declaration"
+msgstr ""
+
+#: c/c-parser.cc:7008
+#, gcc-internal-format
+msgid "ISO C forbids label declarations"
+msgstr ""
+
+#: c/c-parser.cc:7014 c/c-parser.cc:7195 c/c-parser.cc:7220
+#: c/gimple-parser.cc:424
+#, gcc-internal-format
+msgid "expected declaration or statement"
+msgstr ""
+
+#: c/c-parser.cc:7124
+#, gcc-internal-format
+msgid "a label can only be part of a statement and a declaration is not a statement"
+msgstr ""
+
+#: c/c-parser.cc:7144 c/c-parser.cc:7186
+#, gcc-internal-format
+msgid "ISO C90 forbids mixed declarations and code"
+msgstr ""
+
+#: c/c-parser.cc:7228
+#, gcc-internal-format
+msgid "expected %<}%> before %<else%>"
+msgstr ""
+
+#: c/c-parser.cc:7233 cp/parser.cc:13369
+#, gcc-internal-format
+msgid "%<else%> without a previous %<if%>"
+msgstr ""
+
+#: c/c-parser.cc:7264
+#, gcc-internal-format
+msgid "label at end of compound statement"
+msgstr ""
+
+#. Avoid infinite loop in error recovery:
+#. c_parser_skip_until_found stops at a closing nesting
+#. delimiter without consuming it, but here we need to consume
+#. it to proceed further.
+#: c/c-parser.cc:7313 c/c-parser.cc:7317 c/c-parser.cc:7750
+#: c/gimple-parser.cc:2434 cp/parser.cc:12872
+#, gcc-internal-format
+msgid "expected statement"
+msgstr ""
+
+#: c/c-parser.cc:7372
+#, gcc-internal-format
+msgid "expected %<:%> or %<...%>"
+msgstr ""
+
+#: c/c-parser.cc:7400
+#, gcc-internal-format
+msgid "GNU-style attribute between label and declaration appertains to the label"
+msgstr ""
+
+#: c/c-parser.cc:7632
+#, gcc-internal-format
+msgid "expected identifier or %<*%>"
+msgstr ""
+
+#: c/c-parser.cc:7733
+#, gcc-internal-format
+msgid "only attribute %<fallthrough%> or %<assume%> can be applied to a null statement"
+msgstr ""
+
+#: c/c-parser.cc:7858 cp/parser.cc:14984
+#, gcc-internal-format
+msgid "suggest braces around empty body in an %<if%> statement"
+msgstr ""
+
+#: c/c-parser.cc:7900 cp/parser.cc:14987
+#, gcc-internal-format
+msgid "suggest braces around empty body in an %<else%> statement"
+msgstr ""
+
+#: c/c-parser.cc:8031 cp/parser.cc:13782
+#, gcc-internal-format
+msgid "suggest explicit braces to avoid ambiguous %<else%>"
+msgstr ""
+
+#: c/c-parser.cc:8120 c/c-parser.cc:8185 c/c-parser.cc:8304 cp/parser.cc:14614
+#, gcc-internal-format
+msgid "loop not permitted in intervening code in OpenMP loop body"
+msgstr ""
+
+#: c/c-parser.cc:8193
+#, gcc-internal-format
+msgid "suggest braces around empty body in %<do%> statement"
+msgstr ""
+
+#: c/c-parser.cc:8338 c/c-parser.cc:8370
+#, gcc-internal-format
+msgid "multiple iterating variables in fast enumeration"
+msgstr ""
+
+#: c/c-parser.cc:8393
+#, gcc-internal-format
+msgid "invalid iterating variable in fast enumeration"
+msgstr ""
+
+#: c/c-parser.cc:8417 cp/parser.cc:14069
+#, gcc-internal-format
+msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
+msgstr ""
+
+#: c/c-parser.cc:8423 cp/parser.cc:14075
+#, gcc-internal-format
+msgid "missing loop condition in loop with %<GCC unroll%> pragma"
+msgstr ""
+
+#: c/c-parser.cc:8464
+#, gcc-internal-format
+msgid "missing collection in fast enumeration"
+msgstr ""
+
+#: c/c-parser.cc:8586 c/c-parser.cc:8597 c/c-parser.cc:8608
+#, gcc-internal-format
+msgid "duplicate %<asm%> qualifier %qE"
+msgstr ""
+
+#: c/c-parser.cc:8587 c/c-parser.cc:8598 c/c-parser.cc:8609 cp/parser.cc:22744
+#: cp/parser.cc:22761 cp/parser.cc:22775
+#, gcc-internal-format
+msgid "first seen here"
+msgstr ""
+
+#: c/c-parser.cc:8618
+#, gcc-internal-format
+msgid "%qE is not a valid %<asm%> qualifier"
+msgstr ""
+
+#: c/c-parser.cc:8668
+#, gcc-internal-format
+msgid "expected %<:%> or %<)%>"
+msgstr ""
+
+#: c/c-parser.cc:8967 cp/parser.cc:4706
+#, gcc-internal-format
+msgid "a wide string is invalid in this context"
+msgstr ""
+
+#: c/c-parser.cc:9175
+#, gcc-internal-format
+msgid "ISO C forbids omitting the middle term of a %<?:%> expression"
+msgstr ""
+
+#. Location of the binary operator.
+#. Quiet warning.
+#: c/c-parser.cc:9399 cp/typeck.cc:5511
+#, gcc-internal-format
+msgid "division %<sizeof (%T) / sizeof (%T)%> does not compute the number of array elements"
+msgstr ""
+
+#: c/c-parser.cc:9405 cp/typeck.cc:5516
+#, gcc-internal-format
+msgid "first %<sizeof%> operand was declared here"
+msgstr ""
+
+#: c/c-parser.cc:9676
+#, gcc-internal-format
+msgid "storage class specifier in cast"
+msgstr ""
+
+#: c/c-parser.cc:9679
+#, gcc-internal-format
+msgid "alignment specified for type name in cast"
+msgstr ""
+
+#: c/c-parser.cc:9780
+#, gcc-internal-format
+msgid "traditional C rejects the unary plus operator"
+msgstr ""
+
+#: c/c-parser.cc:9912
+#, gcc-internal-format
+msgid "storage class specifier in %<sizeof%>"
+msgstr ""
+
+#: c/c-parser.cc:9915
+#, gcc-internal-format
+msgid "alignment specified for type name in %<sizeof%>"
+msgstr ""
+
+#: c/c-parser.cc:9931
+#, gcc-internal-format
+msgid "%<sizeof%> applied to a bit-field"
+msgstr ""
+
+#: c/c-parser.cc:10004
+#, gcc-internal-format
+msgid "storage class specifier in %qE"
+msgstr ""
+
+#: c/c-parser.cc:10007
+#, gcc-internal-format
+msgid "alignment specified for type name in %qE"
+msgstr ""
+
+#: c/c-parser.cc:10031
+#, gcc-internal-format
+msgid "ISO C does not allow %<%E (expression)%>"
+msgstr ""
+
+#: c/c-parser.cc:10184
+#, gcc-internal-format
+msgid "cannot take address of %qs"
+msgstr ""
+
+#: c/c-parser.cc:10267
+#, gcc-internal-format
+msgid "ISO C99 does not support %<_Generic%>"
+msgstr ""
+
+#: c/c-parser.cc:10270
+#, gcc-internal-format
+msgid "ISO C90 does not support %<_Generic%>"
+msgstr ""
+
+#: c/c-parser.cc:10339
+#, gcc-internal-format
+msgid "%<_Generic%> association has function type"
+msgstr ""
+
+#: c/c-parser.cc:10342
+#, gcc-internal-format
+msgid "%<_Generic%> association has incomplete type"
+msgstr ""
+
+#: c/c-parser.cc:10346
+#, gcc-internal-format
+msgid "%<_Generic%> association has variable length type"
+msgstr ""
+
+#: c/c-parser.cc:10380
+#, gcc-internal-format
+msgid "duplicate %<default%> case in %<_Generic%>"
+msgstr ""
+
+#: c/c-parser.cc:10381
+#, gcc-internal-format
+msgid "original %<default%> is here"
+msgstr ""
+
+#: c/c-parser.cc:10389
+#, gcc-internal-format
+msgid "%<_Generic%> specifies two compatible types"
+msgstr ""
+
+#: c/c-parser.cc:10390
+#, gcc-internal-format
+msgid "compatible type is here"
+msgstr ""
+
+#: c/c-parser.cc:10413
+#, gcc-internal-format
+msgid "%<_Generic%> selector matches multiple associations"
+msgstr ""
+
+#: c/c-parser.cc:10415
+#, gcc-internal-format
+msgid "other match is here"
+msgstr ""
+
+#: c/c-parser.cc:10440
+#, gcc-internal-format
+msgid "%<_Generic%> selector of type %qT is not compatible with any association"
+msgstr ""
+
+#: c/c-parser.cc:10461
+#, gcc-internal-format
+msgid "argument %u of %<__builtin_tgmath%> is not a function pointer"
+msgstr ""
+
+#: c/c-parser.cc:10469
+#, gcc-internal-format
+msgid "argument %u of %<__builtin_tgmath%> is unprototyped"
+msgstr ""
+
+#: c/c-parser.cc:10475
+#, gcc-internal-format
+msgid "argument %u of %<__builtin_tgmath%> has variable arguments"
+msgstr ""
+
+#: c/c-parser.cc:10491
+#, gcc-internal-format
+msgid "argument %u of %<__builtin_tgmath%> has no arguments"
+msgstr ""
+
+#: c/c-parser.cc:10514 c/c-parser.cc:10518
+#, gcc-internal-format
+msgid "ISO C does not support %qs predefined identifier"
+msgstr ""
+
+#: c/c-parser.cc:10522
+#, gcc-internal-format
+msgid "ISO C90 does not support %<__func__%> predefined identifier"
+msgstr ""
+
+#: c/c-parser.cc:10700 c/c-parser.cc:12165 c/c-parser.cc:12187
+#: c/c-parser.cc:21245 c/gimple-parser.cc:1811 c/gimple-parser.cc:2451
+#: cp/parser.cc:43087
+#, gcc-internal-format
+msgid "expected expression"
+msgstr ""
+
+#: c/c-parser.cc:10722
+#, gcc-internal-format
+msgid "braced-group within expression allowed only inside a function"
+msgstr ""
+
+#: c/c-parser.cc:10737
+#, gcc-internal-format
+msgid "ISO C forbids braced-groups within expressions"
+msgstr ""
+
+#: c/c-parser.cc:10931
+#, gcc-internal-format
+msgid "wrong number of arguments to %<__builtin_choose_expr%>"
+msgstr ""
+
+#: c/c-parser.cc:10947
+#, gcc-internal-format
+msgid "first argument to %<__builtin_choose_expr%> not a constant"
+msgstr ""
+
+#: c/c-parser.cc:11017 c/c-parser.cc:11034 c/c-parser.cc:11041
+#, gcc-internal-format
+msgid "too few arguments to %<__builtin_tgmath%>"
+msgstr ""
+
+#: c/c-parser.cc:11062
+#, gcc-internal-format
+msgid "argument %u of %<__builtin_tgmath%> has wrong number of arguments"
+msgstr ""
+
+#: c/c-parser.cc:11106 c/c-parser.cc:11116
+#, gcc-internal-format
+msgid "invalid type-generic return type for argument %u of %<__builtin_tgmath%>"
+msgstr ""
+
+#: c/c-parser.cc:11138 c/c-parser.cc:11148
+#, gcc-internal-format
+msgid "invalid type-generic type for argument %u of argument %u of %<__builtin_tgmath%>"
+msgstr ""
+
+#: c/c-parser.cc:11181
+#, gcc-internal-format
+msgid "function arguments of %<__builtin_tgmath%> all have the same type"
+msgstr ""
+
+#: c/c-parser.cc:11200
+#, gcc-internal-format
+msgid "function arguments of %<__builtin_tgmath%> lack type-generic parameter"
+msgstr ""
+
+#: c/c-parser.cc:11248
+#, gcc-internal-format
+msgid "duplicate type-generic parameter type for function argument %u of %<__builtin_tgmath%>"
+msgstr ""
+
+#: c/c-parser.cc:11271
+#, gcc-internal-format
+msgid "bad return type for function argument %u of %<__builtin_tgmath%>"
+msgstr ""
+
+#: c/c-parser.cc:11288
+#, gcc-internal-format
+msgid "bad type for argument %u of function argument %u of %<__builtin_tgmath%>"
+msgstr ""
+
+#: c/c-parser.cc:11327
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid type of argument %u of type-generic function"
+msgstr ""
+
+#: c/c-parser.cc:11338
+#, gcc-internal-format, gfc-internal-format
+msgid "decimal floating-point argument %u to complex-only type-generic function"
+msgstr ""
+
+#: c/c-parser.cc:11346
+#, gcc-internal-format, gfc-internal-format
+msgid "decimal floating-point argument %u to binary-only type-generic function"
+msgstr ""
+
+#: c/c-parser.cc:11354 c/c-parser.cc:11384
+#, gcc-internal-format
+msgid "both complex and decimal floating-point arguments to type-generic function"
+msgstr ""
+
+#: c/c-parser.cc:11362 c/c-parser.cc:11404
+#, gcc-internal-format
+msgid "both binary and decimal floating-point arguments to type-generic function"
+msgstr ""
+
+#: c/c-parser.cc:11376
+#, gcc-internal-format, gfc-internal-format
+msgid "complex argument %u to decimal-only type-generic function"
+msgstr ""
+
+#: c/c-parser.cc:11396
+#, gcc-internal-format, gfc-internal-format
+msgid "binary argument %u to decimal-only type-generic function"
+msgstr ""
+
+#: c/c-parser.cc:11499
+#, gcc-internal-format
+msgid "no matching function for type-generic call"
+msgstr ""
+
+#: c/c-parser.cc:11540
+#, gcc-internal-format
+msgid "wrong number of arguments to %<__builtin_call_with_static_chain%>"
+msgstr ""
+
+#: c/c-parser.cc:11553
+#, gcc-internal-format
+msgid "first argument to %<__builtin_call_with_static_chain%> must be a call expression"
+msgstr ""
+
+#: c/c-parser.cc:11557
+#, gcc-internal-format
+msgid "second argument to %<__builtin_call_with_static_chain%> must be a pointer type"
+msgstr ""
+
+#: c/c-parser.cc:11583
+#, gcc-internal-format
+msgid "wrong number of arguments to %<__builtin_complex%>"
+msgstr ""
+
+#: c/c-parser.cc:11605
+#, gcc-internal-format
+msgid "%<__builtin_complex%> operand not of real binary floating-point type"
+msgstr ""
+
+#: c/c-parser.cc:11614
+#, gcc-internal-format
+msgid "%<__builtin_complex%> operands of different types"
+msgstr ""
+
+#: c/c-parser.cc:11659 c/c-parser.cc:11688 cp/parser.cc:7764
+#, gcc-internal-format
+msgid "wrong number of arguments to %<__builtin_shuffle%>"
+msgstr ""
+
+#: c/c-parser.cc:11849
+#, gcc-internal-format
+msgid "wrong number of arguments to %qs"
+msgstr ""
+
+#: c/c-parser.cc:11858
+#, gcc-internal-format
+msgid "%qs operand not an integral type"
+msgstr ""
+
+#: c/c-parser.cc:11864
+#, gcc-internal-format
+msgid "argument %u in call to function %qs has enumerated type"
+msgstr ""
+
+#: c/c-parser.cc:11871
+#, gcc-internal-format
+msgid "argument %u in call to function %qs has boolean type"
+msgstr ""
+
+#: c/c-parser.cc:11878
+#, gcc-internal-format
+msgid "argument 1 in call to function %qs has signed type"
+msgstr ""
+
+#: c/c-parser.cc:12142 cp/parser.cc:6134
+#, gcc-internal-format
+msgid "%<omp_all_memory%> may only be used in OpenMP %<depend%> clause"
+msgstr ""
+
+#: c/c-parser.cc:12152
+#, gcc-internal-format
+msgid "ISO C does not support %qs before C23"
+msgstr ""
+
+#: c/c-parser.cc:12240
+#, gcc-internal-format
+msgid "%qT declared in %<constexpr%> compound literal"
+msgstr ""
+
+#: c/c-parser.cc:12245
+#, gcc-internal-format
+msgid "%qT defined in %<constexpr%> compound literal"
+msgstr ""
+
+#: c/c-parser.cc:12260
+#, gcc-internal-format
+msgid "compound literal has variable size"
+msgstr ""
+
+#: c/c-parser.cc:12265
+#, gcc-internal-format
+msgid "compound literal has function type"
+msgstr ""
+
+#: c/c-parser.cc:12296
+#, gcc-internal-format
+msgid "compound literal qualified by address-space qualifier"
+msgstr ""
+
+#: c/c-parser.cc:12301
+#, gcc-internal-format
+msgid "ISO C90 forbids compound literals"
+msgstr ""
+
+#: c/c-parser.cc:12303
+#, gcc-internal-format
+msgid "ISO C forbids storage class specifiers in compound literals before C23"
+msgstr ""
+
+#: c/c-parser.cc:12317
+#, gcc-internal-format
+msgid "%<_Alignas%> specifiers cannot reduce alignment of compound literal"
+msgstr ""
+
+#: c/c-parser.cc:12392
+#, gcc-internal-format
+msgid "using integer absolute value function %qD when argument is of floating-point type %qT"
+msgstr ""
+
+#: c/c-parser.cc:12397
+#, gcc-internal-format
+msgid "using integer absolute value function %qD when argument is of complex type %qT"
+msgstr ""
+
+#: c/c-parser.cc:12405
+#, gcc-internal-format
+msgid "taking the absolute value of unsigned type %qT has no effect"
+msgstr ""
+
+#: c/c-parser.cc:12416
+#, gcc-internal-format
+msgid "using floating-point absolute value function %qD when argument is of integer type %qT"
+msgstr ""
+
+#: c/c-parser.cc:12420
+#, gcc-internal-format
+msgid "using floating-point absolute value function %qD when argument is of decimal floating-point type %qT"
+msgstr ""
+
+#: c/c-parser.cc:12425
+#, gcc-internal-format
+msgid "using floating-point absolute value function %qD when argument is of complex type %qT"
+msgstr ""
+
+#: c/c-parser.cc:12438
+#, gcc-internal-format
+msgid "using complex absolute value function %qD when argument is of integer type %qT"
+msgstr ""
+
+#: c/c-parser.cc:12442
+#, gcc-internal-format
+msgid "using complex absolute value function %qD when argument is of floating-point type %qT"
+msgstr ""
+
+#: c/c-parser.cc:12459
+#, gcc-internal-format
+msgid "using decimal floating-point absolute value function %qD when argument is of integer type %qT"
+msgstr ""
+
+#: c/c-parser.cc:12464
+#, gcc-internal-format
+msgid "using decimal floating-point absolute value function %qD when argument is of floating-point type %qT"
+msgstr ""
+
+#: c/c-parser.cc:12469
+#, gcc-internal-format
+msgid "using decimal floating-point absolute value function %qD when argument is of complex type %qT"
+msgstr ""
+
+#: c/c-parser.cc:12495
+#, gcc-internal-format
+msgid "absolute value function %qD given an argument of type %qT but has parameter of type %qT which may cause truncation of value"
+msgstr ""
+
+#: c/c-parser.cc:12625 cp/parser.cc:8164
+#, gcc-internal-format
+msgid "calls to the OpenMP runtime API are not permitted in intervening code"
+msgstr ""
+
+#: c/c-parser.cc:12999
+#, gcc-internal-format
+msgid "expected identifier or %<)%>"
+msgstr ""
+
+#: c/c-parser.cc:13095
+#, gcc-internal-format
+msgid "extra semicolon"
+msgstr ""
+
+#: c/c-parser.cc:13343
+#, gcc-internal-format
+msgid "extra semicolon in method definition specified"
+msgstr ""
+
+#: c/c-parser.cc:13475
+#, gcc-internal-format
+msgid "method attributes must be specified at the end only"
+msgstr ""
+
+#: c/c-parser.cc:13495
+#, gcc-internal-format
+msgid "expected %<;%> or %<{%> after method attribute definition"
+msgstr ""
+
+#: c/c-parser.cc:13617
+#, gcc-internal-format
+msgid "objective-c method declaration is expected"
+msgstr ""
+
+#: c/c-parser.cc:14069
+#, gcc-internal-format
+msgid "no type or storage class may be specified here,"
+msgstr ""
+
+#: c/c-parser.cc:14137 cp/parser.cc:37593
+#, gcc-internal-format
+msgid "empty property attribute list"
+msgstr ""
+
+#: c/c-parser.cc:14151 cp/parser.cc:37606
+#, gcc-internal-format
+msgid "missing property attribute"
+msgstr ""
+
+#: c/c-parser.cc:14190
+#, gcc-internal-format
+msgid "unknown property attribute %<%s%s%>"
+msgstr ""
+
+#: c/c-parser.cc:14193 cp/parser.cc:37643
+#, gcc-internal-format
+msgid "unknown property attribute"
+msgstr ""
+
+#: c/c-parser.cc:14202 cp/parser.cc:37652
+#, gcc-internal-format
+msgid "expected %<=%> after Objective-C %qE"
+msgstr ""
+
+#: c/c-parser.cc:14213 cp/parser.cc:37666
+#, gcc-internal-format
+msgid "expected %qE selector name"
+msgstr ""
+
+#: c/c-parser.cc:14229 cp/parser.cc:37685
+#, gcc-internal-format
+msgid "setter method names must terminate with %<:%>"
+msgstr ""
+
+#: c/c-parser.cc:14453 cp/semantics.cc:13228
+#, gcc-internal-format
+msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
+msgstr ""
+
+#: c/c-parser.cc:14489 cp/parser.cc:50798
+#, gcc-internal-format
+msgid "intervening code must not contain OpenMP directives"
+msgstr ""
+
+#: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
+#: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
+#: cp/parser.cc:46774 cp/parser.cc:46889 cp/parser.cc:46988 cp/parser.cc:50819
+#: cp/parser.cc:50835 cp/parser.cc:50851 cp/parser.cc:50868 cp/parser.cc:50885
+#: cp/parser.cc:50902 cp/parser.cc:50929 cp/parser.cc:50943 cp/parser.cc:50968
+#: cp/parser.cc:50982
+#, gcc-internal-format
+msgid "%<#pragma %s%> may only be used in compound statements"
+msgstr ""
+
+#: c/c-parser.cc:14532 cp/parser.cc:50957
+#, gcc-internal-format
+msgid "%<#pragma acc routine%> must be at file scope"
+msgstr ""
+
+#: c/c-parser.cc:14622 cp/parser.cc:51081
+#, gcc-internal-format
+msgid "%<#pragma omp scan%> may only be used in a loop construct with %<inscan%> %<reduction%> clause"
+msgstr ""
+
+#: c/c-parser.cc:14629 cp/parser.cc:51087
+#, gcc-internal-format
+msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
+msgstr ""
+
+#: c/c-parser.cc:14641 c/c-parser.cc:14657
+#, gcc-internal-format
+msgid "%<#pragma %s%> may only be used at file scope"
+msgstr ""
+
+#: c/c-parser.cc:14724 cp/parser.cc:51164
+#, gcc-internal-format
+msgid "for, while or do statement expected"
+msgstr ""
+
+#: c/c-parser.cc:14737 cp/parser.cc:50809
+#, gcc-internal-format
+msgid "%<#pragma GCC pch_preprocess%> must be first"
+msgstr ""
+
+#: c/c-parser.cc:15104 c/c-parser.cc:19032 c/c-parser.cc:20713
+#: c/c-parser.cc:20732 c/c-parser.cc:20983 c/c-parser.cc:21041
+#: c/c-parser.cc:21048 c/c-parser.cc:21055 c/c-parser.cc:25952
+#: c/c-parser.cc:25960 c/c-parser.cc:26230 c/c-parser.cc:26240
+#: c/c-parser.cc:26334 c/c-parser.cc:26341 c/c-parser.cc:26348
+#: cp/parser.cc:38116 cp/parser.cc:41695 cp/parser.cc:42613 cp/parser.cc:42650
+#: cp/parser.cc:42839 cp/parser.cc:42902 cp/parser.cc:42909 cp/parser.cc:42916
+#: cp/parser.cc:48243 cp/parser.cc:48250 cp/parser.cc:48257 cp/parser.cc:49704
+#: cp/parser.cc:49712 cp/parser.cc:49864 cp/parser.cc:49874
+#, gcc-internal-format
+msgid "too many %qs clauses"
+msgstr ""
+
+#: c/c-parser.cc:15131
+#, gcc-internal-format
+msgid "expression must be integral"
+msgstr ""
+
+#: c/c-parser.cc:15536 c/c-parser.cc:15548
+#, gcc-internal-format
+msgid "expected %<)%> or %<,%>"
+msgstr ""
+
+#: c/c-parser.cc:15746 c/c-parser.cc:26636
+#, gcc-internal-format
+msgid "%qD is not a variable"
+msgstr ""
+
+#: c/c-parser.cc:15750 cp/semantics.cc:8612
+#, gcc-internal-format
+msgid "%qD is not a pointer variable"
+msgstr ""
+
+#: c/c-parser.cc:15792 cp/parser.cc:38997
+#, gcc-internal-format
+msgid "collapse argument needs positive constant integer expression"
+msgstr ""
+
+#: c/c-parser.cc:15887 cp/parser.cc:39075
+#, gcc-internal-format
+msgid "expected %<none%> or %<present%>"
+msgstr ""
+
+#: c/c-parser.cc:15889 cp/parser.cc:39077
+#, gcc-internal-format
+msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
+msgstr ""
+
+#: c/c-parser.cc:15974 cp/parser.cc:39147
+#, gcc-internal-format
+msgid "expected constant logical expression"
+msgstr ""
+
+#: c/c-parser.cc:16051 cp/parser.cc:39229
+#, gcc-internal-format
+msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
+msgstr ""
+
+#: c/c-parser.cc:16071 c/c-parser.cc:23994 c/c-parser.cc:24104
+#: cp/parser.cc:39247 cp/parser.cc:46766 cp/parser.cc:46881
+#, gcc-internal-format
+msgid "expected %<data%>"
+msgstr ""
+
+#: c/c-parser.cc:16124 cp/parser.cc:39302
+#, gcc-internal-format
+msgid "too many %<if%> clauses with %qs modifier"
+msgstr ""
+
+#: c/c-parser.cc:16131 cp/parser.cc:39309
+#, gcc-internal-format
+msgid "too many %<if%> clauses"
+msgstr ""
+
+#: c/c-parser.cc:16133 cp/parser.cc:39311
+#, gcc-internal-format
+msgid "too many %<if%> clauses without modifier"
+msgstr ""
+
+#: c/c-parser.cc:16139 cp/parser.cc:39317
+#, gcc-internal-format
+msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
+msgstr ""
+
+#: c/c-parser.cc:16244 c/c-parser.cc:16304 c/c-parser.cc:16366
+#: c/c-parser.cc:16414 c/c-parser.cc:16494 c/c-parser.cc:16891
+#: c/c-parser.cc:16973 c/c-parser.cc:17578 c/c-parser.cc:17723
+#: c/c-parser.cc:17791 c/c-parser.cc:18969
+#, gcc-internal-format
+msgid "expected integer expression"
+msgstr ""
+
+#: c/c-parser.cc:16255
+#, gcc-internal-format
+msgid "%<num_threads%> value must be positive"
+msgstr ""
+
+#: c/c-parser.cc:16316
+#, gcc-internal-format
+msgid "%<num_tasks%> value must be positive"
+msgstr ""
+
+#: c/c-parser.cc:16378 cp/semantics.cc:8826
+#, gcc-internal-format
+msgid "%<grainsize%> value must be positive"
+msgstr ""
+
+#: c/c-parser.cc:16427 cp/semantics.cc:8856
+#, gcc-internal-format
+msgid "%<priority%> value must be non-negative"
+msgstr ""
+
+#: c/c-parser.cc:16461 cp/parser.cc:39543
+#, gcc-internal-format
+msgid "expected constant integer expression with valid sync-hint value"
+msgstr ""
+
+#: c/c-parser.cc:16533 cp/parser.cc:39613
+#, gcc-internal-format
+msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> or %<default%>"
+msgstr ""
+
+#: c/c-parser.cc:16601
+#, gcc-internal-format
+msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
+msgstr ""
+
+#: c/c-parser.cc:16678 cp/parser.cc:39765
+#, gcc-internal-format
+msgid "too many %<defaultmap%> clauses with %qs category"
+msgstr ""
+
+#: c/c-parser.cc:16681 cp/parser.cc:39768
+#, gcc-internal-format
+msgid "too many %<defaultmap%> clauses with unspecified category"
+msgstr ""
+
+#: c/c-parser.cc:16765 cp/semantics.cc:7683 cp/semantics.cc:7738
+#, gcc-internal-format
+msgid "%qs expression must be integral"
+msgstr ""
+
+#: c/c-parser.cc:16777 c/c-parser.cc:16900 cp/semantics.cc:7717
+#: cp/semantics.cc:7752
+#, gcc-internal-format
+msgid "%qs value must be positive"
+msgstr ""
+
+#: c/c-parser.cc:16839 cp/parser.cc:38769
+#, gcc-internal-format
+msgid "too many %<static%> arguments"
+msgstr ""
+
+#: c/c-parser.cc:16873 cp/parser.cc:38802
+#, gcc-internal-format
+msgid "unexpected argument"
+msgstr "მოულოდნელი არგუმენტი"
+
+#: c/c-parser.cc:17040 cp/semantics.cc:9043
+#, gcc-internal-format
+msgid "%<tile%> argument needs positive integral constant"
+msgstr ""
+
+#: c/c-parser.cc:17108 cp/parser.cc:41876
+#, gcc-internal-format
+msgid "too many %<self%> clauses"
+msgstr ""
+
+#: c/c-parser.cc:17150 cp/parser.cc:39818
+#, gcc-internal-format
+msgid "expected %<reproducible%> or %<unconstrained%>"
+msgstr ""
+
+#: c/c-parser.cc:17159 c/c-parser.cc:17165 cp/parser.cc:39827
+#: cp/parser.cc:39837
+#, gcc-internal-format
+msgid "expected %<concurrent%>"
+msgstr ""
+
+#: c/c-parser.cc:17201 cp/parser.cc:39877
+#, gcc-internal-format
+msgid "expected %<teams%>, %<parallel%> or %<thread%>"
+msgstr ""
+
+#: c/c-parser.cc:17254 cp/parser.cc:39945
+#, gcc-internal-format
+msgid "ordered argument needs positive constant integer expression"
+msgstr ""
+
+#: c/c-parser.cc:17379 c/c-parser.cc:25503 cp/parser.cc:49345
+#, gcc-internal-format
+msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
+msgstr ""
+
+#: c/c-parser.cc:17501 cp/parser.cc:40203
+#, gcc-internal-format
+msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
+msgstr ""
+
+#: c/c-parser.cc:17555 cp/parser.cc:40219
+#, gcc-internal-format
+msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
+msgstr ""
+
+#: c/c-parser.cc:17559 cp/parser.cc:40222
+#, gcc-internal-format
+msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
+msgstr ""
+
+#: c/c-parser.cc:17572 cp/semantics.cc:7799
+#, gcc-internal-format
+msgid "chunk size value must be positive"
+msgstr ""
+
+#: c/c-parser.cc:17595 cp/parser.cc:40242
+#, gcc-internal-format
+msgid "invalid schedule kind"
+msgstr ""
+
+#: c/c-parser.cc:17734 c/c-parser.cc:17745
+#, gcc-internal-format
+msgid "%<num_teams%> value must be positive"
+msgstr ""
+
+#: c/c-parser.cc:17753 cp/semantics.cc:7766
+#, gcc-internal-format
+msgid "%<num_teams%> lower bound %qE bigger than upper bound %qE"
+msgstr ""
+
+#: c/c-parser.cc:17802 cp/semantics.cc:7895
+#, gcc-internal-format
+msgid "%<thread_limit%> value must be positive"
+msgstr ""
+
+#: c/c-parser.cc:17847 cp/semantics.cc:8023
+#, gcc-internal-format
+msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
+msgstr ""
+
+#: c/c-parser.cc:17959 c/c-parser.cc:20700 cp/parser.cc:42605
+#, gcc-internal-format
+msgid "expected %<allocator%> or %<align%>"
+msgstr ""
+
+#: c/c-parser.cc:17966
+#, gcc-internal-format
+msgid "duplicate %qs modifier"
+msgstr ""
+
+#: c/c-parser.cc:18014 cp/semantics.cc:8158
+#, gcc-internal-format
+msgid "%<allocate%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
+msgstr ""
+
+#: c/c-parser.cc:18025 cp/semantics.cc:8113 cp/semantics.cc:8129
+#, gcc-internal-format
+msgid "%<allocate%> clause %<align%> modifier argument needs to be positive constant power of two integer expression"
+msgstr ""
+
+#: c/c-parser.cc:18144 cp/parser.cc:40689
+#, gcc-internal-format
+msgid "multiple linear modifiers"
+msgstr ""
+
+#: c/c-parser.cc:18156 cp/parser.cc:40702
+#, gcc-internal-format
+msgid "multiple %<step%> modifiers"
+msgstr ""
+
+#: c/c-parser.cc:18164 c/c-parser.cc:18192
+#, gcc-internal-format
+msgid "%<linear%> clause step expression must be integral"
+msgstr ""
+
+#: c/c-parser.cc:18244
+#, gcc-internal-format
+msgid "%<safelen%> clause expression must be positive constant integer expression"
+msgstr ""
+
+#: c/c-parser.cc:18283
+#, gcc-internal-format
+msgid "%<simdlen%> clause expression must be positive constant integer expression"
+msgstr ""
+
+#: c/c-parser.cc:18643 cp/parser.cc:41249
+#, gcc-internal-format
+msgid "%<iterator%> modifier incompatible with %qs"
+msgstr ""
+
+#: c/c-parser.cc:18691 cp/parser.cc:41304 cp/parser.cc:41756 cp/parser.cc:41806
+#, gcc-internal-format
+msgid "invalid depend kind"
+msgstr ""
+
+#: c/c-parser.cc:18752 cp/parser.cc:41334
+#, gcc-internal-format
+msgid "invalid doacross kind"
+msgstr ""
+
+#: c/c-parser.cc:18821 cp/parser.cc:41477
+#, gcc-internal-format
+msgid "too many %<always%> modifiers"
+msgstr ""
+
+#: c/c-parser.cc:18831 cp/parser.cc:41490
+#, gcc-internal-format
+msgid "too many %<close%> modifiers"
+msgstr ""
+
+#: c/c-parser.cc:18841 cp/parser.cc:41503
+#, gcc-internal-format
+msgid "too many %<present%> modifiers"
+msgstr ""
+
+#: c/c-parser.cc:18849 cp/parser.cc:41514
+#, gcc-internal-format
+msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
+msgstr ""
+
+#: c/c-parser.cc:18887 cp/parser.cc:41554
+#, gcc-internal-format
+msgid "invalid map kind"
+msgstr ""
+
+#: c/c-parser.cc:18939 cp/parser.cc:41618
+#, gcc-internal-format
+msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause"
+msgstr ""
+
+#: c/c-parser.cc:18951 cp/parser.cc:41629
+#, gcc-internal-format
+msgid "expected %<ancestor%> or %<device_num%>"
+msgstr ""
+
+#: c/c-parser.cc:18974 cp/semantics.cc:7920
+#, gcc-internal-format
+msgid "the %<device%> clause expression must evaluate to %<1%>"
+msgstr ""
+
+#: c/c-parser.cc:19007 cp/parser.cc:41700
+#, gcc-internal-format
+msgid "invalid dist_schedule kind"
+msgstr ""
+
+#: c/c-parser.cc:19086
+#, gcc-internal-format
+msgid "invalid proc_bind kind"
+msgstr ""
+
+#: c/c-parser.cc:19130
+#, gcc-internal-format
+msgid "expected %<host%>, %<nohost%> or %<any%>"
+msgstr ""
+
+#: c/c-parser.cc:19228 cp/semantics.cc:8339
+#, gcc-internal-format
+msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handle_t%>"
+msgstr ""
+
+#: c/c-parser.cc:19440 cp/parser.cc:42092
+#, gcc-internal-format
+msgid "expected an OpenACC clause"
+msgstr ""
+
+#: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
+#: cp/parser.cc:42511
+#, gcc-internal-format
+msgid "%qs is not valid for %qs"
+msgstr ""
+
+#: c/c-parser.cc:19496 cp/parser.cc:42151
+#, gcc-internal-format
+msgid "clauses in %<simd%> trait should be separated by %<,%>"
+msgstr ""
+
+#: c/c-parser.cc:19649 cp/parser.cc:42344
+#, gcc-internal-format
+msgid "%qs must be the first clause of %qs"
+msgstr ""
+
+#: c/c-parser.cc:19805 cp/parser.cc:42500
+#, gcc-internal-format
+msgid "expected an OpenMP clause"
+msgstr ""
+
+#: c/c-parser.cc:19964 cp/parser.cc:47349
+#, gcc-internal-format
+msgid "no valid clauses specified in %<#pragma acc declare%>"
+msgstr ""
+
+#: c/c-parser.cc:19974 cp/parser.cc:47359
+#, gcc-internal-format
+msgid "array section in %<#pragma acc declare%>"
+msgstr ""
+
+#: c/c-parser.cc:19994 cp/parser.cc:47379
+#, gcc-internal-format
+msgid "%qD must be a global variable in %<#pragma acc declare link%>"
+msgstr ""
+
+#: c/c-parser.cc:20005 cp/parser.cc:47390
+#, gcc-internal-format
+msgid "invalid OpenACC clause at file scope"
+msgstr ""
+
+#: c/c-parser.cc:20012 cp/parser.cc:47397
+#, gcc-internal-format
+msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
+msgstr ""
+
+#: c/c-parser.cc:20020 cp/parser.cc:47405
+#, gcc-internal-format
+msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
+msgstr ""
+
+#: c/c-parser.cc:20031 cp/parser.cc:47427
+#, gcc-internal-format
+msgid "%qD must be a variable declared in the same scope as %<#pragma acc declare%>"
+msgstr ""
+
+#: c/c-parser.cc:20041 cp/parser.cc:47450
+#, gcc-internal-format
+msgid "variable %qD used more than once with %<#pragma acc declare%>"
+msgstr ""
+
+#: c/c-parser.cc:20134 cp/parser.cc:47534
+#, gcc-internal-format
+msgid "expected %<data%> after %<#pragma acc %s%>"
+msgstr ""
+
+#: c/c-parser.cc:20150 cp/parser.cc:47551
+#, gcc-internal-format
+msgid "%<#pragma acc %s data%> has no data movement clause"
+msgstr ""
+
+#: c/c-parser.cc:20182 cp/parser.cc:47309
+#, gcc-internal-format
+msgid "%<host_data%> construct requires %<use_device%> clause"
+msgstr ""
+
+#: c/c-parser.cc:20411 cp/parser.cc:3367
+#, gcc-internal-format
+msgid "%qE has not been declared"
+msgstr ""
+
+#: c/c-parser.cc:20415
+#, gcc-internal-format
+msgid "expected function name"
+msgstr ""
+
+#: c/c-parser.cc:20433 cp/parser.cc:50131
+#, gcc-internal-format
+msgid "%qD does not refer to a function"
+msgstr ""
+
+#: c/c-parser.cc:20456 c/c-parser.cc:20504 cp/parser.cc:1662
+#, gcc-internal-format
+msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
+msgstr ""
+
+#: c/c-parser.cc:20496 cp/parser.cc:50182 cp/parser.cc:50229
+#, gcc-internal-format
+msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
+msgstr ""
+
+#: c/c-parser.cc:20527 cp/parser.cc:50257
+#, gcc-internal-format
+msgid "%<#pragma acc routine%> must be applied before use"
+msgstr ""
+
+#: c/c-parser.cc:20528 cp/parser.cc:50259
+#, gcc-internal-format
+msgid "%<#pragma acc routine%> must be applied before definition"
+msgstr ""
+
+#: c/c-parser.cc:20573 cp/parser.cc:47767
+#, gcc-internal-format
+msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
+msgstr ""
+
+#: c/c-parser.cc:20631
+#, gcc-internal-format
+msgid "variable %qD used in the %<allocator%> clause must be declared before %qD"
+msgstr ""
+
+#: c/c-parser.cc:20635 c/c-parser.cc:20658
+#, gcc-internal-format
+msgid "to be allocated variable declared here"
+msgstr ""
+
+#: c/c-parser.cc:20653
+#, gcc-internal-format
+msgid "variable %qD used in the %<allocator%> clause must not be modified between declaration of %qD and its %<allocate%> directive"
+msgstr ""
+
+#: c/c-parser.cc:20656
+#, gcc-internal-format
+msgid "modified here"
+msgstr ""
+
+#: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
+#, gcc-internal-format
+msgid "%<align%> clause argument needs to be positive constant power of two integer expression"
+msgstr ""
+
+#: c/c-parser.cc:20748
+#, gcc-internal-format
+msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_allocator_handle_t%>"
+msgstr ""
+
+#: c/c-parser.cc:20765
+#, gcc-internal-format
+msgid "function parameter %qD may not appear as list item in an %<allocate%> directive"
+msgstr ""
+
+#: c/c-parser.cc:20772
+#, gcc-internal-format
+msgid "%<allocate%> directive must be in the same scope as %qD"
+msgstr ""
+
+#: c/c-parser.cc:20780
+#, gcc-internal-format
+msgid "%qD already appeared as list item in an %<allocate%> directive"
+msgstr ""
+
+#: c/c-parser.cc:20787
+#, gcc-internal-format
+msgid "%<allocator%> clause required for static variable %qD"
+msgstr ""
+
+#: c/c-parser.cc:20794
+#, gcc-internal-format
+msgid "%<allocator%> clause requires a predefined allocator as %qD is static"
+msgstr ""
+
+#: c/c-parser.cc:20798
+#, gcc-internal-format
+msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
+msgstr ""
+
+#: c/c-parser.cc:20949 cp/parser.cc:42805
+#, gcc-internal-format
+msgid "expected %<read%>, %<write%>, %<update%>, or %<capture%> clause"
+msgstr ""
+
+#: c/c-parser.cc:20988 cp/parser.cc:42844
+#, gcc-internal-format
+msgid "expected %<seq_cst%>, %<acquire%> or %<relaxed%>"
+msgstr ""
+
+#: c/c-parser.cc:21012 cp/parser.cc:42873
+#, gcc-internal-format
+msgid "expected %<read%>, %<write%>, %<update%>, %<capture%>, %<compare%>, %<weak%>, %<fail%>, %<seq_cst%>, %<acq_rel%>, %<release%>, %<relaxed%> or %<hint%> clause"
+msgstr ""
+
+#: c/c-parser.cc:21027 cp/parser.cc:42888
+#, gcc-internal-format
+msgid "too many atomic clauses"
+msgstr ""
+
+#: c/c-parser.cc:21034 cp/parser.cc:42895
+#, gcc-internal-format
+msgid "too many memory order clauses"
+msgstr ""
+
+#: c/c-parser.cc:21072 c/c-parser.cc:21079 cp/parser.cc:42933
+#: cp/parser.cc:42940
+#, gcc-internal-format
+msgid "%qs clause is incompatible with %<read%> or %<write%> clauses"
+msgstr ""
+
+#: c/c-parser.cc:21085 c/c-parser.cc:21090 cp/parser.cc:42946
+#: cp/parser.cc:42951
+#, gcc-internal-format
+msgid "%qs clause requires %qs clause"
+msgstr ""
+
+#: c/c-parser.cc:21113 cp/parser.cc:42974
+#, gcc-internal-format
+msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
+msgstr ""
+
+#: c/c-parser.cc:21124 cp/parser.cc:42985
+#, gcc-internal-format
+msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
+msgstr ""
+
+#: c/c-parser.cc:21156 cp/parser.cc:43017
+#, gcc-internal-format
+msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
+msgstr ""
+
+#: c/c-parser.cc:21166 cp/parser.cc:43027
+#, gcc-internal-format
+msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
+msgstr ""
+
+#: c/c-parser.cc:21289 cp/parser.cc:43127
+#, gcc-internal-format
+msgid "expected %<==%> comparison in %<if%> condition"
+msgstr ""
+
+#: c/c-parser.cc:21296 cp/parser.cc:43134
+#, gcc-internal-format
+msgid "expected %<==%>, %<<%> or %<>%> comparison in %<if%> condition"
+msgstr ""
+
+#: c/c-parser.cc:21369 cp/parser.cc:43199 cp/parser.cc:43482 cp/parser.cc:43576
+#: cp/parser.cc:43594
+#, gcc-internal-format
+msgid "invalid form of %<#pragma omp atomic compare%>"
+msgstr ""
+
+#: c/c-parser.cc:21380 cp/parser.cc:43210
+#, gcc-internal-format
+msgid "unexpected %<else%>"
+msgstr ""
+
+#: c/c-parser.cc:21440 cp/parser.cc:43649
+#, gcc-internal-format
+msgid "invalid form of %<pragma omp atomic compare%>"
+msgstr ""
+
+#: c/c-parser.cc:21711 cp/parser.cc:43503 cp/parser.cc:43529
+#, gcc-internal-format
+msgid "invalid form of %<#pragma omp atomic%>"
+msgstr ""
+
+#: c/c-parser.cc:21715 cp/parser.cc:43569 cp/parser.cc:43603
+#, gcc-internal-format
+msgid "invalid operator for %<#pragma omp atomic%>"
+msgstr ""
+
+#: c/c-parser.cc:21766 cp/parser.cc:43638
+#, gcc-internal-format
+msgid "%<weak%> clause requires atomic equality comparison"
+msgstr ""
+
+#: c/c-parser.cc:21772 cp/semantics.cc:11231 cp/semantics.cc:11241
+#, gcc-internal-format
+msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
+msgstr ""
+
+#: c/c-parser.cc:21875 cp/semantics.cc:11318
+#, gcc-internal-format
+msgid "%<depobj%> expression is not lvalue expression"
+msgstr ""
+
+#: c/c-parser.cc:21918
+#, gcc-internal-format
+msgid "%<destroy%> expression is not lvalue expression"
+msgstr ""
+
+#: c/c-parser.cc:21924 cp/parser.cc:43791
+#, gcc-internal-format
+msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
+msgstr ""
+
+#: c/c-parser.cc:21955 cp/parser.cc:43827
+#, gcc-internal-format
+msgid "expected %<in%>, %<out%>, %<inout%>, %<mutexinoutset%> or %<inoutset%>"
+msgstr ""
+
+#: c/c-parser.cc:21967 cp/parser.cc:43843
+#, gcc-internal-format
+msgid "expected %<depend%>, %<destroy%> or %<update%> clause"
+msgstr ""
+
+#: c/c-parser.cc:22008 cp/parser.cc:43881
+#, gcc-internal-format
+msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
+msgstr ""
+
+#: c/c-parser.cc:22016 cp/parser.cc:43889
+#, gcc-internal-format
+msgid "%<flush%> list specified together with memory order clause"
+msgstr ""
+
+#: c/c-parser.cc:22021
+#, gcc-internal-format
+msgid "expected %<(%> or end of line"
+msgstr ""
+
+#: c/c-parser.cc:22092 cp/parser.cc:44595
+#, gcc-internal-format
+msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a statement"
+msgstr ""
+
+#: c/c-parser.cc:22159 cp/parser.cc:44664
+#, gcc-internal-format
+msgid "%<#pragma omp scan%> with zero preceding executable statements"
+msgstr ""
+
+#: c/c-parser.cc:22193 cp/parser.cc:44697
+#, gcc-internal-format
+msgid "expected %<inclusive%> or %<exclusive%> clause"
+msgstr ""
+
+#: c/c-parser.cc:22198 cp/parser.cc:44703
+#, gcc-internal-format
+msgid "expected %<#pragma omp scan%>"
+msgstr ""
+
+#: c/c-parser.cc:22207 cp/parser.cc:44712
+#, gcc-internal-format
+msgid "%<#pragma omp scan%> with zero succeeding executable statements"
+msgstr ""
+
+#: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
+#, gcc-internal-format
+msgid "expected iteration declaration or initialization"
+msgstr ""
+
+#: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
+#: cp/parser.cc:45070
+#, gcc-internal-format
+msgid "not enough nested loops"
+msgstr ""
+
+#: c/c-parser.cc:22526 cp/parser.cc:45342
+#, gcc-internal-format
+msgid "%<ordered%> clause parameter is less than %<collapse%>"
+msgstr ""
+
+#: c/c-parser.cc:22537 cp/parser.cc:45353
+#, gcc-internal-format
+msgid "for statement expected"
+msgstr ""
+
+#: c/c-parser.cc:22649 cp/parser.cc:44895 cp/parser.cc:44938 cp/pt.cc:18184
+#, gcc-internal-format
+msgid "iteration variable %qD should not be firstprivate"
+msgstr ""
+
+#: c/c-parser.cc:23057 cp/parser.cc:45864
+#, gcc-internal-format
+msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
+msgstr ""
+
+#: c/c-parser.cc:23273 cp/parser.cc:46070
+#, gcc-internal-format
+msgid "expected %<for%> after %qs"
+msgstr ""
+
+#: c/c-parser.cc:23620 cp/parser.cc:46417
+#, gcc-internal-format
+msgid "expected %<point%>"
+msgstr ""
+
+#: c/c-parser.cc:23887 cp/parser.cc:46704
+#, gcc-internal-format
+msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
+msgstr ""
+
+#: c/c-parser.cc:23903 cp/parser.cc:46720
+#, gcc-internal-format
+msgid "%<#pragma omp target data%> must contain at least one %<map%>, %<use_device_ptr%> or %<use_device_addr%> clause"
+msgstr ""
+
+#: c/c-parser.cc:23951 cp/parser.cc:47001
+#, gcc-internal-format
+msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
+msgstr ""
+
+#: c/c-parser.cc:24053 cp/parser.cc:46827
+#, gcc-internal-format
+msgid "%<#pragma omp target enter data%> with map-type other than %<to%>, %<tofrom%> or %<alloc%> on %<map%> clause"
+msgstr ""
+
+#: c/c-parser.cc:24065 cp/parser.cc:46839
+#, gcc-internal-format
+msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
+msgstr ""
+
+#: c/c-parser.cc:24164 cp/parser.cc:46944
+#, gcc-internal-format
+msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<tofrom%>, %<release%> or %<delete%> on %<map%> clause"
+msgstr ""
+
+#: c/c-parser.cc:24177 cp/parser.cc:46957
+#, gcc-internal-format
+msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
+msgstr ""
+
+#: c/c-parser.cc:24422 cp/semantics.cc:10313
+#, gcc-internal-format
+msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
+msgstr ""
+
+#: c/c-parser.cc:24479
+#, gcc-internal-format
+msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition or another %<#pragma omp declare %s%>"
+msgstr ""
+
+#: c/c-parser.cc:24530 c/c-parser.cc:24568
+#, gcc-internal-format
+msgid "%<#pragma omp declare %s%> must be followed by function declaration or definition"
+msgstr ""
+
+#: c/c-parser.cc:24601 cp/parser.cc:47911
+#, gcc-internal-format
+msgid "expected trait selector name"
+msgstr ""
+
+#: c/c-parser.cc:24613 cp/parser.cc:47925
+#, gcc-internal-format
+msgid "unknown selector %qs for context selector set %qs"
+msgstr ""
+
+#: c/c-parser.cc:24641 cp/parser.cc:47954
+#, gcc-internal-format
+msgid "selector %qs does not accept any properties"
+msgstr ""
+
+#: c/c-parser.cc:24663 cp/parser.cc:47986
+#, gcc-internal-format
+msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
+msgstr ""
+
+#: c/c-parser.cc:24672 cp/parser.cc:47996
+#, gcc-internal-format
+msgid "%<score%> argument must be constant integer expression"
+msgstr ""
+
+#: c/c-parser.cc:24675 cp/parser.cc:47999
+#, gcc-internal-format
+msgid "%<score%> argument must be non-negative"
+msgstr ""
+
+#: c/c-parser.cc:24716 cp/parser.cc:48045
+#, gcc-internal-format
+msgid "expected identifier or string literal"
+msgstr ""
+
+#: c/c-parser.cc:24741 cp/parser.cc:48070 cp/pt.cc:12077
+#, gcc-internal-format
+msgid "property must be constant integer expression"
+msgstr ""
+
+#: c/c-parser.cc:24755 cp/parser.cc:48084
+#, gcc-internal-format
+msgid "properties for %<simd%> selector may not be specified in %<metadirective%>"
+msgstr ""
+
+#. FIXME: The "requires" selector was added in OpenMP 5.1.
+#. Currently only the now-deprecated syntax
+#. from OpenMP 5.0 is supported.
+#: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
+#, gcc-internal-format
+msgid "%<requires%> selector is not supported yet"
+msgstr ""
+
+#: c/c-parser.cc:24835 cp/parser.cc:48163
+#, gcc-internal-format
+msgid "expected context selector set name"
+msgstr ""
+
+#: c/c-parser.cc:24912 cp/parser.cc:48478
+#, gcc-internal-format
+msgid "expected %<match%>"
+msgstr ""
+
+#: c/c-parser.cc:24932
+#, gcc-internal-format
+msgid "variant %qD is not a function"
+msgstr ""
+
+#: c/c-parser.cc:24939 cp/decl.cc:8323
+#, gcc-internal-format
+msgid "variant %qD and base %qD have incompatible types"
+msgstr ""
+
+#: c/c-parser.cc:24951 cp/decl.cc:8332
+#, gcc-internal-format
+msgid "variant %qD is a built-in"
+msgstr ""
+
+#: c/c-parser.cc:24997
+#, gcc-internal-format
+msgid "%<#pragma omp declare %s%> not immediately followed by a function declaration or definition"
+msgstr ""
+
+#: c/c-parser.cc:25005 cp/parser.cc:48523
+#, gcc-internal-format
+msgid "%<#pragma omp declare %s%> not immediately followed by a single function declaration or definition"
+msgstr ""
+
+#: c/c-parser.cc:25206 cp/parser.cc:48813
+#, gcc-internal-format
+msgid "%qD specified both in declare target %<link%> and %qs clauses"
+msgstr ""
+
+#: c/c-parser.cc:25210 cp/parser.cc:48817
+#, gcc-internal-format
+msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> clauses"
+msgstr ""
+
+#: c/c-parser.cc:25270 cp/parser.cc:48947
+#, gcc-internal-format
+msgid "directive with only %<device_type%> or %<indirect%> clauses"
+msgstr ""
+
+#: c/c-parser.cc:25273 cp/parser.cc:48950
+#, gcc-internal-format
+msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
+msgstr ""
+
+#: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
+#: cp/parser.cc:49052
+#, gcc-internal-format
+msgid "expected %<target%>"
+msgstr ""
+
+#: c/c-parser.cc:25336 cp/parser.cc:49018
+#, gcc-internal-format
+msgid "expected %<declare target%> or %<assumes%>"
+msgstr ""
+
+#: c/c-parser.cc:25371 cp/parser.cc:49059
+#, gcc-internal-format
+msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%> or %<#pragma omp begin declare target%>"
+msgstr ""
+
+#: c/c-parser.cc:25382 c/c-parser.cc:25413 cp/parser.cc:49070
+#: cp/parser.cc:49101
+#, gcc-internal-format
+msgid "%qs in attribute syntax terminated with %qs in pragma syntax"
+msgstr ""
+
+#: c/c-parser.cc:25389 c/c-parser.cc:25418 cp/parser.cc:49077
+#: cp/parser.cc:49106
+#, gcc-internal-format
+msgid "%qs in pragma syntax terminated with %qs in attribute syntax"
+msgstr ""
+
+#: c/c-parser.cc:25426 cp/parser.cc:49114
+#, gcc-internal-format
+msgid "expected %<declare%> or %<assumes%>"
+msgstr ""
+
+#: c/c-parser.cc:25453
+#, gcc-internal-format
+msgid "%<#pragma omp declare reduction%> not at file or block scope"
+msgstr ""
+
+#: c/c-parser.cc:25530
+#, gcc-internal-format
+msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
+msgstr ""
+
+#: c/c-parser.cc:25534
+#, gcc-internal-format
+msgid "function or array type in %<#pragma omp declare reduction%>"
+msgstr ""
+
+#: c/c-parser.cc:25537
+#, gcc-internal-format
+msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
+msgstr ""
+
+#: c/c-parser.cc:25540
+#, gcc-internal-format
+msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
+msgstr ""
+
+#: c/c-parser.cc:25548
+#, gcc-internal-format
+msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
+msgstr ""
+
+#: c/c-parser.cc:25557
+#, gcc-internal-format
+msgid "previous %<#pragma omp declare reduction%>"
+msgstr ""
+
+#: c/c-parser.cc:25678
+#, gcc-internal-format
+msgid "expected %<omp_priv%> or function-name"
+msgstr ""
+
+#: c/c-parser.cc:25689
+#, gcc-internal-format
+msgid "expected function-name %<(%>"
+msgstr ""
+
+#: c/c-parser.cc:25708
+#, gcc-internal-format
+msgid "one of the initializer call arguments should be %<&omp_priv%>"
+msgstr ""
+
+#: c/c-parser.cc:25839 cp/parser.cc:49587
+#, gcc-internal-format
+msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
+msgstr ""
+
+#: c/c-parser.cc:25908 cp/parser.cc:49654
+#, gcc-internal-format
+msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
+msgstr ""
+
+#: c/c-parser.cc:25937 cp/parser.cc:49689
+#, gcc-internal-format
+msgid "expected %<unified_address%>, %<unified_shared_memory%>, %<dynamic_allocators%>, %<reverse_offload%> or %<atomic_default_mem_order%> clause"
+msgstr ""
+
+#: c/c-parser.cc:25955 cp/parser.cc:49707
+#, gcc-internal-format
+msgid "%qs clause used lexically after first target construct or offloading API"
+msgstr ""
+
+#: c/c-parser.cc:25967 cp/parser.cc:49719
+#, gcc-internal-format
+msgid "more than one %<atomic_default_mem_order%> clause in a single compilation unit"
+msgstr ""
+
+#: c/c-parser.cc:25976 cp/parser.cc:49728
+#, gcc-internal-format
+msgid "%<atomic_default_mem_order%> clause used lexically after first %<atomic%> construct without memory order clause"
+msgstr ""
+
+#: c/c-parser.cc:25990 cp/parser.cc:49742
+#, gcc-internal-format
+msgid "%<pragma omp requires%> requires at least one clause"
+msgstr ""
+
+#: c/c-parser.cc:26009
+#, gcc-internal-format
+msgid "zero sized type %qT in %<reduction%> clause"
+msgstr ""
+
+#: c/c-parser.cc:26015
+#, gcc-internal-format
+msgid "variable sized type %qT in %<reduction%> clause"
+msgstr ""
+
+#: c/c-parser.cc:26172 cp/parser.cc:49799
+#, gcc-internal-format
+msgid "expected %<at%>, %<severity%> or %<message%> clause"
+msgstr ""
+
+#: c/c-parser.cc:26205 cp/parser.cc:49834
+#, gcc-internal-format
+msgid "expected %qs or %qs"
+msgstr ""
+
+#: c/c-parser.cc:26262 cp/parser.cc:49896
+#, gcc-internal-format
+msgid "%<#pragma omp error%> with %<at(execution)%> clause may only be used in compound statements"
+msgstr ""
+
+#: c/c-parser.cc:26285 cp/parser.cc:49923
+#, gcc-internal-format
+msgid "%<pragma omp error%> encountered: %s"
+msgstr ""
+
+#: c/c-parser.cc:26288 cp/parser.cc:49926
+#, gcc-internal-format
+msgid "%<pragma omp error%> encountered"
+msgstr ""
+
+#: c/c-parser.cc:26315 cp/parser.cc:48224
+#, gcc-internal-format
+msgid "expected at least one assumption clause"
+msgstr ""
+
+#: c/c-parser.cc:26401 cp/parser.cc:48310
+#, gcc-internal-format
+msgid "expected directive name"
+msgstr ""
+
+#: c/c-parser.cc:26414 cp/parser.cc:48323
+#, gcc-internal-format
+msgid "unknown OpenMP directive name in %qs clause argument"
+msgstr ""
+
+#: c/c-parser.cc:26421 cp/parser.cc:48330
+#, gcc-internal-format
+msgid "%<%s%s%s%s%s%> directive mentioned in both %<absent%> and %<contains%> clauses"
+msgstr ""
+
+#: c/c-parser.cc:26432 cp/parser.cc:48341
+#, gcc-internal-format
+msgid "%<%s%s%s%s%s%> directive mentioned multiple times in %qs clauses"
+msgstr ""
+
+#: c/c-parser.cc:26455 cp/parser.cc:48368
+#, gcc-internal-format
+msgid "unknown assumption clause %qs"
+msgstr ""
+
+#: c/c-parser.cc:26468 cp/parser.cc:48378
+#, gcc-internal-format
+msgid "expected assumption clause"
+msgstr ""
+
+#: c/c-parser.cc:26638 cp/semantics.cc:9679
+#, gcc-internal-format
+msgid "%qE declared %<threadprivate%> after first use"
+msgstr ""
+
+#: c/c-parser.cc:26640 cp/semantics.cc:9681
+#, gcc-internal-format
+msgid "automatic variable %qE cannot be %<threadprivate%>"
+msgstr ""
+
+#: c/c-parser.cc:26644 cp/semantics.cc:9683
+#, gcc-internal-format
+msgid "%<threadprivate%> %qE has incomplete type"
+msgstr ""
+
+#: c/c-parser.cc:26824 cp/parser.cc:50665
+#, gcc-internal-format
+msgid "%<__transaction_cancel%> without transactional memory support enabled"
+msgstr ""
+
+#: c/c-parser.cc:26830 cp/parser.cc:50671
+#, gcc-internal-format
+msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
+msgstr ""
+
+#: c/c-parser.cc:26839
+#, gcc-internal-format
+msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%> or a %<transaction_may_cancel_outer%> function"
+msgstr ""
+
+#: c/c-parser.cc:26847 cp/parser.cc:50689
+#, gcc-internal-format
+msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
+msgstr ""
+
+#: c/c-parser.cc:26940
+#, gcc-internal-format
+msgid "no closing brace"
+msgstr ""
+
+#: c/c-typeck.cc:237
+#, gcc-internal-format
+msgid "%qD has an incomplete type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:251 c/c-typeck.cc:11338 c/c-typeck.cc:11380 cp/call.cc:4942
+#, gcc-internal-format
+msgid "invalid use of void expression"
+msgstr ""
+
+#: c/c-typeck.cc:259
+#, gcc-internal-format
+msgid "invalid use of flexible array member"
+msgstr ""
+
+#: c/c-typeck.cc:265 cp/typeck2.cc:346 rust/backend/rust-tree.cc:3919
+#, gcc-internal-format
+msgid "invalid use of array with unspecified bounds"
+msgstr ""
+
+#: c/c-typeck.cc:273
+#, gcc-internal-format
+msgid "invalid use of undefined type %qT"
+msgstr ""
+
+#. If this type has a typedef-name, the TYPE_NAME is a TYPE_DECL.
+#: c/c-typeck.cc:276
+#, gcc-internal-format
+msgid "invalid use of incomplete typedef %qT"
+msgstr ""
+
+#: c/c-typeck.cc:349
+#, gcc-internal-format
+msgid "%qT and %qT are in disjoint named address spaces"
+msgstr ""
+
+#: c/c-typeck.cc:374
+#, gcc-internal-format
+msgid "%qs attribute cannot be applied to a function that does not take variable arguments"
+msgstr ""
+
+#: c/c-typeck.cc:709 c/c-typeck.cc:732
+#, gcc-internal-format
+msgid "function types not truly compatible in ISO C"
+msgstr ""
+
+#: c/c-typeck.cc:888
+#, gcc-internal-format
+msgid "cannot mix operands of decimal floating and vector types"
+msgstr ""
+
+#: c/c-typeck.cc:893
+#, gcc-internal-format
+msgid "cannot mix operands of decimal floating and complex types"
+msgstr ""
+
+#: c/c-typeck.cc:898
+#, gcc-internal-format
+msgid "cannot mix operands of decimal floating and other floating types"
+msgstr ""
+
+#: c/c-typeck.cc:928
+#, gcc-internal-format
+msgid "%<_Complex _BitInt(%d)%> unsupported"
+msgstr ""
+
+#: c/c-typeck.cc:1474
+#, gcc-internal-format
+msgid "invalid use of pointers to arrays with different qualifiers in ISO C before C23"
+msgstr ""
+
+#: c/c-typeck.cc:1478
+#, gcc-internal-format
+msgid "types are not quite compatible"
+msgstr ""
+
+#: c/c-typeck.cc:1482
+#, gcc-internal-format
+msgid "pointer target types incompatible in C++"
+msgstr ""
+
+#: c/c-typeck.cc:1657
+#, gcc-internal-format
+msgid "function return types not compatible due to %<volatile%>"
+msgstr ""
+
+#: c/c-typeck.cc:1907
+#, gcc-internal-format
+msgid "converting an array compound literal to a pointer leads to a dangling pointer in C++"
+msgstr ""
+
+#: c/c-typeck.cc:2601 c/c-typeck.cc:9854
+#, gcc-internal-format
+msgid "%qT has no member named %qE; did you mean %qE?"
+msgstr ""
+
+#: c/c-typeck.cc:2605 c/c-typeck.cc:9858
+#, gcc-internal-format
+msgid "%qT has no member named %qE"
+msgstr ""
+
+#: c/c-typeck.cc:2614
+#, gcc-internal-format
+msgid "accessing a member %qE of an atomic structure %qE"
+msgstr ""
+
+#: c/c-typeck.cc:2617
+#, gcc-internal-format
+msgid "accessing a member %qE of an atomic union %qE"
+msgstr ""
+
+#: c/c-typeck.cc:2681
+#, gcc-internal-format
+msgid "%qE is a pointer to pointer; did you mean to dereference it before applying %<->%> to it?"
+msgstr ""
+
+#: c/c-typeck.cc:2690
+#, gcc-internal-format
+msgid "%qE is a pointer; did you mean to use %<->%>?"
+msgstr ""
+
+#: c/c-typeck.cc:2697
+#, gcc-internal-format
+msgid "request for member %qE in something not a structure or union"
+msgstr ""
+
+#: c/c-typeck.cc:2745
+#, gcc-internal-format
+msgid "dereferencing %<void *%> pointer"
+msgstr ""
+
+#: c/c-typeck.cc:2800
+#, gcc-internal-format
+msgid "subscripted value is neither array nor pointer nor vector"
+msgstr ""
+
+#: c/c-typeck.cc:2810 cp/typeck.cc:4001 cp/typeck.cc:4095
+#, gcc-internal-format
+msgid "array subscript is not an integer"
+msgstr ""
+
+#: c/c-typeck.cc:2816
+#, gcc-internal-format
+msgid "subscripted value is pointer to function"
+msgstr ""
+
+#: c/c-typeck.cc:2871
+#, gcc-internal-format
+msgid "ISO C forbids subscripting %<register%> array"
+msgstr ""
+
+#: c/c-typeck.cc:2874
+#, gcc-internal-format
+msgid "ISO C90 forbids subscripting non-lvalue array"
+msgstr ""
+
+#: c/c-typeck.cc:2993
+#, gcc-internal-format
+msgid "underspecified %qD referenced in its initializer"
+msgstr ""
+
+#: c/c-typeck.cc:3048
+#, gcc-internal-format
+msgid "enum constant defined here"
+msgstr ""
+
+#: c/c-typeck.cc:3156 cp/typeck.cc:2137
+#, gcc-internal-format
+msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
+msgstr ""
+
+#: c/c-typeck.cc:3317
+#, gcc-internal-format
+msgid "called object %qE is not a function or function pointer"
+msgstr ""
+
+#: c/c-typeck.cc:3322
+#, gcc-internal-format
+msgid "called object %qD is not a function or function pointer"
+msgstr ""
+
+#: c/c-typeck.cc:3328
+#, gcc-internal-format
+msgid "called object is not a function or function pointer"
+msgstr ""
+
+#. This situation leads to run-time undefined behavior.  We can't,
+#. therefore, simply error unless we can prove that all possible
+#. executions of the program must execute the code.
+#: c/c-typeck.cc:3357
+#, gcc-internal-format
+msgid "function called through a non-compatible type"
+msgstr ""
+
+#: c/c-typeck.cc:3362 c/c-typeck.cc:3417
+#, gcc-internal-format
+msgid "function with qualified void return type called"
+msgstr ""
+
+#: c/c-typeck.cc:3472
+#, gcc-internal-format, gfc-internal-format
+msgid "type of formal parameter %d is incomplete"
+msgstr ""
+
+#: c/c-typeck.cc:3484
+#, gcc-internal-format
+msgid "passing argument %d of %qE as integer rather than floating due to prototype"
+msgstr ""
+
+#: c/c-typeck.cc:3490
+#, gcc-internal-format
+msgid "passing argument %d of %qE as integer rather than complex due to prototype"
+msgstr ""
+
+#: c/c-typeck.cc:3496
+#, gcc-internal-format
+msgid "passing argument %d of %qE as complex rather than floating due to prototype"
+msgstr ""
+
+#: c/c-typeck.cc:3502
+#, gcc-internal-format
+msgid "passing argument %d of %qE as floating rather than integer due to prototype"
+msgstr ""
+
+#: c/c-typeck.cc:3508
+#, gcc-internal-format
+msgid "passing argument %d of %qE as complex rather than integer due to prototype"
+msgstr ""
+
+#: c/c-typeck.cc:3514
+#, gcc-internal-format
+msgid "passing argument %d of %qE as floating rather than complex due to prototype"
+msgstr ""
+
+#: c/c-typeck.cc:3530
+#, gcc-internal-format
+msgid "passing argument %d of %qE as %<float%> rather than %<double%> due to prototype"
+msgstr ""
+
+#: c/c-typeck.cc:3556
+#, gcc-internal-format
+msgid "passing argument %d of %qE as %qT rather than %qT due to prototype"
+msgstr ""
+
+#: c/c-typeck.cc:3582
+#, gcc-internal-format
+msgid "passing argument %d of %qE with different width due to prototype"
+msgstr ""
+
+#: c/c-typeck.cc:3606
+#, gcc-internal-format
+msgid "passing argument %d of %qE as unsigned due to prototype"
+msgstr ""
+
+#: c/c-typeck.cc:3611
+#, gcc-internal-format
+msgid "passing argument %d of %qE as signed due to prototype"
+msgstr ""
+
+#: c/c-typeck.cc:3777
+#, gcc-internal-format
+msgid "too many arguments to method %qE"
+msgstr ""
+
+#: c/c-typeck.cc:3787
+#, gcc-internal-format
+msgid "too many arguments to built-in function %qE expecting %d"
+msgstr ""
+
+#: c/c-typeck.cc:3862
+#, gcc-internal-format
+msgid "implicit conversion from %qT to %qT when passing argument to function"
+msgstr ""
+
+#: c/c-typeck.cc:3932
+#, gcc-internal-format
+msgid "too few arguments to built-in function %qE expecting %u"
+msgstr ""
+
+#: c/c-typeck.cc:4110 c/c-typeck.cc:4138 cp/typeck.cc:5778 cp/typeck.cc:6061
+#, gcc-internal-format
+msgid "comparison with string literal results in unspecified behavior"
+msgstr ""
+
+#: c/c-typeck.cc:4118 c/c-typeck.cc:4129 cp/typeck.cc:5810 cp/typeck.cc:5834
+#, gcc-internal-format
+msgid "comparison between pointer and zero character constant"
+msgstr ""
+
+#: c/c-typeck.cc:4121 c/c-typeck.cc:4132 cp/typeck.cc:5813 cp/typeck.cc:5837
+#, gcc-internal-format
+msgid "did you mean to dereference the pointer?"
+msgstr ""
+
+#: c/c-typeck.cc:4159
+#, gcc-internal-format
+msgid "comparison between %qT and %qT"
+msgstr ""
+
+#: c/c-typeck.cc:4218
+#, gcc-internal-format
+msgid "pointer of type %<void *%> used in subtraction"
+msgstr ""
+
+#: c/c-typeck.cc:4221
+#, gcc-internal-format
+msgid "pointer to a function used in subtraction"
+msgstr ""
+
+#: c/c-typeck.cc:4255
+#, gcc-internal-format
+msgid "arithmetic on pointer to an incomplete type"
+msgstr ""
+
+#: c/c-typeck.cc:4264 cp/typeck.cc:6856
+#, gcc-internal-format
+msgid "arithmetic on pointer to an empty aggregate"
+msgstr ""
+
+#: c/c-typeck.cc:4710
+#, gcc-internal-format
+msgid "%<~%> on a boolean expression"
+msgstr ""
+
+#: c/c-typeck.cc:4714
+#, gcc-internal-format
+msgid "did you mean to use logical not?"
+msgstr ""
+
+#: c/c-typeck.cc:4724
+#, gcc-internal-format
+msgid "ISO C does not support %<~%> for complex conjugation"
+msgstr ""
+
+#: c/c-typeck.cc:4748
+#, gcc-internal-format
+msgid "wrong type argument to absu"
+msgstr ""
+
+#: c/c-typeck.cc:4774
+#, gcc-internal-format
+msgid "wrong type argument to unary exclamation mark"
+msgstr ""
+
+#: c/c-typeck.cc:4832
+#, gcc-internal-format
+msgid "increment of enumeration value is invalid in C++"
+msgstr ""
+
+#: c/c-typeck.cc:4835
+#, gcc-internal-format
+msgid "decrement of enumeration value is invalid in C++"
+msgstr ""
+
+#: c/c-typeck.cc:4842
+#, gcc-internal-format
+msgid "increment of a boolean expression"
+msgstr ""
+
+#: c/c-typeck.cc:4845
+#, gcc-internal-format
+msgid "decrement of a boolean expression"
+msgstr ""
+
+#: c/c-typeck.cc:4861
+#, gcc-internal-format
+msgid "ISO C does not support %<++%> and %<--%> on complex types"
+msgstr ""
+
+#: c/c-typeck.cc:4887 c/c-typeck.cc:4921
+#, gcc-internal-format
+msgid "wrong type argument to increment"
+msgstr ""
+
+#: c/c-typeck.cc:4889 c/c-typeck.cc:4924
+#, gcc-internal-format
+msgid "wrong type argument to decrement"
+msgstr ""
+
+#: c/c-typeck.cc:4909
+#, gcc-internal-format
+msgid "increment of pointer to an incomplete type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:4913
+#, gcc-internal-format
+msgid "decrement of pointer to an incomplete type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:5021
+#, gcc-internal-format
+msgid "taking address of expression of type %<void%>"
+msgstr ""
+
+#: c/c-typeck.cc:5080 c/c-typeck.cc:5273
+#, gcc-internal-format
+msgid "cannot take address of bit-field %qD"
+msgstr ""
+
+#: c/c-typeck.cc:5094
+#, gcc-internal-format
+msgid "cannot take address of scalar with reverse storage order"
+msgstr ""
+
+#: c/c-typeck.cc:5102
+#, gcc-internal-format
+msgid "address of array with reverse scalar storage order requested"
+msgstr ""
+
+#: c/c-typeck.cc:5288
+#, gcc-internal-format
+msgid "address of register compound literal requested"
+msgstr ""
+
+#: c/c-typeck.cc:5309
+#, gcc-internal-format
+msgid "global register variable %qD used in nested function"
+msgstr ""
+
+#: c/c-typeck.cc:5312
+#, gcc-internal-format
+msgid "register variable %qD used in nested function"
+msgstr ""
+
+#: c/c-typeck.cc:5317
+#, gcc-internal-format
+msgid "address of global register variable %qD requested"
+msgstr ""
+
+#: c/c-typeck.cc:5319 d/d-codegen.cc:721
+#, gcc-internal-format
+msgid "address of register variable %qD requested"
+msgstr ""
+
+#: c/c-typeck.cc:5458
+#, gcc-internal-format
+msgid "non-lvalue array in conditional expression"
+msgstr ""
+
+#: c/c-typeck.cc:5540
+#, gcc-internal-format
+msgid "implicit conversion from %qT to %qT to match other result of conditional"
+msgstr ""
+
+#: c/c-typeck.cc:5599 c/c-typeck.cc:5605
+#, gcc-internal-format
+msgid "operand of %<?:%> changes signedness from %qT to %qT due to unsignedness of other operand"
+msgstr ""
+
+#: c/c-typeck.cc:5622
+#, gcc-internal-format
+msgid "ISO C forbids conditional expr with only one void side"
+msgstr ""
+
+#: c/c-typeck.cc:5639
+#, gcc-internal-format
+msgid "pointers to disjoint address spaces used in conditional expression"
+msgstr ""
+
+#: c/c-typeck.cc:5663
+#, gcc-internal-format
+msgid "pointer to array loses qualifier in conditional expression"
+msgstr ""
+
+#: c/c-typeck.cc:5667
+#, gcc-internal-format
+msgid "pointer to array loses qualifier in conditional expression in ISO C before C23"
+msgstr ""
+
+#: c/c-typeck.cc:5672
+#, gcc-internal-format
+msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
+msgstr ""
+
+#: c/c-typeck.cc:5694
+#, gcc-internal-format
+msgid "pointer type mismatch in conditional expression"
+msgstr ""
+
+#: c/c-typeck.cc:5697
+#, gcc-internal-format
+msgid "first expression has type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:5698
+#, gcc-internal-format
+msgid "second expression has type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:5709 c/c-typeck.cc:5722
+#, gcc-internal-format
+msgid "pointer/integer type mismatch in conditional expression"
+msgstr ""
+
+#: c/c-typeck.cc:5749
+#, gcc-internal-format
+msgid "type mismatch in conditional expression"
+msgstr ""
+
+#: c/c-typeck.cc:5864
+#, gcc-internal-format
+msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %E"
+msgstr ""
+
+#: c/c-typeck.cc:5868
+#, gcc-internal-format
+msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>"
+msgstr ""
+
+#: c/c-typeck.cc:5886
+#, gcc-internal-format
+msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>: %E"
+msgstr ""
+
+#: c/c-typeck.cc:5891
+#, gcc-internal-format
+msgid "ignoring return value of type %qT, declared with attribute %<nodiscard%>"
+msgstr ""
+
+#: c/c-typeck.cc:5900 cp/cvt.cc:1116 rust/backend/rust-tree.cc:640
+#, gcc-internal-format
+msgid "in call to %qD, declared here"
+msgstr ""
+
+#: c/c-typeck.cc:5949
+#, gcc-internal-format
+msgid "left-hand operand of comma expression has no effect"
+msgstr ""
+
+#: c/c-typeck.cc:5967 c/c-typeck.cc:11907
+#, gcc-internal-format
+msgid "right-hand operand of comma expression has no effect"
+msgstr ""
+
+#: c/c-typeck.cc:6038
+msgid "cast adds %q#v qualifier to function type"
+msgstr ""
+
+#: c/c-typeck.cc:6044
+msgid "cast discards %qv qualifier from pointer target type"
+msgstr ""
+
+#: c/c-typeck.cc:6079
+#, gcc-internal-format
+msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
+msgstr ""
+
+#: c/c-typeck.cc:6176
+#, gcc-internal-format
+msgid "cast specifies array type"
+msgstr ""
+
+#: c/c-typeck.cc:6182
+#, gcc-internal-format
+msgid "cast specifies function type"
+msgstr ""
+
+#: c/c-typeck.cc:6197
+#, gcc-internal-format
+msgid "ISO C forbids casting nonscalar to the same type"
+msgstr ""
+
+#: c/c-typeck.cc:6201
+#, gcc-internal-format
+msgid "useless cast to type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:6221
+#, gcc-internal-format
+msgid "ISO C forbids casts to union type"
+msgstr ""
+
+#: c/c-typeck.cc:6231
+#, gcc-internal-format
+msgid "cast to union type from type not present in union"
+msgstr ""
+
+#: c/c-typeck.cc:6266
+#, gcc-internal-format
+msgid "cast to %qs address space pointer from disjoint generic address space pointer"
+msgstr ""
+
+#: c/c-typeck.cc:6271
+#, gcc-internal-format
+msgid "cast to generic address space pointer from disjoint %qs address space pointer"
+msgstr ""
+
+#: c/c-typeck.cc:6276
+#, gcc-internal-format
+msgid "cast to %qs address space pointer from disjoint %qs address space pointer"
+msgstr ""
+
+#: c/c-typeck.cc:6309
+#, gcc-internal-format
+msgid "cast increases required alignment of target type"
+msgstr ""
+
+#: c/c-typeck.cc:6321
+#, gcc-internal-format
+msgid "cast from pointer to integer of different size"
+msgstr ""
+
+#: c/c-typeck.cc:6326
+#, gcc-internal-format
+msgid "cast from function call of type %qT to non-matching type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:6336 cp/typeck.cc:9292
+#, gcc-internal-format
+msgid "cast to pointer from integer of different size"
+msgstr ""
+
+#: c/c-typeck.cc:6350
+#, gcc-internal-format
+msgid "ISO C forbids conversion of function pointer to object pointer type"
+msgstr ""
+
+#: c/c-typeck.cc:6359
+#, gcc-internal-format
+msgid "ISO C forbids conversion of object pointer to function pointer type"
+msgstr ""
+
+#: c/c-typeck.cc:6369
+#, gcc-internal-format
+msgid "cast between incompatible function types from %qT to %qT"
+msgstr ""
+
+#: c/c-typeck.cc:6481
+#, gcc-internal-format
+msgid "defining a type in a cast is invalid in C++"
+msgstr ""
+
+#: c/c-typeck.cc:6522
+#, gcc-internal-format
+msgid "assignment to expression with array type"
+msgstr ""
+
+#: c/c-typeck.cc:6648
+#, gcc-internal-format
+msgid "enum conversion in assignment is invalid in C++"
+msgstr ""
+
+#: c/c-typeck.cc:6850 c/c-typeck.cc:6867 c/c-typeck.cc:6918
+#, gcc-internal-format
+msgid "(near initialization for %qs)"
+msgstr ""
+
+#: c/c-typeck.cc:6933
+#, gcc-internal-format
+msgid "array initialized from parenthesized string constant"
+msgstr ""
+
+#: c/c-typeck.cc:6976 c/c-typeck.cc:7217
+#, gcc-internal-format
+msgid "expected %qT but argument is of type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:7010
+#, gcc-internal-format
+msgid "%qD argument %d type is %qT where %qT is expected in a call to built-in function declared without prototype"
+msgstr ""
+
+#: c/c-typeck.cc:7013
+#, gcc-internal-format
+msgid "%qD argument %d promotes to %qT where %qT is expected in a call to built-in function declared without prototype"
+msgstr ""
+
+#: c/c-typeck.cc:7018
+#, gcc-internal-format
+msgid "built-in %qD declared here"
+msgstr ""
+
+#: c/c-typeck.cc:7212
+#, gcc-internal-format
+msgid "enum conversion when passing argument %d of %qE is invalid in C++"
+msgstr ""
+
+#: c/c-typeck.cc:7221
+#, gcc-internal-format
+msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
+msgstr ""
+
+#: c/c-typeck.cc:7226
+#, gcc-internal-format
+msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
+msgstr ""
+
+#: c/c-typeck.cc:7231
+#, gcc-internal-format
+msgid "enum conversion from %qT to %qT in return is invalid in C++"
+msgstr ""
+
+#: c/c-typeck.cc:7249
+#, gcc-internal-format
+msgid "implicit conversion from %qT to %qT"
+msgstr ""
+
+#: c/c-typeck.cc:7428 c/c-typeck.cc:7826
+msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
+msgstr ""
+
+#: c/c-typeck.cc:7431 c/c-typeck.cc:7829
+msgid "assignment makes %q#v qualified function pointer from unqualified"
+msgstr ""
+
+#: c/c-typeck.cc:7434 c/c-typeck.cc:7831
+msgid "initialization makes %q#v qualified function pointer from unqualified"
+msgstr ""
+
+#: c/c-typeck.cc:7437 c/c-typeck.cc:7833
+msgid "return makes %q#v qualified function pointer from unqualified"
+msgstr ""
+
+#: c/c-typeck.cc:7445 c/c-typeck.cc:7717 c/c-typeck.cc:7760
+msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
+msgstr ""
+
+#: c/c-typeck.cc:7447 c/c-typeck.cc:7719 c/c-typeck.cc:7762
+msgid "assignment discards %qv qualifier from pointer target type"
+msgstr ""
+
+#: c/c-typeck.cc:7449 c/c-typeck.cc:7721 c/c-typeck.cc:7764
+msgid "initialization discards %qv qualifier from pointer target type"
+msgstr ""
+
+#: c/c-typeck.cc:7451 c/c-typeck.cc:7723 c/c-typeck.cc:7766
+msgid "return discards %qv qualifier from pointer target type"
+msgstr ""
+
+#: c/c-typeck.cc:7460
+#, gcc-internal-format
+msgid "ISO C prohibits argument conversion to union type"
+msgstr ""
+
+#: c/c-typeck.cc:7528
+#, gcc-internal-format
+msgid "request for implicit conversion from %qT to %qT not permitted in C++"
+msgstr ""
+
+#: c/c-typeck.cc:7555
+#, gcc-internal-format
+msgid "passing argument %d of %qE from pointer to non-enclosed address space"
+msgstr ""
+
+#: c/c-typeck.cc:7566
+#, gcc-internal-format
+msgid "assignment from pointer to non-enclosed address space"
+msgstr ""
+
+#: c/c-typeck.cc:7577
+#, gcc-internal-format
+msgid "initialization from pointer to non-enclosed address space"
+msgstr ""
+
+#: c/c-typeck.cc:7587
+#, gcc-internal-format
+msgid "return from pointer to non-enclosed address space"
+msgstr ""
+
+#: c/c-typeck.cc:7603
+#, gcc-internal-format
+msgid "expected %qT but pointer is of type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:7618
+#, gcc-internal-format
+msgid "argument %d of %qE might be a candidate for a format attribute"
+msgstr ""
+
+#: c/c-typeck.cc:7624
+#, gcc-internal-format
+msgid "assignment left-hand side might be a candidate for a format attribute"
+msgstr ""
+
+#: c/c-typeck.cc:7630
+#, gcc-internal-format
+msgid "initialization left-hand side might be a candidate for a format attribute"
+msgstr ""
+
+#: c/c-typeck.cc:7635 cp/typeck.cc:10455
+#, gcc-internal-format
+msgid "return type might be a candidate for a format attribute"
+msgstr ""
+
+#: c/c-typeck.cc:7659
+#, gcc-internal-format
+msgid "passing argument %d of %qE from incompatible scalar storage order"
+msgstr ""
+
+#: c/c-typeck.cc:7669
+#, gcc-internal-format
+msgid "assignment to %qT from pointer type %qT with incompatible scalar storage order"
+msgstr ""
+
+#: c/c-typeck.cc:7679
+#, gcc-internal-format
+msgid "initialization of %qT from pointer type %qT with incompatible scalar storage order"
+msgstr ""
+
+#: c/c-typeck.cc:7684
+#, gcc-internal-format
+msgid "returning %qT from pointer type with incompatible scalar storage order %qT"
+msgstr ""
+
+#: c/c-typeck.cc:7734
+#, gcc-internal-format
+msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
+msgstr ""
+
+#: c/c-typeck.cc:7737
+#, gcc-internal-format
+msgid "ISO C forbids assignment between function pointer and %<void *%>"
+msgstr ""
+
+#: c/c-typeck.cc:7739
+#, gcc-internal-format
+msgid "ISO C forbids initialization between function pointer and %<void *%>"
+msgstr ""
+
+#: c/c-typeck.cc:7741
+#, gcc-internal-format
+msgid "ISO C forbids return between function pointer and %<void *%>"
+msgstr ""
+
+#: c/c-typeck.cc:7771
+#, gcc-internal-format
+msgid "array with qualifier on the element is not qualified before C23"
+msgstr ""
+
+#: c/c-typeck.cc:7788
+#, gcc-internal-format
+msgid "pointer targets in passing argument %d of %qE differ in signedness"
+msgstr ""
+
+#: c/c-typeck.cc:7796
+#, gcc-internal-format
+msgid "pointer targets in assignment from %qT to %qT differ in signedness"
+msgstr ""
+
+#: c/c-typeck.cc:7802
+#, gcc-internal-format
+msgid "pointer targets in initialization of %qT from %qT differ in signedness"
+msgstr ""
+
+#: c/c-typeck.cc:7807
+#, gcc-internal-format
+msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
+msgstr ""
+
+#: c/c-typeck.cc:7849
+#, gcc-internal-format
+msgid "passing argument %d of %qE from incompatible pointer type"
+msgstr ""
+
+#: c/c-typeck.cc:7858
+#, gcc-internal-format
+msgid "assignment to %qT from pointer to %qD with incompatible type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:7863
+#, gcc-internal-format
+msgid "assignment to %qT from incompatible pointer type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:7870
+#, gcc-internal-format
+msgid "initialization of %qT from pointer to %qD with incompatible type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:7875
+#, gcc-internal-format
+msgid "initialization of %qT from incompatible pointer type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:7882
+#, gcc-internal-format
+msgid "returning pointer to %qD of type %qT from a function with incompatible type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:7887
+#, gcc-internal-format
+msgid "returning %qT from a function with incompatible return type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:7929
+#, gcc-internal-format
+msgid "passing argument %d of %qE makes pointer from integer without a cast"
+msgstr ""
+
+#: c/c-typeck.cc:7936
+#, gcc-internal-format
+msgid "assignment to %qT from %qT makes pointer from integer without a cast"
+msgstr ""
+
+#: c/c-typeck.cc:7942
+#, gcc-internal-format
+msgid "initialization of %qT from %qT makes pointer from integer without a cast"
+msgstr ""
+
+#: c/c-typeck.cc:7947
+#, gcc-internal-format
+msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
+msgstr ""
+
+#: c/c-typeck.cc:7968
+#, gcc-internal-format
+msgid "passing argument %d of %qE makes integer from pointer without a cast"
+msgstr ""
+
+#: c/c-typeck.cc:7975
+#, gcc-internal-format
+msgid "assignment to %qT from %qT makes integer from pointer without a cast"
+msgstr ""
+
+#: c/c-typeck.cc:7981
+#, gcc-internal-format
+msgid "initialization of %qT from %qT makes integer from pointer without a cast"
+msgstr ""
+
+#: c/c-typeck.cc:7985
+#, gcc-internal-format
+msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
+msgstr ""
+
+#: c/c-typeck.cc:8017
+#, gcc-internal-format
+msgid "incompatible type for argument %d of %qE"
+msgstr ""
+
+#: c/c-typeck.cc:8028
+#, gcc-internal-format
+msgid "incompatible types when assigning to type %qT from type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:8039
+#, gcc-internal-format
+msgid "incompatible types when initializing type %qT using type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:8049
+#, gcc-internal-format
+msgid "incompatible types when returning type %qT but %qT was expected"
+msgstr ""
+
+#: c/c-typeck.cc:8129
+#, gcc-internal-format
+msgid "traditional C rejects automatic aggregate initialization"
+msgstr ""
+
+#: c/c-typeck.cc:8371
+#, gcc-internal-format
+msgid "%<constexpr%> pointer initializer is not null"
+msgstr ""
+
+#: c/c-typeck.cc:8379
+#, gcc-internal-format
+msgid "%<constexpr%> integer initializer is not an integer constant expression"
+msgstr ""
+
+#: c/c-typeck.cc:8382 c/c-typeck.cc:8444 c/c-typeck.cc:8581
+#, gcc-internal-format
+msgid "%<constexpr%> initializer not representable in type of object"
+msgstr ""
+
+#: c/c-typeck.cc:8392
+#, gcc-internal-format
+msgid "%<constexpr%> initializer is not an arithmetic constant expression"
+msgstr ""
+
+#: c/c-typeck.cc:8409
+#, gcc-internal-format
+msgid "%<constexpr%> initializer for a real type is of complex type"
+msgstr ""
+
+#: c/c-typeck.cc:8418
+#, gcc-internal-format
+msgid "%<constexpr%> initializer for a binary floating-point type is of decimal type"
+msgstr ""
+
+#: c/c-typeck.cc:8546 c/c-typeck.cc:9480 cp/typeck2.cc:1224
+#, gcc-internal-format
+msgid "initialization of a flexible array member"
+msgstr ""
+
+#: c/c-typeck.cc:8562 cp/typeck2.cc:1241
+#, gcc-internal-format
+msgid "cannot initialize array of %qT from a string literal with type array of %qT"
+msgstr ""
+
+#: c/c-typeck.cc:8621
+#, gcc-internal-format
+msgid "array of inappropriate type initialized from string constant"
+msgstr ""
+
+#: c/c-typeck.cc:8689 cp/typeck.cc:2530
+#, gcc-internal-format
+msgid "invalid use of non-lvalue array"
+msgstr ""
+
+#: c/c-typeck.cc:8703 c/c-typeck.cc:8829 c/c-typeck.cc:9565
+#, gcc-internal-format
+msgid "invalid initializer"
+msgstr ""
+
+#: c/c-typeck.cc:8715 c/c-typeck.cc:8739 c/c-typeck.cc:8742 c/c-typeck.cc:8750
+#: c/c-typeck.cc:8798 c/c-typeck.cc:10344 c/c-typeck.cc:10423
+#, gcc-internal-format
+msgid "initializer element is not constant"
+msgstr ""
+
+#: c/c-typeck.cc:8724
+#, gcc-internal-format
+msgid "array initialized from non-constant array expression"
+msgstr ""
+
+#: c/c-typeck.cc:8755 c/c-typeck.cc:8811 c/c-typeck.cc:10433
+#, gcc-internal-format
+msgid "initializer element is not a constant expression"
+msgstr ""
+
+#: c/c-typeck.cc:8805 c/c-typeck.cc:10428
+#, gcc-internal-format
+msgid "initializer element is not computable at load time"
+msgstr ""
+
+#: c/c-typeck.cc:9107 cp/decl.cc:7700
+#, gcc-internal-format
+msgid "opaque vector types cannot be initialized"
+msgstr ""
+
+#: c/c-typeck.cc:9327
+#, gcc-internal-format
+msgid "extra brace group at end of initializer"
+msgstr ""
+
+#: c/c-typeck.cc:9410
+#, gcc-internal-format
+msgid "braces around scalar initializer"
+msgstr ""
+
+#: c/c-typeck.cc:9477 c/c-typeck.cc:10966 cp/typeck2.cc:1251 cp/typeck2.cc:1586
+#, gcc-internal-format
+msgid "initialization of flexible array member in a nested context"
+msgstr ""
+
+#: c/c-typeck.cc:9514
+#, gcc-internal-format
+msgid "missing braces around initializer"
+msgstr ""
+
+#: c/c-typeck.cc:9537
+#, gcc-internal-format
+msgid "missing initializer for field %qD of %qT"
+msgstr ""
+
+#: c/c-typeck.cc:9577
+#, gcc-internal-format
+msgid "extra elements in scalar initializer"
+msgstr ""
+
+#: c/c-typeck.cc:9696 c/c-typeck.cc:9778
+#, gcc-internal-format
+msgid "array index in non-array initializer"
+msgstr ""
+
+#: c/c-typeck.cc:9701 c/c-typeck.cc:9840
+#, gcc-internal-format
+msgid "field name not in record or union initializer"
+msgstr ""
+
+#: c/c-typeck.cc:9751
+#, gcc-internal-format
+msgid "array index in initializer not of integer type"
+msgstr ""
+
+#: c/c-typeck.cc:9760 c/c-typeck.cc:9769
+#, gcc-internal-format
+msgid "array index in initializer is not an integer constant expression"
+msgstr ""
+
+#: c/c-typeck.cc:9774 c/c-typeck.cc:9776
+#, gcc-internal-format
+msgid "nonconstant array index in initializer"
+msgstr ""
+
+#: c/c-typeck.cc:9780 c/c-typeck.cc:9783
+#, gcc-internal-format
+msgid "array index in initializer exceeds array bounds"
+msgstr ""
+
+#: c/c-typeck.cc:9802
+#, gcc-internal-format
+msgid "empty index range in initializer"
+msgstr ""
+
+#: c/c-typeck.cc:9811
+#, gcc-internal-format
+msgid "array index range in initializer exceeds array bounds"
+msgstr ""
+
+#: c/c-typeck.cc:9913 c/c-typeck.cc:9943 c/c-typeck.cc:10521
+#, gcc-internal-format
+msgid "initialized field with side-effects overwritten"
+msgstr ""
+
+#: c/c-typeck.cc:9917 c/c-typeck.cc:9947 c/c-typeck.cc:10524
+#, gcc-internal-format
+msgid "initialized field overwritten"
+msgstr ""
+
+#: c/c-typeck.cc:10455
+#, gcc-internal-format
+msgid "enum conversion in initialization is invalid in C++"
+msgstr ""
+
+#: c/c-typeck.cc:10836
+#, gcc-internal-format
+msgid "excess elements in %qT initializer"
+msgstr ""
+
+#: c/c-typeck.cc:10848 c/c-typeck.cc:10925
+#, gcc-internal-format
+msgid "excess elements in struct initializer"
+msgstr ""
+
+#: c/c-typeck.cc:10869
+#, gcc-internal-format
+msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
+msgstr ""
+
+#: c/c-typeck.cc:10940 cp/typeck2.cc:1228
+#, gcc-internal-format
+msgid "non-static initialization of a flexible array member"
+msgstr ""
+
+#: c/c-typeck.cc:11035
+#, gcc-internal-format
+msgid "excess elements in union initializer"
+msgstr ""
+
+#: c/c-typeck.cc:11057
+#, gcc-internal-format
+msgid "traditional C rejects initialization of unions"
+msgstr ""
+
+#: c/c-typeck.cc:11119
+#, gcc-internal-format
+msgid "excess elements in array initializer"
+msgstr ""
+
+#: c/c-typeck.cc:11153
+#, gcc-internal-format
+msgid "excess elements in vector initializer"
+msgstr ""
+
+#: c/c-typeck.cc:11185
+#, gcc-internal-format
+msgid "excess elements in scalar initializer"
+msgstr ""
+
+#: c/c-typeck.cc:11428
+#, gcc-internal-format
+msgid "ISO C forbids %<goto *expr;%>"
+msgstr ""
+
+#: c/c-typeck.cc:11434
+#, gcc-internal-format
+msgid "computed goto must be pointer type"
+msgstr ""
+
+#: c/c-typeck.cc:11463 c/gimple-parser.cc:2562 cp/typeck.cc:11056
+#, gcc-internal-format
+msgid "function declared %<noreturn%> has a %<return%> statement"
+msgstr ""
+
+#: c/c-typeck.cc:11490
+#, gcc-internal-format
+msgid "%<return%> with no value, in function returning non-void"
+msgstr ""
+
+#: c/c-typeck.cc:11503 c/gimple-parser.cc:2572
+#, gcc-internal-format
+msgid "%<return%> with a value, in function returning void"
+msgstr ""
+
+#: c/c-typeck.cc:11506
+#, gcc-internal-format
+msgid "ISO C forbids %<return%> with expression, in function returning void"
+msgstr ""
+
+#: c/c-typeck.cc:11583
+#, gcc-internal-format
+msgid "function returns address of label"
+msgstr ""
+
+#: c/c-typeck.cc:11674 cp/semantics.cc:1706
+#, gcc-internal-format
+msgid "switch quantity not an integer"
+msgstr ""
+
+#: c/c-typeck.cc:11699
+#, gcc-internal-format
+msgid "%<long%> switch expression not converted to %<int%> in ISO C"
+msgstr ""
+
+#: c/c-typeck.cc:11737 c/c-typeck.cc:11745
+#, gcc-internal-format
+msgid "case label is not an integer constant expression"
+msgstr ""
+
+#: c/c-typeck.cc:11751 cp/parser.cc:13099
+#, gcc-internal-format
+msgid "case label not within a switch statement"
+msgstr ""
+
+#: c/c-typeck.cc:11753
+#, gcc-internal-format
+msgid "%<default%> label not within a switch statement"
+msgstr ""
+
+#: c/c-typeck.cc:11829 cp/parser.cc:14819
+#, gcc-internal-format
+msgid "break statement not within loop or switch"
+msgstr ""
+
+#: c/c-typeck.cc:11832 c/c-typeck.cc:11852 cp/decl.cc:4061 cp/parser.cc:14829
+#: cp/parser.cc:14850
+#, gcc-internal-format
+msgid "invalid exit from OpenMP structured block"
+msgstr ""
+
+#: c/c-typeck.cc:11835 cp/parser.cc:14832
+#, gcc-internal-format
+msgid "break statement used with OpenMP for loop"
+msgstr ""
+
+#: c/c-typeck.cc:11849 cp/parser.cc:14842
+#, gcc-internal-format
+msgid "continue statement not within a loop"
+msgstr ""
+
+#: c/c-typeck.cc:11889 cp/cp-gimplify.cc:272
+#, gcc-internal-format
+msgid "statement with no effect"
+msgstr ""
+
+#: c/c-typeck.cc:11933
+#, gcc-internal-format
+msgid "expression statement has incomplete type"
+msgstr ""
+
+#: c/c-typeck.cc:12224
+#, gcc-internal-format
+msgid "the comparison will always evaluate as %<false%> for the pointer operand in %qE must not be NULL"
+msgstr ""
+
+#: c/c-typeck.cc:12229
+#, gcc-internal-format
+msgid "the comparison will always evaluate as %<true%> for the pointer operand in %qE must not be NULL"
+msgstr ""
+
+#: c/c-typeck.cc:12247 c/c-typeck.cc:12285
+#, gcc-internal-format
+msgid "the comparison will always evaluate as %<false%> for the address of %qE will never be NULL"
+msgstr ""
+
+#: c/c-typeck.cc:12252 c/c-typeck.cc:12290
+#, gcc-internal-format
+msgid "the comparison will always evaluate as %<true%> for the address of %qE will never be NULL"
+msgstr ""
+
+#: c/c-typeck.cc:12882 c/c-typeck.cc:13046 cp/typeck.cc:6083
+#, gcc-internal-format
+msgid "comparing vectors with different element types"
+msgstr ""
+
+#: c/c-typeck.cc:12890 c/c-typeck.cc:13054 cp/typeck.cc:6096
+#, gcc-internal-format
+msgid "comparing vectors with different number of elements"
+msgstr ""
+
+#: c/c-typeck.cc:12905 c/c-typeck.cc:13069 cp/typeck.cc:6114
+#, gcc-internal-format
+msgid "comparison between types %qT and %qT"
+msgstr ""
+
+#: c/c-typeck.cc:12915 c/c-typeck.cc:13079 cp/typeck.cc:6131
+#, gcc-internal-format
+msgid "could not find an integer type of the same size as %qT"
+msgstr ""
+
+#: c/c-typeck.cc:12929 cp/typeck.cc:5767
+#, gcc-internal-format
+msgid "comparing floating-point with %<==%> or %<!=%> is unsafe"
+msgstr ""
+
+#: c/c-typeck.cc:12968 c/c-typeck.cc:13120
+#, gcc-internal-format
+msgid "comparison of pointers to disjoint address spaces"
+msgstr ""
+
+#: c/c-typeck.cc:12975 c/c-typeck.cc:12981
+#, gcc-internal-format
+msgid "ISO C forbids comparison of %<void *%> with function pointer"
+msgstr ""
+
+#: c/c-typeck.cc:12988 c/c-typeck.cc:13130
+#, gcc-internal-format
+msgid "comparison of distinct pointer types lacks a cast"
+msgstr ""
+
+#: c/c-typeck.cc:13001 c/c-typeck.cc:13007 c/c-typeck.cc:13157
+#: c/c-typeck.cc:13163
+#, gcc-internal-format
+msgid "comparison between pointer and integer"
+msgstr ""
+
+#: c/c-typeck.cc:13108
+#, gcc-internal-format
+msgid "comparison of complete and incomplete pointers"
+msgstr ""
+
+#: c/c-typeck.cc:13110
+#, gcc-internal-format
+msgid "ISO C forbids ordered comparisons of pointers to functions"
+msgstr ""
+
+#: c/c-typeck.cc:13115
+#, gcc-internal-format
+msgid "ordered comparison of pointer with null pointer"
+msgstr ""
+
+#: c/c-typeck.cc:13138 c/c-typeck.cc:13141 c/c-typeck.cc:13148
+#: c/c-typeck.cc:13151
+#, gcc-internal-format
+msgid "ordered comparison of pointer with integer zero"
+msgstr ""
+
+#: c/c-typeck.cc:13228
+#, gcc-internal-format
+msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
+msgstr ""
+
+#: c/c-typeck.cc:13546
+#, gcc-internal-format
+msgid "used array that cannot be converted to pointer where scalar is required"
+msgstr ""
+
+#: c/c-typeck.cc:13550
+#, gcc-internal-format
+msgid "used struct type value where scalar is required"
+msgstr ""
+
+#: c/c-typeck.cc:13554
+#, gcc-internal-format
+msgid "used union type value where scalar is required"
+msgstr ""
+
+#: c/c-typeck.cc:13570
+#, gcc-internal-format
+msgid "used vector type where scalar is required"
+msgstr ""
+
+#: c/c-typeck.cc:13773 cp/semantics.cc:11391
+#, gcc-internal-format
+msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
+msgstr ""
+
+#: c/c-typeck.cc:13784 c/c-typeck.cc:13794 cp/semantics.cc:11402
+#: cp/semantics.cc:11412
+#, gcc-internal-format
+msgid "expected %<cancel%> %<if%> clause modifier"
+msgstr ""
+
+#: c/c-typeck.cc:13829 cp/semantics.cc:11447
+#, gcc-internal-format
+msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
+msgstr ""
+
+#: c/c-typeck.cc:13897 cp/semantics.cc:5552 cp/semantics.cc:8560
+#, gcc-internal-format
+msgid "%qD is not a variable in %qs clause"
+msgstr ""
+
+#: c/c-typeck.cc:13901 c/c-typeck.cc:15708 cp/semantics.cc:5556
+#: cp/semantics.cc:8564
+#, gcc-internal-format
+msgid "%qE is not a variable in %qs clause"
+msgstr ""
+
+#: c/c-typeck.cc:13909
+#, gcc-internal-format
+msgid "%<_Atomic%> %qD in %qs clause"
+msgstr ""
+
+#: c/c-typeck.cc:13919 c/c-typeck.cc:15715 c/c-typeck.cc:15869
+#: cp/semantics.cc:5565 cp/semantics.cc:8571 cp/semantics.cc:8759
+#, gcc-internal-format
+msgid "%qD is threadprivate variable in %qs clause"
+msgstr ""
+
+#: c/c-typeck.cc:13956 cp/semantics.cc:5599
+#, gcc-internal-format
+msgid "low bound %qE of array section does not have integral type"
+msgstr ""
+
+#: c/c-typeck.cc:13963 cp/semantics.cc:5606
+#, gcc-internal-format
+msgid "length %qE of array section does not have integral type"
+msgstr ""
+
+#: c/c-typeck.cc:13986 cp/semantics.cc:5639
+#, gcc-internal-format
+msgid "expected single pointer in %qs clause"
+msgstr ""
+
+#: c/c-typeck.cc:14004 c/c-typeck.cc:14071 c/c-typeck.cc:14364
+#: cp/semantics.cc:5657 cp/semantics.cc:5724
+#, gcc-internal-format
+msgid "zero length array section in %qs clause"
+msgstr ""
+
+#: c/c-typeck.cc:14023 cp/semantics.cc:5676
+#, gcc-internal-format
+msgid "for unknown bound array type length expression must be specified"
+msgstr ""
+
+#: c/c-typeck.cc:14031 cp/semantics.cc:5684
+#, gcc-internal-format
+msgid "negative low bound in array section in %qs clause"
+msgstr ""
+
+#: c/c-typeck.cc:14040 c/c-typeck.cc:14164 cp/semantics.cc:5693
+#: cp/semantics.cc:5817
+#, gcc-internal-format
+msgid "negative length in array section in %qs clause"
+msgstr ""
+
+#: c/c-typeck.cc:14057 cp/semantics.cc:5710
+#, gcc-internal-format
+msgid "low bound %qE above array section size in %qs clause"
+msgstr ""
+
+#: c/c-typeck.cc:14100 cp/semantics.cc:5753
+#, gcc-internal-format
+msgid "length %qE above array section size in %qs clause"
+msgstr ""
+
+#: c/c-typeck.cc:14115 cp/semantics.cc:5768
+#, gcc-internal-format
+msgid "high bound %qE above array section size in %qs clause"
+msgstr ""
+
+#: c/c-typeck.cc:14152 cp/semantics.cc:5805
+#, gcc-internal-format
+msgid "for array function parameter length expression must be specified"
+msgstr ""
+
+#: c/c-typeck.cc:14156 cp/semantics.cc:5809
+#, gcc-internal-format
+msgid "for pointer type length expression must be specified"
+msgstr ""
+
+#: c/c-typeck.cc:14184 c/c-typeck.cc:14303 cp/semantics.cc:5836
+#: cp/semantics.cc:5972
+#, gcc-internal-format
+msgid "array section is not contiguous in %qs clause"
+msgstr ""
+
+#: c/c-typeck.cc:14194 cp/semantics.cc:5846
+#, gcc-internal-format
+msgid "%qE does not have pointer or array type"
+msgstr ""
+
+#: c/c-typeck.cc:14570 cp/semantics.cc:6908
+#, gcc-internal-format
+msgid "iterator %qD has neither integral nor pointer type"
+msgstr ""
+
+#: c/c-typeck.cc:14577
+#, gcc-internal-format
+msgid "iterator %qD has %<_Atomic%> qualified type"
+msgstr ""
+
+#: c/c-typeck.cc:14583 cp/semantics.cc:6915
+#, gcc-internal-format
+msgid "iterator %qD has const qualified type"
+msgstr ""
+
+#: c/c-typeck.cc:14596 cp/semantics.cc:6931
+#, gcc-internal-format
+msgid "iterator step with non-integral type"
+msgstr ""
+
+#: c/c-typeck.cc:14616 cp/semantics.cc:6967
+#, gcc-internal-format
+msgid "iterator %qD has zero step"
+msgstr ""
+
+#: c/c-typeck.cc:14643
+#, gcc-internal-format
+msgid "type of iterator %qD refers to outer iterator %qD"
+msgstr ""
+
+#: c/c-typeck.cc:14650 cp/semantics.cc:7001
+#, gcc-internal-format
+msgid "begin expression refers to outer iterator %qD"
+msgstr ""
+
+#: c/c-typeck.cc:14656 cp/semantics.cc:7007
+#, gcc-internal-format
+msgid "end expression refers to outer iterator %qD"
+msgstr ""
+
+#: c/c-typeck.cc:14662 cp/semantics.cc:7013
+#, gcc-internal-format
+msgid "step expression refers to outer iterator %qD"
+msgstr ""
+
+#: c/c-typeck.cc:14699 cp/semantics.cc:7061
+#, gcc-internal-format
+msgid "expected pointer in %qs clause"
+msgstr ""
+
+#: c/c-typeck.cc:14794 cp/semantics.cc:7150
+#, gcc-internal-format
+msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct"
+msgstr ""
+
+#: c/c-typeck.cc:14816 cp/semantics.cc:7170
+#, gcc-internal-format
+msgid "%<inscan%> %<reduction%> clause with array section"
+msgstr ""
+
+#: c/c-typeck.cc:14842 c/c-typeck.cc:14852
+#, gcc-internal-format
+msgid "%qD in %<reduction%> clause is a zero size array"
+msgstr ""
+
+#: c/c-typeck.cc:14872
+#, gcc-internal-format
+msgid "%<_Atomic%> %qE in %<reduction%> clause"
+msgstr ""
+
+#: c/c-typeck.cc:14884
+#, gcc-internal-format
+msgid "zero sized type %qT in %qs clause"
+msgstr ""
+
+#: c/c-typeck.cc:14892
+#, gcc-internal-format
+msgid "variable sized type %qT in %qs clause"
+msgstr ""
+
+#: c/c-typeck.cc:14936
+#, gcc-internal-format
+msgid "%qE has invalid type for %<reduction(%s)%>"
+msgstr ""
+
+#: c/c-typeck.cc:14945 cp/semantics.cc:6800
+#, gcc-internal-format
+msgid "user defined reduction not found for %qE"
+msgstr ""
+
+#: c/c-typeck.cc:15033
+#, gcc-internal-format
+msgid "variable length element type in array %<reduction%> clause"
+msgstr ""
+
+#: c/c-typeck.cc:15051 c/c-typeck.cc:15963 cp/semantics.cc:9296
+#, gcc-internal-format
+msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
+msgstr ""
+
+#: c/c-typeck.cc:15063 cp/semantics.cc:9364
+#, gcc-internal-format
+msgid "%qE must be %<threadprivate%> for %<copyin%>"
+msgstr ""
+
+#: c/c-typeck.cc:15078 cp/semantics.cc:7213
+#, gcc-internal-format
+msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs when not using OpenMP 5.2 modifiers"
+msgstr ""
+
+#: c/c-typeck.cc:15087
+#, gcc-internal-format
+msgid "linear clause applied to non-integral non-pointer variable with type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:15095
+#, gcc-internal-format
+msgid "%<_Atomic%> %qD in %<linear%> clause"
+msgstr ""
+
+#: c/c-typeck.cc:15114 cp/semantics.cc:7297
+#, gcc-internal-format
+msgid "%<linear%> clause step %qE is neither constant nor a parameter"
+msgstr ""
+
+#: c/c-typeck.cc:15144 c/c-typeck.cc:15863 c/c-typeck.cc:16110
+#: cp/semantics.cc:7384 cp/semantics.cc:8753 cp/semantics.cc:9104
+#, gcc-internal-format
+msgid "%qE is not a variable in clause %qs"
+msgstr ""
+
+#: c/c-typeck.cc:15161 cp/semantics.cc:7402
+#, gcc-internal-format
+msgid "%qD appears more than once in data-sharing clauses"
+msgstr ""
+
+#: c/c-typeck.cc:15172 cp/semantics.cc:7413
+#, gcc-internal-format
+msgid "%qD appears more than once in reduction clauses"
+msgstr ""
+
+#: c/c-typeck.cc:15186 c/c-typeck.cc:15256 c/c-typeck.cc:15291
+#, gcc-internal-format
+msgid "%qE appears more than once in data clauses"
+msgstr ""
+
+#: c/c-typeck.cc:15196 c/c-typeck.cc:15264 c/c-typeck.cc:15611
+#: c/c-typeck.cc:15763 c/c-typeck.cc:15771 c/c-typeck.cc:15787
+#: c/c-typeck.cc:15796 c/c-typeck.cc:15804 cp/semantics.cc:7427
+#: cp/semantics.cc:7437 cp/semantics.cc:7530 cp/semantics.cc:7538
+#: cp/semantics.cc:7585 cp/semantics.cc:8442 cp/semantics.cc:8631
+#: cp/semantics.cc:8639 cp/semantics.cc:8659 cp/semantics.cc:8668
+#: cp/semantics.cc:8676
+#, gcc-internal-format
+msgid "%qD appears more than once in data clauses"
+msgstr ""
+
+#: c/c-typeck.cc:15199 c/c-typeck.cc:15270 c/c-typeck.cc:15807
+#: cp/semantics.cc:7440 cp/semantics.cc:7544 cp/semantics.cc:8679
+#, gcc-internal-format
+msgid "%qD appears both in data and map clauses"
+msgstr ""
+
+#: c/c-typeck.cc:15244 cp/semantics.cc:7517
+#, gcc-internal-format
+msgid "%qE is not a variable in clause %<firstprivate%>"
+msgstr ""
+
+#: c/c-typeck.cc:15284 cp/semantics.cc:7577
+#, gcc-internal-format
+msgid "%qE is not a variable in clause %<lastprivate%>"
+msgstr ""
+
+#: c/c-typeck.cc:15303 cp/semantics.cc:7975
+#, gcc-internal-format
+msgid "%qE is not a variable in %<aligned%> clause"
+msgstr ""
+
+#: c/c-typeck.cc:15310
+#, gcc-internal-format
+msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
+msgstr ""
+
+#: c/c-typeck.cc:15317
+#, gcc-internal-format
+msgid "%<_Atomic%> %qD in %<aligned%> clause"
+msgstr ""
+
+#: c/c-typeck.cc:15324
+#, gcc-internal-format
+msgid "%qE appears more than once in %<aligned%> clauses"
+msgstr ""
+
+#: c/c-typeck.cc:15337 cp/semantics.cc:8046
+#, gcc-internal-format
+msgid "%qE is not a variable in %<nontemporal%> clause"
+msgstr ""
+
+#: c/c-typeck.cc:15343
+#, gcc-internal-format
+msgid "%qE appears more than once in %<nontemporal%> clauses"
+msgstr ""
+
+#: c/c-typeck.cc:15356 cp/semantics.cc:8085
+#, gcc-internal-format
+msgid "%qE is not a variable in %<allocate%> clause"
+msgstr ""
+
+#: c/c-typeck.cc:15362
+#, gcc-internal-format
+msgid "%qE appears more than once in %<allocate%> clauses"
+msgstr ""
+
+#: c/c-typeck.cc:15432 cp/semantics.cc:8211
+#, gcc-internal-format
+msgid "%<depend%> clause with %<depobj%> dependence type on array section"
+msgstr ""
+
+#: c/c-typeck.cc:15447 cp/semantics.cc:8226
+#, gcc-internal-format
+msgid "%<omp_all_memory%> used with %<depend%> kind other than %<out%> or %<inout%>"
+msgstr ""
+
+#: c/c-typeck.cc:15455 cp/semantics.cc:8244
+#, gcc-internal-format
+msgid "%qE is not lvalue expression nor array section in %qs clause"
+msgstr ""
+
+#: c/c-typeck.cc:15476 cp/semantics.cc:8266
+#, gcc-internal-format
+msgid "%qE does not have %<omp_depend_t%> type in %<depend%> clause with %<depobj%> dependence type"
+msgstr ""
+
+#: c/c-typeck.cc:15486 cp/semantics.cc:8278
+#, gcc-internal-format
+msgid "%qE should not have %<omp_depend_t%> type in %<depend%> clause with dependence type other than %<depobj%>"
+msgstr ""
+
+#: c/c-typeck.cc:15547 cp/semantics.cc:8377
+#, gcc-internal-format
+msgid "array section does not have mappable type in %qs clause"
+msgstr ""
+
+#: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
+#: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
+#, gcc-internal-format
+msgid "unsupported map expression %qE"
+msgstr ""
+
+#: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
+#: cp/semantics.cc:8656
+#, gcc-internal-format
+msgid "%qD appears more than once in motion clauses"
+msgstr ""
+
+#: c/c-typeck.cc:15615 c/c-typeck.cc:15790 cp/semantics.cc:8446
+#: cp/semantics.cc:8662
+#, gcc-internal-format
+msgid "%qD appears more than once in map clauses"
+msgstr ""
+
+#: c/c-typeck.cc:15734 c/c-typeck.cc:15876 cp/semantics.cc:8599
+#: cp/semantics.cc:8766
+#, gcc-internal-format
+msgid "%qD does not have a mappable type in %qs clause"
+msgstr ""
+
+#: c/c-typeck.cc:15859 cp/semantics.cc:8748
+#, gcc-internal-format
+msgid "%qE is neither a variable nor a function name in clause %qs"
+msgstr ""
+
+#: c/c-typeck.cc:15885 cp/semantics.cc:8778
+#, gcc-internal-format
+msgid "%qE appears more than once on the same %<declare target%> directive"
+msgstr ""
+
+#: c/c-typeck.cc:15899 cp/semantics.cc:8794
+#, gcc-internal-format
+msgid "%qD is not an argument in %<uniform%> clause"
+msgstr ""
+
+#: c/c-typeck.cc:15902 cp/semantics.cc:8797
+#, gcc-internal-format
+msgid "%qE is not an argument in %<uniform%> clause"
+msgstr ""
+
+#: c/c-typeck.cc:15921
+#, gcc-internal-format
+msgid "%qs variable is not a pointer"
+msgstr ""
+
+#: c/c-typeck.cc:15928
+#, gcc-internal-format
+msgid "%qs variable is neither a pointer nor an array"
+msgstr ""
+
+#: c/c-typeck.cc:15976 c/c-typeck.cc:16071 cp/semantics.cc:9258
+#, gcc-internal-format
+msgid "%<order%> clause must not be used together with %<ordered%>"
+msgstr ""
+
+#: c/c-typeck.cc:15996 cp/semantics.cc:8318
+#, gcc-internal-format
+msgid "too many %qs clauses on a task construct"
+msgstr ""
+
+#: c/c-typeck.cc:16093 cp/semantics.cc:9072
+#, gcc-internal-format
+msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
+msgstr ""
+
+#: c/c-typeck.cc:16160 cp/semantics.cc:9435
+#, gcc-internal-format
+msgid "%qE is predetermined %qs for %qs"
+msgstr ""
+
+#: c/c-typeck.cc:16170
+#, gcc-internal-format
+msgid "%<const%> qualified %qE may appear only in %<shared%> or %<firstprivate%> clauses"
+msgstr ""
+
+#: c/c-typeck.cc:16201 cp/semantics.cc:9210
+#, gcc-internal-format
+msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
+msgstr ""
+
+#: c/c-typeck.cc:16213 cp/semantics.cc:9223
+#, gcc-internal-format
+msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
+msgstr ""
+
+#: c/c-typeck.cc:16224 c/c-typeck.cc:16232 cp/semantics.cc:9232
+#: cp/semantics.cc:9250
+#, gcc-internal-format
+msgid "%qs clause specified together with %<inscan%> %<reduction%> clause"
+msgstr ""
+
+#: c/c-typeck.cc:16280 cp/semantics.cc:9190
+#, gcc-internal-format
+msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
+msgstr ""
+
+#: c/c-typeck.cc:16331 cp/semantics.cc:9240
+#, gcc-internal-format
+msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
+msgstr ""
+
+#: c/c-typeck.cc:16341 cp/semantics.cc:9269
+#, gcc-internal-format
+msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
+msgstr ""
+
+#: c/c-typeck.cc:16359 cp/semantics.cc:9460
+#, gcc-internal-format
+msgid "the event handle of a %<detach%> clause should not be in a data-sharing clause"
+msgstr ""
+
+#: c/c-typeck.cc:16534
+#, gcc-internal-format
+msgid "cannot use %<va_arg%> with reverse storage order"
+msgstr ""
+
+#: c/c-typeck.cc:16539
+#, gcc-internal-format
+msgid "second argument to %<va_arg%> is of incomplete type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:16545
+#, gcc-internal-format
+msgid "second argument to %<va_arg%> is a function type %qT"
+msgstr ""
+
+#: c/c-typeck.cc:16551
+#, gcc-internal-format
+msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
+msgstr ""
+
+#: c/gimple-parser.cc:166
+#, gcc-internal-format
+msgid "expected frequency quality"
+msgstr ""
+
+#: c/gimple-parser.cc:175
+#, gcc-internal-format
+msgid "unknown profile quality"
+msgstr ""
+
+#: c/gimple-parser.cc:187
+#, gcc-internal-format
+msgid "expected frequency value"
+msgstr ""
+
+#: c/gimple-parser.cc:331
+#, gcc-internal-format
+msgid "edge not found"
+msgstr ""
+
+#: c/gimple-parser.cc:347
+#, gcc-internal-format
+msgid "SSA name %qE with version %d has no definition"
+msgstr ""
+
+#: c/gimple-parser.cc:497 c/gimple-parser.cc:503
+#, gcc-internal-format
+msgid "expected block index"
+msgstr ""
+
+#: c/gimple-parser.cc:511
+#, gcc-internal-format
+msgid "invalid block index"
+msgstr ""
+
+#: c/gimple-parser.cc:522
+#, gcc-internal-format
+msgid "expected block specifier"
+msgstr ""
+
+#: c/gimple-parser.cc:540
+#, gcc-internal-format
+msgid "expected loop number"
+msgstr ""
+
+#: c/gimple-parser.cc:558
+#, gcc-internal-format
+msgid "unknown block specifier"
+msgstr ""
+
+#: c/gimple-parser.cc:571 c/gimple-parser.cc:2073
+#, gcc-internal-format
+msgid "expected count value"
+msgstr ""
+
+#: c/gimple-parser.cc:594 c/gimple-parser.cc:681
+#, gcc-internal-format
+msgid "stmts without block"
+msgstr ""
+
+#: c/gimple-parser.cc:631
+#, gcc-internal-format
+msgid "duplicate loop header"
+msgstr ""
+
+#: c/gimple-parser.cc:838
+#, gcc-internal-format
+msgid "invalid source block specification"
+msgstr ""
+
+#: c/gimple-parser.cc:905
+#, gcc-internal-format
+msgid "unexpected RHS for assignment"
+msgstr ""
+
+#: c/gimple-parser.cc:1005
+#, gcc-internal-format
+msgid "%<&&%> not valid in GIMPLE"
+msgstr ""
+
+#: c/gimple-parser.cc:1008
+#, gcc-internal-format
+msgid "%<||%> not valid in GIMPLE"
+msgstr ""
+
+#: c/gimple-parser.cc:1162
+#, gcc-internal-format
+msgid "expected pointer as argument of unary %<*%>"
+msgstr ""
+
+#: c/gimple-parser.cc:1188
+#, gcc-internal-format
+msgid "%<!%> not valid in GIMPLE"
+msgstr ""
+
+#: c/gimple-parser.cc:1247 c/gimple-parser.cc:1633
+#, gcc-internal-format
+msgid "expected constant offset"
+msgstr ""
+
+#: c/gimple-parser.cc:1308
+#, gcc-internal-format
+msgid "SSA name undeclared"
+msgstr ""
+
+#: c/gimple-parser.cc:1330
+#, gcc-internal-format
+msgid "base variable or SSA name undeclared"
+msgstr ""
+
+#: c/gimple-parser.cc:1337
+#, gcc-internal-format
+msgid "invalid base %qE for SSA name"
+msgstr ""
+
+#: c/gimple-parser.cc:1365
+#, gcc-internal-format
+msgid "expecting internal function name"
+msgstr ""
+
+#: c/gimple-parser.cc:1378
+#, gcc-internal-format
+msgid "unknown internal function %qE"
+msgstr ""
+
+#: c/gimple-parser.cc:1520
+#, gcc-internal-format
+msgid "invalid type of %<__MEM%> operand"
+msgstr ""
+
+#: c/gimple-parser.cc:1563
+#, gcc-internal-format
+msgid "expected constant offset for %<__MEM%> operand"
+msgstr ""
+
+#: c/gimple-parser.cc:1574
+#, gcc-internal-format
+msgid "expected constant step for %<__MEM%> operand"
+msgstr ""
+
+#: c/gimple-parser.cc:1627
+#, gcc-internal-format
+msgid "expected constant size"
+msgstr ""
+
+#: c/gimple-parser.cc:1665 c/gimple-parser.cc:1695 c/gimple-parser.cc:1735
+#: c/gimple-parser.cc:1743 c/gimple-parser.cc:1752
+#, gcc-internal-format
+msgid "invalid _Literal"
+msgstr ""
+
+#: c/gimple-parser.cc:1674
+#, gcc-internal-format
+msgid "invalid type for _Literal with constructor"
+msgstr ""
+
+#: c/gimple-parser.cc:1787
+#, gcc-internal-format
+msgid "anonymous SSA name cannot have default definition"
+msgstr ""
+
+#: c/gimple-parser.cc:1871
+#, gcc-internal-format
+msgid "invalid call to non-function"
+msgstr ""
+
+#: c/gimple-parser.cc:1927
+#, gcc-internal-format
+msgid "dereference of non-pointer"
+msgstr ""
+
+#: c/gimple-parser.cc:2054
+#, gcc-internal-format
+msgid "expected pass name"
+msgstr ""
+
+#: c/gimple-parser.cc:2093
+#, gcc-internal-format
+msgid "invalid operation"
+msgstr "არასწორი ოპერაცია"
+
+#: c/gimple-parser.cc:2258
+#, gcc-internal-format
+msgid "comparison required"
+msgstr ""
+
+#: c/gimple-parser.cc:2310
+#, gcc-internal-format
+msgid "%<catch%> is not supported"
+msgstr ""
+
+#: c/gimple-parser.cc:2312
+#, gcc-internal-format
+msgid "expected %<finally%> or %<catch%>"
+msgstr ""
+
+#: c/gimple-parser.cc:2356 c/gimple-parser.cc:2393
+#, gcc-internal-format
+msgid "expected goto expression"
+msgstr ""
+
+#: c/gimple-parser.cc:2364
+#, gcc-internal-format
+msgid "expected else statement"
+msgstr ""
+
+#: c/gimple-parser.cc:2507
+#, gcc-internal-format
+msgid "expected case label"
+msgstr ""
+
+#: cp/call.cc:2041
+#, gcc-internal-format
+msgid "casting %qT to %qT does not use %qD"
+msgstr ""
+
+#. A bad conversion for 'this' must be discarding cv-quals.
+#: cp/call.cc:3888
+#, gcc-internal-format
+msgid "  passing %qT as %<this%> argument discards qualifiers"
+msgstr ""
+
+#: cp/call.cc:3892
+msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
+msgstr ""
+
+#: cp/call.cc:3899
+#, gcc-internal-format, gfc-internal-format
+msgid "  conversion of argument %d would be ill-formed:"
+msgstr ""
+
+#. Conversion of conversion function return value failed.
+#: cp/call.cc:3907
+msgid "  no known conversion from %qH to %qI"
+msgstr ""
+
+#: cp/call.cc:3913
+msgid "  no known conversion for argument %d from %qH to %qI"
+msgstr ""
+
+#: cp/call.cc:3927 cp/pt.cc:7123
+#, gcc-internal-format, gfc-internal-format
+msgid "  candidate expects at least %d argument, %d provided"
+msgid_plural "  candidate expects at least %d arguments, %d provided"
+msgstr[0] ""
+msgstr[1] ""
+
+#: cp/call.cc:3932 cp/pt.cc:7128
+#, gcc-internal-format, gfc-internal-format
+msgid "  candidate expects %d argument, %d provided"
+msgid_plural "  candidate expects %d arguments, %d provided"
+msgstr[0] ""
+msgstr[1] ""
+
+#: cp/call.cc:3960
+#, gcc-internal-format
+msgid "%s%<%D(%T, %T, %T)%> (built-in)"
+msgstr ""
+
+#: cp/call.cc:3965
+#, gcc-internal-format
+msgid "%s%<%D(%T, %T)%> (built-in)"
+msgstr ""
+
+#: cp/call.cc:3969
+#, gcc-internal-format
+msgid "%s%<%D(%T)%> (built-in)"
+msgstr ""
+
+#: cp/call.cc:3973
+#, gcc-internal-format
+msgid "%s%qT (conversion)"
+msgstr ""
+
+#: cp/call.cc:3975
+#, gcc-internal-format
+msgid "%s%#qD (near match)"
+msgstr ""
+
+#: cp/call.cc:3977
+#, gcc-internal-format
+msgid "%s%#qD (ignored)"
+msgstr ""
+
+#: cp/call.cc:3979
+#, gcc-internal-format
+msgid "%s%#qD (deleted)"
+msgstr ""
+
+#: cp/call.cc:3981
+#, gcc-internal-format
+msgid "%s%#qD (reversed)"
+msgstr ""
+
+#: cp/call.cc:3983
+#, gcc-internal-format
+msgid "%s%#qD (rewritten)"
+msgstr ""
+
+#: cp/call.cc:3985
+#, gcc-internal-format
+msgid "%s%#qD"
+msgstr ""
+
+#: cp/call.cc:3989
+#, gcc-internal-format
+msgid "  inherited here"
+msgstr ""
+
+#: cp/call.cc:4010
+#, gcc-internal-format
+msgid "  return type %qT of explicit conversion function cannot be converted to %qT with a qualification conversion"
+msgstr ""
+
+#: cp/call.cc:4016
+#, gcc-internal-format
+msgid "  conversion from return type %qT of template conversion function specialization to %qT is not an exact match"
+msgstr ""
+
+#: cp/call.cc:4027
+#, gcc-internal-format
+msgid "  substitution of deduced template arguments resulted in errors seen above"
+msgstr ""
+
+#. Re-run template unification with diagnostics.
+#: cp/call.cc:4032
+#, gcc-internal-format
+msgid "  template argument deduction/substitution failed:"
+msgstr ""
+
+#: cp/call.cc:4046
+#, gcc-internal-format
+msgid "  a constructor taking a single argument of its own class type is invalid"
+msgstr ""
+
+#: cp/call.cc:4053
+#, gcc-internal-format
+msgid "  an inherited constructor is not a candidate for initialization from an expression of the same or derived type"
+msgstr ""
+
+#: cp/call.cc:4132
+#, gcc-internal-format
+msgid "some candidates omitted; use %<-fdiagnostics-all-candidates%> to display them"
+msgstr ""
+
+#: cp/call.cc:4213 cp/call.cc:4758
+#, gcc-internal-format
+msgid "designated initializers cannot be used with a non-aggregate type %qT"
+msgstr ""
+
+#: cp/call.cc:4652
+msgid "conversion from %qH to %qI is ambiguous"
+msgstr ""
+
+#: cp/call.cc:4764 cp/cvt.cc:864
+msgid "could not convert %qE from %qH to %qI"
+msgstr ""
+
+#: cp/call.cc:4829
+msgid "initializing %qH with %qI in converted constant expression does not bind directly"
+msgstr ""
+
+#: cp/call.cc:4850
+msgid "conversion from %qH to %qI in a converted constant expression"
+msgstr ""
+
+#: cp/call.cc:5035
+#, gcc-internal-format
+msgid "no matching function for call to %<%D(%A)%>"
+msgstr ""
+
+#: cp/call.cc:5038
+#, gcc-internal-format
+msgid "call of overloaded %<%D(%A)%> is ambiguous"
+msgstr ""
+
+#. It's no good looking for an overloaded operator() on a
+#. pointer-to-member-function.
+#: cp/call.cc:5322
+#, gcc-internal-format
+msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
+msgstr ""
+
+#: cp/call.cc:5401
+#, gcc-internal-format
+msgid "no match for call to %<(%T) (%A)%>"
+msgstr ""
+
+#: cp/call.cc:5415
+#, gcc-internal-format
+msgid "call of %<(%T) (%A)%> is ambiguous"
+msgstr ""
+
+#: cp/call.cc:5458
+#, gcc-internal-format
+msgid "ambiguous overload for "
+msgstr ""
+
+#: cp/call.cc:5459
+#, gcc-internal-format
+msgid "no match for "
+msgstr ""
+
+#: cp/call.cc:5462
+#, gcc-internal-format
+msgid " (operand types are %qT, %qT, and %qT)"
+msgstr ""
+
+#: cp/call.cc:5464
+#, gcc-internal-format
+msgid " (operand types are %qT and %qT)"
+msgstr ""
+
+#: cp/call.cc:5466
+#, gcc-internal-format
+msgid " (operand type is %qT)"
+msgstr ""
+
+#: cp/call.cc:5483
+#, gcc-internal-format
+msgid "ternary %<operator?:%>"
+msgstr ""
+
+#: cp/call.cc:5487
+#, gcc-internal-format
+msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
+msgstr ""
+
+#: cp/call.cc:5496 cp/call.cc:5540 cp/call.cc:5550
+#, gcc-internal-format
+msgid "%<operator%s%>"
+msgstr ""
+
+#: cp/call.cc:5499
+#, gcc-internal-format
+msgid "%<operator%s%> in %<%E%s%>"
+msgstr ""
+
+#: cp/call.cc:5506
+#, gcc-internal-format
+msgid "%<operator[]%>"
+msgstr ""
+
+#: cp/call.cc:5509
+#, gcc-internal-format
+msgid "%<operator[]%> in %<%E[%E]%>"
+msgstr ""
+
+#: cp/call.cc:5517
+#, gcc-internal-format
+msgid "%qs"
+msgstr ""
+
+#: cp/call.cc:5520
+#, gcc-internal-format
+msgid "%qs in %<%s %E%>"
+msgstr ""
+
+#: cp/call.cc:5526
+#, gcc-internal-format
+msgid "%<operator %s%>"
+msgstr ""
+
+#: cp/call.cc:5529
+#, gcc-internal-format
+msgid "%<operator %s%> in %<%s%E%>"
+msgstr ""
+
+#: cp/call.cc:5544
+#, gcc-internal-format
+msgid "%<operator%s%> in %<%E %s %E%>"
+msgstr ""
+
+#: cp/call.cc:5553
+#, gcc-internal-format
+msgid "%<operator%s%> in %<%s%E%>"
+msgstr ""
+
+#: cp/call.cc:5665
+#, gcc-internal-format
+msgid "ISO C++ forbids omitting the middle term of a %<?:%> expression"
+msgstr ""
+
+#: cp/call.cc:5742
+#, gcc-internal-format
+msgid "inferred scalar type %qT is not an integer or floating-point type of the same size as %qT"
+msgstr ""
+
+#: cp/call.cc:5759 cp/call.cc:5766
+msgid "conversion of scalar %qH to vector %qI involves truncation"
+msgstr ""
+
+#: cp/call.cc:5822
+#, gcc-internal-format
+msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
+msgstr ""
+
+#: cp/call.cc:5874 cp/call.cc:6220 cp/call.cc:6240
+#, gcc-internal-format
+msgid "operands to %<?:%> of types %qT and %qT have unordered conversion rank"
+msgstr ""
+
+#: cp/call.cc:5946
+#, gcc-internal-format
+msgid "second operand to the conditional operator is of type %<void%>, but the third operand is neither a throw-expression nor of type %<void%>"
+msgstr ""
+
+#: cp/call.cc:5951
+#, gcc-internal-format
+msgid "third operand to the conditional operator is of type %<void%>, but the second operand is neither a throw-expression nor of type %<void%>"
+msgstr ""
+
+#: cp/call.cc:5997 cp/call.cc:6109 cp/call.cc:6360
+#, gcc-internal-format
+msgid "operands to %<?:%> have different types %qT and %qT"
+msgstr ""
+
+#: cp/call.cc:6001
+#, gcc-internal-format
+msgid "  and each type can be converted to the other"
+msgstr ""
+
+#: cp/call.cc:6248
+msgid "implicit conversion from %qH to %qI to match other result of conditional"
+msgstr ""
+
+#: cp/call.cc:6266
+#, gcc-internal-format
+msgid "enumerated mismatch in conditional expression: %qT vs %qT"
+msgstr ""
+
+#: cp/call.cc:6286
+#, gcc-internal-format
+msgid "conditional expression between enumeration type %qT and floating-point type %qT"
+msgstr ""
+
+#: cp/call.cc:6290
+#, gcc-internal-format
+msgid "conditional expression between floating-point type %qT and enumeration type %qT"
+msgstr ""
+
+#: cp/call.cc:6294
+#, gcc-internal-format
+msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
+msgstr ""
+
+#: cp/call.cc:6299
+#, gcc-internal-format
+msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
+msgstr ""
+
+#: cp/call.cc:6315
+#, gcc-internal-format
+msgid "enumerated and non-enumerated type in conditional expression"
+msgstr ""
+
+#: cp/call.cc:7208
+#, gcc-internal-format
+msgid "no %<%D(int)%> declared for postfix %qs, trying prefix operator instead"
+msgstr ""
+
+#: cp/call.cc:7210
+#, gcc-internal-format
+msgid "no %<%D(int)%> declared for postfix %qs"
+msgstr ""
+
+#: cp/call.cc:7290
+#, gcc-internal-format
+msgid "in C++20 this comparison calls the current function recursively with reversed arguments"
+msgstr ""
+
+#: cp/call.cc:7343
+#, gcc-internal-format
+msgid "return type of %qD is not %qs"
+msgstr ""
+
+#: cp/call.cc:7345
+#, gcc-internal-format
+msgid "used as rewritten candidate for comparison of %qT and %qT"
+msgstr ""
+
+#: cp/call.cc:7428
+#, gcc-internal-format
+msgid "comparison between %q#T and %q#T"
+msgstr ""
+
+#: cp/call.cc:7615
+#, gcc-internal-format
+msgid "no match for call to %<%T::operator[] (%A)%>"
+msgstr ""
+
+#: cp/call.cc:7629
+#, gcc-internal-format
+msgid "call of %<%T::operator[] (%A)%> is ambiguous"
+msgstr ""
+
+#: cp/call.cc:7907
+#, gcc-internal-format
+msgid "exception cleanup for this placement new selects non-placement %<operator delete%>"
+msgstr ""
+
+#: cp/call.cc:7910
+#, gcc-internal-format
+msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with %<-fsized-deallocation%>)"
+msgstr ""
+
+#: cp/call.cc:7947
+#, gcc-internal-format
+msgid "%qD is a usual (non-placement) deallocation function"
+msgstr ""
+
+#: cp/call.cc:8141
+#, gcc-internal-format
+msgid "no corresponding deallocation function for %qD"
+msgstr ""
+
+#: cp/call.cc:8144
+#, gcc-internal-format
+msgid "destroying delete %qD cannot be used to release the allocated memory if the initialization throws because the object is not constructed yet"
+msgstr ""
+
+#: cp/call.cc:8153
+#, gcc-internal-format
+msgid "no suitable %<operator %s%> for %qT"
+msgstr ""
+
+#: cp/call.cc:8189
+#, gcc-internal-format
+msgid "%q#D is private within this context"
+msgstr ""
+
+#: cp/call.cc:8190 cp/decl.cc:9122
+#, gcc-internal-format
+msgid "declared private here"
+msgstr ""
+
+#: cp/call.cc:8195
+#, gcc-internal-format
+msgid "%q#D is protected within this context"
+msgstr ""
+
+#: cp/call.cc:8196 cp/decl.cc:9123
+#, gcc-internal-format
+msgid "declared protected here"
+msgstr ""
+
+#: cp/call.cc:8203
+#, gcc-internal-format
+msgid "%q#D is inaccessible within this context"
+msgstr ""
+
+#: cp/call.cc:8284
+#, gcc-internal-format
+msgid "passing NULL to non-pointer argument %P of %qD"
+msgstr ""
+
+#: cp/call.cc:8287 cp/call.cc:8306 cp/decl.cc:10866 cp/decl.cc:10874
+#: cp/typeck.cc:4602
+#, gcc-internal-format
+msgid "  declared here"
+msgstr ""
+
+#: cp/call.cc:8291
+#, gcc-internal-format
+msgid "converting to non-pointer type %qT from NULL"
+msgstr ""
+
+#: cp/call.cc:8303
+#, gcc-internal-format
+msgid "converting %<false%> to pointer type for argument %P of %qD"
+msgstr ""
+
+#: cp/call.cc:8310
+#, gcc-internal-format
+msgid "converting %<false%> to pointer type %qT"
+msgstr ""
+
+#: cp/call.cc:8377
+#, gcc-internal-format
+msgid "  initializing argument %P of %qD"
+msgstr ""
+
+#: cp/call.cc:8398
+#, gcc-internal-format
+msgid "conversions to arrays of unknown bound are only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/call.cc:8448
+#, gcc-internal-format
+msgid "too many braces around initializer for %qT"
+msgstr ""
+
+#: cp/call.cc:8459
+msgid "converting to %qH from %qI requires direct-initialization"
+msgstr ""
+
+#: cp/call.cc:8471
+msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
+msgstr ""
+
+#: cp/call.cc:8479
+msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
+msgstr ""
+
+#: cp/call.cc:8495
+msgid "invalid user-defined conversion from %qH to %qI"
+msgstr ""
+
+#: cp/call.cc:8528 cp/cvt.cc:227
+msgid "invalid conversion from %qH to %qI"
+msgstr ""
+
+#: cp/call.cc:8575 cp/call.cc:8588
+#, gcc-internal-format
+msgid "converting to %qT from initializer list would use explicit constructor %qD"
+msgstr ""
+
+#: cp/call.cc:8581
+#, gcc-internal-format
+msgid "in C++11 and above a default constructor can be explicit"
+msgstr ""
+
+#: cp/call.cc:8861
+msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
+msgstr ""
+
+#: cp/call.cc:8870
+msgid "cannot bind non-const lvalue reference of type %qH to a value of type %qI"
+msgstr ""
+
+#: cp/call.cc:8875
+msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
+msgstr ""
+
+#. extype is volatile
+#: cp/call.cc:8878
+msgid "cannot bind lvalue reference of type %qH to an rvalue of type %qI"
+msgstr ""
+
+#: cp/call.cc:8891
+msgid "cannot bind reference of type %qH to %qI due to different array bounds"
+msgstr ""
+
+#: cp/call.cc:8894
+msgid "binding reference of type %qH to %qI discards qualifiers"
+msgstr ""
+
+#: cp/call.cc:8933
+#, gcc-internal-format
+msgid "cannot bind bit-field %qE to %qT"
+msgstr ""
+
+#: cp/call.cc:8936 cp/call.cc:8954
+#, gcc-internal-format
+msgid "cannot bind packed field %qE to %qT"
+msgstr ""
+
+#: cp/call.cc:8939
+#, gcc-internal-format
+msgid "cannot bind rvalue %qE to %qT"
+msgstr ""
+
+#: cp/call.cc:9140
+msgid "implicit conversion from %qH to %qI when passing argument to function"
+msgstr ""
+
+#: cp/call.cc:9169 cp/cvt.cc:2011
+#, gcc-internal-format
+msgid "scoped enum %qT passed through %<...%> as %qT before %<-fabi-version=6%>, %qT after"
+msgstr ""
+
+#: cp/call.cc:9213
+#, gcc-internal-format
+msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
+msgstr ""
+
+#: cp/call.cc:9249
+#, gcc-internal-format
+msgid "cannot receive reference type %qT through %<...%>"
+msgstr ""
+
+#: cp/call.cc:9259
+#, gcc-internal-format
+msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
+msgstr ""
+
+#: cp/call.cc:9327
+#, gcc-internal-format
+msgid "recursive evaluation of default argument for %q#D"
+msgstr ""
+
+#: cp/call.cc:9336
+#, gcc-internal-format
+msgid "call to %qD uses the default argument for parameter %P, which is not yet defined"
+msgstr ""
+
+#: cp/call.cc:9436
+#, gcc-internal-format
+msgid "argument of function call might be a candidate for a format attribute"
+msgstr ""
+
+#: cp/call.cc:9516
+#, gcc-internal-format
+msgid "use of multiversioned function without a default"
+msgstr ""
+
+#: cp/call.cc:10021
+#, gcc-internal-format
+msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
+msgstr ""
+
+#: cp/call.cc:10144
+#, gcc-internal-format
+msgid "passing %qT as %<this%> argument discards qualifiers"
+msgstr ""
+
+#: cp/call.cc:10147 cp/call.cc:12993
+#, gcc-internal-format
+msgid "  in call to %qD"
+msgstr ""
+
+#: cp/call.cc:10172
+#, gcc-internal-format
+msgid "%qT is not an accessible base of %qT"
+msgstr ""
+
+#: cp/call.cc:10397
+#, gcc-internal-format
+msgid "passing arguments to ellipsis of inherited constructor %qD"
+msgstr ""
+
+#: cp/call.cc:10534
+#, gcc-internal-format
+msgid "assignment from temporary %<initializer_list%> does not extend the lifetime of the underlying array"
+msgstr ""
+
+#: cp/call.cc:10901
+#, gcc-internal-format
+msgid "%qD writing to an object of type %#qT with no trivial copy-assignment"
+msgstr ""
+
+#: cp/call.cc:10904
+#, gcc-internal-format
+msgid "%qD writing to an object of non-trivial type %#qT%s"
+msgstr ""
+
+#: cp/call.cc:10909
+#, gcc-internal-format
+msgid "%qD writing to an object of type %#qT with %qs member %qD"
+msgstr ""
+
+#: cp/call.cc:10914
+#, gcc-internal-format
+msgid "%qD writing to an object of type %#qT containing a pointer to data member%s"
+msgstr ""
+
+#: cp/call.cc:10929
+#, gcc-internal-format
+msgid "; use assignment or value-initialization instead"
+msgstr ""
+
+#: cp/call.cc:10931
+#, gcc-internal-format
+msgid "; use assignment instead"
+msgstr ""
+
+#: cp/call.cc:10933
+#, gcc-internal-format
+msgid "; use value-initialization instead"
+msgstr ""
+
+#: cp/call.cc:10936
+#, gcc-internal-format
+msgid "%qD clearing an object of type %#qT with no trivial copy-assignment%s"
+msgstr ""
+
+#: cp/call.cc:10939
+#, gcc-internal-format
+msgid "%qD clearing an object of non-trivial type %#qT%s"
+msgstr ""
+
+#: cp/call.cc:10941
+#, gcc-internal-format
+msgid "%qD clearing an object of type %#qT containing a pointer-to-member%s"
+msgstr ""
+
+#: cp/call.cc:10962
+#, gcc-internal-format
+msgid "; use copy-assignment or copy-initialization instead"
+msgstr ""
+
+#: cp/call.cc:10964
+#, gcc-internal-format
+msgid "; use copy-assignment instead"
+msgstr ""
+
+#: cp/call.cc:10966
+#, gcc-internal-format
+msgid "; use copy-initialization instead"
+msgstr ""
+
+#: cp/call.cc:10969
+#, gcc-internal-format
+msgid "%qD writing to an object of type %#qT with no trivial copy-assignment%s"
+msgstr ""
+
+#: cp/call.cc:10972
+#, gcc-internal-format
+msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
+msgstr ""
+
+#: cp/call.cc:10975
+#, gcc-internal-format
+msgid "%qD writing to an object with a deleted copy constructor"
+msgstr ""
+
+#: cp/call.cc:10986
+#, gcc-internal-format
+msgid "%qD copying an object of non-trivial type %#qT from an array of %#qT"
+msgstr ""
+
+#: cp/call.cc:10998
+#, gcc-internal-format
+msgid "%qD copying an object of type %#qT with %qs member %qD from an array of %#qT; use assignment or copy-initialization instead"
+msgstr ""
+
+#: cp/call.cc:11017
+#, gcc-internal-format
+msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu bytes unchanged"
+msgstr ""
+
+#: cp/call.cc:11020
+#, gcc-internal-format
+msgid "%qD writing to an object of a non-trivial type %#qT leaves %wu byte unchanged"
+msgstr ""
+
+#: cp/call.cc:11030
+#, gcc-internal-format
+msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
+msgstr ""
+
+#: cp/call.cc:11033
+#, gcc-internal-format
+msgid "%qD moving an object of type %#qT with deleted copy constructor; use %<new%> and %<delete%> instead"
+msgstr ""
+
+#: cp/call.cc:11036
+#, gcc-internal-format
+msgid "%qD moving an object of type %#qT with deleted destructor"
+msgstr ""
+
+#: cp/call.cc:11045
+#, gcc-internal-format
+msgid "%qD moving an object of non-trivial type %#qT and size %E into a region of size %E"
+msgstr ""
+
+#: cp/call.cc:11067
+#, gcc-internal-format
+msgid "%#qT declared here"
+msgstr ""
+
+#: cp/call.cc:11121
+#, gcc-internal-format
+msgid "argument %u in call to function %qE has pointer to a non-trivially-copyable type (%qT)"
+msgstr ""
+
+#: cp/call.cc:11188
+#, gcc-internal-format
+msgid "constructor delegates to itself"
+msgstr ""
+
+#: cp/call.cc:11463 cp/typeck.cc:10386
+msgid "cannot convert %qH to %qI"
+msgstr ""
+
+#: cp/call.cc:11485
+#, gcc-internal-format
+msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
+msgstr ""
+
+#: cp/call.cc:11517
+#, gcc-internal-format
+msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
+msgstr ""
+
+#: cp/call.cc:11565
+#, gcc-internal-format
+msgid "call to non-function %qD"
+msgstr ""
+
+#: cp/call.cc:11603 cp/pt.cc:17213 cp/typeck.cc:3479
+#, gcc-internal-format
+msgid "cannot call constructor %<%T::%D%> directly"
+msgstr ""
+
+#: cp/call.cc:11605
+#, gcc-internal-format
+msgid "for a function-style cast, remove the redundant %<::%D%>"
+msgstr ""
+
+#: cp/call.cc:11787
+#, gcc-internal-format
+msgid "no matching function for call to %<%s(%A)%>"
+msgstr ""
+
+#: cp/call.cc:11790
+#, gcc-internal-format
+msgid "call of overloaded %<%s(%A)%> is ambiguous"
+msgstr ""
+
+#: cp/call.cc:11813
+#, gcc-internal-format
+msgid "pure virtual %q#D called from non-static data member initializer"
+msgstr ""
+
+#: cp/call.cc:11818
+#, gcc-internal-format
+msgid "pure virtual %q#D called from constructor"
+msgstr ""
+
+#: cp/call.cc:11819
+#, gcc-internal-format
+msgid "pure virtual %q#D called from destructor"
+msgstr ""
+
+#: cp/call.cc:11842
+#, gcc-internal-format
+msgid "cannot call member function %qD without object"
+msgstr ""
+
+#: cp/call.cc:12991
+#, gcc-internal-format
+msgid "passing %qT chooses %qT over %qT"
+msgstr ""
+
+#: cp/call.cc:13017
+#, gcc-internal-format
+msgid "C++20 says that these are ambiguous, even though the second is reversed:"
+msgstr ""
+
+#: cp/call.cc:13040
+#, gcc-internal-format
+msgid "try making the operator a %<const%> member function"
+msgstr ""
+
+#: cp/call.cc:13103
+#, gcc-internal-format
+msgid "choosing %qD over %qD"
+msgstr ""
+
+#: cp/call.cc:13104
+msgid "  for conversion from %qH to %qI"
+msgstr ""
+
+#: cp/call.cc:13107
+#, gcc-internal-format
+msgid "  because conversion sequence for the argument is better"
+msgstr ""
+
+#: cp/call.cc:13391
+#, gcc-internal-format
+msgid "default argument mismatch in overload resolution"
+msgstr ""
+
+#: cp/call.cc:13395
+#, gcc-internal-format
+msgid " candidate 1: %q#F"
+msgstr ""
+
+#: cp/call.cc:13397
+#, gcc-internal-format
+msgid " candidate 2: %q#F"
+msgstr ""
+
+#: cp/call.cc:13443
+#, gcc-internal-format
+msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
+msgstr ""
+
+#: cp/call.cc:13855
+#, gcc-internal-format
+msgid "a temporary bound to %qD only persists until the constructor exits"
+msgstr ""
+
+#: cp/call.cc:14008
+msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
+msgstr ""
+
+#: cp/call.cc:14012
+msgid "invalid initialization of reference of type %qH from expression of type %qI"
+msgstr ""
+
+#: cp/call.cc:14330
+#, gcc-internal-format
+msgid "possibly dangling reference to a temporary"
+msgstr ""
+
+#: cp/call.cc:14331
+#, gcc-internal-format
+msgid "the temporary was destroyed at the end of the full expression %qE"
+msgstr ""
+
+#: cp/call.cc:14599
+#, gcc-internal-format
+msgid "explicit conversion function was not considered"
+msgstr ""
+
+#: cp/class.cc:322
+#, gcc-internal-format
+msgid "cannot convert from pointer to base class %qT to pointer to derived class %qT because the base is virtual"
+msgstr ""
+
+#: cp/class.cc:326
+#, gcc-internal-format
+msgid "cannot convert from base class %qT to derived class %qT because the base is virtual"
+msgstr ""
+
+#: cp/class.cc:333
+#, gcc-internal-format
+msgid "cannot convert from pointer to base class %qT to pointer to derived class %qT via virtual base %qT"
+msgstr ""
+
+#: cp/class.cc:338
+#, gcc-internal-format
+msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
+msgstr ""
+
+#: cp/class.cc:391
+#, gcc-internal-format
+msgid "cannot convert from %qT to base class %qT because %qT is incomplete"
+msgstr ""
+
+#: cp/class.cc:1435
+#, gcc-internal-format
+msgid "%q#D conflicts with version inherited from %qT"
+msgstr ""
+
+#: cp/class.cc:1438
+#, gcc-internal-format
+msgid "version inherited from %qT declared here"
+msgstr ""
+
+#: cp/class.cc:1457
+#, gcc-internal-format
+msgid "%q#D cannot be overloaded with %q#D"
+msgstr ""
+
+#: cp/class.cc:1459 cp/decl.cc:1928 cp/decl.cc:1940 cp/decl.cc:1965
+#: cp/decl.cc:1988 cp/name-lookup.cc:2899 cp/name-lookup.cc:3217
+#, gcc-internal-format
+msgid "previous declaration %q#D"
+msgstr ""
+
+#: cp/class.cc:1501
+#, gcc-internal-format
+msgid "conflicting access specifications for method %q+D, ignored"
+msgstr ""
+
+#: cp/class.cc:1504
+#, gcc-internal-format
+msgid "conflicting access specifications for field %qE, ignored"
+msgstr ""
+
+#: cp/class.cc:1607
+#, gcc-internal-format
+msgid "%qD invalid in %q#T because of local method %q#D with same name"
+msgstr ""
+
+#: cp/class.cc:1611
+#, gcc-internal-format
+msgid "local method %q#D declared here"
+msgstr ""
+
+#: cp/class.cc:1616
+#, gcc-internal-format
+msgid "%qD invalid in %q#T because of local member %q#D with same name"
+msgstr ""
+
+#: cp/class.cc:1620
+#, gcc-internal-format
+msgid "local member %q#D declared here"
+msgstr ""
+
+#: cp/class.cc:1691
+#, gcc-internal-format
+msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
+msgstr ""
+
+#: cp/class.cc:1694 cp/class.cc:1701 cp/class.cc:1708 cp/class.cc:1720
+#: cp/cvt.cc:1118 rust/backend/rust-tree.cc:643
+#, gcc-internal-format
+msgid "%qT declared here"
+msgstr ""
+
+#: cp/class.cc:1699
+#, gcc-internal-format
+msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
+msgstr ""
+
+#: cp/class.cc:1706
+#, gcc-internal-format
+msgid "%qT does not have the %E ABI tag that base %qT has"
+msgstr ""
+
+#: cp/class.cc:1714
+#, gcc-internal-format
+msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
+msgstr ""
+
+#: cp/class.cc:2025
+#, gcc-internal-format
+msgid "cannot derive from %<final%> base %qT in derived type %qT"
+msgstr ""
+
+#: cp/class.cc:2499
+#, gcc-internal-format
+msgid "all member functions in class %qT are private"
+msgstr ""
+
+#: cp/class.cc:2511
+#, gcc-internal-format
+msgid "%q#T only defines a private destructor and has no friends"
+msgstr ""
+
+#: cp/class.cc:2554
+#, gcc-internal-format
+msgid "%q#T only defines private constructors and has no friends"
+msgstr ""
+
+#: cp/class.cc:2558
+#, gcc-internal-format
+msgid "%q#D is public, but requires an existing %q#T object"
+msgstr ""
+
+#: cp/class.cc:2848
+#, gcc-internal-format
+msgid "no unique final overrider for %qD in %qT"
+msgstr ""
+
+#: cp/class.cc:3208
+#, gcc-internal-format
+msgid "%qD can be marked override"
+msgstr ""
+
+#: cp/class.cc:3211
+#, gcc-internal-format
+msgid "%q+#D marked %<override%>, but does not override"
+msgstr ""
+
+#: cp/class.cc:3226
+#, gcc-internal-format
+msgid "%q+#D marked %<final%>, but is not virtual"
+msgstr ""
+
+#: cp/class.cc:3303
+#, gcc-internal-format
+msgid "%qD was hidden"
+msgstr ""
+
+#: cp/class.cc:3304
+#, gcc-internal-format
+msgid "  by %qD"
+msgstr ""
+
+#: cp/class.cc:3516
+#, gcc-internal-format
+msgid "the ellipsis in %qD is not inherited"
+msgstr ""
+
+#: cp/class.cc:3720
+#, gcc-internal-format
+msgid "bit-field %q#D with non-integral type %qT"
+msgstr ""
+
+#: cp/class.cc:3736
+#, gcc-internal-format
+msgid "bit-field %q+D width not an integer constant"
+msgstr ""
+
+#: cp/class.cc:3741
+#, gcc-internal-format
+msgid "negative width in bit-field %q+D"
+msgstr ""
+
+#: cp/class.cc:3746
+#, gcc-internal-format
+msgid "zero width for bit-field %q+D"
+msgstr ""
+
+#: cp/class.cc:3756
+#, gcc-internal-format
+msgid "width of %qD exceeds its type"
+msgstr ""
+
+#: cp/class.cc:3762
+#, gcc-internal-format
+msgid "%qD is too small to hold all values of %q#T"
+msgstr ""
+
+#: cp/class.cc:3823
+#, gcc-internal-format
+msgid "member %q+#D with constructor not allowed in union"
+msgstr ""
+
+#: cp/class.cc:3826
+#, gcc-internal-format
+msgid "member %q+#D with destructor not allowed in union"
+msgstr ""
+
+#: cp/class.cc:3828
+#, gcc-internal-format
+msgid "member %q+#D with copy assignment operator not allowed in union"
+msgstr ""
+
+#: cp/class.cc:3832
+#, gcc-internal-format
+msgid "unrestricted unions only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/class.cc:3948
+#, gcc-internal-format
+msgid "in C++98 %q+D may not be static because it is a member of a union"
+msgstr ""
+
+#: cp/class.cc:3961
+#, gcc-internal-format
+msgid "non-static data member %q+D in a union may not have reference type %qT"
+msgstr ""
+
+#: cp/class.cc:3974
+#, gcc-internal-format
+msgid "data member %q+D invalidly declared function type"
+msgstr ""
+
+#: cp/class.cc:3980
+#, gcc-internal-format
+msgid "data member %q+D invalidly declared method type"
+msgstr ""
+
+#: cp/class.cc:4051
+#, gcc-internal-format
+msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
+msgstr ""
+
+#: cp/class.cc:4103
+#, gcc-internal-format
+msgid "member %q+D cannot be declared as a %<mutable%> reference"
+msgstr ""
+
+#: cp/class.cc:4106
+#, gcc-internal-format
+msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
+msgstr ""
+
+#: cp/class.cc:4137
+#, gcc-internal-format
+msgid "multiple fields in union %qT initialized"
+msgstr ""
+
+#: cp/class.cc:4139
+#, gcc-internal-format
+msgid "initialized member %q+D declared here"
+msgstr ""
+
+#: cp/class.cc:4187
+#, gcc-internal-format
+msgid "field %q#D with same name as class"
+msgstr ""
+
+#: cp/class.cc:4215
+#, gcc-internal-format
+msgid "%q#T has pointer data members"
+msgstr ""
+
+#: cp/class.cc:4220
+#, gcc-internal-format
+msgid "  but does not declare %<%T(const %T&)%>"
+msgstr ""
+
+#: cp/class.cc:4222
+#, gcc-internal-format
+msgid "  or %<operator=(const %T&)%>"
+msgstr ""
+
+#: cp/class.cc:4226
+#, gcc-internal-format
+msgid "  but does not declare %<operator=(const %T&)%>"
+msgstr ""
+
+#: cp/class.cc:4228
+#, gcc-internal-format
+msgid "pointer member %q+D declared here"
+msgstr ""
+
+#: cp/class.cc:4316
+#, gcc-internal-format
+msgid "layout of %qs member of type %qT changes in %qs"
+msgstr ""
+
+#: cp/class.cc:4709
+#, gcc-internal-format
+msgid "alignment of %qD increased in %<-fabi-version=9%> (GCC 5.2)"
+msgstr ""
+
+#: cp/class.cc:4712
+#, gcc-internal-format
+msgid "alignment of %qD will increase in %<-fabi-version=9%>"
+msgstr ""
+
+#: cp/class.cc:5040
+#, gcc-internal-format
+msgid "initializer specified for non-virtual method %q+D"
+msgstr ""
+
+#: cp/class.cc:5081
+#, gcc-internal-format
+msgid "no viable destructor for %qT"
+msgstr ""
+
+#: cp/class.cc:5083
+#, gcc-internal-format
+msgid "destructor for %qT is ambiguous"
+msgstr ""
+
+#: cp/class.cc:5551
+#, gcc-internal-format
+msgid "method overrides both %<transaction_pure%> and %qE methods"
+msgstr ""
+
+#: cp/class.cc:5572
+#, gcc-internal-format
+msgid "method declared %qE overriding %qE method"
+msgstr ""
+
+#: cp/class.cc:6204 cp/constexpr.cc:299
+#, gcc-internal-format
+msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
+msgstr ""
+
+#: cp/class.cc:6230 rust/backend/rust-tree.cc:6076
+#, gcc-internal-format
+msgid "%q+T is not literal because:"
+msgstr ""
+
+#: cp/class.cc:6233 rust/backend/rust-tree.cc:6079
+#, gcc-internal-format
+msgid "  %qT is a closure type, which is only literal in C++17 and later"
+msgstr ""
+
+#: cp/class.cc:6236 rust/backend/rust-tree.cc:6087
+#, gcc-internal-format
+msgid "  %q+T has a non-trivial destructor"
+msgstr ""
+
+#: cp/class.cc:6239 rust/backend/rust-tree.cc:6084
+#, gcc-internal-format
+msgid "  %q+T does not have %<constexpr%> destructor"
+msgstr ""
+
+#: cp/class.cc:6247 rust/backend/rust-tree.cc:6092
+#, gcc-internal-format
+msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
+msgstr ""
+
+#: cp/class.cc:6280 rust/backend/rust-tree.cc:6124
+#, gcc-internal-format
+msgid "  base class %qT of %q+T is non-literal"
+msgstr ""
+
+#: cp/class.cc:6295 rust/backend/rust-tree.cc:6138
+#, gcc-internal-format
+msgid "  non-static data member %qD has non-literal type"
+msgstr ""
+
+#: cp/class.cc:6302 rust/backend/rust-tree.cc:6145
+#, gcc-internal-format
+msgid "  non-static data member %qD has volatile type"
+msgstr ""
+
+#: cp/class.cc:6435
+#, gcc-internal-format
+msgid "base class %q#T has accessible non-virtual destructor"
+msgstr ""
+
+#: cp/class.cc:6464
+#, gcc-internal-format
+msgid "non-static reference %q#D in class without a constructor"
+msgstr ""
+
+#: cp/class.cc:6470
+#, gcc-internal-format
+msgid "non-static const member %q#D in class without a constructor"
+msgstr ""
+
+#: cp/class.cc:6816
+#, gcc-internal-format
+msgid "offset of %qT base class for %<-std=c++14%> and up changes in %<-fabi-version=17%> (GCC 12)"
+msgstr ""
+
+#: cp/class.cc:6820
+#, gcc-internal-format
+msgid "offset of %qD for %<-std=c++14%> and up changes in %<-fabi-version=17%> (GCC 12)"
+msgstr ""
+
+#: cp/class.cc:6860
+#, gcc-internal-format
+msgid "direct base %qT inaccessible in %qT due to ambiguity"
+msgstr ""
+
+#: cp/class.cc:6872
+#, gcc-internal-format
+msgid "virtual base %qT inaccessible in %qT due to ambiguity"
+msgstr ""
+
+#: cp/class.cc:7114
+#, gcc-internal-format
+msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
+msgstr ""
+
+#: cp/class.cc:7310
+#, gcc-internal-format
+msgid "size of type %qT is too large (%qE bytes)"
+msgstr ""
+
+#: cp/class.cc:7596
+#, gcc-internal-format
+msgid "invalid use of %q#T with a zero-size array in %q#D"
+msgstr ""
+
+#: cp/class.cc:7598
+#, gcc-internal-format
+msgid "invalid use of %q#T with a flexible array member in %q#T"
+msgstr ""
+
+#: cp/class.cc:7603
+#, gcc-internal-format
+msgid "array member %q#D declared here"
+msgstr ""
+
+#: cp/class.cc:7631
+#, gcc-internal-format
+msgid "zero-size array member %qD not at end of %q#T"
+msgstr ""
+
+#: cp/class.cc:7633
+#, gcc-internal-format
+msgid "zero-size array member %qD in an otherwise empty %q#T"
+msgstr ""
+
+#: cp/class.cc:7642 cp/class.cc:7673
+#, gcc-internal-format
+msgid "in the definition of %q#T"
+msgstr ""
+
+#: cp/class.cc:7650
+#, gcc-internal-format
+msgid "flexible array member %qD not at end of %q#T"
+msgstr ""
+
+#: cp/class.cc:7652
+#, gcc-internal-format
+msgid "flexible array member %qD in an otherwise empty %q#T"
+msgstr ""
+
+#: cp/class.cc:7671
+#, gcc-internal-format
+msgid "next member %q#D declared here"
+msgstr ""
+
+#: cp/class.cc:7785 cp/decl.cc:17649 cp/parser.cc:27638
+#, gcc-internal-format
+msgid "redefinition of %q#T"
+msgstr ""
+
+#: cp/class.cc:7929
+#, gcc-internal-format
+msgid "%q#T has virtual functions and accessible non-virtual destructor"
+msgstr ""
+
+#: cp/class.cc:7957
+#, gcc-internal-format
+msgid "type transparent %q#T does not have any fields"
+msgstr ""
+
+#: cp/class.cc:7963
+#, gcc-internal-format
+msgid "type transparent class %qT has base classes"
+msgstr ""
+
+#: cp/class.cc:7967
+#, gcc-internal-format
+msgid "type transparent class %qT has virtual functions"
+msgstr ""
+
+#: cp/class.cc:7973
+#, gcc-internal-format
+msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
+msgstr ""
+
+#: cp/class.cc:8144
+#, gcc-internal-format
+msgid "definition of %qD does not match %<#include <initializer_list>%>"
+msgstr ""
+
+#: cp/class.cc:8155
+#, gcc-internal-format
+msgid "trying to finish struct, but kicked out due to previous parse errors"
+msgstr ""
+
+#: cp/class.cc:8662
+#, gcc-internal-format
+msgid "language string %<\"%E\"%> not recognized"
+msgstr ""
+
+#: cp/class.cc:8752
+#, gcc-internal-format
+msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
+msgstr ""
+
+#: cp/class.cc:8910
+#, gcc-internal-format
+msgid "no matches converting function %qD to type %q#T"
+msgstr ""
+
+#: cp/class.cc:8937
+#, gcc-internal-format
+msgid "converting overloaded function %qD to type %q#T is ambiguous"
+msgstr ""
+
+#: cp/class.cc:8979
+#, gcc-internal-format
+msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function."
+msgstr ""
+
+#: cp/class.cc:8984
+#, gcc-internal-format
+msgid "a pointer to explicit object member function can only be formed with %<&%E%>"
+msgstr ""
+
+#: cp/class.cc:8994
+#, gcc-internal-format
+msgid "assuming pointer to member %qD"
+msgstr ""
+
+#: cp/class.cc:8997
+#, gcc-internal-format
+msgid "(a pointer to member can only be formed with %<&%E%>)"
+msgstr ""
+
+#: cp/class.cc:9076
+#, gcc-internal-format
+msgid "not enough type information"
+msgstr ""
+
+#: cp/class.cc:9096
+#, gcc-internal-format
+msgid "cannot convert %qE from type %qT to type %qT"
+msgstr ""
+
+#: cp/class.cc:9395
+#, gcc-internal-format
+msgid "declaration of %q#D changes meaning of %qD"
+msgstr ""
+
+#: cp/class.cc:9398
+#, gcc-internal-format
+msgid "used here to mean %q#D"
+msgstr ""
+
+#: cp/constexpr.cc:112
+#, gcc-internal-format
+msgid "the type %qT of %<constexpr%> variable %qD is not literal"
+msgstr ""
+
+#: cp/constexpr.cc:123
+#, gcc-internal-format
+msgid "variable %qD of non-literal type %qT in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
+msgstr ""
+
+#: cp/constexpr.cc:136
+#, gcc-internal-format
+msgid "%<constexpr%> variable %qD has variably-modified type %qT"
+msgstr ""
+
+#: cp/constexpr.cc:236
+#, gcc-internal-format
+msgid "inherited constructor %qD is not %<constexpr%>"
+msgstr ""
+
+#. constexpr_fundef_p
+#: cp/constexpr.cc:250
+#, gcc-internal-format
+msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
+msgstr ""
+
+#: cp/constexpr.cc:263
+#, gcc-internal-format
+msgid "lambdas are implicitly %<constexpr%> only in C++17 and later"
+msgstr ""
+
+#: cp/constexpr.cc:270 cp/decl.cc:14694
+#, gcc-internal-format
+msgid "%<constexpr%> destructors only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#. constexpr_fundef_p
+#: cp/constexpr.cc:283
+#, gcc-internal-format
+msgid "invalid return type %qT of %<constexpr%> function %q+D"
+msgstr ""
+
+#: cp/constexpr.cc:310
+#, gcc-internal-format
+msgid "%q#T has virtual base classes"
+msgstr ""
+
+#: cp/constexpr.cc:568
+#, gcc-internal-format
+msgid "%<constexpr%> constructor does not have empty body"
+msgstr ""
+
+#: cp/constexpr.cc:826
+#, gcc-internal-format
+msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
+msgstr ""
+
+#: cp/constexpr.cc:887
+#, gcc-internal-format
+msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
+msgstr ""
+
+#: cp/constexpr.cc:950
+#, gcc-internal-format
+msgid "body of %<constexpr%> function %qD not a return-statement"
+msgstr ""
+
+#: cp/constexpr.cc:1078
+#, gcc-internal-format
+msgid "%qD is not usable as a %<constexpr%> function because:"
+msgstr ""
+
+#: cp/constexpr.cc:1315 cp/constexpr.cc:6364
+#, gcc-internal-format
+msgid "destroying %qE outside its lifetime"
+msgstr ""
+
+#: cp/constexpr.cc:1606 cp/constexpr.cc:3317
+#: rust/backend/rust-constexpr.cc:3326 rust/backend/rust-constexpr.cc:3589
+#, gcc-internal-format
+msgid "%<constexpr%> call flows off the end of the function"
+msgstr ""
+
+#: cp/constexpr.cc:1608 cp/constexpr.cc:1707 cp/constexpr.cc:1716
+#: cp/constexpr.cc:3589 rust/backend/rust-constexpr.cc:3331
+#: rust/backend/rust-constexpr.cc:3341 rust/backend/rust-constexpr.cc:4324
+#, gcc-internal-format
+msgid "%q+E is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:1898 cp/constexpr.cc:5930 cp/constexpr.cc:8242
+#: rust/backend/rust-constexpr.cc:875 rust/backend/rust-constexpr.cc:2494
+#, gcc-internal-format
+msgid "dereferencing a null pointer"
+msgstr ""
+
+#: cp/constexpr.cc:2086
+#, gcc-internal-format
+msgid "the comparison reduces to %qE"
+msgstr ""
+
+#: cp/constexpr.cc:2089
+#, gcc-internal-format
+msgid "%qE evaluates to false"
+msgstr ""
+
+#: cp/constexpr.cc:2168
+#, gcc-internal-format
+msgid "failed %<assume%> attribute assumption"
+msgstr ""
+
+#: cp/constexpr.cc:2203 cp/constexpr.cc:9692
+#: rust/backend/rust-constexpr.cc:5758
+#, gcc-internal-format
+msgid "call to internal function %qE"
+msgstr ""
+
+#: cp/constexpr.cc:2257 rust/backend/rust-constexpr.cc:2615
+#, gcc-internal-format
+msgid "modifying a const object %qE is not allowed in a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:2285 rust/backend/rust-constexpr.cc:2618
+#, gcc-internal-format
+msgid "originally declared %<const%> here"
+msgstr ""
+
+#: cp/constexpr.cc:2541 cp/constexpr.cc:2597 cp/constexpr.cc:2630
+#: cp/constexpr.cc:2652
+#, gcc-internal-format
+msgid "reference %<dynamic_cast%> failed"
+msgstr ""
+
+#: cp/constexpr.cc:2542
+#, gcc-internal-format
+msgid "dynamic type %qT of its operand does not have a base class of type %qT"
+msgstr ""
+
+#: cp/constexpr.cc:2566
+#, gcc-internal-format
+msgid "virtual table pointer is used uninitialized"
+msgstr ""
+
+#: cp/constexpr.cc:2598 cp/constexpr.cc:2631
+#, gcc-internal-format
+msgid "static type %qT of its operand is a non-public base class of dynamic type %qT"
+msgstr ""
+
+#: cp/constexpr.cc:2654
+#, gcc-internal-format
+msgid "%qT is an ambiguous base class of dynamic type %qT of its operand"
+msgstr ""
+
+#: cp/constexpr.cc:2657
+#, gcc-internal-format
+msgid "dynamic type %qT of its operand does not have an unambiguous public base class %qT"
+msgstr ""
+
+#: cp/constexpr.cc:2734 cp/constexpr.cc:3014 cp/constexpr.cc:9728
+#: rust/backend/rust-constexpr.cc:5789
+#, gcc-internal-format
+msgid "call to non-%<constexpr%> function %qD"
+msgstr ""
+
+#. virtual_offset is only set for virtual bases, which make the
+#. class non-literal, so we don't need to handle it here.
+#: cp/constexpr.cc:2740
+#, gcc-internal-format
+msgid "calling constexpr member function %qD through virtual base subobject"
+msgstr ""
+
+#: cp/constexpr.cc:2856 rust/backend/rust-constexpr.cc:3387
+#, gcc-internal-format
+msgid "expression %qE does not designate a %<constexpr%> function"
+msgstr ""
+
+#: cp/constexpr.cc:2934
+#, gcc-internal-format
+msgid "array deallocation of object allocated with non-array allocation"
+msgstr ""
+
+#: cp/constexpr.cc:2938 cp/constexpr.cc:2961
+#, gcc-internal-format
+msgid "allocation performed here"
+msgstr ""
+
+#: cp/constexpr.cc:2957
+#, gcc-internal-format
+msgid "non-array deallocation of object allocated with array allocation"
+msgstr ""
+
+#: cp/constexpr.cc:2974
+#, gcc-internal-format
+msgid "deallocation of already deallocated storage"
+msgstr ""
+
+#: cp/constexpr.cc:2981
+#, gcc-internal-format
+msgid "deallocation of storage that was not previously allocated"
+msgstr ""
+
+#: cp/constexpr.cc:3098 rust/backend/rust-constexpr.cc:3442
+#, gcc-internal-format
+msgid "%qD called in a constant expression before its definition is complete"
+msgstr ""
+
+#: cp/constexpr.cc:3105
+#, gcc-internal-format
+msgid "%qD called in a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:3109 rust/backend/rust-constexpr.cc:3456
+#, gcc-internal-format
+msgid "%qD used before its definition"
+msgstr ""
+
+#: cp/constexpr.cc:3181 rust/backend/rust-constexpr.cc:3498
+#, gcc-internal-format
+msgid "call has circular dependency"
+msgstr ""
+
+#: cp/constexpr.cc:3192 rust/backend/rust-constexpr.cc:3509
+#, gcc-internal-format
+msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-depth=%> to increase the maximum)"
+msgstr ""
+
+#: cp/constexpr.cc:3547
+#, gcc-internal-format
+msgid "reference to %qD is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:3550
+#, gcc-internal-format
+msgid "pointer to %qD is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:3556
+#, gcc-internal-format
+msgid "address of non-static constexpr variable %qD may differ on each invocation of the enclosing function; add %<static%> to give it a constant address"
+msgstr ""
+
+#: cp/constexpr.cc:3632
+#, gcc-internal-format
+msgid "right operand of shift expression %q+E is negative"
+msgstr ""
+
+#: cp/constexpr.cc:3639
+#, gcc-internal-format
+msgid "right operand of shift expression %q+E is greater than or equal to the precision %wu of the left operand"
+msgstr ""
+
+#: cp/constexpr.cc:3662
+#, gcc-internal-format
+msgid "left operand of shift expression %q+E is negative"
+msgstr ""
+
+#: cp/constexpr.cc:3681
+#, gcc-internal-format
+msgid "shift expression %q+E overflows"
+msgstr ""
+
+#: cp/constexpr.cc:3880
+#, gcc-internal-format
+msgid "arithmetic involving a null pointer in %qE"
+msgstr ""
+
+#: cp/constexpr.cc:4315 rust/backend/rust-constexpr.cc:4399
+#, gcc-internal-format
+msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
+msgstr ""
+
+#: cp/constexpr.cc:4318 rust/backend/rust-constexpr.cc:4404
+#, gcc-internal-format
+msgid "nonzero array subscript %qE is used with array %qD of type %qT with unknown bounds"
+msgstr ""
+
+#: cp/constexpr.cc:4323 rust/backend/rust-constexpr.cc:4411
+#, gcc-internal-format
+msgid "array subscript value %qE is outside the bounds of array type %qT"
+msgstr ""
+
+#: cp/constexpr.cc:4326 rust/backend/rust-constexpr.cc:4416
+#, gcc-internal-format
+msgid "nonzero array subscript %qE is used with array of type %qT with unknown bounds"
+msgstr ""
+
+#: cp/constexpr.cc:4515 rust/backend/rust-constexpr.cc:1667
+#, gcc-internal-format
+msgid "accessing uninitialized array element"
+msgstr ""
+
+#: cp/constexpr.cc:4577 rust/backend/rust-constexpr.cc:1724
+#, gcc-internal-format
+msgid "dereferencing a null pointer in %qE"
+msgstr ""
+
+#: cp/constexpr.cc:4596 cp/constexpr.cc:4712 cp/constexpr.cc:4724
+#: cp/constexpr.cc:7423 cp/constexpr.cc:7553 cp/constexpr.cc:9642
+#: rust/backend/rust-constexpr.cc:1738 rust/backend/rust-constexpr.cc:1983
+#: rust/backend/rust-constexpr.cc:2225 rust/backend/rust-constexpr.cc:4743
+#: rust/backend/rust-constexpr.cc:5712
+#, gcc-internal-format
+msgid "%qE is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:4604 rust/backend/rust-constexpr.cc:1744
+#, gcc-internal-format
+msgid "mutable %qD is not usable in a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:4636 cp/constexpr.cc:4672 cp/constexpr.cc:6528
+#: rust/backend/rust-constexpr.cc:1774 rust/backend/rust-constexpr.cc:1797
+#, gcc-internal-format
+msgid "accessing uninitialized member %qD"
+msgstr ""
+
+#: cp/constexpr.cc:4638 cp/constexpr.cc:4651 cp/constexpr.cc:6523
+#: rust/backend/rust-constexpr.cc:1776
+#, gcc-internal-format
+msgid "accessing %qD member instead of initialized %qD member in constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:4790
+#, gcc-internal-format
+msgid "%qs is not a constant expression because %qT is a union type"
+msgstr ""
+
+#: cp/constexpr.cc:4793
+#, gcc-internal-format
+msgid "%qs is not a constant expression because %qT contains a union type"
+msgstr ""
+
+#: cp/constexpr.cc:4804
+#, gcc-internal-format
+msgid "%qs is not a constant expression because %qT is a pointer type"
+msgstr ""
+
+#: cp/constexpr.cc:4807
+#, gcc-internal-format
+msgid "%qs is not a constant expression because %qT contains a pointer type"
+msgstr ""
+
+#: cp/constexpr.cc:4818
+#, gcc-internal-format
+msgid "%qs is not a constant expression because %qT is a reference type"
+msgstr ""
+
+#: cp/constexpr.cc:4821
+#, gcc-internal-format
+msgid "%qs is not a constant expression because %qT contains a reference type"
+msgstr ""
+
+#: cp/constexpr.cc:4832
+#, gcc-internal-format
+msgid "%qs is not a constant expression because %qT is a pointer to member type"
+msgstr ""
+
+#: cp/constexpr.cc:4836
+#, gcc-internal-format
+msgid "%qs is not a constant expression because %qT contains a pointer to member type"
+msgstr ""
+
+#: cp/constexpr.cc:4847
+#, gcc-internal-format
+msgid "%qs is not a constant expression because %qT is volatile"
+msgstr ""
+
+#: cp/constexpr.cc:4850
+#, gcc-internal-format
+msgid "%qs is not a constant expression because %qT contains a volatile subobject"
+msgstr ""
+
+#: cp/constexpr.cc:5005
+#, gcc-internal-format
+msgid "%qs cannot be constant evaluated on the target"
+msgstr ""
+
+#: cp/constexpr.cc:5014 cp/constexpr.cc:5024
+#, gcc-internal-format
+msgid "%qs cannot be constant evaluated because the type is too large"
+msgstr ""
+
+#: cp/constexpr.cc:5044
+#, gcc-internal-format
+msgid "%qs cannot be constant evaluated because the argument cannot be encoded"
+msgstr ""
+
+#: cp/constexpr.cc:5090
+#, gcc-internal-format
+msgid "%qs accessing uninitialized byte at offset %d"
+msgstr ""
+
+#: cp/constexpr.cc:5102
+#, gcc-internal-format
+msgid "%qs cannot be constant evaluated because the argument cannot be interpreted"
+msgstr ""
+
+#: cp/constexpr.cc:5950 rust/backend/rust-constexpr.cc:895
+#, gcc-internal-format
+msgid "accessing value of %qE through a %qT glvalue in a constant expression"
+msgstr ""
+
+#. Provide a more accurate message for deleted variables.
+#: cp/constexpr.cc:5990 cp/constexpr.cc:6023
+#, gcc-internal-format
+msgid "use of allocated storage after deallocation in a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:5992 cp/constexpr.cc:6018 cp/constexpr.cc:6025
+#: cp/constexpr.cc:6359
+#, gcc-internal-format
+msgid "allocated here"
+msgstr ""
+
+#: cp/constexpr.cc:5996
+#, gcc-internal-format
+msgid "accessing %qE outside its lifetime"
+msgstr ""
+
+#: cp/constexpr.cc:6016
+#, gcc-internal-format
+msgid "the content of uninitialized storage is not usable in a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:6028 rust/backend/rust-constexpr.cc:4041
+#, gcc-internal-format
+msgid "the value of %qD is not usable in a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:6036
+#, gcc-internal-format
+msgid "%qD used in its own initializer"
+msgstr ""
+
+#: cp/constexpr.cc:6041
+#, gcc-internal-format
+msgid "%q#D is not const"
+msgstr ""
+
+#: cp/constexpr.cc:6044
+#, gcc-internal-format
+msgid "%q#D is volatile"
+msgstr ""
+
+#: cp/constexpr.cc:6049 cp/constexpr.cc:6056
+#, gcc-internal-format
+msgid "%qD was not initialized with a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:6062
+#, gcc-internal-format
+msgid "%qD was not declared %<constexpr%>"
+msgstr ""
+
+#: cp/constexpr.cc:6065
+#, gcc-internal-format
+msgid "%qD does not have integral or enumeration type"
+msgstr ""
+
+#: cp/constexpr.cc:6357
+#, gcc-internal-format
+msgid "modification of allocated storage after deallocation is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:6366
+#, gcc-internal-format
+msgid "modification of %qE outside its lifetime is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:6373
+#, gcc-internal-format
+msgid "destroying %qE from outside current evaluation is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:6376
+#, gcc-internal-format
+msgid "modification of %qE from outside current evaluation is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:6503
+#, gcc-internal-format
+msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
+msgstr ""
+
+#: cp/constexpr.cc:6532
+#, gcc-internal-format
+msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
+msgstr ""
+
+#: cp/constexpr.cc:6539
+#, gcc-internal-format
+msgid "initializing %qD requires a member access expression as the left operand of the assignment"
+msgstr ""
+
+#: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
+#, gcc-internal-format
+msgid "change of the active member of a union from %qD to %qD during initialization"
+msgstr ""
+
+#: cp/constexpr.cc:6999 cp/constexpr.cc:8591 cp/constexpr.cc:8603
+#: rust/backend/rust-constexpr.cc:4668
+#, gcc-internal-format
+msgid "statement is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:7095 rust/backend/rust-constexpr.cc:4933
+#, gcc-internal-format
+msgid "%<constexpr%> loop iteration count exceeds limit of %d (use %<-fconstexpr-loop-limit=%> to increase the limit)"
+msgstr ""
+
+#: cp/constexpr.cc:7202 rust/backend/rust-constexpr.cc:999
+#, gcc-internal-format
+msgid "inline assembly is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:7204 rust/backend/rust-constexpr.cc:1000
+#, gcc-internal-format
+msgid "only unevaluated inline assembly is allowed in a %<constexpr%> function in C++20"
+msgstr ""
+
+#: cp/constexpr.cc:7222
+#, gcc-internal-format
+msgid "use of %qD"
+msgstr ""
+
+#: cp/constexpr.cc:7226
+#, gcc-internal-format
+msgid "its value can vary between compiler versions or with different %<-mtune%> or %<-mcpu%> flags"
+msgstr ""
+
+#: cp/constexpr.cc:7228
+#, gcc-internal-format
+msgid "if this use is part of a public ABI, change it to instead use a constant variable you define"
+msgstr ""
+
+#: cp/constexpr.cc:7230
+#, gcc-internal-format, gfc-internal-format
+msgid "the default value for the current CPU tuning is %d bytes"
+msgstr ""
+
+#: cp/constexpr.cc:7232
+#, gcc-internal-format
+msgid "you can stabilize this value with %<--param hardware_destructive_interference_size=%d%>, or disable this warning with %<-Wno-interference-size%>"
+msgstr ""
+
+#: cp/constexpr.cc:7385
+#, gcc-internal-format
+msgid "value %qE of type %qT is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:7398
+#, gcc-internal-format
+msgid "%<constexpr%> evaluation operation count exceeds limit of %wd (use %<-fconstexpr-ops-limit=%> to increase the limit)"
+msgstr ""
+
+#: cp/constexpr.cc:7583
+#, gcc-internal-format
+msgid "control passes through definition of %qD with thread storage duration"
+msgstr ""
+
+#: cp/constexpr.cc:7586
+#, gcc-internal-format
+msgid "control passes through definition of %qD with static storage duration"
+msgstr ""
+
+#: cp/constexpr.cc:7651 cp/constexpr.cc:10336
+#: rust/backend/rust-constexpr.cc:2056 rust/backend/rust-constexpr.cc:6206
+#, gcc-internal-format
+msgid "temporary of non-literal type %qT in a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:8100 cp/constexpr.cc:9843
+#, gcc-internal-format
+msgid "%<reinterpret_cast%> is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:8131 rust/backend/rust-constexpr.cc:2461
+#, gcc-internal-format
+msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:8181
+#, gcc-internal-format
+msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
+msgstr ""
+
+#: cp/constexpr.cc:8188
+#, gcc-internal-format
+msgid "pointed-to object declared here"
+msgstr ""
+
+#: cp/constexpr.cc:8193
+#, gcc-internal-format
+msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
+msgstr ""
+
+#: cp/constexpr.cc:8205
+#, gcc-internal-format
+msgid "cast from %qT is not allowed in a constant expression before C++26"
+msgstr ""
+
+#: cp/constexpr.cc:8219
+#, gcc-internal-format
+msgid "%qE is not a constant expression when the class %qT is still incomplete"
+msgstr ""
+
+#: cp/constexpr.cc:8253 rust/backend/rust-constexpr.cc:2506
+#, gcc-internal-format
+msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:8391 cp/constexpr.cc:10154 cp/constexpr.cc:10559
+#: rust/backend/rust-constexpr.cc:6100 rust/backend/rust-constexpr.cc:6415
+#, gcc-internal-format
+msgid "expression %qE is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:8436 cp/constexpr.cc:10600
+#, gcc-internal-format
+msgid "%<goto%> is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:8494
+#, gcc-internal-format
+msgid "contract predicate is false in constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:8510
+#, gcc-internal-format
+msgid "unexpected template-id %qE"
+msgstr ""
+
+#: cp/constexpr.cc:8516 cp/constraint.cc:178 cp/constraint.cc:755
+#, gcc-internal-format
+msgid "function concept must be called"
+msgstr ""
+
+#: cp/constexpr.cc:8541
+#, gcc-internal-format
+msgid "address of a call to %qs is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:8606
+#, gcc-internal-format
+msgid "unexpected expression %qE of kind %s"
+msgstr ""
+
+#: cp/constexpr.cc:8882 rust/backend/rust-constexpr.cc:5158
+#, gcc-internal-format
+msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
+msgstr ""
+
+#: cp/constexpr.cc:8890 rust/backend/rust-constexpr.cc:5167
+#, gcc-internal-format
+msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
+msgstr ""
+
+#: cp/constexpr.cc:8906 rust/backend/rust-constexpr.cc:5183
+#, gcc-internal-format
+msgid "%qE is not a constant expression because it refers to a result of %<operator new%>"
+msgstr ""
+
+#: cp/constexpr.cc:8917 rust/backend/rust-constexpr.cc:5195
+#, gcc-internal-format
+msgid "%qE is not a constant expression because allocated storage has not been deallocated"
+msgstr ""
+
+#: cp/constexpr.cc:8937 rust/backend/rust-constexpr.cc:5213
+#, gcc-internal-format
+msgid "immediate evaluation returns address of immediate function %qD"
+msgstr ""
+
+#: cp/constexpr.cc:8941
+#, gcc-internal-format
+msgid "constant evaluation returns address of immediate function %qD"
+msgstr ""
+
+#: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
+#, gcc-internal-format
+msgid "lvalue-to-rvalue conversion of a volatile lvalue %qE with type %qT"
+msgstr ""
+
+#: cp/constexpr.cc:9808
+#, gcc-internal-format
+msgid "lambda capture of %qE is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:9811
+#, gcc-internal-format
+msgid "because it is used as a glvalue"
+msgstr ""
+
+#: cp/constexpr.cc:9867 rust/backend/rust-constexpr.cc:5893
+#, gcc-internal-format
+msgid "%<reinterpret_cast%> from integer to pointer"
+msgstr ""
+
+#: cp/constexpr.cc:9901 rust/backend/rust-constexpr.cc:5921
+#, gcc-internal-format
+msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:9940
+#, gcc-internal-format
+msgid "use of %<this%> in a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:10089
+#, gcc-internal-format
+msgid "lambda-expression is not a constant expression before C++17"
+msgstr ""
+
+#: cp/constexpr.cc:10101
+#, gcc-internal-format
+msgid "new-expression is not a constant expression before C++20"
+msgstr ""
+
+#: cp/constexpr.cc:10168
+#, gcc-internal-format
+msgid "virtual functions cannot be %<constexpr%> before C++20"
+msgstr ""
+
+#: cp/constexpr.cc:10184
+#, gcc-internal-format
+msgid "%<typeid%> is not a constant expression because %qE is of polymorphic type"
+msgstr ""
+
+#: cp/constexpr.cc:10247
+#, gcc-internal-format
+msgid "cast to non-integral type %qT in a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:10300
+#, gcc-internal-format
+msgid "%qD defined %<thread_local%> in %<constexpr%> context"
+msgstr ""
+
+#: cp/constexpr.cc:10308
+#, gcc-internal-format
+msgid "%qD defined %<static%> in %<constexpr%> context"
+msgstr ""
+
+#: cp/constexpr.cc:10386 rust/backend/rust-constexpr.cc:6251
+#, gcc-internal-format
+msgid "division by zero is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:10487 rust/backend/rust-constexpr.cc:6349
+#, gcc-internal-format
+msgid "%<delete[]%> is not a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:10556
+#, gcc-internal-format
+msgid "neither branch of %<if%> is a constant expression"
+msgstr ""
+
+#: cp/constexpr.cc:10569
+#, gcc-internal-format
+msgid "non-constant array initialization"
+msgstr ""
+
+#: cp/constexpr.cc:10617 rust/backend/rust-constexpr.cc:6427
+#, gcc-internal-format
+msgid "label definition in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
+msgstr ""
+
+#: cp/constexpr.cc:10648 rust/backend/rust-constexpr.cc:6438
+#, gcc-internal-format, gfc-internal-format
+msgid "unexpected AST of kind %s"
+msgstr ""
+
+#: cp/constraint.cc:166
+#, gcc-internal-format
+msgid "constraint expression does not have type %<bool%>"
+msgstr ""
+
+#: cp/constraint.cc:375
+#, gcc-internal-format
+msgid "function call of variable concept %qE"
+msgstr ""
+
+#: cp/constraint.cc:547
+#, gcc-internal-format
+msgid "MAP %qD TO %qT"
+msgstr ""
+
+#: cp/constraint.cc:549
+#, gcc-internal-format
+msgid "MAP %qD TO %qE"
+msgstr ""
+
+#: cp/constraint.cc:562
+#, gcc-internal-format
+msgid "argument %qT"
+msgstr ""
+
+#: cp/constraint.cc:564
+#, gcc-internal-format
+msgid "argument %qE"
+msgstr ""
+
+#: cp/constraint.cc:1214
+#, gcc-internal-format
+msgid "%qT does not match original declaration"
+msgstr ""
+
+#: cp/constraint.cc:1217
+#, gcc-internal-format
+msgid "original template declaration here"
+msgstr ""
+
+#: cp/constraint.cc:1417
+#, gcc-internal-format
+msgid "no matching concepts for %qE"
+msgstr ""
+
+#: cp/constraint.cc:1723
+#, gcc-internal-format
+msgid "%qE cannot be introduced with an ellipsis %<...%>"
+msgstr ""
+
+#: cp/constraint.cc:1724
+#, gcc-internal-format
+msgid "prototype declared here"
+msgstr ""
+
+#: cp/constraint.cc:1811
+#, gcc-internal-format
+msgid "all template parameters of %qD must be introduced"
+msgstr ""
+
+#: cp/constraint.cc:1839
+#, gcc-internal-format
+msgid "cannot deduce template parameters from introduction list"
+msgstr ""
+
+#: cp/constraint.cc:2004
+#, gcc-internal-format
+msgid "the required expression %qE is invalid, because"
+msgstr ""
+
+#: cp/constraint.cc:2011
+#, gcc-internal-format
+msgid "the required expression %qE is invalid"
+msgstr ""
+
+#. Replay the substitution error.
+#: cp/constraint.cc:2053
+#, gcc-internal-format
+msgid "the required type %qT is invalid, because"
+msgstr ""
+
+#: cp/constraint.cc:2057
+#, gcc-internal-format
+msgid "the required type %qT is invalid"
+msgstr ""
+
+#: cp/constraint.cc:2112 cp/constraint.cc:2186
+#, gcc-internal-format
+msgid "cannot convert %qE to %qT"
+msgstr ""
+
+#: cp/constraint.cc:2141
+#, gcc-internal-format
+msgid "%qE is not %<noexcept%>"
+msgstr ""
+
+#: cp/constraint.cc:2163
+#, gcc-internal-format
+msgid "%qE does not satisfy return-type-requirement, because"
+msgstr ""
+
+#: cp/constraint.cc:2170
+#, gcc-internal-format
+msgid "%qE does not satisfy return-type-requirement"
+msgstr ""
+
+#: cp/constraint.cc:2181
+#, gcc-internal-format
+msgid "cannot convert %qE to %qT because"
+msgstr ""
+
+#. Replay the substitution error.
+#: cp/constraint.cc:2225
+#, gcc-internal-format
+msgid "nested requirement %qE is not satisfied, because"
+msgstr ""
+
+#: cp/constraint.cc:2229
+#, gcc-internal-format
+msgid "nested requirement %qE is not satisfied"
+msgstr ""
+
+#: cp/constraint.cc:2744
+#, gcc-internal-format
+msgid "satisfaction of atomic constraint %qE depends on itself"
+msgstr ""
+
+#: cp/constraint.cc:2790
+#, gcc-internal-format
+msgid "satisfaction value of atomic constraint %qE changed from %qE to %qE"
+msgstr ""
+
+#: cp/constraint.cc:2793
+#, gcc-internal-format
+msgid "satisfaction value first evaluated to %qE from here"
+msgstr ""
+
+#: cp/constraint.cc:2910
+#, gcc-internal-format
+msgid "no operand of the disjunction is satisfied"
+msgstr ""
+
+#: cp/constraint.cc:2923
+#, gcc-internal-format
+msgid "the operand %qE is unsatisfied because"
+msgstr ""
+
+#: cp/constraint.cc:3565
+#, gcc-internal-format
+msgid "definition of concept %qD is empty"
+msgstr ""
+
+#: cp/constraint.cc:3568
+#, gcc-internal-format
+msgid "definition of concept %qD has multiple statements"
+msgstr ""
+
+#: cp/constraint.cc:3724
+#, gcc-internal-format
+msgid "  %qT is not nothrow copy assignable"
+msgstr ""
+
+#: cp/constraint.cc:3727 cp/constraint.cc:3812
+#, gcc-internal-format
+msgid "  %qT is not nothrow default constructible"
+msgstr ""
+
+#: cp/constraint.cc:3730
+#, gcc-internal-format
+msgid "  %qT is not nothrow copy constructible"
+msgstr ""
+
+#: cp/constraint.cc:3733
+#, gcc-internal-format
+msgid "  %qT is not trivially copy assignable"
+msgstr ""
+
+#: cp/constraint.cc:3736 cp/constraint.cc:3852
+#, gcc-internal-format
+msgid "  %qT is not trivially default constructible"
+msgstr ""
+
+#: cp/constraint.cc:3739
+#, gcc-internal-format
+msgid "  %qT is not trivially copy constructible"
+msgstr ""
+
+#: cp/constraint.cc:3742
+#, gcc-internal-format
+msgid "  %qT is not trivially destructible"
+msgstr ""
+
+#: cp/constraint.cc:3745
+#, gcc-internal-format
+msgid "  %qT does not have unique object representations"
+msgstr ""
+
+#: cp/constraint.cc:3748
+#, gcc-internal-format
+msgid "  %qT does not have a virtual destructor"
+msgstr ""
+
+#: cp/constraint.cc:3751
+#, gcc-internal-format
+msgid "  %qT is not an abstract class"
+msgstr ""
+
+#: cp/constraint.cc:3754
+#, gcc-internal-format
+msgid "  %qT is not an aggregate"
+msgstr ""
+
+#: cp/constraint.cc:3757
+#, gcc-internal-format
+msgid "  %qT is not an array"
+msgstr ""
+
+#: cp/constraint.cc:3760
+#, gcc-internal-format
+msgid "  %qT is not assignable from %qT"
+msgstr ""
+
+#: cp/constraint.cc:3763
+#, gcc-internal-format
+msgid "  %qT is not a base of %qT"
+msgstr ""
+
+#: cp/constraint.cc:3766
+#, gcc-internal-format
+msgid "  %qT is not a bounded array"
+msgstr ""
+
+#: cp/constraint.cc:3769
+#, gcc-internal-format
+msgid "  %qT is not a class"
+msgstr ""
+
+#: cp/constraint.cc:3773
+#, gcc-internal-format
+msgid "  %qT is not default constructible"
+msgstr ""
+
+#: cp/constraint.cc:3775
+#, gcc-internal-format
+msgid "  %qT is not constructible from %qE"
+msgstr ""
+
+#: cp/constraint.cc:3778
+#, gcc-internal-format
+msgid "  %qT is not convertible from %qE"
+msgstr ""
+
+#: cp/constraint.cc:3781
+#, gcc-internal-format
+msgid "  %qT is not an empty class"
+msgstr ""
+
+#: cp/constraint.cc:3784
+#, gcc-internal-format
+msgid "  %qT is not an enum"
+msgstr ""
+
+#: cp/constraint.cc:3787
+#, gcc-internal-format
+msgid "  %qT is not a final class"
+msgstr ""
+
+#: cp/constraint.cc:3790
+#, gcc-internal-format
+msgid "  %qT is not a function"
+msgstr ""
+
+#: cp/constraint.cc:3793
+#, gcc-internal-format
+msgid "  %qT is not layout compatible with %qT"
+msgstr ""
+
+#: cp/constraint.cc:3796
+#, gcc-internal-format
+msgid "  %qT is not a literal type"
+msgstr ""
+
+#: cp/constraint.cc:3799
+#, gcc-internal-format
+msgid "  %qT is not a member function pointer"
+msgstr ""
+
+#: cp/constraint.cc:3802
+#, gcc-internal-format
+msgid "  %qT is not a member object pointer"
+msgstr ""
+
+#: cp/constraint.cc:3805
+#, gcc-internal-format
+msgid "  %qT is not a member pointer"
+msgstr ""
+
+#: cp/constraint.cc:3808
+#, gcc-internal-format
+msgid "  %qT is not nothrow assignable from %qT"
+msgstr ""
+
+#: cp/constraint.cc:3814
+#, gcc-internal-format
+msgid "  %qT is not nothrow constructible from %qE"
+msgstr ""
+
+#: cp/constraint.cc:3817
+#, gcc-internal-format
+msgid "  %qT is not nothrow convertible from %qE"
+msgstr ""
+
+#: cp/constraint.cc:3820
+#, gcc-internal-format
+msgid "  %qT is not an object type"
+msgstr ""
+
+#: cp/constraint.cc:3823
+#, gcc-internal-format
+msgid "  %qT is not pointer-interconvertible base of %qT"
+msgstr ""
+
+#: cp/constraint.cc:3827
+#, gcc-internal-format
+msgid "  %qT is not a POD type"
+msgstr ""
+
+#: cp/constraint.cc:3830
+#, gcc-internal-format
+msgid "  %qT is not a polymorphic type"
+msgstr ""
+
+#: cp/constraint.cc:3833
+#, gcc-internal-format
+msgid "  %qT is not a reference"
+msgstr ""
+
+#: cp/constraint.cc:3836
+#, gcc-internal-format
+msgid "  %qT is not the same as %qT"
+msgstr ""
+
+#: cp/constraint.cc:3839
+#, gcc-internal-format
+msgid "  %qT is not a scoped enum"
+msgstr ""
+
+#: cp/constraint.cc:3842
+#, gcc-internal-format
+msgid "  %qT is not an standard layout type"
+msgstr ""
+
+#: cp/constraint.cc:3845
+#, gcc-internal-format
+msgid "  %qT is not a trivial type"
+msgstr ""
+
+#: cp/constraint.cc:3848
+#, gcc-internal-format
+msgid "  %qT is not trivially assignable from %qT"
+msgstr ""
+
+#: cp/constraint.cc:3854
+#, gcc-internal-format
+msgid "  %qT is not trivially constructible from %qE"
+msgstr ""
+
+#: cp/constraint.cc:3857
+#, gcc-internal-format
+msgid "  %qT is not trivially copyable"
+msgstr ""
+
+#: cp/constraint.cc:3860
+#, gcc-internal-format
+msgid "  %qT is not a union"
+msgstr ""
+
+#: cp/constraint.cc:3863
+#, gcc-internal-format
+msgid "  %qT is not a reference that binds to a temporary object of type %qT (direct-initialization)"
+msgstr ""
+
+#: cp/constraint.cc:3867
+#, gcc-internal-format
+msgid "  %qT is not a reference that binds to a temporary object of type %qT (copy-initialization)"
+msgstr ""
+
+#: cp/constraint.cc:3871
+#, gcc-internal-format
+msgid "  %qD is not deducible from %qT"
+msgstr ""
+
+#: cp/constraint.cc:3898
+#, gcc-internal-format
+msgid "invalid constraints"
+msgstr ""
+
+#: cp/constraint.cc:3923
+#, gcc-internal-format
+msgid "constraint %qE has type %qT, not %<bool%>"
+msgstr ""
+
+#: cp/constraint.cc:3926
+#, gcc-internal-format
+msgid "the expression %qE evaluated to %<false%>"
+msgstr ""
+
+#: cp/constraint.cc:3977
+#, gcc-internal-format
+msgid "constraints not satisfied"
+msgstr ""
+
+#: cp/constraint.cc:3992
+#, gcc-internal-format
+msgid "set %qs to at least %d for more detail"
+msgstr ""
+
+#: cp/contracts.cc:183
+#, gcc-internal-format
+msgid "axiom contract semantic must be %<assume%> or %<ignore%>"
+msgstr ""
+
+#: cp/contracts.cc:186
+#, gcc-internal-format
+msgid "the %<audit%> semantic should be at least as strong as the %<default%> semantic"
+msgstr ""
+
+#: cp/contracts.cc:204
+#, gcc-internal-format, gfc-internal-format
+msgid "'%s' is not a valid explicit concrete semantic"
+msgstr ""
+
+#: cp/contracts.cc:344
+#, gcc-internal-format
+msgid "%<-fcontract-build-level=%> cannot be mixed with p1332/p1429"
+msgstr ""
+
+#: cp/contracts.cc:357
+#, gcc-internal-format
+msgid "%<-fcontract-build-level=%> must be off|default|audit"
+msgstr ""
+
+#: cp/contracts.cc:367
+#, gcc-internal-format
+msgid "%<-fcontract-assumption-mode=%> cannot be mixed with p1332/p1429"
+msgstr ""
+
+#: cp/contracts.cc:378
+#, gcc-internal-format
+msgid "%<-fcontract-assumption-mode=%> must be %<on%> or %<off%>"
+msgstr ""
+
+#: cp/contracts.cc:388
+#, gcc-internal-format
+msgid "%<-fcontract-continuation-mode=%> cannot be mixed with p1332/p1429"
+msgstr ""
+
+#: cp/contracts.cc:399
+#, gcc-internal-format
+msgid "%<-fcontract-continuation-mode=%> must be %<on%> or %<off%>"
+msgstr ""
+
+#: cp/contracts.cc:411
+#, gcc-internal-format
+msgid "%<-fcontract-role=%> must be in the form role:semantics"
+msgstr ""
+
+#: cp/contracts.cc:422 cp/contracts.cc:431
+#, gcc-internal-format
+msgid "%<-fcontract-role=%> semantics must include default,audit,axiom values"
+msgstr ""
+
+#: cp/contracts.cc:450
+#, gcc-internal-format
+msgid "%<-fcontract-role=%> cannot be mixed with std/p1429 contract flags"
+msgstr ""
+
+#. TODO: not enough space?
+#: cp/contracts.cc:464
+#, gcc-internal-format
+msgid "%<-fcontract-level=%> too many custom roles"
+msgstr ""
+
+#: cp/contracts.cc:476
+#, gcc-internal-format
+msgid "%<-fcontract-semantic=%> must be in the form level:semantic"
+msgstr ""
+
+#: cp/contracts.cc:482
+#, gcc-internal-format
+msgid "%<-fcontract-semantic=%> cannot be mixed with std/p1332 contract flags"
+msgstr ""
+
+#: cp/contracts.cc:490
+#, gcc-internal-format
+msgid "%<-fcontract-semantic=%> cannot find default role"
+msgstr ""
+
+#: cp/contracts.cc:506
+#, gcc-internal-format
+msgid "%<-fcontract-semantic=%> level must be default, audit, or axiom"
+msgstr ""
+
+#: cp/contracts.cc:647
+#, gcc-internal-format
+msgid "constructor does not return a value to test"
+msgstr ""
+
+#: cp/contracts.cc:649
+#, gcc-internal-format
+msgid "destructor does not return a value to test"
+msgstr ""
+
+#: cp/contracts.cc:650
+#, gcc-internal-format
+msgid "function does not return a value to test"
+msgstr ""
+
+#: cp/contracts.cc:1149
+#, gcc-internal-format
+msgid "mismatched contract attribute in declaration"
+msgstr ""
+
+#: cp/contracts.cc:1151 cp/contracts.cc:1182
+#, gcc-internal-format
+msgid "previous contract here"
+msgstr ""
+
+#: cp/contracts.cc:1179
+#, gcc-internal-format
+msgid "mismatched contract condition in declaration"
+msgstr ""
+
+#: cp/contracts.cc:1222
+#, gcc-internal-format
+msgid "declaration has a different number of contracts than previously declared"
+msgstr ""
+
+#: cp/contracts.cc:1228
+#, gcc-internal-format
+msgid "original declaration with fewer contracts here"
+msgstr ""
+
+#: cp/contracts.cc:1965
+#, gcc-internal-format
+msgid "contracts must appertain to a function type"
+msgstr ""
+
+#: cp/contracts.cc:2178
+#, gcc-internal-format
+msgid "cannot add contracts after definition"
+msgstr ""
+
+#: cp/contracts.cc:2179
+#, gcc-internal-format
+msgid "original definition here"
+msgstr ""
+
+#: cp/contracts.cc:2187
+#, gcc-internal-format
+msgid "cannot add contracts to a virtual function"
+msgstr ""
+
+#: cp/contracts.cc:2188
+#, gcc-internal-format
+msgid "original declaration here"
+msgstr ""
+
+#: cp/contracts.cc:2198
+#, gcc-internal-format
+msgid "declaration adds contracts to %q#D"
+msgstr ""
+
+#: cp/coroutines.cc:303
+#, gcc-internal-format
+msgid "coroutines require a traits template; cannot find %<%E::%E%>"
+msgstr ""
+
+#: cp/coroutines.cc:305
+#, gcc-internal-format
+msgid "perhaps %<#include <coroutine>%> is missing"
+msgstr ""
+
+#: cp/coroutines.cc:360
+#, gcc-internal-format
+msgid "cannot instantiate %<coroutine traits%>"
+msgstr ""
+
+#: cp/coroutines.cc:382
+#, gcc-internal-format
+msgid "coroutines require a handle class template; cannot find %<%E::%E%>"
+msgstr ""
+
+#: cp/coroutines.cc:407
+#, gcc-internal-format
+msgid "cannot instantiate a %<coroutine handle%> for promise type %qT"
+msgstr ""
+
+#: cp/coroutines.cc:492
+#, gcc-internal-format
+msgid "unable to find the promise type for this coroutine"
+msgstr ""
+
+#: cp/coroutines.cc:511
+#, gcc-internal-format
+msgid "the coroutine promise type %qT declares both %<return_value%> and %<return_void%>"
+msgstr ""
+
+#: cp/coroutines.cc:515
+#, gcc-internal-format
+msgid "%<return_void%> declared here"
+msgstr ""
+
+#: cp/coroutines.cc:648 cp/coroutines.cc:726 cp/coroutines.cc:4283
+#, gcc-internal-format
+msgid "no member named %qE in %qT"
+msgstr ""
+
+#: cp/coroutines.cc:741
+#, gcc-internal-format
+msgid "%qs cannot be used outside a function"
+msgstr ""
+
+#. [basic.start.main] 3. The function main shall not be a coroutine.
+#: cp/coroutines.cc:749
+#, gcc-internal-format
+msgid "%qs cannot be used in the %<main%> function"
+msgstr ""
+
+#. [dcl.constexpr] 3.3 it shall not be a coroutine.
+#: cp/coroutines.cc:760
+#, gcc-internal-format
+msgid "%qs cannot be used in a %<constexpr%> function"
+msgstr ""
+
+#: cp/coroutines.cc:771
+#, gcc-internal-format
+msgid "%qs cannot be used in a function with a deduced return type"
+msgstr ""
+
+#: cp/coroutines.cc:782
+#, gcc-internal-format
+msgid "%qs cannot be used in a varargs function"
+msgstr ""
+
+#. [class.ctor] 7. a constructor shall not be a coroutine.
+#: cp/coroutines.cc:789
+#, gcc-internal-format
+msgid "%qs cannot be used in a constructor"
+msgstr ""
+
+#. [class.dtor] 21. a destructor shall not be a coroutine.
+#: cp/coroutines.cc:796
+#, gcc-internal-format
+msgid "%qs cannot be used in a destructor"
+msgstr ""
+
+#. TODO: record or extract positions of returns (and the first coro
+#. keyword) so that we can add notes to the diagnostic about where
+#. the bad keyword is and what made the function into a coro.
+#: cp/coroutines.cc:827
+#, gcc-internal-format
+msgid "a %<return%> statement is not allowed in coroutine; did you mean %<co_return%>?"
+msgstr ""
+
+#: cp/coroutines.cc:875
+#, gcc-internal-format
+msgid "the expression %qE is required to be non-throwing"
+msgstr ""
+
+#: cp/coroutines.cc:877
+#, gcc-internal-format
+msgid "must be declared with %<noexcept(true)%>"
+msgstr ""
+
+#: cp/coroutines.cc:957
+#, gcc-internal-format
+msgid "awaitable type %qT is not a structure"
+msgstr ""
+
+#: cp/coroutines.cc:1072
+#, gcc-internal-format
+msgid "%<await_suspend%> must return %<void%>, %<bool%> or a coroutine handle"
+msgstr ""
+
+#: cp/coroutines.cc:1379
+#, gcc-internal-format
+msgid "function declared %<noreturn%> has a %<co_return%> statement"
+msgstr ""
+
+#: cp/coroutines.cc:1416
+#, gcc-internal-format
+msgid "the align argument to %<__builtin_coro_promise%> must be a constant"
+msgstr ""
+
+#: cp/coroutines.cc:1426
+#, gcc-internal-format
+msgid "the direction argument to %<__builtin_coro_promise%> must be a constant"
+msgstr ""
+
+#: cp/coroutines.cc:1904
+#, gcc-internal-format
+msgid "no suspend point info for %qD"
+msgstr ""
+
+#: cp/coroutines.cc:2102 cp/coroutines.cc:4652
+#, gcc-internal-format
+msgid "%qE is provided by %qT but is not usable with the function signature %qD"
+msgstr ""
+
+#: cp/coroutines.cc:2546
+#, gcc-internal-format
+msgid "duplicate info for %qE"
+msgstr ""
+
+#: cp/coroutines.cc:3691
+#, gcc-internal-format
+msgid "await expressions are not permitted in handlers"
+msgstr ""
+
+#: cp/coroutines.cc:3923
+#, gcc-internal-format
+msgid "variable length arrays are not yet supported in coroutines"
+msgstr ""
+
+#: cp/coroutines.cc:4657
+#, gcc-internal-format
+msgid "%qE is provided by %qT but %qE is not marked %<throw()%> or %<noexcept%>"
+msgstr ""
+
+#: cp/coroutines.cc:4660
+#, gcc-internal-format
+msgid "%qE is marked %<throw()%> or %<noexcept%> but no usable %<get_return_object_on_allocation_failure%> is provided by %qT"
+msgstr ""
+
+#: cp/coroutines.cc:4689
+#, gcc-internal-format
+msgid "%qE is provided by %qT but %<std::nothrow%> cannot be found"
+msgstr ""
+
+#. We can't initialize a non-class return value from void.
+#: cp/coroutines.cc:5064
+#, gcc-internal-format
+msgid "cannot initialize a return object of type %qT with an rvalue of type %<void%>"
+msgstr ""
+
+#: cp/cp-gimplify.cc:192
+#, gcc-internal-format
+msgid "both branches of %<if%> statement marked as %qs"
+msgstr ""
+
+#: cp/cp-gimplify.cc:536
+#, gcc-internal-format
+msgid "%qD was promoted to an immediate function because its body contains an immediate-escalating expression %qE"
+msgstr ""
+
+#: cp/cp-gimplify.cc:539
+#, gcc-internal-format
+msgid "%qD was promoted to an immediate function"
+msgstr ""
+
+#: cp/cp-gimplify.cc:1174
+#, gcc-internal-format
+msgid "taking address of an immediate function %qD"
+msgstr ""
+
+#: cp/cp-gimplify.cc:1273
+#, gcc-internal-format
+msgid "call to consteval function %qE is not a constant expression"
+msgstr ""
+
+#: cp/cp-gimplify.cc:2012
+#, gcc-internal-format
+msgid "%<throw%> will always call %<terminate%>"
+msgstr ""
+
+#: cp/cp-gimplify.cc:2015
+#, gcc-internal-format
+msgid "in C++11 destructors default to %<noexcept%>"
+msgstr ""
+
+#: cp/cp-gimplify.cc:2027
+#, gcc-internal-format
+msgid "in C++11 this %<throw%> will call %<terminate%> because destructors default to %<noexcept%>"
+msgstr ""
+
+#: cp/cp-gimplify.cc:3624
+#, gcc-internal-format
+msgid "ignoring attribute %qE after earlier %qE"
+msgstr ""
+
+#: cp/cp-gimplify.cc:3666
+#, gcc-internal-format
+msgid "pack expansion of %qE attribute"
+msgstr ""
+
+#: cp/cp-gimplify.cc:3669
+#, gcc-internal-format
+msgid "use fold expression in the attribute argument instead"
+msgstr ""
+
+#: cp/cp-gimplify.cc:3708 cp/cp-gimplify.cc:3720 cp/decl.cc:4465
+#: cp/method.cc:984
+#, gcc-internal-format
+msgid "%qD is not a type"
+msgstr ""
+
+#: cp/cp-gimplify.cc:3726
+#, gcc-internal-format
+msgid "%qD is not a class type"
+msgstr ""
+
+#: cp/cp-gimplify.cc:3743
+#, gcc-internal-format
+msgid "%qD does not have %<const char *%> type"
+msgstr ""
+
+#: cp/cp-gimplify.cc:3753
+#, gcc-internal-format
+msgid "%qD does not have integral type"
+msgstr ""
+
+#: cp/cp-gimplify.cc:3765
+#, gcc-internal-format
+msgid "%<std::source_location::__impl%> does not contain only non-static data members %<_M_file_name%>, %<_M_function_name%>, %<_M_line%> and %<_M_column%>"
+msgstr ""
+
+#: cp/cvt.cc:92
+msgid "cannot convert from incomplete type %qH to %qI"
+msgstr ""
+
+#: cp/cvt.cc:102
+msgid "conversion of %qE from %qH to %qI is ambiguous"
+msgstr ""
+
+#: cp/cvt.cc:174 cp/cvt.cc:201 cp/cvt.cc:255
+msgid "cannot convert %qE from type %qH to type %qI"
+msgstr ""
+
+#: cp/cvt.cc:391
+#, gcc-internal-format
+msgid "initialization of volatile reference type %q#T from rvalue of type %qT"
+msgstr ""
+
+#: cp/cvt.cc:394
+#, gcc-internal-format
+msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
+msgstr ""
+
+#: cp/cvt.cc:397
+#, gcc-internal-format
+msgid "initialization of non-const reference type %q#T from rvalue of type %qT"
+msgstr ""
+
+#: cp/cvt.cc:400
+#, gcc-internal-format
+msgid "conversion to non-const reference type %q#T from rvalue of type %qT"
+msgstr ""
+
+#: cp/cvt.cc:476
+msgid "conversion from %qH to %qI discards qualifiers"
+msgstr ""
+
+#: cp/cvt.cc:498 cp/typeck.cc:8823
+#, gcc-internal-format
+msgid "casting %qT to %qT does not dereference pointer"
+msgstr ""
+
+#: cp/cvt.cc:526
+msgid "cannot convert type %qH to type %qI"
+msgstr ""
+
+#: cp/cvt.cc:818
+#, gcc-internal-format
+msgid "conversion from %q#T to %q#T"
+msgstr ""
+
+#: cp/cvt.cc:836
+#, gcc-internal-format
+msgid "the result of the conversion is unspecified because %qE is outside the range of type %qT"
+msgstr ""
+
+#: cp/cvt.cc:847 cp/cvt.cc:902
+#, gcc-internal-format
+msgid "%q#T used where a %qT was expected"
+msgstr ""
+
+#: cp/cvt.cc:856
+#, gcc-internal-format
+msgid "could not convert %qE from %<void%> to %<bool%>"
+msgstr ""
+
+#: cp/cvt.cc:918
+#, gcc-internal-format
+msgid "%q#T used where a floating-point value was expected"
+msgstr ""
+
+#: cp/cvt.cc:976
+msgid "conversion from %qH to non-scalar type %qI requested"
+msgstr ""
+
+#: cp/cvt.cc:1088
+#, gcc-internal-format
+msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>: %<%s%>"
+msgstr ""
+
+#: cp/cvt.cc:1090
+#, gcc-internal-format
+msgid "ignoring return value of %qD, declared with attribute %<nodiscard%>%s"
+msgstr ""
+
+#: cp/cvt.cc:1106
+#, gcc-internal-format
+msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>: %<%s%>"
+msgstr ""
+
+#: cp/cvt.cc:1108
+#, gcc-internal-format
+msgid "ignoring returned value of type %qT, declared with attribute %<nodiscard%>%s"
+msgstr ""
+
+#: cp/cvt.cc:1130
+#, gcc-internal-format
+msgid "ignoring return value of %qD, declared with attribute %<warn_unused_result%>"
+msgstr ""
+
+#: cp/cvt.cc:1184
+#, gcc-internal-format
+msgid "pseudo-destructor is not called"
+msgstr ""
+
+#: cp/cvt.cc:1282 rust/backend/rust-tree.cc:339
+#, gcc-internal-format
+msgid "conversion to void will not access object of incomplete type %qT"
+msgstr ""
+
+#: cp/cvt.cc:1286 rust/backend/rust-tree.cc:345
+#, gcc-internal-format
+msgid "indirection will not access object of incomplete type %qT in second operand of conditional expression"
+msgstr ""
+
+#: cp/cvt.cc:1291 rust/backend/rust-tree.cc:352
+#, gcc-internal-format
+msgid "indirection will not access object of incomplete type %qT in third operand of conditional expression"
+msgstr ""
+
+#: cp/cvt.cc:1296 rust/backend/rust-tree.cc:359
+#, gcc-internal-format
+msgid "indirection will not access object of incomplete type %qT in right operand of comma operator"
+msgstr ""
+
+#: cp/cvt.cc:1301 rust/backend/rust-tree.cc:366
+#, gcc-internal-format
+msgid "indirection will not access object of incomplete type %qT in left operand of comma operator"
+msgstr ""
+
+#: cp/cvt.cc:1306 rust/backend/rust-tree.cc:373
+#, gcc-internal-format
+msgid "indirection will not access object of incomplete type %qT in statement"
+msgstr ""
+
+#: cp/cvt.cc:1310 rust/backend/rust-tree.cc:379
+#, gcc-internal-format
+msgid "indirection will not access object of incomplete type %qT in for increment expression"
+msgstr ""
+
+#: cp/cvt.cc:1326 rust/backend/rust-tree.cc:396
+#, gcc-internal-format
+msgid "conversion to void will not access object of type %qT"
+msgstr ""
+
+#: cp/cvt.cc:1330 rust/backend/rust-tree.cc:402
+#, gcc-internal-format
+msgid "implicit dereference will not access object of type %qT in second operand of conditional expression"
+msgstr ""
+
+#: cp/cvt.cc:1335 rust/backend/rust-tree.cc:409
+#, gcc-internal-format
+msgid "implicit dereference will not access object of type %qT in third operand of conditional expression"
+msgstr ""
+
+#: cp/cvt.cc:1340 rust/backend/rust-tree.cc:416
+#, gcc-internal-format
+msgid "implicit dereference will not access object of type %qT in right operand of comma operator"
+msgstr ""
+
+#: cp/cvt.cc:1345 rust/backend/rust-tree.cc:423
+#, gcc-internal-format
+msgid "implicit dereference will not access object of type %qT in left operand of comma operator"
+msgstr ""
+
+#: cp/cvt.cc:1350 rust/backend/rust-tree.cc:430
+#, gcc-internal-format
+msgid "implicit dereference will not access object of type %qT in statement"
+msgstr ""
+
+#: cp/cvt.cc:1354 rust/backend/rust-tree.cc:436
+#, gcc-internal-format
+msgid "implicit dereference will not access object of type %qT in for increment expression"
+msgstr ""
+
+#: cp/cvt.cc:1368 rust/backend/rust-tree.cc:450
+#, gcc-internal-format
+msgid "conversion to void will not access object of non-trivially-copyable type %qT"
+msgstr ""
+
+#: cp/cvt.cc:1373 rust/backend/rust-tree.cc:456
+#, gcc-internal-format
+msgid "indirection will not access object of non-trivially-copyable type %qT in second operand of conditional expression"
+msgstr ""
+
+#: cp/cvt.cc:1378 rust/backend/rust-tree.cc:463
+#, gcc-internal-format
+msgid "indirection will not access object of non-trivially-copyable type %qT in third operand of conditional expression"
+msgstr ""
+
+#: cp/cvt.cc:1383 rust/backend/rust-tree.cc:470
+#, gcc-internal-format
+msgid "indirection will not access object of non-trivially-copyable type %qT in right operand of comma operator"
+msgstr ""
+
+#: cp/cvt.cc:1388 rust/backend/rust-tree.cc:477
+#, gcc-internal-format
+msgid "indirection will not access object of non-trivially-copyable type %qT in left operand of comma operator"
+msgstr ""
+
+#: cp/cvt.cc:1393 rust/backend/rust-tree.cc:484
+#, gcc-internal-format
+msgid "indirection will not access object of non-trivially-copyable type %qT in statement"
+msgstr ""
+
+#: cp/cvt.cc:1398 rust/backend/rust-tree.cc:490
+#, gcc-internal-format
+msgid "indirection will not access object of non-trivially-copyable type %qT in for increment expression"
+msgstr ""
+
+#: cp/cvt.cc:1440 rust/backend/rust-tree.cc:531
+#, gcc-internal-format
+msgid "conversion to void will not access object %qE of incomplete type %qT"
+msgstr ""
+
+#: cp/cvt.cc:1444 rust/backend/rust-tree.cc:537
+#, gcc-internal-format
+msgid "variable %qE of incomplete type %qT will not be accessed in second operand of conditional expression"
+msgstr ""
+
+#: cp/cvt.cc:1449 rust/backend/rust-tree.cc:544
+#, gcc-internal-format
+msgid "variable %qE of incomplete type %qT will not be accessed in third operand of conditional expression"
+msgstr ""
+
+#: cp/cvt.cc:1454 rust/backend/rust-tree.cc:551
+#, gcc-internal-format
+msgid "variable %qE of incomplete type %qT will not be accessed in right operand of comma operator"
+msgstr ""
+
+#: cp/cvt.cc:1459 rust/backend/rust-tree.cc:557
+#, gcc-internal-format
+msgid "variable %qE of incomplete type %qT will not be accessed in left operand of comma operator"
+msgstr ""
+
+#: cp/cvt.cc:1464 rust/backend/rust-tree.cc:563
+#, gcc-internal-format
+msgid "variable %qE of incomplete type %qT will not be accessed in statement"
+msgstr ""
+
+#: cp/cvt.cc:1468 rust/backend/rust-tree.cc:569
+#, gcc-internal-format
+msgid "variable %qE of incomplete type %qT will not be accessed in for increment expression"
+msgstr ""
+
+#: cp/cvt.cc:1524
+#, gcc-internal-format
+msgid "conversion to void cannot resolve address of overloaded function"
+msgstr ""
+
+#: cp/cvt.cc:1528
+#, gcc-internal-format
+msgid "second operand of conditional expression cannot resolve address of overloaded function"
+msgstr ""
+
+#: cp/cvt.cc:1532
+#, gcc-internal-format
+msgid "third operand of conditional expression cannot resolve address of overloaded function"
+msgstr ""
+
+#: cp/cvt.cc:1536
+#, gcc-internal-format
+msgid "right operand of comma operator cannot resolve address of overloaded function"
+msgstr ""
+
+#: cp/cvt.cc:1540
+#, gcc-internal-format
+msgid "left operand of comma operator cannot resolve address of overloaded function"
+msgstr ""
+
+#: cp/cvt.cc:1544
+#, gcc-internal-format
+msgid "statement cannot resolve address of overloaded function"
+msgstr ""
+
+#: cp/cvt.cc:1548
+#, gcc-internal-format
+msgid "for increment expression cannot resolve address of overloaded function"
+msgstr ""
+
+#: cp/cvt.cc:1564
+#, gcc-internal-format
+msgid "second operand of conditional expression is a reference, not call, to function %qE"
+msgstr ""
+
+#: cp/cvt.cc:1569
+#, gcc-internal-format
+msgid "third operand of conditional expression is a reference, not call, to function %qE"
+msgstr ""
+
+#: cp/cvt.cc:1574
+#, gcc-internal-format
+msgid "right operand of comma operator is a reference, not call, to function %qE"
+msgstr ""
+
+#: cp/cvt.cc:1579
+#, gcc-internal-format
+msgid "left operand of comma operator is a reference, not call, to function %qE"
+msgstr ""
+
+#: cp/cvt.cc:1584
+#, gcc-internal-format
+msgid "statement is a reference, not call, to function %qE"
+msgstr ""
+
+#: cp/cvt.cc:1589
+#, gcc-internal-format
+msgid "for increment expression is a reference, not call, to function %qE"
+msgstr ""
+
+#: cp/cvt.cc:1618
+#, gcc-internal-format
+msgid "second operand of conditional expression has no effect"
+msgstr ""
+
+#: cp/cvt.cc:1623
+#, gcc-internal-format
+msgid "third operand of conditional expression has no effect"
+msgstr ""
+
+#: cp/cvt.cc:1628
+#, gcc-internal-format
+msgid "right operand of comma operator has no effect"
+msgstr ""
+
+#: cp/cvt.cc:1632
+#, gcc-internal-format
+msgid "left operand of comma operator has no effect"
+msgstr ""
+
+#: cp/cvt.cc:1636
+#, gcc-internal-format
+msgid "statement has no effect"
+msgstr ""
+
+#: cp/cvt.cc:1640
+#, gcc-internal-format
+msgid "for increment expression has no effect"
+msgstr ""
+
+#: cp/cvt.cc:1793
+#, gcc-internal-format
+msgid "converting NULL to non-pointer type"
+msgstr ""
+
+#: cp/cvt.cc:1911
+#, gcc-internal-format
+msgid "default type conversion cannot deduce template argument for %qD"
+msgstr ""
+
+#: cp/cvt.cc:1926
+#, gcc-internal-format
+msgid "ambiguous default type conversion from %qT"
+msgstr ""
+
+#: cp/cvt.cc:1929
+#, gcc-internal-format
+msgid "  candidate conversions include %qD and %qD"
+msgstr ""
+
+#: cp/cxx-pretty-print.cc:2315
+#, gcc-internal-format
+msgid "template-parameter-"
+msgstr ""
+
+#: cp/cxx-pretty-print.cc:2329
+#, gcc-internal-format
+msgid "requires"
+msgstr ""
+
+#: cp/cxx-pretty-print.cc:2849 cp/error.cc:399
+#, gcc-internal-format
+msgid "with"
+msgstr ""
+
+#: cp/decl.cc:715
+#, gcc-internal-format
+msgid "unused structured binding declaration"
+msgstr ""
+
+#: cp/decl.cc:718
+#, gcc-internal-format
+msgid "unused variable %qD"
+msgstr ""
+
+#: cp/decl.cc:728
+#, gcc-internal-format
+msgid "structured binding declaration set but not used"
+msgstr ""
+
+#: cp/decl.cc:883
+#, gcc-internal-format
+msgid "%qF declared %<static%> but never defined"
+msgstr ""
+
+#: cp/decl.cc:890
+#, gcc-internal-format
+msgid "odr-used inline variable %qD is not defined"
+msgstr ""
+
+#: cp/decl.cc:1335
+#, gcc-internal-format
+msgid "%qD was declared %<extern%> and later %<static%>"
+msgstr ""
+
+#: cp/decl.cc:1375
+#, gcc-internal-format
+msgid "declaration of %qF has a different exception specifier"
+msgstr ""
+
+#: cp/decl.cc:1389
+#, gcc-internal-format
+msgid "from previous declaration %qF"
+msgstr ""
+
+#: cp/decl.cc:1442
+#, gcc-internal-format
+msgid "redeclaration %qD differs in %qs from previous declaration"
+msgstr ""
+
+#: cp/decl.cc:1446 cp/decl.cc:16636
+#, gcc-internal-format
+msgid "previous declaration %qD"
+msgstr ""
+
+#: cp/decl.cc:1475
+#, gcc-internal-format
+msgid "cannot specialize concept %q#D"
+msgstr ""
+
+#: cp/decl.cc:1497
+#, gcc-internal-format
+msgid "redeclaration of %q#D may not have default arguments"
+msgstr ""
+
+#: cp/decl.cc:1526
+#, gcc-internal-format
+msgid "friend declaration of %q#D specifies default arguments and isn%'t the only declaration"
+msgstr ""
+
+#: cp/decl.cc:1529
+#, gcc-internal-format
+msgid "previous declaration of %q#D"
+msgstr ""
+
+#: cp/decl.cc:1581
+#, gcc-internal-format
+msgid "ambiguating new declaration %q+#D"
+msgstr ""
+
+#: cp/decl.cc:1583 cp/decl.cc:2008
+#, gcc-internal-format
+msgid "old declaration %q#D"
+msgstr ""
+
+#: cp/decl.cc:1623
+#, gcc-internal-format
+msgid "redefinition of default argument for %q+#D"
+msgstr ""
+
+#: cp/decl.cc:1625
+#, gcc-internal-format
+msgid "original definition appeared here"
+msgstr ""
+
+#: cp/decl.cc:1691
+#, gcc-internal-format
+msgid "built-in function %qD declared as non-function"
+msgstr ""
+
+#: cp/decl.cc:1704 cp/decl.cc:1830
+#, gcc-internal-format
+msgid "shadowing built-in function %q#D"
+msgstr ""
+
+#: cp/decl.cc:1705 cp/decl.cc:1831
+#, gcc-internal-format
+msgid "shadowing library function %q#D"
+msgstr ""
+
+#: cp/decl.cc:1713
+#, gcc-internal-format
+msgid "library function %q#D redeclared as non-function %q#D"
+msgstr ""
+
+#: cp/decl.cc:1717 cp/decl.cc:1778
+#, gcc-internal-format
+msgid "declaration of %q#D conflicts with built-in declaration %q#D"
+msgstr ""
+
+#: cp/decl.cc:1805
+#, gcc-internal-format
+msgid "definition of %q#D ambiguates built-in declaration %q#D"
+msgstr ""
+
+#: cp/decl.cc:1811 cp/decl.cc:1825
+#, gcc-internal-format
+msgid "new declaration %q#D ambiguates built-in declaration %q#D"
+msgstr ""
+
+#: cp/decl.cc:1815
+#, gcc-internal-format
+msgid "ignoring the %q#D declaration"
+msgstr ""
+
+#: cp/decl.cc:1919
+#, gcc-internal-format
+msgid "literal operator %q#D conflicts with raw literal operator"
+msgstr ""
+
+#: cp/decl.cc:1923
+#, gcc-internal-format
+msgid "raw literal operator %q#D conflicts with literal operator template"
+msgstr ""
+
+#: cp/decl.cc:1939
+#, gcc-internal-format
+msgid "%q#D redeclared as different kind of entity"
+msgstr ""
+
+#: cp/decl.cc:1963
+#, gcc-internal-format
+msgid "conflicting declaration of template %q#D"
+msgstr ""
+
+#: cp/decl.cc:1985
+#, gcc-internal-format
+msgid "conflicting declaration of C function %q#D"
+msgstr ""
+
+#: cp/decl.cc:2006
+#, gcc-internal-format
+msgid "ambiguating new declaration of %q#D"
+msgstr ""
+
+#: cp/decl.cc:2016
+#, gcc-internal-format
+msgid "conflicting declaration %q#D"
+msgstr ""
+
+#: cp/decl.cc:2018
+#, gcc-internal-format
+msgid "previous declaration as %q#D"
+msgstr ""
+
+#: cp/decl.cc:2028
+#, gcc-internal-format
+msgid "redeclaration of %<pragma omp declare reduction%>"
+msgstr ""
+
+#: cp/decl.cc:2030
+#, gcc-internal-format
+msgid "previous %<pragma omp declare reduction%> declaration"
+msgstr ""
+
+#: cp/decl.cc:2088
+#, gcc-internal-format
+msgid "%q#D previously defined here"
+msgstr ""
+
+#: cp/decl.cc:2089 cp/name-lookup.cc:3370 cp/name-lookup.cc:3408
+#: cp/name-lookup.cc:3434
+#, gcc-internal-format
+msgid "%q#D previously declared here"
+msgstr ""
+
+#: cp/decl.cc:2097
+#, gcc-internal-format
+msgid "parameter declaration is not name-independent"
+msgstr ""
+
+#: cp/decl.cc:2102
+#, gcc-internal-format
+msgid "structured binding at namespace scope is not name-independent"
+msgstr ""
+
+#: cp/decl.cc:2106
+#, gcc-internal-format
+msgid "static structured binding is not name-independent"
+msgstr ""
+
+#: cp/decl.cc:2110
+#, gcc-internal-format
+msgid "extern structured binding is not name-independent"
+msgstr ""
+
+#: cp/decl.cc:2117
+#, gcc-internal-format
+msgid "static data member is not name-independent"
+msgstr ""
+
+#: cp/decl.cc:2120
+#, gcc-internal-format
+msgid "variable at namespace scope is not name-independent"
+msgstr ""
+
+#: cp/decl.cc:2123
+#, gcc-internal-format
+msgid "static variable is not name-independent"
+msgstr ""
+
+#: cp/decl.cc:2126
+#, gcc-internal-format
+msgid "extern variable is not name-independent"
+msgstr ""
+
+#: cp/decl.cc:2138
+#, gcc-internal-format
+msgid "prototype specified for %q#D"
+msgstr ""
+
+#: cp/decl.cc:2140
+#, gcc-internal-format
+msgid "previous non-prototype definition here"
+msgstr ""
+
+#: cp/decl.cc:2180
+#, gcc-internal-format
+msgid "conflicting declaration of %q#D with %qL linkage"
+msgstr ""
+
+#: cp/decl.cc:2183
+#, gcc-internal-format
+msgid "previous declaration with %qL linkage"
+msgstr ""
+
+#: cp/decl.cc:2232 cp/decl.cc:2242
+#, gcc-internal-format
+msgid "default argument given for parameter %d of %q#D"
+msgstr ""
+
+#: cp/decl.cc:2235 cp/decl.cc:2245
+#, gcc-internal-format
+msgid "previous specification in %q#D here"
+msgstr ""
+
+#: cp/decl.cc:2300 cp/decl.cc:16654
+#, gcc-internal-format
+msgid "conflicting exporting for declaration %qD"
+msgstr ""
+
+#: cp/decl.cc:2302 cp/decl.cc:16656
+#, gcc-internal-format
+msgid "previously declared here without exporting"
+msgstr ""
+
+#: cp/decl.cc:2330
+#, gcc-internal-format
+msgid "previous definition of %qD here"
+msgstr ""
+
+#: cp/decl.cc:2331
+#, gcc-internal-format
+msgid "previous declaration of %qD here"
+msgstr ""
+
+#: cp/decl.cc:2344
+#, gcc-internal-format
+msgid "function %qD declared %<[[noreturn]]%> but its first declaration was not"
+msgstr ""
+
+#: cp/decl.cc:2391
+#, gcc-internal-format
+msgid "redundant redeclaration of %qD in same scope"
+msgstr ""
+
+#: cp/decl.cc:2407
+#, gcc-internal-format
+msgid "deleted definition of %qD is not first declaration"
+msgstr ""
+
+#. From [temp.expl.spec]:
+#.
+#. If a template, a member template or the member of a class
+#. template is explicitly specialized then that
+#. specialization shall be declared before the first use of
+#. that specialization that would cause an implicit
+#. instantiation to take place, in every translation unit in
+#. which such a use occurs.
+#: cp/decl.cc:2905
+#, gcc-internal-format
+msgid "explicit specialization of %qD after first use"
+msgstr ""
+
+#: cp/decl.cc:3087
+#, gcc-internal-format
+msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
+msgstr ""
+
+#. Reject two definitions.
+#: cp/decl.cc:3365 cp/decl.cc:3394 cp/decl.cc:3432 cp/decl.cc:3449
+#: cp/decl.cc:3548
+#, gcc-internal-format
+msgid "redefinition of %q#D"
+msgstr ""
+
+#: cp/decl.cc:3381
+#, gcc-internal-format
+msgid "%qD conflicts with used function"
+msgstr ""
+
+#: cp/decl.cc:3391
+#, gcc-internal-format
+msgid "%q#D not declared in class"
+msgstr ""
+
+#: cp/decl.cc:3405 cp/decl.cc:3459
+#, gcc-internal-format
+msgid "%q+D redeclared inline with %<gnu_inline%> attribute"
+msgstr ""
+
+#: cp/decl.cc:3408 cp/decl.cc:3462
+#, gcc-internal-format
+msgid "%q+D redeclared inline without %<gnu_inline%> attribute"
+msgstr ""
+
+#: cp/decl.cc:3418
+#, gcc-internal-format
+msgid "comparison operator %q+D defaulted after its first declaration"
+msgstr ""
+
+#. is_primary=
+#. is_partial=
+#. is_friend_decl=
+#: cp/decl.cc:3479
+#, gcc-internal-format
+msgid "redeclaration of friend %q#D may not have default template arguments"
+msgstr ""
+
+#: cp/decl.cc:3494
+#, gcc-internal-format
+msgid "thread-local declaration of %q#D follows non-thread-local declaration"
+msgstr ""
+
+#: cp/decl.cc:3497
+#, gcc-internal-format
+msgid "non-thread-local declaration of %q#D follows thread-local declaration"
+msgstr ""
+
+#: cp/decl.cc:3512 cp/decl.cc:3556 cp/name-lookup.cc:2894
+#: cp/name-lookup.cc:3402 cp/name-lookup.cc:3405 cp/name-lookup.cc:3428
+#: cp/name-lookup.cc:3431
+#, gcc-internal-format
+msgid "redeclaration of %q#D"
+msgstr ""
+
+#: cp/decl.cc:3539
+#, gcc-internal-format
+msgid "redundant redeclaration of %<constexpr%> static data member %qD"
+msgstr ""
+
+#: cp/decl.cc:3607
+#, gcc-internal-format
+msgid "local label %qE conflicts with existing label"
+msgstr ""
+
+#: cp/decl.cc:3608
+#, gcc-internal-format
+msgid "previous label"
+msgstr ""
+
+#: cp/decl.cc:3698
+#, gcc-internal-format
+msgid "jump to label %qD"
+msgstr ""
+
+#: cp/decl.cc:3699
+#, gcc-internal-format
+msgid "jump to case label"
+msgstr ""
+
+#: cp/decl.cc:3703
+#, gcc-internal-format
+msgid "  as a possible target of computed goto"
+msgstr ""
+
+#: cp/decl.cc:3705
+#, gcc-internal-format
+msgid "  from here"
+msgstr ""
+
+#: cp/decl.cc:3733 cp/decl.cc:3971
+#, gcc-internal-format
+msgid "  exits OpenMP structured block"
+msgstr ""
+
+#: cp/decl.cc:3758
+#, gcc-internal-format
+msgid "  crosses initialization of %q#D"
+msgstr ""
+
+#: cp/decl.cc:3770 cp/decl.cc:3937
+#, gcc-internal-format
+msgid "  enters %<try%> block"
+msgstr ""
+
+#: cp/decl.cc:3776 cp/decl.cc:3926 cp/decl.cc:3939
+#, gcc-internal-format
+msgid "  enters %<catch%> block"
+msgstr ""
+
+#: cp/decl.cc:3782 cp/decl.cc:3953
+#, gcc-internal-format
+msgid "  enters OpenMP structured block"
+msgstr ""
+
+#: cp/decl.cc:3788 cp/decl.cc:3941
+#, gcc-internal-format
+msgid "  enters synchronized or atomic statement"
+msgstr ""
+
+#: cp/decl.cc:3794 cp/decl.cc:3947
+#, gcc-internal-format
+msgid "  enters statement expression"
+msgstr ""
+
+#: cp/decl.cc:3801 cp/decl.cc:3943
+#, gcc-internal-format
+msgid "  enters %<constexpr if%> statement"
+msgstr ""
+
+#: cp/decl.cc:3807 cp/decl.cc:3945
+#, gcc-internal-format
+msgid "  enters %<consteval if%> statement"
+msgstr ""
+
+#: cp/decl.cc:3838 cp/decl.cc:4012
+#, gcc-internal-format
+msgid "  does not destroy %qD"
+msgstr ""
+
+#: cp/decl.cc:3840 cp/decl.cc:3995
+#, gcc-internal-format
+msgid "  does not clean up handled exception"
+msgstr ""
+
+#: cp/decl.cc:3931
+#, gcc-internal-format
+msgid "  skips initialization of %q#D"
+msgstr ""
+
+#: cp/decl.cc:4472 cp/parser.cc:7205
+#, gcc-internal-format
+msgid "%qD used without template arguments"
+msgstr ""
+
+#: cp/decl.cc:4478
+#, gcc-internal-format
+msgid "%qD is a function, not a type"
+msgstr ""
+
+#: cp/decl.cc:4489
+#, gcc-internal-format
+msgid "%q#T is not a class"
+msgstr ""
+
+#: cp/decl.cc:4528 cp/decl.cc:4629
+#, gcc-internal-format
+msgid "no class template named %q#T in %q#T"
+msgstr ""
+
+#: cp/decl.cc:4529
+#, gcc-internal-format
+msgid "no type named %q#T in %q#T"
+msgstr ""
+
+#: cp/decl.cc:4542
+#, gcc-internal-format
+msgid "lookup of %qT in %qT is ambiguous"
+msgstr ""
+
+#: cp/decl.cc:4551
+#, gcc-internal-format
+msgid "%<typename %T::%D%> names %q#T, which is not a class template"
+msgstr ""
+
+#: cp/decl.cc:4564
+#, gcc-internal-format
+msgid "%<typename %T::%D%> names %q#D, which is not a type"
+msgstr ""
+
+#: cp/decl.cc:4638
+#, gcc-internal-format
+msgid "template parameters do not match template %qD"
+msgstr ""
+
+#: cp/decl.cc:4995
+#, gcc-internal-format
+msgid "%<-faligned-new=%d%> is not a power of two"
+msgstr ""
+
+#: cp/decl.cc:5169
+#, gcc-internal-format
+msgid "%<--param destructive-interference-size=%d%> is less than %d"
+msgstr ""
+
+#: cp/decl.cc:5173
+#, gcc-internal-format
+msgid "%<--param destructive-interference-size=%d%> is less than %<--param l1-cache-line-size=%d%>"
+msgstr ""
+
+#: cp/decl.cc:5186
+#, gcc-internal-format
+msgid "%<--param constructive-interference-size=%d%> is less than %d"
+msgstr ""
+
+#: cp/decl.cc:5191
+#, gcc-internal-format
+msgid "%<--param constructive-interference-size=%d%> is greater than %<--param l1-cache-line-size=%d%>"
+msgstr ""
+
+#: cp/decl.cc:5518
+#, gcc-internal-format
+msgid "%q#D invalid; an anonymous union may only have public non-static data members"
+msgstr ""
+
+#: cp/decl.cc:5528 cp/parser.cc:23596
+#, gcc-internal-format
+msgid "this flexibility is deprecated and will be removed"
+msgstr ""
+
+#: cp/decl.cc:5557
+#, gcc-internal-format
+msgid "anonymous struct with base classes"
+msgstr ""
+
+#: cp/decl.cc:5569
+#, gcc-internal-format
+msgid "member %q+#D with constructor not allowed in anonymous aggregate"
+msgstr ""
+
+#: cp/decl.cc:5572
+#, gcc-internal-format
+msgid "member %q+#D with destructor not allowed in anonymous aggregate"
+msgstr ""
+
+#: cp/decl.cc:5575
+#, gcc-internal-format
+msgid "member %q+#D with copy assignment operator not allowed in anonymous aggregate"
+msgstr ""
+
+#: cp/decl.cc:5594
+#, gcc-internal-format
+msgid "attribute ignored in declaration of %q#T"
+msgstr ""
+
+#: cp/decl.cc:5597
+#, gcc-internal-format
+msgid "attribute for %q#T must follow the %qs keyword"
+msgstr ""
+
+#: cp/decl.cc:5639
+#, gcc-internal-format
+msgid "multiple types in one declaration"
+msgstr ""
+
+#: cp/decl.cc:5644
+#, gcc-internal-format
+msgid "redeclaration of C++ built-in type %qT"
+msgstr ""
+
+#: cp/decl.cc:5661
+#, gcc-internal-format
+msgid "%<auto%> can only be specified for variables or function declarations"
+msgstr ""
+
+#: cp/decl.cc:5694
+#, gcc-internal-format
+msgid "missing type-name in typedef-declaration"
+msgstr ""
+
+#: cp/decl.cc:5702
+#, gcc-internal-format
+msgid "ISO C++ prohibits anonymous structs"
+msgstr ""
+
+#: cp/decl.cc:5709
+#, gcc-internal-format
+msgid "%<inline%> can only be specified for functions"
+msgstr ""
+
+#: cp/decl.cc:5712
+#, gcc-internal-format
+msgid "%<virtual%> can only be specified for functions"
+msgstr ""
+
+#: cp/decl.cc:5717
+#, gcc-internal-format
+msgid "%<friend%> can only be specified inside a class"
+msgstr ""
+
+#: cp/decl.cc:5720
+#, gcc-internal-format
+msgid "%<explicit%> can only be specified for constructors"
+msgstr ""
+
+#: cp/decl.cc:5723
+#, gcc-internal-format
+msgid "a storage class can only be specified for objects and functions"
+msgstr ""
+
+#: cp/decl.cc:5727
+#, gcc-internal-format
+msgid "%<const%> can only be specified for objects and functions"
+msgstr ""
+
+#: cp/decl.cc:5731
+#, gcc-internal-format
+msgid "%<volatile%> can only be specified for objects and functions"
+msgstr ""
+
+#: cp/decl.cc:5735
+#, gcc-internal-format
+msgid "%<__restrict%> can only be specified for objects and functions"
+msgstr ""
+
+#: cp/decl.cc:5739
+#, gcc-internal-format
+msgid "%<__thread%> can only be specified for objects and functions"
+msgstr ""
+
+#: cp/decl.cc:5743
+#, gcc-internal-format
+msgid "%<typedef%> was ignored in this declaration"
+msgstr ""
+
+#: cp/decl.cc:5746 cp/decl.cc:5749 cp/decl.cc:5752
+#, gcc-internal-format
+msgid "%qs cannot be used for type declarations"
+msgstr ""
+
+#: cp/decl.cc:5774
+#, gcc-internal-format
+msgid "attribute ignored in explicit instantiation %q#T"
+msgstr ""
+
+#: cp/decl.cc:5777
+#, gcc-internal-format
+msgid "no attribute can be applied to an explicit instantiation"
+msgstr ""
+
+#: cp/decl.cc:5856
+#, gcc-internal-format
+msgid "ignoring attributes applied to class type %qT outside of definition"
+msgstr ""
+
+#. A template type parameter or other dependent type.
+#: cp/decl.cc:5860
+#, gcc-internal-format
+msgid "ignoring attributes applied to dependent type %qT without an associated declaration"
+msgstr ""
+
+#: cp/decl.cc:5926 cp/decl2.cc:1064
+#, gcc-internal-format
+msgid "typedef %qD is initialized (use %qs instead)"
+msgstr ""
+
+#: cp/decl.cc:5939
+#, gcc-internal-format
+msgid "declaration of %q#D has %<extern%> and is initialized"
+msgstr ""
+
+#: cp/decl.cc:5977
+#, gcc-internal-format
+msgid "definition of %q#D is marked %<dllimport%>"
+msgstr ""
+
+#: cp/decl.cc:6001
+#, gcc-internal-format
+msgid "%q+#D is not a static data member of %q#T"
+msgstr ""
+
+#: cp/decl.cc:6009
+#, gcc-internal-format
+msgid "non-member-template declaration of %qD"
+msgstr ""
+
+#: cp/decl.cc:6010
+#, gcc-internal-format
+msgid "does not match member template declaration here"
+msgstr ""
+
+#: cp/decl.cc:6022
+#, gcc-internal-format
+msgid "ISO C++ does not permit %<%T::%D%> to be defined as %<%T::%D%>"
+msgstr ""
+
+#: cp/decl.cc:6034
+#, gcc-internal-format
+msgid "duplicate initialization of %qD"
+msgstr ""
+
+#: cp/decl.cc:6084 cp/decl.cc:6088
+#, gcc-internal-format
+msgid "declaration of %q#D outside of class is not definition"
+msgstr ""
+
+#: cp/decl.cc:6106
+#, gcc-internal-format
+msgid "block-scope extern declaration %q#D must not be attached to a named module"
+msgstr ""
+
+#: cp/decl.cc:6142
+#, gcc-internal-format
+msgid "%qD defined %<thread_local%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
+msgstr ""
+
+#: cp/decl.cc:6148
+#, gcc-internal-format
+msgid "%qD defined %<static%> in %qs function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
+msgstr ""
+
+#: cp/decl.cc:6214
+#, gcc-internal-format
+msgid "variable %q#D has initializer but incomplete type"
+msgstr ""
+
+#: cp/decl.cc:6223 cp/decl.cc:7557
+#, gcc-internal-format
+msgid "elements of array %q#D have incomplete type"
+msgstr ""
+
+#: cp/decl.cc:6234
+#, gcc-internal-format
+msgid "aggregate %q#D has incomplete type and cannot be defined"
+msgstr ""
+
+#: cp/decl.cc:6304
+#, gcc-internal-format
+msgid "%qD declared as reference but not initialized"
+msgstr ""
+
+#: cp/decl.cc:6387
+#, gcc-internal-format
+msgid "name used in a GNU-style designated initializer for an array"
+msgstr ""
+
+#: cp/decl.cc:6393
+#, gcc-internal-format
+msgid "name %qD used in a GNU-style designated initializer for an array"
+msgstr ""
+
+#: cp/decl.cc:6412
+#, gcc-internal-format
+msgid "non-trivial designated initializers not supported"
+msgstr ""
+
+#: cp/decl.cc:6416
+#, gcc-internal-format
+msgid "C99 designator %qE is not an integral constant-expression"
+msgstr ""
+
+#: cp/decl.cc:6477
+#, gcc-internal-format
+msgid "initializer fails to determine size of %qD"
+msgstr ""
+
+#: cp/decl.cc:6484
+#, gcc-internal-format
+msgid "array size missing in %qD"
+msgstr ""
+
+#: cp/decl.cc:6496
+#, gcc-internal-format
+msgid "zero-size array %qD"
+msgstr ""
+
+#: cp/decl.cc:6536
+#, gcc-internal-format
+msgid "storage size of %qD isn%'t known"
+msgstr ""
+
+#: cp/decl.cc:6561
+#, gcc-internal-format
+msgid "storage size of %qD isn%'t constant"
+msgstr ""
+
+#: cp/decl.cc:6645
+#, gcc-internal-format
+msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
+msgstr ""
+
+#: cp/decl.cc:6649
+#, gcc-internal-format
+msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
+msgstr ""
+
+#: cp/decl.cc:6655
+#, gcc-internal-format
+msgid "you can work around this by removing the initializer"
+msgstr ""
+
+#: cp/decl.cc:6697 rust/backend/rust-tree.cc:3278
+#, gcc-internal-format
+msgid "uninitialized %<const %D%>"
+msgstr ""
+
+#: cp/decl.cc:6704 rust/backend/rust-tree.cc:3285
+#, gcc-internal-format
+msgid "uninitialized variable %qD in %<constexpr%> function"
+msgstr ""
+
+#: cp/decl.cc:6713 rust/backend/rust-tree.cc:3294
+#, gcc-internal-format
+msgid "uninitialized variable %qD in %<constexpr%> context"
+msgstr ""
+
+#: cp/decl.cc:6721
+#, gcc-internal-format
+msgid "%q#T has no user-provided default constructor"
+msgstr ""
+
+#: cp/decl.cc:6725
+#, gcc-internal-format
+msgid "constructor is not user-provided because it is explicitly defaulted in the class body"
+msgstr ""
+
+#: cp/decl.cc:6728
+#, gcc-internal-format
+msgid "and the implicitly-defined constructor does not initialize %q#D"
+msgstr ""
+
+#: cp/decl.cc:6921
+#, gcc-internal-format
+msgid "invalid type %qT as initializer for a vector of type %qT"
+msgstr ""
+
+#: cp/decl.cc:6993
+#, gcc-internal-format
+msgid "initializer for %qT must be brace-enclosed"
+msgstr ""
+
+#: cp/decl.cc:7037
+#, gcc-internal-format
+msgid "%<[%E] =%> used in a GNU-style designated initializer for class %qT"
+msgstr ""
+
+#: cp/decl.cc:7053 cp/init.cc:3407 cp/search.cc:1230
+#, gcc-internal-format
+msgid "request for member %qD is ambiguous"
+msgstr ""
+
+#: cp/decl.cc:7058
+#, gcc-internal-format
+msgid "%qT has no non-static data member named %qD"
+msgstr ""
+
+#: cp/decl.cc:7083
+#, gcc-internal-format
+msgid "%qD is not a direct member of %qT"
+msgstr ""
+
+#: cp/decl.cc:7138
+#, gcc-internal-format
+msgid "invalid initializer for %q#D"
+msgstr ""
+
+#: cp/decl.cc:7188
+#, gcc-internal-format
+msgid "C99 designator %qE outside aggregate initializer"
+msgstr ""
+
+#: cp/decl.cc:7227 cp/decl.cc:7515 cp/typeck2.cc:1599 cp/typeck2.cc:1929
+#: cp/typeck2.cc:1977 cp/typeck2.cc:2024
+#, gcc-internal-format
+msgid "too many initializers for %qT"
+msgstr ""
+
+#: cp/decl.cc:7269
+#, gcc-internal-format
+msgid "braces around scalar initializer for type %qT"
+msgstr ""
+
+#: cp/decl.cc:7279
+#, gcc-internal-format
+msgid "too many braces around scalar initializer for type %qT"
+msgstr ""
+
+#: cp/decl.cc:7412
+#, gcc-internal-format
+msgid "missing braces around initializer for %qT"
+msgstr ""
+
+#: cp/decl.cc:7545
+#, gcc-internal-format
+msgid "structured binding has incomplete type %qT"
+msgstr ""
+
+#: cp/decl.cc:7559
+#, gcc-internal-format
+msgid "elements of array %q#T have incomplete type"
+msgstr ""
+
+#: cp/decl.cc:7572
+#, gcc-internal-format
+msgid "variable-sized compound literal"
+msgstr ""
+
+#: cp/decl.cc:7628
+#, gcc-internal-format
+msgid "%q#D has incomplete type"
+msgstr ""
+
+#: cp/decl.cc:7649
+#, gcc-internal-format
+msgid "scalar object %qD requires one element in initializer"
+msgstr ""
+
+#: cp/decl.cc:7694
+#, gcc-internal-format
+msgid "in C++98 %qD must be initialized by constructor, not by %<{...}%>"
+msgstr ""
+
+#: cp/decl.cc:7837
+#, gcc-internal-format
+msgid "array %qD initialized by parenthesized string literal %qE"
+msgstr ""
+
+#: cp/decl.cc:7876
+#, gcc-internal-format
+msgid "initializer invalid for static member with constructor"
+msgstr ""
+
+#: cp/decl.cc:7878
+#, gcc-internal-format
+msgid "non-constant in-class initialization invalid for static member %qD"
+msgstr ""
+
+#: cp/decl.cc:7881
+#, gcc-internal-format
+msgid "non-constant in-class initialization invalid for non-inline static member %qD"
+msgstr ""
+
+#: cp/decl.cc:7886
+#, gcc-internal-format
+msgid "(an out of class initialization is required)"
+msgstr ""
+
+#: cp/decl.cc:8088
+#, gcc-internal-format
+msgid "reference %qD is initialized with itself"
+msgstr ""
+
+#: cp/decl.cc:8347
+#, gcc-internal-format
+msgid "could not find variant declaration"
+msgstr ""
+
+#: cp/decl.cc:8371
+#, gcc-internal-format
+msgid "%<declare variant%> on constructor %qD"
+msgstr ""
+
+#: cp/decl.cc:8376
+#, gcc-internal-format
+msgid "%<declare variant%> on destructor %qD"
+msgstr ""
+
+#: cp/decl.cc:8381
+#, gcc-internal-format
+msgid "%<declare variant%> on defaulted %qD"
+msgstr ""
+
+#: cp/decl.cc:8386
+#, gcc-internal-format
+msgid "%<declare variant%> on deleted %qD"
+msgstr ""
+
+#: cp/decl.cc:8391
+#, gcc-internal-format
+msgid "%<declare variant%> on virtual %qD"
+msgstr ""
+
+#: cp/decl.cc:8445
+#, gcc-internal-format
+msgid "assignment (not initialization) in declaration"
+msgstr ""
+
+#: cp/decl.cc:8466 cp/decl.cc:15250
+#, gcc-internal-format
+msgid "ISO C++17 does not allow %<register%> storage class specifier"
+msgstr ""
+
+#: cp/decl.cc:8470 cp/decl.cc:15254
+#, gcc-internal-format
+msgid "%<register%> storage class specifier used"
+msgstr ""
+
+#: cp/decl.cc:8515 cp/decl.cc:15217
+#, gcc-internal-format
+msgid "declaration of %q#D has no initializer"
+msgstr ""
+
+#: cp/decl.cc:8551
+#, gcc-internal-format
+msgid "initializer for %<decltype(auto) %D%> has function type; did you forget the %<()%>?"
+msgstr ""
+
+#: cp/decl.cc:8562
+#, gcc-internal-format
+msgid "deduced type %qT for %qD is incomplete"
+msgstr ""
+
+#: cp/decl.cc:8700
+#, gcc-internal-format
+msgid "variable concept has no initializer"
+msgstr ""
+
+#: cp/decl.cc:8759
+#, gcc-internal-format
+msgid "shadowing previous type declaration of %q#D"
+msgstr ""
+
+#: cp/decl.cc:8802
+#, gcc-internal-format
+msgid "%<constinit%> can only be applied to a variable with static or thread storage duration"
+msgstr ""
+
+#: cp/decl.cc:8997
+#, gcc-internal-format
+msgid "function %q#D is initialized like a variable"
+msgstr ""
+
+#: cp/decl.cc:9108
+#, gcc-internal-format
+msgid "cannot decompose class type %qT because it has an anonymous struct member"
+msgstr ""
+
+#: cp/decl.cc:9111
+#, gcc-internal-format
+msgid "cannot decompose class type %qT because it has an anonymous union member"
+msgstr ""
+
+#: cp/decl.cc:9118
+#, gcc-internal-format
+msgid "cannot decompose inaccessible member %qD of %qT"
+msgstr ""
+
+#: cp/decl.cc:9144
+#, gcc-internal-format
+msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
+msgstr ""
+
+#: cp/decl.cc:9153
+#, gcc-internal-format
+msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
+msgstr ""
+
+#: cp/decl.cc:9390
+#, gcc-internal-format
+msgid "structured binding refers to incomplete type %qT"
+msgstr ""
+
+#: cp/decl.cc:9406
+#, gcc-internal-format
+msgid "cannot decompose variable length array %qT"
+msgstr ""
+
+#: cp/decl.cc:9415 cp/decl.cc:9494
+#, gcc-internal-format, gfc-internal-format
+msgid "%u name provided for structured binding"
+msgid_plural "%u names provided for structured binding"
+msgstr[0] ""
+msgstr[1] ""
+
+#: cp/decl.cc:9419
+#, gcc-internal-format, gfc-internal-format
+msgid "only %u name provided for structured binding"
+msgid_plural "only %u names provided for structured binding"
+msgstr[0] ""
+msgstr[1] ""
+
+#: cp/decl.cc:9422
+#, gcc-internal-format
+msgid "while %qT decomposes into %wu element"
+msgid_plural "while %qT decomposes into %wu elements"
+msgstr[0] ""
+msgstr[1] ""
+
+#: cp/decl.cc:9463
+#, gcc-internal-format
+msgid "cannot decompose variable length vector %qT"
+msgstr ""
+
+#: cp/decl.cc:9487
+#, gcc-internal-format
+msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
+msgstr ""
+
+#: cp/decl.cc:9496
+#, gcc-internal-format
+msgid "while %qT decomposes into %E elements"
+msgstr ""
+
+#: cp/decl.cc:9517
+#, gcc-internal-format
+msgid "%<std::tuple_element<%u, %T>::type%> is %<void%>"
+msgstr ""
+
+#: cp/decl.cc:9523
+#, gcc-internal-format
+msgid "in initialization of structured binding variable %qD"
+msgstr ""
+
+#: cp/decl.cc:9552
+#, gcc-internal-format
+msgid "cannot decompose union type %qT"
+msgstr ""
+
+#: cp/decl.cc:9557
+#, gcc-internal-format
+msgid "cannot decompose non-array non-class type %qT"
+msgstr ""
+
+#: cp/decl.cc:9562
+#, gcc-internal-format
+msgid "cannot decompose lambda closure type %qT"
+msgstr ""
+
+#: cp/decl.cc:9568
+#, gcc-internal-format
+msgid "structured binding refers to incomplete class type %qT"
+msgstr ""
+
+#: cp/decl.cc:9577
+#, gcc-internal-format
+msgid "cannot decompose class type %qT without non-static data members"
+msgstr ""
+
+#: cp/decl.cc:10062
+#, gcc-internal-format
+msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
+msgstr ""
+
+#: cp/decl.cc:10065
+#, gcc-internal-format
+msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
+msgstr ""
+
+#: cp/decl.cc:10070
+#, gcc-internal-format
+msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
+msgstr ""
+
+#: cp/decl.cc:10289
+#, gcc-internal-format
+msgid "initializer fails to determine size of %qT"
+msgstr ""
+
+#: cp/decl.cc:10293
+#, gcc-internal-format
+msgid "array size missing in %qT"
+msgstr ""
+
+#: cp/decl.cc:10296
+#, gcc-internal-format
+msgid "zero-size array %qT"
+msgstr ""
+
+#: cp/decl.cc:10312
+#, gcc-internal-format
+msgid "destructor for alien class %qT cannot be a member"
+msgstr ""
+
+#: cp/decl.cc:10314
+#, gcc-internal-format
+msgid "constructor for alien class %qT cannot be a member"
+msgstr ""
+
+#: cp/decl.cc:10340
+#, gcc-internal-format
+msgid "%qD declared as a %<virtual%> variable"
+msgstr ""
+
+#: cp/decl.cc:10342
+#, gcc-internal-format
+msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
+msgstr ""
+
+#: cp/decl.cc:10348
+#, gcc-internal-format
+msgid "%qD declared as a %<virtual%> parameter"
+msgstr ""
+
+#: cp/decl.cc:10351
+#, gcc-internal-format
+msgid "%qD declared as an %<inline%> parameter"
+msgstr ""
+
+#: cp/decl.cc:10353
+#, gcc-internal-format
+msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
+msgstr ""
+
+#: cp/decl.cc:10359
+#, gcc-internal-format
+msgid "%qD declared as a %<virtual%> type"
+msgstr ""
+
+#: cp/decl.cc:10362
+#, gcc-internal-format
+msgid "%qD declared as an %<inline%> type"
+msgstr ""
+
+#: cp/decl.cc:10364
+#, gcc-internal-format
+msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
+msgstr ""
+
+#: cp/decl.cc:10370
+#, gcc-internal-format
+msgid "%qD declared as a %<virtual%> field"
+msgstr ""
+
+#: cp/decl.cc:10373
+#, gcc-internal-format
+msgid "%qD declared as an %<inline%> field"
+msgstr ""
+
+#: cp/decl.cc:10375
+#, gcc-internal-format
+msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
+msgstr ""
+
+#: cp/decl.cc:10382
+#, gcc-internal-format
+msgid "%q+D declared as a friend"
+msgstr ""
+
+#: cp/decl.cc:10389
+#, gcc-internal-format
+msgid "%q+D declared with an exception specification"
+msgstr ""
+
+#: cp/decl.cc:10421
+#, gcc-internal-format
+msgid "definition of %qD is not in namespace enclosing %qT"
+msgstr ""
+
+#: cp/decl.cc:10461
+#, gcc-internal-format
+msgid "static member function %q#D declared with type qualifiers"
+msgstr ""
+
+#: cp/decl.cc:10472
+#, gcc-internal-format
+msgid "concept %q#D declared with function parameters"
+msgstr ""
+
+#: cp/decl.cc:10479
+#, gcc-internal-format
+msgid "concept %q#D declared with a deduced return type"
+msgstr ""
+
+#: cp/decl.cc:10482
+#, gcc-internal-format
+msgid "concept %q#D with non-%<bool%> return type %qT"
+msgstr ""
+
+#: cp/decl.cc:10558
+#, gcc-internal-format
+msgid "concept %qD has no definition"
+msgstr ""
+
+#: cp/decl.cc:10587
+#, gcc-internal-format
+msgid "a function concept cannot be constrained"
+msgstr ""
+
+#: cp/decl.cc:10602
+#, gcc-internal-format
+msgid "constraints on a non-templated function"
+msgstr ""
+
+#: cp/decl.cc:10604
+#, gcc-internal-format
+msgid "constrained non-template friend declaration must be a definition"
+msgstr ""
+
+#: cp/decl.cc:10611
+#, gcc-internal-format
+msgid "friend function template with constraints that depend on outer template parameters must be a definition"
+msgstr ""
+
+#: cp/decl.cc:10660
+#, gcc-internal-format
+msgid "defining explicit specialization %qD in friend declaration"
+msgstr ""
+
+#: cp/decl.cc:10671
+#, gcc-internal-format
+msgid "invalid use of template-id %qD in declaration of primary template"
+msgstr ""
+
+#: cp/decl.cc:10689
+#, gcc-internal-format
+msgid "default arguments are not allowed in declaration of friend template specialization %qD"
+msgstr ""
+
+#: cp/decl.cc:10698
+#, gcc-internal-format
+msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
+msgstr ""
+
+#: cp/decl.cc:10715
+#, gcc-internal-format
+msgid "friend declaration of %qD specifies default arguments and isn%'t a definition"
+msgstr ""
+
+#: cp/decl.cc:10757
+#, gcc-internal-format
+msgid "cannot declare %<::main%> to be a template"
+msgstr ""
+
+#: cp/decl.cc:10760
+#, gcc-internal-format
+msgid "cannot declare %<::main%> to be inline"
+msgstr ""
+
+#: cp/decl.cc:10763 cp/decl.cc:10766
+#, gcc-internal-format
+msgid "cannot declare %<::main%> to be %qs"
+msgstr ""
+
+#: cp/decl.cc:10768
+#, gcc-internal-format
+msgid "cannot declare %<::main%> to be static"
+msgstr ""
+
+#: cp/decl.cc:10835
+#, gcc-internal-format
+msgid "non-member function %qD cannot have cv-qualifier"
+msgstr ""
+
+#: cp/decl.cc:10837
+#, gcc-internal-format
+msgid "static member function %qD cannot have cv-qualifier"
+msgstr ""
+
+#: cp/decl.cc:10838
+#, gcc-internal-format
+msgid "explicit object member function %qD cannot have cv-qualifier"
+msgstr ""
+
+#: cp/decl.cc:10843
+#, gcc-internal-format
+msgid "non-member function %qD cannot have ref-qualifier"
+msgstr ""
+
+#: cp/decl.cc:10845
+#, gcc-internal-format
+msgid "static member function %qD cannot have ref-qualifier"
+msgstr ""
+
+#: cp/decl.cc:10846
+#, gcc-internal-format
+msgid "explicit object member function %qD cannot have ref-qualifier"
+msgstr ""
+
+#: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
+#, gcc-internal-format
+msgid "explicit object parameter declared here"
+msgstr ""
+
+#: cp/decl.cc:10864
+#, gcc-internal-format
+msgid "deduction guide %qD must be declared in the same scope as %qT"
+msgstr ""
+
+#: cp/decl.cc:10872
+#, gcc-internal-format
+msgid "deduction guide %qD must have the same access as %qT"
+msgstr ""
+
+#: cp/decl.cc:10878
+#, gcc-internal-format
+msgid "deduction guide %qD must not have a function body"
+msgstr ""
+
+#: cp/decl.cc:10891
+#, gcc-internal-format
+msgid "literal operator with C linkage"
+msgstr ""
+
+#: cp/decl.cc:10901
+#, gcc-internal-format
+msgid "%qD has invalid argument list"
+msgstr ""
+
+#: cp/decl.cc:10909
+#, gcc-internal-format
+msgid "integer suffix %qs shadowed by implementation"
+msgstr ""
+
+#: cp/decl.cc:10915
+#, gcc-internal-format
+msgid "floating-point suffix %qs shadowed by implementation"
+msgstr ""
+
+#: cp/decl.cc:10922
+#, gcc-internal-format
+msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
+msgstr ""
+
+#: cp/decl.cc:10927
+#, gcc-internal-format
+msgid "%qD must be a non-member function"
+msgstr ""
+
+#: cp/decl.cc:11013
+#, gcc-internal-format
+msgid "%<::main%> must return %<int%>"
+msgstr ""
+
+#: cp/decl.cc:11053
+#, gcc-internal-format
+msgid "definition of implicitly-declared %qD"
+msgstr ""
+
+#: cp/decl.cc:11058
+#, gcc-internal-format
+msgid "definition of explicitly-defaulted %q+D"
+msgstr ""
+
+#: cp/decl.cc:11060
+#, gcc-internal-format
+msgid "%q#D explicitly defaulted here"
+msgstr ""
+
+#: cp/decl.cc:11077
+#, gcc-internal-format
+msgid "no %q#D member function declared in class %qT"
+msgstr ""
+
+#: cp/decl.cc:11271
+#, gcc-internal-format
+msgid "cannot declare %<::main%> to be a global variable"
+msgstr ""
+
+#: cp/decl.cc:11280
+#, gcc-internal-format
+msgid "a non-template variable cannot be %<concept%>"
+msgstr ""
+
+#: cp/decl.cc:11286
+#, gcc-internal-format
+msgid "concept must be defined at namespace scope"
+msgstr ""
+
+#: cp/decl.cc:11293
+#, gcc-internal-format
+msgid "concept must have type %<bool%>"
+msgstr ""
+
+#: cp/decl.cc:11296
+#, gcc-internal-format
+msgid "a variable concept cannot be constrained"
+msgstr ""
+
+#: cp/decl.cc:11418
+#, gcc-internal-format
+msgid "in-class initialization of static data member %q#D of incomplete type"
+msgstr ""
+
+#: cp/decl.cc:11422
+#, gcc-internal-format
+msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
+msgstr ""
+
+#: cp/decl.cc:11426
+#, gcc-internal-format
+msgid "in-class initialization of static data member %q#D of non-literal type"
+msgstr ""
+
+#: cp/decl.cc:11437
+#, gcc-internal-format
+msgid "invalid in-class initialization of static data member of non-integral type %qT"
+msgstr ""
+
+#: cp/decl.cc:11442
+#, gcc-internal-format
+msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
+msgstr ""
+
+#: cp/decl.cc:11447
+#, gcc-internal-format
+msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
+msgstr ""
+
+#: cp/decl.cc:11558
+#, gcc-internal-format
+msgid "size of array %qD has non-integral type %qT"
+msgstr ""
+
+#: cp/decl.cc:11561
+#, gcc-internal-format
+msgid "size of array has non-integral type %qT"
+msgstr ""
+
+#: cp/decl.cc:11592 cp/decl.cc:11664
+#, gcc-internal-format
+msgid "size of array %qD is not an integral constant-expression"
+msgstr ""
+
+#: cp/decl.cc:11596 cp/decl.cc:11667
+#, gcc-internal-format
+msgid "size of array is not an integral constant-expression"
+msgstr ""
+
+#: cp/decl.cc:11647
+#, gcc-internal-format
+msgid "ISO C++ forbids zero-size array %qD"
+msgstr ""
+
+#: cp/decl.cc:11650
+#, gcc-internal-format
+msgid "ISO C++ forbids zero-size array"
+msgstr ""
+
+#: cp/decl.cc:11674
+#, gcc-internal-format
+msgid "ISO C++ forbids variable length array %qD"
+msgstr ""
+
+#: cp/decl.cc:11677
+#, gcc-internal-format
+msgid "ISO C++ forbids variable length array"
+msgstr ""
+
+#: cp/decl.cc:11683
+#, gcc-internal-format
+msgid "variable length array %qD is used"
+msgstr ""
+
+#: cp/decl.cc:11686
+#, gcc-internal-format
+msgid "variable length array is used"
+msgstr ""
+
+#: cp/decl.cc:11738
+#, gcc-internal-format
+msgid "overflow in array dimension"
+msgstr ""
+
+#: cp/decl.cc:11798
+#, gcc-internal-format
+msgid "%qD declared as array of template placeholder type %qT"
+msgstr ""
+
+#: cp/decl.cc:11801
+#, gcc-internal-format
+msgid "creating array of template placeholder type %qT"
+msgstr ""
+
+#: cp/decl.cc:11811
+#, gcc-internal-format
+msgid "declaration of %qD as array of void"
+msgstr ""
+
+#: cp/decl.cc:11813
+#, gcc-internal-format
+msgid "creating array of void"
+msgstr ""
+
+#: cp/decl.cc:11818
+#, gcc-internal-format
+msgid "declaration of %qD as array of functions"
+msgstr ""
+
+#: cp/decl.cc:11820
+#, gcc-internal-format
+msgid "creating array of functions"
+msgstr ""
+
+#: cp/decl.cc:11825
+#, gcc-internal-format
+msgid "declaration of %qD as array of references"
+msgstr ""
+
+#: cp/decl.cc:11827
+#, gcc-internal-format
+msgid "creating array of references"
+msgstr ""
+
+#: cp/decl.cc:11832
+#, gcc-internal-format
+msgid "declaration of %qD as array of function members"
+msgstr ""
+
+#: cp/decl.cc:11835
+#, gcc-internal-format
+msgid "creating array of function members"
+msgstr ""
+
+#: cp/decl.cc:11853
+#, gcc-internal-format
+msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
+msgstr ""
+
+#: cp/decl.cc:11857
+#, gcc-internal-format
+msgid "multidimensional array must have bounds for all dimensions except the first"
+msgstr ""
+
+#: cp/decl.cc:11871
+#, gcc-internal-format
+msgid "variable-length array of %<auto%>"
+msgstr ""
+
+#: cp/decl.cc:11947
+#, gcc-internal-format
+msgid "return type specification for constructor invalid"
+msgstr ""
+
+#: cp/decl.cc:11950
+#, gcc-internal-format
+msgid "qualifiers are not allowed on constructor declaration"
+msgstr ""
+
+#: cp/decl.cc:11961
+#, gcc-internal-format
+msgid "return type specification for destructor invalid"
+msgstr ""
+
+#: cp/decl.cc:11964
+#, gcc-internal-format
+msgid "qualifiers are not allowed on destructor declaration"
+msgstr ""
+
+#: cp/decl.cc:11977
+#, gcc-internal-format
+msgid "return type specified for %<operator %T%>"
+msgstr ""
+
+#: cp/decl.cc:11980
+#, gcc-internal-format
+msgid "qualifiers are not allowed on declaration of %<operator %T%>"
+msgstr ""
+
+#: cp/decl.cc:11989
+#, gcc-internal-format
+msgid "return type specified for deduction guide"
+msgstr ""
+
+#: cp/decl.cc:11992
+#, gcc-internal-format
+msgid "qualifiers are not allowed on declaration of deduction guide"
+msgstr ""
+
+#: cp/decl.cc:11996
+#, gcc-internal-format
+msgid "template template parameter %qT in declaration of deduction guide"
+msgstr ""
+
+#: cp/decl.cc:12005
+#, gcc-internal-format
+msgid "%<decl-specifier%> in declaration of deduction guide"
+msgstr ""
+
+#: cp/decl.cc:12026
+#, gcc-internal-format
+msgid "unnamed variable or field declared void"
+msgstr ""
+
+#: cp/decl.cc:12034
+#, gcc-internal-format
+msgid "variable or field declared void"
+msgstr ""
+
+#: cp/decl.cc:12049
+#, gcc-internal-format
+msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
+msgstr ""
+
+#: cp/decl.cc:12054
+#, gcc-internal-format
+msgid "inline variables are only available with %<-std=c++17%> or %<-std=gnu++17%>"
+msgstr ""
+
+#: cp/decl.cc:12110
+#, gcc-internal-format
+msgid "%qT as type rather than plain %<decltype(auto)%>"
+msgstr ""
+
+#: cp/decl.cc:12116
+#, gcc-internal-format
+msgid "%<decltype(auto)%> cannot be cv-qualified"
+msgstr ""
+
+#: cp/decl.cc:12332
+#, gcc-internal-format
+msgid "invalid use of qualified-name %<::%D%>"
+msgstr ""
+
+#: cp/decl.cc:12335 cp/decl.cc:12357
+#, gcc-internal-format
+msgid "invalid use of qualified-name %<%T::%D%>"
+msgstr ""
+
+#: cp/decl.cc:12338
+#, gcc-internal-format
+msgid "invalid use of qualified-name %<%D::%D%>"
+msgstr ""
+
+#: cp/decl.cc:12348
+#, gcc-internal-format
+msgid "%q#T is not a class or namespace"
+msgstr ""
+
+#: cp/decl.cc:12372
+#, gcc-internal-format
+msgid "declaration of %qE as non-function"
+msgstr ""
+
+#: cp/decl.cc:12379
+#, gcc-internal-format
+msgid "declaration of %qE as non-member"
+msgstr ""
+
+#: cp/decl.cc:12407
+#, gcc-internal-format
+msgid "declarator-id missing; using reserved word %qD"
+msgstr ""
+
+#: cp/decl.cc:12458
+#, gcc-internal-format
+msgid "function definition does not declare parameters"
+msgstr ""
+
+#: cp/decl.cc:12466 cp/decl.cc:12475 cp/decl.cc:14460
+#, gcc-internal-format
+msgid "declaration of %qD as non-function"
+msgstr ""
+
+#: cp/decl.cc:12483
+#, gcc-internal-format
+msgid "declaration of %qD as %<typedef%>"
+msgstr ""
+
+#: cp/decl.cc:12488
+#, gcc-internal-format
+msgid "declaration of %qD as parameter"
+msgstr ""
+
+#: cp/decl.cc:12523
+#, gcc-internal-format
+msgid "both %qs and %qs specified"
+msgstr ""
+
+#: cp/decl.cc:12530 cp/decl.cc:12537 cp/decl.cc:12544 cp/decl.cc:12551
+#, gcc-internal-format
+msgid "%qs cannot appear in a typedef declaration"
+msgstr ""
+
+#: cp/decl.cc:12562
+#, gcc-internal-format
+msgid "can use at most one of the %<constinit%> and %<constexpr%> specifiers"
+msgstr ""
+
+#: cp/decl.cc:12572
+#, gcc-internal-format
+msgid "two or more data types in declaration of %qs"
+msgstr ""
+
+#: cp/decl.cc:12626
+#, gcc-internal-format
+msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
+msgstr ""
+
+#: cp/decl.cc:12675 cp/decl.cc:12679 cp/decl.cc:12682
+#, gcc-internal-format
+msgid "ISO C++ forbids declaration of %qs with no type"
+msgstr ""
+
+#: cp/decl.cc:12699
+#, gcc-internal-format
+msgid "%<__int%d%> is not supported by this target"
+msgstr ""
+
+#: cp/decl.cc:12707
+#, gcc-internal-format
+msgid "ISO C++ does not support %<__int%d%> for %qs"
+msgstr ""
+
+#: cp/decl.cc:12761
+#, gcc-internal-format
+msgid "%<signed%> and %<unsigned%> specified together"
+msgstr ""
+
+#: cp/decl.cc:12767
+#, gcc-internal-format
+msgid "%<long%> and %<short%> specified together"
+msgstr ""
+
+#: cp/decl.cc:12775
+#, gcc-internal-format
+msgid "%qs specified with %qT"
+msgstr ""
+
+#: cp/decl.cc:12782
+#, gcc-internal-format
+msgid "%qs specified with typedef-name %qD"
+msgstr ""
+
+#: cp/decl.cc:12791
+#, gcc-internal-format
+msgid "%qs specified with %<decltype%>"
+msgstr ""
+
+#: cp/decl.cc:12793
+#, gcc-internal-format
+msgid "%qs specified with %<typeof%>"
+msgstr ""
+
+#: cp/decl.cc:12862
+#, gcc-internal-format
+msgid "complex invalid for %qs"
+msgstr ""
+
+#: cp/decl.cc:12906
+#, gcc-internal-format
+msgid "missing template argument list after %qE; for deduction, template placeholder must be followed by a simple declarator-id"
+msgstr ""
+
+#: cp/decl.cc:12932
+#, gcc-internal-format
+msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
+msgstr ""
+
+#: cp/decl.cc:12941
+#, gcc-internal-format
+msgid "member %qD can be declared both %<virtual%> and %<constexpr%> only in %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/decl.cc:12954
+#, gcc-internal-format
+msgid "typedef declaration invalid in parameter declaration"
+msgstr ""
+
+#: cp/decl.cc:12961
+#, gcc-internal-format
+msgid "storage class specified for template parameter %qs"
+msgstr ""
+
+#: cp/decl.cc:12971 cp/decl.cc:13148
+#, gcc-internal-format
+msgid "storage class specified for parameter %qs"
+msgstr ""
+
+#: cp/decl.cc:12979 cp/decl.cc:12988 cp/decl.cc:12994 cp/decl.cc:13000
+#, gcc-internal-format
+msgid "a parameter cannot be declared %qs"
+msgstr ""
+
+#: cp/decl.cc:13010
+#, gcc-internal-format
+msgid "%<virtual%> outside class declaration"
+msgstr ""
+
+#: cp/decl.cc:13020 cp/decl.cc:13023 cp/decl.cc:13025 cp/decl.cc:13028
+#: cp/decl.cc:13038 cp/decl.cc:13048 cp/decl.cc:13058 cp/decl.cc:13062
+#, gcc-internal-format
+msgid "structured binding declaration cannot be %qs"
+msgstr ""
+
+#: cp/decl.cc:13032 cp/decl.cc:13054
+#, gcc-internal-format
+msgid "structured binding declaration can be %qs only in %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/decl.cc:13042
+#, gcc-internal-format
+msgid "%<volatile%>-qualified structured binding is deprecated"
+msgstr ""
+
+#: cp/decl.cc:13066
+#, gcc-internal-format
+msgid "structured binding declaration cannot be C++98 %<auto%>"
+msgstr ""
+
+#: cp/decl.cc:13078
+#, gcc-internal-format
+msgid "structured binding declaration cannot have type %qT"
+msgstr ""
+
+#: cp/decl.cc:13081
+#, gcc-internal-format
+msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
+msgstr ""
+
+#: cp/decl.cc:13089
+#, gcc-internal-format
+msgid "structured binding declaration cannot have constrained %<auto%> type %qT"
+msgstr ""
+
+#: cp/decl.cc:13120
+#, gcc-internal-format
+msgid "multiple storage classes in declaration of %qs"
+msgstr ""
+
+#: cp/decl.cc:13146
+#, gcc-internal-format
+msgid "storage class specified for %qs"
+msgstr ""
+
+#: cp/decl.cc:13160
+#, gcc-internal-format
+msgid "nested function %qs declared %<extern%>"
+msgstr ""
+
+#: cp/decl.cc:13165
+#, gcc-internal-format
+msgid "top-level declaration of %qs specifies %<auto%>"
+msgstr ""
+
+#: cp/decl.cc:13173
+#, gcc-internal-format
+msgid "function-scope %qs implicitly auto and declared %<__thread%>"
+msgstr ""
+
+#: cp/decl.cc:13187
+#, gcc-internal-format
+msgid "storage class specifiers invalid in friend function declarations"
+msgstr ""
+
+#: cp/decl.cc:13220 cp/decl.cc:14850 cp/parser.cc:15434 cp/parser.cc:21379
+#: cp/parser.cc:28063
+#, gcc-internal-format
+msgid "attribute ignored"
+msgstr ""
+
+#: cp/decl.cc:13221
+#, gcc-internal-format
+msgid "an attribute that appertains to a type-specifier is ignored"
+msgstr ""
+
+#: cp/decl.cc:13291
+#, gcc-internal-format
+msgid "unnecessary parentheses in declaration of %qs"
+msgstr ""
+
+#: cp/decl.cc:13297
+#, gcc-internal-format
+msgid "remove parentheses"
+msgstr ""
+
+#: cp/decl.cc:13365
+#, gcc-internal-format
+msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
+msgstr ""
+
+#: cp/decl.cc:13379
+#, gcc-internal-format
+msgid "a function type cannot have an explicit object parameter"
+msgstr ""
+
+#: cp/decl.cc:13385
+#, gcc-internal-format
+msgid "a pointer to function type cannot have an explicit object parameter"
+msgstr ""
+
+#: cp/decl.cc:13389
+#, gcc-internal-format
+msgid "a pointer to member function type cannot have an explicit object parameter"
+msgstr ""
+
+#: cp/decl.cc:13397
+#, gcc-internal-format
+msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
+msgstr ""
+
+#: cp/decl.cc:13401
+#, gcc-internal-format
+msgid "the type of an explicit object member function is a regular function type"
+msgstr ""
+
+#: cp/decl.cc:13422
+#, gcc-internal-format
+msgid "only the first parameter of a member function can be declared as an explicit object parameter"
+msgstr ""
+
+#: cp/decl.cc:13427
+#, gcc-internal-format
+msgid "valid explicit object parameter declared here"
+msgstr ""
+
+#: cp/decl.cc:13431
+#, gcc-internal-format
+msgid "requires-clause on return type"
+msgstr ""
+
+#: cp/decl.cc:13451
+#, gcc-internal-format
+msgid "%qs function uses %<auto%> type specifier without trailing return type"
+msgstr ""
+
+#: cp/decl.cc:13455
+#, gcc-internal-format
+msgid "deduced return type only available with %<-std=c++14%> or %<-std=gnu++14%>"
+msgstr ""
+
+#: cp/decl.cc:13460
+#, gcc-internal-format
+msgid "virtual function cannot have deduced return type"
+msgstr ""
+
+#: cp/decl.cc:13467
+#, gcc-internal-format
+msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
+msgstr ""
+
+#: cp/decl.cc:13476
+#, gcc-internal-format
+msgid "%qs function with trailing return type has %<decltype(auto)%> as its type rather than plain %<auto%>"
+msgstr ""
+
+#: cp/decl.cc:13481
+#, gcc-internal-format
+msgid "invalid use of %<decltype(auto)%>"
+msgstr ""
+
+#: cp/decl.cc:13493
+#, gcc-internal-format
+msgid "deduced class type %qD in function return type"
+msgstr ""
+
+#: cp/decl.cc:13502
+#, gcc-internal-format
+msgid "deduction guide for %qT must have trailing return type"
+msgstr ""
+
+#: cp/decl.cc:13515
+#, gcc-internal-format
+msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
+msgstr ""
+
+#: cp/decl.cc:13529
+#, gcc-internal-format
+msgid "trailing return type only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/decl.cc:13532
+#, gcc-internal-format
+msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
+msgstr ""
+
+#: cp/decl.cc:13539
+#, gcc-internal-format
+msgid "a conversion function cannot have a trailing return type"
+msgstr ""
+
+#: cp/decl.cc:13565
+#, gcc-internal-format
+msgid "%<volatile%>-qualified return type is deprecated"
+msgstr ""
+
+#: cp/decl.cc:13577
+#, gcc-internal-format
+msgid "%qs declared as function returning a function"
+msgstr ""
+
+#: cp/decl.cc:13583
+#, gcc-internal-format
+msgid "%qs declared as function returning an array"
+msgstr ""
+
+#: cp/decl.cc:13590
+#, gcc-internal-format
+msgid "%<constinit%> on function return type is not allowed"
+msgstr ""
+
+#: cp/decl.cc:13623
+#, gcc-internal-format
+msgid "destructor cannot be static member function"
+msgstr ""
+
+#: cp/decl.cc:13625
+#, gcc-internal-format
+msgid "constructor cannot be static member function"
+msgstr ""
+
+#: cp/decl.cc:13630
+#, gcc-internal-format
+msgid "destructors may not be cv-qualified"
+msgstr ""
+
+#: cp/decl.cc:13631
+#, gcc-internal-format
+msgid "constructors may not be cv-qualified"
+msgstr ""
+
+#: cp/decl.cc:13639
+#, gcc-internal-format
+msgid "destructors may not be ref-qualified"
+msgstr ""
+
+#: cp/decl.cc:13640
+#, gcc-internal-format
+msgid "constructors may not be ref-qualified"
+msgstr ""
+
+#: cp/decl.cc:13658
+#, gcc-internal-format
+msgid "constructors cannot be declared %<virtual%>"
+msgstr ""
+
+#: cp/decl.cc:13675
+#, gcc-internal-format
+msgid "virtual functions cannot be friends"
+msgstr ""
+
+#: cp/decl.cc:13680
+#, gcc-internal-format
+msgid "friend declaration not in class definition"
+msgstr ""
+
+#: cp/decl.cc:13684
+#, gcc-internal-format
+msgid "cannot define friend function %qs in a local class definition"
+msgstr ""
+
+#: cp/decl.cc:13694
+#, gcc-internal-format
+msgid "friend function definition %qs cannot have a name qualified with %<::%>"
+msgstr ""
+
+#: cp/decl.cc:13698
+#, gcc-internal-format
+msgid "friend function definition %qs cannot have a name qualified with %<%D::%>"
+msgstr ""
+
+#: cp/decl.cc:13724
+#, gcc-internal-format
+msgid "a non-member function cannot have an explicit object parameter"
+msgstr ""
+
+#: cp/decl.cc:13732
+#, gcc-internal-format
+msgid "an explicit object member function cannot be %<virtual%>"
+msgstr ""
+
+#: cp/decl.cc:13742
+#, gcc-internal-format
+msgid "an explicit object member function cannot be %<static%>"
+msgstr ""
+
+#: cp/decl.cc:13751
+#, gcc-internal-format
+msgid "%qD cannot be an explicit object member function"
+msgstr ""
+
+#: cp/decl.cc:13774
+#, gcc-internal-format
+msgid "destructors may not have parameters"
+msgstr ""
+
+#: cp/decl.cc:13832
+#, gcc-internal-format
+msgid "cannot declare pointer to %q#T"
+msgstr ""
+
+#: cp/decl.cc:13845 cp/decl.cc:13852
+#, gcc-internal-format
+msgid "cannot declare reference to %q#T"
+msgstr ""
+
+#: cp/decl.cc:13854
+#, gcc-internal-format
+msgid "cannot declare pointer to %q#T member"
+msgstr ""
+
+#: cp/decl.cc:13883
+#, gcc-internal-format
+msgid "cannot declare reference to qualified function type %qT"
+msgstr ""
+
+#: cp/decl.cc:13884
+#, gcc-internal-format
+msgid "cannot declare pointer to qualified function type %qT"
+msgstr ""
+
+#: cp/decl.cc:13957
+#, gcc-internal-format
+msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
+msgstr ""
+
+#: cp/decl.cc:14037
+#, gcc-internal-format
+msgid "template-id %qD used as a declarator"
+msgstr ""
+
+#: cp/decl.cc:14063
+#, gcc-internal-format
+msgid "member functions are implicitly friends of their class"
+msgstr ""
+
+#: cp/decl.cc:14068
+#, gcc-internal-format
+msgid "extra qualification %<%T::%> on member %qs"
+msgstr ""
+
+#: cp/decl.cc:14098
+#, gcc-internal-format
+msgid "cannot define member function %<%T::%s%> within %qT"
+msgstr ""
+
+#: cp/decl.cc:14100
+#, gcc-internal-format
+msgid "cannot declare member function %<%T::%s%> within %qT"
+msgstr ""
+
+#: cp/decl.cc:14108
+#, gcc-internal-format
+msgid "cannot declare member %<%T::%s%> within %qT"
+msgstr ""
+
+#: cp/decl.cc:14148
+#, gcc-internal-format
+msgid "non-parameter %qs cannot be a parameter pack"
+msgstr ""
+
+#: cp/decl.cc:14157
+#, gcc-internal-format
+msgid "data member may not have variably modified type %qT"
+msgstr ""
+
+#: cp/decl.cc:14160
+#, gcc-internal-format
+msgid "parameter may not have variably modified type %qT"
+msgstr ""
+
+#: cp/decl.cc:14171
+#, gcc-internal-format
+msgid "%<explicit%> outside class declaration"
+msgstr ""
+
+#: cp/decl.cc:14174
+#, gcc-internal-format
+msgid "%<explicit%> in friend declaration"
+msgstr ""
+
+#: cp/decl.cc:14177
+#, gcc-internal-format
+msgid "only declarations of constructors and conversion operators can be %<explicit%>"
+msgstr ""
+
+#: cp/decl.cc:14187
+#, gcc-internal-format
+msgid "non-member %qs cannot be declared %<mutable%>"
+msgstr ""
+
+#: cp/decl.cc:14194
+#, gcc-internal-format
+msgid "non-object member %qs cannot be declared %<mutable%>"
+msgstr ""
+
+#: cp/decl.cc:14200
+#, gcc-internal-format
+msgid "function %qs cannot be declared %<mutable%>"
+msgstr ""
+
+#: cp/decl.cc:14206
+#, gcc-internal-format
+msgid "%<static%> %qs cannot be declared %<mutable%>"
+msgstr ""
+
+#: cp/decl.cc:14212
+#, gcc-internal-format
+msgid "%<const%> %qs cannot be declared %<mutable%>"
+msgstr ""
+
+#: cp/decl.cc:14218
+#, gcc-internal-format
+msgid "reference %qs cannot be declared %<mutable%>"
+msgstr ""
+
+#: cp/decl.cc:14234
+#, gcc-internal-format
+msgid "typedef may not be a function definition"
+msgstr ""
+
+#: cp/decl.cc:14237
+#, gcc-internal-format
+msgid "typedef may not be a member function definition"
+msgstr ""
+
+#: cp/decl.cc:14263
+#, gcc-internal-format
+msgid "%<auto%> not allowed in alias declaration"
+msgstr ""
+
+#: cp/decl.cc:14266
+#, gcc-internal-format
+msgid "typedef declared %<auto%>"
+msgstr ""
+
+#: cp/decl.cc:14271
+#, gcc-internal-format
+msgid "requires-clause on typedef"
+msgstr ""
+
+#: cp/decl.cc:14275
+#, gcc-internal-format
+msgid "typedef name may not be a nested-name-specifier"
+msgstr ""
+
+#: cp/decl.cc:14301
+#, gcc-internal-format
+msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
+msgstr ""
+
+#: cp/decl.cc:14390
+#, gcc-internal-format
+msgid "%<inline%> specified for friend class declaration"
+msgstr ""
+
+#: cp/decl.cc:14398
+#, gcc-internal-format
+msgid "template parameters cannot be friends"
+msgstr ""
+
+#: cp/decl.cc:14400
+#, gcc-internal-format
+msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
+msgstr ""
+
+#: cp/decl.cc:14404
+#, gcc-internal-format
+msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
+msgstr ""
+
+#: cp/decl.cc:14417
+#, gcc-internal-format
+msgid "trying to make class %qT a friend of global scope"
+msgstr ""
+
+#: cp/decl.cc:14437
+#, gcc-internal-format
+msgid "invalid qualifiers on non-member function type"
+msgstr ""
+
+#: cp/decl.cc:14441
+#, gcc-internal-format
+msgid "requires-clause on type-id"
+msgstr ""
+
+#: cp/decl.cc:14451
+#, gcc-internal-format
+msgid "abstract declarator %qT used as declaration"
+msgstr ""
+
+#: cp/decl.cc:14466
+#, gcc-internal-format
+msgid "requires-clause on declaration of non-function type %qT"
+msgstr ""
+
+#: cp/decl.cc:14485
+#, gcc-internal-format
+msgid "cannot use %<::%> in parameter declaration"
+msgstr ""
+
+#: cp/decl.cc:14495 cp/parser.cc:20813
+#, gcc-internal-format
+msgid "cannot declare a parameter with %<decltype(auto)%>"
+msgstr ""
+
+#: cp/decl.cc:14502
+#, gcc-internal-format
+msgid "missing template argument list after %qE; template placeholder not permitted in parameter"
+msgstr ""
+
+#: cp/decl.cc:14505
+#, gcc-internal-format
+msgid "or use %<auto%> for an abbreviated function template"
+msgstr ""
+
+#: cp/decl.cc:14511 cp/parser.cc:25355
+#, gcc-internal-format
+msgid "%<auto%> parameter not permitted in this context"
+msgstr ""
+
+#: cp/decl.cc:14521
+#, gcc-internal-format
+msgid "parameter declared %<auto%>"
+msgstr ""
+
+#: cp/decl.cc:14575 cp/parser.cc:3687
+#, gcc-internal-format
+msgid "invalid use of template-name %qE without an argument list"
+msgstr ""
+
+#: cp/decl.cc:14579
+#, gcc-internal-format
+msgid "non-static data member declared with placeholder %qT"
+msgstr ""
+
+#: cp/decl.cc:14600
+#, gcc-internal-format
+msgid "ISO C++ forbids flexible array member %qs"
+msgstr ""
+
+#: cp/decl.cc:14603
+#, gcc-internal-format
+msgid "ISO C++ forbids flexible array members"
+msgstr ""
+
+#. Something like struct S { int N::j; };
+#: cp/decl.cc:14619
+#, gcc-internal-format
+msgid "invalid use of %<::%>"
+msgstr ""
+
+#: cp/decl.cc:14640
+#, gcc-internal-format
+msgid "declaration of function %qD in invalid context"
+msgstr ""
+
+#: cp/decl.cc:14650
+#, gcc-internal-format
+msgid "function %qD declared %<virtual%> inside a union"
+msgstr ""
+
+#: cp/decl.cc:14660
+#, gcc-internal-format
+msgid "%qD cannot be declared %<virtual%>, since it is always static"
+msgstr ""
+
+#: cp/decl.cc:14674
+#, gcc-internal-format
+msgid "expected qualified name in friend declaration for destructor %qD"
+msgstr ""
+
+#: cp/decl.cc:14681
+#, gcc-internal-format
+msgid "declaration of %qD as member of %qT"
+msgstr ""
+
+#: cp/decl.cc:14688 cp/decl.cc:14701
+#, gcc-internal-format
+msgid "a destructor cannot be %qs"
+msgstr ""
+
+#: cp/decl.cc:14707
+#, gcc-internal-format
+msgid "expected qualified name in friend declaration for constructor %qD"
+msgstr ""
+
+#: cp/decl.cc:14716
+#, gcc-internal-format
+msgid "a constructor cannot be %<concept%>"
+msgstr ""
+
+#: cp/decl.cc:14722
+#, gcc-internal-format
+msgid "a concept cannot be a member function"
+msgstr ""
+
+#: cp/decl.cc:14730 cp/decl.cc:15085
+#, gcc-internal-format
+msgid "%qD cannot be %qs"
+msgstr ""
+
+#: cp/decl.cc:14739
+#, gcc-internal-format
+msgid "specialization of variable template %qD declared as function"
+msgstr ""
+
+#: cp/decl.cc:14742
+#, gcc-internal-format
+msgid "variable template declared here"
+msgstr ""
+
+#: cp/decl.cc:14805
+#, gcc-internal-format
+msgid "field %qD has incomplete type %qT"
+msgstr ""
+
+#: cp/decl.cc:14810
+#, gcc-internal-format
+msgid "name %qT has incomplete type"
+msgstr ""
+
+#: cp/decl.cc:14830
+#, gcc-internal-format
+msgid "%qE is neither function nor member function; cannot be declared friend"
+msgstr ""
+
+#: cp/decl.cc:14833
+#, gcc-internal-format
+msgid "unnamed field is neither function nor member function; cannot be declared friend"
+msgstr ""
+
+#: cp/decl.cc:14851 cp/parser.cc:21380 cp/parser.cc:28064
+#, gcc-internal-format
+msgid "an attribute that appertains to a friend declaration that is not a definition is ignored"
+msgstr ""
+
+#: cp/decl.cc:14901 cp/decl.cc:14912
+#, gcc-internal-format
+msgid "static data member %qE declared %qs"
+msgstr ""
+
+#: cp/decl.cc:14906
+#, gcc-internal-format
+msgid "%<constexpr%> static data member %qD must have an initializer"
+msgstr ""
+
+#: cp/decl.cc:14949 cp/decl.cc:14957 cp/decl.cc:14964 cp/decl.cc:14971
+#, gcc-internal-format
+msgid "non-static data member %qE declared %qs"
+msgstr ""
+
+#: cp/decl.cc:15023
+#, gcc-internal-format
+msgid "storage class %<auto%> invalid for function %qs"
+msgstr ""
+
+#: cp/decl.cc:15026
+#, gcc-internal-format
+msgid "storage class %<register%> invalid for function %qs"
+msgstr ""
+
+#: cp/decl.cc:15032
+#, gcc-internal-format
+msgid "storage class %<__thread%> invalid for function %qs"
+msgstr ""
+
+#: cp/decl.cc:15036
+#, gcc-internal-format
+msgid "storage class %<thread_local%> invalid for function %qs"
+msgstr ""
+
+#: cp/decl.cc:15041
+#, gcc-internal-format
+msgid "%<constinit%> specifier invalid for function %qs"
+msgstr ""
+
+#: cp/decl.cc:15044
+#, gcc-internal-format
+msgid "virt-specifiers in %qs not allowed outside a class definition"
+msgstr ""
+
+#: cp/decl.cc:15056
+#, gcc-internal-format
+msgid "%<static%> specifier invalid for function %qs declared out of global scope"
+msgstr ""
+
+#: cp/decl.cc:15060
+#, gcc-internal-format
+msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
+msgstr ""
+
+#: cp/decl.cc:15068
+#, gcc-internal-format
+msgid "virtual non-class function %qs"
+msgstr ""
+
+#: cp/decl.cc:15075
+#, gcc-internal-format
+msgid "%qs defined in a non-class scope"
+msgstr ""
+
+#: cp/decl.cc:15076
+#, gcc-internal-format
+msgid "%qs declared in a non-class scope"
+msgstr ""
+
+#: cp/decl.cc:15119
+#, gcc-internal-format
+msgid "cannot declare member function %qD to have static linkage"
+msgstr ""
+
+#: cp/decl.cc:15128
+#, gcc-internal-format
+msgid "cannot declare static function inside another function"
+msgstr ""
+
+#: cp/decl.cc:15169
+#, gcc-internal-format
+msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
+msgstr ""
+
+#: cp/decl.cc:15176
+#, gcc-internal-format
+msgid "static member %qD declared %<register%>"
+msgstr ""
+
+#: cp/decl.cc:15182
+#, gcc-internal-format
+msgid "cannot explicitly declare member %q#D to have extern linkage"
+msgstr ""
+
+#: cp/decl.cc:15190
+#, gcc-internal-format
+msgid "declaration of %<constexpr%> variable %qD is not a definition"
+msgstr ""
+
+#: cp/decl.cc:15197
+#, gcc-internal-format
+msgid "a variable cannot be declared %<consteval%>"
+msgstr ""
+
+#: cp/decl.cc:15229
+#, gcc-internal-format
+msgid "%qs initialized and declared %<extern%>"
+msgstr ""
+
+#: cp/decl.cc:15234
+#, gcc-internal-format
+msgid "%qs has both %<extern%> and initializer"
+msgstr ""
+
+#: cp/decl.cc:15436
+#, gcc-internal-format
+msgid "default argument %qE uses %qD"
+msgstr ""
+
+#: cp/decl.cc:15439
+#, gcc-internal-format
+msgid "default argument %qE uses local variable %qD"
+msgstr ""
+
+#: cp/decl.cc:15566
+#, gcc-internal-format
+msgid "invalid use of cv-qualified type %qT in parameter declaration"
+msgstr ""
+
+#: cp/decl.cc:15570
+#, gcc-internal-format
+msgid "invalid use of type %<void%> in parameter declaration"
+msgstr ""
+
+#: cp/decl.cc:15599
+#, gcc-internal-format
+msgid "%<volatile%>-qualified parameter is deprecated"
+msgstr ""
+
+#: cp/decl.cc:15607
+#, gcc-internal-format
+msgid "parameter %qD invalidly declared method type"
+msgstr ""
+
+#: cp/decl.cc:15632
+#, gcc-internal-format
+msgid "parameter %qD includes pointer to array of unknown bound %qT"
+msgstr ""
+
+#: cp/decl.cc:15634
+#, gcc-internal-format
+msgid "parameter %qD includes reference to array of unknown bound %qT"
+msgstr ""
+
+#: cp/decl.cc:15917
+#, gcc-internal-format
+msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
+msgstr ""
+
+#: cp/decl.cc:15996
+#, gcc-internal-format
+msgid "%qD may not be declared within a namespace"
+msgstr ""
+
+#: cp/decl.cc:16003
+#, gcc-internal-format
+msgid "%qD may not be declared as static"
+msgstr ""
+
+#: cp/decl.cc:16031
+#, gcc-internal-format
+msgid "%qD must be a non-static member function"
+msgstr ""
+
+#: cp/decl.cc:16039
+#, gcc-internal-format
+msgid "%qD must be a member function"
+msgstr ""
+
+#: cp/decl.cc:16047
+#, gcc-internal-format
+msgid "%qD may be a static member function only with %<-std=c++23%> or %<-std=gnu++23%>"
+msgstr ""
+
+#: cp/decl.cc:16057
+#, gcc-internal-format
+msgid "%qD must be either a non-static member function or a non-member function"
+msgstr ""
+
+#: cp/decl.cc:16067
+#, gcc-internal-format
+msgid "%qD must have an argument of class or enumerated type"
+msgstr ""
+
+#. 13.4.0.3
+#: cp/decl.cc:16098
+#, gcc-internal-format
+msgid "ISO C++ prohibits overloading %<operator ?:%>"
+msgstr ""
+
+#: cp/decl.cc:16108
+#, gcc-internal-format
+msgid "%qD must not have variable number of arguments"
+msgstr ""
+
+#: cp/decl.cc:16134
+#, gcc-internal-format
+msgid "%qD must have either zero or one argument"
+msgstr ""
+
+#: cp/decl.cc:16135
+#, gcc-internal-format
+msgid "%qD must have either one or two arguments"
+msgstr ""
+
+#: cp/decl.cc:16147
+#, gcc-internal-format
+msgid "postfix %qD must have %<int%> as its argument"
+msgstr ""
+
+#: cp/decl.cc:16148
+#, gcc-internal-format
+msgid "postfix %qD must have %<int%> as its second argument"
+msgstr ""
+
+#: cp/decl.cc:16159
+#, gcc-internal-format
+msgid "%qD must have no arguments"
+msgstr ""
+
+#: cp/decl.cc:16160 cp/decl.cc:16170
+#, gcc-internal-format
+msgid "%qD must have exactly one argument"
+msgstr ""
+
+#: cp/decl.cc:16171
+#, gcc-internal-format
+msgid "%qD must have exactly two arguments"
+msgstr ""
+
+#: cp/decl.cc:16186
+#, gcc-internal-format
+msgid "%qD cannot have default arguments"
+msgstr ""
+
+#: cp/decl.cc:16210
+#, gcc-internal-format
+msgid "converting %qT to %<void%> will never use a type conversion operator"
+msgstr ""
+
+#: cp/decl.cc:16217
+#, gcc-internal-format
+msgid "converting %qT to a reference to the same type will never use a type conversion operator"
+msgstr ""
+
+#: cp/decl.cc:16219
+#, gcc-internal-format
+msgid "converting %qT to the same type will never use a type conversion operator"
+msgstr ""
+
+#: cp/decl.cc:16228
+#, gcc-internal-format
+msgid "converting %qT to a reference to a base class %qT will never use a type conversion operator"
+msgstr ""
+
+#: cp/decl.cc:16230
+#, gcc-internal-format
+msgid "converting %qT to a base class %qT will never use a type conversion operator"
+msgstr ""
+
+#: cp/decl.cc:16246
+#, gcc-internal-format
+msgid "user-defined %qD always evaluates both arguments"
+msgstr ""
+
+#: cp/decl.cc:16265
+#, gcc-internal-format
+msgid "prefix %qD should return %qT"
+msgstr ""
+
+#: cp/decl.cc:16272
+#, gcc-internal-format
+msgid "postfix %qD should return %qT"
+msgstr ""
+
+#: cp/decl.cc:16284
+#, gcc-internal-format
+msgid "%qD should return by value"
+msgstr ""
+
+#: cp/decl.cc:16339
+#, gcc-internal-format
+msgid "using template type parameter %qT after %qs"
+msgstr ""
+
+#: cp/decl.cc:16362
+#, gcc-internal-format
+msgid "using alias template specialization %qT after %qs"
+msgstr ""
+
+#: cp/decl.cc:16365
+#, gcc-internal-format
+msgid "using typedef-name %qD after %qs"
+msgstr ""
+
+#: cp/decl.cc:16367
+#, gcc-internal-format
+msgid "%qD has a previous declaration here"
+msgstr ""
+
+#: cp/decl.cc:16375
+#, gcc-internal-format
+msgid "%qT referred to as %qs"
+msgstr ""
+
+#: cp/decl.cc:16376 cp/decl.cc:16383
+#, gcc-internal-format
+msgid "%qT has a previous declaration here"
+msgstr ""
+
+#: cp/decl.cc:16382
+#, gcc-internal-format
+msgid "%qT referred to as enum"
+msgstr ""
+
+#. If a class template appears as elaborated type specifier
+#. without a template header such as:
+#.
+#. template <class T> class C {};
+#. void f(class C);		// No template header here
+#.
+#. then the required template argument is missing.
+#: cp/decl.cc:16397
+#, gcc-internal-format
+msgid "template argument required for %<%s %T%>"
+msgstr ""
+
+#: cp/decl.cc:16440 cp/name-lookup.cc:6131 cp/name-lookup.cc:6263
+#: cp/parser.cc:7215 cp/parser.cc:32116
+#, gcc-internal-format
+msgid "reference to %qD is ambiguous"
+msgstr ""
+
+#: cp/decl.cc:16449
+#, gcc-internal-format
+msgid "class template %qD redeclared as non-template"
+msgstr ""
+
+#: cp/decl.cc:16471 cp/name-lookup.cc:5821
+#, gcc-internal-format
+msgid "%qD has the same name as the class in which it is declared"
+msgstr ""
+
+#: cp/decl.cc:16499 cp/friend.cc:317 cp/parser.cc:3512 cp/parser.cc:6920
+#: cp/pt.cc:10003
+#, gcc-internal-format
+msgid "%qT is not a template"
+msgstr ""
+
+#: cp/decl.cc:16504
+#, gcc-internal-format
+msgid "perhaps you want to explicitly add %<%T::%>"
+msgstr ""
+
+#: cp/decl.cc:16609
+#, gcc-internal-format
+msgid "use of enum %q#D without previous declaration"
+msgstr ""
+
+#: cp/decl.cc:16635
+#, gcc-internal-format
+msgid "redeclaration of %qT as a non-template"
+msgstr ""
+
+#: cp/decl.cc:16770
+#, gcc-internal-format
+msgid "derived union %qT invalid"
+msgstr ""
+
+#: cp/decl.cc:16777
+#, gcc-internal-format
+msgid "%qT defined with multiple direct bases"
+msgstr ""
+
+#: cp/decl.cc:16788
+#, gcc-internal-format
+msgid "%qT defined with direct virtual base"
+msgstr ""
+
+#: cp/decl.cc:16813
+#, gcc-internal-format
+msgid "base type %qT fails to be a struct or class type"
+msgstr ""
+
+#: cp/decl.cc:16843
+#, gcc-internal-format
+msgid "recursive type %qT undefined"
+msgstr ""
+
+#: cp/decl.cc:16845
+#, gcc-internal-format
+msgid "duplicate base type %qT invalid"
+msgstr ""
+
+#: cp/decl.cc:17003
+#, gcc-internal-format
+msgid "scoped/unscoped mismatch in enum %q#T"
+msgstr ""
+
+#: cp/decl.cc:17006 cp/decl.cc:17015 cp/decl.cc:17026 cp/decl.cc:17618
+#: cp/parser.cc:21734
+#, gcc-internal-format
+msgid "previous definition here"
+msgstr ""
+
+#: cp/decl.cc:17012
+#, gcc-internal-format
+msgid "underlying type mismatch in enum %q#T"
+msgstr ""
+
+#: cp/decl.cc:17023
+#, gcc-internal-format
+msgid "different underlying type in enum %q#T"
+msgstr ""
+
+#: cp/decl.cc:17096
+#, gcc-internal-format
+msgid "underlying type %qT of %qT must be an integral type"
+msgstr ""
+
+#. DR 377
+#.
+#. IF no integral type can represent all the enumerator values, the
+#. enumeration is ill-formed.
+#: cp/decl.cc:17245
+#, gcc-internal-format
+msgid "no integral type can represent all of the enumerator values for %qT"
+msgstr ""
+
+#: cp/decl.cc:17426
+#, gcc-internal-format
+msgid "enumerator value for %qD must have integral or unscoped enumeration type"
+msgstr ""
+
+#: cp/decl.cc:17436
+#, gcc-internal-format
+msgid "enumerator value for %qD is not an integer constant"
+msgstr ""
+
+#: cp/decl.cc:17485
+#, gcc-internal-format
+msgid "incremented enumerator value is too large for %<unsigned long%>"
+msgstr ""
+
+#: cp/decl.cc:17486
+#, gcc-internal-format
+msgid "incremented enumerator value is too large for %<long%>"
+msgstr ""
+
+#: cp/decl.cc:17497
+#, gcc-internal-format
+msgid "overflow in enumeration values at %qD"
+msgstr ""
+
+#: cp/decl.cc:17517
+#, gcc-internal-format
+msgid "enumerator value %qE is outside the range of underlying type %qT"
+msgstr ""
+
+#: cp/decl.cc:17616 cp/parser.cc:21732
+#, gcc-internal-format
+msgid "multiple definition of %q#T"
+msgstr ""
+
+#: cp/decl.cc:17690
+#, gcc-internal-format
+msgid "return type %q#T is incomplete"
+msgstr ""
+
+#: cp/decl.cc:17848 cp/typeck.cc:11238
+#, gcc-internal-format
+msgid "%<operator=%> should return a reference to %<*this%>"
+msgstr ""
+
+#: cp/decl.cc:18678
+#, gcc-internal-format
+msgid "no return statements in function returning %qT"
+msgstr ""
+
+#: cp/decl.cc:18680 cp/typeck.cc:11118
+#, gcc-internal-format
+msgid "only plain %<auto%> return type can be deduced to %<void%>"
+msgstr ""
+
+#: cp/decl.cc:18740
+#, gcc-internal-format
+msgid "no return statement in %<constexpr%> function returning non-void"
+msgstr ""
+
+#: cp/decl.cc:18920
+#, gcc-internal-format
+msgid "%qD is already defined in class %qT"
+msgstr ""
+
+#: cp/decl.cc:19310
+#, gcc-internal-format
+msgid "using %qs"
+msgstr ""
+
+#: cp/decl.cc:19322
+#, gcc-internal-format
+msgid "use of %qD before deduction of %<auto%>"
+msgstr ""
+
+#: cp/decl2.cc:386
+#, gcc-internal-format
+msgid "name missing for member function"
+msgstr ""
+
+#: cp/decl2.cc:481 cp/decl2.cc:529
+#, gcc-internal-format
+msgid "top-level comma expression in array subscript changed meaning in C++23"
+msgstr ""
+
+#: cp/decl2.cc:519
+#, gcc-internal-format
+msgid "built-in subscript operator without expression list"
+msgstr ""
+
+#: cp/decl2.cc:533
+#, gcc-internal-format
+msgid "built-in subscript operator with more than one expression in expression list"
+msgstr ""
+
+#: cp/decl2.cc:560 cp/decl2.cc:575
+#, gcc-internal-format
+msgid "ambiguous conversion for array subscript"
+msgstr ""
+
+#: cp/decl2.cc:569
+#, gcc-internal-format
+msgid "invalid types %<%T[%T]%> for array subscript"
+msgstr ""
+
+#: cp/decl2.cc:688
+#, gcc-internal-format
+msgid "deleting array %q#E"
+msgstr ""
+
+#: cp/decl2.cc:696
+#, gcc-internal-format
+msgid "type %q#T argument given to %<delete%>, expected pointer"
+msgstr ""
+
+#: cp/decl2.cc:710
+#, gcc-internal-format
+msgid "cannot delete a function.  Only pointer-to-objects are valid arguments to %<delete%>"
+msgstr ""
+
+#: cp/decl2.cc:720
+#, gcc-internal-format
+msgid "deleting %qT is undefined"
+msgstr ""
+
+#: cp/decl2.cc:768 cp/pt.cc:5962
+#, gcc-internal-format
+msgid "template declaration of %q#D"
+msgstr ""
+
+#: cp/decl2.cc:808
+#, gcc-internal-format
+msgid "template parameter lists provided don%'t match the template parameters of %qD"
+msgstr ""
+
+#: cp/decl2.cc:823 cp/pt.cc:5930
+#, gcc-internal-format
+msgid "destructor %qD declared as member template"
+msgstr ""
+
+#: cp/decl2.cc:915
+#, gcc-internal-format
+msgid "no declaration matches %q#D"
+msgstr ""
+
+#: cp/decl2.cc:920
+#, gcc-internal-format
+msgid "no conversion operators declared"
+msgstr ""
+
+#: cp/decl2.cc:923
+#, gcc-internal-format
+msgid "no functions named %qD"
+msgstr ""
+
+#: cp/decl2.cc:925
+#, gcc-internal-format
+msgid "%#qT defined here"
+msgstr ""
+
+#: cp/decl2.cc:985
+#, gcc-internal-format
+msgid "local class %q#T shall not have static data member %q#D"
+msgstr ""
+
+#: cp/decl2.cc:994
+#, gcc-internal-format
+msgid "static data member %qD in unnamed class"
+msgstr ""
+
+#: cp/decl2.cc:996
+#, gcc-internal-format
+msgid "unnamed class defined here"
+msgstr ""
+
+#: cp/decl2.cc:1077
+#, gcc-internal-format
+msgid "explicit template argument list not allowed"
+msgstr ""
+
+#: cp/decl2.cc:1119
+#, gcc-internal-format
+msgid "%qD is already defined in %qT"
+msgstr ""
+
+#: cp/decl2.cc:1148 cp/decl2.cc:1156
+#, gcc-internal-format
+msgid "invalid initializer for member function %qD"
+msgstr ""
+
+#: cp/decl2.cc:1165
+#, gcc-internal-format
+msgid "initializer specified for friend function %qD"
+msgstr ""
+
+#: cp/decl2.cc:1168
+#, gcc-internal-format
+msgid "initializer specified for static member function %qD"
+msgstr ""
+
+#: cp/decl2.cc:1216
+#, gcc-internal-format
+msgid "%<asm%> specifiers are not permitted on non-static data members"
+msgstr ""
+
+#: cp/decl2.cc:1273
+#, gcc-internal-format
+msgid "bit-field %qD with non-integral type %qT"
+msgstr ""
+
+#: cp/decl2.cc:1281
+#, gcc-internal-format
+msgid "cannot declare %qD to be a bit-field type"
+msgstr ""
+
+#: cp/decl2.cc:1292
+#, gcc-internal-format
+msgid "cannot declare bit-field %qD with function type"
+msgstr ""
+
+#: cp/decl2.cc:1298
+#, gcc-internal-format
+msgid "cannot declare bit-field %qD with %<warn_if_not_aligned%> type"
+msgstr ""
+
+#: cp/decl2.cc:1305
+#, gcc-internal-format
+msgid "%qD is already defined in the class %qT"
+msgstr ""
+
+#: cp/decl2.cc:1313
+#, gcc-internal-format
+msgid "static member %qD cannot be a bit-field"
+msgstr ""
+
+#: cp/decl2.cc:1327
+#, gcc-internal-format
+msgid "width of bit-field %qD has non-integral type %qT"
+msgstr ""
+
+#: cp/decl2.cc:1769
+#, gcc-internal-format
+msgid "%q+D static data member inside of declare target directive"
+msgstr ""
+
+#: cp/decl2.cc:1924
+#, gcc-internal-format
+msgid "anonymous struct not inside named type"
+msgstr ""
+
+#: cp/decl2.cc:1940
+#, gcc-internal-format
+msgid "%q#D invalid; an anonymous union can only have non-static data members"
+msgstr ""
+
+#: cp/decl2.cc:1947
+#, gcc-internal-format
+msgid "private member %q#D in anonymous union"
+msgstr ""
+
+#: cp/decl2.cc:1950
+#, gcc-internal-format
+msgid "protected member %q#D in anonymous union"
+msgstr ""
+
+#: cp/decl2.cc:2015
+#, gcc-internal-format
+msgid "namespace-scope anonymous aggregates must be static"
+msgstr ""
+
+#: cp/decl2.cc:2024
+#, gcc-internal-format
+msgid "anonymous union with no members"
+msgstr ""
+
+#: cp/decl2.cc:2061
+#, gcc-internal-format
+msgid "%<operator new%> must return type %qT"
+msgstr ""
+
+#. [basic.stc.dynamic.allocation]
+#.
+#. The first parameter shall not have an associated default
+#. argument.
+#: cp/decl2.cc:2073
+#, gcc-internal-format
+msgid "the first parameter of %<operator new%> cannot have a default argument"
+msgstr ""
+
+#: cp/decl2.cc:2089
+#, gcc-internal-format
+msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
+msgstr ""
+
+#: cp/decl2.cc:2119
+#, gcc-internal-format
+msgid "%<operator delete%> must return type %qT"
+msgstr ""
+
+#: cp/decl2.cc:2134
+#, gcc-internal-format
+msgid "destroying %<operator delete%> must be a member function"
+msgstr ""
+
+#: cp/decl2.cc:2137
+#, gcc-internal-format
+msgid "%<operator delete[]%> cannot be a destroying delete"
+msgstr ""
+
+#: cp/decl2.cc:2139
+#, gcc-internal-format
+msgid "destroying %<operator delete%> must be a usual deallocation function"
+msgstr ""
+
+#: cp/decl2.cc:2149
+#, gcc-internal-format
+msgid "%<operator delete%> takes type %qT as first parameter"
+msgstr ""
+
+#: cp/decl2.cc:3160
+#, gcc-internal-format
+msgid "%qT has a field %q#D whose type has no linkage"
+msgstr ""
+
+#: cp/decl2.cc:3164
+#, gcc-internal-format
+msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
+msgstr ""
+
+#: cp/decl2.cc:3170
+#, gcc-internal-format
+msgid "%qT has a field %q#D whose type has internal linkage"
+msgstr ""
+
+#. In C++98 this can only happen with unnamed namespaces.
+#: cp/decl2.cc:3174
+#, gcc-internal-format
+msgid "%qT has a field %q#D whose type uses the anonymous namespace"
+msgstr ""
+
+#: cp/decl2.cc:3182
+#, gcc-internal-format
+msgid "%qT declared with greater visibility than the type of its field %qD"
+msgstr ""
+
+#: cp/decl2.cc:3201
+#, gcc-internal-format
+msgid "%qT has a base %qT which has no linkage"
+msgstr ""
+
+#: cp/decl2.cc:3205
+#, gcc-internal-format
+msgid "%qT has a base %qT which depends on the type %qT which has no linkage"
+msgstr ""
+
+#: cp/decl2.cc:3211
+#, gcc-internal-format
+msgid "%qT has a base %qT which has internal linkage"
+msgstr ""
+
+#. In C++98 this can only happen with unnamed namespaces.
+#: cp/decl2.cc:3215
+#, gcc-internal-format
+msgid "%qT has a base %qT which uses the anonymous namespace"
+msgstr ""
+
+#: cp/decl2.cc:3222
+#, gcc-internal-format
+msgid "%qT declared with greater visibility than its base %qT"
+msgstr ""
+
+#: cp/decl2.cc:4714
+#, gcc-internal-format
+msgid "%q#D, declared using an unnamed type, is used but never defined"
+msgstr ""
+
+#: cp/decl2.cc:4718
+#, gcc-internal-format
+msgid "%q#D, declared using an unnamed type, is used but not defined"
+msgstr ""
+
+#. DRs 132, 319 and 389 seem to indicate types with
+#. no linkage can only be used to declare extern "C"
+#. entities.  Since it's not always an error in the
+#. ISO C++ 90 Standard, we only issue a warning.
+#: cp/decl2.cc:4728
+#, gcc-internal-format
+msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
+msgstr ""
+
+#: cp/decl2.cc:4732
+#, gcc-internal-format
+msgid "unnamed type with no linkage used to declare function %q#D with linkage"
+msgstr ""
+
+#: cp/decl2.cc:4736
+#, gcc-internal-format
+msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
+msgstr ""
+
+#: cp/decl2.cc:4754
+#, gcc-internal-format
+msgid "%q#D, declared using local type %qT, is used but never defined"
+msgstr ""
+
+#: cp/decl2.cc:4758
+#, gcc-internal-format
+msgid "%q#D, declared using local type %qT, is used but not defined here"
+msgstr ""
+
+#: cp/decl2.cc:4766
+#, gcc-internal-format
+msgid "type %qT with no linkage used to declare variable %q#D with linkage"
+msgstr ""
+
+#: cp/decl2.cc:4769
+#, gcc-internal-format
+msgid "type %qT with no linkage used to declare function %q#D with linkage"
+msgstr ""
+
+#: cp/decl2.cc:4966
+#, gcc-internal-format
+msgid "mangling of %q#D as %qE conflicts with a previous mangle"
+msgstr ""
+
+#: cp/decl2.cc:4969
+#, gcc-internal-format
+msgid "previous mangling %q#D"
+msgstr ""
+
+#: cp/decl2.cc:4971
+#, gcc-internal-format
+msgid "a later %<-fabi-version=%> (or =0) avoids this error with a change in mangling"
+msgstr ""
+
+#: cp/decl2.cc:5043 cp/decl2.cc:5046
+#, gcc-internal-format
+msgid "the program should also define %qD"
+msgstr ""
+
+#: cp/decl2.cc:5385
+#, gcc-internal-format
+msgid "inline function %qD used but never defined"
+msgstr ""
+
+#: cp/decl2.cc:5611
+#, gcc-internal-format
+msgid "default argument missing for parameter %P of %q#D"
+msgstr ""
+
+#: cp/decl2.cc:5616
+#, gcc-internal-format
+msgid "...following parameter %P which has a default argument"
+msgstr ""
+
+#: cp/decl2.cc:5740
+#, gcc-internal-format
+msgid "implicitly-declared %qD is deprecated"
+msgstr ""
+
+#: cp/decl2.cc:5744
+#, gcc-internal-format
+msgid "because %qT has user-provided %qD"
+msgstr ""
+
+#. We mark a lambda conversion op as deleted if we can't
+#. generate it properly; see maybe_add_lambda_conv_op.
+#: cp/decl2.cc:5885
+#, gcc-internal-format
+msgid "converting lambda that uses %<...%> to function pointer"
+msgstr ""
+
+#: cp/decl2.cc:5888
+#, gcc-internal-format
+msgid "use of deleted function %qD"
+msgstr ""
+
+#: cp/decl2.cc:5942
+#, gcc-internal-format
+msgid "use of function %qD with unsatisfied constraints"
+msgstr ""
+
+#: cp/decl2.cc:5974
+#, gcc-internal-format
+msgid "use of built-in parameter pack %qD outside of a template"
+msgstr ""
+
+#: cp/error.cc:4115
+#, gcc-internal-format
+msgid "(no argument)"
+msgstr ""
+
+#: cp/error.cc:4207
+#, gcc-internal-format
+msgid "[...]"
+msgstr ""
+
+#: cp/error.cc:4554
+#, gcc-internal-format
+msgid "extended initializer lists only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/error.cc:4559
+#, gcc-internal-format
+msgid "explicit conversion operators only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/error.cc:4564
+#, gcc-internal-format
+msgid "variadic templates only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/error.cc:4569
+#, gcc-internal-format
+msgid "lambda expressions only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/error.cc:4574
+#, gcc-internal-format
+msgid "C++11 auto only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/error.cc:4579
+#, gcc-internal-format
+msgid "scoped enums only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/error.cc:4584
+#, gcc-internal-format
+msgid "defaulted and deleted functions only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/error.cc:4590
+#, gcc-internal-format
+msgid "inline namespaces only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/error.cc:4595
+#, gcc-internal-format
+msgid "override controls (override/final) only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/error.cc:4600
+#, gcc-internal-format
+msgid "non-static data member initializers only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/error.cc:4605
+#, gcc-internal-format
+msgid "user-defined literals only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/error.cc:4610
+#, gcc-internal-format
+msgid "delegating constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/error.cc:4615
+#, gcc-internal-format
+msgid "inheriting constructors only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/error.cc:4620
+#, gcc-internal-format
+msgid "C++11 attributes only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/error.cc:4625
+#, gcc-internal-format
+msgid "ref-qualifiers only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/error.cc:4675
+#, gcc-internal-format
+msgid "incomplete type %qT used in nested name specifier"
+msgstr ""
+
+#: cp/error.cc:4679
+#, gcc-internal-format
+msgid "reference to %<%T::%D%> is ambiguous"
+msgstr ""
+
+#: cp/error.cc:4693
+#, gcc-internal-format
+msgid "%qD is not a member of %qT; did you mean %qs?"
+msgstr ""
+
+#: cp/error.cc:4697 cp/typeck.cc:2871
+#, gcc-internal-format
+msgid "%qD is not a member of %qT"
+msgstr ""
+
+#: cp/error.cc:4719
+#, gcc-internal-format
+msgid "%qD is not a member of %qD; did you mean %qs?"
+msgstr ""
+
+#: cp/error.cc:4723 cp/typeck.cc:3463
+#, gcc-internal-format
+msgid "%qD is not a member of %qD"
+msgstr ""
+
+#: cp/error.cc:4734
+#, gcc-internal-format
+msgid "%<::%D%> has not been declared; did you mean %qs?"
+msgstr ""
+
+#: cp/error.cc:4738
+#, gcc-internal-format
+msgid "%<::%D%> has not been declared"
+msgstr ""
+
+#: cp/except.cc:380
+#, gcc-internal-format
+msgid "exception handling disabled, use %<-fexceptions%> to enable"
+msgstr ""
+
+#: cp/except.cc:628
+#, gcc-internal-format
+msgid "throwing NULL, which has integral, not pointer type"
+msgstr ""
+
+#: cp/except.cc:731
+#, gcc-internal-format
+msgid "  in thrown expression"
+msgstr ""
+
+#: cp/except.cc:878
+#, gcc-internal-format
+msgid "cannot declare %<catch%> parameter to be of rvalue reference type %qT"
+msgstr ""
+
+#: cp/except.cc:888
+#, gcc-internal-format
+msgid "cannot throw expression of type %qT because it involves types of variable size"
+msgstr ""
+
+#: cp/except.cc:891
+#, gcc-internal-format
+msgid "cannot catch type %qT because it involves types of variable size"
+msgstr ""
+
+#: cp/except.cc:992
+#, gcc-internal-format
+msgid "exception of type %qT will be caught by earlier handler"
+msgstr ""
+
+#: cp/except.cc:994
+#, gcc-internal-format
+msgid "for type %qT"
+msgstr ""
+
+#: cp/except.cc:1023
+#, gcc-internal-format
+msgid "%<...%> handler must be the last handler for its try block"
+msgstr ""
+
+#: cp/except.cc:1119
+#, gcc-internal-format
+msgid "noexcept-expression evaluates to %<false%> because of a call to %qD"
+msgstr ""
+
+#: cp/except.cc:1122
+#, gcc-internal-format
+msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
+msgstr ""
+
+#: cp/expr.cc:232
+#, gcc-internal-format
+msgid "using value of assignment with %<volatile%>-qualified left operand is deprecated"
+msgstr ""
+
+#: cp/friend.cc:194
+#, gcc-internal-format
+msgid "%qD is already a friend of class %qT"
+msgstr ""
+
+#: cp/friend.cc:291
+#, gcc-internal-format
+msgid "invalid type %qT declared %<friend%>"
+msgstr ""
+
+#. template <class U> friend class T::X<U>;
+#. [temp.friend]
+#. Friend declarations shall not declare partial
+#. specializations.
+#: cp/friend.cc:308 cp/friend.cc:356
+#, gcc-internal-format
+msgid "partial specialization %qT declared %<friend%>"
+msgstr ""
+
+#: cp/friend.cc:322
+#, gcc-internal-format
+msgid "perhaps you need explicit template arguments in your nested-name-specifier"
+msgstr ""
+
+#: cp/friend.cc:334
+#, gcc-internal-format
+msgid "class %qT is implicitly friends with itself"
+msgstr ""
+
+#: cp/friend.cc:397
+#, gcc-internal-format
+msgid "%qT is not a member of %qT"
+msgstr ""
+
+#: cp/friend.cc:403
+#, gcc-internal-format
+msgid "%qT is not a member class template of %qT"
+msgstr ""
+
+#: cp/friend.cc:413
+#, gcc-internal-format
+msgid "%qT is not a nested class of %qT"
+msgstr ""
+
+#. template <class T> friend class T;
+#: cp/friend.cc:427
+#, gcc-internal-format
+msgid "template parameter type %qT declared %<friend%>"
+msgstr ""
+
+#. template <class T> friend class A; where A is not a template
+#: cp/friend.cc:435
+#, gcc-internal-format
+msgid "%q#T is not a template"
+msgstr ""
+
+#: cp/friend.cc:458
+#, gcc-internal-format
+msgid "%qD is already a friend of %qT"
+msgstr ""
+
+#: cp/friend.cc:468
+#, gcc-internal-format
+msgid "%qT is already a friend of %qT"
+msgstr ""
+
+#: cp/friend.cc:521
+#, gcc-internal-format
+msgid "friend declaration %qD may not have virt-specifiers"
+msgstr ""
+
+#: cp/friend.cc:599
+#, gcc-internal-format
+msgid "member %qD declared as friend before type %qT defined"
+msgstr ""
+
+#: cp/friend.cc:647
+#, gcc-internal-format
+msgid "friend declaration %q#D declares a non-template function"
+msgstr ""
+
+#: cp/friend.cc:651
+#, gcc-internal-format
+msgid "(if this is not what you intended, make sure the function template has already been declared and add %<<>%> after the function name here)"
+msgstr ""
+
+#: cp/init.cc:398
+#, gcc-internal-format
+msgid "value-initialization of incomplete type %qT"
+msgstr ""
+
+#: cp/init.cc:481
+#, gcc-internal-format
+msgid "cannot value-initialize array of unknown bound %qT"
+msgstr ""
+
+#: cp/init.cc:520
+#, gcc-internal-format
+msgid "value-initialization of function type %qT"
+msgstr ""
+
+#: cp/init.cc:526
+#, gcc-internal-format
+msgid "value-initialization of reference type %qT"
+msgstr ""
+
+#: cp/init.cc:595
+#, gcc-internal-format
+msgid "recursive instantiation of default member initializer for %qD"
+msgstr ""
+
+#: cp/init.cc:662
+#, gcc-internal-format
+msgid "default member initializer for %qD required before the end of its enclosing class"
+msgstr ""
+
+#: cp/init.cc:664
+#, gcc-internal-format
+msgid "defined here"
+msgstr ""
+
+#: cp/init.cc:732
+#, gcc-internal-format
+msgid "initializer for flexible array member %q#D"
+msgstr ""
+
+#: cp/init.cc:797
+#, gcc-internal-format
+msgid "initializing %qD from %qE does not extend the lifetime of the underlying array"
+msgstr ""
+
+#: cp/init.cc:901 cp/init.cc:1014
+#, gcc-internal-format
+msgid "%qD is initialized with itself"
+msgstr ""
+
+#: cp/init.cc:907
+#, gcc-internal-format
+msgid "reference %qD is not yet bound to a value when used here"
+msgstr ""
+
+#: cp/init.cc:912
+#, gcc-internal-format
+msgid "member %qD is used uninitialized"
+msgstr ""
+
+#: cp/init.cc:991
+#, gcc-internal-format
+msgid "%qD should be initialized in the member initialization list"
+msgstr ""
+
+#: cp/init.cc:1133
+#, gcc-internal-format
+msgid "invalid initializer for array member %q#D"
+msgstr ""
+
+#: cp/init.cc:1148 cp/init.cc:1174 cp/init.cc:2769 cp/method.cc:2494
+#, gcc-internal-format
+msgid "uninitialized const member in %q#T"
+msgstr ""
+
+#: cp/init.cc:1150 cp/init.cc:1168 cp/init.cc:1176 cp/init.cc:2754
+#: cp/init.cc:2782 cp/method.cc:2497 cp/method.cc:2508
+#, gcc-internal-format
+msgid "%q#D should be initialized"
+msgstr ""
+
+#: cp/init.cc:1166 cp/init.cc:2741 cp/method.cc:2505
+#, gcc-internal-format
+msgid "uninitialized reference member in %q#T"
+msgstr ""
+
+#: cp/init.cc:1351
+#, gcc-internal-format
+msgid "%qD will be initialized after"
+msgstr ""
+
+#: cp/init.cc:1354
+#, gcc-internal-format
+msgid "base %qT will be initialized after"
+msgstr ""
+
+#: cp/init.cc:1358
+#, gcc-internal-format
+msgid "  %q#D"
+msgstr ""
+
+#: cp/init.cc:1360
+#, gcc-internal-format
+msgid "  base %qT"
+msgstr ""
+
+#: cp/init.cc:1362
+#, gcc-internal-format
+msgid "  when initialized here"
+msgstr ""
+
+#: cp/init.cc:1379
+#, gcc-internal-format
+msgid "multiple initializations given for %qD"
+msgstr ""
+
+#: cp/init.cc:1383
+#, gcc-internal-format
+msgid "multiple initializations given for base %qT"
+msgstr ""
+
+#: cp/init.cc:1470
+#, gcc-internal-format
+msgid "initializations for multiple members of %qT"
+msgstr ""
+
+#: cp/init.cc:1579
+#, gcc-internal-format
+msgid "base class %q#T should be explicitly initialized in the copy constructor"
+msgstr ""
+
+#: cp/init.cc:1815 cp/init.cc:1834
+#, gcc-internal-format
+msgid "class %qT does not have any field named %qD"
+msgstr ""
+
+#: cp/init.cc:1821
+#, gcc-internal-format
+msgid "%q#D is a static data member; it can only be initialized at its definition"
+msgstr ""
+
+#: cp/init.cc:1828
+#, gcc-internal-format
+msgid "%q#D is not a non-static data member of %qT"
+msgstr ""
+
+#: cp/init.cc:1867
+#, gcc-internal-format
+msgid "unnamed initializer for %qT, which has no base classes"
+msgstr ""
+
+#: cp/init.cc:1875
+#, gcc-internal-format
+msgid "unnamed initializer for %qT, which uses multiple inheritance"
+msgstr ""
+
+#: cp/init.cc:1922
+#, gcc-internal-format
+msgid "%qD is both a direct base and an indirect virtual base"
+msgstr ""
+
+#: cp/init.cc:1930
+#, gcc-internal-format
+msgid "type %qT is not a direct or virtual base of %qT"
+msgstr ""
+
+#: cp/init.cc:1933
+#, gcc-internal-format
+msgid "type %qT is not a direct base of %qT"
+msgstr ""
+
+#: cp/init.cc:2045 cp/init.cc:4944 cp/typeck2.cc:1384
+#, gcc-internal-format
+msgid "array must be initialized with a brace-enclosed initializer"
+msgstr ""
+
+#: cp/init.cc:2366 cp/semantics.cc:4056 rust/backend/rust-tree.cc:4168
+#, gcc-internal-format
+msgid "%qT is not a class type"
+msgstr ""
+
+#: cp/init.cc:2424
+#, gcc-internal-format
+msgid "incomplete type %qT does not have member %qD"
+msgstr ""
+
+#: cp/init.cc:2438
+#, gcc-internal-format
+msgid "invalid pointer to bit-field %qD"
+msgstr ""
+
+#: cp/init.cc:2524 cp/typeck.cc:2357 rust/backend/rust-tree.cc:3811
+#, gcc-internal-format
+msgid "invalid use of non-static member function %qD"
+msgstr ""
+
+#: cp/init.cc:2531 cp/semantics.cc:2379
+#, gcc-internal-format
+msgid "invalid use of non-static data member %qD"
+msgstr ""
+
+#: cp/init.cc:2738
+#, gcc-internal-format
+msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
+msgstr ""
+
+#: cp/init.cc:2746
+#, gcc-internal-format
+msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
+msgstr ""
+
+#: cp/init.cc:2750
+#, gcc-internal-format
+msgid "uninitialized reference member in base %q#T of %q#T"
+msgstr ""
+
+#: cp/init.cc:2766
+#, gcc-internal-format
+msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
+msgstr ""
+
+#: cp/init.cc:2774
+#, gcc-internal-format
+msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
+msgstr ""
+
+#: cp/init.cc:2778
+#, gcc-internal-format
+msgid "uninitialized const member in base %q#T of %q#T"
+msgstr ""
+
+#: cp/init.cc:2893
+#, gcc-internal-format
+msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
+msgstr ""
+
+#: cp/init.cc:2896
+#, gcc-internal-format
+msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size at most %qwu"
+msgstr ""
+
+#: cp/init.cc:2906
+#, gcc-internal-format
+msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
+msgstr ""
+
+#: cp/init.cc:2909
+#, gcc-internal-format
+msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size at most %qwu"
+msgstr ""
+
+#: cp/init.cc:2918
+#, gcc-internal-format
+msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
+msgstr ""
+
+#: cp/init.cc:2921
+#, gcc-internal-format
+msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size at most %qwu"
+msgstr ""
+
+#: cp/init.cc:2938
+#, gcc-internal-format
+msgid "at offset %wi from %qD declared here"
+msgstr ""
+
+#: cp/init.cc:2942
+#, gcc-internal-format
+msgid "at offset [%wi, %wi] from %qD declared here"
+msgstr ""
+
+#: cp/init.cc:3140
+#, gcc-internal-format
+msgid "integer overflow in array size"
+msgstr ""
+
+#: cp/init.cc:3150
+#, gcc-internal-format
+msgid "array size in new-expression must be constant"
+msgstr ""
+
+#: cp/init.cc:3168
+#, gcc-internal-format
+msgid "variably modified type not allowed in new-expression"
+msgstr ""
+
+#: cp/init.cc:3184
+#, gcc-internal-format
+msgid "non-constant array new length must be specified directly, not by %<typedef%>"
+msgstr ""
+
+#: cp/init.cc:3186
+#, gcc-internal-format
+msgid "non-constant array new length must be specified without parentheses around the type-id"
+msgstr ""
+
+#: cp/init.cc:3196
+#, gcc-internal-format
+msgid "invalid type %<void%> for %<new%>"
+msgstr ""
+
+#: cp/init.cc:3202
+#, gcc-internal-format
+msgid "%<new%> of %<initializer_list%> does not extend the lifetime of the underlying array"
+msgstr ""
+
+#: cp/init.cc:3244
+#, gcc-internal-format
+msgid "uninitialized const in %<new%> of %q#T"
+msgstr ""
+
+#: cp/init.cc:3400
+#, gcc-internal-format
+msgid "no suitable %qD found in class %qT"
+msgstr ""
+
+#: cp/init.cc:3489
+#, gcc-internal-format
+msgid "%<new%> of type %qT with extended alignment %d"
+msgstr ""
+
+#: cp/init.cc:3492
+#, gcc-internal-format
+msgid "uses %qD, which does not have an alignment parameter"
+msgstr ""
+
+#: cp/init.cc:3495
+#, gcc-internal-format
+msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
+msgstr ""
+
+#: cp/init.cc:3691
+#, gcc-internal-format
+msgid "parenthesized initializer in array new"
+msgstr ""
+
+#: cp/init.cc:3962
+#, gcc-internal-format
+msgid "size in array new must have integral type"
+msgstr ""
+
+#: cp/init.cc:3991
+#, gcc-internal-format
+msgid "new cannot be applied to a reference type"
+msgstr ""
+
+#: cp/init.cc:4000
+#, gcc-internal-format
+msgid "new cannot be applied to a function type"
+msgstr ""
+
+#: cp/init.cc:4120
+#, gcc-internal-format
+msgid "possible problem detected in invocation of operator %<delete []%>"
+msgstr ""
+
+#: cp/init.cc:4124
+#, gcc-internal-format
+msgid "neither the destructor nor the class-specific operator %<delete []%> will be called, even if they are declared when the class is defined"
+msgstr ""
+
+#: cp/init.cc:4846
+#, gcc-internal-format
+msgid "initializer ends prematurely"
+msgstr ""
+
+#: cp/init.cc:5144
+#, gcc-internal-format
+msgid "unknown array size in delete"
+msgstr ""
+
+#: cp/init.cc:5178
+#, gcc-internal-format
+msgid "possible problem detected in invocation of %<operator delete%>"
+msgstr ""
+
+#: cp/init.cc:5183
+#, gcc-internal-format
+msgid "neither the destructor nor the class-specific %<operator delete%> will be called, even if they are declared when the class is defined"
+msgstr ""
+
+#: cp/init.cc:5198
+#, gcc-internal-format
+msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
+msgstr ""
+
+#: cp/init.cc:5203
+#, gcc-internal-format
+msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
+msgstr ""
+
+#: cp/init.cc:5517
+#, gcc-internal-format
+msgid "type to vector delete is neither pointer or array type"
+msgstr ""
+
+#: cp/lambda.cc:550
+#, gcc-internal-format
+msgid "array of runtime bound cannot be captured by copy, only by reference"
+msgstr ""
+
+#: cp/lambda.cc:565
+#, gcc-internal-format
+msgid "capture of variably-modified type %qT that is not an N3639 array of runtime bound"
+msgstr ""
+
+#: cp/lambda.cc:569
+#, gcc-internal-format
+msgid "because the array element type %qT has variable size"
+msgstr ""
+
+#: cp/lambda.cc:593
+#, gcc-internal-format
+msgid "cannot capture %qE by reference"
+msgstr ""
+
+#: cp/lambda.cc:603
+#, gcc-internal-format
+msgid "capture by copy of incomplete type %qT"
+msgstr ""
+
+#: cp/lambda.cc:675
+#, gcc-internal-format
+msgid "trying to capture %qD in instantiation of generic lambda"
+msgstr ""
+
+#: cp/lambda.cc:751
+#, gcc-internal-format
+msgid "implicit capture of %qE via %<[=]%> is deprecated in C++20"
+msgstr ""
+
+#: cp/lambda.cc:753
+#, gcc-internal-format
+msgid "add explicit %<this%> or %<*this%> capture"
+msgstr ""
+
+#: cp/lambda.cc:874
+#, gcc-internal-format
+msgid "%<this%> was not captured for this lambda function"
+msgstr ""
+
+#: cp/lex.cc:644
+#, gcc-internal-format
+msgid "invalid %<#pragma %s%>"
+msgstr ""
+
+#: cp/lex.cc:652
+#, gcc-internal-format
+msgid "%<#pragma vtable%> no longer supported"
+msgstr ""
+
+#: cp/lex.cc:724
+#, gcc-internal-format
+msgid "%<#pragma implementation%> for %qs appears after file is included"
+msgstr ""
+
+#: cp/lex.cc:752
+#, gcc-internal-format
+msgid "%qD not defined"
+msgstr ""
+
+#: cp/lex.cc:764
+#, gcc-internal-format
+msgid "%qD was not declared in this scope; did you mean %qs?"
+msgstr ""
+
+#: cp/lex.cc:768
+#, gcc-internal-format
+msgid "%qD was not declared in this scope"
+msgstr ""
+
+#. In a template, it is invalid to write "f()" or "f(3)" if no
+#. declaration of "f" is available.  Historically, G++ and most
+#. other compilers accepted that usage since they deferred all name
+#. lookup until instantiation time rather than doing unqualified
+#. name lookup at template definition time; explain to the user what
+#. is going wrong.
+#.
+#. Note that we have the exact wording of the following message in
+#. the manual (trouble.texi, node "Name lookup"), so they need to
+#. be kept in synch.
+#: cp/lex.cc:810
+#, gcc-internal-format
+msgid "there are no arguments to %qD that depend on a template parameter, so a declaration of %qD must be available"
+msgstr ""
+
+#: cp/lex.cc:819
+#, gcc-internal-format
+msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
+msgstr ""
+
+#: cp/logic.cc:303
+#, gcc-internal-format
+msgid "  # %E"
+msgstr ""
+
+#: cp/mangle.cc:2662
+#, gcc-internal-format
+msgid "mangling %<typeof%>, use %<decltype%> instead"
+msgstr ""
+
+#: cp/mangle.cc:2666
+#, gcc-internal-format
+msgid "use of built-in trait %qT in function signature; use library traits instead"
+msgstr ""
+
+#: cp/mangle.cc:3836
+#, gcc-internal-format
+msgid "use of built-in trait %qE in function signature; use library traits instead"
+msgstr ""
+
+#: cp/mangle.cc:3841
+#, gcc-internal-format, gfc-internal-format
+msgid "mangling %C"
+msgstr ""
+
+#: cp/mangle.cc:3915
+#, gcc-internal-format
+msgid "omitted middle operand to %<?:%> operand cannot be mangled"
+msgstr ""
+
+#: cp/mangle.cc:4486
+#, gcc-internal-format
+msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
+msgstr ""
+
+#: cp/mangle.cc:4532 cp/mangle.cc:4711
+#, gcc-internal-format
+msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
+msgstr ""
+
+#: cp/mangle.cc:4538 cp/mangle.cc:4717
+#, gcc-internal-format
+msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
+msgstr ""
+
+#: cp/mangle.cc:4864
+#, gcc-internal-format
+msgid "the mangled name of a thunk for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
+msgstr ""
+
+#: cp/mangle.cc:4869
+#, gcc-internal-format
+msgid "the mangled name of %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
+msgstr ""
+
+#: cp/mangle.cc:4874
+#, gcc-internal-format
+msgid "the mangled name of the initialization guard variable for %qD changes between %<-fabi-version=%d%> and %<-fabi-version=%d%>"
+msgstr ""
+
+#: cp/mapper-client.cc:318
+#, gcc-internal-format
+msgid "failed %s mapper %qs line %u"
+msgstr ""
+
+#: cp/mapper-client.cc:319
+#, gcc-internal-format
+msgid "failed %s mapper %qs"
+msgstr ""
+
+#: cp/mapper-client.cc:331
+#, gcc-internal-format, gfc-internal-format
+msgid "failed mapper handshake %s"
+msgstr ""
+
+#: cp/mapper-client.cc:365
+#, gcc-internal-format, gfc-internal-format
+msgid "mapper died by signal %s"
+msgstr ""
+
+#: cp/mapper-client.cc:368
+#, gcc-internal-format, gfc-internal-format
+msgid "mapper exit status %d"
+msgstr ""
+
+#: cp/method.cc:861 cp/method.cc:2447
+#, gcc-internal-format
+msgid "non-static const member %q#D, cannot use default assignment operator"
+msgstr ""
+
+#: cp/method.cc:867 cp/method.cc:2453
+#, gcc-internal-format
+msgid "non-static reference member %q#D, cannot use default assignment operator"
+msgstr ""
+
+#: cp/method.cc:957
+#, gcc-internal-format
+msgid "%qD is not a static data member"
+msgstr ""
+
+#: cp/method.cc:958
+#, gcc-internal-format
+msgid "determining value of %qs"
+msgstr ""
+
+#: cp/method.cc:985
+#, gcc-internal-format
+msgid "forming type of %qs"
+msgstr ""
+
+#: cp/method.cc:1176
+#, gcc-internal-format
+msgid "defaulted %qD only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/method.cc:1191
+#, gcc-internal-format
+msgid "defaulted %qD must return %<bool%>"
+msgstr ""
+
+#: cp/method.cc:1199
+#, gcc-internal-format
+msgid "defaulted %qD must be %<const%>"
+msgstr ""
+
+#: cp/method.cc:1204
+#, gcc-internal-format
+msgid "defaulted %qD must not have %<&&%> ref-qualifier"
+msgstr ""
+
+#: cp/method.cc:1233
+#, gcc-internal-format
+msgid "defaulted %qD is not a friend of %qT"
+msgstr ""
+
+#: cp/method.cc:1245
+#, gcc-internal-format
+msgid "defaulted member %qD must have parameter type %<const %T&%>"
+msgstr ""
+
+#: cp/method.cc:1248
+#, gcc-internal-format
+msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT"
+msgstr ""
+
+#: cp/method.cc:1251
+#, gcc-internal-format
+msgid "defaulted %qD must have parameters of either type %<const %T&%> or %qT, not both"
+msgstr ""
+
+#. Return type is auto, suggest changing it.
+#: cp/method.cc:1408
+#, gcc-internal-format
+msgid "changing the return type from %qs to a comparison category type will allow the comparison to use %qs and %qs"
+msgstr ""
+
+#: cp/method.cc:1428
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, not a comparison category type"
+msgstr ""
+
+#: cp/method.cc:1437
+#, gcc-internal-format
+msgid "three-way comparison of %qD has type %qT, which does not convert to %qT"
+msgstr ""
+
+#: cp/method.cc:1482
+#, gcc-internal-format
+msgid "cannot default compare union %qT"
+msgstr ""
+
+#: cp/method.cc:1550
+#, gcc-internal-format
+msgid "cannot default compare reference member %qD"
+msgstr ""
+
+#: cp/method.cc:1559
+#, gcc-internal-format
+msgid "cannot default compare anonymous union member"
+msgstr ""
+
+#: cp/method.cc:1577
+#, gcc-internal-format
+msgid "cannot default compare flexible array member"
+msgstr ""
+
+#: cp/method.cc:1858
+#, gcc-internal-format
+msgid "synthesized method %qD first required here"
+msgstr ""
+
+#: cp/method.cc:2370
+#, gcc-internal-format
+msgid "union member %q+D with non-trivial %qD"
+msgstr ""
+
+#: cp/method.cc:2381
+#, gcc-internal-format
+msgid "defaulted destructor calls non-%<constexpr%> %qD"
+msgstr ""
+
+#: cp/method.cc:2382
+#, gcc-internal-format
+msgid "defaulted constructor calls non-%<constexpr%> %qD"
+msgstr ""
+
+#: cp/method.cc:2470
+#, gcc-internal-format
+msgid "initializer for %q#D is invalid"
+msgstr ""
+
+#: cp/method.cc:2527
+#, gcc-internal-format
+msgid "defaulted default constructor does not initialize %q#D"
+msgstr ""
+
+#: cp/method.cc:2538
+#, gcc-internal-format
+msgid "copying non-static data member %q#D of rvalue reference type"
+msgstr ""
+
+#. A trivial constructor doesn't have any NSDMI.
+#: cp/method.cc:2756
+#, gcc-internal-format
+msgid "defaulted default constructor does not initialize any non-static data member"
+msgstr ""
+
+#: cp/method.cc:2800
+#, gcc-internal-format
+msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
+msgstr ""
+
+#: cp/method.cc:2932
+#, gcc-internal-format
+msgid "a lambda closure type has a deleted default constructor"
+msgstr ""
+
+#: cp/method.cc:2935
+#, gcc-internal-format
+msgid "a lambda closure type has a deleted copy assignment operator"
+msgstr ""
+
+#: cp/method.cc:2944
+#, gcc-internal-format
+msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
+msgstr ""
+
+#: cp/method.cc:2955
+#, gcc-internal-format
+msgid "%q#D inherits from multiple base subobjects"
+msgstr ""
+
+#: cp/method.cc:2963 cp/method.cc:2987
+#, gcc-internal-format
+msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
+msgstr ""
+
+#: cp/method.cc:2996
+msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
+msgstr ""
+
+#: cp/method.cc:3426
+#, gcc-internal-format
+msgid "defaulted declaration %q+D does not match the expected signature"
+msgstr ""
+
+#: cp/method.cc:3429
+#, gcc-internal-format
+msgid "expected signature: %qD"
+msgstr ""
+
+#: cp/method.cc:3461
+#, gcc-internal-format
+msgid "explicitly defaulted function %q+D cannot be declared %qs because the implicit declaration is not %qs:"
+msgstr ""
+
+#: cp/method.cc:3481
+#, gcc-internal-format
+msgid "a template cannot be defaulted"
+msgstr ""
+
+#: cp/method.cc:3520
+#, gcc-internal-format
+msgid "%qD cannot be defaulted"
+msgstr ""
+
+#: cp/method.cc:3529
+#, gcc-internal-format
+msgid "defaulted function %q+D with default argument"
+msgstr ""
+
+#: cp/module.cc:1583
+#, gcc-internal-format
+msgid "section %qs is missing or corrupted"
+msgstr ""
+
+#: cp/module.cc:1585
+#, gcc-internal-format, gfc-internal-format
+msgid "section #%u is missing or corrupted"
+msgstr ""
+
+#: cp/module.cc:1807
+#, gcc-internal-format
+msgid "not Encapsulated Lazy Records of Named Declarations"
+msgstr ""
+
+#: cp/module.cc:1822
+#, gcc-internal-format
+msgid "unexpected encapsulation format or type"
+msgstr ""
+
+#: cp/module.cc:1831
+#, gcc-internal-format
+msgid "encapsulation is malformed"
+msgstr ""
+
+#: cp/module.cc:11604
+#, gcc-internal-format
+msgid "conflicting global module declaration %#qD"
+msgstr ""
+
+#: cp/module.cc:11606
+#, gcc-internal-format
+msgid "existing declaration %#qD"
+msgstr ""
+
+#: cp/module.cc:12655
+#, gcc-internal-format
+msgid "definition of %qD does not match"
+msgstr ""
+
+#: cp/module.cc:12657
+#, gcc-internal-format
+msgid "existing definition %qD"
+msgstr ""
+
+#: cp/module.cc:12669
+#, gcc-internal-format
+msgid "... this enumerator %qD"
+msgstr ""
+
+#: cp/module.cc:12671
+#, gcc-internal-format
+msgid "enumerator %qD does not match ..."
+msgstr ""
+
+#: cp/module.cc:12677
+#, gcc-internal-format
+msgid "additional enumerators beginning with %qD"
+msgstr ""
+
+#: cp/module.cc:12681
+#, gcc-internal-format
+msgid "enumeration range differs"
+msgstr ""
+
+#: cp/module.cc:13782
+#, gcc-internal-format
+msgid "%q#D references internal linkage entity %q#D"
+msgstr ""
+
+#: cp/module.cc:14365
+#, gcc-internal-format
+msgid "recursive lazy load"
+msgstr ""
+
+#. Cannot import the current module.
+#: cp/module.cc:14384
+#, gcc-internal-format
+msgid "cannot import module in its own purview"
+msgstr ""
+
+#: cp/module.cc:14385 cp/module.cc:19710
+#, gcc-internal-format
+msgid "module %qs declared here"
+msgstr ""
+
+#: cp/module.cc:14729
+#, gcc-internal-format
+msgid "indirect import %qs is not already loaded"
+msgstr ""
+
+#: cp/module.cc:14735
+#, gcc-internal-format
+msgid "import %qs has CRC mismatch"
+msgstr ""
+
+#: cp/module.cc:16563
+#, gcc-internal-format
+msgid "unable to represent further imported source locations"
+msgstr ""
+
+#: cp/module.cc:17438
+#, gcc-internal-format
+msgid "not exporting %<#define %E%> as it is a keyword"
+msgstr ""
+
+#: cp/module.cc:17678
+#, gcc-internal-format
+msgid "macro definitions of %qE corrupted"
+msgstr ""
+
+#: cp/module.cc:17702 cp/module.cc:17705
+#, gcc-internal-format
+msgid "inconsistent imported macro definition %qE"
+msgstr ""
+
+#: cp/module.cc:17711
+#, gcc-internal-format
+msgid "%<#undef %E%>"
+msgstr ""
+
+#: cp/module.cc:17713
+#, gcc-internal-format
+msgid "%<#define %s%>"
+msgstr ""
+
+#: cp/module.cc:17946
+#, gcc-internal-format
+msgid "compiled module file is %qs"
+msgstr ""
+
+#: cp/module.cc:17983 cp/module.cc:17988
+#, gcc-internal-format, gfc-internal-format
+msgid "compiled module is %sversion %s"
+msgstr ""
+
+#: cp/module.cc:17994
+#, gcc-internal-format, gfc-internal-format
+msgid "compiler is %sversion %s%s%s"
+msgstr ""
+
+#: cp/module.cc:18024
+#, gcc-internal-format
+msgid "module %qs found"
+msgstr ""
+
+#: cp/module.cc:18026
+#, gcc-internal-format
+msgid "header module expected, module %qs found"
+msgstr ""
+
+#: cp/module.cc:18027
+#, gcc-internal-format
+msgid "module %qs expected, header module found"
+msgstr ""
+
+#: cp/module.cc:18042
+#, gcc-internal-format
+msgid "module %qs CRC mismatch"
+msgstr ""
+
+#: cp/module.cc:18056
+#, gcc-internal-format
+msgid "target & host is %qs:%qs, expected %qs:%qs"
+msgstr ""
+
+#: cp/module.cc:18068
+#, gcc-internal-format
+msgid "language dialect differs %qs, expected %qs"
+msgstr ""
+
+#: cp/module.cc:18084
+#, gcc-internal-format
+msgid "module contains OpenMP, use %<-fopenmp%> to enable"
+msgstr ""
+
+#: cp/module.cc:18101
+#, gcc-internal-format
+msgid "fixed tree mismatch"
+msgstr ""
+
+#: cp/module.cc:18192
+#, gcc-internal-format
+msgid "interface partition is not exported"
+msgstr ""
+
+#: cp/module.cc:18749
+#, gcc-internal-format, gfc-internal-format
+msgid "failed to read compiled module cluster %u: %s"
+msgstr ""
+
+#: cp/module.cc:18787
+#, gcc-internal-format, gfc-internal-format
+msgid "failed to read compiled module: %s"
+msgstr ""
+
+#: cp/module.cc:18797
+#, gcc-internal-format
+msgid "consider using %<-fno-module-lazy%>, increasing %<-param-lazy-modules=%u%> value, or increasing the per-process file descriptor limit"
+msgstr ""
+
+#: cp/module.cc:18802
+#, gcc-internal-format
+msgid "imports must be built before being imported"
+msgstr ""
+
+#: cp/module.cc:18805
+#, gcc-internal-format
+msgid "returning to the gate for a mechanical issue"
+msgstr ""
+
+#: cp/module.cc:19117
+#, gcc-internal-format
+msgid "declaration %qD conflicts with builtin"
+msgstr ""
+
+#: cp/module.cc:19122
+#, gcc-internal-format
+msgid "redeclaring %qD in module %qs conflicts with import"
+msgstr ""
+
+#: cp/module.cc:19125
+#, gcc-internal-format
+msgid "redeclaring %qD in global module conflicts with import"
+msgstr ""
+
+#: cp/module.cc:19130
+#, gcc-internal-format
+msgid "import declared attached to module %qs"
+msgstr ""
+
+#: cp/module.cc:19134
+#, gcc-internal-format
+msgid "import declared in global module"
+msgstr ""
+
+#: cp/module.cc:19140
+#, gcc-internal-format
+msgid "conflicting declaration of %qD in module %qs"
+msgstr ""
+
+#: cp/module.cc:19143
+#, gcc-internal-format
+msgid "conflicting declaration of %qD in global module"
+msgstr ""
+
+#: cp/module.cc:19148
+#, gcc-internal-format
+msgid "previously declared in module %qs"
+msgstr ""
+
+#: cp/module.cc:19152
+#, gcc-internal-format
+msgid "previously declared in global module"
+msgstr ""
+
+#: cp/module.cc:19404
+#, gcc-internal-format
+msgid "reading CMI %qs"
+msgstr ""
+
+#: cp/module.cc:19555
+#, gcc-internal-format
+msgid "failed to load binding %<%E%s%E%>"
+msgstr ""
+
+#: cp/module.cc:19556
+#, gcc-internal-format
+msgid "failed to load binding %<%E%s%E@%s%>"
+msgstr ""
+
+#: cp/module.cc:19563
+#, gcc-internal-format
+msgid "during load of binding %<%E%s%E%>"
+msgstr ""
+
+#: cp/module.cc:19564
+#, gcc-internal-format
+msgid "during load of binding %<%E%s%E@%s%>"
+msgstr ""
+
+#: cp/module.cc:19626
+#, gcc-internal-format
+msgid "failed to load pendings for %<%E%s%E%>"
+msgstr ""
+
+#: cp/module.cc:19630
+#, gcc-internal-format
+msgid "during load of pendings for %<%E%s%E%>"
+msgstr ""
+
+#. Only header units should appear inside language
+#. specifications.  The std doesn't specify this, but I think
+#. that's an error in resolving US 033, because language linkage
+#. is also our escape clause to getting things into the global
+#. module, so we don't want to confuse things by having to think
+#. about whether 'extern "C++" { import foo; }' puts foo's
+#. contents into the global module all of a sudden.
+#: cp/module.cc:19675
+#, gcc-internal-format
+msgid "import of named module %qs inside language-linkage block"
+msgstr ""
+
+#: cp/module.cc:19705
+#, gcc-internal-format
+msgid "module already declared"
+msgstr ""
+
+#: cp/module.cc:19706
+#, gcc-internal-format
+msgid "module already imported"
+msgstr ""
+
+#: cp/module.cc:19711
+#, gcc-internal-format
+msgid "module %qs imported here"
+msgstr ""
+
+#: cp/module.cc:19918
+#, gcc-internal-format, gfc-internal-format
+msgid "unknown Compiled Module Interface: %s"
+msgstr ""
+
+#: cp/module.cc:19961
+#, gcc-internal-format
+msgid "cannot determine %<#include%> translation of %s: %s"
+msgstr ""
+
+#: cp/module.cc:19979
+#, gcc-internal-format
+msgid "include %qs translated to import"
+msgstr ""
+
+#: cp/module.cc:19980
+#, gcc-internal-format
+msgid "include %qs processed textually"
+msgstr ""
+
+#: cp/module.cc:20339
+#, gcc-internal-format
+msgid "C++ modules are incompatible with precompiled headers"
+msgstr ""
+
+#: cp/module.cc:20343
+#, gcc-internal-format
+msgid "C++ modules are incompatible with traditional preprocessing"
+msgstr ""
+
+#: cp/module.cc:20353
+#, gcc-internal-format
+msgid "macro debug output may be incomplete with modules"
+msgstr ""
+
+#: cp/module.cc:20354
+#, gcc-internal-format
+msgid "module dependencies require preprocessing"
+msgstr ""
+
+#: cp/module.cc:20356
+#, gcc-internal-format
+msgid "you should use the %<-%s%> option"
+msgstr ""
+
+#: cp/module.cc:20391 cp/module.cc:20420
+#, gcc-internal-format
+msgid "invalid header name %qs"
+msgstr ""
+
+#: cp/module.cc:20430
+#, gcc-internal-format
+msgid "invalid module name %qs"
+msgstr ""
+
+#: cp/module.cc:20630
+#, gcc-internal-format
+msgid "%<-fmodule-only%> used for non-interface"
+msgstr ""
+
+#: cp/module.cc:20670
+#, gcc-internal-format
+msgid "writing CMI %qs"
+msgstr ""
+
+#: cp/module.cc:20677
+#, gcc-internal-format
+msgid "not writing module %qs due to errors"
+msgstr ""
+
+#: cp/module.cc:20742
+#, gcc-internal-format, gfc-internal-format
+msgid "failed to write compiled module: %s"
+msgstr ""
+
+#: cp/module.cc:20839
+#, gcc-internal-format
+msgid "unknown header kind %qs"
+msgstr ""
+
+#: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
+#, gcc-internal-format
+msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
+msgstr ""
+
+#: cp/name-lookup.cc:2891
+#, gcc-internal-format
+msgid "redeclaration of %q#D with different template parameters"
+msgstr ""
+
+#: cp/name-lookup.cc:2897
+#, gcc-internal-format
+msgid "%q#D conflicts with a previous declaration"
+msgstr ""
+
+#: cp/name-lookup.cc:3064
+#, gcc-internal-format
+msgid "%q#D hides constructor for %q#D"
+msgstr ""
+
+#: cp/name-lookup.cc:3215
+#, gcc-internal-format
+msgid "conflicting C language linkage declaration %q#D"
+msgstr ""
+
+#: cp/name-lookup.cc:3220
+#, gcc-internal-format
+msgid "due to different exception specifications"
+msgstr ""
+
+#: cp/name-lookup.cc:3330
+#, gcc-internal-format
+msgid "lambda parameter %qD previously declared as a capture"
+msgstr ""
+
+#: cp/name-lookup.cc:3363 cp/name-lookup.cc:3367
+#, gcc-internal-format
+msgid "declaration of %q#D shadows a parameter"
+msgstr ""
+
+#: cp/name-lookup.cc:3526
+#, gcc-internal-format
+msgid "declaration of %qD shadows a member of %qT"
+msgstr ""
+
+#: cp/name-lookup.cc:4018
+#, gcc-internal-format
+msgid "friend declaration %qD in local class without prior local declaration"
+msgstr ""
+
+#: cp/name-lookup.cc:4569
+#, gcc-internal-format
+msgid "%s %<%s(%E)%> %p %d"
+msgstr ""
+
+#: cp/name-lookup.cc:4572
+#, gcc-internal-format
+msgid "%s %s %p %d"
+msgstr ""
+
+#: cp/name-lookup.cc:5158
+#, gcc-internal-format
+msgid "exporting %q#D that does not have external linkage"
+msgstr ""
+
+#: cp/name-lookup.cc:5163
+#, gcc-internal-format
+msgid "%q#D declared here with no linkage"
+msgstr ""
+
+#: cp/name-lookup.cc:5166
+#, gcc-internal-format
+msgid "%q#D declared here with internal linkage"
+msgstr ""
+
+#: cp/name-lookup.cc:5169
+#, gcc-internal-format
+msgid "%q#D declared here with module linkage"
+msgstr ""
+
+#: cp/name-lookup.cc:5968
+#, gcc-internal-format
+msgid "%<%T%s%D%> names destructor"
+msgstr ""
+
+#: cp/name-lookup.cc:5984
+#, gcc-internal-format
+msgid "using-declaration for non-member at class scope"
+msgstr ""
+
+#: cp/name-lookup.cc:5992
+#, gcc-internal-format
+msgid "%<using%> with enumeration scope %q#T only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/name-lookup.cc:6008 cp/pt.cc:18531
+#, gcc-internal-format
+msgid "%qT is not a class, namespace, or enumeration"
+msgstr ""
+
+#: cp/name-lookup.cc:6018
+#, gcc-internal-format
+msgid "non-member using-declaration names constructor of %qT"
+msgstr ""
+
+#: cp/name-lookup.cc:6029 cp/name-lookup.cc:6102
+#, gcc-internal-format
+msgid "using-declaration for member at non-class scope"
+msgstr ""
+
+#: cp/name-lookup.cc:6052
+#, gcc-internal-format
+msgid "%qT is not a direct base of %qT"
+msgstr ""
+
+#: cp/name-lookup.cc:6112
+#, gcc-internal-format
+msgid "did you mean %<using enum %T::%D%>?"
+msgstr ""
+
+#: cp/name-lookup.cc:6124
+#, gcc-internal-format
+msgid "%qD has not been declared in %qD"
+msgstr ""
+
+#: cp/name-lookup.cc:6138
+#, gcc-internal-format
+msgid "using-declaration may not name namespace %qD"
+msgstr ""
+
+#: cp/name-lookup.cc:6149
+#, gcc-internal-format
+msgid "%<%T::%D%> names constructor in %qT"
+msgstr ""
+
+#: cp/name-lookup.cc:6242
+#, gcc-internal-format
+msgid "declaration of %qD not in a namespace surrounding %qD"
+msgstr ""
+
+#: cp/name-lookup.cc:6283
+#, gcc-internal-format
+msgid "explicit qualification in declaration of %qD"
+msgstr ""
+
+#: cp/name-lookup.cc:6293
+#, gcc-internal-format
+msgid "%qD should have been declared inside %qD"
+msgstr ""
+
+#: cp/name-lookup.cc:6362
+#, gcc-internal-format
+msgid "%qD has not been declared within %qD"
+msgstr ""
+
+#: cp/name-lookup.cc:6364
+#, gcc-internal-format
+msgid "only here as a %<friend%>"
+msgstr ""
+
+#: cp/name-lookup.cc:6418
+#, gcc-internal-format
+msgid "%qD attribute requires a single NTBS argument"
+msgstr ""
+
+#: cp/name-lookup.cc:6425
+#, gcc-internal-format
+msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
+msgstr ""
+
+#: cp/name-lookup.cc:6435 cp/name-lookup.cc:6462
+#, gcc-internal-format
+msgid "ignoring %qD attribute on anonymous namespace"
+msgstr ""
+
+#: cp/name-lookup.cc:6441
+#, gcc-internal-format
+msgid "ignoring %qD attribute on non-inline namespace"
+msgstr ""
+
+#: cp/name-lookup.cc:6478 cp/name-lookup.cc:8872
+#, gcc-internal-format
+msgid "%qD attribute directive ignored"
+msgstr ""
+
+#: cp/name-lookup.cc:6804
+#, gcc-internal-format
+msgid "maximum limit of %d namespaces searched for %qE"
+msgstr ""
+
+#: cp/name-lookup.cc:6856
+#, gcc-internal-format
+msgid "suggested alternative:"
+msgid_plural "suggested alternatives:"
+msgstr[0] ""
+msgstr[1] ""
+
+#: cp/name-lookup.cc:6862
+#, gcc-internal-format
+msgid "  %qE"
+msgstr ""
+
+#: cp/name-lookup.cc:7176
+#, gcc-internal-format
+msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
+msgstr ""
+
+#: cp/name-lookup.cc:7182
+#, gcc-internal-format
+msgid "%<std::%s%> is only available from %s onwards"
+msgstr ""
+
+#: cp/name-lookup.cc:7618
+#, gcc-internal-format
+msgid "the macro %qs had not yet been defined"
+msgstr ""
+
+#: cp/name-lookup.cc:7621
+#, gcc-internal-format
+msgid "it was later defined here"
+msgstr ""
+
+#: cp/name-lookup.cc:8416
+#, gcc-internal-format
+msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn%'t a template"
+msgstr ""
+
+#: cp/name-lookup.cc:8844
+#, gcc-internal-format
+msgid "%<strong%> using directive no longer supported"
+msgstr ""
+
+#: cp/name-lookup.cc:8847
+#, gcc-internal-format
+msgid "you can use an inline namespace instead"
+msgstr ""
+
+#: cp/name-lookup.cc:8866
+#, gcc-internal-format
+msgid "%<omp::%E%> not allowed to be specified in this context"
+msgstr ""
+
+#. We only allow depth 255.
+#: cp/name-lookup.cc:8958
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot nest more than %d namespaces"
+msgstr ""
+
+#: cp/name-lookup.cc:9055
+#, gcc-internal-format
+msgid "%<namespace %E%> is ambiguous"
+msgstr ""
+
+#: cp/name-lookup.cc:9071
+#, gcc-internal-format
+msgid "namespace alias %qD not allowed here, assuming %qD"
+msgstr ""
+
+#: cp/name-lookup.cc:9158
+#, gcc-internal-format
+msgid "inline namespace must be specified at initial definition"
+msgstr ""
+
+#: cp/name-lookup.cc:9159
+#, gcc-internal-format
+msgid "%qD defined here"
+msgstr ""
+
+#: cp/name-lookup.cc:9207
+#, gcc-internal-format
+msgid "%s namespace %qD conflicts with reachable definition"
+msgstr ""
+
+#: cp/name-lookup.cc:9209
+#, gcc-internal-format, gfc-internal-format
+msgid "reachable %s definition here"
+msgstr ""
+
+#: cp/name-lookup.cc:9252
+#, gcc-internal-format
+msgid "XXX entering %<pop_everything ()%>"
+msgstr ""
+
+#: cp/name-lookup.cc:9261
+#, gcc-internal-format
+msgid "XXX leaving %<pop_everything ()%>"
+msgstr ""
+
+#: cp/optimize.cc:629
+#, gcc-internal-format
+msgid "making multiple clones of %qD"
+msgstr ""
+
+#: cp/parser.cc:1006
+#, gcc-internal-format
+msgid "identifier %qE is a keyword in C++11"
+msgstr ""
+
+#: cp/parser.cc:1020
+#, gcc-internal-format
+msgid "identifier %qE is a keyword in C++20"
+msgstr ""
+
+#: cp/parser.cc:1569 cp/parser.cc:1582
+#, gcc-internal-format
+msgid "%<LEXER_DEBUGGING_ENABLED_P%> is not set to true"
+msgstr ""
+
+#: cp/parser.cc:1607 cp/parser.cc:47879
+#, gcc-internal-format
+msgid "%<#pragma omp declare %s%> not immediately followed by function declaration or definition"
+msgstr ""
+
+#: cp/parser.cc:1647
+#, gcc-internal-format
+msgid "%<declare %s%> directive not immediately followed by function declaration or definition"
+msgstr ""
+
+#: cp/parser.cc:3226
+#, gcc-internal-format
+msgid "%<#pragma%> is not allowed here"
+msgstr ""
+
+#: cp/parser.cc:3355
+#, gcc-internal-format
+msgid "%<%E::%E%> has not been declared"
+msgstr ""
+
+#: cp/parser.cc:3358
+#, gcc-internal-format
+msgid "%<::%E%> has not been declared"
+msgstr ""
+
+#: cp/parser.cc:3361
+#, gcc-internal-format
+msgid "request for member %qE in non-class type %qT"
+msgstr ""
+
+#: cp/parser.cc:3364 cp/parser.cc:21671
+#, gcc-internal-format
+msgid "%<%T::%E%> has not been declared"
+msgstr ""
+
+#: cp/parser.cc:3374
+#, gcc-internal-format
+msgid "%<%E::%E%> is not a type"
+msgstr ""
+
+#: cp/parser.cc:3378
+#, gcc-internal-format
+msgid "%<%E::%E%> is not a class or namespace"
+msgstr ""
+
+#: cp/parser.cc:3383
+#, gcc-internal-format
+msgid "%<%E::%E%> is not a class, namespace, or enumeration"
+msgstr ""
+
+#: cp/parser.cc:3396
+#, gcc-internal-format
+msgid "%<::%E%> is not a type"
+msgstr ""
+
+#: cp/parser.cc:3399
+#, gcc-internal-format
+msgid "%<::%E%> is not a class or namespace"
+msgstr ""
+
+#: cp/parser.cc:3403
+#, gcc-internal-format
+msgid "%<::%E%> is not a class, namespace, or enumeration"
+msgstr ""
+
+#: cp/parser.cc:3415
+#, gcc-internal-format
+msgid "%qE is not a type"
+msgstr ""
+
+#: cp/parser.cc:3418
+#, gcc-internal-format
+msgid "%qE is not a class or namespace"
+msgstr ""
+
+#: cp/parser.cc:3422
+#, gcc-internal-format
+msgid "%qE is not a class, namespace, or enumeration"
+msgstr ""
+
+#: cp/parser.cc:3486
+#, gcc-internal-format
+msgid "new types may not be defined in a return type"
+msgstr ""
+
+#: cp/parser.cc:3488
+#, gcc-internal-format
+msgid "(perhaps a semicolon is missing after the definition of %qT)"
+msgstr ""
+
+#: cp/parser.cc:3516
+#, gcc-internal-format
+msgid "%qE is not a class template"
+msgstr ""
+
+#: cp/parser.cc:3518
+#, gcc-internal-format
+msgid "%qE is not a template"
+msgstr ""
+
+#: cp/parser.cc:3521
+#, gcc-internal-format
+msgid "invalid template-id"
+msgstr ""
+
+#: cp/parser.cc:3555
+#, gcc-internal-format
+msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
+msgstr ""
+
+#: cp/parser.cc:3559
+#, gcc-internal-format
+msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.cc:3564
+#, gcc-internal-format
+msgid "%<typeid%> operator cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.cc:3568
+#, gcc-internal-format
+msgid "non-constant compound literals cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.cc:3572
+#, gcc-internal-format
+msgid "a function call cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.cc:3576
+#, gcc-internal-format
+msgid "an increment cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.cc:3580
+#, gcc-internal-format
+msgid "an decrement cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.cc:3584
+#, gcc-internal-format
+msgid "an array reference cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.cc:3588
+#, gcc-internal-format
+msgid "the address of a label cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.cc:3592
+#, gcc-internal-format
+msgid "calls to overloaded operators cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.cc:3596
+#, gcc-internal-format
+msgid "an assignment cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.cc:3599
+#, gcc-internal-format
+msgid "a comma operator cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.cc:3603
+#, gcc-internal-format
+msgid "a call to a constructor cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.cc:3607
+#, gcc-internal-format
+msgid "a transaction expression cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.cc:3653
+#, gcc-internal-format
+msgid "%qs cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/parser.cc:3690
+#, gcc-internal-format
+msgid "class template argument deduction is only available with %<-std=c++17%> or %<-std=gnu++17%>"
+msgstr ""
+
+#: cp/parser.cc:3695
+#, gcc-internal-format
+msgid "invalid use of destructor %qD as a type"
+msgstr ""
+
+#. Something like 'unsigned A a;'
+#: cp/parser.cc:3698
+#, gcc-internal-format
+msgid "invalid combination of multiple type-specifiers"
+msgstr ""
+
+#: cp/parser.cc:3711
+#, gcc-internal-format
+msgid "%qE does not name a type; did you mean %qs?"
+msgstr ""
+
+#: cp/parser.cc:3715
+#, gcc-internal-format
+msgid "%qE does not name a type"
+msgstr ""
+
+#: cp/parser.cc:3724
+#, gcc-internal-format
+msgid "C++11 %<constexpr%> only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/parser.cc:3727
+#, gcc-internal-format
+msgid "C++11 %<noexcept%> only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/parser.cc:3733
+#, gcc-internal-format
+msgid "%qE is not recognized as a module control-line"
+msgstr ""
+
+#: cp/parser.cc:3736
+#, gcc-internal-format
+msgid "C++20 %qE only available with %<-fmodules-ts%>"
+msgstr ""
+
+#: cp/parser.cc:3739
+#, gcc-internal-format
+msgid "C++20 %qE only available with %<-fmodules-ts%>, which is not yet enabled with %<-std=c++20%>"
+msgstr ""
+
+#: cp/parser.cc:3745
+#, gcc-internal-format
+msgid "C++11 %<thread_local%> only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/parser.cc:3748
+#, gcc-internal-format
+msgid "C++20 %<constinit%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/parser.cc:3751
+#, gcc-internal-format
+msgid "%<concept%> only available with %<-std=c++20%> or %<-fconcepts%>"
+msgstr ""
+
+#: cp/parser.cc:3754 cp/parser.cc:31353
+#, gcc-internal-format
+msgid "%<requires%> only available with %<-std=c++20%> or %<-fconcepts%>"
+msgstr ""
+
+#: cp/parser.cc:3776
+#, gcc-internal-format
+msgid "(perhaps %<typename %T::%E%> was intended)"
+msgstr ""
+
+#: cp/parser.cc:3804 cp/parser.cc:3816
+#, gcc-internal-format
+msgid "%qE in namespace %qE does not name a template type; did you mean %qs?"
+msgstr ""
+
+#: cp/parser.cc:3809 cp/parser.cc:3821
+#, gcc-internal-format
+msgid "%qE in namespace %qE does not name a template type"
+msgstr ""
+
+#: cp/parser.cc:3829
+#, gcc-internal-format
+msgid "%qE in namespace %qE does not name a type; did you mean %qs?"
+msgstr ""
+
+#: cp/parser.cc:3834
+#, gcc-internal-format
+msgid "%qE in namespace %qE does not name a type"
+msgstr ""
+
+#: cp/parser.cc:3845
+#, gcc-internal-format
+msgid "%<%T::%E%> names the constructor, not the type"
+msgstr ""
+
+#: cp/parser.cc:3848
+#, gcc-internal-format
+msgid "and %qT has no template constructors"
+msgstr ""
+
+#: cp/parser.cc:3858
+#, gcc-internal-format
+msgid "need %<typename%> before %<%T::%D::%E%> because %<%T::%D%> is a dependent scope"
+msgstr ""
+
+#: cp/parser.cc:3866
+#, gcc-internal-format
+msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
+msgstr ""
+
+#: cp/parser.cc:3878 cp/parser.cc:3882
+#, gcc-internal-format
+msgid "%qE in %q#T does not name a template type"
+msgstr ""
+
+#: cp/parser.cc:3886
+#, gcc-internal-format
+msgid "%qE in %q#T does not name a type"
+msgstr ""
+
+#: cp/parser.cc:4573
+#, gcc-internal-format
+msgid "expected string-literal"
+msgstr ""
+
+#: cp/parser.cc:4645
+#, gcc-internal-format
+msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
+msgstr ""
+
+#: cp/parser.cc:4664
+#, gcc-internal-format
+msgid "concatenation of string literals with conflicting encoding prefixes"
+msgstr ""
+
+#: cp/parser.cc:4885
+#, gcc-internal-format
+msgid "unable to find character literal operator %qD with %qT argument"
+msgstr ""
+
+#: cp/parser.cc:4991
+#, gcc-internal-format
+msgid "integer literal exceeds range of %qT type"
+msgstr ""
+
+#: cp/parser.cc:4998
+#, gcc-internal-format
+msgid "floating literal exceeds range of %qT type"
+msgstr ""
+
+#: cp/parser.cc:5002
+#, gcc-internal-format
+msgid "floating literal truncated to zero"
+msgstr ""
+
+#: cp/parser.cc:5031
+#, gcc-internal-format
+msgid "failed to translate literal to execution character set %qT"
+msgstr ""
+
+#: cp/parser.cc:5065
+#, gcc-internal-format
+msgid "unable to find numeric literal operator %qD"
+msgstr ""
+
+#: cp/parser.cc:5071
+#, gcc-internal-format
+msgid "add %<using namespace std::complex_literals%> (from %<<complex>%>) to enable the C++14 user-defined literal suffixes"
+msgstr ""
+
+#: cp/parser.cc:5075
+#, gcc-internal-format
+msgid "or use %<j%> instead of %<i%> for the GNU built-in suffix"
+msgstr ""
+
+#: cp/parser.cc:5079
+#, gcc-internal-format
+msgid "use %<-fext-numeric-literals%> to enable more built-in suffixes"
+msgstr ""
+
+#: cp/parser.cc:5163
+#, gcc-internal-format
+msgid "unable to find string literal operator %qD with %qT, %qT arguments"
+msgstr ""
+
+#: cp/parser.cc:5257
+#, gcc-internal-format
+msgid "global module fragment contents must be from preprocessor inclusion"
+msgstr ""
+
+#: cp/parser.cc:5272 cp/parser.cc:15792
+#, gcc-internal-format
+msgid "expected declaration"
+msgstr ""
+
+#: cp/parser.cc:5637 cp/parser.cc:5653
+#, gcc-internal-format
+msgid "expected binary operator"
+msgstr ""
+
+#: cp/parser.cc:5659
+#, gcc-internal-format
+msgid "expected ..."
+msgstr ""
+
+#: cp/parser.cc:5671
+#, gcc-internal-format
+msgid "binary expression in operand of fold-expression"
+msgstr ""
+
+#: cp/parser.cc:5676
+#, gcc-internal-format
+msgid "conditional expression in operand of fold-expression"
+msgstr ""
+
+#: cp/parser.cc:5687
+#, gcc-internal-format
+msgid "mismatched operator in fold-expression"
+msgstr ""
+
+#: cp/parser.cc:5792
+#, gcc-internal-format
+msgid "fixed-point types not supported in C++"
+msgstr ""
+
+#: cp/parser.cc:5882
+#, gcc-internal-format
+msgid "ISO C++ forbids braced-groups within expressions"
+msgstr ""
+
+#: cp/parser.cc:5894
+#, gcc-internal-format
+msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
+msgstr ""
+
+#: cp/parser.cc:5934
+#, gcc-internal-format
+msgid "fold-expressions only available with %<-std=c++17%> or %<-std=gnu++17%>"
+msgstr ""
+
+#: cp/parser.cc:5995 cp/parser.cc:6150 cp/parser.cc:6334 cp/semantics.cc:4403
+#, gcc-internal-format
+msgid "expected primary-expression"
+msgstr ""
+
+#: cp/parser.cc:6025
+#, gcc-internal-format
+msgid "%<this%> may not be used in this context"
+msgstr ""
+
+#: cp/parser.cc:6144
+#, gcc-internal-format
+msgid "a template declaration cannot appear at block scope"
+msgstr ""
+
+#: cp/parser.cc:6294
+#, gcc-internal-format
+msgid "parameter %qD may not appear in this context"
+msgstr ""
+
+#: cp/parser.cc:6295
+#, gcc-internal-format
+msgid "local variable %qD may not appear in this context"
+msgstr ""
+
+#: cp/parser.cc:6362
+#, gcc-internal-format
+msgid "expected %qs keyword before dependent template name"
+msgstr ""
+
+#: cp/parser.cc:6505
+#, gcc-internal-format
+msgid "expected id-expression"
+msgstr ""
+
+#: cp/parser.cc:6668
+#, gcc-internal-format
+msgid "scope %qT before %<~%> is not a class-name"
+msgstr ""
+
+#: cp/parser.cc:6678
+#, gcc-internal-format
+msgid "%<template%> keyword not permitted in destructor name"
+msgstr ""
+
+#: cp/parser.cc:6715 cp/parser.cc:8911
+#, gcc-internal-format
+msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
+msgstr ""
+
+#: cp/parser.cc:6729 cp/parser.cc:6733
+#, gcc-internal-format
+msgid "template-id not allowed for destructor in C++20"
+msgstr ""
+
+#: cp/parser.cc:6735 cp/parser.cc:32586
+#, gcc-internal-format
+msgid "remove the %qs"
+msgstr ""
+
+#: cp/parser.cc:6843
+#, gcc-internal-format
+msgid "declaration of %<~%T%> as member of %qT"
+msgstr ""
+
+#: cp/parser.cc:6858
+#, gcc-internal-format
+msgid "typedef-name %qD used as destructor declarator"
+msgstr ""
+
+#: cp/parser.cc:6894 cp/parser.cc:24195
+#, gcc-internal-format
+msgid "expected unqualified-id"
+msgstr ""
+
+#: cp/parser.cc:6921 cp/typeck.cc:3161 cp/typeck.cc:3164 cp/typeck.cc:3181
+#, gcc-internal-format
+msgid "%qD is not a template"
+msgstr ""
+
+#: cp/parser.cc:7035
+#, gcc-internal-format
+msgid "found %<:%> in nested-name-specifier, expected %<::%>"
+msgstr ""
+
+#: cp/parser.cc:7116
+#, gcc-internal-format
+msgid "%<decltype%> evaluates to %qT, which is not a class or enumeration type"
+msgstr ""
+
+#: cp/parser.cc:7143 cp/parser.cc:7154
+#, gcc-internal-format
+msgid "concept-id %qD in nested-name-specifier"
+msgstr ""
+
+#: cp/parser.cc:7146
+#, gcc-internal-format
+msgid "function template-id %qD in nested-name-specifier"
+msgstr ""
+
+#: cp/parser.cc:7160
+#, gcc-internal-format
+msgid "variable template-id %qD in nested-name-specifier"
+msgstr ""
+
+#: cp/parser.cc:7334
+#, gcc-internal-format
+msgid "expected nested-name-specifier"
+msgstr ""
+
+#: cp/parser.cc:7541 cp/parser.cc:10156
+#, gcc-internal-format
+msgid "types may not be defined in casts"
+msgstr ""
+
+#: cp/parser.cc:7630
+#, gcc-internal-format
+msgid "types may not be defined in a %<typeid%> expression"
+msgstr ""
+
+#: cp/parser.cc:7722
+#, gcc-internal-format
+msgid "wrong number of arguments to %<__builtin_addressof%>"
+msgstr ""
+
+#: cp/parser.cc:7734 cp/pt.cc:21039
+#, gcc-internal-format
+msgid "wrong number of arguments to %<__builtin_launder%>"
+msgstr ""
+
+#: cp/parser.cc:7747
+#, gcc-internal-format
+msgid "wrong number of arguments to %<__builtin_assoc_barrier%>"
+msgstr ""
+
+#: cp/parser.cc:7773
+#, gcc-internal-format
+msgid "wrong number of arguments to %<__builtin_shufflevector%>"
+msgstr ""
+
+#: cp/parser.cc:7907
+#, gcc-internal-format
+msgid "ISO C++ forbids compound-literals"
+msgstr ""
+
+#: cp/parser.cc:7966
+#, gcc-internal-format
+msgid "two consecutive %<[%> shall only introduce an attribute"
+msgstr ""
+
+#: cp/parser.cc:8017
+#, gcc-internal-format
+msgid "types may not be defined in %<__builtin_classify_type%> calls"
+msgstr ""
+
+#: cp/parser.cc:8400 cp/parser.cc:8429
+#, gcc-internal-format
+msgid "cannot use multidimensional subscript in OpenMP array section"
+msgstr ""
+
+#: cp/parser.cc:8687 cp/typeck.cc:3049
+#, gcc-internal-format
+msgid "invalid use of %qD"
+msgstr ""
+
+#: cp/parser.cc:8696
+#, gcc-internal-format
+msgid "%<%D::%D%> is not a class member"
+msgstr ""
+
+#: cp/parser.cc:8963
+#, gcc-internal-format
+msgid "non-scalar type"
+msgstr ""
+
+#: cp/parser.cc:9073
+#, gcc-internal-format
+msgid "ISO C++ does not allow %<alignof%> with a non-type"
+msgstr ""
+
+#: cp/parser.cc:9168
+#, gcc-internal-format
+msgid "types may not be defined in %<noexcept%> expressions"
+msgstr ""
+
+#: cp/parser.cc:9444 cp/parser.cc:33999
+#, gcc-internal-format
+msgid "types may not be defined in %qs expressions"
+msgstr ""
+
+#: cp/parser.cc:9509
+#, gcc-internal-format
+msgid "%<__builtin_has_attribute%> with dependent argument not supported yet"
+msgstr ""
+
+#: cp/parser.cc:9595
+#, gcc-internal-format
+msgid "types may not be defined in a new-expression"
+msgstr ""
+
+#: cp/parser.cc:9611
+#, gcc-internal-format
+msgid "array bound forbidden after parenthesized type-id"
+msgstr ""
+
+#: cp/parser.cc:9613
+#, gcc-internal-format
+msgid "try removing the parentheses around the type-id"
+msgstr ""
+
+#: cp/parser.cc:9645
+#, gcc-internal-format
+msgid "initialization of new-expression for type %<auto%> requires exactly one element"
+msgstr ""
+
+#: cp/parser.cc:9690
+#, gcc-internal-format
+msgid "expected expression-list or type-id"
+msgstr ""
+
+#: cp/parser.cc:9719
+#, gcc-internal-format
+msgid "types may not be defined in a new-type-id"
+msgstr ""
+
+#: cp/parser.cc:9854
+#, gcc-internal-format
+msgid "expression in new-declarator must have integral or enumeration type"
+msgstr ""
+
+#: cp/parser.cc:10261
+#, gcc-internal-format
+msgid "use of old-style cast to %q#T"
+msgstr ""
+
+#: cp/parser.cc:10410
+#, gcc-internal-format
+msgid "%<>>%> operator is treated as two right angle brackets in C++11"
+msgstr ""
+
+#: cp/parser.cc:10413
+#, gcc-internal-format
+msgid "suggest parentheses around %<>>%> expression"
+msgstr ""
+
+#: cp/parser.cc:10639
+#, gcc-internal-format
+msgid "ISO C++ does not allow %<?:%> with omitted middle operand"
+msgstr ""
+
+#: cp/parser.cc:10947
+#, gcc-internal-format
+msgid "top-level comma expression in array subscript is deprecated"
+msgstr ""
+
+#: cp/parser.cc:11095
+#, gcc-internal-format
+msgid "types may not be defined within %<__builtin_offsetof%>"
+msgstr ""
+
+#: cp/parser.cc:11229
+#, gcc-internal-format
+msgid "trailing argument to %<__type_pack_element%> is not a type"
+msgstr ""
+
+#: cp/parser.cc:11329
+#, gcc-internal-format
+msgid "lambda-expression in template parameter type"
+msgstr ""
+
+#: cp/parser.cc:11339
+#, gcc-internal-format
+msgid "lambda-expression in unevaluated context only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/parser.cc:11349
+#, gcc-internal-format
+msgid "lambda-expression in template-argument only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/parser.cc:11509
+#, gcc-internal-format
+msgid "non-local lambda expression cannot have a capture-default"
+msgstr ""
+
+#: cp/parser.cc:11532
+#, gcc-internal-format
+msgid "expected end of capture-list"
+msgstr ""
+
+#: cp/parser.cc:11548
+#, gcc-internal-format
+msgid "explicit by-copy capture of %<this%> with by-copy capture default only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/parser.cc:11554 cp/parser.cc:11576 cp/parser.cc:11772
+#, gcc-internal-format
+msgid "already captured %qD in lambda expression"
+msgstr ""
+
+#: cp/parser.cc:11570
+#, gcc-internal-format
+msgid "%<*this%> capture only available with %<-std=c++17%> or %<-std=gnu++17%>"
+msgstr ""
+
+#: cp/parser.cc:11590
+#, gcc-internal-format
+msgid "%<this%> cannot be captured by reference"
+msgstr ""
+
+#: cp/parser.cc:11610
+#, gcc-internal-format
+msgid "pack init-capture only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/parser.cc:11621
+#, gcc-internal-format
+msgid "%<&%> should come before %<...%>"
+msgstr ""
+
+#: cp/parser.cc:11651
+#, gcc-internal-format
+msgid "lambda capture initializers only available with %<-std=c++14%> or %<-std=gnu++14%>"
+msgstr ""
+
+#: cp/parser.cc:11660
+#, gcc-internal-format
+msgid "empty initializer for lambda init-capture"
+msgstr ""
+
+#: cp/parser.cc:11684
+#, gcc-internal-format
+msgid "capture of non-variable %qE"
+msgstr ""
+
+#: cp/parser.cc:11688 cp/parser.cc:11698 cp/semantics.cc:4245
+#: cp/semantics.cc:4260
+#, gcc-internal-format
+msgid "%q#D declared here"
+msgstr ""
+
+#: cp/parser.cc:11694
+#, gcc-internal-format
+msgid "capture of variable %qD with non-automatic storage duration"
+msgstr ""
+
+#: cp/parser.cc:11732
+#, gcc-internal-format
+msgid "too many %<...%> in lambda capture"
+msgstr ""
+
+#: cp/parser.cc:11743
+#, gcc-internal-format
+msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
+msgstr ""
+
+#: cp/parser.cc:11748
+#, gcc-internal-format
+msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
+msgstr ""
+
+#: cp/parser.cc:11830
+#, gcc-internal-format
+msgid "lambda templates are only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/parser.cc:11879
+#, gcc-internal-format
+msgid "default argument specified for lambda parameter"
+msgstr ""
+
+#: cp/parser.cc:11902
+#, gcc-internal-format
+msgid "parameter declaration before lambda declaration specifiers only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
+msgstr ""
+
+#: cp/parser.cc:11932 cp/pt.cc:14783
+#, gcc-internal-format
+msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
+msgstr ""
+
+#: cp/parser.cc:11945
+#, gcc-internal-format
+msgid "%<mutable%> lambda specifier with explicit object parameter"
+msgstr ""
+
+#: cp/parser.cc:11954
+#, gcc-internal-format
+msgid "the passed in closure object will not be mutated because it is taken by value"
+msgstr ""
+
+#: cp/parser.cc:11958
+#, gcc-internal-format
+msgid "declare the explicit object parameter as non-const reference instead"
+msgstr ""
+
+#: cp/parser.cc:11962
+#, gcc-internal-format
+msgid "explicit object parameter is already a mutable reference"
+msgstr ""
+
+#: cp/parser.cc:11969
+#, gcc-internal-format
+msgid "%<static%> lambda specifier with explicit object parameter"
+msgstr ""
+
+#: cp/parser.cc:11987
+#, gcc-internal-format
+msgid "%<static%> lambda specifier with lambda capture"
+msgstr ""
+
+#: cp/parser.cc:11999
+#, gcc-internal-format
+msgid "parameter declaration before lambda transaction qualifier only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
+msgstr ""
+
+#: cp/parser.cc:12012
+#, gcc-internal-format
+msgid "parameter declaration before lambda exception specification only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
+msgstr ""
+
+#: cp/parser.cc:12030
+#, gcc-internal-format
+msgid "parameter declaration before lambda trailing return type only optional with %<-std=c++2b%> or %<-std=gnu++2b%>"
+msgstr ""
+
+#: cp/parser.cc:12072
+#, gcc-internal-format
+msgid "%<constexpr%> lambda only available with %<-std=c++17%> or %<-std=gnu++17%>"
+msgstr ""
+
+#: cp/parser.cc:12636
+#, gcc-internal-format
+msgid "preconditions cannot be statements"
+msgstr ""
+
+#: cp/parser.cc:12639
+#, gcc-internal-format
+msgid "postconditions cannot be statements"
+msgstr ""
+
+#: cp/parser.cc:12644
+#, gcc-internal-format
+msgid "assertions must be followed by %<;%>"
+msgstr ""
+
+#: cp/parser.cc:12809
+#, gcc-internal-format
+msgid "label at end of compound statement only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
+msgstr ""
+
+#: cp/parser.cc:12987 cp/parser.cc:13197
+#, gcc-internal-format
+msgid "attributes at the beginning of statement are ignored"
+msgstr ""
+
+#: cp/parser.cc:13031
+#, gcc-internal-format
+msgid "expected labeled-statement"
+msgstr ""
+
+#: cp/parser.cc:13080
+#, gcc-internal-format
+msgid "case label %qE not within a switch statement"
+msgstr ""
+
+#: cp/parser.cc:13204
+#, gcc-internal-format
+msgid "need %<typename%> before %qE because %qT is a dependent scope"
+msgstr ""
+
+#: cp/parser.cc:13213
+#, gcc-internal-format
+msgid "%<%T::%D%> names the constructor, not the type"
+msgstr ""
+
+#: cp/parser.cc:13265
+#, gcc-internal-format
+msgid "compound-statement in %<constexpr%> function"
+msgstr ""
+
+#: cp/parser.cc:13527
+#, gcc-internal-format
+msgid "%<if constexpr%> only available with %<-std=c++17%> or %<-std=gnu++17%>"
+msgstr ""
+
+#: cp/parser.cc:13549
+#, gcc-internal-format
+msgid "%<if consteval%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
+msgstr ""
+
+#: cp/parser.cc:13574 cp/parser.cc:13609
+#, gcc-internal-format
+msgid "%<if consteval%> requires compound statement"
+msgstr ""
+
+#: cp/parser.cc:13651
+#, gcc-internal-format
+msgid "init-statement in selection statements only available with %<-std=c++17%> or %<-std=gnu++17%>"
+msgstr ""
+
+#: cp/parser.cc:13819 cp/parser.cc:34511
+#, gcc-internal-format
+msgid "expected selection-statement"
+msgstr ""
+
+#: cp/parser.cc:13860
+#, gcc-internal-format
+msgid "condition declares an array"
+msgstr ""
+
+#: cp/parser.cc:13862
+#, gcc-internal-format
+msgid "condition declares a function"
+msgstr ""
+
+#: cp/parser.cc:13902
+#, gcc-internal-format
+msgid "types may not be defined in conditions"
+msgstr ""
+
+#. Anything else is an error.
+#: cp/parser.cc:13984 cp/parser.cc:23466 cp/parser.cc:26107
+#, gcc-internal-format
+msgid "expected initializer"
+msgstr ""
+
+#: cp/parser.cc:14034
+#, gcc-internal-format
+msgid "range-based %<for%> loops with initializer only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/parser.cc:14287
+#, gcc-internal-format
+msgid "loop variable %qD of type %qT binds to a temporary constructed from type %qT"
+msgstr ""
+
+#. rval
+#: cp/parser.cc:14294
+#, gcc-internal-format
+msgid "use non-reference type %qT to make the copy explicit or %qT to prevent copying"
+msgstr ""
+
+#: cp/parser.cc:14318
+#, gcc-internal-format
+msgid "loop variable %qD creates a copy from type %qT"
+msgstr ""
+
+#: cp/parser.cc:14323
+#, gcc-internal-format
+msgid "use reference type to prevent copying"
+msgstr ""
+
+#: cp/parser.cc:14464
+#, gcc-internal-format
+msgid "range-based %<for%> expression of type %qT has incomplete type"
+msgstr ""
+
+#: cp/parser.cc:14548
+#, gcc-internal-format
+msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
+msgstr ""
+
+#: cp/parser.cc:14700 cp/parser.cc:34514
+#, gcc-internal-format
+msgid "expected iteration-statement"
+msgstr ""
+
+#: cp/parser.cc:14745
+#, gcc-internal-format
+msgid "alias-declaration in init-statement only available with %<-std=c++23%> or %<-std=gnu++23%>"
+msgstr ""
+
+#: cp/parser.cc:14762
+#, gcc-internal-format
+msgid "range-based %<for%> loops only available with %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/parser.cc:14893
+#, gcc-internal-format
+msgid "%<goto%> in %<constexpr%> function only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
+msgstr ""
+
+#. Issue a warning about this use of a GNU extension.
+#: cp/parser.cc:14902
+#, gcc-internal-format
+msgid "ISO C++ forbids computed gotos"
+msgstr ""
+
+#: cp/parser.cc:14915 cp/parser.cc:34517
+#, gcc-internal-format
+msgid "expected jump-statement"
+msgstr ""
+
+#: cp/parser.cc:15090
+#, gcc-internal-format
+msgid "expected module-partition"
+msgstr ""
+
+#: cp/parser.cc:15092
+#, gcc-internal-format
+msgid "expected module-name"
+msgstr ""
+
+#: cp/parser.cc:15133
+#, gcc-internal-format
+msgid "module-declaration not permitted in header-unit"
+msgstr ""
+
+#: cp/parser.cc:15159
+#, gcc-internal-format
+msgid "private module fragment"
+msgstr ""
+
+#: cp/parser.cc:15163
+#, gcc-internal-format
+msgid "private module fragment only permitted in purview of module interface or partition"
+msgstr ""
+
+#. Neither the first declaration, nor in a GMF.
+#: cp/parser.cc:15169
+#, gcc-internal-format
+msgid "module-declaration only permitted as first declaration, or ending a global module fragment"
+msgstr ""
+
+#: cp/parser.cc:15209
+#, gcc-internal-format
+msgid "post-module-declaration imports must be contiguous"
+msgstr ""
+
+#: cp/parser.cc:15212
+#, gcc-internal-format
+msgid "perhaps insert a line break, or other disambiguation, to prevent this being considered a module control-line"
+msgstr ""
+
+#: cp/parser.cc:15220
+#, gcc-internal-format
+msgid "import-declaration must be at global scope"
+msgstr ""
+
+#: cp/parser.cc:15241
+#, gcc-internal-format
+msgid "import specifying a module-partition must appear after a named module-declaration"
+msgstr ""
+
+#: cp/parser.cc:15253
+#, gcc-internal-format
+msgid "import cannot appear directly in a linkage-specification"
+msgstr ""
+
+#: cp/parser.cc:15263
+#, gcc-internal-format
+msgid "post-module-declaration imports must not be include-translated"
+msgstr ""
+
+#: cp/parser.cc:15266
+#, gcc-internal-format
+msgid "post-module-declaration imports must not be from header inclusion"
+msgstr ""
+
+#: cp/parser.cc:15287
+#, gcc-internal-format
+msgid "%qE may only occur after a module interface declaration"
+msgstr ""
+
+#: cp/parser.cc:15295
+#, gcc-internal-format
+msgid "%qE may only occur once in an export declaration"
+msgstr ""
+
+#: cp/parser.cc:15316
+#, gcc-internal-format
+msgid "%<export%> not part of following module-directive"
+msgstr ""
+
+#: cp/parser.cc:15403 cp/parser.cc:28020
+#, gcc-internal-format
+msgid "extra %<;%>"
+msgstr ""
+
+#: cp/parser.cc:15461
+#, gcc-internal-format
+msgid "attributes are not permitted in this position"
+msgstr ""
+
+#: cp/parser.cc:15465
+#, gcc-internal-format
+msgid "attributes may be inserted here"
+msgstr ""
+
+#: cp/parser.cc:15683
+#, gcc-internal-format
+msgid "%<__label__%> not at the beginning of a block"
+msgstr ""
+
+#: cp/parser.cc:15929
+#, gcc-internal-format
+msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
+msgstr ""
+
+#: cp/parser.cc:15948
+#, gcc-internal-format
+msgid "inconsistent deduction for %qT: %qT and then %qT"
+msgstr ""
+
+#: cp/parser.cc:15969
+#, gcc-internal-format
+msgid "mixing declarations and function-definitions is forbidden"
+msgstr ""
+
+#: cp/parser.cc:15994
+#, gcc-internal-format
+msgid "types may not be defined in a for-range-declaration"
+msgstr ""
+
+#: cp/parser.cc:16051
+#, gcc-internal-format
+msgid "initializer in range-based %<for%> loop"
+msgstr ""
+
+#: cp/parser.cc:16054
+#, gcc-internal-format
+msgid "multiple declarations in range-based %<for%> loop"
+msgstr ""
+
+#: cp/parser.cc:16107
+#, gcc-internal-format
+msgid "structured bindings only available with %<-std=c++17%> or %<-std=gnu++17%>"
+msgstr ""
+
+#: cp/parser.cc:16161
+#, gcc-internal-format
+msgid "empty structured binding declaration"
+msgstr ""
+
+#: cp/parser.cc:16179
+#, gcc-internal-format
+msgid "invalid initializer for structured binding declaration"
+msgstr ""
+
+#: cp/parser.cc:16371
+#, gcc-internal-format
+msgid "%<this%> must be the first specifier in a parameter declaration"
+msgstr ""
+
+#: cp/parser.cc:16394
+#, gcc-internal-format
+msgid "%<friend%> used outside of class"
+msgstr ""
+
+#: cp/parser.cc:16433
+#, gcc-internal-format
+msgid "the %<bool%> keyword is not allowed in a C++20 concept definition"
+msgstr ""
+
+#: cp/parser.cc:16436
+#, gcc-internal-format
+msgid "C++20 concept definition syntax is %<concept <name> = <expr>%>"
+msgstr ""
+
+#: cp/parser.cc:16487
+#, gcc-internal-format
+msgid "%<typedef%> specifier conflicts with %qs"
+msgstr ""
+
+#: cp/parser.cc:16513
+#, gcc-internal-format
+msgid "%<auto%> changes meaning in C++11; please remove it"
+msgstr ""
+
+#: cp/parser.cc:16549
+#, gcc-internal-format
+msgid "%qD invalid in condition"
+msgstr ""
+
+#: cp/parser.cc:16558
+#, gcc-internal-format
+msgid "%qD invalid in lambda"
+msgstr ""
+
+#: cp/parser.cc:16562
+#, gcc-internal-format
+msgid "%qD only valid in lambda with %<-std=c++23%> or %<-std=gnu++23%>"
+msgstr ""
+
+#: cp/parser.cc:16644
+#, gcc-internal-format
+msgid "type-specifier invalid in lambda"
+msgstr ""
+
+#: cp/parser.cc:16656
+#, gcc-internal-format
+msgid "standard attributes in middle of decl-specifiers"
+msgstr ""
+
+#: cp/parser.cc:16658
+#, gcc-internal-format
+msgid "standard attributes must precede the decl-specifiers to apply to the declaration, or follow them to apply to the type"
+msgstr ""
+
+#: cp/parser.cc:16673
+#, gcc-internal-format
+msgid "class definition may not be declared a friend"
+msgstr ""
+
+#: cp/parser.cc:16746 cp/parser.cc:28562
+#, gcc-internal-format
+msgid "templates may not be %<virtual%>"
+msgstr ""
+
+#: cp/parser.cc:16765
+#, gcc-internal-format
+msgid "types may not be defined in explicit-specifier"
+msgstr ""
+
+#: cp/parser.cc:16769
+#, gcc-internal-format
+msgid "%<explicit(bool)%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/parser.cc:16837
+#, gcc-internal-format
+msgid "invalid linkage-specification"
+msgstr ""
+
+#: cp/parser.cc:16944
+#, gcc-internal-format
+msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
+msgstr ""
+
+#: cp/parser.cc:16974
+#, gcc-internal-format
+msgid "%<static_assert%> with non-string message only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
+msgstr ""
+
+#: cp/parser.cc:17172
+#, gcc-internal-format
+msgid "%<decltype(auto)%> type specifier only available with %<-std=c++14%> or %<-std=gnu++14%>"
+msgstr ""
+
+#: cp/parser.cc:17185
+#, gcc-internal-format
+msgid "types may not be defined in %<decltype%> expressions"
+msgstr ""
+
+#: cp/parser.cc:17358
+#, gcc-internal-format
+msgid "types may not be defined in a conversion-type-id"
+msgstr ""
+
+#: cp/parser.cc:17387
+#, gcc-internal-format
+msgid "invalid use of %<auto%> in conversion operator"
+msgstr ""
+
+#: cp/parser.cc:17391
+#, gcc-internal-format
+msgid "use of %<auto%> in member template conversion operator can never be deduced"
+msgstr ""
+
+#: cp/parser.cc:17475
+#, gcc-internal-format
+msgid "only constructors take member initializers"
+msgstr ""
+
+#: cp/parser.cc:17502
+#, gcc-internal-format
+msgid "cannot expand initializer for member %qD"
+msgstr ""
+
+#: cp/parser.cc:17514 cp/pt.cc:27696
+#, gcc-internal-format
+msgid "mem-initializer for %qD follows constructor delegation"
+msgstr ""
+
+#: cp/parser.cc:17526 cp/pt.cc:27708
+#, gcc-internal-format
+msgid "constructor delegation follows mem-initializer for %qD"
+msgstr ""
+
+#: cp/parser.cc:17578
+#, gcc-internal-format
+msgid "anachronistic old-style base class initializer"
+msgstr ""
+
+#: cp/parser.cc:17662
+#, gcc-internal-format
+msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
+msgstr ""
+
+#: cp/parser.cc:18062
+#, gcc-internal-format
+msgid "unexpected keyword; remove space between quotes and suffix identifier"
+msgstr ""
+
+#: cp/parser.cc:18068
+#, gcc-internal-format
+msgid "expected suffix identifier"
+msgstr ""
+
+#: cp/parser.cc:18077
+#, gcc-internal-format
+msgid "expected empty string after %<operator%> keyword"
+msgstr ""
+
+#: cp/parser.cc:18083
+#, gcc-internal-format
+msgid "invalid encoding prefix in literal operator"
+msgstr ""
+
+#: cp/parser.cc:18117
+#, gcc-internal-format
+msgid "expected operator"
+msgstr ""
+
+#: cp/parser.cc:18164
+#, gcc-internal-format
+msgid "keyword %<export%> not implemented, and will be ignored"
+msgstr ""
+
+#: cp/parser.cc:18166
+#, gcc-internal-format
+msgid "keyword %<export%> is deprecated, and is ignored"
+msgstr ""
+
+#: cp/parser.cc:18168
+#, gcc-internal-format
+msgid "keyword %<export%> is enabled with %<-fmodules-ts%>"
+msgstr ""
+
+#: cp/parser.cc:18347
+#, gcc-internal-format
+msgid "invalid constrained type parameter"
+msgstr ""
+
+#: cp/parser.cc:18355
+#, gcc-internal-format
+msgid "cv-qualified type parameter"
+msgstr ""
+
+#: cp/parser.cc:18502
+#, gcc-internal-format
+msgid "invalid use of %<auto%> in default template argument"
+msgstr ""
+
+#: cp/parser.cc:18738 cp/parser.cc:18824 cp/parser.cc:25855
+#, gcc-internal-format
+msgid "template parameter pack %qD cannot have a default argument"
+msgstr ""
+
+#: cp/parser.cc:18742 cp/parser.cc:18828
+#, gcc-internal-format
+msgid "template parameter packs cannot have default arguments"
+msgstr ""
+
+#: cp/parser.cc:18895
+#, gcc-internal-format
+msgid "expected template-id"
+msgstr ""
+
+#: cp/parser.cc:18957
+#, gcc-internal-format
+msgid "%<<::%> cannot begin a template-argument list"
+msgstr ""
+
+#: cp/parser.cc:18961
+#, gcc-internal-format
+msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
+msgstr ""
+
+#: cp/parser.cc:18965
+#, gcc-internal-format
+msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
+msgstr ""
+
+#: cp/parser.cc:18995
+#, gcc-internal-format
+msgid "invalid template-argument-list"
+msgstr ""
+
+#: cp/parser.cc:18996
+#, gcc-internal-format
+msgid "function name as the left hand operand of %<<%> is ill-formed in C++20; wrap the function name in %<()%>"
+msgstr ""
+
+#: cp/parser.cc:19003
+#, gcc-internal-format
+msgid "expected %<(%> after template-argument-list"
+msgstr ""
+
+#: cp/parser.cc:19117
+#, gcc-internal-format
+msgid "parse error in template argument list"
+msgstr ""
+
+#. The name does not name a template.
+#: cp/parser.cc:19202 cp/parser.cc:19393 cp/parser.cc:19591
+#, gcc-internal-format
+msgid "expected template-name"
+msgstr ""
+
+#. Explain what went wrong.
+#: cp/parser.cc:19248
+#, gcc-internal-format
+msgid "non-template %qD used as template"
+msgstr ""
+
+#: cp/parser.cc:19250
+#, gcc-internal-format
+msgid "use %<%T::template %D%> to indicate that it is a template"
+msgstr ""
+
+#: cp/parser.cc:19455
+#, gcc-internal-format
+msgid "expected parameter pack before %<...%>"
+msgstr ""
+
+#: cp/parser.cc:19556 cp/parser.cc:19574 cp/parser.cc:19744
+#, gcc-internal-format
+msgid "expected template-argument"
+msgstr ""
+
+#: cp/parser.cc:19714
+#, gcc-internal-format
+msgid "invalid non-type template argument"
+msgstr ""
+
+#: cp/parser.cc:19853
+#, gcc-internal-format
+msgid "explicit instantiation shall not use %<inline%> specifier"
+msgstr ""
+
+#: cp/parser.cc:19857
+#, gcc-internal-format
+msgid "explicit instantiation shall not use %<constexpr%> specifier"
+msgstr ""
+
+#: cp/parser.cc:19861
+#, gcc-internal-format
+msgid "explicit instantiation shall not use %<consteval%> specifier"
+msgstr ""
+
+#: cp/parser.cc:19921
+#, gcc-internal-format
+msgid "template specialization with C linkage"
+msgstr ""
+
+#: cp/parser.cc:20150
+#, gcc-internal-format
+msgid "expected type specifier"
+msgstr ""
+
+#: cp/parser.cc:20350
+#, gcc-internal-format
+msgid "use of %<auto%> in lambda parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
+msgstr ""
+
+#: cp/parser.cc:20356
+#, gcc-internal-format
+msgid "use of %<auto%> in template argument only available with %<-fconcepts-ts%>"
+msgstr ""
+
+#: cp/parser.cc:20360
+#, gcc-internal-format
+msgid "use of %<auto%> in parameter declaration only available with %<-std=c++20%> or %<-fconcepts%>"
+msgstr ""
+
+#: cp/parser.cc:20364
+#, gcc-internal-format
+msgid "use of %<auto%> in parameter declaration only available with %<-std=c++14%> or %<-std=gnu++14%>"
+msgstr ""
+
+#: cp/parser.cc:20518
+#, gcc-internal-format
+msgid "expected template-id for type"
+msgstr ""
+
+#: cp/parser.cc:20649
+#, gcc-internal-format
+msgid "expected type-name"
+msgstr ""
+
+#: cp/parser.cc:20761
+#, gcc-internal-format
+msgid "%qE does not constrain a type"
+msgstr ""
+
+#: cp/parser.cc:20762
+#, gcc-internal-format
+msgid "concept defined here"
+msgstr ""
+
+#: cp/parser.cc:20794
+#, gcc-internal-format
+msgid "expected %<auto%> or %<decltype(auto)%> after %qE"
+msgstr ""
+
+#: cp/parser.cc:20801
+#, gcc-internal-format
+msgid "unexpected placeholder in constrained result type"
+msgstr ""
+
+#: cp/parser.cc:21044
+#, gcc-internal-format
+msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
+msgstr ""
+
+#: cp/parser.cc:21120
+#, gcc-internal-format
+msgid "%<template%> must follow a nested-name-specifier"
+msgstr ""
+
+#: cp/parser.cc:21282
+#, gcc-internal-format
+msgid "declaration %qD does not declare anything"
+msgstr ""
+
+#: cp/parser.cc:21370
+#, gcc-internal-format
+msgid "attributes ignored on uninstantiated type"
+msgstr ""
+
+#: cp/parser.cc:21376
+#, gcc-internal-format
+msgid "attributes ignored on template instantiation"
+msgstr ""
+
+#: cp/parser.cc:21387
+#, gcc-internal-format
+msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
+msgstr ""
+
+#: cp/parser.cc:21528
+#, gcc-internal-format
+msgid "%qD is an enumeration template"
+msgstr ""
+
+#: cp/parser.cc:21539
+#, gcc-internal-format
+msgid "%qD does not name an enumeration in %qT"
+msgstr ""
+
+#: cp/parser.cc:21554
+#, gcc-internal-format
+msgid "unnamed scoped enum is not allowed"
+msgstr ""
+
+#: cp/parser.cc:21572
+#, gcc-internal-format
+msgid "types may not be defined in enum-base"
+msgstr ""
+
+#: cp/parser.cc:21618
+#, gcc-internal-format
+msgid "declaration of enumeration with fixed underlying type and no enumerator list is only permitted as a standalone declaration"
+msgstr ""
+
+#: cp/parser.cc:21622
+#, gcc-internal-format
+msgid "expected %<;%> or %<{%>"
+msgstr ""
+
+#: cp/parser.cc:21665
+#, gcc-internal-format
+msgid "cannot add an enumerator list to a template instantiation"
+msgstr ""
+
+#: cp/parser.cc:21679
+#, gcc-internal-format
+msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
+msgstr ""
+
+#: cp/parser.cc:21691 cp/parser.cc:27471
+#, gcc-internal-format
+msgid "declaration of %qD in namespace %qD which does not enclose %qD"
+msgstr ""
+
+#: cp/parser.cc:21696 cp/parser.cc:27476
+#, gcc-internal-format
+msgid "declaration of %qD in %qD which does not enclose %qD"
+msgstr ""
+
+#: cp/parser.cc:21708 cp/parser.cc:27489
+#, gcc-internal-format
+msgid "extra qualification not allowed"
+msgstr ""
+
+#: cp/parser.cc:21747
+#, gcc-internal-format
+msgid "ISO C++ forbids empty unnamed enum"
+msgstr ""
+
+#: cp/parser.cc:21771
+#, gcc-internal-format
+msgid "opaque-enum-specifier without name"
+msgstr ""
+
+#: cp/parser.cc:21774
+#, gcc-internal-format
+msgid "opaque-enum-specifier must use a simple identifier"
+msgstr ""
+
+#: cp/parser.cc:21895
+#, gcc-internal-format
+msgid "unexpanded parameter pack in enumerator in lambda"
+msgstr ""
+
+#: cp/parser.cc:21970
+#, gcc-internal-format
+msgid "%qD is not a namespace-name; did you mean %qs?"
+msgstr ""
+
+#: cp/parser.cc:21974
+#, gcc-internal-format
+msgid "%qD is not a namespace-name"
+msgstr ""
+
+#: cp/parser.cc:21978
+#, gcc-internal-format
+msgid "expected namespace-name"
+msgstr ""
+
+#: cp/parser.cc:22039
+#, gcc-internal-format
+msgid "nested inline namespace definitions only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/parser.cc:22051
+#, gcc-internal-format
+msgid "standard attributes on namespaces must precede the namespace name"
+msgstr ""
+
+#: cp/parser.cc:22070
+#, gcc-internal-format
+msgid "nested namespace definitions only available with %<-std=c++17%> or %<-std=gnu++17%>"
+msgstr ""
+
+#: cp/parser.cc:22080
+#, gcc-internal-format
+msgid "nested namespace name required"
+msgstr ""
+
+#: cp/parser.cc:22085
+#, gcc-internal-format
+msgid "namespace name required"
+msgstr ""
+
+#: cp/parser.cc:22089
+#, gcc-internal-format
+msgid "a nested namespace definition cannot have attributes"
+msgstr ""
+
+#: cp/parser.cc:22092
+#, gcc-internal-format
+msgid "a nested namespace definition cannot be inline"
+msgstr ""
+
+#: cp/parser.cc:22099
+#, gcc-internal-format
+msgid "namespace %qD entered"
+msgstr ""
+
+#: cp/parser.cc:22154
+#, gcc-internal-format
+msgid "%<namespace%> definition is not allowed here"
+msgstr ""
+
+#: cp/parser.cc:22336
+#, gcc-internal-format
+msgid "pack expansion in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
+msgstr ""
+
+#: cp/parser.cc:22380
+#, gcc-internal-format
+msgid "a template-id may not appear in a using-declaration"
+msgstr ""
+
+#: cp/parser.cc:22398
+#, gcc-internal-format
+msgid "comma-separated list in using-declaration only available with %<-std=c++17%> or %<-std=gnu++17%>"
+msgstr ""
+
+#: cp/parser.cc:22408
+#, gcc-internal-format
+msgid "access declarations are deprecated in favor of using-declarations; suggestion: add the %<using%> keyword"
+msgstr ""
+
+#: cp/parser.cc:22454
+#, gcc-internal-format
+msgid "%<using enum%> only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/parser.cc:22457
+#, gcc-internal-format
+msgid "%<using enum%> of dependent type %qT"
+msgstr ""
+
+#: cp/parser.cc:22459
+#, gcc-internal-format
+msgid "%<using enum%> of non-enumeration type %q#T"
+msgstr ""
+
+#: cp/parser.cc:22461
+#, gcc-internal-format
+msgid "%<using enum%> of incomplete type %qT"
+msgstr ""
+
+#: cp/parser.cc:22463
+#, gcc-internal-format
+msgid "%<using enum%> of %qT before its enum-specifier"
+msgstr ""
+
+#: cp/parser.cc:22473
+#, gcc-internal-format
+msgid "opaque-enum-declaration here"
+msgstr ""
+
+#: cp/parser.cc:22543
+#, gcc-internal-format
+msgid "types may not be defined in alias template declarations"
+msgstr ""
+
+#: cp/parser.cc:22722
+#, gcc-internal-format
+msgid "%<asm%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/parser.cc:22742 cp/parser.cc:22759 cp/parser.cc:22773
+#, gcc-internal-format
+msgid "duplicate %<asm%> qualifier %qT"
+msgstr ""
+
+#: cp/parser.cc:22749
+#, gcc-internal-format
+msgid "%<asm%> qualifier %qT ignored outside of function body"
+msgstr ""
+
+#: cp/parser.cc:22786
+#, gcc-internal-format
+msgid "%qT is not an %<asm%> qualifier"
+msgstr ""
+
+#: cp/parser.cc:22802
+#, gcc-internal-format
+msgid "%<asm%> qualifier outside of function body"
+msgstr ""
+
+#: cp/parser.cc:22948
+#, gcc-internal-format
+msgid "attributes ignored on %<asm%> declaration"
+msgstr ""
+
+#: cp/parser.cc:23035
+#, gcc-internal-format
+msgid "empty parentheses were disambiguated as a function declaration"
+msgstr ""
+
+#: cp/parser.cc:23046
+#, gcc-internal-format
+msgid "remove parentheses to default-initialize a variable"
+msgstr ""
+
+#: cp/parser.cc:23051
+#, gcc-internal-format
+msgid "or replace parentheses with braces to aggregate-initialize a variable"
+msgstr ""
+
+#: cp/parser.cc:23054
+#, gcc-internal-format
+msgid "or replace parentheses with braces to value-initialize a variable"
+msgstr ""
+
+#: cp/parser.cc:23071 cp/parser.cc:23096
+#, gcc-internal-format
+msgid "parentheses were disambiguated as a function declaration"
+msgstr ""
+
+#: cp/parser.cc:23083 cp/parser.cc:23104
+#, gcc-internal-format
+msgid "replace parentheses with braces to declare a variable"
+msgstr ""
+
+#: cp/parser.cc:23090
+#, gcc-internal-format
+msgid "add parentheses to declare a variable"
+msgstr ""
+
+#: cp/parser.cc:23337
+#, gcc-internal-format
+msgid "a function-definition is not allowed here"
+msgstr ""
+
+#: cp/parser.cc:23348
+#, gcc-internal-format
+msgid "an %<asm%> specification is not allowed on a function-definition"
+msgstr ""
+
+#: cp/parser.cc:23352
+#, gcc-internal-format
+msgid "attributes are not allowed on a function-definition"
+msgstr ""
+
+#: cp/parser.cc:23403
+#, gcc-internal-format
+msgid "expected constructor, destructor, or type conversion"
+msgstr ""
+
+#: cp/parser.cc:23547
+#, gcc-internal-format
+msgid "initializer provided for function"
+msgstr ""
+
+#: cp/parser.cc:23589
+#, gcc-internal-format
+msgid "attributes after parenthesized initializer ignored"
+msgstr ""
+
+#: cp/parser.cc:23603
+#, gcc-internal-format
+msgid "non-function %qD declared as implicit template"
+msgstr ""
+
+#: cp/parser.cc:24115
+#, gcc-internal-format
+msgid "array bound is not an integer constant"
+msgstr ""
+
+#: cp/parser.cc:24241
+#, gcc-internal-format
+msgid "cannot define member of dependent typedef %qT"
+msgstr ""
+
+#: cp/parser.cc:24245
+#, gcc-internal-format
+msgid "%<%T::%E%> is not a type"
+msgstr ""
+
+#. We do not attempt to print the declarator
+#. here because we do not have enough
+#. information about its original syntactic
+#. form.
+#: cp/parser.cc:24274
+#, gcc-internal-format
+msgid "invalid declarator"
+msgstr ""
+
+#: cp/parser.cc:24282
+#, gcc-internal-format
+msgid "invalid use of constructor as a template"
+msgstr ""
+
+#: cp/parser.cc:24284
+#, gcc-internal-format
+msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
+msgstr ""
+
+#. But declarations with qualified-ids can't appear in a
+#. function.
+#: cp/parser.cc:24399
+#, gcc-internal-format
+msgid "qualified-id in declaration"
+msgstr ""
+
+#: cp/parser.cc:24424
+#, gcc-internal-format
+msgid "expected declarator"
+msgstr ""
+
+#: cp/parser.cc:24545
+#, gcc-internal-format
+msgid "%qD is a namespace"
+msgstr ""
+
+#: cp/parser.cc:24547
+#, gcc-internal-format
+msgid "cannot form pointer to member of non-class %q#T"
+msgstr ""
+
+#: cp/parser.cc:24568
+#, gcc-internal-format
+msgid "expected ptr-operator"
+msgstr ""
+
+#: cp/parser.cc:24629
+#, gcc-internal-format
+msgid "duplicate cv-qualifier"
+msgstr ""
+
+#: cp/parser.cc:24683
+#, gcc-internal-format
+msgid "multiple ref-qualifiers"
+msgstr ""
+
+#: cp/parser.cc:24720
+#, gcc-internal-format
+msgid "%qE requires %<-fgnu-tm%>"
+msgstr ""
+
+#: cp/parser.cc:24778
+#, gcc-internal-format
+msgid "duplicate virt-specifier"
+msgstr ""
+
+#: cp/parser.cc:25043
+#, gcc-internal-format
+msgid "missing template arguments after %qE"
+msgstr ""
+
+#: cp/parser.cc:25049
+#, gcc-internal-format
+msgid "%qT not permitted in template argument"
+msgstr ""
+
+#: cp/parser.cc:25052 cp/typeck2.cc:336 cp/typeck2.cc:382 cp/typeck2.cc:2479
+#: rust/backend/rust-tree.cc:3909
+#, gcc-internal-format
+msgid "invalid use of %qT"
+msgstr ""
+
+#: cp/parser.cc:25078
+#, gcc-internal-format
+msgid "types may not be defined in template arguments"
+msgstr ""
+
+#: cp/parser.cc:25087
+#, gcc-internal-format
+msgid "invalid use of %<auto%> in template argument"
+msgstr ""
+
+#: cp/parser.cc:25193
+#, gcc-internal-format
+msgid "expected type-specifier"
+msgstr ""
+
+#: cp/parser.cc:25533
+#, gcc-internal-format
+msgid "expected %<,%> or %<...%>"
+msgstr ""
+
+#: cp/parser.cc:25611
+#, gcc-internal-format
+msgid "types may not be defined in parameter types"
+msgstr ""
+
+#: cp/parser.cc:25732
+#, gcc-internal-format
+msgid "%<this%> specifier in template parameter declaration"
+msgstr ""
+
+#: cp/parser.cc:25792
+#, gcc-internal-format
+msgid "an explicit object parameter cannot be a function parameter pack"
+msgstr ""
+
+#: cp/parser.cc:25839
+#, gcc-internal-format
+msgid "default arguments are only permitted for function parameters"
+msgstr ""
+
+#: cp/parser.cc:25857
+#, gcc-internal-format
+msgid "parameter pack %qD cannot have a default argument"
+msgstr ""
+
+#: cp/parser.cc:25863
+#, gcc-internal-format
+msgid "template parameter pack cannot have a default argument"
+msgstr ""
+
+#: cp/parser.cc:25865
+#, gcc-internal-format
+msgid "parameter pack cannot have a default argument"
+msgstr ""
+
+#: cp/parser.cc:25888
+#, gcc-internal-format
+msgid "an explicit object parameter may not have a default argument"
+msgstr ""
+
+#: cp/parser.cc:26012
+#, gcc-internal-format
+msgid "function-try-block body of %<constexpr%> constructor only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/parser.cc:26016
+#, gcc-internal-format
+msgid "function-try-block body of %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/parser.cc:26357
+#, gcc-internal-format
+msgid "C++ designated initializers only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/parser.cc:26379
+#, gcc-internal-format
+msgid "ISO C++ does not allow GNU designated initializers"
+msgstr ""
+
+#: cp/parser.cc:26417
+#, gcc-internal-format
+msgid "ISO C++ does not allow C99 designated initializers"
+msgstr ""
+
+#: cp/parser.cc:26431
+#, gcc-internal-format
+msgid "either all initializer clauses should be designated or none of them should be"
+msgstr ""
+
+#: cp/parser.cc:26464
+#, gcc-internal-format
+msgid "%<...%> not allowed in designated initializer list"
+msgstr ""
+
+#: cp/parser.cc:26515
+#, gcc-internal-format
+msgid "%<.%s%> designator used multiple times in the same initializer list"
+msgstr ""
+
+#: cp/parser.cc:26571 cp/parser.cc:26708
+#, gcc-internal-format
+msgid "expected class-name"
+msgstr ""
+
+#: cp/parser.cc:26955
+#, gcc-internal-format
+msgid "expected %<;%> after class definition"
+msgstr ""
+
+#: cp/parser.cc:26958
+#, gcc-internal-format
+msgid "expected %<;%> after struct definition"
+msgstr ""
+
+#: cp/parser.cc:26961
+#, gcc-internal-format
+msgid "expected %<;%> after union definition"
+msgstr ""
+
+#: cp/parser.cc:27413
+#, gcc-internal-format
+msgid "expected %<{%> or %<:%>"
+msgstr ""
+
+#: cp/parser.cc:27424
+#, gcc-internal-format
+msgid "cannot specify %<override%> for a class"
+msgstr ""
+
+#: cp/parser.cc:27432
+#, gcc-internal-format
+msgid "global qualification of class name is invalid"
+msgstr ""
+
+#: cp/parser.cc:27439
+#, gcc-internal-format
+msgid "qualified name does not name a class"
+msgstr ""
+
+#: cp/parser.cc:27451
+#, gcc-internal-format
+msgid "keyword %<template%> not allowed in class-head-name"
+msgstr ""
+
+#: cp/parser.cc:27457
+#, gcc-internal-format
+msgid "invalid class name in declaration of %qD"
+msgstr ""
+
+#: cp/parser.cc:27511
+#, gcc-internal-format
+msgid "an explicit specialization must be preceded by %<template <>%>"
+msgstr ""
+
+#: cp/parser.cc:27543
+#, gcc-internal-format
+msgid "function template %qD redeclared as a class template"
+msgstr ""
+
+#: cp/parser.cc:27576
+#, gcc-internal-format
+msgid "could not resolve typename type"
+msgstr ""
+
+#: cp/parser.cc:27640
+#, gcc-internal-format
+msgid "previous definition of %q#T"
+msgstr ""
+
+#. In a lambda this should work, but doesn't currently.
+#. We're in a lambda, but it isn't the innermost class.
+#. This should work, but currently doesn't.
+#: cp/parser.cc:27654 cp/pt.cc:4328
+#, gcc-internal-format
+msgid "unexpanded parameter pack in local class in lambda"
+msgstr ""
+
+#: cp/parser.cc:27760 cp/parser.cc:34520
+#, gcc-internal-format
+msgid "expected class-key"
+msgstr ""
+
+#: cp/parser.cc:27785
+#, gcc-internal-format
+msgid "ISO C++ forbids typename key in template template parameter; use %<-std=c++17%> or %<-std=gnu++17%>"
+msgstr ""
+
+#: cp/parser.cc:27789
+#, gcc-internal-format
+msgid "expected %<class%> or %<typename%>"
+msgstr ""
+
+#: cp/parser.cc:28039
+#, gcc-internal-format
+msgid "in C++03 a class-key must be used when declaring a friend"
+msgstr ""
+
+#: cp/parser.cc:28070
+#, gcc-internal-format
+msgid "friend declaration does not name a class or function"
+msgstr ""
+
+#: cp/parser.cc:28088
+#, gcc-internal-format
+msgid "a storage class on an anonymous aggregate in class scope is not allowed"
+msgstr ""
+
+#: cp/parser.cc:28190
+#, gcc-internal-format
+msgid "default member initializers for bit-fields only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/parser.cc:28197
+#, gcc-internal-format
+msgid "default member initializer for unnamed bit-field"
+msgstr ""
+
+#: cp/parser.cc:28210
+#, gcc-internal-format
+msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
+msgstr ""
+
+#: cp/parser.cc:28369
+#, gcc-internal-format
+msgid "bit-field %qD has non-integral type %qT"
+msgstr ""
+
+#: cp/parser.cc:28397
+#, gcc-internal-format
+msgid "pure-specifier on function-definition"
+msgstr ""
+
+#: cp/parser.cc:28418
+#, gcc-internal-format
+msgid "extra %<;%> after in-class function definition"
+msgstr ""
+
+#: cp/parser.cc:28467
+#, gcc-internal-format
+msgid "stray %<,%> at end of member declaration"
+msgstr ""
+
+#: cp/parser.cc:28481
+#, gcc-internal-format
+msgid "expected %<;%> at end of member declaration"
+msgstr ""
+
+#: cp/parser.cc:28556
+#, gcc-internal-format
+msgid "invalid pure specifier (only %<= 0%> is allowed)"
+msgstr ""
+
+#: cp/parser.cc:28591
+#, gcc-internal-format
+msgid "a brace-enclosed initializer is not allowed here"
+msgstr ""
+
+#: cp/parser.cc:28721
+#, gcc-internal-format
+msgid "%<virtual%> specified more than once in base-specifier"
+msgstr ""
+
+#: cp/parser.cc:28741
+#, gcc-internal-format
+msgid "more than one access specifier in base-specifier"
+msgstr ""
+
+#: cp/parser.cc:28765
+#, gcc-internal-format
+msgid "keyword %<typename%> not allowed outside of templates"
+msgstr ""
+
+#: cp/parser.cc:28768
+#, gcc-internal-format
+msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
+msgstr ""
+
+#: cp/parser.cc:28967 cp/parser.cc:29061
+#, gcc-internal-format
+msgid "types may not be defined in an exception-specification"
+msgstr ""
+
+#: cp/parser.cc:29069
+#, gcc-internal-format
+msgid "ISO C++17 does not allow dynamic exception specifications"
+msgstr ""
+
+#: cp/parser.cc:29075
+#, gcc-internal-format
+msgid "dynamic exception specifications are deprecated in C++11"
+msgstr ""
+
+#: cp/parser.cc:29119
+#, gcc-internal-format
+msgid "invalid use of %<auto%> in exception-specification"
+msgstr ""
+
+#: cp/parser.cc:29160
+#, gcc-internal-format
+msgid "%<try%> in %<constexpr%> function only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/parser.cc:29272
+#, gcc-internal-format
+msgid "types may not be defined in exception-declarations"
+msgstr ""
+
+#: cp/parser.cc:29838
+#, gcc-internal-format
+msgid "expected attribute argument as balanced token sequence"
+msgstr ""
+
+#: cp/parser.cc:29984
+#, gcc-internal-format
+msgid "attribute using prefix used together with scoped attribute token"
+msgstr ""
+
+#: cp/parser.cc:29998
+#, gcc-internal-format
+msgid "expected an identifier for the attribute name"
+msgstr ""
+
+#. e.g. [[attr()]].
+#: cp/parser.cc:30141
+#, gcc-internal-format
+msgid "parentheses must be omitted if %qE attribute argument list is empty"
+msgstr ""
+
+#: cp/parser.cc:30176
+#, gcc-internal-format
+msgid "attribute %qs specified multiple times"
+msgstr ""
+
+#: cp/parser.cc:30218
+#, gcc-internal-format
+msgid "expected attribute before %<...%>"
+msgstr ""
+
+#: cp/parser.cc:30221
+#, gcc-internal-format
+msgid "attribute with no arguments contains no parameter packs"
+msgstr ""
+
+#: cp/parser.cc:30267
+#, gcc-internal-format
+msgid "expected contract-role"
+msgstr ""
+
+#. We got some other token other than a ':'.
+#: cp/parser.cc:30348
+#, gcc-internal-format
+msgid "expected contract semantic or level"
+msgstr ""
+
+#: cp/parser.cc:30358
+#, gcc-internal-format
+msgid "expected contract level: %<default%>, %<audit%>, or %<axiom%>"
+msgstr ""
+
+#: cp/parser.cc:30368
+#, gcc-internal-format
+msgid "invalid use of contract role for explicit semantic"
+msgstr ""
+
+#: cp/parser.cc:30505
+#, gcc-internal-format
+msgid "contracts are only available with %<-fcontracts%>"
+msgstr ""
+
+#: cp/parser.cc:30664
+#, gcc-internal-format
+msgid "attribute using prefix only available with %<-std=c++17%> or %<-std=gnu++17%>"
+msgstr ""
+
+#: cp/parser.cc:31013 cp/parser.cc:31022
+#, gcc-internal-format
+msgid "expression must be enclosed in parentheses"
+msgstr ""
+
+#: cp/parser.cc:31370
+#, gcc-internal-format
+msgid "missing additional %<requires%> to start a requires-expression"
+msgstr ""
+
+#: cp/parser.cc:31613
+#, gcc-internal-format
+msgid "testing if a concept-id is a valid expression; add %<requires%> to check satisfaction"
+msgstr ""
+
+#: cp/parser.cc:31751
+#, gcc-internal-format
+msgid "result type is not a plain type-constraint"
+msgstr ""
+
+#: cp/parser.cc:31759
+#, gcc-internal-format
+msgid "return-type-requirement is not a type-constraint"
+msgstr ""
+
+#: cp/parser.cc:32277
+#, gcc-internal-format
+msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
+msgstr ""
+
+#: cp/parser.cc:32282
+#, gcc-internal-format
+msgid "invalid declaration of %<%T::%E%>"
+msgstr ""
+
+#: cp/parser.cc:32286
+#, gcc-internal-format
+msgid "too few template-parameter-lists"
+msgstr ""
+
+#. Otherwise, there are too many template parameter lists.  We have
+#. something like:
+#.
+#. template <class T> template <class U> void S::f();
+#: cp/parser.cc:32293
+#, gcc-internal-format
+msgid "too many template-parameter-lists"
+msgstr ""
+
+#: cp/parser.cc:32585
+#, gcc-internal-format
+msgid "template-id not allowed for constructor in C++20"
+msgstr ""
+
+#: cp/parser.cc:32696
+#, gcc-internal-format
+msgid "named return values are no longer supported"
+msgstr ""
+
+#: cp/parser.cc:32869
+#, gcc-internal-format
+msgid "ISO C++ did not adopt string literal operator templates taking an argument pack of characters"
+msgstr ""
+
+#: cp/parser.cc:32878
+#, gcc-internal-format
+msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%> or single non-type parameter of class type"
+msgstr ""
+
+#: cp/parser.cc:32884
+#, gcc-internal-format
+msgid "literal operator template %qD has invalid parameter list; expected non-type template parameter pack %<<char...>%>"
+msgstr ""
+
+#: cp/parser.cc:32991
+#, gcc-internal-format
+msgid "template-introductions are not part of C++20 concepts; use %qs to enable"
+msgstr ""
+
+#: cp/parser.cc:33001
+#, gcc-internal-format
+msgid "no matching concept for template-introduction"
+msgstr ""
+
+#: cp/parser.cc:33024
+#, gcc-internal-format
+msgid "invalid declaration of member template in local class"
+msgstr ""
+
+#: cp/parser.cc:33033
+#, gcc-internal-format
+msgid "template with C linkage"
+msgstr ""
+
+#: cp/parser.cc:33053
+#, gcc-internal-format
+msgid "invalid explicit specialization"
+msgstr ""
+
+#: cp/parser.cc:33165
+#, gcc-internal-format
+msgid "template declaration of %<typedef%>"
+msgstr ""
+
+#: cp/parser.cc:33216
+#, gcc-internal-format
+msgid "a class template declaration must not declare anything else"
+msgstr ""
+
+#: cp/parser.cc:33268
+#, gcc-internal-format
+msgid "explicit template specialization cannot have a storage class"
+msgstr ""
+
+#: cp/parser.cc:33585
+#, gcc-internal-format
+msgid "%<>>%> should be %<> >%> within a nested template argument list"
+msgstr ""
+
+#: cp/parser.cc:33598
+#, gcc-internal-format
+msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
+msgstr ""
+
+#: cp/parser.cc:33629
+#, gcc-internal-format
+msgid "%qs should be %qs to terminate a template argument list"
+msgstr ""
+
+#: cp/parser.cc:33946
+#, gcc-internal-format
+msgid "%<sizeof...%> argument must be surrounded by parentheses"
+msgstr ""
+
+#: cp/parser.cc:34123
+#, gcc-internal-format
+msgid "invalid use of %qD in linkage specification"
+msgstr ""
+
+#: cp/parser.cc:34134
+#, gcc-internal-format
+msgid "duplicate %qD specifier"
+msgstr ""
+
+#: cp/parser.cc:34137
+#, gcc-internal-format
+msgid "%qD specifier conflicts with %qs"
+msgstr ""
+
+#: cp/parser.cc:34149
+#, gcc-internal-format
+msgid "%<__thread%> before %qD"
+msgstr ""
+
+#: cp/parser.cc:34165
+#, gcc-internal-format
+msgid "%qD specifier conflicts with %<typedef%>"
+msgstr ""
+
+#: cp/parser.cc:34274
+#, gcc-internal-format
+msgid "ISO C++ 1998 does not support %<long long%>"
+msgstr ""
+
+#: cp/parser.cc:34285
+#, gcc-internal-format
+msgid "both %<__thread%> and %<thread_local%> specified"
+msgstr ""
+
+#: cp/parser.cc:34290
+#, gcc-internal-format
+msgid "duplicate %qD"
+msgstr ""
+
+#: cp/parser.cc:34319
+#, gcc-internal-format
+msgid "duplicate %qs"
+msgstr ""
+
+#: cp/parser.cc:34371
+#, gcc-internal-format
+msgid "expected %<new%>"
+msgstr ""
+
+#: cp/parser.cc:34374
+#, gcc-internal-format
+msgid "expected %<delete%>"
+msgstr ""
+
+#: cp/parser.cc:34377
+#, gcc-internal-format
+msgid "expected %<return%>"
+msgstr ""
+
+#: cp/parser.cc:34383
+#, gcc-internal-format
+msgid "expected %<extern%>"
+msgstr ""
+
+#: cp/parser.cc:34386
+#, gcc-internal-format
+msgid "expected %<static_assert%>"
+msgstr ""
+
+#: cp/parser.cc:34389
+#, gcc-internal-format
+msgid "expected %<decltype%>"
+msgstr ""
+
+#: cp/parser.cc:34392
+#, gcc-internal-format
+msgid "expected %<operator%>"
+msgstr ""
+
+#: cp/parser.cc:34395
+#, gcc-internal-format
+msgid "expected %<class%>"
+msgstr ""
+
+#: cp/parser.cc:34398
+#, gcc-internal-format
+msgid "expected %<template%>"
+msgstr ""
+
+#: cp/parser.cc:34401
+#, gcc-internal-format
+msgid "expected %<namespace%>"
+msgstr ""
+
+#: cp/parser.cc:34404
+#, gcc-internal-format
+msgid "expected %<using%>"
+msgstr ""
+
+#: cp/parser.cc:34407
+#, gcc-internal-format
+msgid "expected %<asm%>"
+msgstr ""
+
+#: cp/parser.cc:34410
+#, gcc-internal-format
+msgid "expected %<try%>"
+msgstr ""
+
+#: cp/parser.cc:34413
+#, gcc-internal-format
+msgid "expected %<catch%>"
+msgstr ""
+
+#: cp/parser.cc:34416
+#, gcc-internal-format
+msgid "expected %<throw%>"
+msgstr ""
+
+#: cp/parser.cc:34419
+#, gcc-internal-format
+msgid "expected %<auto%>"
+msgstr ""
+
+#: cp/parser.cc:34422
+#, gcc-internal-format
+msgid "expected %<__label__%>"
+msgstr ""
+
+#: cp/parser.cc:34425
+#, gcc-internal-format
+msgid "expected %<@try%>"
+msgstr ""
+
+#: cp/parser.cc:34428
+#, gcc-internal-format
+msgid "expected %<@synchronized%>"
+msgstr ""
+
+#: cp/parser.cc:34431
+#, gcc-internal-format
+msgid "expected %<@throw%>"
+msgstr ""
+
+#: cp/parser.cc:34434
+#, gcc-internal-format
+msgid "expected %<__transaction_atomic%>"
+msgstr ""
+
+#: cp/parser.cc:34437
+#, gcc-internal-format
+msgid "expected %<__transaction_relaxed%>"
+msgstr ""
+
+#: cp/parser.cc:34440
+#, gcc-internal-format
+msgid "expected %<co_yield%>"
+msgstr ""
+
+#: cp/parser.cc:34472
+#, gcc-internal-format
+msgid "expected %<::%>"
+msgstr ""
+
+#: cp/parser.cc:34484
+#, gcc-internal-format
+msgid "expected %<...%>"
+msgstr ""
+
+#: cp/parser.cc:34487
+#, gcc-internal-format
+msgid "expected %<*%>"
+msgstr ""
+
+#: cp/parser.cc:34490
+#, gcc-internal-format
+msgid "expected %<~%>"
+msgstr ""
+
+#: cp/parser.cc:34496
+#, gcc-internal-format
+msgid "expected %<:%> or %<::%>"
+msgstr ""
+
+#: cp/parser.cc:34523
+#, gcc-internal-format
+msgid "expected %<class%>, %<typename%>, or %<template%>"
+msgstr ""
+
+#: cp/parser.cc:34858
+#, gcc-internal-format
+msgid "redundant enum-key %<enum%s%> in reference to %q#T"
+msgstr ""
+
+#: cp/parser.cc:35009
+#, gcc-internal-format
+msgid "%qs tag used in naming %q#T"
+msgstr ""
+
+#: cp/parser.cc:35014
+#, gcc-internal-format
+msgid "%q#T was previously declared here"
+msgstr ""
+
+#: cp/parser.cc:35135
+#, gcc-internal-format
+msgid "redundant class-key %qs in reference to %q#T"
+msgstr ""
+
+#: cp/parser.cc:35293 cp/parser.cc:35327
+#, gcc-internal-format
+msgid "%qT declared with a mismatched class-key %qs"
+msgstr ""
+
+#: cp/parser.cc:35300 cp/parser.cc:35333
+#, gcc-internal-format
+msgid "remove the class-key or replace it with %qs"
+msgstr ""
+
+#: cp/parser.cc:35301 cp/parser.cc:35334
+#, gcc-internal-format
+msgid "replace the class-key with %qs"
+msgstr ""
+
+#: cp/parser.cc:35308
+#, gcc-internal-format
+msgid "%qT defined as %qs here"
+msgstr ""
+
+#: cp/parser.cc:35309
+#, gcc-internal-format
+msgid "%qT first declared as %qs here"
+msgstr ""
+
+#: cp/parser.cc:35392
+#, gcc-internal-format
+msgid "%qD redeclared with different access"
+msgstr ""
+
+#: cp/parser.cc:35413
+#, gcc-internal-format
+msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
+msgstr ""
+
+#: cp/parser.cc:35663
+#, gcc-internal-format
+msgid "file ends in default argument"
+msgstr ""
+
+#: cp/parser.cc:35904 cp/parser.cc:37212 cp/parser.cc:37401
+#, gcc-internal-format
+msgid "misplaced %<@%D%> Objective-C++ construct"
+msgstr ""
+
+#: cp/parser.cc:35975
+#, gcc-internal-format
+msgid "objective-c++ message receiver expected"
+msgstr ""
+
+#: cp/parser.cc:36045
+#, gcc-internal-format
+msgid "objective-c++ message argument(s) are expected"
+msgstr ""
+
+#: cp/parser.cc:36076
+#, gcc-internal-format
+msgid "%<@encode%> must specify a type as an argument"
+msgstr ""
+
+#: cp/parser.cc:36480
+#, gcc-internal-format
+msgid "invalid Objective-C++ selector name"
+msgstr ""
+
+#: cp/parser.cc:36555 cp/parser.cc:36573
+#, gcc-internal-format
+msgid "objective-c++ method declaration is expected"
+msgstr ""
+
+#: cp/parser.cc:36567 cp/parser.cc:36633
+#, gcc-internal-format
+msgid "method attributes must be specified at the end"
+msgstr ""
+
+#: cp/parser.cc:36676
+#, gcc-internal-format
+msgid "stray %qs between Objective-C++ methods"
+msgstr ""
+
+#: cp/parser.cc:36873 cp/parser.cc:36880 cp/parser.cc:36887
+#, gcc-internal-format
+msgid "invalid type for instance variable"
+msgstr ""
+
+#: cp/parser.cc:37004
+#, gcc-internal-format
+msgid "identifier expected after %<@protocol%>"
+msgstr ""
+
+#: cp/parser.cc:37177
+#, gcc-internal-format
+msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
+msgstr ""
+
+#: cp/parser.cc:37184
+#, gcc-internal-format
+msgid "prefix attributes are ignored before %<@%D%>"
+msgstr ""
+
+#: cp/parser.cc:37464 cp/parser.cc:37471 cp/parser.cc:37478
+#, gcc-internal-format
+msgid "invalid type for property"
+msgstr ""
+
+#: cp/parser.cc:37640
+#, gcc-internal-format
+msgid "unknown property attribute %qE"
+msgstr ""
+
+#: cp/parser.cc:38912
+#, gcc-internal-format
+msgid "expected integer expression list"
+msgstr ""
+
+#: cp/parser.cc:38929
+#, gcc-internal-format
+msgid "%<wait%> expression must be integral"
+msgstr ""
+
+#: cp/parser.cc:39685
+#, gcc-internal-format
+msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
+msgstr ""
+
+#: cp/parser.cc:40076
+#, gcc-internal-format
+msgid "invalid reduction-identifier"
+msgstr ""
+
+#: cp/parser.cc:41045
+#, gcc-internal-format
+msgid "types may not be defined in iterator type"
+msgstr ""
+
+#. FIXME: When implementing properly, delete the align/allocate expr error
+#. check above and add one in semantics.cc (to properly handle templates).
+#. Base this on the allocator/align modifiers check for the 'allocate' clause
+#. in semantics.cc's finish_omp_clauses.
+#: cp/parser.cc:42673
+#, gcc-internal-format
+msgid "%<#pragma omp allocate%> not yet supported"
+msgstr ""
+
+#: cp/parser.cc:44124
+#, gcc-internal-format
+msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
+msgstr ""
+
+#: cp/parser.cc:44862
+#, gcc-internal-format
+msgid "%<ordered%> clause with parameter on range-based %<for%> loop"
+msgstr ""
+
+#: cp/parser.cc:44944 cp/pt.cc:18191
+#, gcc-internal-format
+msgid "iteration variable %qD should not be reduction"
+msgstr ""
+
+#: cp/parser.cc:47841
+#, gcc-internal-format
+msgid "%<#pragma omp declare %s%> followed by %<#pragma omp declare %s%>"
+msgstr ""
+
+#: cp/parser.cc:48611
+#, gcc-internal-format
+msgid "OpenMP directive other than %<declare simd%> or %<declare variant%> appertains to a declaration"
+msgstr ""
+
+#: cp/parser.cc:49218
+#, gcc-internal-format
+msgid "invalid initializer clause"
+msgstr ""
+
+#: cp/parser.cc:49249
+#, gcc-internal-format
+msgid "expected id-expression (arguments)"
+msgstr ""
+
+#: cp/parser.cc:49261
+#, gcc-internal-format
+msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
+msgstr ""
+
+#: cp/parser.cc:49364
+#, gcc-internal-format
+msgid "types may not be defined in declare reduction type list"
+msgstr ""
+
+#: cp/parser.cc:49384 cp/semantics.cc:6444
+#, gcc-internal-format
+msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
+msgstr ""
+
+#: cp/parser.cc:49388 cp/semantics.cc:6452
+#, gcc-internal-format
+msgid "function or array type %qT in %<#pragma omp declare reduction%>"
+msgstr ""
+
+#: cp/parser.cc:49391 cp/pt.cc:14676 cp/semantics.cc:6458
+#, gcc-internal-format
+msgid "reference type %qT in %<#pragma omp declare reduction%>"
+msgstr ""
+
+#: cp/parser.cc:49394 cp/semantics.cc:6464
+#, gcc-internal-format
+msgid "%<const%>, %<volatile%> or %<__restrict%>-qualified type %qT in %<#pragma omp declare reduction%>"
+msgstr ""
+
+#: cp/parser.cc:50114
+#, gcc-internal-format
+msgid "%<#pragma acc routine%> names a set of overloads"
+msgstr ""
+
+#: cp/parser.cc:50124
+#, gcc-internal-format
+msgid "%qD does not refer to a namespace scope function"
+msgstr ""
+
+#. cancel-and-throw is unimplemented.
+#: cp/parser.cc:50485
+#, gcc-internal-format
+msgid "%<atomic_cancel%>"
+msgstr ""
+
+#: cp/parser.cc:50532 cp/semantics.cc:11476
+#, gcc-internal-format
+msgid "%<__transaction_relaxed%> without transactional memory support enabled"
+msgstr ""
+
+#: cp/parser.cc:50534 cp/semantics.cc:11478
+#, gcc-internal-format
+msgid "%<__transaction_atomic%> without transactional memory support enabled"
+msgstr ""
+
+#: cp/parser.cc:50680
+#, gcc-internal-format
+msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
+msgstr ""
+
+#: cp/parser.cc:50683
+#, gcc-internal-format
+msgid "  or a %<transaction_may_cancel_outer%> function"
+msgstr ""
+
+#: cp/parser.cc:50730
+#, gcc-internal-format
+msgid "malformed %<#pragma GCC pch_preprocess%>"
+msgstr ""
+
+#: cp/parser.cc:51030
+#, gcc-internal-format
+msgid "%<#pragma omp requires%> may only be used at file or namespace scope"
+msgstr ""
+
+#: cp/parser.cc:51041
+#, gcc-internal-format
+msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
+msgstr ""
+
+#: cp/parser.cc:51118
+#, gcc-internal-format
+msgid "%<#pragma GCC %s%> must be inside a function"
+msgstr ""
+
+#: cp/parser.cc:51260
+#, gcc-internal-format
+msgid "multi-source compilation not implemented for C++"
+msgstr ""
+
+#: cp/parser.cc:51297
+#, gcc-internal-format
+msgid "placeholder type not allowed in this context"
+msgstr ""
+
+#: cp/parser.cc:51506
+#, gcc-internal-format
+msgid "implicit templates may not be %<virtual%>"
+msgstr ""
+
+#: cp/parser.cc:51562
+#, gcc-internal-format
+msgid "%<extern \"C\"%> linkage started here"
+msgstr ""
+
+#: cp/pt.cc:313
+#, gcc-internal-format
+msgid "data member %qD cannot be a member template"
+msgstr ""
+
+#: cp/pt.cc:326
+#, gcc-internal-format
+msgid "invalid member template declaration %qD"
+msgstr ""
+
+#: cp/pt.cc:780
+#, gcc-internal-format
+msgid "explicit specialization in non-namespace scope %qD"
+msgstr ""
+
+#: cp/pt.cc:794
+#, gcc-internal-format
+msgid "enclosing class templates are not explicitly specialized"
+msgstr ""
+
+#: cp/pt.cc:878
+#, gcc-internal-format
+msgid "specialization of %qD must appear at namespace scope"
+msgstr ""
+
+#: cp/pt.cc:889 cp/pt.cc:1130
+#, gcc-internal-format
+msgid "specialization of %qD in different namespace"
+msgstr ""
+
+#: cp/pt.cc:891
+#, gcc-internal-format
+msgid "  from definition of %q#D"
+msgstr ""
+
+#: cp/pt.cc:908
+#, gcc-internal-format
+msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
+msgstr ""
+
+#: cp/pt.cc:1042
+#, gcc-internal-format
+msgid "name of class shadows template template parameter %qD"
+msgstr ""
+
+#: cp/pt.cc:1054
+#, gcc-internal-format
+msgid "specialization of alias template %qD"
+msgstr ""
+
+#: cp/pt.cc:1057 cp/pt.cc:1196
+#, gcc-internal-format
+msgid "explicit specialization of non-template %qT"
+msgstr ""
+
+#: cp/pt.cc:1089
+#, gcc-internal-format
+msgid "specialization of %qT after instantiation"
+msgstr ""
+
+#: cp/pt.cc:1133
+#, gcc-internal-format
+msgid "from definition of %q#D"
+msgstr ""
+
+#. But if we've had an implicit instantiation, that's a
+#. problem ([temp.expl.spec]/6).
+#: cp/pt.cc:1174
+#, gcc-internal-format
+msgid "specialization %qT after instantiation %qT"
+msgstr ""
+
+#: cp/pt.cc:1192
+#, gcc-internal-format
+msgid "template specialization of %qD not allowed by ISO C++"
+msgstr ""
+
+#: cp/pt.cc:1569
+#, gcc-internal-format
+msgid "specialization of %qD after instantiation"
+msgstr ""
+
+#: cp/pt.cc:2047 cp/semantics.cc:6314
+#, gcc-internal-format
+msgid "%s %#qD"
+msgstr ""
+
+#: cp/pt.cc:2183
+#, gcc-internal-format
+msgid "%qD is not a function template"
+msgstr ""
+
+#: cp/pt.cc:2188
+#, gcc-internal-format
+msgid "%qD is not a variable template"
+msgstr ""
+
+#: cp/pt.cc:2471
+#, gcc-internal-format
+msgid "template-id %qD for %q+D does not match any template declaration"
+msgstr ""
+
+#: cp/pt.cc:2475
+#, gcc-internal-format
+msgid "saw %d %<template<>%>, need %d for specializing a member function template"
+msgstr ""
+
+#: cp/pt.cc:2485
+#, gcc-internal-format
+msgid "ambiguous template specialization %qD for %q+D"
+msgstr ""
+
+#: cp/pt.cc:2689
+#, gcc-internal-format
+msgid "variable templates only available with %<-std=c++14%> or %<-std=gnu++14%>"
+msgstr ""
+
+#: cp/pt.cc:2699
+#, gcc-internal-format
+msgid "too many template headers for %qD (should be %d)"
+msgstr ""
+
+#: cp/pt.cc:2705
+#, gcc-internal-format
+msgid "members of an explicitly specialized class are defined without a template header"
+msgstr ""
+
+#: cp/pt.cc:2729
+#, gcc-internal-format
+msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
+msgstr ""
+
+#. This was allowed in C++98, so only pedwarn.
+#: cp/pt.cc:2734
+#, gcc-internal-format
+msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
+msgstr ""
+
+#: cp/pt.cc:2770
+#, gcc-internal-format
+msgid "explicit specialization %q#D may be missing attributes"
+msgstr ""
+
+#: cp/pt.cc:2774
+#, gcc-internal-format, gfc-internal-format
+msgid "missing primary template attributes %s"
+msgstr ""
+
+#: cp/pt.cc:2775
+#, gcc-internal-format, gfc-internal-format
+msgid "missing primary template attribute %s"
+msgstr ""
+
+#: cp/pt.cc:2867 cp/pt.cc:2927
+#, gcc-internal-format
+msgid "template-id %qE in declaration of primary template"
+msgstr ""
+
+#: cp/pt.cc:2880
+#, gcc-internal-format
+msgid "template parameter list used in explicit instantiation"
+msgstr ""
+
+#: cp/pt.cc:2886
+#, gcc-internal-format
+msgid "definition provided for explicit instantiation"
+msgstr ""
+
+#: cp/pt.cc:2894
+#, gcc-internal-format
+msgid "too many template parameter lists in declaration of %qD"
+msgstr ""
+
+#: cp/pt.cc:2897
+#, gcc-internal-format
+msgid "too few template parameter lists in declaration of %qD"
+msgstr ""
+
+#: cp/pt.cc:2899
+#, gcc-internal-format
+msgid "explicit specialization of %qD must be introduced by %<template <>%>"
+msgstr ""
+
+#: cp/pt.cc:2905
+#, gcc-internal-format
+msgid "explicit specialization declared %<concept%>"
+msgstr ""
+
+#: cp/pt.cc:2938
+#, gcc-internal-format
+msgid "non-type partial specialization %qE is not allowed"
+msgstr ""
+
+#: cp/pt.cc:2942
+#, gcc-internal-format
+msgid "non-class, non-variable partial specialization %qE is not allowed"
+msgstr ""
+
+#: cp/pt.cc:2974
+#, gcc-internal-format
+msgid "default argument specified in explicit specialization"
+msgstr ""
+
+#: cp/pt.cc:3017
+#, gcc-internal-format
+msgid "%qD is not a template function"
+msgstr ""
+
+#. From [temp.expl.spec]:
+#.
+#. If such an explicit specialization for the member
+#. of a class template names an implicitly-declared
+#. special member function (clause _special_), the
+#. program is ill-formed.
+#.
+#. Similar language is found in [temp.explicit].
+#: cp/pt.cc:3079
+#, gcc-internal-format
+msgid "specialization of implicitly-declared special member function"
+msgstr ""
+
+#: cp/pt.cc:3095
+#, gcc-internal-format
+msgid "no member function %qD declared in %qT"
+msgstr ""
+
+#: cp/pt.cc:3126
+#, gcc-internal-format
+msgid "friend declaration %qD is not visible to explicit specialization"
+msgstr ""
+
+#: cp/pt.cc:3129
+#, gcc-internal-format
+msgid "friend declaration here"
+msgstr ""
+
+#: cp/pt.cc:3240
+#, gcc-internal-format
+msgid "explicit specialization of function concept %qD"
+msgstr ""
+
+#: cp/pt.cc:3818
+#, gcc-internal-format
+msgid "argument to %<__integer_pack%> must be between 0 and %d"
+msgstr ""
+
+#: cp/pt.cc:4191
+#, gcc-internal-format
+msgid "base initializer expansion %qT contains no parameter packs"
+msgstr ""
+
+#: cp/pt.cc:4259
+#, gcc-internal-format
+msgid "expansion pattern %qT contains no parameter packs"
+msgstr ""
+
+#: cp/pt.cc:4261
+#, gcc-internal-format
+msgid "expansion pattern %qE contains no parameter packs"
+msgstr ""
+
+#: cp/pt.cc:4345
+#, gcc-internal-format
+msgid "parameter packs not expanded with %<...%>:"
+msgstr ""
+
+#: cp/pt.cc:4362 cp/pt.cc:5243
+#, gcc-internal-format
+msgid "        %qD"
+msgstr ""
+
+#: cp/pt.cc:4364
+#, gcc-internal-format, gfc-internal-format
+msgid "        %s"
+msgstr ""
+
+#: cp/pt.cc:4490
+#, gcc-internal-format
+msgid "declaration of template parameter %q+D shadows template parameter"
+msgstr ""
+
+#: cp/pt.cc:4493
+#, gcc-internal-format
+msgid "declaration of %q+#D shadows template parameter"
+msgstr ""
+
+#: cp/pt.cc:4495
+#, gcc-internal-format
+msgid "template parameter %qD declared here"
+msgstr ""
+
+#: cp/pt.cc:5179
+#, gcc-internal-format
+msgid "specialization of variable concept %q#D"
+msgstr ""
+
+#: cp/pt.cc:5238
+#, gcc-internal-format
+msgid "template parameters not deducible in partial specialization:"
+msgstr ""
+
+#: cp/pt.cc:5261
+#, gcc-internal-format
+msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
+msgstr ""
+
+#: cp/pt.cc:5265
+#, gcc-internal-format
+msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
+msgstr ""
+
+#: cp/pt.cc:5269 cp/pt.cc:5280 cp/pt.cc:5288
+#, gcc-internal-format
+msgid "primary template here"
+msgstr ""
+
+#: cp/pt.cc:5277
+#, gcc-internal-format
+msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
+msgstr ""
+
+#: cp/pt.cc:5287
+#, gcc-internal-format
+msgid "too many arguments for partial specialization %qT"
+msgstr ""
+
+#: cp/pt.cc:5302
+#, gcc-internal-format
+msgid "partial specialization %qD is not more specialized than"
+msgstr ""
+
+#: cp/pt.cc:5304
+#, gcc-internal-format
+msgid "primary template %qD"
+msgstr ""
+
+#: cp/pt.cc:5346
+#, gcc-internal-format
+msgid "parameter pack argument %qE must be at the end of the template argument list"
+msgstr ""
+
+#: cp/pt.cc:5349
+#, gcc-internal-format
+msgid "parameter pack argument %qT must be at the end of the template argument list"
+msgstr ""
+
+#: cp/pt.cc:5411
+#, gcc-internal-format
+msgid "type %qT of template argument %qE depends on a template parameter"
+msgid_plural "type %qT of template argument %qE depends on template parameters"
+msgstr[0] ""
+msgstr[1] ""
+
+#: cp/pt.cc:5479
+#, gcc-internal-format
+msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
+msgstr ""
+
+#: cp/pt.cc:5483
+#, gcc-internal-format
+msgid "partial specialization of %qD after instantiation of %qD"
+msgstr ""
+
+#: cp/pt.cc:5666
+#, gcc-internal-format
+msgid "no default argument for %qD"
+msgstr ""
+
+#. A primary class template, primary variable template
+#. (DR 2032), or alias template can only have one
+#. parameter pack, at the end of the template
+#. parameter list.
+#: cp/pt.cc:5689
+#, gcc-internal-format
+msgid "parameter pack %q+D must be at the end of the template parameter list"
+msgstr ""
+
+#: cp/pt.cc:5725
+#, gcc-internal-format
+msgid "default template arguments may not be used in function template friend re-declaration"
+msgstr ""
+
+#: cp/pt.cc:5728
+#, gcc-internal-format
+msgid "default template arguments may not be used in template friend declarations"
+msgstr ""
+
+#: cp/pt.cc:5731
+#, gcc-internal-format
+msgid "default template arguments may not be used in function templates without %<-std=c++11%> or %<-std=gnu++11%>"
+msgstr ""
+
+#: cp/pt.cc:5734
+#, gcc-internal-format
+msgid "default template arguments may not be used in partial specializations"
+msgstr ""
+
+#: cp/pt.cc:5737 cp/pt.cc:5795
+#, gcc-internal-format
+msgid "default argument for template parameter for class enclosing %qD"
+msgstr ""
+
+#: cp/pt.cc:5906
+#, gcc-internal-format
+msgid "template %qD declared"
+msgstr ""
+
+#: cp/pt.cc:5914
+#, gcc-internal-format
+msgid "template class without a name"
+msgstr ""
+
+#: cp/pt.cc:5922
+#, gcc-internal-format
+msgid "member template %qD may not have virt-specifiers"
+msgstr ""
+
+#. [basic.stc.dynamic.allocation]
+#.
+#. An allocation function can be a function
+#. template. ... Template allocation functions shall
+#. have two or more parameters.
+#: cp/pt.cc:5945
+#, gcc-internal-format
+msgid "invalid template declaration of %qD"
+msgstr ""
+
+#: cp/pt.cc:6097
+#, gcc-internal-format
+msgid "template definition of non-template %q#D"
+msgstr ""
+
+#: cp/pt.cc:6136
+#, gcc-internal-format
+msgid "expected %d levels of template parms for %q#D, got %d"
+msgstr ""
+
+#: cp/pt.cc:6150
+#, gcc-internal-format
+msgid "got %d template parameters for %q#D"
+msgstr ""
+
+#: cp/pt.cc:6153
+#, gcc-internal-format
+msgid "got %d template parameters for %q#T"
+msgstr ""
+
+#: cp/pt.cc:6155
+#, gcc-internal-format, gfc-internal-format
+msgid "  but %d required"
+msgstr ""
+
+#: cp/pt.cc:6176
+#, gcc-internal-format
+msgid "template arguments to %qD do not match original template %qD"
+msgstr ""
+
+#: cp/pt.cc:6179
+#, gcc-internal-format
+msgid "use %<template<>%> for an explicit specialization"
+msgstr ""
+
+#: cp/pt.cc:6201
+#, gcc-internal-format
+msgid "redeclaration of %qD with different constraints"
+msgstr ""
+
+#: cp/pt.cc:6346
+#, gcc-internal-format
+msgid "%qT is not a template type"
+msgstr ""
+
+#: cp/pt.cc:6359
+#, gcc-internal-format
+msgid "template specifiers not specified in declaration of %qD"
+msgstr ""
+
+#: cp/pt.cc:6370
+#, gcc-internal-format, gfc-internal-format
+msgid "redeclared with %d template parameter"
+msgid_plural "redeclared with %d template parameters"
+msgstr[0] ""
+msgstr[1] ""
+
+#: cp/pt.cc:6374
+#, gcc-internal-format
+msgid "previous declaration %qD used %d template parameter"
+msgid_plural "previous declaration %qD used %d template parameters"
+msgstr[0] ""
+msgstr[1] ""
+
+#: cp/pt.cc:6408
+#, gcc-internal-format
+msgid "template parameter %q+#D"
+msgstr ""
+
+#: cp/pt.cc:6410
+#, gcc-internal-format
+msgid "redeclared here as %q#D"
+msgstr ""
+
+#: cp/pt.cc:6412
+#, gcc-internal-format
+msgid "redeclared here"
+msgstr ""
+
+#: cp/pt.cc:6423
+#, gcc-internal-format
+msgid "declaration of template parameter %q+#D with different constraints"
+msgstr ""
+
+#: cp/pt.cc:6426 cp/pt.cc:6454
+#, gcc-internal-format
+msgid "original declaration appeared here"
+msgstr ""
+
+#: cp/pt.cc:6451
+#, gcc-internal-format
+msgid "redeclaration of %q#D with different constraints"
+msgstr ""
+
+#: cp/pt.cc:6872 cp/pt.cc:6942
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for type %qT"
+msgstr ""
+
+#: cp/pt.cc:6875
+#, gcc-internal-format
+msgid "it must be the address of a function with external linkage"
+msgstr ""
+
+#: cp/pt.cc:6878
+#, gcc-internal-format
+msgid "it must be the name of a function with external linkage"
+msgstr ""
+
+#: cp/pt.cc:6892
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
+msgstr ""
+
+#: cp/pt.cc:6896
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
+msgstr ""
+
+#: cp/pt.cc:6945
+#, gcc-internal-format
+msgid "it must be a pointer-to-member of the form %<&X::Y%>"
+msgstr ""
+
+#: cp/pt.cc:6947
+#, gcc-internal-format
+msgid "because it is a member of %qT"
+msgstr ""
+
+#: cp/pt.cc:7016
+#, gcc-internal-format
+msgid "  couldn%'t deduce template parameter %qD"
+msgstr ""
+
+#: cp/pt.cc:7025
+#, gcc-internal-format
+msgid "  types %qT and %qT have incompatible cv-qualifiers"
+msgstr ""
+
+#: cp/pt.cc:7034
+#, gcc-internal-format
+msgid "  mismatched types %qT and %qT"
+msgstr ""
+
+#: cp/pt.cc:7043
+#, gcc-internal-format
+msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
+msgstr ""
+
+#: cp/pt.cc:7054
+#, gcc-internal-format
+msgid "  template argument %qE does not match pointer-to-member constant %qE"
+msgstr ""
+
+#: cp/pt.cc:7064
+#, gcc-internal-format
+msgid "  %qE is not equivalent to %qE"
+msgstr ""
+
+#: cp/pt.cc:7073
+#, gcc-internal-format
+msgid "  inconsistent parameter pack deduction with %qT and %qT"
+msgstr ""
+
+#: cp/pt.cc:7085
+#, gcc-internal-format
+msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
+msgstr ""
+
+#: cp/pt.cc:7089
+#, gcc-internal-format
+msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
+msgstr ""
+
+#: cp/pt.cc:7100
+#, gcc-internal-format
+msgid "  variable-sized array type %qT is not a valid template argument"
+msgstr ""
+
+#: cp/pt.cc:7111
+#, gcc-internal-format
+msgid "  member function type %qT is not a valid template argument"
+msgstr ""
+
+#: cp/pt.cc:7154
+#, gcc-internal-format
+msgid "  cannot convert %qE (type %qT) to type %qT"
+msgstr ""
+
+#: cp/pt.cc:7167
+#, gcc-internal-format
+msgid "  %qT is an ambiguous base class of %qT"
+msgstr ""
+
+#: cp/pt.cc:7171
+#, gcc-internal-format
+msgid "  %qT is not derived from %qT"
+msgstr ""
+
+#: cp/pt.cc:7182
+#, gcc-internal-format
+msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
+msgstr ""
+
+#: cp/pt.cc:7192
+#, gcc-internal-format
+msgid "  cannot deduce a template for %qT from non-template type %qT"
+msgstr ""
+
+#: cp/pt.cc:7202
+#, gcc-internal-format
+msgid "  template argument %qE does not match %qE"
+msgstr ""
+
+#: cp/pt.cc:7253
+#, gcc-internal-format
+msgid "%qE is not a valid template argument of type %qT because %qE is not a variable or function"
+msgstr ""
+
+#: cp/pt.cc:7262
+#, gcc-internal-format
+msgid "%qE is not a valid template argument of type %qT in C++98 because %qD does not have external linkage"
+msgstr ""
+
+#: cp/pt.cc:7272
+#, gcc-internal-format
+msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
+msgstr ""
+
+#: cp/pt.cc:7289
+#, gcc-internal-format
+msgid "the address of %qD is not a valid template argument"
+msgstr ""
+
+#: cp/pt.cc:7299
+#, gcc-internal-format
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr ""
+
+#: cp/pt.cc:7306
+#, gcc-internal-format
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr ""
+
+#: cp/pt.cc:7324
+#, gcc-internal-format
+msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
+msgstr ""
+
+#: cp/pt.cc:7332
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
+msgstr ""
+
+#: cp/pt.cc:7454
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
+msgstr ""
+
+#: cp/pt.cc:7619
+#, gcc-internal-format
+msgid "in template argument for type %qT"
+msgstr ""
+
+#: cp/pt.cc:7633
+#, gcc-internal-format
+msgid "template argument %qE for type %qT not a compile-time constant"
+msgstr ""
+
+#: cp/pt.cc:7719
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
+msgstr ""
+
+#: cp/pt.cc:7727
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
+msgstr ""
+
+#: cp/pt.cc:7745
+#, gcc-internal-format
+msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
+msgstr ""
+
+#: cp/pt.cc:7804
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for type %qT because it is a pointer"
+msgstr ""
+
+#: cp/pt.cc:7806
+#, gcc-internal-format
+msgid "try using %qE instead"
+msgstr ""
+
+#: cp/pt.cc:7860
+#, gcc-internal-format
+msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
+msgstr ""
+
+#: cp/pt.cc:8452
+#, gcc-internal-format
+msgid "ignoring attributes on template argument %qT"
+msgstr ""
+
+#: cp/pt.cc:8468
+#, gcc-internal-format
+msgid "ignoring attributes in template argument %qE"
+msgstr ""
+
+#: cp/pt.cc:8612
+#, gcc-internal-format
+msgid "injected-class-name %qD used as template template argument"
+msgstr ""
+
+#: cp/pt.cc:8641
+#, gcc-internal-format
+msgid "invalid use of destructor %qE as a type"
+msgstr ""
+
+#: cp/pt.cc:8646
+#, gcc-internal-format
+msgid "to refer to a type member of a template parameter, use %<typename %E%>"
+msgstr ""
+
+#: cp/pt.cc:8662 cp/pt.cc:8696 cp/pt.cc:8746
+#, gcc-internal-format
+msgid "type/value mismatch at argument %d in template parameter list for %qD"
+msgstr ""
+
+#: cp/pt.cc:8670
+#, gcc-internal-format
+msgid "  expected a constant of type %qT, got %qT"
+msgstr ""
+
+#: cp/pt.cc:8678
+#, gcc-internal-format
+msgid "  ambiguous template argument for non-type template parameter is treated as function type"
+msgstr ""
+
+#: cp/pt.cc:8684
+#, gcc-internal-format
+msgid "  expected a class template, got %qE"
+msgstr ""
+
+#: cp/pt.cc:8687
+#, gcc-internal-format
+msgid "  expected a type, got %qE"
+msgstr ""
+
+#: cp/pt.cc:8701
+#, gcc-internal-format
+msgid "  expected a type, got %qT"
+msgstr ""
+
+#: cp/pt.cc:8704
+#, gcc-internal-format
+msgid "  expected a class template, got %qT"
+msgstr ""
+
+#: cp/pt.cc:8750
+#, gcc-internal-format
+msgid "  expected a template of type %qD, got %qT"
+msgstr ""
+
+#: cp/pt.cc:8764
+#, gcc-internal-format
+msgid "constraint mismatch at argument %d in template parameter list for %qD"
+msgstr ""
+
+#: cp/pt.cc:8767
+#, gcc-internal-format
+msgid "  expected %qD but got %qD"
+msgstr ""
+
+#: cp/pt.cc:8855
+#, gcc-internal-format
+msgid "could not convert template argument %qE from %qT to %qT"
+msgstr ""
+
+#: cp/pt.cc:8993 cp/pt.cc:9319
+#, gcc-internal-format, gfc-internal-format
+msgid "template argument %d is invalid"
+msgstr ""
+
+#: cp/pt.cc:9008 cp/pt.cc:9153
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong number of template arguments (%d, should be %d)"
+msgstr ""
+
+#: cp/pt.cc:9149
+#, gcc-internal-format, gfc-internal-format
+msgid "wrong number of template arguments (%d, should be at least %d)"
+msgstr ""
+
+#: cp/pt.cc:9158
+#, gcc-internal-format
+msgid "provided for %qD"
+msgstr ""
+
+#: cp/pt.cc:9183
+#, gcc-internal-format
+msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
+msgstr ""
+
+#: cp/pt.cc:9187
+#, gcc-internal-format
+msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
+msgstr ""
+
+#: cp/pt.cc:9285
+#, gcc-internal-format
+msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
+msgstr ""
+
+#: cp/pt.cc:9852
+#, gcc-internal-format
+msgid "%q#D is not a function template"
+msgstr ""
+
+#: cp/pt.cc:10015
+#, gcc-internal-format
+msgid "non-template type %qT used as a template"
+msgstr ""
+
+#: cp/pt.cc:10017
+#, gcc-internal-format
+msgid "for template declaration %q+D"
+msgstr ""
+
+#: cp/pt.cc:10186 cp/pt.cc:22299
+#, gcc-internal-format
+msgid "template constraint failure for %qD"
+msgstr ""
+
+#: cp/pt.cc:10539
+#, gcc-internal-format
+msgid "use of invalid variable template %qE"
+msgstr ""
+
+#: cp/pt.cc:11263
+#, gcc-internal-format
+msgid "template instantiation depth exceeds maximum of %d (use %<-ftemplate-depth=%> to increase the maximum)"
+msgstr ""
+
+#: cp/pt.cc:12037
+#, gcc-internal-format
+msgid "score argument must be constant integer expression"
+msgstr ""
+
+#: cp/pt.cc:12046
+#, gcc-internal-format
+msgid "score argument must be non-negative"
+msgstr ""
+
+#: cp/pt.cc:12073
+#, gcc-internal-format
+msgid "property must be constant integer expression or string literal"
+msgstr ""
+
+#: cp/pt.cc:12622
+#, gcc-internal-format
+msgid "flexible array member %qD in union"
+msgstr ""
+
+#: cp/pt.cc:13112
+#, gcc-internal-format
+msgid "fold of empty expansion over %O"
+msgstr ""
+
+#: cp/pt.cc:13572
+#, gcc-internal-format
+msgid "%qE is not the entire pattern of the pack expansion"
+msgstr ""
+
+#: cp/pt.cc:13660
+#, gcc-internal-format
+msgid "mismatched argument pack lengths while expanding %qT"
+msgstr ""
+
+#: cp/pt.cc:13663
+#, gcc-internal-format
+msgid "mismatched argument pack lengths while expanding %qE"
+msgstr ""
+
+#: cp/pt.cc:14351
+#, gcc-internal-format
+msgid "  when instantiating default argument for call to %qD"
+msgstr ""
+
+#: cp/pt.cc:14447
+#, gcc-internal-format
+msgid "creating pointer to member function of non-class type %qT"
+msgstr ""
+
+#: cp/pt.cc:15439
+#, gcc-internal-format, gfc-internal-format
+msgid "mismatched argument pack lengths (%d vs %d)"
+msgstr ""
+
+#. It may seem that this case cannot occur, since:
+#.
+#. typedef void f();
+#. void g() { f x; }
+#.
+#. declares a function, not a variable.  However:
+#.
+#. typedef void f();
+#. template <typename T> void g() { T t; }
+#. template void g<f>();
+#.
+#. is an attempt to declare a variable with function
+#. type.
+#: cp/pt.cc:15628
+#, gcc-internal-format
+msgid "variable %qD has function type"
+msgstr ""
+
+#: cp/pt.cc:15829
+#, gcc-internal-format
+msgid "invalid parameter type %qT"
+msgstr ""
+
+#: cp/pt.cc:15831
+#, gcc-internal-format
+msgid "in declaration %q+D"
+msgstr ""
+
+#: cp/pt.cc:15958
+#, gcc-internal-format
+msgid "function returning an array"
+msgstr ""
+
+#: cp/pt.cc:15960
+#, gcc-internal-format
+msgid "function returning a function"
+msgstr ""
+
+#: cp/pt.cc:16666
+#, gcc-internal-format
+msgid "forming reference to void"
+msgstr ""
+
+#: cp/pt.cc:16668
+#, gcc-internal-format
+msgid "forming pointer to reference type %qT"
+msgstr ""
+
+#: cp/pt.cc:16670
+#, gcc-internal-format
+msgid "forming reference to reference type %qT"
+msgstr ""
+
+#: cp/pt.cc:16683
+#, gcc-internal-format
+msgid "forming pointer to qualified function type %qT"
+msgstr ""
+
+#: cp/pt.cc:16686
+#, gcc-internal-format
+msgid "forming reference to qualified function type %qT"
+msgstr ""
+
+#: cp/pt.cc:16734
+#, gcc-internal-format
+msgid "creating pointer to member of non-class type %qT"
+msgstr ""
+
+#: cp/pt.cc:16740
+#, gcc-internal-format
+msgid "creating pointer to member reference type %qT"
+msgstr ""
+
+#: cp/pt.cc:16746
+#, gcc-internal-format
+msgid "creating pointer to member of type void"
+msgstr ""
+
+#: cp/pt.cc:16812
+#, gcc-internal-format
+msgid "creating array of %qT"
+msgstr ""
+
+#: cp/pt.cc:16849
+#, gcc-internal-format
+msgid "%qD is instantiated for an empty pack"
+msgstr ""
+
+#: cp/pt.cc:16870
+#, gcc-internal-format
+msgid "%qT is not a class, struct, or union type"
+msgstr ""
+
+#: cp/pt.cc:16910
+#, gcc-internal-format
+msgid "%qT resolves to %qT, which is not an enumeration type"
+msgstr ""
+
+#: cp/pt.cc:16918
+#, gcc-internal-format
+msgid "%qT resolves to %qT, which is not a class type"
+msgstr ""
+
+#: cp/pt.cc:17036
+#, gcc-internal-format
+msgid "use of %qs in template"
+msgstr ""
+
+#: cp/pt.cc:17355
+#, gcc-internal-format
+msgid "qualifying type %qT does not match destructor name ~%qT"
+msgstr ""
+
+#: cp/pt.cc:17370
+#, gcc-internal-format
+msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
+msgstr ""
+
+#: cp/pt.cc:17372
+#, gcc-internal-format
+msgid "say %<typename %E%> if a type is meant"
+msgstr ""
+
+#: cp/pt.cc:17465
+#, gcc-internal-format
+msgid "initializer for %q#D expands to an empty list of expressions"
+msgstr ""
+
+#: cp/pt.cc:19489 cp/pt.cc:21680
+#, gcc-internal-format
+msgid "invalid use of pack expansion expression"
+msgstr ""
+
+#: cp/pt.cc:19493 cp/pt.cc:21684
+#, gcc-internal-format
+msgid "use %<...%> to expand argument pack"
+msgstr ""
+
+#: cp/pt.cc:19640
+#, gcc-internal-format
+msgid "empty initializer in lambda init-capture"
+msgstr ""
+
+#: cp/pt.cc:20954
+#, gcc-internal-format
+msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
+msgstr ""
+
+#: cp/pt.cc:20989
+#, gcc-internal-format
+msgid "declarations in dependent base %qT are not found by unqualified lookup"
+msgstr ""
+
+#: cp/pt.cc:20994
+#, gcc-internal-format
+msgid "use %<this->%D%> instead"
+msgstr ""
+
+#: cp/pt.cc:20997
+#, gcc-internal-format
+msgid "use %<%T::%D%> instead"
+msgstr ""
+
+#: cp/pt.cc:21002
+#, gcc-internal-format
+msgid "%qD declared here, later in the translation unit"
+msgstr ""
+
+#: cp/pt.cc:21053
+#, gcc-internal-format
+msgid "wrong number of arguments to %<__builtin_convertvector%>"
+msgstr ""
+
+#: cp/pt.cc:21080
+#, gcc-internal-format
+msgid "wrong number of arguments to %<assume%> attribute"
+msgstr ""
+
+#: cp/pt.cc:21291
+#, gcc-internal-format
+msgid "%qT is not a class or namespace"
+msgstr ""
+
+#: cp/pt.cc:21294
+#, gcc-internal-format
+msgid "%qD is not a class or namespace"
+msgstr ""
+
+#: cp/pt.cc:21612
+#, gcc-internal-format
+msgid "using invalid field %qD"
+msgstr ""
+
+#: cp/pt.cc:21945
+#, gcc-internal-format
+msgid "%qT is/uses unnamed type"
+msgstr ""
+
+#: cp/pt.cc:21947
+#, gcc-internal-format
+msgid "template argument for %qD uses local type %qT"
+msgstr ""
+
+#: cp/pt.cc:21957
+#, gcc-internal-format
+msgid "%qT is a variably modified type"
+msgstr ""
+
+#: cp/pt.cc:21972
+#, gcc-internal-format
+msgid "integral expression %qE is not constant"
+msgstr ""
+
+#: cp/pt.cc:21990
+#, gcc-internal-format
+msgid "  trying to instantiate %qD"
+msgstr ""
+
+#: cp/pt.cc:26383
+#, gcc-internal-format
+msgid "ambiguous template instantiation for %q#T"
+msgstr ""
+
+#: cp/pt.cc:26385
+#, gcc-internal-format
+msgid "ambiguous template instantiation for %q#D"
+msgstr ""
+
+#: cp/pt.cc:26391
+msgid "%s %#qS"
+msgstr ""
+
+#: cp/pt.cc:26418 cp/pt.cc:26513
+#, gcc-internal-format
+msgid "explicit instantiation of non-template %q#D"
+msgstr ""
+
+#: cp/pt.cc:26424
+#, gcc-internal-format
+msgid "explicit instantiation of variable concept %q#D"
+msgstr ""
+
+#: cp/pt.cc:26426
+#, gcc-internal-format
+msgid "explicit instantiation of function concept %q#D"
+msgstr ""
+
+#: cp/pt.cc:26445
+#, gcc-internal-format
+msgid "%qD is not a static data member of a class template"
+msgstr ""
+
+#: cp/pt.cc:26451 cp/pt.cc:26508
+#, gcc-internal-format
+msgid "no matching template for %qD found"
+msgstr ""
+
+#: cp/pt.cc:26456
+#, gcc-internal-format
+msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
+msgstr ""
+
+#: cp/pt.cc:26464
+#, gcc-internal-format
+msgid "explicit instantiation of %q#D"
+msgstr ""
+
+#: cp/pt.cc:26500
+#, gcc-internal-format
+msgid "duplicate explicit instantiation of %q#D"
+msgstr ""
+
+#: cp/pt.cc:26523 cp/pt.cc:26590
+#, gcc-internal-format
+msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
+msgstr ""
+
+#: cp/pt.cc:26528 cp/pt.cc:26605
+#, gcc-internal-format
+msgid "storage class %qD applied to template instantiation"
+msgstr ""
+
+#: cp/pt.cc:26562
+#, gcc-internal-format
+msgid "explicit instantiation of non-class template %qD"
+msgstr ""
+
+#: cp/pt.cc:26565
+#, gcc-internal-format
+msgid "explicit instantiation of non-template type %qT"
+msgstr ""
+
+#: cp/pt.cc:26574
+#, gcc-internal-format
+msgid "explicit instantiation of %q#T before definition of template"
+msgstr ""
+
+#: cp/pt.cc:26595
+#, gcc-internal-format
+msgid "ISO C++ forbids the use of %qE on explicit instantiations"
+msgstr ""
+
+#: cp/pt.cc:26635
+#, gcc-internal-format
+msgid "duplicate explicit instantiation of %q#T"
+msgstr ""
+
+#: cp/pt.cc:26951
+#, gcc-internal-format
+msgid "exception specification of %qD depends on itself"
+msgstr ""
+
+#. [temp.explicit]
+#.
+#. The definition of a non-exported function template, a
+#. non-exported member function template, or a non-exported
+#. member function or static data member of a class template
+#. shall be present in every translation unit in which it is
+#. explicitly instantiated.
+#: cp/pt.cc:27424
+#, gcc-internal-format
+msgid "explicit instantiation of %qD but no definition available"
+msgstr ""
+
+#: cp/pt.cc:27469
+#, gcc-internal-format
+msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use %<-ftemplate-depth=%> to increase the maximum)"
+msgstr ""
+
+#: cp/pt.cc:27843
+#, gcc-internal-format
+msgid "non-type template parameters of deduced class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/pt.cc:27873
+#, gcc-internal-format
+msgid "%qT is not a valid type for a template non-type parameter because it is not structural"
+msgstr ""
+
+#: cp/pt.cc:27882
+#, gcc-internal-format
+msgid "non-type template parameters of class type only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/pt.cc:27890
+#, gcc-internal-format
+msgid "invalid template non-type parameter"
+msgstr ""
+
+#: cp/pt.cc:27892
+#, gcc-internal-format
+msgid "%q#T is not a valid type for a template non-type parameter"
+msgstr ""
+
+#: cp/pt.cc:29336
+#, gcc-internal-format
+msgid "keyword %<template%> not allowed in declarator-id"
+msgstr ""
+
+#: cp/pt.cc:29527
+#, gcc-internal-format
+msgid "a concept cannot be constrained"
+msgstr ""
+
+#: cp/pt.cc:29536
+#, gcc-internal-format
+msgid "concept %qE not in namespace scope"
+msgstr ""
+
+#: cp/pt.cc:29542
+#, gcc-internal-format
+msgid "concept %qE has multiple template parameter lists"
+msgstr ""
+
+#: cp/pt.cc:29573
+#, gcc-internal-format
+msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
+msgstr ""
+
+#: cp/pt.cc:30867
+#, gcc-internal-format
+msgid "non-deducible template %qT used without template arguments"
+msgstr ""
+
+#: cp/pt.cc:30879
+#, gcc-internal-format
+msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
+msgstr ""
+
+#: cp/pt.cc:30885
+#, gcc-internal-format
+msgid "use %qD directly instead"
+msgstr ""
+
+#: cp/pt.cc:31013
+#, gcc-internal-format
+msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
+msgstr ""
+
+#: cp/pt.cc:31020
+#, gcc-internal-format
+msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
+msgstr ""
+
+#: cp/pt.cc:31032
+#, gcc-internal-format
+msgid "class template argument deduction failed:"
+msgstr ""
+
+#: cp/pt.cc:31035
+#, gcc-internal-format
+msgid "explicit deduction guides not considered for copy-initialization"
+msgstr ""
+
+#. TODO: Pass down location from cp_finish_decl.
+#: cp/pt.cc:31049
+#, gcc-internal-format
+msgid "class template argument deduction for %qT failed: explicit deduction guide selected in copy-list-initialization"
+msgstr ""
+
+#: cp/pt.cc:31053
+#, gcc-internal-format
+msgid "explicit deduction guide declared here"
+msgstr ""
+
+#: cp/pt.cc:31067
+#, gcc-internal-format
+msgid "%qT may not intend to support class template argument deduction"
+msgstr ""
+
+#: cp/pt.cc:31069
+#, gcc-internal-format
+msgid "add a deduction guide to suppress this warning"
+msgstr ""
+
+#: cp/pt.cc:31191
+#, gcc-internal-format
+msgid "direct-list-initialization of %<auto%> requires exactly one element"
+msgstr ""
+
+#: cp/pt.cc:31194
+#, gcc-internal-format
+msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
+msgstr ""
+
+#: cp/pt.cc:31261
+#, gcc-internal-format
+msgid "unable to deduce lambda return type from %qE"
+msgstr ""
+
+#: cp/pt.cc:31264
+#, gcc-internal-format
+msgid "unable to deduce %qT from %qE"
+msgstr ""
+
+#: cp/pt.cc:31339
+#, gcc-internal-format
+msgid "placeholder constraints not satisfied"
+msgstr ""
+
+#: cp/pt.cc:31343
+#, gcc-internal-format
+msgid "deduced initializer does not satisfy placeholder constraints"
+msgstr ""
+
+#: cp/pt.cc:31347
+#, gcc-internal-format
+msgid "deduced return type does not satisfy placeholder constraints"
+msgstr ""
+
+#: cp/pt.cc:31351
+#, gcc-internal-format
+msgid "deduced expression type does not satisfy placeholder constraints"
+msgstr ""
+
+#: cp/pt.cc:31506
+#, gcc-internal-format
+msgid "invalid use of %qT in template argument"
+msgstr ""
+
+#: cp/rtti.cc:310
+#, gcc-internal-format
+msgid "cannot use %<typeid%> with %<-fno-rtti%>"
+msgstr ""
+
+#: cp/rtti.cc:323
+#, gcc-internal-format
+msgid "must %<#include <typeinfo>%> before using %<typeid%>"
+msgstr ""
+
+#: cp/rtti.cc:424
+#, gcc-internal-format
+msgid "cannot create type information for type %qT because it involves types of variable size"
+msgstr ""
+
+#: cp/rtti.cc:524
+#, gcc-internal-format
+msgid "%<typeid%> of qualified function type %qT"
+msgstr ""
+
+#: cp/rtti.cc:714 cp/rtti.cc:730
+#, gcc-internal-format
+msgid "%<dynamic_cast<%#T>(%#D)%> can never succeed"
+msgstr ""
+
+#: cp/rtti.cc:742
+#, gcc-internal-format
+msgid "%<dynamic_cast%> not permitted with %<-fno-rtti%>"
+msgstr ""
+
+#: cp/rtti.cc:822
+#, gcc-internal-format
+msgid "cannot %<dynamic_cast%> %qE (of type %q#T) to type %q#T (%s)"
+msgstr ""
+
+#: cp/search.cc:298
+#, gcc-internal-format
+msgid "%qT is an ambiguous base of %qT"
+msgstr ""
+
+#: cp/search.cc:314
+#, gcc-internal-format
+msgid "%qT is an inaccessible base of %qT"
+msgstr ""
+
+#: cp/search.cc:1992
+#, gcc-internal-format
+msgid "looser exception specification on overriding virtual function %q+#F"
+msgstr ""
+
+#: cp/search.cc:1995
+#, gcc-internal-format
+msgid "overridden function is %q#F"
+msgstr ""
+
+#: cp/search.cc:2070
+#, gcc-internal-format
+msgid "invalid covariant return type for %q#D"
+msgstr ""
+
+#: cp/search.cc:2072 cp/search.cc:2089 cp/search.cc:2106
+#, gcc-internal-format
+msgid "overridden function is %q#D"
+msgstr ""
+
+#: cp/search.cc:2085
+#, gcc-internal-format
+msgid "invalid covariant return type for %q+#D"
+msgstr ""
+
+#: cp/search.cc:2087
+#, gcc-internal-format
+msgid "conflicting return type specified for %q+#D"
+msgstr ""
+
+#: cp/search.cc:2104
+#, gcc-internal-format
+msgid "conflicting type attributes specified for %q+#D"
+msgstr ""
+
+#: cp/search.cc:2119
+#, gcc-internal-format
+msgid "%<consteval%> function %q+D overriding non-%<consteval%> function"
+msgstr ""
+
+#: cp/search.cc:2122
+#, gcc-internal-format
+msgid "non-%<consteval%> function %q+D overriding %<consteval%> function"
+msgstr ""
+
+#: cp/search.cc:2125 cp/search.cc:2154 cp/search.cc:2163 cp/search.cc:2174
+#: cp/search.cc:2199
+#, gcc-internal-format
+msgid "overridden function is %qD"
+msgstr ""
+
+#: cp/search.cc:2141
+#, gcc-internal-format
+msgid "%qD declared %<transaction_safe_dynamic%>"
+msgstr ""
+
+#: cp/search.cc:2143
+#, gcc-internal-format
+msgid "overriding %qD declared %<transaction_safe%>"
+msgstr ""
+
+#: cp/search.cc:2151
+#, gcc-internal-format
+msgid "deleted function %q+D overriding non-deleted function"
+msgstr ""
+
+#: cp/search.cc:2160
+#, gcc-internal-format
+msgid "non-deleted function %q+D overriding deleted function"
+msgstr ""
+
+#: cp/search.cc:2171
+#, gcc-internal-format
+msgid "function with contracts %q+D overriding contractless function"
+msgstr ""
+
+#: cp/search.cc:2197
+#, gcc-internal-format
+msgid "virtual function %q+D overriding final function"
+msgstr ""
+
+#: cp/search.cc:2285
+#, gcc-internal-format
+msgid "%q+#D cannot be declared"
+msgstr ""
+
+#: cp/search.cc:2286
+#, gcc-internal-format
+msgid "  since %q+#D declared in base class"
+msgstr ""
+
+#: cp/search.cc:2292
+#, gcc-internal-format
+msgid "explicit object member function overrides virtual function"
+msgstr ""
+
+#: cp/search.cc:2295
+#, gcc-internal-format
+msgid "virtual function declared here"
+msgstr ""
+
+#: cp/semantics.cc:1114
+#, gcc-internal-format
+msgid "%<std::is_constant_evaluated%> always evaluates to true in %<if constexpr%>"
+msgstr ""
+
+#: cp/semantics.cc:1120
+#, gcc-internal-format
+msgid "%<std::is_constant_evaluated%> evaluates to true when checking if trivially empty iteration statement is trivial infinite loop"
+msgstr ""
+
+#: cp/semantics.cc:1125
+#, gcc-internal-format
+msgid "and evaluates to false when actually evaluating the condition in non-%<constexpr%> function"
+msgstr ""
+
+#: cp/semantics.cc:1130
+#, gcc-internal-format
+msgid "%<std::is_constant_evaluated%> always evaluates to false in a non-%<constexpr%> function"
+msgstr ""
+
+#: cp/semantics.cc:1134
+#, gcc-internal-format
+msgid "%<std::is_constant_evaluated%> always evaluates to true in a %<consteval%> function"
+msgstr ""
+
+#: cp/semantics.cc:1351
+#, gcc-internal-format
+msgid "suggest explicit braces around empty body in %<do%> statement"
+msgstr ""
+
+#: cp/semantics.cc:1890
+#, gcc-internal-format
+msgid "catching polymorphic type %q#T by value"
+msgstr ""
+
+#: cp/semantics.cc:1895
+#, gcc-internal-format
+msgid "catching type %q#T by value"
+msgstr ""
+
+#: cp/semantics.cc:1900
+#, gcc-internal-format
+msgid "catching non-reference type %q#T"
+msgstr ""
+
+#: cp/semantics.cc:2112
+#, gcc-internal-format
+msgid "type of %<asm%> operand %qE could not be determined"
+msgstr ""
+
+#: cp/semantics.cc:2194
+#, gcc-internal-format
+msgid "%<__label__%> declarations are only allowed in function scopes"
+msgstr ""
+
+#: cp/semantics.cc:2369
+#, gcc-internal-format
+msgid "invalid use of member %qD in static member function"
+msgstr ""
+
+#: cp/semantics.cc:2373
+#, gcc-internal-format
+msgid "invalid use of member %qD in constructor %<pre%> contract"
+msgstr ""
+
+#: cp/semantics.cc:2377
+#, gcc-internal-format
+msgid "invalid use of member %qD in destructor %<post%> contract"
+msgstr ""
+
+#: cp/semantics.cc:2640
+#, gcc-internal-format
+msgid "%qE missing template arguments"
+msgstr ""
+
+#: cp/semantics.cc:2700
+#, gcc-internal-format
+msgid "a statement expression is an insufficient context for overload resolution"
+msgstr ""
+
+#: cp/semantics.cc:3059
+#, gcc-internal-format
+msgid "cannot call a concept as a function"
+msgstr ""
+
+#: cp/semantics.cc:3142
+#, gcc-internal-format
+msgid "arguments to destructor are not allowed"
+msgstr ""
+
+#: cp/semantics.cc:3246
+#, gcc-internal-format
+msgid "%<this%> is unavailable for explicit object member functions"
+msgstr ""
+
+#: cp/semantics.cc:3258
+#, gcc-internal-format
+msgid "use explicit object parameter %qs instead"
+msgstr ""
+
+#: cp/semantics.cc:3262
+#, gcc-internal-format
+msgid "name the explicit object parameter"
+msgstr ""
+
+#: cp/semantics.cc:3267
+#, gcc-internal-format
+msgid "%<this%> is unavailable for static member functions"
+msgstr ""
+
+#: cp/semantics.cc:3269
+#, gcc-internal-format
+msgid "invalid use of %<this%> before it is valid"
+msgstr ""
+
+#: cp/semantics.cc:3271
+#, gcc-internal-format
+msgid "invalid use of %<this%> after it is valid"
+msgstr ""
+
+#: cp/semantics.cc:3273
+#, gcc-internal-format
+msgid "invalid use of %<this%> in non-member function"
+msgstr ""
+
+#: cp/semantics.cc:3275
+#, gcc-internal-format
+msgid "invalid use of %<this%> at top level"
+msgstr ""
+
+#: cp/semantics.cc:3297
+#, gcc-internal-format
+msgid "invalid qualifying scope in pseudo-destructor name"
+msgstr ""
+
+#: cp/semantics.cc:3305 cp/typeck.cc:3081
+#, gcc-internal-format
+msgid "qualified type %qT does not match destructor name ~%qT"
+msgstr ""
+
+#: cp/semantics.cc:3327
+#, gcc-internal-format
+msgid "%qE is not of type %qT"
+msgstr ""
+
+#: cp/semantics.cc:3441
+#, gcc-internal-format
+msgid "compound literal of non-object type %qT"
+msgstr ""
+
+#: cp/semantics.cc:3461
+#, gcc-internal-format
+msgid "%<auto{x}%> cannot be constrained"
+msgstr ""
+
+#: cp/semantics.cc:3466
+#, gcc-internal-format
+msgid "%<auto{x}%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
+msgstr ""
+
+#: cp/semantics.cc:3658
+#, gcc-internal-format
+msgid "template type parameters must use the keyword %<class%> or %<typename%>"
+msgstr ""
+
+#: cp/semantics.cc:3711
+#, gcc-internal-format
+msgid "invalid use of type %qT as a default value for a template template-parameter"
+msgstr ""
+
+#: cp/semantics.cc:3715
+#, gcc-internal-format
+msgid "invalid default argument for a template template parameter"
+msgstr ""
+
+#: cp/semantics.cc:3732
+#, gcc-internal-format
+msgid "definition of %q#T inside template parameter list"
+msgstr ""
+
+#: cp/semantics.cc:3763
+#, gcc-internal-format
+msgid "invalid definition of qualified type %qT"
+msgstr ""
+
+#: cp/semantics.cc:4051
+#, gcc-internal-format
+msgid "invalid base-class specification"
+msgstr ""
+
+#: cp/semantics.cc:4219
+#, gcc-internal-format
+msgid "cannot capture member %qD of anonymous union"
+msgstr ""
+
+#: cp/semantics.cc:4236
+#, gcc-internal-format
+msgid "%qD is not captured"
+msgstr ""
+
+#: cp/semantics.cc:4240
+#, gcc-internal-format
+msgid "the lambda has no capture-default"
+msgstr ""
+
+#: cp/semantics.cc:4242
+#, gcc-internal-format
+msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
+msgstr ""
+
+#: cp/semantics.cc:4257
+#, gcc-internal-format
+msgid "use of local variable with automatic storage from containing function"
+msgstr ""
+
+#: cp/semantics.cc:4259
+#, gcc-internal-format
+msgid "use of parameter from containing function"
+msgstr ""
+
+#: cp/semantics.cc:4387
+#, gcc-internal-format
+msgid "use of parameter outside function body"
+msgstr ""
+
+#: cp/semantics.cc:4397
+#, gcc-internal-format
+msgid "missing template arguments"
+msgstr ""
+
+#: cp/semantics.cc:4433
+#, gcc-internal-format
+msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
+msgstr ""
+
+#: cp/semantics.cc:4484
+#, gcc-internal-format
+msgid "use of class template %qT as expression"
+msgstr ""
+
+#. Ambiguous reference to base members.
+#: cp/semantics.cc:4491
+#, gcc-internal-format
+msgid "request for member %qD is ambiguous in multiple inheritance lattice"
+msgstr ""
+
+#: cp/semantics.cc:4519
+#, gcc-internal-format
+msgid "%qD cannot appear in a constant-expression"
+msgstr ""
+
+#: cp/semantics.cc:4672
+#, gcc-internal-format
+msgid "type of %qE is unknown"
+msgstr ""
+
+#: cp/semantics.cc:4690 rust/backend/rust-tree.cc:5511
+#, gcc-internal-format
+msgid "%qT is not an enumeration type"
+msgstr ""
+
+#: cp/semantics.cc:4717
+#, gcc-internal-format
+msgid "%<__type_pack_element%> index is not an integral constant"
+msgstr ""
+
+#: cp/semantics.cc:4723
+#, gcc-internal-format
+msgid "%<__type_pack_element%> index is negative"
+msgstr ""
+
+#: cp/semantics.cc:4729
+#, gcc-internal-format
+msgid "%<__type_pack_element%> index is out of range"
+msgstr ""
+
+#. Parameter packs can only be used in templates
+#: cp/semantics.cc:4852
+#, gcc-internal-format
+msgid "parameter pack %<__bases%> only valid in template declaration"
+msgstr ""
+
+#: cp/semantics.cc:4884
+#, gcc-internal-format
+msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
+msgstr ""
+
+#: cp/semantics.cc:4897
+#, gcc-internal-format
+msgid "cannot apply %<offsetof%> to member function %qD"
+msgstr ""
+
+#: cp/semantics.cc:4901
+#, gcc-internal-format
+msgid "cannot apply %<offsetof%> to member function"
+msgstr ""
+
+#: cp/semantics.cc:4906
+#, gcc-internal-format
+msgid "cannot apply %<offsetof%> to an enumerator %qD"
+msgstr ""
+
+#: cp/semantics.cc:4917
+#, gcc-internal-format
+msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-supported"
+msgstr ""
+
+#: cp/semantics.cc:6117
+#, gcc-internal-format
+msgid "pointer-to-member mapping %qE not supported"
+msgstr ""
+
+#: cp/semantics.cc:6311
+#, gcc-internal-format
+msgid "user defined reduction lookup is ambiguous"
+msgstr ""
+
+#: cp/semantics.cc:6584
+#, gcc-internal-format
+msgid "%qE in %<reduction%> clause is a zero size array"
+msgstr ""
+
+#: cp/semantics.cc:6630
+#, gcc-internal-format
+msgid "%qE has const type for %<reduction%>"
+msgstr ""
+
+#: cp/semantics.cc:6749
+#, gcc-internal-format
+msgid "user defined reduction with constructor initializer for base class %qT"
+msgstr ""
+
+#: cp/semantics.cc:7221
+#, gcc-internal-format
+msgid "modifier other than %<val%> specified in %<linear%> clause on %<simd%> or %<for%> constructs when using OpenMP 5.2 modifiers"
+msgstr ""
+
+#: cp/semantics.cc:7236
+#, gcc-internal-format
+msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
+msgstr ""
+
+#: cp/semantics.cc:7251
+#, gcc-internal-format
+msgid "linear clause applied to non-integral non-pointer variable with %qT type"
+msgstr ""
+
+#: cp/semantics.cc:7275
+#, gcc-internal-format
+msgid "linear step expression must be integral"
+msgstr ""
+
+#: cp/semantics.cc:7368 cp/semantics.cc:7500 cp/semantics.cc:7560
+#: cp/semantics.cc:7961 cp/semantics.cc:9087
+#, gcc-internal-format
+msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
+msgstr ""
+
+#: cp/semantics.cc:7380 cp/semantics.cc:9100
+#, gcc-internal-format
+msgid "%qD is not a variable in clause %qs"
+msgstr ""
+
+#: cp/semantics.cc:7513
+#, gcc-internal-format
+msgid "%qD is not a variable in clause %<firstprivate%>"
+msgstr ""
+
+#: cp/semantics.cc:7573
+#, gcc-internal-format
+msgid "%qD is not a variable in clause %<lastprivate%>"
+msgstr ""
+
+#: cp/semantics.cc:7624
+#, gcc-internal-format
+msgid "%<gang%> static expression must be integral"
+msgstr ""
+
+#: cp/semantics.cc:7638
+#, gcc-internal-format
+msgid "%<gang%> static value must be positive"
+msgstr ""
+
+#: cp/semantics.cc:7672
+#, gcc-internal-format
+msgid "%<gang%> num expression must be integral"
+msgstr ""
+
+#: cp/semantics.cc:7675
+#, gcc-internal-format
+msgid "%<vector%> length expression must be integral"
+msgstr ""
+
+#: cp/semantics.cc:7679
+#, gcc-internal-format
+msgid "%<worker%> num expression must be integral"
+msgstr ""
+
+#: cp/semantics.cc:7701
+#, gcc-internal-format
+msgid "%<gang%> num value must be positive"
+msgstr ""
+
+#: cp/semantics.cc:7705
+#, gcc-internal-format
+msgid "%<vector%> length value must be positive"
+msgstr ""
+
+#: cp/semantics.cc:7710
+#, gcc-internal-format
+msgid "%<worker%> num value must be positive"
+msgstr ""
+
+#: cp/semantics.cc:7786
+#, gcc-internal-format
+msgid "schedule chunk size expression must be integral"
+msgstr ""
+
+#: cp/semantics.cc:7819
+#, gcc-internal-format
+msgid "%qs length expression must be integral"
+msgstr ""
+
+#: cp/semantics.cc:7833
+#, gcc-internal-format
+msgid "%qs length expression must be positive constant integer expression"
+msgstr ""
+
+#: cp/semantics.cc:7853
+#, gcc-internal-format
+msgid "%<async%> expression must be integral"
+msgstr ""
+
+#: cp/semantics.cc:7882
+#, gcc-internal-format
+msgid "%<thread_limit%> expression must be integral"
+msgstr ""
+
+#: cp/semantics.cc:7912
+#, gcc-internal-format
+msgid "%<device%> id must be integral"
+msgstr ""
+
+#: cp/semantics.cc:7943
+#, gcc-internal-format
+msgid "%<dist_schedule%> chunk size expression must be integral"
+msgstr ""
+
+#: cp/semantics.cc:7972
+#, gcc-internal-format
+msgid "%qD is not a variable in %<aligned%> clause"
+msgstr ""
+
+#: cp/semantics.cc:7987
+#, gcc-internal-format
+msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
+msgstr ""
+
+#: cp/semantics.cc:7994
+#, gcc-internal-format
+msgid "%qD appears more than once in %<aligned%> clauses"
+msgstr ""
+
+#: cp/semantics.cc:8009
+#, gcc-internal-format
+msgid "%<aligned%> clause alignment expression must be integral"
+msgstr ""
+
+#: cp/semantics.cc:8042
+#, gcc-internal-format
+msgid "%qD is not a variable in %<nontemporal%> clause"
+msgstr ""
+
+#: cp/semantics.cc:8053
+#, gcc-internal-format
+msgid "%qD appears more than once in %<nontemporal%> clauses"
+msgstr ""
+
+#: cp/semantics.cc:8070
+#, gcc-internal-format
+msgid "%<this%> not allowed in %<allocate%> clause"
+msgstr ""
+
+#: cp/semantics.cc:8082
+#, gcc-internal-format
+msgid "%qD is not a variable in %<allocate%> clause"
+msgstr ""
+
+#: cp/semantics.cc:8091
+#, gcc-internal-format
+msgid "%qD appears more than once in %<allocate%> clauses"
+msgstr ""
+
+#: cp/semantics.cc:8239
+#, gcc-internal-format
+msgid "%qD is not lvalue expression nor array section in %qs clause"
+msgstr ""
+
+#: cp/semantics.cc:8741
+#, gcc-internal-format
+msgid "template %qE in clause %qs"
+msgstr ""
+
+#: cp/semantics.cc:8744
+#, gcc-internal-format
+msgid "overloaded function name %qE in clause %qs"
+msgstr ""
+
+#: cp/semantics.cc:8813
+#, gcc-internal-format
+msgid "%<grainsize%> expression must be integral"
+msgstr ""
+
+#: cp/semantics.cc:8843
+#, gcc-internal-format
+msgid "%<priority%> expression must be integral"
+msgstr ""
+
+#: cp/semantics.cc:8873
+#, gcc-internal-format
+msgid "%<hint%> expression must be integral"
+msgstr ""
+
+#: cp/semantics.cc:8886
+#, gcc-internal-format
+msgid "%<hint%> expression must be constant integer expression"
+msgstr ""
+
+#: cp/semantics.cc:8903
+#, gcc-internal-format
+msgid "%<filter%> expression must be integral"
+msgstr ""
+
+#: cp/semantics.cc:8934
+#, gcc-internal-format
+msgid "%qs variable is neither a pointer nor reference to pointer"
+msgstr ""
+
+#: cp/semantics.cc:8944
+#, gcc-internal-format
+msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
+msgstr ""
+
+#: cp/semantics.cc:9028
+#, gcc-internal-format
+msgid "%<tile%> argument needs integral type"
+msgstr ""
+
+#: cp/semantics.cc:9445
+#, gcc-internal-format
+msgid "%<const%> qualified %qE without %<mutable%> member may appear only in %<shared%> or %<firstprivate%> clauses"
+msgstr ""
+
+#: cp/semantics.cc:9672
+#, gcc-internal-format
+msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
+msgstr ""
+
+#: cp/semantics.cc:9686
+#, gcc-internal-format
+msgid "%<threadprivate%> %qE directive not in %qT definition"
+msgstr ""
+
+#: cp/semantics.cc:10423
+#, gcc-internal-format
+msgid "difference between %qE and %qD does not have integer type"
+msgstr ""
+
+#: cp/semantics.cc:10908
+#, gcc-internal-format
+msgid "%<#pragma omp simd%> used with class iteration variable %qE"
+msgstr ""
+
+#: cp/semantics.cc:11228 cp/semantics.cc:11238
+#, gcc-internal-format
+msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
+msgstr ""
+
+#: cp/semantics.cc:11580
+#, gcc-internal-format
+msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
+msgstr ""
+
+#: cp/semantics.cc:11596
+#, gcc-internal-format
+msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
+msgstr ""
+
+#: cp/semantics.cc:11605
+#, gcc-internal-format
+msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
+msgstr ""
+
+#: cp/semantics.cc:11663
+#, gcc-internal-format
+msgid "%<static_assert%> message %<size()%> must be a constant expression"
+msgstr ""
+
+#: cp/semantics.cc:11671
+#, gcc-internal-format
+msgid "%<static_assert%> message %<size()%> %qE too large"
+msgstr ""
+
+#: cp/semantics.cc:11698
+#, gcc-internal-format
+msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
+msgstr ""
+
+#: cp/semantics.cc:11725
+#, gcc-internal-format
+msgid "%<static_assert%> message %<data()%> must be a core constant expression"
+msgstr ""
+
+#: cp/semantics.cc:11751
+#, gcc-internal-format
+msgid "static assertion failed: %.*s"
+msgstr ""
+
+#: cp/semantics.cc:11759
+#, gcc-internal-format
+msgid "non-constant condition for static assertion"
+msgstr ""
+
+#: cp/semantics.cc:11788
+#, gcc-internal-format
+msgid "argument to %<decltype%> must be an expression"
+msgstr ""
+
+#: cp/semantics.cc:11834
+#, gcc-internal-format
+msgid "%<decltype%> cannot resolve address of overloaded function"
+msgstr ""
+
+#: cp/semantics.cc:12138 rust/backend/rust-tree.cc:5225
+#, gcc-internal-format
+msgid "%<__builtin_is_pointer_interconvertible_with_class%> needs a single argument"
+msgstr ""
+
+#: cp/semantics.cc:12147 rust/backend/rust-tree.cc:5234
+#, gcc-internal-format
+msgid "%<__builtin_is_pointer_interconvertible_with_class%> argument is not pointer to member"
+msgstr ""
+
+#: cp/semantics.cc:12318 rust/backend/rust-tree.cc:5838
+#, gcc-internal-format
+msgid "%<__builtin_is_corresponding_member%> not well defined for anonymous unions"
+msgstr ""
+
+#: cp/semantics.cc:12342 rust/backend/rust-tree.cc:5882
+#, gcc-internal-format
+msgid "%<__builtin_is_corresponding_member%> needs two arguments"
+msgstr ""
+
+#: cp/semantics.cc:12353 rust/backend/rust-tree.cc:5892
+#, gcc-internal-format
+msgid "%<__builtin_is_corresponding_member%> argument is not pointer to member"
+msgstr ""
+
+#: cp/semantics.cc:12837
+#, gcc-internal-format
+msgid "%qD is not a class or alias template"
+msgstr ""
+
+#: cp/semantics.cc:13026
+#, gcc-internal-format
+msgid "operand of fold expression has no unexpanded parameter packs"
+msgstr ""
+
+#: cp/semantics.cc:13086
+#, gcc-internal-format
+msgid "both arguments in binary fold have unexpanded parameter packs"
+msgstr ""
+
+#: cp/semantics.cc:13088
+#, gcc-internal-format
+msgid "no unexpanded parameter packs in binary fold"
+msgstr ""
+
+#: cp/semantics.cc:13106
+#, gcc-internal-format
+msgid "non-pointer argument to %<__builtin_launder%>"
+msgstr ""
+
+#. std::bit_cast for destination ARRAY_TYPE is not possible,
+#. as functions may not return an array, so don't bother trying
+#. to support this (and then deal with VLAs etc.).
+#: cp/semantics.cc:13155
+#, gcc-internal-format
+msgid "%<__builtin_bit_cast%> destination type %qT is an array type"
+msgstr ""
+
+#: cp/semantics.cc:13161
+#, gcc-internal-format
+msgid "%<__builtin_bit_cast%> destination type %qT is not trivially copyable"
+msgstr ""
+
+#: cp/semantics.cc:13188
+#, gcc-internal-format
+msgid "%<__builtin_bit_cast%> source type %qT is not trivially copyable"
+msgstr ""
+
+#: cp/semantics.cc:13196
+#, gcc-internal-format
+msgid "%<__builtin_bit_cast%> source size %qE not equal to destination type size %qE"
+msgstr ""
+
+#: cp/tree.cc:1489 rust/backend/rust-tree.cc:2609
+#, gcc-internal-format
+msgid "%qV qualifiers cannot be applied to %qT"
+msgstr ""
+
+#: cp/tree.cc:2007
+#, gcc-internal-format
+msgid "statement-expression in a constant expression"
+msgstr ""
+
+#: cp/tree.cc:4527
+#, gcc-internal-format
+msgid "%<-fabi-version=13%> (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
+msgstr ""
+
+#: cp/tree.cc:4531
+#, gcc-internal-format
+msgid "%<-fabi-version=12%> (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr ""
+
+#: cp/tree.cc:4535
+#, gcc-internal-format
+msgid " declared here"
+msgstr ""
+
+#: cp/tree.cc:4540
+#, gcc-internal-format
+msgid "the calling convention for %qT changes in %<-fabi-version=13%> (GCC 8.2)"
+msgstr ""
+
+#: cp/tree.cc:4542
+#, gcc-internal-format
+msgid " because all of its copy and move constructors are deleted"
+msgstr ""
+
+#: cp/tree.cc:4969
+#, gcc-internal-format
+msgid "base class %qT is not public"
+msgstr ""
+
+#: cp/tree.cc:4972
+#, gcc-internal-format
+msgid "%qD is not public"
+msgstr ""
+
+#: cp/tree.cc:4979
+#, gcc-internal-format
+msgid "%qD is mutable"
+msgstr ""
+
+#: cp/tree.cc:4987
+#, gcc-internal-format
+msgid "%qD has a non-structural type"
+msgstr ""
+
+#: cp/tree.cc:5010
+#, gcc-internal-format
+msgid "%qE attribute can only be applied to functions or parameters"
+msgstr ""
+
+#: cp/tree.cc:5031
+#, gcc-internal-format
+msgid "%qE attribute argument must be a string constant"
+msgstr ""
+
+#: cp/tree.cc:5046
+#, gcc-internal-format
+msgid "%qE attribute can only be applied to functions or to class or enumeration types"
+msgstr ""
+
+#: cp/tree.cc:5066 cp/tree.cc:5071
+#, gcc-internal-format
+msgid "%qE attribute can only be applied to non-static data members"
+msgstr ""
+
+#: cp/tree.cc:5077
+#, gcc-internal-format
+msgid "%qE attribute cannot be applied to a bit-field"
+msgstr ""
+
+#: cp/tree.cc:5097
+#, gcc-internal-format
+msgid "%qE attribute takes no arguments"
+msgstr ""
+
+#: cp/tree.cc:5101
+#, gcc-internal-format
+msgid "ISO C++ %qE attribute does not apply to functions; treating as %<[[gnu::%E]]%>"
+msgstr ""
+
+#: cp/tree.cc:5185
+#, gcc-internal-format
+msgid "requested %<init_priority%> is not an integer constant"
+msgstr ""
+
+#: cp/tree.cc:5207
+#, gcc-internal-format
+msgid "can only use %qE attribute on file-scope definitions of objects of class type"
+msgstr ""
+
+#: cp/tree.cc:5215
+#, gcc-internal-format
+msgid "requested %<init_priority%> %i is out of range [0, %i]"
+msgstr ""
+
+#: cp/tree.cc:5226
+#, gcc-internal-format
+msgid "requested %<init_priority%> %i is reserved for internal use"
+msgstr ""
+
+#: cp/tree.cc:5256
+#, gcc-internal-format
+msgid "redeclaration of %qD adds abi tag %qE"
+msgstr ""
+
+#: cp/tree.cc:5276
+#, gcc-internal-format
+msgid "the %qE attribute requires arguments"
+msgstr ""
+
+#: cp/tree.cc:5287
+#, gcc-internal-format
+msgid "arguments to the %qE attribute must be narrow string literals"
+msgstr ""
+
+#: cp/tree.cc:5300 cp/tree.cc:5313
+#, gcc-internal-format
+msgid "arguments to the %qE attribute must contain valid identifiers"
+msgstr ""
+
+#: cp/tree.cc:5302
+#, gcc-internal-format
+msgid "%<%c%> is not a valid first character for an identifier"
+msgstr ""
+
+#: cp/tree.cc:5315
+#, gcc-internal-format
+msgid "%<%c%> is not a valid character in an identifier"
+msgstr ""
+
+#: cp/tree.cc:5339
+#, gcc-internal-format
+msgid "%qE attribute applied to non-class, non-enum type %qT"
+msgstr ""
+
+#: cp/tree.cc:5345
+#, gcc-internal-format
+msgid "%qE attribute applied to %qT after its definition"
+msgstr ""
+
+#: cp/tree.cc:5352
+#, gcc-internal-format
+msgid "ignoring %qE attribute applied to template instantiation %qT"
+msgstr ""
+
+#: cp/tree.cc:5359
+#, gcc-internal-format
+msgid "ignoring %qE attribute applied to template specialization %qT"
+msgstr ""
+
+#: cp/tree.cc:5381
+#, gcc-internal-format
+msgid "%qE attribute applied to non-function, non-variable %qD"
+msgstr ""
+
+#: cp/tree.cc:5387
+#, gcc-internal-format
+msgid "%qE attribute applied to extern \"C\" declaration %qD"
+msgstr ""
+
+#: cp/tree.cc:5420
+#, gcc-internal-format
+msgid "%qE attribute argument must be an expression that evaluates to true or false"
+msgstr ""
+
+#: cp/tree.cc:6290
+#, gcc-internal-format
+msgid "zero as null pointer constant"
+msgstr ""
+
+#: cp/tree.cc:6331 rust/backend/rust-tree.cc:3189
+#, gcc-internal-format
+msgid "%<lang_*%> check: failed in %s, at %s:%d"
+msgstr ""
+
+#: cp/typeck.cc:628
+#, gcc-internal-format
+msgid "comparison between distinct pointer types %qT and %qT lacks a cast"
+msgstr ""
+
+#: cp/typeck.cc:634
+#, gcc-internal-format
+msgid "conversion between distinct pointer types %qT and %qT lacks a cast"
+msgstr ""
+
+#: cp/typeck.cc:640
+#, gcc-internal-format
+msgid "conditional expression between distinct pointer types %qT and %qT lacks a cast"
+msgstr ""
+
+#: cp/typeck.cc:788
+#, gcc-internal-format
+msgid "ISO C++ forbids comparison between pointer of type %<void *%> and pointer-to-function"
+msgstr ""
+
+#: cp/typeck.cc:793
+#, gcc-internal-format
+msgid "ISO C++ forbids conversion between pointer of type %<void *%> and pointer-to-function"
+msgstr ""
+
+#: cp/typeck.cc:798
+#, gcc-internal-format
+msgid "ISO C++ forbids conditional expression between pointer of type %<void *%> and pointer-to-function"
+msgstr ""
+
+#: cp/typeck.cc:877
+#, gcc-internal-format
+msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
+msgstr ""
+
+#: cp/typeck.cc:882
+#, gcc-internal-format
+msgid "conversion between distinct pointer-to-member types %qT and %qT lacks a cast"
+msgstr ""
+
+#: cp/typeck.cc:887
+#, gcc-internal-format
+msgid "conditional expression between distinct pointer-to-member types %qT and %qT lacks a cast"
+msgstr ""
+
+#: cp/typeck.cc:1713
+#, gcc-internal-format
+msgid "canonical types differ for identical types %qT and %qT"
+msgstr ""
+
+#: cp/typeck.cc:1720
+#, gcc-internal-format
+msgid "same canonical type node for different types %qT and %qT"
+msgstr ""
+
+#: cp/typeck.cc:2050
+#, gcc-internal-format
+msgid "invalid application of %qs to a member function"
+msgstr ""
+
+#: cp/typeck.cc:2148
+#, gcc-internal-format
+msgid "invalid application of %<sizeof%> to a bit-field"
+msgstr ""
+
+#: cp/typeck.cc:2156
+#, gcc-internal-format
+msgid "ISO C++ forbids applying %<sizeof%> to an expression of function type"
+msgstr ""
+
+#: cp/typeck.cc:2221
+#, gcc-internal-format
+msgid "invalid application of %<__alignof%> to a bit-field"
+msgstr ""
+
+#: cp/typeck.cc:2232
+#, gcc-internal-format
+msgid "ISO C++ forbids applying %<__alignof%> to an expression of function type"
+msgstr ""
+
+#: cp/typeck.cc:2316
+#, gcc-internal-format
+msgid "%<alignas%> argument has non-integral type %qT"
+msgstr ""
+
+#: cp/typeck.cc:2362 rust/backend/rust-tree.cc:3817
+#, gcc-internal-format
+msgid "invalid use of non-static member function of type %qT"
+msgstr ""
+
+#: cp/typeck.cc:2712
+#, gcc-internal-format
+msgid "ISO C++ forbids converting a string constant to %qT"
+msgstr ""
+
+#: cp/typeck.cc:2716
+#, gcc-internal-format
+msgid "deprecated conversion from string constant to %qT"
+msgstr ""
+
+#: cp/typeck.cc:2831 cp/typeck.cc:3395
+#, gcc-internal-format
+msgid "request for member %qD in %qE, which is of pointer type %qT (maybe you meant to use %<->%> ?)"
+msgstr ""
+
+#: cp/typeck.cc:2835 cp/typeck.cc:3399
+#, gcc-internal-format
+msgid "request for member %qD in %qE, which is of non-class type %qT"
+msgstr ""
+
+#: cp/typeck.cc:2869
+#, gcc-internal-format
+msgid "invalid use of non-static data member %qE"
+msgstr ""
+
+#: cp/typeck.cc:2946
+#, gcc-internal-format
+msgid "invalid access to non-static data member %qD in virtual base of NULL object"
+msgstr ""
+
+#: cp/typeck.cc:3096
+#, gcc-internal-format
+msgid "object type %qT does not match destructor name ~%qT"
+msgstr ""
+
+#: cp/typeck.cc:3105
+#, gcc-internal-format
+msgid "the type being destroyed is %qT, but the destructor refers to %qT"
+msgstr ""
+
+#: cp/typeck.cc:3247
+#, gcc-internal-format
+msgid "field %q#D can be accessed via %q#D"
+msgstr ""
+
+#. No hint.
+#: cp/typeck.cc:3266
+#, gcc-internal-format
+msgid "%q#T has no member named %qE"
+msgstr ""
+
+#: cp/typeck.cc:3289
+#, gcc-internal-format
+msgid "%q#T has no member named %qE; did you mean %q#D? (accessible via %q#D)"
+msgstr ""
+
+#: cp/typeck.cc:3300
+#, gcc-internal-format
+msgid "%q#T has no member named %qE; did you mean %q#D? (not accessible from this context)"
+msgstr ""
+
+#: cp/typeck.cc:3315
+#, gcc-internal-format
+msgid "%q#T has no member named %qE; did you mean %qE?"
+msgstr ""
+
+#: cp/typeck.cc:3429 cp/typeck.cc:3455
+#, gcc-internal-format
+msgid "%<%D::%D%> is not a member of %qT"
+msgstr ""
+
+#: cp/typeck.cc:3509
+#, gcc-internal-format
+msgid "%qT is not a base of %qT"
+msgstr ""
+
+#: cp/typeck.cc:3572
+#, gcc-internal-format
+msgid "%qD is not a member template function"
+msgstr ""
+
+#: cp/typeck.cc:3837
+#, gcc-internal-format
+msgid "%qT is not a pointer-to-object type"
+msgstr ""
+
+#: cp/typeck.cc:3869
+#, gcc-internal-format
+msgid "invalid use of array indexing on pointer to member"
+msgstr ""
+
+#: cp/typeck.cc:3872
+#, gcc-internal-format
+msgid "invalid use of unary %<*%> on pointer to member"
+msgstr ""
+
+#: cp/typeck.cc:3875
+#, gcc-internal-format
+msgid "invalid use of implicit conversion on pointer to member"
+msgstr ""
+
+#: cp/typeck.cc:3879
+#, gcc-internal-format
+msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
+msgstr ""
+
+#: cp/typeck.cc:3945
+#, gcc-internal-format
+msgid "subscript missing in array reference"
+msgstr ""
+
+#: cp/typeck.cc:4050
+#, gcc-internal-format
+msgid "subscripting array declared %<register%>"
+msgstr ""
+
+#: cp/typeck.cc:4089
+#, gcc-internal-format
+msgid "subscripted value is neither array nor pointer"
+msgstr ""
+
+#: cp/typeck.cc:4161
+#, gcc-internal-format
+msgid "object missing in use of %qE"
+msgstr ""
+
+#: cp/typeck.cc:4386
+#, gcc-internal-format
+msgid "ISO C++ forbids calling %<::main%> from within program"
+msgstr ""
+
+#: cp/typeck.cc:4407
+#, gcc-internal-format
+msgid "must use %<.*%> or %<->*%> to call pointer-to-member function in %<%E (...)%>, e.g. %<(... ->* %E) (...)%>"
+msgstr ""
+
+#: cp/typeck.cc:4424
+#, gcc-internal-format
+msgid "%qE cannot be used as a function"
+msgstr ""
+
+#: cp/typeck.cc:4427
+#, gcc-internal-format
+msgid "%qD cannot be used as a function"
+msgstr ""
+
+#: cp/typeck.cc:4430
+#, gcc-internal-format
+msgid "expression cannot be used as a function"
+msgstr ""
+
+#: cp/typeck.cc:4488
+#, gcc-internal-format
+msgid "too many arguments to constructor %q#D"
+msgstr ""
+
+#: cp/typeck.cc:4489
+#, gcc-internal-format
+msgid "too few arguments to constructor %q#D"
+msgstr ""
+
+#: cp/typeck.cc:4494
+#, gcc-internal-format
+msgid "too many arguments to member function %q#D"
+msgstr ""
+
+#: cp/typeck.cc:4495
+#, gcc-internal-format
+msgid "too few arguments to member function %q#D"
+msgstr ""
+
+#: cp/typeck.cc:4501
+#, gcc-internal-format
+msgid "too many arguments to function %q#D"
+msgstr ""
+
+#: cp/typeck.cc:4502
+#, gcc-internal-format
+msgid "too few arguments to function %q#D"
+msgstr ""
+
+#: cp/typeck.cc:4512
+#, gcc-internal-format
+msgid "too many arguments to method %q#D"
+msgstr ""
+
+#: cp/typeck.cc:4513
+#, gcc-internal-format
+msgid "too few arguments to method %q#D"
+msgstr ""
+
+#: cp/typeck.cc:4516
+#, gcc-internal-format
+msgid "too many arguments to function"
+msgstr ""
+
+#: cp/typeck.cc:4517
+#, gcc-internal-format
+msgid "too few arguments to function"
+msgstr ""
+
+#: cp/typeck.cc:4599
+#, gcc-internal-format
+msgid "parameter %P of %qD has incomplete type %qT"
+msgstr ""
+
+#: cp/typeck.cc:4605
+#, gcc-internal-format
+msgid "parameter %P has incomplete type %qT"
+msgstr ""
+
+#: cp/typeck.cc:4914
+#, gcc-internal-format
+msgid "the address %qE will never be NULL"
+msgstr ""
+
+#: cp/typeck.cc:4960
+#, gcc-internal-format
+msgid "the address of %qD will never be NULL"
+msgstr ""
+
+#: cp/typeck.cc:4975
+#, gcc-internal-format
+msgid "the compiler can assume that the address of %qE will never be NULL"
+msgstr ""
+
+#: cp/typeck.cc:4978
+#, gcc-internal-format
+msgid "comparing the result of pointer addition %qE and NULL"
+msgstr ""
+
+#: cp/typeck.cc:4993
+#, gcc-internal-format
+msgid "the compiler can assume that the address of %qD will never be NULL"
+msgstr ""
+
+#: cp/typeck.cc:5052
+#, gcc-internal-format
+msgid "bitwise operation between different enumeration types %qT and %qT"
+msgstr ""
+
+#: cp/typeck.cc:5055
+#, gcc-internal-format
+msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
+msgstr ""
+
+#: cp/typeck.cc:5061
+#, gcc-internal-format
+msgid "arithmetic between different enumeration types %qT and %qT"
+msgstr ""
+
+#: cp/typeck.cc:5064
+#, gcc-internal-format
+msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
+msgstr ""
+
+#: cp/typeck.cc:5101
+#, gcc-internal-format
+msgid "comparison of enumeration type %qT with floating-point type %qT"
+msgstr ""
+
+#: cp/typeck.cc:5104
+#, gcc-internal-format
+msgid "comparison of floating-point type %qT with enumeration type %qT"
+msgstr ""
+
+#: cp/typeck.cc:5107
+#, gcc-internal-format
+msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
+msgstr ""
+
+#: cp/typeck.cc:5111
+#, gcc-internal-format
+msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
+msgstr ""
+
+#: cp/typeck.cc:5120
+#, gcc-internal-format
+msgid "arithmetic between enumeration type %qT and floating-point type %qT"
+msgstr ""
+
+#: cp/typeck.cc:5123
+#, gcc-internal-format
+msgid "arithmetic between floating-point type %qT and enumeration type %qT"
+msgstr ""
+
+#: cp/typeck.cc:5126
+#, gcc-internal-format
+msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
+msgstr ""
+
+#: cp/typeck.cc:5130
+#, gcc-internal-format
+msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
+msgstr ""
+
+#: cp/typeck.cc:5265 cp/typeck.cc:5277
+#, gcc-internal-format
+msgid "assuming cast to type %qT from overloaded function"
+msgstr ""
+
+#: cp/typeck.cc:5391
+#, gcc-internal-format
+msgid "NULL used in arithmetic"
+msgstr ""
+
+#: cp/typeck.cc:5853 cp/typeck.cc:5862 cp/typeck.cc:6163 cp/typeck.cc:6172
+#, gcc-internal-format
+msgid "ISO C++ forbids comparison between pointer and integer"
+msgstr ""
+
+#: cp/typeck.cc:6085 cp/typeck.cc:6098
+#, gcc-internal-format
+msgid "operand types are %qT and %qT"
+msgstr ""
+
+#: cp/typeck.cc:6121
+#, gcc-internal-format
+msgid "three-way comparison of vectors"
+msgstr ""
+
+#: cp/typeck.cc:6155
+#, gcc-internal-format
+msgid "ordered comparison of pointer with integer zero (%qT and %qT)"
+msgstr ""
+
+#: cp/typeck.cc:6202
+#, gcc-internal-format
+msgid "unordered comparison on non-floating-point argument"
+msgstr ""
+
+#: cp/typeck.cc:6268
+msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
+msgstr ""
+
+#: cp/typeck.cc:6377
+#, gcc-internal-format
+msgid "invalid operands of types %qT and %qT to binary %qO"
+msgstr ""
+
+#: cp/typeck.cc:6778
+#, gcc-internal-format
+msgid "ISO C++ forbids using pointer of type %<void *%> in subtraction"
+msgstr ""
+
+#: cp/typeck.cc:6786
+#, gcc-internal-format
+msgid "ISO C++ forbids using pointer to a function in subtraction"
+msgstr ""
+
+#: cp/typeck.cc:6794
+#, gcc-internal-format
+msgid "ISO C++ forbids using pointer to a method in subtraction"
+msgstr ""
+
+#: cp/typeck.cc:6847
+#, gcc-internal-format
+msgid "invalid use of a pointer to an incomplete type in pointer arithmetic"
+msgstr ""
+
+#: cp/typeck.cc:6924
+#, gcc-internal-format
+msgid "taking address of constructor %qD"
+msgstr ""
+
+#: cp/typeck.cc:6925
+#, gcc-internal-format
+msgid "taking address of destructor %qD"
+msgstr ""
+
+#: cp/typeck.cc:6941
+#, gcc-internal-format
+msgid "invalid use of %qE to form a pointer-to-member-function"
+msgstr ""
+
+#: cp/typeck.cc:6944
+#, gcc-internal-format
+msgid "  a qualified-id is required"
+msgstr ""
+
+#: cp/typeck.cc:6951
+#, gcc-internal-format
+msgid "parentheses around %qE cannot be used to form a pointer-to-member-function"
+msgstr ""
+
+#: cp/typeck.cc:7146
+#, gcc-internal-format
+msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
+msgstr ""
+
+#: cp/typeck.cc:7152
+#, gcc-internal-format
+msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
+msgstr ""
+
+#: cp/typeck.cc:7158
+#, gcc-internal-format
+msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
+msgstr ""
+
+#: cp/typeck.cc:7164
+#, gcc-internal-format
+msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
+msgstr ""
+
+#: cp/typeck.cc:7169
+#, gcc-internal-format
+msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
+msgstr ""
+
+#. Make this a permerror because we used to accept it.
+#: cp/typeck.cc:7202
+#, gcc-internal-format
+msgid "taking address of rvalue"
+msgstr ""
+
+#: cp/typeck.cc:7219
+#, gcc-internal-format
+msgid "ISO C++ forbids taking address of function %<::main%>"
+msgstr ""
+
+#: cp/typeck.cc:7277
+#, gcc-internal-format
+msgid "cannot create pointer to reference member %qD"
+msgstr ""
+
+#: cp/typeck.cc:7312 cp/typeck.cc:7888 rust/backend/rust-tree.cc:4714
+#, gcc-internal-format
+msgid "attempt to take address of bit-field"
+msgstr ""
+
+#: cp/typeck.cc:7474
+#, gcc-internal-format
+msgid "%<~%> on an expression of type %<bool%>"
+msgstr ""
+
+#: cp/typeck.cc:7475
+#, gcc-internal-format
+msgid "did you mean to use logical not (%<!%>)?"
+msgstr ""
+
+#: cp/typeck.cc:7607
+#, gcc-internal-format
+msgid "ISO C++ forbids incrementing an enum"
+msgstr ""
+
+#: cp/typeck.cc:7608
+#, gcc-internal-format
+msgid "ISO C++ forbids decrementing an enum"
+msgstr ""
+
+#: cp/typeck.cc:7624
+#, gcc-internal-format
+msgid "cannot increment a pointer to incomplete type %qT"
+msgstr ""
+
+#: cp/typeck.cc:7626
+#, gcc-internal-format
+msgid "cannot decrement a pointer to incomplete type %qT"
+msgstr ""
+
+#: cp/typeck.cc:7638
+#, gcc-internal-format
+msgid "ISO C++ forbids incrementing a pointer of type %qT"
+msgstr ""
+
+#: cp/typeck.cc:7640
+#, gcc-internal-format
+msgid "ISO C++ forbids decrementing a pointer of type %qT"
+msgstr ""
+
+#: cp/typeck.cc:7680
+#, gcc-internal-format
+msgid "%qs expression of %<volatile%>-qualified type is deprecated"
+msgstr ""
+
+#: cp/typeck.cc:7693
+#, gcc-internal-format
+msgid "use of an operand of type %qT in %<operator--%> is forbidden"
+msgstr ""
+
+#: cp/typeck.cc:7703
+#, gcc-internal-format
+msgid "use of an operand of type %qT in %<operator++%> is forbidden in C++17"
+msgstr ""
+
+#: cp/typeck.cc:7711
+#, gcc-internal-format
+msgid "use of an operand of type %qT in %<operator++%> is deprecated"
+msgstr ""
+
+#: cp/typeck.cc:7900 rust/backend/rust-tree.cc:4726
+#, gcc-internal-format
+msgid "cannot take the address of %<this%>, which is an rvalue expression"
+msgstr ""
+
+#: cp/typeck.cc:7922 d/d-codegen.cc:719 rust/backend/rust-tree.cc:4745
+#, gcc-internal-format
+msgid "address of explicit register variable %qD requested"
+msgstr ""
+
+#: cp/typeck.cc:7927 rust/backend/rust-tree.cc:4752
+#, gcc-internal-format
+msgid "address requested for %qD, which is declared %<register%>"
+msgstr ""
+
+#: cp/typeck.cc:7998
+#, gcc-internal-format
+msgid "list-initializer for non-class type must not be parenthesized"
+msgstr ""
+
+#: cp/typeck.cc:8010
+#, gcc-internal-format
+msgid "expression list treated as compound expression in initializer"
+msgstr ""
+
+#: cp/typeck.cc:8014
+#, gcc-internal-format
+msgid "expression list treated as compound expression in mem-initializer"
+msgstr ""
+
+#: cp/typeck.cc:8018
+#, gcc-internal-format
+msgid "expression list treated as compound expression in functional cast"
+msgstr ""
+
+#: cp/typeck.cc:8056
+#, gcc-internal-format, gfc-internal-format
+msgid "%s expression list treated as compound expression"
+msgstr ""
+
+#: cp/typeck.cc:8157
+#, gcc-internal-format
+msgid "no context to resolve type of %qE"
+msgstr ""
+
+#: cp/typeck.cc:8194
+#, gcc-internal-format
+msgid "cast from type %qT to type %qT casts away qualifiers"
+msgstr ""
+
+#: cp/typeck.cc:8200
+#, gcc-internal-format
+msgid "%<static_cast%> from type %qT to type %qT casts away qualifiers"
+msgstr ""
+
+#: cp/typeck.cc:8207
+#, gcc-internal-format
+msgid "%<reinterpret_cast%> from type %qT to type %qT casts away qualifiers"
+msgstr ""
+
+#: cp/typeck.cc:8233
+#, gcc-internal-format
+msgid "useless cast to type %q#T"
+msgstr ""
+
+#: cp/typeck.cc:8247
+#, gcc-internal-format
+msgid "type qualifiers ignored on cast result type"
+msgstr ""
+
+#: cp/typeck.cc:8695
+#, gcc-internal-format
+msgid "invalid %<static_cast%> from type %qT to type %qT"
+msgstr ""
+
+#: cp/typeck.cc:8701 cp/typeck.cc:8707 cp/typeck.cc:10418
+#, gcc-internal-format
+msgid "class type %qT is incomplete"
+msgstr ""
+
+#: cp/typeck.cc:8735
+msgid "converting from %qH to %qI"
+msgstr ""
+
+#: cp/typeck.cc:8810
+#, gcc-internal-format
+msgid "invalid cast of a prvalue expression of type %qT to type %qT"
+msgstr ""
+
+#: cp/typeck.cc:8880
+msgid "cast from %qH to %qI loses precision"
+msgstr ""
+
+#: cp/typeck.cc:8905
+msgid "cast between incompatible function types from %qH to %qI"
+msgstr ""
+
+#: cp/typeck.cc:8916
+msgid "cast between incompatible pointer to member types from %qH to %qI"
+msgstr ""
+
+#: cp/typeck.cc:8937 cp/typeck.cc:9127
+msgid "cast from %qH to %qI increases required alignment of target type"
+msgstr ""
+
+#: cp/typeck.cc:8954
+#, gcc-internal-format
+msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
+msgstr ""
+
+#: cp/typeck.cc:8968
+#, gcc-internal-format
+msgid "invalid cast from type %qT to type %qT"
+msgstr ""
+
+#: cp/typeck.cc:9041
+#, gcc-internal-format
+msgid "invalid use of %<const_cast%> with type %qT, which is not a pointer, reference, nor a pointer-to-data-member type"
+msgstr ""
+
+#: cp/typeck.cc:9050
+#, gcc-internal-format
+msgid "invalid use of %<const_cast%> with type %qT, which is a pointer or reference to a function type"
+msgstr ""
+
+#: cp/typeck.cc:9092
+#, gcc-internal-format
+msgid "invalid %<const_cast%> of an rvalue of type %qT to type %qT"
+msgstr ""
+
+#: cp/typeck.cc:9162
+#, gcc-internal-format
+msgid "invalid %<const_cast%> from type %qT to type %qT"
+msgstr ""
+
+#: cp/typeck.cc:9263 cp/typeck.cc:9272
+#, gcc-internal-format
+msgid "ISO C++ forbids casting to an array type %qT"
+msgstr ""
+
+#: cp/typeck.cc:9281
+#, gcc-internal-format
+msgid "invalid cast to function type %qT"
+msgstr ""
+
+#: cp/typeck.cc:9394
+#, gcc-internal-format
+msgid "moving %qE of type %qT to itself"
+msgstr ""
+
+#: cp/typeck.cc:9395 cp/typeck.cc:10947 cp/typeck.cc:10963 cp/typeck.cc:10988
+#: cp/typeck.cc:11025
+#, gcc-internal-format
+msgid "remove %<std::move%> call"
+msgstr ""
+
+#: cp/typeck.cc:9655
+#, gcc-internal-format
+msgid "  in evaluation of %<%Q(%#T, %#T)%>"
+msgstr ""
+
+#: cp/typeck.cc:9715
+#, gcc-internal-format
+msgid "assigning to an array from an initializer list"
+msgstr ""
+
+#: cp/typeck.cc:9742
+#, gcc-internal-format
+msgid "incompatible types in assignment of %qT to %qT"
+msgstr ""
+
+#: cp/typeck.cc:9758
+#, gcc-internal-format
+msgid "array used as initializer"
+msgstr ""
+
+#: cp/typeck.cc:9760
+#, gcc-internal-format
+msgid "invalid array assignment"
+msgstr ""
+
+#: cp/typeck.cc:9896
+#, gcc-internal-format
+msgid "   in pointer to member function conversion"
+msgstr ""
+
+#: cp/typeck.cc:9910
+#, gcc-internal-format
+msgid "pointer to member conversion via virtual base %qT"
+msgstr ""
+
+#: cp/typeck.cc:9957 cp/typeck.cc:9976
+#, gcc-internal-format
+msgid "   in pointer to member conversion"
+msgstr ""
+
+#: cp/typeck.cc:10057
+#, gcc-internal-format
+msgid "invalid conversion to type %qT from type %qT"
+msgstr ""
+
+#: cp/typeck.cc:10377
+msgid "cannot convert %qH to %qI in default argument"
+msgstr ""
+
+#: cp/typeck.cc:10382
+msgid "cannot convert %qH to %qI in argument passing"
+msgstr ""
+
+#: cp/typeck.cc:10391
+msgid "cannot convert %qH to %qI in initialization"
+msgstr ""
+
+#: cp/typeck.cc:10395
+msgid "cannot convert %qH to %qI in return"
+msgstr ""
+
+#: cp/typeck.cc:10400
+msgid "cannot convert %qH to %qI in assignment"
+msgstr ""
+
+#: cp/typeck.cc:10436
+#, gcc-internal-format
+msgid "parameter %qP of %qD might be a candidate for a format attribute"
+msgstr ""
+
+#: cp/typeck.cc:10440
+#, gcc-internal-format
+msgid "parameter might be a candidate for a format attribute"
+msgstr ""
+
+#: cp/typeck.cc:10445
+#, gcc-internal-format
+msgid "target of conversion might be a candidate for a format attribute"
+msgstr ""
+
+#: cp/typeck.cc:10450
+#, gcc-internal-format
+msgid "target of initialization might be a candidate for a format attribute"
+msgstr ""
+
+#: cp/typeck.cc:10460
+#, gcc-internal-format
+msgid "left-hand side of assignment might be a candidate for a format attribute"
+msgstr ""
+
+#: cp/typeck.cc:10546
+#, gcc-internal-format
+msgid "in passing argument %P of %qD"
+msgstr ""
+
+#: cp/typeck.cc:10630
+#, gcc-internal-format
+msgid "returning reference to temporary"
+msgstr ""
+
+#: cp/typeck.cc:10633
+#, gcc-internal-format
+msgid "returning pointer to temporary"
+msgstr ""
+
+#: cp/typeck.cc:10636
+#, gcc-internal-format
+msgid "returning temporary %<initializer_list%> does not extend the lifetime of the underlying array"
+msgstr ""
+
+#: cp/typeck.cc:10672
+#, gcc-internal-format
+msgid "reference to local variable %qD returned"
+msgstr ""
+
+#: cp/typeck.cc:10676
+#, gcc-internal-format
+msgid "returning local %<initializer_list%> variable %qD does not extend the lifetime of the underlying array"
+msgstr ""
+
+#: cp/typeck.cc:10682
+#, gcc-internal-format
+msgid "address of label %qD returned"
+msgstr ""
+
+#: cp/typeck.cc:10686
+#, gcc-internal-format
+msgid "address of local variable %qD returned"
+msgstr ""
+
+#: cp/typeck.cc:10946
+#, gcc-internal-format
+msgid "moving a temporary object prevents copy elision"
+msgstr ""
+
+#: cp/typeck.cc:10961
+#, gcc-internal-format
+msgid "moving a local object in a return statement prevents copy elision"
+msgstr ""
+
+#: cp/typeck.cc:10987 cp/typeck.cc:11022
+#, gcc-internal-format
+msgid "redundant move in return statement"
+msgstr ""
+
+#: cp/typeck.cc:11024
+#, gcc-internal-format
+msgid "redundant move in initialization"
+msgstr ""
+
+#: cp/typeck.cc:11062
+#, gcc-internal-format
+msgid "returning a value from a destructor"
+msgstr ""
+
+#. If a return statement appears in a handler of the
+#. function-try-block of a constructor, the program is ill-formed.
+#: cp/typeck.cc:11074
+#, gcc-internal-format
+msgid "cannot return from a handler of a function-try-block of a constructor"
+msgstr ""
+
+#. You can't return a value from a constructor.
+#: cp/typeck.cc:11077
+#, gcc-internal-format
+msgid "returning a value from a constructor"
+msgstr ""
+
+#. Give a helpful error message.
+#: cp/typeck.cc:11116 cp/typeck.cc:11162
+#, gcc-internal-format
+msgid "return-statement with no value, in function returning %qT"
+msgstr ""
+
+#: cp/typeck.cc:11124
+#, gcc-internal-format
+msgid "returning initializer list"
+msgstr ""
+
+#: cp/typeck.cc:11143
+#, gcc-internal-format
+msgid "inconsistent types %qT and %qT deduced for lambda return type"
+msgstr ""
+
+#: cp/typeck.cc:11146
+#, gcc-internal-format
+msgid "inconsistent deduction for auto return type: %qT and then %qT"
+msgstr ""
+
+#: cp/typeck.cc:11181
+#, gcc-internal-format
+msgid "return-statement with a value, in function returning %qT"
+msgstr ""
+
+#: cp/typeck.cc:11210
+#, gcc-internal-format
+msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or %<-fcheck-new%> is in effect)"
+msgstr ""
+
+#: cp/typeck.cc:11299
+#, gcc-internal-format
+msgid "not eliding copy on return from %qD"
+msgstr ""
+
+#: cp/typeck.cc:11311
+#, gcc-internal-format
+msgid "not eliding copy on return in %qD"
+msgstr ""
+
+#: cp/typeck.cc:11898
+#, gcc-internal-format
+msgid "using rvalue as lvalue"
+msgstr ""
+
+#: cp/typeck2.cc:51
+#, gcc-internal-format
+msgid "type %qT is not a base type for type %qT"
+msgstr ""
+
+#: cp/typeck2.cc:107
+#, gcc-internal-format
+msgid "assignment of constant field %qD"
+msgstr ""
+
+#: cp/typeck2.cc:108
+#, gcc-internal-format
+msgid "constant field %qD used as %<asm%> output"
+msgstr ""
+
+#: cp/typeck2.cc:109
+#, gcc-internal-format
+msgid "increment of constant field %qD"
+msgstr ""
+
+#: cp/typeck2.cc:110
+#, gcc-internal-format
+msgid "decrement of constant field %qD"
+msgstr ""
+
+#: cp/typeck2.cc:117
+#, gcc-internal-format
+msgid "assignment of read-only reference %qD"
+msgstr ""
+
+#: cp/typeck2.cc:118
+#, gcc-internal-format
+msgid "read-only reference %qD used as %<asm%> output"
+msgstr ""
+
+#: cp/typeck2.cc:119
+#, gcc-internal-format
+msgid "increment of read-only reference %qD"
+msgstr ""
+
+#: cp/typeck2.cc:120
+#, gcc-internal-format
+msgid "decrement of read-only reference %qD"
+msgstr ""
+
+#: cp/typeck2.cc:175
+#, gcc-internal-format
+msgid "cannot declare variable %q+D to be of abstract type %qT"
+msgstr ""
+
+#: cp/typeck2.cc:180
+#, gcc-internal-format
+msgid "cannot declare parameter %q+D to be of abstract type %qT"
+msgstr ""
+
+#: cp/typeck2.cc:183
+#, gcc-internal-format
+msgid "cannot declare parameter to be of abstract type %qT"
+msgstr ""
+
+#: cp/typeck2.cc:187
+#, gcc-internal-format
+msgid "cannot declare field %q+D to be of abstract type %qT"
+msgstr ""
+
+#: cp/typeck2.cc:191
+#, gcc-internal-format
+msgid "invalid abstract return type for member function %q+#D"
+msgstr ""
+
+#: cp/typeck2.cc:193
+#, gcc-internal-format
+msgid "invalid abstract return type for function %q+#D"
+msgstr ""
+
+#. Here we do not have location information.
+#: cp/typeck2.cc:196
+#, gcc-internal-format
+msgid "invalid abstract type %qT for %qE"
+msgstr ""
+
+#: cp/typeck2.cc:198
+#, gcc-internal-format
+msgid "invalid abstract type for %q+D"
+msgstr ""
+
+#: cp/typeck2.cc:203
+#, gcc-internal-format
+msgid "creating array of %qT, which is an abstract class type"
+msgstr ""
+
+#: cp/typeck2.cc:206
+#, gcc-internal-format
+msgid "invalid cast to abstract class type %qT"
+msgstr ""
+
+#: cp/typeck2.cc:209
+#, gcc-internal-format
+msgid "invalid new-expression of abstract class type %qT"
+msgstr ""
+
+#: cp/typeck2.cc:212
+#, gcc-internal-format
+msgid "invalid abstract return type %qT"
+msgstr ""
+
+#: cp/typeck2.cc:215
+#, gcc-internal-format
+msgid "invalid abstract parameter type %qT"
+msgstr ""
+
+#: cp/typeck2.cc:218
+#, gcc-internal-format
+msgid "expression of abstract class type %qT cannot be used in throw-expression"
+msgstr ""
+
+#: cp/typeck2.cc:222
+#, gcc-internal-format
+msgid "cannot declare %<catch%> parameter to be of abstract class type %qT"
+msgstr ""
+
+#: cp/typeck2.cc:226
+#, gcc-internal-format
+msgid "cannot allocate an object of abstract type %qT"
+msgstr ""
+
+#: cp/typeck2.cc:236
+#, gcc-internal-format
+msgid "  because the following virtual functions are pure within %qT:"
+msgstr ""
+
+#: cp/typeck2.cc:242
+#, gcc-internal-format
+msgid "    %#qD"
+msgstr ""
+
+#: cp/typeck2.cc:282
+#, gcc-internal-format
+msgid "definition of %q#T is not complete until the closing brace"
+msgstr ""
+
+#: cp/typeck2.cc:285
+#, gcc-internal-format
+msgid "forward declaration of %q#T"
+msgstr ""
+
+#: cp/typeck2.cc:287
+#, gcc-internal-format
+msgid "declaration of %q#T"
+msgstr ""
+
+#: cp/typeck2.cc:314
+#, gcc-internal-format
+msgid "%qD has incomplete type"
+msgstr ""
+
+#: cp/typeck2.cc:328
+#, gcc-internal-format
+msgid "invalid use of incomplete type %q#T"
+msgstr ""
+
+#: cp/typeck2.cc:364 rust/backend/rust-tree.cc:3936
+#, gcc-internal-format
+msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
+msgstr ""
+
+#: cp/typeck2.cc:369 rust/backend/rust-tree.cc:3942
+#, gcc-internal-format
+msgid "invalid use of member %qD (did you forget the %<&%> ?)"
+msgstr ""
+
+#: cp/typeck2.cc:379
+#, gcc-internal-format
+msgid "invalid use of placeholder %qT"
+msgstr ""
+
+#: cp/typeck2.cc:386
+#, gcc-internal-format
+msgid "invalid use of template type parameter %qT"
+msgstr ""
+
+#: cp/typeck2.cc:391
+#, gcc-internal-format
+msgid "invalid use of template template parameter %qT"
+msgstr ""
+
+#: cp/typeck2.cc:397
+#, gcc-internal-format
+msgid "invalid use of pack expansion %qT"
+msgstr ""
+
+#: cp/typeck2.cc:403
+#, gcc-internal-format
+msgid "invalid use of dependent type %qT"
+msgstr ""
+
+#: cp/typeck2.cc:410 rust/backend/rust-tree.cc:3952
+#, gcc-internal-format
+msgid "invalid use of brace-enclosed initializer list"
+msgstr ""
+
+#: cp/typeck2.cc:418 rust/backend/rust-tree.cc:3960
+#, gcc-internal-format
+msgid "address of overloaded function with no contextual type information"
+msgstr ""
+
+#: cp/typeck2.cc:422 rust/backend/rust-tree.cc:3965
+#, gcc-internal-format
+msgid "overloaded function with no contextual type information"
+msgstr ""
+
+#: cp/typeck2.cc:425 rust/backend/rust-tree.cc:3969
+#, gcc-internal-format
+msgid "insufficient contextual information to determine type"
+msgstr ""
+
+#: cp/typeck2.cc:838
+#, gcc-internal-format
+msgid "constructor syntax used, but no constructor declared for type %qT"
+msgstr ""
+
+#: cp/typeck2.cc:889 cp/typeck2.cc:906
+#, gcc-internal-format
+msgid "%<constinit%> variable %qD does not have a constant initializer"
+msgstr ""
+
+#: cp/typeck2.cc:1094
+msgid "narrowing conversion of %qE from %qH to %qI is ill-formed in C++11"
+msgstr ""
+
+#: cp/typeck2.cc:1106 cp/typeck2.cc:1118
+msgid "narrowing conversion of %qE from %qH to %qI"
+msgstr ""
+
+#: cp/typeck2.cc:1109
+#, gcc-internal-format
+msgid " the expression has a constant value but is not a C++ constant-expression"
+msgstr ""
+
+#: cp/typeck2.cc:1281
+#, gcc-internal-format
+msgid "initializer-string for %qT is too long"
+msgstr ""
+
+#: cp/typeck2.cc:1344
+#, gcc-internal-format
+msgid "initializing a base class of type %qT results in object slicing"
+msgstr ""
+
+#: cp/typeck2.cc:1346
+#, gcc-internal-format
+msgid "remove %<{ }%> around initializer"
+msgstr ""
+
+#: cp/typeck2.cc:1366
+#, gcc-internal-format
+msgid "cannot initialize aggregate of type %qT with a compound literal"
+msgstr ""
+
+#: cp/typeck2.cc:1826 cp/typeck2.cc:1857
+#, gcc-internal-format
+msgid "missing initializer for member %qD"
+msgstr ""
+
+#: cp/typeck2.cc:1833
+#, gcc-internal-format
+msgid "member %qD is uninitialized reference"
+msgstr ""
+
+#: cp/typeck2.cc:1840
+#, gcc-internal-format
+msgid "member %qD with uninitialized reference fields"
+msgstr ""
+
+#: cp/typeck2.cc:1926
+#, gcc-internal-format
+msgid "designator order for field %qD does not match declaration order in %qT"
+msgstr ""
+
+#: cp/typeck2.cc:1999
+#, gcc-internal-format
+msgid "no field %qD found in union being initialized"
+msgstr ""
+
+#: cp/typeck2.cc:2010
+#, gcc-internal-format
+msgid "index value instead of field name in union initializer"
+msgstr ""
+
+#: cp/typeck2.cc:2225
+#, gcc-internal-format
+msgid "circular pointer delegation detected"
+msgstr ""
+
+#: cp/typeck2.cc:2239
+#, gcc-internal-format
+msgid "base operand of %<->%> has non-pointer type %qT"
+msgstr ""
+
+#: cp/typeck2.cc:2269
+#, gcc-internal-format
+msgid "result of %<operator->()%> yields non-pointer result"
+msgstr ""
+
+#: cp/typeck2.cc:2271
+#, gcc-internal-format
+msgid "base operand of %<->%> is not a pointer"
+msgstr ""
+
+#: cp/typeck2.cc:2298
+#, gcc-internal-format
+msgid "%qE cannot be used as a member pointer, since it is of type %qT"
+msgstr ""
+
+#: cp/typeck2.cc:2307
+#, gcc-internal-format
+msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
+msgstr ""
+
+#: cp/typeck2.cc:2329
+#, gcc-internal-format
+msgid "pointer to member type %qT incompatible with object type %qT"
+msgstr ""
+
+#: cp/typeck2.cc:2391
+#, gcc-internal-format
+msgid "pointer-to-member-function type %qT requires an rvalue"
+msgstr ""
+
+#: cp/typeck2.cc:2402
+#, gcc-internal-format
+msgid "pointer-to-member-function type %qT requires an lvalue"
+msgstr ""
+
+#: cp/typeck2.cc:2410
+#, gcc-internal-format
+msgid "pointer-to-member-function type %qT requires an lvalue before C++20"
+msgstr ""
+
+#: cp/typeck2.cc:2451
+#, gcc-internal-format
+msgid "functional cast to array type %qT"
+msgstr ""
+
+#: cp/typeck2.cc:2468
+#, gcc-internal-format
+msgid "%<auto(x)%> cannot be constrained"
+msgstr ""
+
+#: cp/typeck2.cc:2473
+#, gcc-internal-format
+msgid "%<auto(x)%> only available with %<-std=c++2b%> or %<-std=gnu++2b%>"
+msgstr ""
+
+#: cp/typeck2.cc:2498
+#, gcc-internal-format
+msgid "invalid value-initialization of reference type"
+msgstr ""
+
+#: cp/typeck2.cc:2739
+#, gcc-internal-format
+msgid "call to function %qD which throws incomplete type %q#T"
+msgstr ""
+
+#: cp/typeck2.cc:2742
+#, gcc-internal-format
+msgid "call to function which throws incomplete type %q#T"
+msgstr ""
+
+#: cp/vtable-class-hierarchy.cc:706
+#, gcc-internal-format
+msgid "unable to open log file %<vtv_class_set_sizes.log%>: %m"
+msgstr ""
+
+#: cp/vtable-class-hierarchy.cc:846
+#, gcc-internal-format
+msgid "unable to open log file %<vtv_set_ptr_data.log%>: %m"
+msgstr ""
+
+#: cp/vtable-class-hierarchy.cc:1095
+#, gcc-internal-format
+msgid "unable to open log file %<vtv_count_data.log%>: %m"
+msgstr ""
+
+#: d/d-attribs.cc:375 d/d-attribs.cc:392
+#, gcc-internal-format
+msgid "unknown attribute %qs"
+msgstr ""
+
+#: d/d-attribs.cc:1153
+#, gcc-internal-format
+msgid "%q+D declared weak after being used"
+msgstr ""
+
+#: d/d-attribs.cc:1532
+#, gcc-internal-format
+msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<simd%> attribute"
+msgstr ""
+
+#: d/d-builtins.cc:824
+#, gcc-internal-format
+msgid "conflicting types for built-in function %qs; expected %qs"
+msgstr ""
+
+#: d/d-codegen.cc:331
+#, gcc-internal-format
+msgid "cannot determine the length of a %qs"
+msgstr ""
+
+#: d/d-codegen.cc:1242
+#, gcc-internal-format
+msgid "overlapping initializer for field %qT.%qD"
+msgstr ""
+
+#: d/d-codegen.cc:1437
+#, gcc-internal-format
+msgid "the address of %qD will never be %<null%>"
+msgstr ""
+
+#: d/d-codegen.cc:2222
+#, gcc-internal-format
+msgid "need %<this%> to access member %qE"
+msgstr ""
+
+#: d/d-codegen.cc:2370
+#, gcc-internal-format
+msgid "tried to perform floating-point modulo division on %qT"
+msgstr ""
+
+#: d/d-codegen.cc:2421
+#, gcc-internal-format
+msgid "cannot get frame pointer to %qs"
+msgstr ""
+
+#. Should instead error on line that references `fd'.
+#: d/d-codegen.cc:2447
+#, gcc-internal-format
+msgid "nested function missing body"
+msgstr ""
+
+#: d/d-codegen.cc:2489
+#, gcc-internal-format
+msgid "%qs is a nested function and cannot be accessed from %qs"
+msgstr ""
+
+#: d/d-codegen.cc:2798
+#, gcc-internal-format
+msgid "variable %qs has scoped destruction, cannot build closure"
+msgstr ""
+
+#: d/d-codegen.cc:2806
+#, gcc-internal-format
+msgid "explicit register variable %qs cannot be used in nested function"
+msgstr ""
+
+#: d/d-codegen.cc:3031
+#, gcc-internal-format
+msgid "forward reference to frame of %qs"
+msgstr ""
+
+#: d/d-convert.cc:378
+#, gcc-internal-format
+msgid "cannot convert a delegate expression to %qs"
+msgstr ""
+
+#: d/d-convert.cc:394
+#, gcc-internal-format
+msgid "cannot convert struct %qs to %qs"
+msgstr ""
+
+#. Casting from a C++ interface to a class/non-C++ interface
+#. always results in null as there is no run-time information,
+#. and no way one can derive from the other.
+#: d/d-convert.cc:441
+#, gcc-internal-format
+msgid "cast to %qs will produce null result"
+msgstr ""
+
+#: d/d-convert.cc:481
+#, gcc-internal-format
+msgid "cannot cast %qs to %qs since sizes do not line up"
+msgstr ""
+
+#: d/d-convert.cc:515
+#, gcc-internal-format
+msgid "cannot cast expression of type %qs to type %qs"
+msgstr ""
+
+#: d/d-convert.cc:562
+#, gcc-internal-format
+msgid "cannot cast expression of type %qs to %qs"
+msgstr ""
+
+#: d/d-convert.cc:609
+#, gcc-internal-format
+msgid "cast from %qs to %qs will produce zero result"
+msgstr ""
+
+#: d/d-convert.cc:748
+#, gcc-internal-format
+msgid "cannot convert parameter %qs from type %qs to type %qs in assignment"
+msgstr ""
+
+#: d/d-convert.cc:754
+#, gcc-internal-format
+msgid "cannot convert parameter %qs from type %qs to type %qs in argument passing"
+msgstr ""
+
+#: d/d-convert.cc:759
+#, gcc-internal-format
+msgid "parameters of type %<va_list%> {aka %qs} are decayed to pointer types, and require %<va_copy%> to be converted back into a static array type"
+msgstr ""
+
+#: d/d-lang.cc:463
+#, gcc-internal-format
+msgid "bad argument for %<-fdebug%>: %qs"
+msgstr ""
+
+#: d/d-lang.cc:517
+#, gcc-internal-format
+msgid "bad argument for %<-fextern-std%>: %qs"
+msgstr ""
+
+#: d/d-lang.cc:536
+#, gcc-internal-format
+msgid "bad argument for %<-fmodule-file%>: %qs"
+msgstr ""
+
+#: d/d-lang.cc:698
+#, gcc-internal-format
+msgid "bad argument for %<-fversion%>: %qs"
+msgstr ""
+
+#: d/d-lang.cc:968
+#, gcc-internal-format
+msgid "unable to open %s for writing: %m"
+msgstr ""
+
+#: d/d-lang.cc:975
+#, gcc-internal-format
+msgid "writing output file %s: %m"
+msgstr ""
+
+#: d/d-lang.cc:995
+#, gcc-internal-format
+msgid "unable to open %s for reading: %m"
+msgstr ""
+
+#: d/d-lang.cc:1020
+#, gcc-internal-format
+msgid "reading ddoc file %s: %m"
+msgstr ""
+
+#: d/d-lang.cc:1079
+#, gcc-internal-format
+msgid "%<-fonly=%> argument is different from first input file name"
+msgstr ""
+
+#: d/d-lang.cc:1262
+#, gcc-internal-format
+msgid "unable to resolve forward reference in definition"
+msgstr ""
+
+#: d/d-target.cc:156
+#, gcc-internal-format
+msgid "D does not support pointers on this target."
+msgstr ""
+
+#: d/d-target.cc:252
+#, gcc-internal-format
+msgid "cannot represent built-in %<va_list%> type in D"
+msgstr ""
+
+#: d/decl.cc:373
+#, gcc-internal-format, gfc-internal-format
+msgid "pragma(%s) not implemented"
+msgstr ""
+
+#: d/decl.cc:480 d/decl.cc:598 d/decl.cc:672 d/decl.cc:715 d/decl.cc:754
+#, gcc-internal-format
+msgid "had semantic errors when compiling"
+msgstr ""
+
+#. Hiding detected; same name, overlapping specializations.
+#: d/decl.cc:571
+#, gcc-internal-format
+msgid "use of %qs"
+msgstr ""
+
+#: d/decl.cc:573
+#, gcc-internal-format
+msgid "is hidden by %qs"
+msgstr ""
+
+#: d/decl.cc:576
+#, gcc-internal-format
+msgid "use %<alias %s = %s.%s;%> to introduce base class overload set"
+msgstr ""
+
+#: d/decl.cc:812
+#, gcc-internal-format
+msgid "size is too large"
+msgstr ""
+
+#: d/decl.cc:1424
+#, gcc-internal-format
+msgid "function requires a dual-context, which is not yet supported by GDC"
+msgstr ""
+
+#: d/decl.cc:1601
+#, gcc-internal-format
+msgid "explicit register variable %qs declared %<extern%>"
+msgstr ""
+
+#: d/decl.cc:1604
+#, gcc-internal-format
+msgid "explicit register variable %qs declared thread local"
+msgstr ""
+
+#: d/decl.cc:1817
+#, gcc-internal-format
+msgid "mismatch between declaration %qE size (%wd) and its initializer size (%wd)"
+msgstr ""
+
+#: d/expr.cc:569
+#, gcc-internal-format
+msgid "cannot handle comparison of type %<%s == %s%>"
+msgstr ""
+
+#: d/expr.cc:717
+#, gcc-internal-format
+msgid "array concatenation of expression %qs requires the GC and cannot be used with %<-fno-druntime%>"
+msgstr ""
+
+#: d/expr.cc:811
+#, gcc-internal-format
+msgid "appending to array in %qs requires the GC and cannot be used with %<-fno-druntime%>"
+msgstr ""
+
+#. Static arrays have already been handled by the front-end.
+#: d/expr.cc:1286
+#, gcc-internal-format
+msgid "unexpected type for array length: %qs"
+msgstr ""
+
+#: d/expr.cc:1421
+#, gcc-internal-format
+msgid "don%'t know how to delete %qs"
+msgstr ""
+
+#: d/expr.cc:1445
+#, gcc-internal-format
+msgid "%qs is not an associative array"
+msgstr ""
+
+#: d/expr.cc:1729 d/expr.cc:2109
+#, gcc-internal-format
+msgid "need %<this%> to access member %qs"
+msgstr ""
+
+#: d/expr.cc:1811
+#, gcc-internal-format
+msgid "delegates are only for non-static functions"
+msgstr ""
+
+#: d/expr.cc:1883
+#, gcc-internal-format
+msgid "%qs is not a field, but a %qs"
+msgstr ""
+
+#: d/expr.cc:2135
+#, gcc-internal-format
+msgid "recursive reference %qs"
+msgstr ""
+
+#: d/expr.cc:2155 d/expr.cc:3027
+#, gcc-internal-format
+msgid "non-constant expression %qs"
+msgstr ""
+
+#: d/expr.cc:2994
+#, gcc-internal-format
+msgid "%qs is not an expression"
+msgstr ""
+
+#: d/expr.cc:3001
+#, gcc-internal-format
+msgid "type %qs is not an expression"
+msgstr ""
+
+#: d/intrinsics.cc:221
+#, gcc-internal-format
+msgid "mismatch in return type of intrinsic function %qD (%qT, should be %qs)"
+msgstr ""
+
+#: d/intrinsics.cc:235
+#, gcc-internal-format
+msgid "mismatch in argument %u type of intrinsic function %qD (%qT, should be %qs)"
+msgstr ""
+
+#: d/intrinsics.cc:247 d/intrinsics.cc:252
+#, gcc-internal-format
+msgid "mismatch in argument %u type of intrinsic function %qD (%qT, should be %qT)"
+msgstr ""
+
+#: d/intrinsics.cc:437
+#, gcc-internal-format
+msgid "argument %qE cannot be read at compile time"
+msgstr ""
+
+#: d/intrinsics.cc:446
+#, gcc-internal-format
+msgid "element index %qE is out of bounds %<[0 .. %E]%>"
+msgstr ""
+
+#: d/intrinsics.cc:493
+#, gcc-internal-format
+msgid "mismatch in call of intrinsic function %qD"
+msgstr ""
+
+#. It's a D language intrinsic with no library implementation.
+#: d/intrinsics.cc:1479
+#, gcc-internal-format
+msgid "intrinsic function %qE must be directly called"
+msgstr ""
+
+#: d/modules.cc:417
+#, gcc-internal-format
+msgid "%<-fmoduleinfo%> is not supported on this target"
+msgstr ""
+
+#: d/toir.cc:245
+#, gcc-internal-format
+msgid "calling %qE without side effects discards return value of type %qT; prepend a %<cast(void)%> if intentional"
+msgstr ""
+
+#: d/toir.cc:419 d/toir.cc:444
+#, gcc-internal-format
+msgid "cannot %<goto%> into %<try%> block"
+msgstr ""
+
+#: d/toir.cc:422 d/toir.cc:446
+#, gcc-internal-format
+msgid "cannot %<goto%> into %<catch%> block"
+msgstr ""
+
+#: d/toir.cc:461
+#, gcc-internal-format, gfc-internal-format
+msgid "label %s referenced outside of any function"
+msgstr ""
+
+#: d/toir.cc:836
+#, gcc-internal-format, gfc-internal-format
+msgid "cannot handle switch condition of type %s"
+msgstr ""
+
+#: d/toir.cc:1213
+#, gcc-internal-format
+msgid "exception handling disabled; use %<-fexceptions%> to enable"
+msgstr ""
+
+#: d/toir.cc:1220
+#, gcc-internal-format
+msgid "cannot throw C++ classes"
+msgstr ""
+
+#: d/toir.cc:1222
+#, gcc-internal-format
+msgid "cannot throw COM objects"
+msgstr ""
+
+#: d/toir.cc:1355
+#, gcc-internal-format
+msgid "D inline assembler statements are not supported in GDC."
+msgstr ""
+
+#: d/typeinfo.cc:1424
+#, gcc-internal-format
+msgid "expression %qs requires %<object.TypeInfo%> and cannot be used with %<-fno-rtti%>"
+msgstr ""
+
+#: d/typeinfo.cc:1428
+#, gcc-internal-format
+msgid "%<object.TypeInfo%> cannot be used with %<-fno-rtti%>"
+msgstr ""
+
+#: d/typeinfo.cc:1443
+#, gcc-internal-format
+msgid "%<object.TypeInfo%> could not be found, but is implicitly used"
+msgstr ""
+
+#: d/types.cc:161
+#, gcc-internal-format
+msgid "missing or corrupt object.d"
+msgstr ""
+
+#: d/types.cc:902
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid expression for static array dimension: %s"
+msgstr ""
+
+#: d/types.cc:1110
+#, gcc-internal-format
+msgid "size of %qs (%wd) differ from its declared size (%wd)"
+msgstr ""
+
+#: fortran/arith.cc:47
+#, gcc-internal-format, gfc-internal-format
+msgid "Conversion of an Infinity or Not-a-Number at %L to INTEGER"
+msgstr ""
+
+#: fortran/arith.cc:97
+#, gcc-internal-format, gfc-internal-format
+msgid "Arithmetic OK at %L"
+msgstr ""
+
+#: fortran/arith.cc:100
+#, gcc-internal-format, gfc-internal-format
+msgid "Arithmetic overflow at %L"
+msgstr ""
+
+#: fortran/arith.cc:103
+#, gcc-internal-format, gfc-internal-format
+msgid "Arithmetic underflow at %L"
+msgstr ""
+
+#: fortran/arith.cc:106
+#, gcc-internal-format, gfc-internal-format
+msgid "Arithmetic NaN at %L"
+msgstr ""
+
+#: fortran/arith.cc:109
+#, gcc-internal-format, gfc-internal-format
+msgid "Division by zero at %L"
+msgstr ""
+
+#: fortran/arith.cc:112
+#, gcc-internal-format, gfc-internal-format
+msgid "Array operands are incommensurate at %L"
+msgstr ""
+
+#: fortran/arith.cc:115
+#, gcc-internal-format, gfc-internal-format
+msgid "Integer outside symmetric range implied by Standard Fortran at %L"
+msgstr ""
+
+#: fortran/arith.cc:119
+#, gcc-internal-format, gfc-internal-format
+msgid "Illegal type in character concatenation at %L"
+msgstr ""
+
+#: fortran/arith.cc:122
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid type in arithmetic operation at %L"
+msgstr ""
+
+#: fortran/arith.cc:126 fortran/arith.cc:2130
+#, gcc-internal-format
+msgid "gfc_arith_error(): Bad error code"
+msgstr ""
+
+#: fortran/arith.cc:183
+#, gcc-internal-format
+msgid "Fix min_int calculation"
+msgstr ""
+
+#: fortran/arith.cc:578
+#, gcc-internal-format
+msgid "gfc_range_check(): Bad type"
+msgstr ""
+
+#: fortran/arith.cc:651
+#, gcc-internal-format
+msgid "gfc_arith_uminus(): Bad basic type"
+msgstr ""
+
+#: fortran/arith.cc:688
+#, gcc-internal-format
+msgid "gfc_arith_plus(): Bad basic type"
+msgstr ""
+
+#: fortran/arith.cc:725
+#, gcc-internal-format
+msgid "gfc_arith_minus(): Bad basic type"
+msgstr ""
+
+#: fortran/arith.cc:763
+#, gcc-internal-format
+msgid "gfc_arith_times(): Bad basic type"
+msgstr ""
+
+#: fortran/arith.cc:805
+#, gcc-internal-format
+msgid "Integer division truncated to constant %qs at %L"
+msgstr ""
+
+#: fortran/arith.cc:854
+#, gcc-internal-format
+msgid "gfc_arith_divide(): Bad basic type"
+msgstr ""
+
+#: fortran/arith.cc:910
+#, gcc-internal-format
+msgid "arith_power(): Bad base"
+msgstr ""
+
+#: fortran/arith.cc:949
+#, gcc-internal-format, gfc-internal-format
+msgid "Negative exponent of integer has zero result at %L"
+msgstr ""
+
+#: fortran/arith.cc:969
+#, gcc-internal-format, gfc-internal-format
+msgid "Result of exponentiation at %L exceeds the range of %s"
+msgstr ""
+
+#: fortran/arith.cc:1006 fortran/arith.cc:1031
+#, gcc-internal-format, gfc-internal-format
+msgid "Noninteger exponent in an initialization expression at %L"
+msgstr ""
+
+#: fortran/arith.cc:1017
+#, gcc-internal-format, gfc-internal-format
+msgid "Raising a negative REAL at %L to a REAL power is prohibited"
+msgstr ""
+
+#: fortran/arith.cc:1045
+#, gcc-internal-format
+msgid "arith_power(): unknown type"
+msgstr ""
+
+#: fortran/arith.cc:1116
+#, gcc-internal-format
+msgid "compare_real(): Bad operator"
+msgstr ""
+
+#: fortran/arith.cc:1156
+#, gcc-internal-format
+msgid "gfc_compare_expr(): Bad basic type"
+msgstr ""
+
+#: fortran/arith.cc:1777
+#, gcc-internal-format
+msgid "eval_intrinsic(): Bad operator"
+msgstr ""
+
+#: fortran/arith.cc:1836
+#, gcc-internal-format
+msgid "eval_type_intrinsic0(): op NULL"
+msgstr ""
+
+#: fortran/arith.cc:2098
+#, gcc-internal-format, gfc-internal-format
+msgid "Arithmetic OK converting %s to %s at %L"
+msgstr ""
+
+#: fortran/arith.cc:2102
+#, gcc-internal-format
+msgid "Arithmetic overflow converting %s to %s at %L. This check can be disabled with the option %<-fno-range-check%>"
+msgstr ""
+
+#: fortran/arith.cc:2107
+#, gcc-internal-format
+msgid "Arithmetic underflow converting %s to %s at %L. This check can be disabled with the option %<-fno-range-check%>"
+msgstr ""
+
+#: fortran/arith.cc:2112
+#, gcc-internal-format
+msgid "Arithmetic NaN converting %s to %s at %L. This check can be disabled with the option %<-fno-range-check%>"
+msgstr ""
+
+#: fortran/arith.cc:2117
+#, gcc-internal-format, gfc-internal-format
+msgid "Division by zero converting %s to %s at %L"
+msgstr ""
+
+#: fortran/arith.cc:2121
+#, gcc-internal-format, gfc-internal-format
+msgid "Array operands are incommensurate converting %s to %s at %L"
+msgstr ""
+
+#: fortran/arith.cc:2125
+#, gcc-internal-format, gfc-internal-format
+msgid "Integer outside symmetric range implied by Standard Fortran converting %s to %s at %L"
+msgstr ""
+
+#: fortran/arith.cc:2215 fortran/arith.cc:2334 fortran/arith.cc:2397
+#: fortran/arith.cc:2452 fortran/arith.cc:2515 fortran/arith.cc:2587
+#: fortran/arith.cc:2657
+#, gcc-internal-format
+msgid "Conversion from %qs to %qs at %L"
+msgstr ""
+
+#: fortran/arith.cc:2247 fortran/arith.cc:2283 fortran/arith.cc:2325
+#: fortran/arith.cc:2387 fortran/arith.cc:2442 fortran/arith.cc:2505
+#: fortran/arith.cc:2577 fortran/arith.cc:2649
+#, gcc-internal-format
+msgid "Change of value in conversion from %qs to %qs at %L"
+msgstr ""
+
+#: fortran/arith.cc:2491 fortran/arith.cc:2563
+#, gcc-internal-format
+msgid "Non-zero imaginary part discarded in conversion from %qs to %qs at %L"
+msgstr ""
+
+#: fortran/arith.cc:2742
+#, gcc-internal-format
+msgid "The Hollerith constant at %L is truncated in conversion to %qs"
+msgstr ""
+
+#: fortran/arith.cc:2771
+#, gcc-internal-format, gfc-internal-format
+msgid "The character constant at %L is truncated in conversion to %s"
+msgstr ""
+
+#: fortran/array.cc:98 fortran/array.cc:130 fortran/array.cc:158
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid BOZ literal constant used in subscript at %C"
+msgstr ""
+
+#: fortran/array.cc:103
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected array subscript at %C"
+msgstr ""
+
+#: fortran/array.cc:112
+#, gcc-internal-format
+msgid "Unexpected %<*%> in coarray subscript at %C"
+msgstr ""
+
+#: fortran/array.cc:139
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing lower bound in assumed size coarray specification at %C"
+msgstr ""
+
+#: fortran/array.cc:149
+#, gcc-internal-format, gfc-internal-format
+msgid "Strides not allowed in coarray subscript at %C"
+msgstr ""
+
+#: fortran/array.cc:163
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected array subscript stride at %C"
+msgstr ""
+
+#: fortran/array.cc:223
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid form of array reference at %C"
+msgstr ""
+
+#: fortran/array.cc:230
+#, gcc-internal-format, gfc-internal-format
+msgid "Array reference at %C has more than 7 dimensions"
+msgstr ""
+
+#: fortran/array.cc:233 fortran/array.cc:334
+#, gcc-internal-format, gfc-internal-format
+msgid "Array reference at %C cannot have more than %d dimensions"
+msgstr ""
+
+#: fortran/array.cc:248 fortran/array.cc:716 fortran/check.cc:3445
+#: fortran/check.cc:5976 fortran/check.cc:6021 fortran/check.cc:6063
+#: fortran/check.cc:6090 fortran/check.cc:6353 fortran/match.cc:1854
+#: fortran/match.cc:3316 fortran/match.cc:3658 fortran/match.cc:3854
+#: fortran/simplify.cc:3026 fortran/simplify.cc:3056 fortran/simplify.cc:6409
+#: fortran/simplify.cc:8450
+#, gcc-internal-format
+msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
+msgstr ""
+
+#: fortran/array.cc:254
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected coarray designator at %C"
+msgstr ""
+
+#: fortran/array.cc:276
+#, gcc-internal-format, gfc-internal-format
+msgid "TEAM= attribute in %C misplaced"
+msgstr ""
+
+#: fortran/array.cc:288
+#, gcc-internal-format, gfc-internal-format
+msgid "STAT= attribute in %C misplaced"
+msgstr ""
+
+#: fortran/array.cc:297
+#, gcc-internal-format, gfc-internal-format
+msgid "Too few codimensions at %C, expected %d not %d"
+msgstr ""
+
+#: fortran/array.cc:303
+#, gcc-internal-format, gfc-internal-format
+msgid "Too many codimensions at %C, expected %d not %d"
+msgstr ""
+
+#: fortran/array.cc:313 fortran/array.cc:321
+#, gcc-internal-format
+msgid "Unexpected %<*%> for codimension %d of %d at %C"
+msgstr ""
+
+#: fortran/array.cc:316
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid form of coarray reference at %C"
+msgstr ""
+
+#: fortran/array.cc:328
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid codimension %d at %C, only %d codimensions exist"
+msgstr ""
+
+#: fortran/array.cc:392
+#, gcc-internal-format
+msgid "Variable %qs at %L in this context must be constant"
+msgstr ""
+
+#: fortran/array.cc:395
+#, gcc-internal-format, gfc-internal-format
+msgid "Expression at %L in this context must be constant"
+msgstr ""
+
+#. F2018:R821: "assumed-implied-spec  is  [ lower-bound : ] *".
+#: fortran/array.cc:497
+#, gcc-internal-format, gfc-internal-format
+msgid "A lower bound must precede colon in assumed-size array specification at %L"
+msgstr ""
+
+#: fortran/array.cc:509
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected expression in array specification at %C"
+msgstr ""
+
+#: fortran/array.cc:522 fortran/array.cc:554
+#, gcc-internal-format, gfc-internal-format
+msgid "Expecting a scalar INTEGER expression at %C, found %s"
+msgstr ""
+
+#: fortran/array.cc:591
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-rank array at %C"
+msgstr ""
+
+#: fortran/array.cc:625
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad array specification for implied-shape array at %C"
+msgstr ""
+
+#: fortran/array.cc:641 fortran/array.cc:754
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad array specification for an explicitly shaped array at %C"
+msgstr ""
+
+#: fortran/array.cc:651 fortran/array.cc:764
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad array specification for assumed shape array at %C"
+msgstr ""
+
+#: fortran/array.cc:665 fortran/array.cc:778
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad specification for deferred shape array at %C"
+msgstr ""
+
+#: fortran/array.cc:675 fortran/array.cc:782
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad specification for assumed size array at %C"
+msgstr ""
+
+#: fortran/array.cc:687 fortran/array.cc:794
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected another dimension in array declaration at %C"
+msgstr ""
+
+#: fortran/array.cc:693 fortran/array.cc:722 fortran/array.cc:800
+#, gcc-internal-format, gfc-internal-format
+msgid "Array specification at %C has more than %d dimensions"
+msgstr ""
+
+#: fortran/array.cc:699
+#, gcc-internal-format, gfc-internal-format
+msgid "Array specification at %C with more than 7 dimensions"
+msgstr ""
+
+#: fortran/array.cc:711
+#, gcc-internal-format, gfc-internal-format
+msgid "Coarray declaration at %C"
+msgstr ""
+
+#: fortran/array.cc:808
+#, gcc-internal-format
+msgid "Upper bound of last coarray dimension must be %<*%> at %C"
+msgstr ""
+
+#: fortran/array.cc:882
+#, gcc-internal-format
+msgid "The assumed-rank array %qs at %L shall not have a codimension"
+msgstr ""
+
+#: fortran/array.cc:938
+#, gcc-internal-format
+msgid "rank + corank of %qs exceeds %d at %C"
+msgstr ""
+
+#: fortran/array.cc:1061
+#, gcc-internal-format
+msgid "DO-iterator %qs at %L is inside iterator of the same name"
+msgstr ""
+
+#: fortran/array.cc:1153 fortran/array.cc:1381
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in array constructor at %C"
+msgstr ""
+
+#: fortran/array.cc:1183
+#, gcc-internal-format, gfc-internal-format
+msgid "BOZ literal constant at %L cannot appear in an array constructor"
+msgstr ""
+
+#: fortran/array.cc:1192
+#, gcc-internal-format, gfc-internal-format
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr ""
+
+#: fortran/array.cc:1254
+#, gcc-internal-format, gfc-internal-format
+msgid "[...] style array constructors at %C"
+msgstr ""
+
+#: fortran/array.cc:1274
+#, gcc-internal-format, gfc-internal-format
+msgid "Array constructor including type specification at %C"
+msgstr ""
+
+#: fortran/array.cc:1280 fortran/match.cc:4290
+#, gcc-internal-format, gfc-internal-format
+msgid "Type-spec at %L cannot contain a deferred type parameter"
+msgstr ""
+
+#: fortran/array.cc:1288
+#, gcc-internal-format, gfc-internal-format
+msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
+msgstr ""
+
+#: fortran/array.cc:1306
+#, gcc-internal-format, gfc-internal-format
+msgid "Empty array constructor at %C is not allowed"
+msgstr ""
+
+#: fortran/array.cc:1343 fortran/array.cc:1353
+#, gcc-internal-format, gfc-internal-format
+msgid "Incompatible typespec for array element at %L"
+msgstr ""
+
+#: fortran/array.cc:1428
+#, gcc-internal-format, gfc-internal-format
+msgid "Element in %s array constructor at %L is %s"
+msgstr ""
+
+#: fortran/array.cc:1759
+#, gcc-internal-format, gfc-internal-format
+msgid "Iterator step at %L cannot be zero"
+msgstr ""
+
+#: fortran/array.cc:1918
+#, gcc-internal-format
+msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
+msgstr ""
+
+#: fortran/array.cc:2097
+#, gcc-internal-format, gfc-internal-format
+msgid "AC-IMPLIED-DO initial expression references control variable at %L"
+msgstr ""
+
+#: fortran/array.cc:2104
+#, gcc-internal-format, gfc-internal-format
+msgid "AC-IMPLIED-DO final expression references control variable at %L"
+msgstr ""
+
+#: fortran/array.cc:2111
+#, gcc-internal-format, gfc-internal-format
+msgid "AC-IMPLIED-DO step expression references control variable at %L"
+msgstr ""
+
+#: fortran/array.cc:2123
+#, gcc-internal-format, gfc-internal-format
+msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
+msgstr ""
+
+#: fortran/array.cc:2215
+#, gcc-internal-format
+msgid "Different CHARACTER lengths (%wd/%wd) in array constructor at %L"
+msgstr ""
+
+#: fortran/array.cc:2333
+#, gcc-internal-format
+msgid "spec_dimen_size(): Bad dimension"
+msgstr ""
+
+#: fortran/array.cc:2399
+#, gcc-internal-format
+msgid "gfc_ref_dimen_size(): Bad dimension"
+msgstr ""
+
+#: fortran/array.cc:2403
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad array dimension at %L"
+msgstr ""
+
+#: fortran/array.cc:2541
+#, gcc-internal-format
+msgid "gfc_ref_dimen_size(): Bad dimen_type"
+msgstr ""
+
+#: fortran/array.cc:2592
+#, gcc-internal-format
+msgid "gfc_array_dimen_size(): Bad dimension"
+msgstr ""
+
+#: fortran/array.cc:2644
+#, gcc-internal-format
+msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
+msgstr ""
+
+#: fortran/array.cc:2792
+#, gcc-internal-format
+msgid "gfc_find_array_ref(): No ref found"
+msgstr ""
+
+#. if (c == 0)
+#: fortran/bbt.cc:119
+#, gcc-internal-format
+msgid "insert_bbt(): Duplicate key found"
+msgstr ""
+
+#: fortran/check.cc:87
+#, gcc-internal-format
+msgid "BOZ literal constant at %L cannot be an actual argument to %qs"
+msgstr ""
+
+#: fortran/check.cc:103
+#, gcc-internal-format
+msgid "Arguments of %qs at %L and %L cannot both be BOZ literal constants"
+msgstr ""
+
+#: fortran/check.cc:123 fortran/resolve.cc:11545
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid use of BOZ literal constant at %L"
+msgstr ""
+
+#: fortran/check.cc:371
+#, gcc-internal-format, gfc-internal-format
+msgid "Failure in conversion of BOZ to REAL at %L"
+msgstr ""
+
+#: fortran/check.cc:477
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a scalar"
+msgstr ""
+
+#: fortran/check.cc:493
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be %s"
+msgstr ""
+
+#: fortran/check.cc:527
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must have a numeric type"
+msgstr ""
+
+#: fortran/check.cc:542 fortran/check.cc:572
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL"
+msgstr ""
+
+#: fortran/check.cc:560
+#, gcc-internal-format
+msgid "Fortran 2003: Character for %qs argument of %qs intrinsic at %L"
+msgstr ""
+
+#: fortran/check.cc:567
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
+msgstr ""
+
+#: fortran/check.cc:590 fortran/check.cc:3400
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
+msgstr ""
+
+#: fortran/check.cc:605
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be REAL or COMPLEX"
+msgstr ""
+
+#: fortran/check.cc:622
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
+msgstr ""
+
+#: fortran/check.cc:651 fortran/check.cc:7632
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a constant"
+msgstr ""
+
+#: fortran/check.cc:660
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid kind for %s at %L"
+msgstr ""
+
+#: fortran/check.cc:679
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be double precision"
+msgstr ""
+
+#: fortran/check.cc:702
+#, gcc-internal-format
+msgid "Expected coarray variable as %qs argument to the %s intrinsic at %L"
+msgstr ""
+
+#: fortran/check.cc:719
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a logical array"
+msgstr ""
+
+#: fortran/check.cc:744
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be an array"
+msgstr ""
+
+#: fortran/check.cc:765
+#, gcc-internal-format
+msgid "%qs at %L must be nonnegative"
+msgstr ""
+
+#: fortran/check.cc:786
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be positive"
+msgstr ""
+
+#: fortran/check.cc:819
+#, gcc-internal-format
+msgid "The absolute value of SHIFT at %L must be less than or equal to BIT_SIZE(%qs)"
+msgstr ""
+
+#: fortran/check.cc:830
+#, gcc-internal-format
+msgid "%qs at %L must be less than or equal to BIT_SIZE(%qs)"
+msgstr ""
+
+#: fortran/check.cc:840
+#, gcc-internal-format
+msgid "%qs at %L must be less than BIT_SIZE(%qs)"
+msgstr ""
+
+#: fortran/check.cc:867
+#, gcc-internal-format
+msgid "%qs at %L must be less than or equal to the BIT_SIZE of INTEGER(KIND=%d)"
+msgstr ""
+
+#: fortran/check.cc:893
+#, gcc-internal-format
+msgid "%<%s + %s%> at %L must be less than or equal to BIT_SIZE(%qs)"
+msgstr ""
+
+#: fortran/check.cc:926
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be the same type and kind as %qs"
+msgstr ""
+
+#: fortran/check.cc:943
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be of rank %d"
+msgstr ""
+
+#: fortran/check.cc:958
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must not be OPTIONAL"
+msgstr ""
+
+#: fortran/check.cc:980
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be ALLOCATABLE"
+msgstr ""
+
+#: fortran/check.cc:998
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be of kind %d"
+msgstr ""
+
+#: fortran/check.cc:1017
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L cannot be INTENT(IN)"
+msgstr ""
+
+#: fortran/check.cc:1044
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a variable"
+msgstr ""
+
+#: fortran/check.cc:1093
+#, gcc-internal-format
+msgid "%<dim%> argument of %qs intrinsic at %L is not a valid codimension index"
+msgstr ""
+
+#: fortran/check.cc:1145
+#, gcc-internal-format
+msgid "%<dim%> argument of %qs intrinsic at %L is not a valid dimension index"
+msgstr ""
+
+#: fortran/check.cc:1248
+#, gcc-internal-format, gfc-internal-format
+msgid "Unequal character lengths (%ld/%ld) in %s at %L"
+msgstr ""
+
+#: fortran/check.cc:1269
+#, gcc-internal-format
+msgid "Size of %qs argument of %qs intrinsic at %L too small (%wd/%ld)"
+msgstr ""
+
+#: fortran/check.cc:1332
+#, gcc-internal-format, gfc-internal-format
+msgid "BOZ literal constant at %L cannot appear in ACHAR intrinsic subprogram"
+msgstr ""
+
+#: fortran/check.cc:1423
+#, gcc-internal-format
+msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
+msgstr ""
+
+#: fortran/check.cc:1432 fortran/check.cc:3717
+#, gcc-internal-format, gfc-internal-format
+msgid "Different type kinds at %L"
+msgstr ""
+
+#: fortran/check.cc:1455
+#, gcc-internal-format
+msgid "NULL at %L is not permitted as actual argument to %qs intrinsic function"
+msgstr ""
+
+#: fortran/check.cc:1477
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
+msgstr ""
+
+#: fortran/check.cc:1486 fortran/check.cc:1521 fortran/check.cc:4412
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
+msgstr ""
+
+#: fortran/check.cc:1503
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
+msgstr ""
+
+#: fortran/check.cc:1512
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
+msgstr ""
+
+#: fortran/check.cc:1539
+#, gcc-internal-format, gfc-internal-format
+msgid "Array section with a vector subscript at %L shall not be the target of a pointer"
+msgstr ""
+
+#: fortran/check.cc:1586
+#, gcc-internal-format, gfc-internal-format
+msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
+msgstr ""
+
+#: fortran/check.cc:1594
+#, gcc-internal-format, gfc-internal-format
+msgid "ATOM argument at %L of the %s intrinsic function shall be a coarray or coindexed"
+msgstr ""
+
+#: fortran/check.cc:1601
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
+msgstr ""
+
+#: fortran/check.cc:1619 fortran/check.cc:1832
+#, gcc-internal-format, gfc-internal-format
+msgid "STAT= argument to %s at %L"
+msgstr ""
+
+#: fortran/check.cc:1638 fortran/check.cc:1772 fortran/check.cc:1869
+#, gcc-internal-format, gfc-internal-format
+msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
+msgstr ""
+
+#: fortran/check.cc:1652 fortran/check.cc:1852
+#, gcc-internal-format, gfc-internal-format
+msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
+msgstr ""
+
+#: fortran/check.cc:1672
+#, gcc-internal-format, gfc-internal-format
+msgid "VALUE argument of the %s intrinsic function at %L shall be definable"
+msgstr ""
+
+#: fortran/check.cc:1691 fortran/check.cc:1705 fortran/check.cc:1740
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L not yet supported"
+msgstr ""
+
+#: fortran/check.cc:1725
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
+msgstr ""
+
+#: fortran/check.cc:1779 fortran/check.cc:1876
+#, gcc-internal-format, gfc-internal-format
+msgid "OLD argument of the %s intrinsic function at %L shall be definable"
+msgstr ""
+
+#: fortran/check.cc:1794
+#, gcc-internal-format, gfc-internal-format
+msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
+msgstr ""
+
+#: fortran/check.cc:1804
+#, gcc-internal-format, gfc-internal-format
+msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
+msgstr ""
+
+#: fortran/check.cc:1817
+#, gcc-internal-format, gfc-internal-format
+msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
+msgstr ""
+
+#: fortran/check.cc:1896
+#, gcc-internal-format, gfc-internal-format
+msgid "Negative argument N at %L"
+msgstr ""
+
+#: fortran/check.cc:1994
+#, gcc-internal-format, gfc-internal-format
+msgid "BOZ literal constant at %L cannot appear in CHAR intrinsic subprogram"
+msgstr ""
+
+#: fortran/check.cc:2118 fortran/check.cc:2608
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
+msgstr ""
+
+#: fortran/check.cc:2127 fortran/check.cc:2617
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
+msgstr ""
+
+#: fortran/check.cc:2137 fortran/check.cc:2143
+#, gcc-internal-format, gfc-internal-format
+msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
+msgstr ""
+
+#: fortran/check.cc:2165
+#, gcc-internal-format
+msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
+msgstr ""
+
+#: fortran/check.cc:2173
+#, gcc-internal-format, gfc-internal-format
+msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
+msgstr ""
+
+#: fortran/check.cc:2196
+#, gcc-internal-format, gfc-internal-format
+msgid "The stat= argument at %L must be a kind=4 integer variable"
+msgstr ""
+
+#: fortran/check.cc:2212
+#, gcc-internal-format, gfc-internal-format
+msgid "The errmsg= argument at %L must be a default-kind character variable"
+msgstr ""
+
+#: fortran/check.cc:2220
+#, gcc-internal-format
+msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
+msgstr ""
+
+#: fortran/check.cc:2235
+#, gcc-internal-format, gfc-internal-format
+msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
+msgstr ""
+
+#: fortran/check.cc:2254
+#, gcc-internal-format, gfc-internal-format
+msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
+msgstr ""
+
+#: fortran/check.cc:2261
+#, gcc-internal-format, gfc-internal-format
+msgid "Support for the A argument at %L with allocatable components is not yet implemented"
+msgstr ""
+
+#: fortran/check.cc:2275
+#, gcc-internal-format, gfc-internal-format
+msgid "OPERATION argument at %L must be a PURE function"
+msgstr ""
+
+#. None of the intrinsics fulfills the criteria of taking two arguments,
+#. returning the same type and kind as the arguments and being permitted
+#. as actual argument.
+#: fortran/check.cc:2285
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
+msgstr ""
+
+#: fortran/check.cc:2302
+#, gcc-internal-format, gfc-internal-format
+msgid "The function passed as OPERATION at %L shall have two arguments"
+msgstr ""
+
+#: fortran/check.cc:2312
+#, gcc-internal-format, gfc-internal-format
+msgid "The A argument at %L has type %s but the function passed as OPERATION at %L returns %s"
+msgstr ""
+
+#: fortran/check.cc:2321
+#, gcc-internal-format, gfc-internal-format
+msgid "The function passed as OPERATION at %L has arguments of type %s and %s but shall have type %s"
+msgstr ""
+
+#: fortran/check.cc:2332
+#, gcc-internal-format, gfc-internal-format
+msgid "The function passed as OPERATION at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
+msgstr ""
+
+#: fortran/check.cc:2340
+#, gcc-internal-format, gfc-internal-format
+msgid "The function passed as OPERATION at %L shall have the VALUE attribute either for none or both arguments"
+msgstr ""
+
+#: fortran/check.cc:2347
+#, gcc-internal-format, gfc-internal-format
+msgid "The function passed as OPERATION at %L shall have the TARGET attribute either for none or both arguments"
+msgstr ""
+
+#: fortran/check.cc:2354
+#, gcc-internal-format, gfc-internal-format
+msgid "The function passed as OPERATION at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
+msgstr ""
+
+#: fortran/check.cc:2362
+#, gcc-internal-format, gfc-internal-format
+msgid "The function passed as OPERATION at %L shall not have the OPTIONAL attribute for either of the arguments"
+msgstr ""
+
+#: fortran/check.cc:2392
+#, gcc-internal-format, gfc-internal-format
+msgid "The character length of the A argument at %L and of the arguments of the OPERATION at %L shall be the same"
+msgstr ""
+
+#: fortran/check.cc:2399
+#, gcc-internal-format, gfc-internal-format
+msgid "The character length of the A argument at %L and of the function result of the OPERATION at %L shall be the same"
+msgstr ""
+
+#: fortran/check.cc:2417
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
+msgstr ""
+
+#: fortran/check.cc:2445 fortran/check.cc:2459
+#, gcc-internal-format, gfc-internal-format
+msgid "BOZ constant at %L cannot appear in the COMPLEX intrinsic subprogram"
+msgstr ""
+
+#: fortran/check.cc:2496 fortran/check.cc:3126 fortran/check.cc:3209
+#: fortran/check.cc:3431 fortran/check.cc:3479 fortran/check.cc:4959
+#: fortran/check.cc:5084 fortran/check.cc:5154 fortran/check.cc:6339
+#: fortran/check.cc:6470
+#, gcc-internal-format
+msgid "%qs intrinsic with KIND argument at %L"
+msgstr ""
+
+#: fortran/check.cc:2543 fortran/check.cc:2812 fortran/check.cc:2872
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
+msgstr ""
+
+#: fortran/check.cc:2558 fortran/check.cc:2827 fortran/check.cc:2887
+#, gcc-internal-format
+msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
+msgstr ""
+
+#: fortran/check.cc:2670 fortran/check.cc:3811 fortran/check.cc:3819
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
+msgstr ""
+
+#: fortran/check.cc:2684
+#, gcc-internal-format
+msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
+msgstr ""
+
+#: fortran/check.cc:2704 fortran/check.cc:2712
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be default real"
+msgstr ""
+
+#: fortran/check.cc:2848
+#, gcc-internal-format
+msgid "%qs must be of same type and kind as %qs at %L in %qs"
+msgstr ""
+
+#: fortran/check.cc:2906
+#, gcc-internal-format
+msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
+msgstr ""
+
+#: fortran/check.cc:2924
+#, gcc-internal-format, gfc-internal-format
+msgid "BOZ literal constant at %L cannot appear in the FLOAT intrinsic subprogram"
+msgstr ""
+
+#: fortran/check.cc:2938
+#, gcc-internal-format, gfc-internal-format
+msgid "non-default INTEGER kind argument to %s intrinsic at %L"
+msgstr ""
+
+#: fortran/check.cc:2999
+#, gcc-internal-format
+msgid "COMPLEX argument %qs of %qs intrinsic at %L"
+msgstr ""
+
+#: fortran/check.cc:3081
+#, gcc-internal-format
+msgid "Arguments of %qs have different kind type parameters at %L"
+msgstr ""
+
+#: fortran/check.cc:3177
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of %s at %L must be of length one"
+msgstr ""
+
+#: fortran/check.cc:3216
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
+msgstr ""
+
+#: fortran/check.cc:3250
+#, gcc-internal-format
+msgid "%qs intrinsic subprogram at %L has been removed.  Use INT intrinsic subprogram."
+msgstr ""
+
+#: fortran/check.cc:3302
+#, gcc-internal-format, gfc-internal-format
+msgid "SIZE at %L must be positive"
+msgstr ""
+
+#: fortran/check.cc:3314
+#, gcc-internal-format, gfc-internal-format
+msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
+msgstr ""
+
+#: fortran/check.cc:3373
+#, gcc-internal-format, gfc-internal-format
+msgid "STATUS at %L shall be an INTENT(OUT) variable"
+msgstr ""
+
+#: fortran/check.cc:3382
+#, gcc-internal-format
+msgid "%qs at %L shall be an INTENT(OUT) variable"
+msgstr ""
+
+#: fortran/check.cc:3407
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a data entity"
+msgstr ""
+
+#: fortran/check.cc:3621
+#, gcc-internal-format
+msgid "Intrinsic %qs at %L must have at least two arguments"
+msgstr ""
+
+#: fortran/check.cc:3669
+#, gcc-internal-format
+msgid "Missing %qs argument to the %s intrinsic at %L"
+msgstr ""
+
+#: fortran/check.cc:3684
+#, gcc-internal-format
+msgid "Duplicate argument %qs at %L to intrinsic %s"
+msgstr ""
+
+#: fortran/check.cc:3689
+#, gcc-internal-format
+msgid "Unknown argument %qs at %L to intrinsic %s"
+msgstr ""
+
+#: fortran/check.cc:3714
+#, gcc-internal-format, gfc-internal-format
+msgid "Different character kinds at %L"
+msgstr ""
+
+#: fortran/check.cc:3723
+#, gcc-internal-format
+msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
+msgstr ""
+
+#: fortran/check.cc:3754
+#, gcc-internal-format
+msgid "%qs intrinsic with CHARACTER argument at %L"
+msgstr ""
+
+#: fortran/check.cc:3761
+#, gcc-internal-format
+msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
+msgstr ""
+
+#: fortran/check.cc:3828
+#, gcc-internal-format
+msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
+msgstr ""
+
+#: fortran/check.cc:3842
+#, gcc-internal-format
+msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
+msgstr ""
+
+#: fortran/check.cc:3861
+#, gcc-internal-format
+msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
+msgstr ""
+
+#: fortran/check.cc:3870
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
+msgstr ""
+
+#: fortran/check.cc:4035
+#, gcc-internal-format
+msgid "Argument %qs of %qs intrinsic at %L must be in type conformance to argument %qs at %L"
+msgstr ""
+
+#: fortran/check.cc:4153 fortran/check.cc:7552 fortran/check.cc:7567
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
+msgstr ""
+
+#: fortran/check.cc:4236
+#, gcc-internal-format, gfc-internal-format
+msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
+msgstr ""
+
+#: fortran/check.cc:4247
+#, gcc-internal-format, gfc-internal-format
+msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
+msgstr ""
+
+#: fortran/check.cc:4254
+#, gcc-internal-format, gfc-internal-format
+msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
+msgstr ""
+
+#: fortran/check.cc:4265
+#, gcc-internal-format, gfc-internal-format
+msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
+msgstr ""
+
+#: fortran/check.cc:4274
+#, gcc-internal-format, gfc-internal-format
+msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
+msgstr ""
+
+#: fortran/check.cc:4314
+#, gcc-internal-format, gfc-internal-format
+msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
+msgstr ""
+
+#: fortran/check.cc:4341
+#, gcc-internal-format
+msgid "Argument %<S%> of NEAREST at %L shall not be zero"
+msgstr ""
+
+#: fortran/check.cc:4397
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
+msgstr ""
+
+#: fortran/check.cc:4405
+#, gcc-internal-format, gfc-internal-format
+msgid "NULL intrinsic with allocatable MOLD at %L"
+msgstr ""
+
+#: fortran/check.cc:4484 fortran/check.cc:6417
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
+msgstr ""
+
+#: fortran/check.cc:4545
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
+msgstr ""
+
+#: fortran/check.cc:4555
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
+msgstr ""
+
+#: fortran/check.cc:4574
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
+msgstr ""
+
+#: fortran/check.cc:4625
+#, gcc-internal-format, gfc-internal-format
+msgid "The argument of the RANK intrinsic at %L must be a data object"
+msgstr ""
+
+#: fortran/check.cc:4733
+#, gcc-internal-format
+msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
+msgstr ""
+
+#: fortran/check.cc:4743
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L is empty"
+msgstr ""
+
+#: fortran/check.cc:4750
+#, gcc-internal-format
+msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
+msgstr ""
+
+#: fortran/check.cc:4773
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
+msgstr ""
+
+#: fortran/check.cc:4813
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
+msgstr ""
+
+#: fortran/check.cc:4831
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
+msgstr ""
+
+#: fortran/check.cc:4840
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
+msgstr ""
+
+#: fortran/check.cc:4875 fortran/simplify.cc:7050
+#, gcc-internal-format, gfc-internal-format
+msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
+msgstr ""
+
+#: fortran/check.cc:4892 fortran/check.cc:4911
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
+msgstr ""
+
+#: fortran/check.cc:4902 fortran/check.cc:4921
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
+msgstr ""
+
+#: fortran/check.cc:5020
+#, gcc-internal-format
+msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
+msgstr ""
+
+#: fortran/check.cc:5051
+#, gcc-internal-format
+msgid "%qs intrinsic with RADIX argument at %L"
+msgstr ""
+
+#: fortran/check.cc:5099
+#, gcc-internal-format
+msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
+msgstr ""
+
+#: fortran/check.cc:5172 fortran/check.cc:7612
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
+msgstr ""
+
+#: fortran/check.cc:5188 fortran/check.cc:5334 fortran/check.cc:7604
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
+msgstr ""
+
+#: fortran/check.cc:5199 fortran/check.cc:5346
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
+msgstr ""
+
+#: fortran/check.cc:5281
+#, gcc-internal-format
+msgid "is_c_interoperable(): gfc_simplify_expr failed"
+msgstr ""
+
+#: fortran/check.cc:5325
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
+msgstr ""
+
+#: fortran/check.cc:5364
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
+msgstr ""
+
+#: fortran/check.cc:5378
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
+msgstr ""
+
+#: fortran/check.cc:5402
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
+msgstr ""
+
+#: fortran/check.cc:5414
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
+msgstr ""
+
+#: fortran/check.cc:5421
+#, gcc-internal-format, gfc-internal-format
+msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
+msgstr ""
+
+#: fortran/check.cc:5428
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
+msgstr ""
+
+#: fortran/check.cc:5435
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
+msgstr ""
+
+#: fortran/check.cc:5441
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
+msgstr ""
+
+#: fortran/check.cc:5460
+#, gcc-internal-format, gfc-internal-format
+msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
+msgstr ""
+
+#: fortran/check.cc:5470
+#, gcc-internal-format, gfc-internal-format
+msgid "Polymorphic FPTR at %L to C_F_POINTER"
+msgstr ""
+
+#: fortran/check.cc:5476
+#, gcc-internal-format, gfc-internal-format
+msgid "FPTR argument to C_F_POINTER at %L is a function returning a pointer"
+msgstr ""
+
+#: fortran/check.cc:5483
+#, gcc-internal-format, gfc-internal-format
+msgid "Noninteroperable array FPTR argument to C_F_POINTER at %L: %s"
+msgstr ""
+
+#: fortran/check.cc:5499
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
+msgstr ""
+
+#: fortran/check.cc:5511
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
+msgstr ""
+
+#: fortran/check.cc:5518
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
+msgstr ""
+
+#: fortran/check.cc:5524
+#, gcc-internal-format, gfc-internal-format
+msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
+msgstr ""
+
+#: fortran/check.cc:5538
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
+msgstr ""
+
+#: fortran/check.cc:5550
+#, gcc-internal-format
+msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
+msgstr ""
+
+#: fortran/check.cc:5557
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
+msgstr ""
+
+#: fortran/check.cc:5563
+#, gcc-internal-format, gfc-internal-format
+msgid "Noninteroperable procedure at %L to C_FUNLOC"
+msgstr ""
+
+#: fortran/check.cc:5577
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument X at %L to C_LOC shall not be coindexed"
+msgstr ""
+
+#: fortran/check.cc:5583
+#, gcc-internal-format, gfc-internal-format
+msgid "X argument at %L to C_LOC shall not be polymorphic"
+msgstr ""
+
+#: fortran/check.cc:5594
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
+msgstr ""
+
+#: fortran/check.cc:5602
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
+msgstr ""
+
+#: fortran/check.cc:5611
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument at %L to C_LOC shall not be polymorphic"
+msgstr ""
+
+#: fortran/check.cc:5618
+#, gcc-internal-format, gfc-internal-format
+msgid "Noninteroperable array at %L as argument to C_LOC: %s"
+msgstr ""
+
+#: fortran/check.cc:5629
+#, gcc-internal-format, gfc-internal-format
+msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
+msgstr ""
+
+#: fortran/check.cc:5634
+#, gcc-internal-format, gfc-internal-format
+msgid "Array section at %L to C_LOC"
+msgstr ""
+
+#: fortran/check.cc:5662
+#, gcc-internal-format, gfc-internal-format
+msgid "non double precision REAL argument to %s intrinsic at %L"
+msgstr ""
+
+#: fortran/check.cc:5678
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
+msgstr ""
+
+#: fortran/check.cc:5697
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
+msgstr ""
+
+#: fortran/check.cc:5721
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must have length at least 1"
+msgstr ""
+
+#: fortran/check.cc:5985
+#, gcc-internal-format, gfc-internal-format
+msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
+msgstr ""
+
+#: fortran/check.cc:5992
+#, gcc-internal-format, gfc-internal-format
+msgid "Type of %s argument of IMAGE_INDEX at %L shall be INTEGER"
+msgstr ""
+
+#: fortran/check.cc:6003
+#, gcc-internal-format, gfc-internal-format
+msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
+msgstr ""
+
+#: fortran/check.cc:6036
+#, gcc-internal-format, gfc-internal-format
+msgid "DISTANCE= argument to NUM_IMAGES at %L"
+msgstr ""
+
+#: fortran/check.cc:6049
+#, gcc-internal-format, gfc-internal-format
+msgid "FAILED= argument to NUM_IMAGES at %L"
+msgstr ""
+
+#: fortran/check.cc:6073
+#, gcc-internal-format, gfc-internal-format
+msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
+msgstr ""
+
+#: fortran/check.cc:6099
+#, gcc-internal-format, gfc-internal-format
+msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
+msgstr ""
+
+#: fortran/check.cc:6106
+#, gcc-internal-format, gfc-internal-format
+msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
+msgstr ""
+
+#: fortran/check.cc:6117
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected DIM argument with noncoarray argument at %L"
+msgstr ""
+
+#: fortran/check.cc:6135
+#, gcc-internal-format, gfc-internal-format
+msgid "DISTANCE= argument to THIS_IMAGE at %L"
+msgstr ""
+
+#: fortran/check.cc:6193
+#, gcc-internal-format
+msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L is an array and shall not have storage size 0 when %<SOURCE%> argument has size greater than 0"
+msgstr ""
+
+#: fortran/check.cc:6245
+#, gcc-internal-format
+msgid "%<SOURCE%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
+msgstr ""
+
+#: fortran/check.cc:6264
+#, gcc-internal-format
+msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be a %s"
+msgstr ""
+
+#: fortran/check.cc:6272
+#, gcc-internal-format
+msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
+msgstr ""
+
+#: fortran/check.cc:6307
+msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %zd < result size %zd"
+msgstr ""
+
+#: fortran/check.cc:6431
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
+msgstr ""
+
+#: fortran/check.cc:6444
+#, gcc-internal-format
+msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
+msgstr ""
+
+#: fortran/check.cc:6580
+#, gcc-internal-format, gfc-internal-format
+msgid "VALUES argument of DATE_AND_TIME at %L has non-default kind"
+msgstr ""
+
+#: fortran/check.cc:6592
+#, gcc-internal-format, gfc-internal-format
+msgid "VALUES argument of DATE_AND_TIME at %L must have a decimal exponent range of at least four"
+msgstr ""
+
+#: fortran/check.cc:6731 fortran/check.cc:6763
+#, gcc-internal-format
+msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
+msgstr ""
+
+#: fortran/check.cc:6771
+#, gcc-internal-format, gfc-internal-format
+msgid "Too many arguments to %s at %L"
+msgstr ""
+
+#: fortran/check.cc:6789
+#, gcc-internal-format
+msgid "fe_runtime_error string must be null terminated"
+msgstr ""
+
+#: fortran/check.cc:6801
+#, gcc-internal-format, gfc-internal-format
+msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
+msgstr ""
+
+#: fortran/check.cc:6843
+#, gcc-internal-format, gfc-internal-format
+msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
+msgstr ""
+
+#: fortran/check.cc:6850
+#, gcc-internal-format, gfc-internal-format
+msgid "COUNT argument to SYSTEM_CLOCK at %L with kind smaller than default integer"
+msgstr ""
+
+#: fortran/check.cc:6871
+#, gcc-internal-format, gfc-internal-format
+msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
+msgstr ""
+
+#: fortran/check.cc:6881
+#, gcc-internal-format, gfc-internal-format
+msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
+msgstr ""
+
+#: fortran/check.cc:6888
+#, gcc-internal-format, gfc-internal-format
+msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L with kind smaller than default integer"
+msgstr ""
+
+#: fortran/check.cc:6908
+#, gcc-internal-format, gfc-internal-format
+msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
+msgstr ""
+
+#: fortran/check.cc:6918
+#, gcc-internal-format, gfc-internal-format
+msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L with kind smaller than default integer"
+msgstr ""
+
+#: fortran/check.cc:6933 fortran/check.cc:6940
+#, gcc-internal-format, gfc-internal-format
+msgid "integer arguments to SYSTEM_CLOCK at %L with different kind parameters"
+msgstr ""
+
+#: fortran/check.cc:7154
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
+msgstr ""
+
+#: fortran/check.cc:7336
+#, gcc-internal-format
+msgid "Actual argument at %L of %qs intrinsic shall be an associated pointer"
+msgstr ""
+
+#: fortran/check.cc:7525 fortran/check.cc:7536
+#, gcc-internal-format
+msgid "%qs argument of %qs intrinsic at %L must be INTEGER, LOGICAL, or a BOZ literal constant"
+msgstr ""
+
+#: fortran/check.cc:7596
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
+msgstr ""
+
+#. Since the extension field is 8 bit wide, we can only have
+#. up to 255 extension levels.
+#: fortran/class.cc:799 fortran/decl.cc:4079 fortran/decl.cc:10785
+#, gcc-internal-format
+msgid "Maximum extension level reached with type %qs at %L"
+msgstr ""
+
+#: fortran/class.cc:3109 fortran/class.cc:3183
+#, gcc-internal-format
+msgid "%qs of %qs is PRIVATE at %L"
+msgstr ""
+
+#: fortran/cpp.cc:501
+#, gcc-internal-format
+msgid "To enable preprocessing, use %<-cpp%>"
+msgstr ""
+
+#: fortran/cpp.cc:580 fortran/cpp.cc:591 fortran/cpp.cc:719
+#, gcc-internal-format
+msgid "opening output file %qs: %s"
+msgstr ""
+
+#: fortran/data.cc:67
+#, gcc-internal-format, gfc-internal-format
+msgid "non-constant array in DATA statement %L"
+msgstr ""
+
+#: fortran/data.cc:78
+#, gcc-internal-format, gfc-internal-format
+msgid "Subscript at %L below array lower bound (%ld < %ld) in dimension %d"
+msgstr ""
+
+#: fortran/data.cc:89
+#, gcc-internal-format, gfc-internal-format
+msgid "Subscript at %L above array upper bound (%ld > %ld) in dimension %d"
+msgstr ""
+
+#: fortran/data.cc:172
+#, gcc-internal-format, gfc-internal-format
+msgid "failure to simplify substring reference in DATA statement at %L"
+msgstr ""
+
+#: fortran/data.cc:205
+#, gcc-internal-format, gfc-internal-format
+msgid "Unused initialization string at %L because variable has zero length"
+msgstr ""
+
+#: fortran/data.cc:211
+#, gcc-internal-format
+msgid "Initialization string at %L was truncated to fit the variable (%wd/%wd)"
+msgstr ""
+
+#: fortran/data.cc:220 fortran/resolve.cc:5298
+#, gcc-internal-format, gfc-internal-format
+msgid "Substring start index at %L is less than one"
+msgstr ""
+
+#: fortran/data.cc:226 fortran/resolve.cc:5328
+#, gcc-internal-format, gfc-internal-format
+msgid "Substring end index at %L exceeds the string length"
+msgstr ""
+
+#: fortran/data.cc:316
+#, gcc-internal-format
+msgid "%qs at %L already is initialized at %L"
+msgstr ""
+
+#: fortran/data.cc:343
+#, gcc-internal-format, gfc-internal-format
+msgid "Data element below array lower bound at %L"
+msgstr ""
+
+#: fortran/data.cc:360 fortran/data.cc:449
+#, gcc-internal-format, gfc-internal-format
+msgid "Data element above array upper bound at %L"
+msgstr ""
+
+#: fortran/data.cc:390 fortran/data.cc:615
+#, gcc-internal-format
+msgid "re-initialization of %qs at %L"
+msgstr ""
+
+#: fortran/data.cc:560
+#, gcc-internal-format, gfc-internal-format
+msgid "LEN or KIND inquiry ref in DATA statement at %L"
+msgstr ""
+
+#: fortran/data.cc:638
+#, gcc-internal-format
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr ""
+
+#: fortran/data.cc:698 fortran/data.cc:717 fortran/data.cc:731
+#: fortran/data.cc:757 fortran/data.cc:904
+#, gcc-internal-format
+msgid "Simplification error"
+msgstr ""
+
+#: fortran/decl.cc:293
+#, gcc-internal-format, gfc-internal-format
+msgid "Inquiry parameter cannot appear in a data-stmt-object-list at %C"
+msgstr ""
+
+#: fortran/decl.cc:307
+#, gcc-internal-format
+msgid "Host associated variable %qs may not be in the DATA statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:314
+#, gcc-internal-format
+msgid "initialization of common block variable %qs in DATA statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:449
+#, gcc-internal-format
+msgid "Symbol %qs must be a PARAMETER in DATA statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:475
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid initializer %s in Data statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:580
+#, gcc-internal-format, gfc-internal-format
+msgid "BOZ at %L cannot appear in an old-style initialization"
+msgstr ""
+
+#: fortran/decl.cc:588
+#, gcc-internal-format
+msgid "BOZ literal constant near %L cannot be assigned to a %qs variable in an old-style initialization"
+msgstr ""
+
+#: fortran/decl.cc:598
+#, gcc-internal-format, gfc-internal-format
+msgid "Initialization at %C is not allowed in a PURE procedure"
+msgstr ""
+
+#: fortran/decl.cc:645
+#, gcc-internal-format, gfc-internal-format
+msgid "DATA statement at %C cannot appear within an INTERFACE"
+msgstr ""
+
+#: fortran/decl.cc:669
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid substring in data-implied-do at %L in DATA statement"
+msgstr ""
+
+#: fortran/decl.cc:692
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocatable component or deferred-shaped array near %C in DATA statement"
+msgstr ""
+
+#: fortran/decl.cc:734
+#, gcc-internal-format, gfc-internal-format
+msgid "BOZ literal constant at %L cannot appear in a structure constructor"
+msgstr ""
+
+#: fortran/decl.cc:750
+#, gcc-internal-format, gfc-internal-format
+msgid "DATA statement at %C is not allowed in a PURE procedure"
+msgstr ""
+
+#: fortran/decl.cc:759
+#, gcc-internal-format, gfc-internal-format
+msgid "part-ref with pointer attribute near %L is not rightmost part-ref of data-stmt-object"
+msgstr ""
+
+#: fortran/decl.cc:798
+#, gcc-internal-format, gfc-internal-format
+msgid "Empty old style initializer list at %C"
+msgstr ""
+
+#: fortran/decl.cc:807
+#, gcc-internal-format, gfc-internal-format
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr ""
+
+#: fortran/decl.cc:830
+#, gcc-internal-format, gfc-internal-format
+msgid "Repeat spec invalid in scalar initializer at %C"
+msgstr ""
+
+#: fortran/decl.cc:835
+#, gcc-internal-format, gfc-internal-format
+msgid "Repeat spec must be an integer at %C"
+msgstr ""
+
+#: fortran/decl.cc:846
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected data constant after repeat spec at %C"
+msgstr ""
+
+#: fortran/decl.cc:878
+#, gcc-internal-format, gfc-internal-format
+msgid "End of scalar initializer expected at %C"
+msgstr ""
+
+#: fortran/decl.cc:906
+#, gcc-internal-format, gfc-internal-format
+msgid "Not enough elements in array initializer at %C"
+msgstr ""
+
+#: fortran/decl.cc:908
+#, gcc-internal-format, gfc-internal-format
+msgid "Too many elements in array initializer at %C"
+msgstr ""
+
+#: fortran/decl.cc:934
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in old style initializer list at %C"
+msgstr ""
+
+#: fortran/decl.cc:958
+#, gcc-internal-format, gfc-internal-format
+msgid "The assumed-rank array at %C shall not have a codimension"
+msgstr ""
+
+#: fortran/decl.cc:1023
+#, gcc-internal-format, gfc-internal-format
+msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
+msgstr ""
+
+#: fortran/decl.cc:1047
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad INTENT specification at %C"
+msgstr ""
+
+#: fortran/decl.cc:1069
+#, gcc-internal-format, gfc-internal-format
+msgid "deferred type parameter at %C"
+msgstr ""
+
+#: fortran/decl.cc:1162 fortran/resolve.cc:13335
+#, gcc-internal-format, gfc-internal-format
+msgid "Scalar INTEGER expression expected at %L"
+msgstr ""
+
+#: fortran/decl.cc:1188
+#, gcc-internal-format, gfc-internal-format
+msgid "Old-style character length at %C"
+msgstr ""
+
+#: fortran/decl.cc:1219
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in character length specification at %C"
+msgstr ""
+
+#: fortran/decl.cc:1371 fortran/decl.cc:1378 fortran/decl.cc:1444
+#, gcc-internal-format
+msgid "Procedure %qs at %C is already defined at %L"
+msgstr ""
+
+#: fortran/decl.cc:1386
+#, gcc-internal-format
+msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
+msgstr ""
+
+#: fortran/decl.cc:1398
+#, gcc-internal-format
+msgid "Name %qs at %C is already defined as a generic interface at %L"
+msgstr ""
+
+#: fortran/decl.cc:1416
+#, gcc-internal-format
+msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
+msgstr ""
+
+#: fortran/decl.cc:1432
+#, gcc-internal-format
+msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
+msgstr ""
+
+#: fortran/decl.cc:1515
+#, gcc-internal-format
+msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
+msgstr ""
+
+#: fortran/decl.cc:1542
+#, gcc-internal-format
+msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
+msgstr ""
+
+#: fortran/decl.cc:1549
+#, gcc-internal-format
+msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
+msgstr ""
+
+#: fortran/decl.cc:1556
+#, gcc-internal-format
+msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
+msgstr ""
+
+#: fortran/decl.cc:1565
+#, gcc-internal-format
+msgid "Dummy argument %qs at %L may not be a pointer with CONTIGUOUS attribute as procedure %qs is BIND(C)"
+msgstr ""
+
+#: fortran/decl.cc:1575
+#, gcc-internal-format
+msgid "Default-initialized %s dummy argument %qs at %L is not permitted in BIND(C) procedure %qs"
+msgstr ""
+
+#: fortran/decl.cc:1596
+#, gcc-internal-format
+msgid "Allocatable character dummy argument %qs at %L must have deferred length as procedure %qs is BIND(C)"
+msgstr ""
+
+#: fortran/decl.cc:1601
+#, gcc-internal-format
+msgid "Pointer character dummy argument %qs at %L must have deferred length as procedure %qs is BIND(C)"
+msgstr ""
+
+#: fortran/decl.cc:1608
+#, gcc-internal-format
+msgid "Deferred-length character dummy argument %qs at %L of procedure %qs with BIND(C) attribute"
+msgstr ""
+
+#: fortran/decl.cc:1620
+#, gcc-internal-format
+msgid "Character dummy argument %qs at %L must be of length 1 as it has the VALUE attribute"
+msgstr ""
+
+#: fortran/decl.cc:1631
+#, gcc-internal-format
+msgid "Assumed-length character dummy argument %qs at %L of procedure %qs with BIND(C) attribute"
+msgstr ""
+
+#: fortran/decl.cc:1645
+#, gcc-internal-format
+msgid "Character dummy argument %qs at %L must be of constant length of one or assumed length, unless it has assumed shape or assumed rank, as procedure %qs has the BIND(C) attribute"
+msgstr ""
+
+#: fortran/decl.cc:1663
+#, gcc-internal-format
+msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
+msgstr ""
+
+#: fortran/decl.cc:1671
+#, gcc-internal-format
+msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
+msgstr ""
+
+#: fortran/decl.cc:1680
+#, gcc-internal-format
+msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
+msgstr ""
+
+#: fortran/decl.cc:1687
+#, gcc-internal-format
+msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
+msgstr ""
+
+#: fortran/decl.cc:1698
+#, gcc-internal-format
+msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
+msgstr ""
+
+#: fortran/decl.cc:1766
+#, gcc-internal-format
+msgid "Symbol %qs at %C also declared as a type at %L"
+msgstr ""
+
+#: fortran/decl.cc:1828
+#, gcc-internal-format
+msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
+msgstr ""
+
+#: fortran/decl.cc:1868
+#, gcc-internal-format, gfc-internal-format
+msgid "CHARACTER length must be a constant at %L"
+msgstr ""
+
+#: fortran/decl.cc:1883
+#, gcc-internal-format, gfc-internal-format
+msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
+msgstr ""
+
+#: fortran/decl.cc:1891
+#, gcc-internal-format, gfc-internal-format
+msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
+msgstr ""
+
+#: fortran/decl.cc:2029
+#, gcc-internal-format
+msgid "Initializer not allowed for PARAMETER %qs at %C"
+msgstr ""
+
+#: fortran/decl.cc:2042
+#, gcc-internal-format, gfc-internal-format
+msgid "PARAMETER at %L is missing an initializer"
+msgstr ""
+
+#: fortran/decl.cc:2052
+#, gcc-internal-format
+msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
+msgstr ""
+
+#: fortran/decl.cc:2095
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot initialize parameter array at %L with variable length elements"
+msgstr ""
+
+#: fortran/decl.cc:2129
+#, gcc-internal-format, gfc-internal-format
+msgid "Rank mismatch of array at %L and its initializer (%d/%d)"
+msgstr ""
+
+#: fortran/decl.cc:2142
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot initialize implied-shape array at %L with scalar"
+msgstr ""
+
+#: fortran/decl.cc:2152
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad shape of initializer at %L"
+msgstr ""
+
+#: fortran/decl.cc:2159
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot determine shape of initializer at %L"
+msgstr ""
+
+#: fortran/decl.cc:2194
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-constant lower bound in implied-shape declaration at %L"
+msgstr ""
+
+#: fortran/decl.cc:2244
+#, gcc-internal-format
+msgid "Entity %qs at %L is incompatible with a BOZ literal constant"
+msgstr ""
+
+#: fortran/decl.cc:2309 fortran/decl.cc:2316
+#, gcc-internal-format, gfc-internal-format
+msgid "Component at %C must have the POINTER attribute"
+msgstr ""
+
+#: fortran/decl.cc:2325
+#, gcc-internal-format
+msgid "Component %qs with CLASS at %C must be allocatable or pointer"
+msgstr ""
+
+#: fortran/decl.cc:2334
+#, gcc-internal-format, gfc-internal-format
+msgid "Array component of structure at %C must have explicit or deferred shape"
+msgstr ""
+
+#: fortran/decl.cc:2358 fortran/symbol.cc:2276
+#, gcc-internal-format
+msgid "Component %qs at %C already declared at %L"
+msgstr ""
+
+#: fortran/decl.cc:2413
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer array component of structure at %C must have a deferred shape"
+msgstr ""
+
+#: fortran/decl.cc:2422
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocatable component of structure at %C must have a deferred shape"
+msgstr ""
+
+#: fortran/decl.cc:2431
+#, gcc-internal-format, gfc-internal-format
+msgid "Array component of structure at %C must have an explicit shape"
+msgstr ""
+
+#: fortran/decl.cc:2448
+#, gcc-internal-format
+msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
+msgstr ""
+
+#: fortran/decl.cc:2505
+#, gcc-internal-format, gfc-internal-format
+msgid "NULL() initialization at %C is ambiguous"
+msgstr ""
+
+#: fortran/decl.cc:2522
+#, gcc-internal-format, gfc-internal-format
+msgid "NULL() initialization at %C may not have MOLD"
+msgstr ""
+
+#: fortran/decl.cc:2539
+#, gcc-internal-format, gfc-internal-format
+msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
+msgstr ""
+
+#: fortran/decl.cc:2560
+#, gcc-internal-format, gfc-internal-format
+msgid "Error in pointer initialization at %C"
+msgstr ""
+
+#: fortran/decl.cc:2567
+#, gcc-internal-format, gfc-internal-format
+msgid "non-NULL pointer initialization at %C"
+msgstr ""
+
+#: fortran/decl.cc:2590
+#, gcc-internal-format
+msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
+msgstr ""
+
+#: fortran/decl.cc:2644
+#, gcc-internal-format
+msgid "%qs not allowed outside STRUCTURE at %C"
+msgstr ""
+
+#: fortran/decl.cc:2646
+#, gcc-internal-format
+msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
+msgstr ""
+
+#: fortran/decl.cc:2654
+#, gcc-internal-format
+msgid "%qs entity cannot have attributes at %C"
+msgstr ""
+
+#: fortran/decl.cc:2664
+#, gcc-internal-format
+msgid "Invalid character %qc in variable name at %C"
+msgstr ""
+
+#: fortran/decl.cc:2706
+#, gcc-internal-format
+msgid "Non-PARAMETER symbol %qs at %L cannot be implied-shape"
+msgstr ""
+
+#: fortran/decl.cc:2716
+#, gcc-internal-format, gfc-internal-format
+msgid "Implied-shape array at %L"
+msgstr ""
+
+#: fortran/decl.cc:2773
+#, gcc-internal-format, gfc-internal-format
+msgid "Explicit array shape at %C must be constant of INTEGER type and not %s type"
+msgstr ""
+
+#: fortran/decl.cc:2781
+#, gcc-internal-format, gfc-internal-format
+msgid "Explicit shaped array with nonconstant bounds at %C"
+msgstr ""
+
+#: fortran/decl.cc:2882
+#, gcc-internal-format
+msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
+msgstr ""
+
+#: fortran/decl.cc:2893
+#, gcc-internal-format
+msgid "%qs entity cannot have an initializer at %C"
+msgstr ""
+
+#: fortran/decl.cc:2918 fortran/decl.cc:9015
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate array spec for Cray pointee at %C"
+msgstr ""
+
+#: fortran/decl.cc:2926
+#, gcc-internal-format
+msgid "Cannot set pointee array spec."
+msgstr ""
+
+#: fortran/decl.cc:2989
+#, gcc-internal-format, gfc-internal-format
+msgid "Old-style initialization at %C"
+msgstr ""
+
+#: fortran/decl.cc:2997
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid old style initialization for derived type component at %C"
+msgstr ""
+
+#: fortran/decl.cc:3010
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in old style initialization of %s at %C"
+msgstr ""
+
+#: fortran/decl.cc:3030 fortran/decl.cc:7230
+#, gcc-internal-format, gfc-internal-format
+msgid "Initialization at %C isn't for a pointer variable"
+msgstr ""
+
+#: fortran/decl.cc:3053
+#, gcc-internal-format
+msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
+msgstr ""
+
+#: fortran/decl.cc:3062 fortran/decl.cc:10959
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected an initialization expression at %C"
+msgstr ""
+
+#: fortran/decl.cc:3069
+#, gcc-internal-format, gfc-internal-format
+msgid "Initialization of variable at %C is not allowed in a PURE procedure"
+msgstr ""
+
+#: fortran/decl.cc:3086
+#, gcc-internal-format, gfc-internal-format
+msgid "Initialization of allocatable component at %C is not allowed"
+msgstr ""
+
+#: fortran/decl.cc:3095
+#, gcc-internal-format, gfc-internal-format
+msgid "Initialization of structure component with a HOLLERITH constant at %L is not allowed"
+msgstr ""
+
+#: fortran/decl.cc:3109
+#, gcc-internal-format, gfc-internal-format
+msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
+msgstr ""
+
+#: fortran/decl.cc:3117
+#, gcc-internal-format, gfc-internal-format
+msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
+msgstr ""
+
+#: fortran/decl.cc:3125
+#, gcc-internal-format, gfc-internal-format
+msgid "The component at %C which is a type parameter must be a scalar"
+msgstr ""
+
+#: fortran/decl.cc:3134
+#, gcc-internal-format, gfc-internal-format
+msgid "BOZ literal constant at %L cannot appear as an initializer"
+msgstr ""
+
+#: fortran/decl.cc:3151
+#, gcc-internal-format
+msgid "Incompatible initialization between a derived type entity and an entity with %qs type at %C"
+msgstr ""
+
+#: fortran/decl.cc:3214 fortran/decl.cc:3249
+#, gcc-internal-format, gfc-internal-format
+msgid "Old-style type declaration %s*%d not supported at %C"
+msgstr ""
+
+#: fortran/decl.cc:3255
+#, gcc-internal-format, gfc-internal-format
+msgid "Nonstandard type declaration %s*%d at %C"
+msgstr ""
+
+#: fortran/decl.cc:3314 fortran/decl.cc:3391
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing right parenthesis at %C"
+msgstr ""
+
+#: fortran/decl.cc:3327 fortran/decl.cc:3462
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected initialization expression at %C"
+msgstr ""
+
+#: fortran/decl.cc:3335 fortran/decl.cc:3468
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected scalar initialization expression at %C"
+msgstr ""
+
+#: fortran/decl.cc:3365 fortran/decl.cc:4115
+#, gcc-internal-format, gfc-internal-format
+msgid "Kind %d not supported for type %s at %C"
+msgstr ""
+
+#: fortran/decl.cc:3378
+#, gcc-internal-format, gfc-internal-format
+msgid "C kind type parameter is for type %s but type at %L is %s"
+msgstr ""
+
+#: fortran/decl.cc:3389
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing right parenthesis or comma at %C"
+msgstr ""
+
+#: fortran/decl.cc:3494
+#, gcc-internal-format, gfc-internal-format
+msgid "Kind %d is not supported for CHARACTER at %C"
+msgstr ""
+
+#: fortran/decl.cc:3626
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in CHARACTER declaration at %C"
+msgstr ""
+
+#: fortran/decl.cc:3727
+#, gcc-internal-format
+msgid "RECORD at %C is an extension, enable it with %<-fdec-structure%>"
+msgstr ""
+
+#: fortran/decl.cc:3740
+#, gcc-internal-format, gfc-internal-format
+msgid "Structure name expected after RECORD at %C"
+msgstr ""
+
+#: fortran/decl.cc:3853
+#, gcc-internal-format, gfc-internal-format
+msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
+msgstr ""
+
+#: fortran/decl.cc:3877
+#, gcc-internal-format, gfc-internal-format
+msgid "The type parameter spec list at %C does not contain enough parameter expressions"
+msgstr ""
+
+#: fortran/decl.cc:3901
+#, gcc-internal-format
+msgid "The derived parameter %qs at %C does not have a default value"
+msgstr ""
+
+#: fortran/decl.cc:3934
+#, gcc-internal-format, gfc-internal-format
+msgid "The parameter expression at %C must be of INTEGER type and not %s type"
+msgstr ""
+
+#: fortran/decl.cc:3941
+#, gcc-internal-format, gfc-internal-format
+msgid "The parameter expression at %C does not simplify to an INTEGER constant"
+msgstr ""
+
+#: fortran/decl.cc:3968
+#, gcc-internal-format
+msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
+msgstr ""
+
+#: fortran/decl.cc:3975
+#, gcc-internal-format
+msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
+msgstr ""
+
+#: fortran/decl.cc:3990
+#, gcc-internal-format, gfc-internal-format
+msgid "The type parameter spec list at %C contains too many parameter expressions"
+msgstr ""
+
+#: fortran/decl.cc:3999
+#, gcc-internal-format, gfc-internal-format
+msgid "Parameterized derived type at %C is ambiguous"
+msgstr ""
+
+#: fortran/decl.cc:4250
+#, gcc-internal-format, gfc-internal-format
+msgid "BYTE type at %C"
+msgstr ""
+
+#: fortran/decl.cc:4262
+#, gcc-internal-format, gfc-internal-format
+msgid "BYTE type used at %C is not available on the target machine"
+msgstr ""
+
+#: fortran/decl.cc:4324
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed type at %C is not allowed for components"
+msgstr ""
+
+#: fortran/decl.cc:4327
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed type at %C"
+msgstr ""
+
+#: fortran/decl.cc:4349 fortran/decl.cc:4383 fortran/decl.cc:4416
+#: fortran/decl.cc:4715
+#, gcc-internal-format, gfc-internal-format
+msgid "TYPE with intrinsic-type-spec at %C"
+msgstr ""
+
+#: fortran/decl.cc:4361 fortran/decl.cc:4389 fortran/decl.cc:4422
+#: fortran/decl.cc:4448 fortran/decl.cc:4740 fortran/decl.cc:4758
+#, gcc-internal-format, gfc-internal-format
+msgid "Malformed type-spec at %C"
+msgstr ""
+
+#: fortran/decl.cc:4412
+#, gcc-internal-format, gfc-internal-format
+msgid "DOUBLE COMPLEX at %C"
+msgstr ""
+
+#: fortran/decl.cc:4464 fortran/decl.cc:4606 fortran/decl.cc:4618
+#: fortran/decl.cc:4632 fortran/decl.cc:5117 fortran/decl.cc:5125
+#, gcc-internal-format
+msgid "Type name %qs at %C is ambiguous"
+msgstr ""
+
+#: fortran/decl.cc:4565
+#, gcc-internal-format, gfc-internal-format
+msgid "CLASS statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:4647
+#, gcc-internal-format
+msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
+msgstr ""
+
+#: fortran/decl.cc:4793
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate IMPLICIT NONE statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:4802
+#, gcc-internal-format, gfc-internal-format
+msgid "IMPLICIT NONE with spec list at %C"
+msgstr ""
+
+#: fortran/decl.cc:4861
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing character range in IMPLICIT at %C"
+msgstr ""
+
+#: fortran/decl.cc:4907
+#, gcc-internal-format, gfc-internal-format
+msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:4960
+#, gcc-internal-format, gfc-internal-format
+msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
+msgstr ""
+
+#: fortran/decl.cc:4970
+#, gcc-internal-format, gfc-internal-format
+msgid "Empty IMPLICIT statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:5076
+#, gcc-internal-format, gfc-internal-format
+msgid "IMPORT statement at %C only permitted in an INTERFACE body"
+msgstr ""
+
+#: fortran/decl.cc:5083
+#, gcc-internal-format, gfc-internal-format
+msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
+msgstr ""
+
+#: fortran/decl.cc:5088
+#, gcc-internal-format, gfc-internal-format
+msgid "IMPORT statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:5102
+#, gcc-internal-format, gfc-internal-format
+msgid "Expecting list of named entities at %C"
+msgstr ""
+
+#: fortran/decl.cc:5131
+#, gcc-internal-format
+msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
+msgstr ""
+
+#: fortran/decl.cc:5138
+#, gcc-internal-format
+msgid "%qs is already IMPORTed from host scoping unit at %C"
+msgstr ""
+
+#: fortran/decl.cc:5179
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in IMPORT statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:5519
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing codimension specification at %C"
+msgstr ""
+
+#: fortran/decl.cc:5521
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing dimension specification at %C"
+msgstr ""
+
+#: fortran/decl.cc:5616
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate %s attribute at %L"
+msgstr ""
+
+#: fortran/decl.cc:5633
+#, gcc-internal-format
+msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
+msgstr ""
+
+#: fortran/decl.cc:5652
+#, gcc-internal-format, gfc-internal-format
+msgid "ALLOCATABLE attribute at %C in a TYPE definition"
+msgstr ""
+
+#: fortran/decl.cc:5654
+#, gcc-internal-format, gfc-internal-format
+msgid "ALLOCATABLE attribute at %C in a STRUCTURE definition"
+msgstr ""
+
+#: fortran/decl.cc:5664
+#, gcc-internal-format, gfc-internal-format
+msgid "KIND attribute at %C in a TYPE definition"
+msgstr ""
+
+#: fortran/decl.cc:5666
+#, gcc-internal-format, gfc-internal-format
+msgid "KIND attribute at %C in a STRUCTURE definition"
+msgstr ""
+
+#: fortran/decl.cc:5674
+#, gcc-internal-format, gfc-internal-format
+msgid "Component with KIND attribute at %C must be INTEGER"
+msgstr ""
+
+#: fortran/decl.cc:5683
+#, gcc-internal-format, gfc-internal-format
+msgid "LEN attribute at %C in a TYPE definition"
+msgstr ""
+
+#: fortran/decl.cc:5685
+#, gcc-internal-format, gfc-internal-format
+msgid "LEN attribute at %C in a STRUCTURE definition"
+msgstr ""
+
+#: fortran/decl.cc:5693
+#, gcc-internal-format, gfc-internal-format
+msgid "Component with LEN attribute at %C must be INTEGER"
+msgstr ""
+
+#: fortran/decl.cc:5701
+#, gcc-internal-format, gfc-internal-format
+msgid "Attribute at %L is not allowed in a TYPE definition"
+msgstr ""
+
+#: fortran/decl.cc:5703
+#, gcc-internal-format, gfc-internal-format
+msgid "Attribute at %L is not allowed in a STRUCTURE definition"
+msgstr ""
+
+#: fortran/decl.cc:5721
+#, gcc-internal-format, gfc-internal-format
+msgid "Attribute %s at %L in a TYPE definition"
+msgstr ""
+
+#: fortran/decl.cc:5731
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute at %L is not allowed outside of the specification part of a module"
+msgstr ""
+
+#: fortran/decl.cc:5741
+#, gcc-internal-format, gfc-internal-format
+msgid "Attribute at %L is not allowed outside a TYPE definition"
+msgstr ""
+
+#: fortran/decl.cc:5754
+#, gcc-internal-format, gfc-internal-format
+msgid "ASYNCHRONOUS attribute at %C"
+msgstr ""
+
+#: fortran/decl.cc:5765
+#, gcc-internal-format, gfc-internal-format
+msgid "CONTIGUOUS attribute at %C"
+msgstr ""
+
+#: fortran/decl.cc:5820 fortran/decl.cc:9317
+#, gcc-internal-format, gfc-internal-format
+msgid "PROTECTED at %C only allowed in specification part of a module"
+msgstr ""
+
+#: fortran/decl.cc:5826
+#, gcc-internal-format, gfc-internal-format
+msgid "PROTECTED attribute at %C"
+msgstr ""
+
+#: fortran/decl.cc:5860
+#, gcc-internal-format, gfc-internal-format
+msgid "VALUE attribute at %C"
+msgstr ""
+
+#: fortran/decl.cc:5867
+#, gcc-internal-format, gfc-internal-format
+msgid "VOLATILE attribute at %C"
+msgstr ""
+
+#: fortran/decl.cc:5874
+#, gcc-internal-format
+msgid "match_attr_spec(): Bad attribute"
+msgstr ""
+
+#: fortran/decl.cc:5915
+#, gcc-internal-format, gfc-internal-format
+msgid "Multiple identifiers provided with single NAME= specifier at %C"
+msgstr ""
+
+#: fortran/decl.cc:6013
+#, gcc-internal-format
+msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
+msgstr ""
+
+#: fortran/decl.cc:6035
+#, gcc-internal-format
+msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
+msgstr ""
+
+#: fortran/decl.cc:6046
+#, gcc-internal-format
+msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
+msgstr ""
+
+#: fortran/decl.cc:6052
+#, gcc-internal-format
+msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
+msgstr ""
+
+#: fortran/decl.cc:6064
+#, gcc-internal-format
+msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
+msgstr ""
+
+#: fortran/decl.cc:6078
+#, gcc-internal-format
+msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
+msgstr ""
+
+#: fortran/decl.cc:6086
+#, gcc-internal-format
+msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
+msgstr ""
+
+#: fortran/decl.cc:6098
+#, gcc-internal-format
+msgid "Return type of BIND(C) function %qs at %L cannot be an array"
+msgstr ""
+
+#: fortran/decl.cc:6104
+#, gcc-internal-format
+msgid "Return type of BIND(C) function %qs of character type at %L must have length 1"
+msgstr ""
+
+#. Use gfc_warning_now because we won't say that the symbol fails
+#. just because of this.
+#: fortran/decl.cc:6115
+#, gcc-internal-format
+msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
+msgstr ""
+
+#: fortran/decl.cc:6189
+#, gcc-internal-format, gfc-internal-format
+msgid "Need either entity or common block name for attribute specification statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:6234
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing entity or common block name for attribute specification statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:6241
+#, gcc-internal-format
+msgid "Missing symbol"
+msgstr ""
+
+#: fortran/decl.cc:6270
+#, gcc-internal-format, gfc-internal-format
+msgid "BIND(C) statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:6332
+#, gcc-internal-format, gfc-internal-format
+msgid "CLASS entity at %C cannot have the PARAMETER attribute"
+msgstr ""
+
+#: fortran/decl.cc:6364
+#, gcc-internal-format, gfc-internal-format
+msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
+msgstr ""
+
+#: fortran/decl.cc:6406
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in anonymous structure declaration at %C"
+msgstr ""
+
+#: fortran/decl.cc:6415
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in data declaration at %C"
+msgstr ""
+
+#: fortran/decl.cc:6487
+#, gcc-internal-format, gfc-internal-format
+msgid "MODULE prefix at %C"
+msgstr ""
+
+#: fortran/decl.cc:6492
+#, gcc-internal-format, gfc-internal-format
+msgid "MODULE prefix at %C found outside of a module, submodule, or interface"
+msgstr ""
+
+#: fortran/decl.cc:6543
+#, gcc-internal-format, gfc-internal-format
+msgid "IMPURE procedure at %C"
+msgstr ""
+
+#: fortran/decl.cc:6555
+#, gcc-internal-format, gfc-internal-format
+msgid "PURE and IMPURE must not appear both at %C"
+msgstr ""
+
+#: fortran/decl.cc:6601
+#, gcc-internal-format, gfc-internal-format
+msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
+msgstr ""
+
+#: fortran/decl.cc:6608
+#, gcc-internal-format, gfc-internal-format
+msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
+msgstr ""
+
+#: fortran/decl.cc:6615
+#, gcc-internal-format, gfc-internal-format
+msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
+msgstr ""
+
+#: fortran/decl.cc:6676
+#, gcc-internal-format, gfc-internal-format
+msgid "A type parameter list is required at %C"
+msgstr ""
+
+#: fortran/decl.cc:6690 fortran/primary.cc:1885
+#, gcc-internal-format, gfc-internal-format
+msgid "Alternate-return argument at %C"
+msgstr ""
+
+#: fortran/decl.cc:6696 fortran/decl.cc:6704
+#, gcc-internal-format, gfc-internal-format
+msgid "A parameter name is required at %C"
+msgstr ""
+
+#: fortran/decl.cc:6744
+#, gcc-internal-format
+msgid "Name %qs at %C is the name of the procedure"
+msgstr ""
+
+#: fortran/decl.cc:6757
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected parameter list in type declaration at %C"
+msgstr ""
+
+#: fortran/decl.cc:6760
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk in formal argument list at %C"
+msgstr ""
+
+#: fortran/decl.cc:6778
+#, gcc-internal-format
+msgid "Duplicate name %qs in parameter list at %C"
+msgstr ""
+
+#: fortran/decl.cc:6781
+#, gcc-internal-format
+msgid "Duplicate symbol %qs in formal argument list at %C"
+msgstr ""
+
+#: fortran/decl.cc:6823
+#, gcc-internal-format
+msgid "MODULE PROCEDURE formal argument %qs conflicts with alternate return at %C"
+msgstr ""
+
+#: fortran/decl.cc:6827
+#, gcc-internal-format
+msgid "MODULE PROCEDURE formal argument is alternate return and conflicts with %qs in the separate declaration at %C"
+msgstr ""
+
+#: fortran/decl.cc:6832
+#, gcc-internal-format, gfc-internal-format
+msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
+msgstr ""
+
+#: fortran/decl.cc:6839
+#, gcc-internal-format, gfc-internal-format
+msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
+msgstr ""
+
+#: fortran/decl.cc:6878
+#, gcc-internal-format, gfc-internal-format
+msgid "RESULT variable at %C must be different than function name"
+msgstr ""
+
+#: fortran/decl.cc:6955
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after function declaration at %C"
+msgstr ""
+
+#: fortran/decl.cc:6965 fortran/decl.cc:8103
+#, gcc-internal-format, gfc-internal-format
+msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
+msgstr ""
+
+#: fortran/decl.cc:7169
+#, gcc-internal-format, gfc-internal-format
+msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
+msgstr ""
+
+#: fortran/decl.cc:7176
+#, gcc-internal-format, gfc-internal-format
+msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
+msgstr ""
+
+#: fortran/decl.cc:7182
+#, gcc-internal-format, gfc-internal-format
+msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
+msgstr ""
+
+#: fortran/decl.cc:7205
+#, gcc-internal-format
+msgid "Procedure %qs at %L already has basic type of %s"
+msgstr ""
+
+#: fortran/decl.cc:7251 fortran/decl.cc:7439 fortran/decl.cc:11443
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in PROCEDURE statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:7300 fortran/decl.cc:11343
+#, gcc-internal-format
+msgid "Expected %<::%> after binding-attributes at %C"
+msgstr ""
+
+#: fortran/decl.cc:7307
+#, gcc-internal-format, gfc-internal-format
+msgid "NOPASS or explicit interface required at %C"
+msgstr ""
+
+#: fortran/decl.cc:7311
+#, gcc-internal-format, gfc-internal-format
+msgid "Procedure pointer component at %C"
+msgstr ""
+
+#: fortran/decl.cc:7383
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in procedure pointer component at %C"
+msgstr ""
+
+#: fortran/decl.cc:7401
+#, gcc-internal-format, gfc-internal-format
+msgid "PROCEDURE at %C must be in a generic interface"
+msgstr ""
+
+#: fortran/decl.cc:7410 fortran/decl.cc:10083
+#, gcc-internal-format, gfc-internal-format
+msgid "double colon in MODULE PROCEDURE statement at %L"
+msgstr ""
+
+#: fortran/decl.cc:7480
+#, gcc-internal-format, gfc-internal-format
+msgid "PROCEDURE statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:7552
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected formal argument list in function definition at %C"
+msgstr ""
+
+#: fortran/decl.cc:7582 fortran/decl.cc:7861 fortran/decl.cc:8070
+#: fortran/symbol.cc:1916
+#, gcc-internal-format, gfc-internal-format
+msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
+msgstr ""
+
+#: fortran/decl.cc:7612 fortran/decl.cc:8128
+#, gcc-internal-format
+msgid "Mismatch in BIND(C) names (%qs/%qs) at %C"
+msgstr ""
+
+#: fortran/decl.cc:7755
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:7764
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a PROGRAM"
+msgstr ""
+
+#: fortran/decl.cc:7767
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a MODULE"
+msgstr ""
+
+#: fortran/decl.cc:7770
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
+msgstr ""
+
+#: fortran/decl.cc:7773
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
+msgstr ""
+
+#: fortran/decl.cc:7777 fortran/decl.cc:7822
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within an INTERFACE"
+msgstr ""
+
+#: fortran/decl.cc:7781
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
+msgstr ""
+
+#: fortran/decl.cc:7785
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
+msgstr ""
+
+#: fortran/decl.cc:7789
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
+msgstr ""
+
+#: fortran/decl.cc:7794
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a DO block"
+msgstr ""
+
+#: fortran/decl.cc:7798
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a SELECT block"
+msgstr ""
+
+#: fortran/decl.cc:7802
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a FORALL block"
+msgstr ""
+
+#: fortran/decl.cc:7806
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a WHERE block"
+msgstr ""
+
+#: fortran/decl.cc:7810
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear within a contained subprogram"
+msgstr ""
+
+#: fortran/decl.cc:7814
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected ENTRY statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:7835
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %C cannot appear in a contained procedure"
+msgstr ""
+
+#: fortran/decl.cc:7886 fortran/decl.cc:8110
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing required parentheses before BIND(C) at %C"
+msgstr ""
+
+#: fortran/decl.cc:7980
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY statement at %L with BIND(C) prohibited in an elemental procedure"
+msgstr ""
+
+#: fortran/decl.cc:8137
+#, gcc-internal-format, gfc-internal-format
+msgid "Alternate return dummy argument cannot appear in a SUBROUTINE with the BIND(C) attribute at %L"
+msgstr ""
+
+#: fortran/decl.cc:8200 fortran/decl.cc:8207
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid C identifier in NAME= specifier at %C"
+msgstr ""
+
+#: fortran/decl.cc:8247
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in NAME= specifier for binding label at %C"
+msgstr ""
+
+#: fortran/decl.cc:8263
+#, gcc-internal-format, gfc-internal-format
+msgid "NAME= specifier at %C should be a constant expression"
+msgstr ""
+
+#: fortran/decl.cc:8271
+#, gcc-internal-format, gfc-internal-format
+msgid "NAME= specifier at %C should be a scalar of default character kind"
+msgstr ""
+
+#: fortran/decl.cc:8290
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing closing paren for binding label at %C"
+msgstr ""
+
+#: fortran/decl.cc:8296
+#, gcc-internal-format, gfc-internal-format
+msgid "No binding name is allowed in BIND(C) at %C"
+msgstr ""
+
+#: fortran/decl.cc:8302
+#, gcc-internal-format, gfc-internal-format
+msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
+msgstr ""
+
+#: fortran/decl.cc:8331
+#, gcc-internal-format, gfc-internal-format
+msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
+msgstr ""
+
+#: fortran/decl.cc:8578
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected END statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:8587
+#, gcc-internal-format, gfc-internal-format
+msgid "END statement instead of %s statement at %L"
+msgstr ""
+
+#. We would have required END [something].
+#: fortran/decl.cc:8596
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement expected at %L"
+msgstr ""
+
+#: fortran/decl.cc:8607
+#, gcc-internal-format, gfc-internal-format
+msgid "Expecting %s statement at %L"
+msgstr ""
+
+#: fortran/decl.cc:8627
+#, gcc-internal-format
+msgid "Expected block name of %qs in %s statement at %L"
+msgstr ""
+
+#: fortran/decl.cc:8644
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected terminating name at %C"
+msgstr ""
+
+#: fortran/decl.cc:8658 fortran/decl.cc:8666
+#, gcc-internal-format
+msgid "Expected label %qs for %s statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:8765
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing array specification at %L in DIMENSION statement"
+msgstr ""
+
+#: fortran/decl.cc:8773
+#, gcc-internal-format, gfc-internal-format
+msgid "Dimensions specified for %s at %L after its initialization"
+msgstr ""
+
+#: fortran/decl.cc:8781
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing array specification at %L in CODIMENSION statement"
+msgstr ""
+
+#: fortran/decl.cc:8790
+#, gcc-internal-format, gfc-internal-format
+msgid "Array specification must be deferred at %L"
+msgstr ""
+
+#: fortran/decl.cc:8895
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected character in variable list at %C"
+msgstr ""
+
+#: fortran/decl.cc:8932
+#, gcc-internal-format
+msgid "Expected %<(%> at %C"
+msgstr ""
+
+#: fortran/decl.cc:8946 fortran/decl.cc:8986
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected variable name at %C"
+msgstr ""
+
+#: fortran/decl.cc:8962
+#, gcc-internal-format, gfc-internal-format
+msgid "Cray pointer at %C must be an integer"
+msgstr ""
+
+#: fortran/decl.cc:8966
+#, gcc-internal-format, gfc-internal-format
+msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
+msgstr ""
+
+#: fortran/decl.cc:8972
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected \",\" at %C"
+msgstr ""
+
+#: fortran/decl.cc:9011
+#, gcc-internal-format
+msgid "Cannot set Cray pointee array spec."
+msgstr ""
+
+#: fortran/decl.cc:9035
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected \")\" at %C"
+msgstr ""
+
+#: fortran/decl.cc:9047
+#, gcc-internal-format
+msgid "Expected %<,%> or end of statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:9073
+#, gcc-internal-format, gfc-internal-format
+msgid "INTENT is not allowed inside of BLOCK at %C"
+msgstr ""
+
+#: fortran/decl.cc:9105
+#, gcc-internal-format, gfc-internal-format
+msgid "OPTIONAL is not allowed inside of BLOCK at %C"
+msgstr ""
+
+#: fortran/decl.cc:9124
+#, gcc-internal-format
+msgid "Cray pointer declaration at %C requires %<-fcray-pointer%> flag"
+msgstr ""
+
+#: fortran/decl.cc:9163
+#, gcc-internal-format, gfc-internal-format
+msgid "CONTIGUOUS statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:9261
+#, gcc-internal-format, gfc-internal-format
+msgid "Access specification of the %s operator at %C has already been specified"
+msgstr ""
+
+#: fortran/decl.cc:9277
+#, gcc-internal-format, gfc-internal-format
+msgid "Access specification of the .%s. operator at %C has already been specified"
+msgstr ""
+
+#: fortran/decl.cc:9325
+#, gcc-internal-format, gfc-internal-format
+msgid "PROTECTED statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:9359
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in PROTECTED statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:9386 fortran/decl.cc:9411
+#, gcc-internal-format, gfc-internal-format
+msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
+msgstr ""
+
+#: fortran/decl.cc:9432 fortran/decl.cc:9452
+#, gcc-internal-format, gfc-internal-format
+msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
+msgstr ""
+
+#: fortran/decl.cc:9474
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected variable name at %C in PARAMETER statement"
+msgstr ""
+
+#: fortran/decl.cc:9481
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected = sign in PARAMETER statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:9487
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected expression at %C in PARAMETER statement"
+msgstr ""
+
+#: fortran/decl.cc:9507
+#, gcc-internal-format, gfc-internal-format
+msgid "Initializing already initialized variable at %C"
+msgstr ""
+
+#. With legacy PARAMETER statements, don't expect a terminating ')'.
+#: fortran/decl.cc:9532
+#, gcc-internal-format, gfc-internal-format
+msgid "PARAMETER without '()' at %C"
+msgstr ""
+
+#: fortran/decl.cc:9548
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected characters in PARAMETER statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:9567 fortran/decl.cc:9623
+#, gcc-internal-format
+msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
+msgstr ""
+
+#: fortran/decl.cc:9602
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected entity-list in AUTOMATIC statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:9609
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in AUTOMATIC statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:9658
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected entity-list in STATIC statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:9665
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in STATIC statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:9684
+#, gcc-internal-format, gfc-internal-format
+msgid "Blanket SAVE statement at %C follows previous SAVE statement"
+msgstr ""
+
+#: fortran/decl.cc:9695
+#, gcc-internal-format, gfc-internal-format
+msgid "SAVE statement at %C follows blanket SAVE statement"
+msgstr ""
+
+#: fortran/decl.cc:9743
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in SAVE statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:9760
+#, gcc-internal-format, gfc-internal-format
+msgid "VALUE is not allowed inside of BLOCK at %C"
+msgstr ""
+
+#: fortran/decl.cc:9764
+#, gcc-internal-format, gfc-internal-format
+msgid "VALUE statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:9802
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in VALUE statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:9814
+#, gcc-internal-format, gfc-internal-format
+msgid "VOLATILE statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:9841
+#, gcc-internal-format
+msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
+msgstr ""
+
+#: fortran/decl.cc:9866
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in VOLATILE statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:9878
+#, gcc-internal-format, gfc-internal-format
+msgid "ASYNCHRONOUS statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:9922
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in ASYNCHRONOUS statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:9947
+#, gcc-internal-format, gfc-internal-format
+msgid "MODULE PROCEDURE declaration at %C"
+msgstr ""
+
+#: fortran/decl.cc:10058
+#, gcc-internal-format, gfc-internal-format
+msgid "MODULE PROCEDURE at %C must be in a generic module interface"
+msgstr ""
+
+#: fortran/decl.cc:10116
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
+msgstr ""
+
+#: fortran/decl.cc:10165
+#, gcc-internal-format, gfc-internal-format
+msgid "Ambiguous symbol in TYPE definition at %C"
+msgstr ""
+
+#: fortran/decl.cc:10174
+#, gcc-internal-format
+msgid "Symbol %qs at %C has not been previously defined"
+msgstr ""
+
+#: fortran/decl.cc:10180
+#, gcc-internal-format
+msgid "%qs in EXTENDS expression at %C is not a derived type"
+msgstr ""
+
+#: fortran/decl.cc:10187
+#, gcc-internal-format
+msgid "%qs cannot be extended at %C because it is BIND(C)"
+msgstr ""
+
+#: fortran/decl.cc:10194
+#, gcc-internal-format
+msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
+msgstr ""
+
+#: fortran/decl.cc:10217
+#, gcc-internal-format, gfc-internal-format
+msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
+msgstr ""
+
+#: fortran/decl.cc:10229
+#, gcc-internal-format, gfc-internal-format
+msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
+msgstr ""
+
+#: fortran/decl.cc:10250
+#, gcc-internal-format, gfc-internal-format
+msgid "ABSTRACT type at %C"
+msgstr ""
+
+#: fortran/decl.cc:10296
+#, gcc-internal-format, gfc-internal-format
+msgid "Failed to create structure type '%s' at %C"
+msgstr ""
+
+#: fortran/decl.cc:10302
+#, gcc-internal-format
+msgid "Type definition of %qs at %C was already defined at %L"
+msgstr ""
+
+#: fortran/decl.cc:10349
+#, gcc-internal-format, gfc-internal-format
+msgid "Junk after MAP statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:10382
+#, gcc-internal-format, gfc-internal-format
+msgid "Junk after UNION statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:10417
+#, gcc-internal-format
+msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
+msgstr ""
+
+#: fortran/decl.cc:10431
+#, gcc-internal-format, gfc-internal-format
+msgid "Structure name expected in non-nested structure declaration at %C"
+msgstr ""
+
+#: fortran/decl.cc:10449
+#, gcc-internal-format, gfc-internal-format
+msgid "Junk after non-nested STRUCTURE statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:10456
+#, gcc-internal-format
+msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
+msgstr ""
+
+#: fortran/decl.cc:10619
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected :: in TYPE definition at %C"
+msgstr ""
+
+#: fortran/decl.cc:10632
+#, gcc-internal-format, gfc-internal-format
+msgid "Mangled derived type definition at %C"
+msgstr ""
+
+#: fortran/decl.cc:10661
+#, gcc-internal-format
+msgid "Type name %qs at %C cannot be the same as an intrinsic type"
+msgstr ""
+
+#: fortran/decl.cc:10672
+#, gcc-internal-format
+msgid "Derived type name %qs at %C already has a basic type of %s"
+msgstr ""
+
+#: fortran/decl.cc:10675
+#, gcc-internal-format
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr ""
+
+#: fortran/decl.cc:10690
+#, gcc-internal-format
+msgid "Dummy argument %qs at %L cannot be a derived type at %C"
+msgstr ""
+
+#: fortran/decl.cc:10699
+#, gcc-internal-format
+msgid "Derived type definition of %qs at %C has already been defined"
+msgstr ""
+
+#: fortran/decl.cc:10762
+#, gcc-internal-format, gfc-internal-format
+msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
+msgstr ""
+
+#: fortran/decl.cc:10845
+#, gcc-internal-format, gfc-internal-format
+msgid "Cray Pointee at %C cannot be assumed shape array"
+msgstr ""
+
+#: fortran/decl.cc:10865
+#, gcc-internal-format, gfc-internal-format
+msgid "ENUM and ENUMERATOR at %C"
+msgstr ""
+
+#: fortran/decl.cc:10897
+#, gcc-internal-format, gfc-internal-format
+msgid "Enumerator exceeds the C integer type at %C"
+msgstr ""
+
+#: fortran/decl.cc:10976
+#, gcc-internal-format, gfc-internal-format
+msgid "ENUMERATOR %L not initialized with integer expression"
+msgstr ""
+
+#: fortran/decl.cc:11024
+#, gcc-internal-format, gfc-internal-format
+msgid "ENUM definition statement expected before %C"
+msgstr ""
+
+#: fortran/decl.cc:11060
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in ENUMERATOR definition at %C"
+msgstr ""
+
+#: fortran/decl.cc:11107 fortran/decl.cc:11122
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate access-specifier at %C"
+msgstr ""
+
+#: fortran/decl.cc:11142
+#, gcc-internal-format, gfc-internal-format
+msgid "Binding attributes already specify passing, illegal NOPASS at %C"
+msgstr ""
+
+#: fortran/decl.cc:11162
+#, gcc-internal-format, gfc-internal-format
+msgid "Binding attributes already specify passing, illegal PASS at %C"
+msgstr ""
+
+#: fortran/decl.cc:11189
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate POINTER attribute at %C"
+msgstr ""
+
+#: fortran/decl.cc:11207
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate NON_OVERRIDABLE at %C"
+msgstr ""
+
+#: fortran/decl.cc:11223
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate DEFERRED at %C"
+msgstr ""
+
+#: fortran/decl.cc:11236
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected access-specifier at %C"
+msgstr ""
+
+#: fortran/decl.cc:11238
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected binding attribute at %C"
+msgstr ""
+
+#: fortran/decl.cc:11246
+#, gcc-internal-format, gfc-internal-format
+msgid "NON_OVERRIDABLE and DEFERRED cannot both appear at %C"
+msgstr ""
+
+#: fortran/decl.cc:11259
+#, gcc-internal-format, gfc-internal-format
+msgid "POINTER attribute is required for procedure pointer component at %C"
+msgstr ""
+
+#: fortran/decl.cc:11301
+#, gcc-internal-format
+msgid "Interface-name expected after %<(%> at %C"
+msgstr ""
+
+#: fortran/decl.cc:11307
+#, gcc-internal-format
+msgid "%<)%> expected at %C"
+msgstr ""
+
+#: fortran/decl.cc:11327
+#, gcc-internal-format, gfc-internal-format
+msgid "Interface must be specified for DEFERRED binding at %C"
+msgstr ""
+
+#: fortran/decl.cc:11332
+#, gcc-internal-format, gfc-internal-format
+msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
+msgstr ""
+
+#: fortran/decl.cc:11355
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected binding name at %C"
+msgstr ""
+
+#: fortran/decl.cc:11359
+#, gcc-internal-format, gfc-internal-format
+msgid "PROCEDURE list at %C"
+msgstr ""
+
+#: fortran/decl.cc:11371
+#, gcc-internal-format
+msgid "%<=> target%> is invalid for DEFERRED binding at %C"
+msgstr ""
+
+#: fortran/decl.cc:11377
+#, gcc-internal-format
+msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
+msgstr ""
+
+#: fortran/decl.cc:11387
+#, gcc-internal-format
+msgid "Expected binding target after %<=>%> at %C"
+msgstr ""
+
+#: fortran/decl.cc:11404
+#, gcc-internal-format
+msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
+msgstr ""
+
+#: fortran/decl.cc:11415
+#, gcc-internal-format
+msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
+msgstr ""
+
+#: fortran/decl.cc:11466
+#, gcc-internal-format, gfc-internal-format
+msgid "GENERIC at %C must be inside a derived-type CONTAINS"
+msgstr ""
+
+#: fortran/decl.cc:11486
+#, gcc-internal-format
+msgid "Expected %<::%> at %C"
+msgstr ""
+
+#: fortran/decl.cc:11498
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected generic name or operator descriptor at %C"
+msgstr ""
+
+#: fortran/decl.cc:11519
+#, gcc-internal-format, gfc-internal-format
+msgid "Malformed GENERIC statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:11530
+#, gcc-internal-format
+msgid "Expected %<=>%> at %C"
+msgstr ""
+
+#: fortran/decl.cc:11566
+#, gcc-internal-format
+msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
+msgstr ""
+
+#: fortran/decl.cc:11574
+#, gcc-internal-format
+msgid "Binding at %C must have the same access as already defined binding %qs"
+msgstr ""
+
+#: fortran/decl.cc:11622
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected specific binding name at %C"
+msgstr ""
+
+#: fortran/decl.cc:11632
+#, gcc-internal-format
+msgid "%qs already defined as specific binding for the generic %qs at %C"
+msgstr ""
+
+#: fortran/decl.cc:11650
+#, gcc-internal-format, gfc-internal-format
+msgid "Junk after GENERIC binding at %C"
+msgstr ""
+
+#: fortran/decl.cc:11685
+#, gcc-internal-format, gfc-internal-format
+msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
+msgstr ""
+
+#: fortran/decl.cc:11697
+#, gcc-internal-format, gfc-internal-format
+msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
+msgstr ""
+
+#: fortran/decl.cc:11719
+#, gcc-internal-format, gfc-internal-format
+msgid "Empty FINAL at %C"
+msgstr ""
+
+#: fortran/decl.cc:11726
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected module procedure name at %C"
+msgstr ""
+
+#: fortran/decl.cc:11736
+#, gcc-internal-format
+msgid "Expected %<,%> at %C"
+msgstr ""
+
+#: fortran/decl.cc:11742
+#, gcc-internal-format
+msgid "Unknown procedure name %qs at %C"
+msgstr ""
+
+#: fortran/decl.cc:11755
+#, gcc-internal-format
+msgid "%qs at %C is already defined as FINAL procedure"
+msgstr ""
+
+#: fortran/decl.cc:11829
+#, gcc-internal-format, gfc-internal-format
+msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:11875
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
+msgstr ""
+
+#: fortran/decl.cc:11896
+#, gcc-internal-format
+msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
+msgstr ""
+
+#: fortran/decl.cc:11910
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in !GCC$ UNROLL directive at %C"
+msgstr ""
+
+#: fortran/decl.cc:11974
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in !GCC$ IVDEP directive at %C"
+msgstr ""
+
+#: fortran/decl.cc:11991
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in !GCC$ VECTOR directive at %C"
+msgstr ""
+
+#: fortran/decl.cc:12008
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in !GCC$ NOVECTOR directive at %C"
+msgstr ""
+
+#: fortran/dependency.cc:106
+#, gcc-internal-format
+msgid "identical_array_ref(): inconsistent dimensions"
+msgstr ""
+
+#: fortran/dependency.cc:199
+#, gcc-internal-format
+msgid "are_identical_variables: Bad type"
+msgstr ""
+
+#: fortran/dependency.cc:1021
+#, gcc-internal-format, gfc-internal-format
+msgid "INTENT(%s) actual argument at %L might interfere with actual argument at %L."
+msgstr ""
+
+#: fortran/dependency.cc:1325
+#, gcc-internal-format
+msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
+msgstr ""
+
+#: fortran/dump-parse-tree.cc:296
+#, gcc-internal-format
+msgid "show_array_spec(): Unhandled array shape type."
+msgstr ""
+
+#: fortran/dump-parse-tree.cc:375
+#, gcc-internal-format
+msgid "show_array_ref(): Unknown array reference"
+msgstr ""
+
+#: fortran/dump-parse-tree.cc:449
+#, gcc-internal-format
+msgid "show_ref(): Bad component code"
+msgstr ""
+
+#: fortran/dump-parse-tree.cc:722
+#, gcc-internal-format
+msgid "show_expr(): Bad intrinsic in expression"
+msgstr ""
+
+#: fortran/dump-parse-tree.cc:765
+#, gcc-internal-format
+msgid "show_expr(): Don't know how to show expr"
+msgstr ""
+
+#: fortran/dump-parse-tree.cc:3567
+#, gcc-internal-format
+msgid "show_code_node(): Bad statement code"
+msgstr ""
+
+#: fortran/dump-parse-tree.cc:3903 fortran/dump-parse-tree.cc:4008
+#, gcc-internal-format
+msgid "Cannot convert %qs to interoperable type at %L"
+msgstr ""
+
+#: fortran/error.cc:388
+#, gcc-internal-format, gfc-internal-format
+msgid "    Included at %s:%d:"
+msgstr ""
+
+#: fortran/error.cc:474
+#, gcc-internal-format
+msgid "<During initialization>\n"
+msgstr ""
+
+#: fortran/expr.cc:149
+#, gcc-internal-format
+msgid "gfc_get_constant_expr(): locus %<where%> cannot be NULL"
+msgstr ""
+
+#: fortran/expr.cc:357
+#, gcc-internal-format
+msgid "gfc_copy_expr(): Bad expr node"
+msgstr ""
+
+#: fortran/expr.cc:514
+#, gcc-internal-format
+msgid "free_expr0(): Bad expr type"
+msgstr ""
+
+#: fortran/expr.cc:669 fortran/expr.cc:671 fortran/expr.cc:722
+#: fortran/expr.cc:724
+#, gcc-internal-format, gfc-internal-format
+msgid "Constant expression required at %C"
+msgstr ""
+
+#: fortran/expr.cc:678 fortran/expr.cc:680 fortran/expr.cc:731
+#: fortran/expr.cc:733
+#, gcc-internal-format, gfc-internal-format
+msgid "Integer expression required at %C"
+msgstr ""
+
+#: fortran/expr.cc:688 fortran/expr.cc:690 fortran/expr.cc:744
+#: fortran/expr.cc:746
+#, gcc-internal-format, gfc-internal-format
+msgid "Integer value too large in expression at %C"
+msgstr ""
+
+#: fortran/expr.cc:1117
+#, gcc-internal-format
+msgid "gfc_is_constant_expr(): Unknown expression type"
+msgstr ""
+
+#: fortran/expr.cc:1312
+#, gcc-internal-format
+msgid "simplify_intrinsic_op(): Bad operator"
+msgstr ""
+
+#: fortran/expr.cc:1417
+#, gcc-internal-format, gfc-internal-format
+msgid "Index in dimension %d is out of bounds at %L"
+msgstr ""
+
+#: fortran/expr.cc:1616 fortran/expr.cc:1667
+#, gcc-internal-format, gfc-internal-format
+msgid "index in dimension %d is out of bounds at %L"
+msgstr ""
+
+#: fortran/expr.cc:1742
+#, gcc-internal-format
+msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option"
+msgstr ""
+
+#: fortran/expr.cc:1753
+#, gcc-internal-format, gfc-internal-format
+msgid "Error in array constructor referenced at %L"
+msgstr ""
+
+#: fortran/expr.cc:1861 fortran/primary.cc:2398 fortran/primary.cc:2575
+#, gcc-internal-format, gfc-internal-format
+msgid "LEN part_ref at %C"
+msgstr ""
+
+#: fortran/expr.cc:1886 fortran/primary.cc:2393 fortran/primary.cc:2590
+#, gcc-internal-format, gfc-internal-format
+msgid "KIND part_ref at %C"
+msgstr ""
+
+#: fortran/expr.cc:1897
+#, gcc-internal-format, gfc-internal-format
+msgid "RE part_ref at %C"
+msgstr ""
+
+#: fortran/expr.cc:1909
+#, gcc-internal-format, gfc-internal-format
+msgid "IM part_ref at %C"
+msgstr ""
+
+#: fortran/expr.cc:2559
+#, gcc-internal-format, gfc-internal-format
+msgid "elemental function arguments at %C are not compliant"
+msgstr ""
+
+#: fortran/expr.cc:2603
+#, gcc-internal-format, gfc-internal-format
+msgid "Numeric or CHARACTER operands are required in expression at %L"
+msgstr ""
+
+#: fortran/expr.cc:2628
+#, gcc-internal-format, gfc-internal-format
+msgid "Concatenation operator in expression at %L must have two CHARACTER operands"
+msgstr ""
+
+#: fortran/expr.cc:2635
+#, gcc-internal-format, gfc-internal-format
+msgid "Concat operator at %L must concatenate strings of the same kind"
+msgstr ""
+
+#: fortran/expr.cc:2645
+#, gcc-internal-format, gfc-internal-format
+msgid ".NOT. operator in expression at %L must have a LOGICAL operand"
+msgstr ""
+
+#: fortran/expr.cc:2661
+#, gcc-internal-format, gfc-internal-format
+msgid "LOGICAL operands are required in expression at %L"
+msgstr ""
+
+#: fortran/expr.cc:2672
+#, gcc-internal-format, gfc-internal-format
+msgid "Only intrinsic operators can be used in expression at %L"
+msgstr ""
+
+#: fortran/expr.cc:2680
+#, gcc-internal-format, gfc-internal-format
+msgid "Numeric operands are required in expression at %L"
+msgstr ""
+
+#: fortran/expr.cc:2703
+#, gcc-internal-format
+msgid "Invalid initialization expression for ALLOCATABLE component %qs in structure constructor at %L"
+msgstr ""
+
+#: fortran/expr.cc:2840
+#, gcc-internal-format
+msgid "Assumed or deferred character length variable %qs in constant expression at %L"
+msgstr ""
+
+#: fortran/expr.cc:2915
+#, gcc-internal-format
+msgid "transformational intrinsic %qs at %L is not permitted in an initialization expression"
+msgstr ""
+
+#: fortran/expr.cc:2946
+#, gcc-internal-format, gfc-internal-format
+msgid "Evaluation of nonstandard initialization expression at %L"
+msgstr ""
+
+#: fortran/expr.cc:3023 fortran/resolve.cc:2862
+#, gcc-internal-format
+msgid "Function %qs in initialization expression at %L must be an intrinsic function"
+msgstr ""
+
+#: fortran/expr.cc:3035
+#, gcc-internal-format
+msgid "Intrinsic function %qs at %L is not permitted in an initialization expression"
+msgstr ""
+
+#: fortran/expr.cc:3074
+#, gcc-internal-format
+msgid "PARAMETER %qs is used at %L before its definition is complete"
+msgstr ""
+
+#: fortran/expr.cc:3094
+#, gcc-internal-format
+msgid "Assumed size array %qs at %L is not permitted in an initialization expression"
+msgstr ""
+
+#: fortran/expr.cc:3100
+#, gcc-internal-format
+msgid "Assumed shape array %qs at %L is not permitted in an initialization expression"
+msgstr ""
+
+#: fortran/expr.cc:3109
+#, gcc-internal-format
+msgid "Assumed-shape array %qs at %L is not permitted in an initialization expression"
+msgstr ""
+
+#: fortran/expr.cc:3113
+#, gcc-internal-format
+msgid "Deferred array %qs at %L is not permitted in an initialization expression"
+msgstr ""
+
+#: fortran/expr.cc:3119
+#, gcc-internal-format
+msgid "Array %qs at %L is a variable, which does not reduce to a constant expression"
+msgstr ""
+
+#: fortran/expr.cc:3125
+#, gcc-internal-format
+msgid "Assumed-rank array %qs at %L is not permitted in an initialization expression"
+msgstr ""
+
+#: fortran/expr.cc:3135
+#, gcc-internal-format
+msgid "Parameter %qs at %L has not been declared or is a variable, which does not reduce to a constant expression"
+msgstr ""
+
+#: fortran/expr.cc:3189
+#, gcc-internal-format
+msgid "check_init_expr(): Unknown expression type"
+msgstr ""
+
+#: fortran/expr.cc:3329
+#, gcc-internal-format
+msgid "Specification function %qs at %L cannot be a statement function"
+msgstr ""
+
+#: fortran/expr.cc:3336
+#, gcc-internal-format
+msgid "Specification function %qs at %L cannot be an internal function"
+msgstr ""
+
+#: fortran/expr.cc:3343
+#, gcc-internal-format
+msgid "Specification function %qs at %L must be PURE"
+msgstr ""
+
+#: fortran/expr.cc:3351
+#, gcc-internal-format
+msgid "Specification function %qs at %L cannot be RECURSIVE"
+msgstr ""
+
+#: fortran/expr.cc:3498
+#, gcc-internal-format
+msgid "Dummy argument %qs not allowed in expression at %L"
+msgstr ""
+
+#: fortran/expr.cc:3506
+#, gcc-internal-format
+msgid "Dummy argument %qs at %L cannot be OPTIONAL"
+msgstr ""
+
+#: fortran/expr.cc:3513
+#, gcc-internal-format
+msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
+msgstr ""
+
+#: fortran/expr.cc:3535
+#, gcc-internal-format
+msgid "Variable %qs cannot appear in the expression at %L"
+msgstr ""
+
+#: fortran/expr.cc:3566
+#, gcc-internal-format
+msgid "check_restricted(): Unknown expression type"
+msgstr ""
+
+#: fortran/expr.cc:3586
+#, gcc-internal-format, gfc-internal-format
+msgid "Expression at %L must be of INTEGER type, found %s"
+msgstr ""
+
+#: fortran/expr.cc:3598
+#, gcc-internal-format
+msgid "Function %qs at %L must be PURE"
+msgstr ""
+
+#: fortran/expr.cc:3607
+#, gcc-internal-format, gfc-internal-format
+msgid "Expression at %L must be scalar"
+msgstr ""
+
+#. Reject truncation.
+#: fortran/expr.cc:3639
+#, gcc-internal-format, gfc-internal-format
+msgid "optype_msgid overflow: %d"
+msgstr ""
+
+#: fortran/expr.cc:3643
+#, gcc-internal-format, gfc-internal-format
+msgid "Incompatible ranks in %s (%d and %d) at %L"
+msgstr ""
+
+#: fortran/expr.cc:3657
+#, gcc-internal-format, gfc-internal-format
+msgid "Different shape for %s at %L on dimension %d (%d and %d)"
+msgstr ""
+
+#: fortran/expr.cc:3705
+#, gcc-internal-format, gfc-internal-format
+msgid "Assignment to a LEN or KIND part_ref at %L is not allowed"
+msgstr ""
+
+#: fortran/expr.cc:3761
+#, gcc-internal-format
+msgid "%qs at %L is not a VALUE"
+msgstr ""
+
+#: fortran/expr.cc:3772
+#, gcc-internal-format, gfc-internal-format
+msgid "Illegal assignment to external procedure at %L"
+msgstr ""
+
+#: fortran/expr.cc:3780
+#, gcc-internal-format, gfc-internal-format
+msgid "Incompatible ranks %d and %d in assignment at %L"
+msgstr ""
+
+#: fortran/expr.cc:3787
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable type is UNKNOWN in assignment at %L"
+msgstr ""
+
+#: fortran/expr.cc:3799
+#, gcc-internal-format, gfc-internal-format
+msgid "NULL appears on right-hand side in assignment at %L"
+msgstr ""
+
+#: fortran/expr.cc:3809
+#, gcc-internal-format, gfc-internal-format
+msgid "POINTER-valued function appears on right-hand side of assignment at %L"
+msgstr ""
+
+#: fortran/expr.cc:3852
+#, gcc-internal-format
+msgid "BOZ literal constant near %L cannot be assigned to a %qs variable"
+msgstr ""
+
+#: fortran/expr.cc:3859
+#, gcc-internal-format, gfc-internal-format
+msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
+msgstr ""
+
+#: fortran/expr.cc:3889
+#, gcc-internal-format, gfc-internal-format
+msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
+msgstr ""
+
+#: fortran/expr.cc:3933
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer assignment target is not a POINTER at %L"
+msgstr ""
+
+#: fortran/expr.cc:3941
+#, gcc-internal-format
+msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
+msgstr ""
+
+#: fortran/expr.cc:3965
+#, gcc-internal-format
+msgid "Expected bounds specification for %qs at %L"
+msgstr ""
+
+#: fortran/expr.cc:3970
+#, gcc-internal-format
+msgid "Bounds specification for %qs in pointer assignment at %L"
+msgstr ""
+
+#: fortran/expr.cc:3999
+#, gcc-internal-format, gfc-internal-format
+msgid "Stride must not be present at %L"
+msgstr ""
+
+#: fortran/expr.cc:4005 fortran/expr.cc:4025
+#, gcc-internal-format
+msgid "Rank remapping requires a list of %<lower-bound : upper-bound%> specifications at %L"
+msgstr ""
+
+#: fortran/expr.cc:4013 fortran/expr.cc:4032
+#, gcc-internal-format
+msgid "Expected list of %<lower-bound :%> or list of %<lower-bound : upper-bound%> specifications at %L"
+msgstr ""
+
+#: fortran/expr.cc:4059
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer object at %L shall not have a coindex"
+msgstr ""
+
+#: fortran/expr.cc:4080
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid procedure pointer assignment at %L"
+msgstr ""
+
+#: fortran/expr.cc:4105
+#, gcc-internal-format
+msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
+msgstr ""
+
+#: fortran/expr.cc:4114
+#, gcc-internal-format
+msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
+msgstr ""
+
+#: fortran/expr.cc:4124
+#, gcc-internal-format
+msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
+msgstr ""
+
+#: fortran/expr.cc:4130
+#, gcc-internal-format
+msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
+msgstr ""
+
+#: fortran/expr.cc:4137
+#, gcc-internal-format
+msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
+msgstr ""
+
+#: fortran/expr.cc:4145
+#, gcc-internal-format
+msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
+msgstr ""
+
+#: fortran/expr.cc:4168
+#, gcc-internal-format, gfc-internal-format
+msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
+msgstr ""
+
+#: fortran/expr.cc:4221
+#, gcc-internal-format
+msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
+msgstr ""
+
+#: fortran/expr.cc:4231 fortran/expr.cc:4246
+#, gcc-internal-format
+msgid "Explicit interface required for component %qs at %L: %s"
+msgstr ""
+
+#: fortran/expr.cc:4237 fortran/expr.cc:4252 fortran/resolve.cc:2742
+#, gcc-internal-format
+msgid "Explicit interface required for %qs at %L: %s"
+msgstr ""
+
+#: fortran/expr.cc:4264
+#, gcc-internal-format, gfc-internal-format
+msgid "Interface mismatch in procedure pointer assignment at %L: %s"
+msgstr ""
+
+#: fortran/expr.cc:4273
+#, gcc-internal-format
+msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
+msgstr ""
+
+#: fortran/expr.cc:4286
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer assignment target cannot be a constant at %L"
+msgstr ""
+
+#: fortran/expr.cc:4300
+#, gcc-internal-format, gfc-internal-format
+msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
+msgstr ""
+
+#: fortran/expr.cc:4305
+#, gcc-internal-format, gfc-internal-format
+msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
+msgstr ""
+
+#: fortran/expr.cc:4313
+#, gcc-internal-format, gfc-internal-format
+msgid "Different kind type parameters in pointer assignment at %L"
+msgstr ""
+
+#: fortran/expr.cc:4320
+#, gcc-internal-format, gfc-internal-format
+msgid "Different ranks in pointer assignment at %L"
+msgstr ""
+
+#: fortran/expr.cc:4339
+#, gcc-internal-format, gfc-internal-format
+msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
+msgstr ""
+
+#: fortran/expr.cc:4352
+#, gcc-internal-format, gfc-internal-format
+msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
+msgstr ""
+
+#: fortran/expr.cc:4356
+#, gcc-internal-format, gfc-internal-format
+msgid "Rank remapping target is not rank 1 at %L"
+msgstr ""
+
+#. The test above might need to be extend when F08, Note 5.4 has to be
+#. interpreted in the way that target and pointer with the same coindex
+#. are allowed.
+#: fortran/expr.cc:4381 fortran/expr.cc:4507
+#, gcc-internal-format, gfc-internal-format
+msgid "Data target at %L shall not have a coindex"
+msgstr ""
+
+#: fortran/expr.cc:4384
+#, gcc-internal-format, gfc-internal-format
+msgid "Target expression in pointer assignment at %L must deliver a pointer result"
+msgstr ""
+
+#: fortran/expr.cc:4398
+#, gcc-internal-format, gfc-internal-format
+msgid "Zero-sized array detected at %L where an entity with the TARGET attribute is expected"
+msgstr ""
+
+#: fortran/expr.cc:4404 fortran/expr.cc:4419
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer assignment target in initialization expression does not have the TARGET attribute at %L"
+msgstr ""
+
+#: fortran/expr.cc:4435
+#, gcc-internal-format, gfc-internal-format
+msgid "Every subscript of target specification at %L must be a constant expression"
+msgstr ""
+
+#: fortran/expr.cc:4446
+#, gcc-internal-format, gfc-internal-format
+msgid "Substring starting and ending points of target specification at %L must be constant expressions"
+msgstr ""
+
+#: fortran/expr.cc:4462
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
+msgstr ""
+
+#: fortran/expr.cc:4477
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad target in pointer assignment in PURE procedure at %L"
+msgstr ""
+
+#: fortran/expr.cc:4486
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer assignment with vector subscript on rhs at %L"
+msgstr ""
+
+#: fortran/expr.cc:4494
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer assignment target has PROTECTED attribute at %L"
+msgstr ""
+
+#: fortran/expr.cc:4522 fortran/expr.cc:4527
+#, gcc-internal-format, gfc-internal-format
+msgid "Assignment to contiguous pointer from non-contiguous target at %L"
+msgstr ""
+
+#: fortran/expr.cc:4567
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer at %L in pointer assignment might outlive the pointer target"
+msgstr ""
+
+#: fortran/expr.cc:4643 fortran/resolve.cc:1565
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer initialization target at %L must not be ALLOCATABLE"
+msgstr ""
+
+#: fortran/expr.cc:4649
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer initialization target at %L must have the TARGET attribute"
+msgstr ""
+
+#: fortran/expr.cc:4664 fortran/resolve.cc:1571
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer initialization target at %L must have the SAVE attribute"
+msgstr ""
+
+#: fortran/expr.cc:4676
+#, gcc-internal-format, gfc-internal-format
+msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
+msgstr ""
+
+#: fortran/expr.cc:4682
+#, gcc-internal-format
+msgid "Internal procedure %qs is invalid in procedure pointer initialization at %L"
+msgstr ""
+
+#: fortran/expr.cc:4689
+#, gcc-internal-format
+msgid "Dummy procedure %qs is invalid in procedure pointer initialization at %L"
+msgstr ""
+
+#: fortran/expr.cc:5157
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr ""
+
+#: fortran/expr.cc:6272
+#, gcc-internal-format, gfc-internal-format
+msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.cc:6280
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-variable expression in variable definition context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.cc:6288
+#, gcc-internal-format
+msgid "Named constant %qs in variable definition context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.cc:6299
+#, gcc-internal-format
+msgid "%qs in variable definition context (%s) at %L is not a variable"
+msgstr ""
+
+#: fortran/expr.cc:6310
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-POINTER in pointer association context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.cc:6319
+#, gcc-internal-format, gfc-internal-format
+msgid "Type inaccessible in variable definition context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.cc:6332
+#, gcc-internal-format, gfc-internal-format
+msgid "LOCK_TYPE in variable definition context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.cc:6345
+#, gcc-internal-format, gfc-internal-format
+msgid "LOCK_EVENT in variable definition context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.cc:6376
+#, gcc-internal-format
+msgid "%qs parameter inquiry for %qs in variable definition context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.cc:6393
+#, gcc-internal-format
+msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.cc:6403
+#, gcc-internal-format
+msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.cc:6416
+#, gcc-internal-format
+msgid "Variable %qs is PROTECTED and cannot appear in a pointer association context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.cc:6424
+#, gcc-internal-format
+msgid "Variable %qs is PROTECTED and cannot appear in a variable definition context (%s) at %L"
+msgstr ""
+
+#: fortran/expr.cc:6439
+#, gcc-internal-format
+msgid "Variable %qs cannot appear in a variable definition context (%s) at %L in PURE procedure"
+msgstr ""
+
+#: fortran/expr.cc:6499 fortran/expr.cc:6520
+#, gcc-internal-format
+msgid "%qs at %L associated to vector-indexed target cannot be used in a variable definition context (%s)"
+msgstr ""
+
+#: fortran/expr.cc:6504
+#, gcc-internal-format
+msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
+msgstr ""
+
+#: fortran/expr.cc:6513
+#, gcc-internal-format
+msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
+msgstr ""
+
+#: fortran/expr.cc:6532
+#, gcc-internal-format
+msgid "Associate-name %qs cannot appear in a variable definition context (%s) at %L because its target at %L cannot, either"
+msgstr ""
+
+#: fortran/expr.cc:6574
+#, gcc-internal-format, gfc-internal-format
+msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
+msgstr ""
+
+#: fortran/frontend-passes.cc:195
+#, gcc-internal-format
+msgid "Inconsistent internal state: No location in statement"
+msgstr ""
+
+#: fortran/frontend-passes.cc:211
+#, gcc-internal-format, gfc-internal-format
+msgid "Inconsistent internal state: No location in expression near %L"
+msgstr ""
+
+#: fortran/frontend-passes.cc:419
+#, gcc-internal-format
+msgid "Illegal id in copy_walk_reduction_arg"
+msgstr ""
+
+#: fortran/frontend-passes.cc:870 fortran/trans-array.cc:1514
+#: fortran/trans-array.cc:7206 fortran/trans-array.cc:8880
+#: fortran/trans-intrinsic.cc:8502
+#, gcc-internal-format, gfc-internal-format
+msgid "Creating array temporary at %L"
+msgstr ""
+
+#: fortran/frontend-passes.cc:897
+#, gcc-internal-format
+msgid "Removing call to impure function %qs at %L"
+msgstr ""
+
+#: fortran/frontend-passes.cc:901
+#, gcc-internal-format, gfc-internal-format
+msgid "Removing call to impure function at %L"
+msgstr ""
+
+#: fortran/frontend-passes.cc:1356 fortran/frontend-passes.cc:1395
+#, gcc-internal-format
+msgid "bad expression"
+msgstr ""
+
+#: fortran/frontend-passes.cc:1391
+#, gcc-internal-format
+msgid "bad op"
+msgstr ""
+
+#: fortran/frontend-passes.cc:2175
+#, gcc-internal-format
+msgid "illegal OP in optimize_comparison"
+msgstr ""
+
+#: fortran/frontend-passes.cc:2352
+#, gcc-internal-format
+msgid "Index variable %qs set to undefined as INTENT(OUT) argument at %L in procedure %qs called from within DO loop at %L"
+msgstr ""
+
+#: fortran/frontend-passes.cc:2361
+#, gcc-internal-format
+msgid "Index variable %qs not definable as INTENT(INOUT) argument at %L in procedure %qs called from within DO loop at %L"
+msgstr ""
+
+#: fortran/frontend-passes.cc:2499
+#, gcc-internal-format
+msgid "Index variable %qs set to undefined as INTENT(OUT) argument at %L in subroutine %qs called from within DO loop at %L"
+msgstr ""
+
+#: fortran/frontend-passes.cc:2508
+#, gcc-internal-format
+msgid "Index variable %qs not definable as INTENT(INOUT) argument at %L in subroutine %qs called from within DO loop at %L"
+msgstr ""
+
+#: fortran/frontend-passes.cc:2661
+#, gcc-internal-format
+msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to subroutine %qs"
+msgstr ""
+
+#: fortran/frontend-passes.cc:2668
+#, gcc-internal-format
+msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
+msgstr ""
+
+#: fortran/frontend-passes.cc:2931 fortran/frontend-passes.cc:2957
+#, gcc-internal-format, gfc-internal-format
+msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
+msgstr ""
+
+#: fortran/frontend-passes.cc:2941 fortran/frontend-passes.cc:2967
+#, gcc-internal-format, gfc-internal-format
+msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
+msgstr ""
+
+#: fortran/frontend-passes.cc:3059
+#, gcc-internal-format
+msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
+msgstr ""
+
+#: fortran/frontend-passes.cc:3065
+#, gcc-internal-format
+msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
+msgstr ""
+
+#: fortran/frontend-passes.cc:3481 fortran/trans-expr.cc:1938
+#, gcc-internal-format, gfc-internal-format
+msgid "Code for reallocating the allocatable array at %L will be added"
+msgstr ""
+
+#: fortran/frontend-passes.cc:4006
+#, gcc-internal-format
+msgid "Scalarization using DIMEN_RANGE unimplemented"
+msgstr ""
+
+#: fortran/frontend-passes.cc:5215
+#, gcc-internal-format, gfc-internal-format
+msgid "Interchanging loops at %L"
+msgstr ""
+
+#: fortran/frontend-passes.cc:5855
+#, gcc-internal-format, gfc-internal-format
+msgid "%s between %L and %L"
+msgstr ""
+
+#: fortran/gfortranspec.cc:146 m2/gm2spec.cc:250
+#, gcc-internal-format
+msgid "overflowed output argument list for %qs"
+msgstr ""
+
+#: fortran/gfortranspec.cc:301
+#, gcc-internal-format
+msgid "no input files; unwilling to write output files"
+msgstr ""
+
+#: fortran/interface.cc:254
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in generic specification at %C"
+msgstr ""
+
+#: fortran/interface.cc:281
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error: Trailing garbage in INTERFACE statement at %C"
+msgstr ""
+
+#: fortran/interface.cc:301
+#, gcc-internal-format
+msgid "Dummy procedure %qs at %C cannot have a generic interface"
+msgstr ""
+
+#: fortran/interface.cc:334
+#, gcc-internal-format, gfc-internal-format
+msgid "ABSTRACT INTERFACE at %C"
+msgstr ""
+
+#: fortran/interface.cc:341
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in ABSTRACT INTERFACE statement at %C"
+msgstr ""
+
+#: fortran/interface.cc:372
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error: Trailing garbage in END INTERFACE statement at %C"
+msgstr ""
+
+#: fortran/interface.cc:385
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected a nameless interface at %C"
+msgstr ""
+
+#: fortran/interface.cc:398
+#, gcc-internal-format
+msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
+msgstr ""
+
+#: fortran/interface.cc:429
+#, gcc-internal-format
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C"
+msgstr ""
+
+#: fortran/interface.cc:432
+#, gcc-internal-format
+msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %qs"
+msgstr ""
+
+#: fortran/interface.cc:446
+#, gcc-internal-format
+msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
+msgstr ""
+
+#: fortran/interface.cc:458
+#, gcc-internal-format
+msgid "Expecting %<END INTERFACE %s%> at %C"
+msgstr ""
+
+#: fortran/interface.cc:648
+#, gcc-internal-format
+msgid "gfc_compare_derived_types: invalid derived type"
+msgstr ""
+
+#: fortran/interface.cc:936
+#, gcc-internal-format, gfc-internal-format
+msgid "Alternate return cannot appear in operator interface at %L"
+msgstr ""
+
+#: fortran/interface.cc:965
+#, gcc-internal-format, gfc-internal-format
+msgid "Assignment operator interface at %L must have two arguments"
+msgstr ""
+
+#: fortran/interface.cc:968
+#, gcc-internal-format, gfc-internal-format
+msgid "Operator interface at %L has the wrong number of arguments"
+msgstr ""
+
+#: fortran/interface.cc:981
+#, gcc-internal-format, gfc-internal-format
+msgid "Assignment operator interface at %L must be a SUBROUTINE"
+msgstr ""
+
+#: fortran/interface.cc:999
+#, gcc-internal-format, gfc-internal-format
+msgid "Assignment operator interface at %L must not redefine an INTRINSIC type assignment"
+msgstr ""
+
+#: fortran/interface.cc:1008
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic operator interface at %L must be a FUNCTION"
+msgstr ""
+
+#: fortran/interface.cc:1019
+#, gcc-internal-format, gfc-internal-format
+msgid "First argument of defined assignment at %L must be INTENT(OUT) or INTENT(INOUT)"
+msgstr ""
+
+#: fortran/interface.cc:1026
+#, gcc-internal-format, gfc-internal-format
+msgid "Second argument of defined assignment at %L must be INTENT(IN)"
+msgstr ""
+
+#: fortran/interface.cc:1035 fortran/resolve.cc:18237
+#, gcc-internal-format, gfc-internal-format
+msgid "First argument of operator interface at %L must be INTENT(IN)"
+msgstr ""
+
+#: fortran/interface.cc:1042 fortran/resolve.cc:18255
+#, gcc-internal-format, gfc-internal-format
+msgid "Second argument of operator interface at %L must be INTENT(IN)"
+msgstr ""
+
+#: fortran/interface.cc:1147
+#, gcc-internal-format, gfc-internal-format
+msgid "Operator interface at %L conflicts with intrinsic interface"
+msgstr ""
+
+#: fortran/interface.cc:1511 fortran/interface.cc:1583
+#, gcc-internal-format, gfc-internal-format
+msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
+msgstr ""
+
+#: fortran/interface.cc:1696
+#, gcc-internal-format, gfc-internal-format
+msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
+msgstr ""
+
+#: fortran/interface.cc:1743
+#, gcc-internal-format, gfc-internal-format
+msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
+msgstr ""
+
+#: fortran/interface.cc:1940
+#, gcc-internal-format
+msgid "Procedure %qs in %s at %L has no explicit interface; did you mean %qs?"
+msgstr ""
+
+#: fortran/interface.cc:1945
+#, gcc-internal-format
+msgid "Procedure %qs in %s at %L has no explicit interface"
+msgstr ""
+
+#: fortran/interface.cc:1949
+#, gcc-internal-format
+msgid "Procedure %qs in %s at %L is neither function nor subroutine; did you mean %qs?"
+msgstr ""
+
+#: fortran/interface.cc:1953
+#, gcc-internal-format
+msgid "Procedure %qs in %s at %L is neither function nor subroutine"
+msgstr ""
+
+#: fortran/interface.cc:1965
+#, gcc-internal-format, gfc-internal-format
+msgid "In %s at %L procedures must be either all SUBROUTINEs or all FUNCTIONs"
+msgstr ""
+
+#: fortran/interface.cc:1969
+#, gcc-internal-format, gfc-internal-format
+msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
+msgstr ""
+
+#: fortran/interface.cc:1977
+#, gcc-internal-format
+msgid "Internal procedure %qs in %s at %L"
+msgstr ""
+
+#: fortran/interface.cc:2034 fortran/interface.cc:2039
+#, gcc-internal-format
+msgid "Ambiguous interfaces in %s for %qs at %L and %qs at %L"
+msgstr ""
+
+#: fortran/interface.cc:2044
+#, gcc-internal-format
+msgid "Although not referenced, %qs has ambiguous interfaces at %L"
+msgstr ""
+
+#: fortran/interface.cc:2082
+#, gcc-internal-format
+msgid "%qs at %L is not a module procedure"
+msgstr ""
+
+#: fortran/interface.cc:2287
+#, gcc-internal-format
+msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
+msgstr ""
+
+#: fortran/interface.cc:2290
+#, gcc-internal-format
+msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
+msgstr ""
+
+#: fortran/interface.cc:2293
+#, gcc-internal-format
+msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
+msgstr ""
+
+#: fortran/interface.cc:2296
+#, gcc-internal-format
+msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
+msgstr ""
+
+#: fortran/interface.cc:2308
+#, gcc-internal-format, gfc-internal-format
+msgid "Rank mismatch between actual argument at %L and actual argument at %L (scalar and rank-%d)"
+msgstr ""
+
+#: fortran/interface.cc:2312
+#, gcc-internal-format, gfc-internal-format
+msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and scalar)"
+msgstr ""
+
+#: fortran/interface.cc:2316
+#, gcc-internal-format, gfc-internal-format
+msgid "Rank mismatch between actual argument at %L and actual argument at %L (rank-%d and rank-%d)"
+msgstr ""
+
+#: fortran/interface.cc:2439
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid procedure argument at %L"
+msgstr ""
+
+#: fortran/interface.cc:2448 fortran/interface.cc:2457
+#: fortran/interface.cc:2484
+#, gcc-internal-format
+msgid "Interface mismatch in dummy procedure %qs at %L: %s"
+msgstr ""
+
+#: fortran/interface.cc:2495
+#, gcc-internal-format
+msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
+msgstr ""
+
+#: fortran/interface.cc:2518
+#, gcc-internal-format, gfc-internal-format
+msgid "Type mismatch between actual argument at %L and actual argument at %L (%s/%s)."
+msgstr ""
+
+#: fortran/interface.cc:2528
+#, gcc-internal-format
+msgid "Type mismatch in argument %qs at %L; passed %s to %s"
+msgstr ""
+
+#: fortran/interface.cc:2538
+#, gcc-internal-format
+msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
+msgstr ""
+
+#: fortran/interface.cc:2552
+#, gcc-internal-format
+msgid "Assumed-type actual argument at %L corresponding to assumed-rank dummy argument %qs must be assumed-shape or assumed-rank"
+msgstr ""
+
+#: fortran/interface.cc:2569
+#, gcc-internal-format
+msgid "Actual argument to %qs at %L must be polymorphic"
+msgstr ""
+
+#: fortran/interface.cc:2579
+#, gcc-internal-format
+msgid "Actual argument to %qs at %L must have the same declared type"
+msgstr ""
+
+#: fortran/interface.cc:2594
+#, gcc-internal-format
+msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
+msgstr ""
+
+#: fortran/interface.cc:2610
+#, gcc-internal-format
+msgid "Actual argument to %qs at %L must be a coarray"
+msgstr ""
+
+#: fortran/interface.cc:2632
+#, gcc-internal-format
+msgid "Corank mismatch in argument %qs at %L (%d and %d)"
+msgstr ""
+
+#: fortran/interface.cc:2650
+#, gcc-internal-format
+msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
+msgstr ""
+
+#: fortran/interface.cc:2665
+#, gcc-internal-format
+msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
+msgstr ""
+
+#: fortran/interface.cc:2680
+#, gcc-internal-format
+msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
+msgstr ""
+
+#: fortran/interface.cc:2699
+#, gcc-internal-format
+msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
+msgstr ""
+
+#: fortran/interface.cc:2712
+#, gcc-internal-format
+msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
+msgstr ""
+
+#: fortran/interface.cc:2719
+#, gcc-internal-format
+msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
+msgstr ""
+
+#: fortran/interface.cc:2805
+#, gcc-internal-format
+msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.cc:2816
+#, gcc-internal-format, gfc-internal-format
+msgid "Element of assumed-shape or pointer array as actual argument at %L cannot correspond to actual argument at %L"
+msgstr ""
+
+#: fortran/interface.cc:2821
+#, gcc-internal-format
+msgid "Element of assumed-shape or pointer array passed to array dummy argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.cc:2834
+#, gcc-internal-format
+msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.cc:2842
+#, gcc-internal-format
+msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.cc:3230
+#, gcc-internal-format
+msgid "Keyword argument %qs at %L is invalid in a statement function"
+msgstr ""
+
+#: fortran/interface.cc:3253
+#, gcc-internal-format
+msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
+msgstr ""
+
+#: fortran/interface.cc:3257
+#, gcc-internal-format
+msgid "Keyword argument %qs at %L is not in the procedure"
+msgstr ""
+
+#: fortran/interface.cc:3266
+#, gcc-internal-format
+msgid "Keyword argument %qs at %L is already associated with another actual argument"
+msgstr ""
+
+#: fortran/interface.cc:3276
+#, gcc-internal-format, gfc-internal-format
+msgid "More actual than formal arguments in procedure call at %L"
+msgstr ""
+
+#: fortran/interface.cc:3289
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing alternate return specifier in subroutine call at %L"
+msgstr ""
+
+#: fortran/interface.cc:3303
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected alternate return specifier in subroutine call at %L"
+msgstr ""
+
+#: fortran/interface.cc:3326
+#, gcc-internal-format
+msgid "Intrinsic %<NULL()%> without %<MOLD%> argument at %L passed to assumed-rank dummy %qs"
+msgstr ""
+
+#: fortran/interface.cc:3340
+#, gcc-internal-format
+msgid "Intrinsic %<NULL()%> without %<MOLD%> argument at %L passed to assumed-length dummy %qs"
+msgstr ""
+
+#: fortran/interface.cc:3362
+#, gcc-internal-format
+msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
+msgstr ""
+
+#: fortran/interface.cc:3365
+#, gcc-internal-format
+msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
+msgstr ""
+
+#: fortran/interface.cc:3391
+#, gcc-internal-format, gfc-internal-format
+msgid "Actual argument at %L to assumed-type dummy has type parameters or is of derived type with type-bound or FINAL procedures"
+msgstr ""
+
+#: fortran/interface.cc:3403
+#, gcc-internal-format, gfc-internal-format
+msgid "Unlimited polymorphic actual argument at %L is not matched with either an unlimited polymorphic or assumed type dummy argument"
+msgstr ""
+
+#: fortran/interface.cc:3427
+#, gcc-internal-format
+msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.cc:3434
+#, gcc-internal-format
+msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.cc:3449
+#, gcc-internal-format
+msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
+msgstr ""
+
+#: fortran/interface.cc:3472
+#, gcc-internal-format
+msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
+msgstr ""
+
+#: fortran/interface.cc:3482 fortran/interface.cc:3487
+#, gcc-internal-format
+msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
+msgstr ""
+
+#: fortran/interface.cc:3508
+#, gcc-internal-format
+msgid "Expected a procedure pointer for argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.cc:3525
+#, gcc-internal-format
+msgid "Expected a procedure for argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.cc:3590
+#, gcc-internal-format
+msgid "Actual argument for %qs cannot be an assumed-size array at %L"
+msgstr ""
+
+#: fortran/interface.cc:3619
+#, gcc-internal-format
+msgid "Actual argument to assumed-rank INTENT(OUT) dummy %qs at %L cannot be of unknown size"
+msgstr ""
+
+#: fortran/interface.cc:3634
+#, gcc-internal-format
+msgid "Actual argument for %qs at %L must be a pointer"
+msgstr ""
+
+#: fortran/interface.cc:3643
+#, gcc-internal-format
+msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
+msgstr ""
+
+#: fortran/interface.cc:3652
+#, gcc-internal-format
+msgid "Actual argument for %qs at %L must be a pointer or a valid target for the dummy pointer in a pointer assignment statement"
+msgstr ""
+
+#: fortran/interface.cc:3666
+#, gcc-internal-format
+msgid "Coindexed actual argument at %L to pointer dummy %qs"
+msgstr ""
+
+#: fortran/interface.cc:3680
+#, gcc-internal-format
+msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
+msgstr ""
+
+#: fortran/interface.cc:3695
+#, gcc-internal-format
+msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
+msgstr ""
+
+#: fortran/interface.cc:3710
+#, gcc-internal-format
+msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
+msgstr ""
+
+#: fortran/interface.cc:3723
+#, gcc-internal-format
+msgid "Actual CLASS array argument for %qs must be a full array at %L"
+msgstr ""
+
+#: fortran/interface.cc:3734
+#, gcc-internal-format
+msgid "Actual argument for %qs must be ALLOCATABLE at %L"
+msgstr ""
+
+#: fortran/interface.cc:3745
+#, gcc-internal-format
+msgid "Actual argument for %qs at %L is a function result and the dummy argument is ALLOCATABLE"
+msgstr ""
+
+#: fortran/interface.cc:3783
+#, gcc-internal-format
+msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
+msgstr ""
+
+#: fortran/interface.cc:3803
+#, gcc-internal-format
+msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
+msgstr ""
+
+#: fortran/interface.cc:3821
+#, gcc-internal-format
+msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
+msgstr ""
+
+#: fortran/interface.cc:3842
+#, gcc-internal-format
+msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
+msgstr ""
+
+#: fortran/interface.cc:3870
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing alternate return spec in subroutine call at %L"
+msgstr ""
+
+#: fortran/interface.cc:3883
+#, gcc-internal-format
+msgid "Missing actual argument for argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.cc:4011
+#, gcc-internal-format
+msgid "compare_actual_expr(): Bad component code"
+msgstr ""
+
+#: fortran/interface.cc:4040
+#, gcc-internal-format
+msgid "check_some_aliasing(): List mismatch"
+msgstr ""
+
+#: fortran/interface.cc:4066
+#, gcc-internal-format
+msgid "check_some_aliasing(): corrupted data"
+msgstr ""
+
+#: fortran/interface.cc:4076
+#, gcc-internal-format
+msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
+msgstr ""
+
+#: fortran/interface.cc:4106
+#, gcc-internal-format
+msgid "check_intents(): List mismatch"
+msgstr ""
+
+#: fortran/interface.cc:4126
+#, gcc-internal-format, gfc-internal-format
+msgid "Procedure argument at %L is local to a PURE procedure and has the POINTER attribute"
+msgstr ""
+
+#: fortran/interface.cc:4138
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindexed actual argument at %L in PURE procedure is passed to an INTENT(%s) argument"
+msgstr ""
+
+#: fortran/interface.cc:4148
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindexed actual argument at %L in PURE procedure is passed to a POINTER dummy argument"
+msgstr ""
+
+#: fortran/interface.cc:4159
+#, gcc-internal-format
+msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
+msgstr ""
+
+#: fortran/interface.cc:4201
+#, gcc-internal-format
+msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
+msgstr ""
+
+#: fortran/interface.cc:4205 fortran/interface.cc:4215
+#, gcc-internal-format
+msgid "Procedure %qs called at %L is not explicitly declared"
+msgstr ""
+
+#: fortran/interface.cc:4211
+#, gcc-internal-format
+msgid "Procedure %qs called with an implicit interface at %L"
+msgstr ""
+
+#: fortran/interface.cc:4224
+#, gcc-internal-format
+msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
+msgstr ""
+
+#: fortran/interface.cc:4232
+#, gcc-internal-format
+msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
+msgstr ""
+
+#: fortran/interface.cc:4240
+#, gcc-internal-format
+msgid "Allocatable function %qs at %L must have an explicit function interface"
+msgstr ""
+
+#: fortran/interface.cc:4257
+#, gcc-internal-format, gfc-internal-format
+msgid "Explicit interface required for polymorphic argument at %L"
+msgstr ""
+
+#: fortran/interface.cc:4266
+#, gcc-internal-format
+msgid "Keyword argument requires explicit interface for procedure %qs at %L"
+msgstr ""
+
+#: fortran/interface.cc:4275
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-type argument %s at %L requires an explicit interface"
+msgstr ""
+
+#: fortran/interface.cc:4290
+#, gcc-internal-format
+msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
+msgstr ""
+
+#: fortran/interface.cc:4305
+#, gcc-internal-format
+msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
+msgstr ""
+
+#: fortran/interface.cc:4315
+#, gcc-internal-format, gfc-internal-format
+msgid "MOLD argument to NULL required at %L"
+msgstr ""
+
+#: fortran/interface.cc:4323
+#, gcc-internal-format, gfc-internal-format
+msgid "Passing intrinsic NULL as actual argument at %L requires an explicit interface"
+msgstr ""
+
+#: fortran/interface.cc:4333
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-rank argument requires an explicit interface at %L"
+msgstr ""
+
+#: fortran/interface.cc:4375
+#, gcc-internal-format
+msgid "Procedure pointer component %qs called with an implicit interface at %L"
+msgstr ""
+
+#: fortran/interface.cc:4386
+#, gcc-internal-format
+msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
+msgstr ""
+
+#: fortran/interface.cc:4471
+#, gcc-internal-format, gfc-internal-format
+msgid "MOLD= required in NULL() argument at %L: Ambiguity between specific functions %s and %s"
+msgstr ""
+
+#: fortran/interface.cc:4541
+#, gcc-internal-format
+msgid "Unable to find symbol %qs"
+msgstr ""
+
+#: fortran/interface.cc:4925
+#, gcc-internal-format
+msgid "Entity %qs at %L is already present in the interface"
+msgstr ""
+
+#: fortran/interface.cc:5042
+#, gcc-internal-format
+msgid "gfc_add_interface(): Bad interface type"
+msgstr ""
+
+#: fortran/interface.cc:5136
+#, gcc-internal-format
+msgid "Cannot overwrite GENERIC %qs at %L"
+msgstr ""
+
+#: fortran/interface.cc:5148
+#, gcc-internal-format
+msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
+msgstr ""
+
+#: fortran/interface.cc:5156
+#, gcc-internal-format
+msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
+msgstr ""
+
+#: fortran/interface.cc:5164
+#, gcc-internal-format
+msgid "%qs at %L overrides a PURE procedure and must also be PURE"
+msgstr ""
+
+#: fortran/interface.cc:5173
+#, gcc-internal-format
+msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
+msgstr ""
+
+#: fortran/interface.cc:5179
+#, gcc-internal-format
+msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
+msgstr ""
+
+#: fortran/interface.cc:5188
+#, gcc-internal-format
+msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
+msgstr ""
+
+#: fortran/interface.cc:5199
+#, gcc-internal-format
+msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
+msgstr ""
+
+#: fortran/interface.cc:5207
+#, gcc-internal-format
+msgid "Result mismatch for the overriding procedure %qs at %L: %s"
+msgstr ""
+
+#: fortran/interface.cc:5218
+#, gcc-internal-format
+msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
+msgstr ""
+
+#: fortran/interface.cc:5248
+#, gcc-internal-format
+msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
+msgstr ""
+
+#: fortran/interface.cc:5259
+#, gcc-internal-format
+msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
+msgstr ""
+
+#: fortran/interface.cc:5268
+#, gcc-internal-format
+msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
+msgstr ""
+
+#: fortran/interface.cc:5277
+#, gcc-internal-format
+msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
+msgstr ""
+
+#: fortran/interface.cc:5288
+#, gcc-internal-format
+msgid "%qs at %L overrides a binding with PASS and must also be PASS"
+msgstr ""
+
+#: fortran/interface.cc:5295
+#, gcc-internal-format
+msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
+msgstr ""
+
+#: fortran/interface.cc:5316
+#, gcc-internal-format, gfc-internal-format
+msgid "DTIO dummy argument at %L must be of type %s"
+msgstr ""
+
+#: fortran/interface.cc:5323
+#, gcc-internal-format, gfc-internal-format
+msgid "DTIO dummy argument at %L must be of KIND = %d"
+msgstr ""
+
+#: fortran/interface.cc:5330
+#, gcc-internal-format, gfc-internal-format
+msgid "DTIO dummy argument at %L must be a scalar"
+msgstr ""
+
+#: fortran/interface.cc:5334
+#, gcc-internal-format, gfc-internal-format
+msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
+msgstr ""
+
+#: fortran/interface.cc:5338
+#, gcc-internal-format, gfc-internal-format
+msgid "DTIO character argument at %L must have assumed length"
+msgstr ""
+
+#: fortran/interface.cc:5342
+#, gcc-internal-format, gfc-internal-format
+msgid "DTIO dummy argument at %L must have INTENT %s"
+msgstr ""
+
+#: fortran/interface.cc:5400 fortran/interface.cc:5446
+#, gcc-internal-format, gfc-internal-format
+msgid "Alternate return at %L is not permitted in a DTIO procedure"
+msgstr ""
+
+#: fortran/interface.cc:5412
+#, gcc-internal-format
+msgid "DTIO procedure %qs at %L must be a subroutine"
+msgstr ""
+
+#: fortran/interface.cc:5424
+#, gcc-internal-format
+msgid "Too few dummy arguments in DTIO procedure %qs at %L"
+msgstr ""
+
+#: fortran/interface.cc:5431
+#, gcc-internal-format
+msgid "Too many dummy arguments in DTIO procedure %qs at %L"
+msgstr ""
+
+#: fortran/intrinsic.cc:261
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable with NO_ARG_CHECK attribute at %L is only permitted as argument to the intrinsic functions C_LOC and PRESENT"
+msgstr ""
+
+#: fortran/intrinsic.cc:277
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-type argument at %L is not permitted as actual argument to the intrinsic %s"
+msgstr ""
+
+#: fortran/intrinsic.cc:284
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-type argument at %L is only permitted as first actual argument to the intrinsic %s"
+msgstr ""
+
+#: fortran/intrinsic.cc:291
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-rank argument at %L is only permitted as actual argument to intrinsic inquiry functions"
+msgstr ""
+
+#: fortran/intrinsic.cc:298
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-rank argument at %L is only permitted as first actual argument to the intrinsic inquiry function %s"
+msgstr ""
+
+#: fortran/intrinsic.cc:346
+#, gcc-internal-format
+msgid "do_check(): too many args"
+msgstr ""
+
+#: fortran/intrinsic.cc:426
+#, gcc-internal-format
+msgid "add_sym(): Bad sizing mode"
+msgstr ""
+
+#: fortran/intrinsic.cc:1186
+#, gcc-internal-format
+msgid "The intrinsic %qs at %L is not included in the selected standard but %s and %qs will be treated as if declared EXTERNAL.  Use an appropriate %<-std=%> option or define %<-fall-intrinsics%> to allow this intrinsic."
+msgstr ""
+
+#: fortran/intrinsic.cc:1221
+#, gcc-internal-format
+msgid "make_generic(): Cannot find generic symbol %qs"
+msgstr ""
+
+#: fortran/intrinsic.cc:4316
+#, gcc-internal-format, gfc-internal-format
+msgid "ALLOCATED intrinsic at %L requires an array or scalar allocatable entity"
+msgstr ""
+
+#: fortran/intrinsic.cc:4329
+#, gcc-internal-format, gfc-internal-format
+msgid "Scalar entity required at %L"
+msgstr ""
+
+#: fortran/intrinsic.cc:4340
+#, gcc-internal-format, gfc-internal-format
+msgid "Array entity required at %L"
+msgstr ""
+
+#: fortran/intrinsic.cc:4347
+#, gcc-internal-format
+msgid "Invalid keyword %qs in %qs intrinsic function at %L"
+msgstr ""
+
+#: fortran/intrinsic.cc:4374
+#, gcc-internal-format
+msgid "Too many arguments in call to %qs at %L"
+msgstr ""
+
+#: fortran/intrinsic.cc:4390
+#, gcc-internal-format, gfc-internal-format
+msgid "The argument list functions %%VAL, %%LOC or %%REF are not allowed in this context at %L"
+msgstr ""
+
+#: fortran/intrinsic.cc:4393
+#, gcc-internal-format
+msgid "Cannot find keyword named %qs in call to %qs at %L"
+msgstr ""
+
+#: fortran/intrinsic.cc:4400
+#, gcc-internal-format
+msgid "Argument %qs appears twice in call to %qs at %L"
+msgstr ""
+
+#: fortran/intrinsic.cc:4414
+#, gcc-internal-format
+msgid "Missing actual argument %qs in call to %qs at %L"
+msgstr ""
+
+#: fortran/intrinsic.cc:4430
+#, gcc-internal-format, gfc-internal-format
+msgid "ALTERNATE RETURN not permitted at %L"
+msgstr ""
+
+#: fortran/intrinsic.cc:4484
+#, gcc-internal-format
+msgid "In call to %qs at %L, type mismatch in argument %qs; pass %qs to %qs"
+msgstr ""
+
+#: fortran/intrinsic.cc:4612
+#, gcc-internal-format
+msgid "resolve_intrinsic(): Too many args for intrinsic"
+msgstr ""
+
+#: fortran/intrinsic.cc:4707
+#, gcc-internal-format
+msgid "do_simplify(): Too many args for intrinsic"
+msgstr ""
+
+#: fortran/intrinsic.cc:4719
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot simplify expression at %L"
+msgstr ""
+
+#: fortran/intrinsic.cc:4752
+#, gcc-internal-format
+msgid "init_arglist(): too many arguments"
+msgstr ""
+
+#: fortran/intrinsic.cc:4908
+#, gcc-internal-format
+msgid "Invalid standard code on intrinsic %qs (%d)"
+msgstr ""
+
+#: fortran/intrinsic.cc:4917
+#, gcc-internal-format
+msgid "Intrinsic %qs (%s) used at %L"
+msgstr ""
+
+#: fortran/intrinsic.cc:4989
+#, gcc-internal-format
+msgid "Function %qs as initialization expression at %L"
+msgstr ""
+
+#: fortran/intrinsic.cc:5007
+#, gcc-internal-format
+msgid "Transformational function %qs at %L is invalid in an initialization expression"
+msgstr ""
+
+#: fortran/intrinsic.cc:5083
+#, gcc-internal-format, gfc-internal-format
+msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
+msgstr ""
+
+#: fortran/intrinsic.cc:5174
+#, gcc-internal-format
+msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
+msgstr ""
+
+#: fortran/intrinsic.cc:5181
+#, gcc-internal-format
+msgid "Subroutine call to intrinsic %qs at %L is not PURE"
+msgstr ""
+
+#: fortran/intrinsic.cc:5284
+#, gcc-internal-format, gfc-internal-format
+msgid "Extension: Conversion from %s to %s at %L"
+msgstr ""
+
+#: fortran/intrinsic.cc:5305
+#, gcc-internal-format, gfc-internal-format
+msgid "Nonstandard conversion from %s to %s at %L"
+msgstr ""
+
+#: fortran/intrinsic.cc:5322 fortran/intrinsic.cc:5339
+#, gcc-internal-format, gfc-internal-format
+msgid "Possible change of value in conversion from %s to %s at %L"
+msgstr ""
+
+#. If HOLLERITH is involved, all bets are off.
+#: fortran/intrinsic.cc:5327 fortran/intrinsic.cc:5347
+#, gcc-internal-format, gfc-internal-format
+msgid "Conversion from %s to %s at %L"
+msgstr ""
+
+#. Use of -fdec-char-conversions allows assignment of character data
+#. to non-character variables.  This not permitted for nonconstant
+#. strings.
+#: fortran/intrinsic.cc:5413 fortran/resolve.cc:11520
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot convert %s to %s at %L"
+msgstr ""
+
+#: fortran/intrinsic.cc:5418
+#, gcc-internal-format
+msgid "Cannot convert %qs to %qs at %L"
+msgstr ""
+
+#: fortran/intrinsic.cc:5510
+#, gcc-internal-format
+msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
+msgstr ""
+
+#: fortran/intrinsic.cc:5516
+#, gcc-internal-format
+msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
+msgstr ""
+
+#: fortran/io.cc:176 fortran/primary.cc:940
+#, gcc-internal-format, gfc-internal-format
+msgid "Extension: backslash character at %C"
+msgstr ""
+
+#: fortran/io.cc:210
+#, gcc-internal-format, gfc-internal-format
+msgid "Nonconforming tab character in format at %C"
+msgstr ""
+
+#: fortran/io.cc:453
+#, gcc-internal-format, gfc-internal-format
+msgid "DP format specifier not allowed at %C"
+msgstr ""
+
+#: fortran/io.cc:460
+#, gcc-internal-format, gfc-internal-format
+msgid "DC format specifier not allowed at %C"
+msgstr ""
+
+#: fortran/io.cc:467
+#, gcc-internal-format, gfc-internal-format
+msgid "Fortran 2003: DT format specifier not allowed at %C"
+msgstr ""
+
+#: fortran/io.cc:596
+#, gcc-internal-format, gfc-internal-format
+msgid "Positive width required in format string at %L"
+msgstr ""
+
+#: fortran/io.cc:598
+#, gcc-internal-format, gfc-internal-format
+msgid "Nonnegative width required in format string at %L"
+msgstr ""
+
+#: fortran/io.cc:600
+#, gcc-internal-format
+msgid "Unexpected element %qc in format string at %L"
+msgstr ""
+
+#: fortran/io.cc:602
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected end of format string in format string at %L"
+msgstr ""
+
+#: fortran/io.cc:604
+#, gcc-internal-format, gfc-internal-format
+msgid "Zero width in format descriptor in format string at %L"
+msgstr ""
+
+#: fortran/io.cc:624
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing leading left parenthesis in format string at %L"
+msgstr ""
+
+#: fortran/io.cc:653
+#, gcc-internal-format
+msgid "Left parenthesis required after %<*%> in format string at %L"
+msgstr ""
+
+#: fortran/io.cc:685
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected P edit descriptor in format string at %L"
+msgstr ""
+
+#. P requires a prior number.
+#: fortran/io.cc:693
+#, gcc-internal-format, gfc-internal-format
+msgid "P descriptor requires leading scale factor in format string at %L"
+msgstr ""
+
+#: fortran/io.cc:701
+#, gcc-internal-format, gfc-internal-format
+msgid "X descriptor requires leading space count at %L"
+msgstr ""
+
+#: fortran/io.cc:730
+#, gcc-internal-format, gfc-internal-format
+msgid "$ descriptor at %L"
+msgstr ""
+
+#: fortran/io.cc:734
+#, gcc-internal-format, gfc-internal-format
+msgid "$ should be the last specifier in format at %L"
+msgstr ""
+
+#: fortran/io.cc:766
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing item in format string at %L"
+msgstr ""
+
+#: fortran/io.cc:797 fortran/io.cc:812
+#, gcc-internal-format, gfc-internal-format
+msgid "Comma required after P descriptor in format string at %L"
+msgstr ""
+
+#: fortran/io.cc:827
+#, gcc-internal-format, gfc-internal-format
+msgid "Positive width required with T descriptor in format string at %L"
+msgstr ""
+
+#: fortran/io.cc:846 fortran/io.cc:850
+#, gcc-internal-format, gfc-internal-format
+msgid "Extension: Zero width after L descriptor at %L"
+msgstr ""
+
+#: fortran/io.cc:862
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing positive width after L descriptor at %L"
+msgstr ""
+
+#: fortran/io.cc:893
+#, gcc-internal-format
+msgid "%<G0%> in format at %L"
+msgstr ""
+
+#: fortran/io.cc:911
+#, gcc-internal-format, gfc-internal-format
+msgid "E specifier not allowed with g0 descriptor in format string at %L"
+msgstr ""
+
+#: fortran/io.cc:931
+#, gcc-internal-format, gfc-internal-format
+msgid "Positive width required in format specifier %s at %L"
+msgstr ""
+
+#: fortran/io.cc:941
+#, gcc-internal-format, gfc-internal-format
+msgid "positive width required at %L"
+msgstr ""
+
+#: fortran/io.cc:964 fortran/io.cc:971
+#, gcc-internal-format, gfc-internal-format
+msgid "Period required in format specifier %s at %L"
+msgstr ""
+
+#: fortran/io.cc:1009 fortran/io.cc:1018
+#, gcc-internal-format, gfc-internal-format
+msgid "Positive exponent width required in format string at %L"
+msgstr ""
+
+#: fortran/io.cc:1066
+#, gcc-internal-format, gfc-internal-format
+msgid "Right parenthesis expected at %C in format string at %L"
+msgstr ""
+
+#: fortran/io.cc:1108
+#, gcc-internal-format, gfc-internal-format
+msgid "Period required in format specifier in format string at %L"
+msgstr ""
+
+#: fortran/io.cc:1114
+#, gcc-internal-format, gfc-internal-format
+msgid "Period required in format specifier at %L"
+msgstr ""
+
+#: fortran/io.cc:1136
+#, gcc-internal-format, gfc-internal-format
+msgid "The H format specifier at %L is a Fortran 95 deleted feature"
+msgstr ""
+
+#: fortran/io.cc:1231 fortran/io.cc:1293
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing comma at %L"
+msgstr ""
+
+#: fortran/io.cc:1349
+#, gcc-internal-format, gfc-internal-format
+msgid "Extraneous characters in format at %L"
+msgstr ""
+
+#: fortran/io.cc:1371
+#, gcc-internal-format, gfc-internal-format
+msgid "Format statement in module main block at %C"
+msgstr ""
+
+#: fortran/io.cc:1380
+#, gcc-internal-format, gfc-internal-format
+msgid "FORMAT statement at %C cannot appear within an INTERFACE"
+msgstr ""
+
+#: fortran/io.cc:1386
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing format label at %C"
+msgstr ""
+
+#: fortran/io.cc:1441 fortran/io.cc:1472 fortran/io.cc:1552
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid value for %s specification at %C"
+msgstr ""
+
+#: fortran/io.cc:1447 fortran/io.cc:1478 fortran/io.cc:1634 fortran/io.cc:1647
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate %s specification at %C"
+msgstr ""
+
+#: fortran/io.cc:1489
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s cannot be INTENT(IN) at %C"
+msgstr ""
+
+#: fortran/io.cc:1497
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s cannot be assigned in PURE procedure at %C"
+msgstr ""
+
+#: fortran/io.cc:1527
+#, gcc-internal-format, gfc-internal-format
+msgid "Expecting a variable at %L"
+msgstr ""
+
+#: fortran/io.cc:1558
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate %s label specification at %C"
+msgstr ""
+
+#: fortran/io.cc:1578 fortran/io.cc:1595 fortran/io.cc:1616
+#, gcc-internal-format
+msgid "%s at %C is a DEC extension, enable with %<-fdec%>"
+msgstr ""
+
+#: fortran/io.cc:1669
+#, gcc-internal-format, gfc-internal-format
+msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
+msgstr ""
+
+#: fortran/io.cc:1694
+#, gcc-internal-format, gfc-internal-format
+msgid "FORMAT tag at %L cannot be a zero-sized array"
+msgstr ""
+
+#: fortran/io.cc:1735
+#, gcc-internal-format, gfc-internal-format
+msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
+msgstr ""
+
+#: fortran/io.cc:1741
+#, gcc-internal-format, gfc-internal-format
+msgid "ASSIGNED variable in FORMAT tag at %L"
+msgstr ""
+
+#: fortran/io.cc:1746
+#, gcc-internal-format
+msgid "Variable %qs at %L has not been assigned a format label"
+msgstr ""
+
+#: fortran/io.cc:1753
+#, gcc-internal-format
+msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
+msgstr ""
+
+#: fortran/io.cc:1768
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-character non-Hollerith in FORMAT tag at %L"
+msgstr ""
+
+#: fortran/io.cc:1772
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-character in FORMAT tag at %L"
+msgstr ""
+
+#: fortran/io.cc:1778
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-character assumed shape array element in FORMAT tag at %L"
+msgstr ""
+
+#: fortran/io.cc:1785
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-character assumed size array element in FORMAT tag at %L"
+msgstr ""
+
+#: fortran/io.cc:1792
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-character pointer array element in FORMAT tag at %L"
+msgstr ""
+
+#: fortran/io.cc:1818
+#, gcc-internal-format, gfc-internal-format
+msgid "%s tag at %L must be of type %s"
+msgstr ""
+
+#: fortran/io.cc:1825
+#, gcc-internal-format, gfc-internal-format
+msgid "%s tag at %L must be a character string of default kind"
+msgstr ""
+
+#: fortran/io.cc:1832
+#, gcc-internal-format, gfc-internal-format
+msgid "%s tag at %L must be scalar"
+msgstr ""
+
+#: fortran/io.cc:1838
+#, gcc-internal-format, gfc-internal-format
+msgid "IOMSG tag at %L"
+msgstr ""
+
+#: fortran/io.cc:1846
+#, gcc-internal-format, gfc-internal-format
+msgid "Fortran 95 requires default INTEGER in %s tag at %L"
+msgstr ""
+
+#: fortran/io.cc:1855
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-default LOGICAL kind in %s tag at %L"
+msgstr ""
+
+#: fortran/io.cc:1862
+#, gcc-internal-format, gfc-internal-format
+msgid "NEWUNIT specifier at %L"
+msgstr ""
+
+#: fortran/io.cc:1880
+#, gcc-internal-format, gfc-internal-format
+msgid "CONVERT tag at %L"
+msgstr ""
+
+#: fortran/io.cc:2096
+#, gcc-internal-format
+msgid "Fortran 2003: %s specifier in %s statement at %L has value %qs"
+msgstr ""
+
+#: fortran/io.cc:2104 fortran/io.cc:2131
+#, gcc-internal-format
+msgid "%s specifier in %s statement at %L has value %qs"
+msgstr ""
+
+#: fortran/io.cc:2123
+#, gcc-internal-format
+msgid "Extension: %s specifier in %s statement at %L has value %qs"
+msgstr ""
+
+#: fortran/io.cc:2145 fortran/io.cc:2153
+#, gcc-internal-format
+msgid "%s specifier in %s statement at %L has invalid value %qs"
+msgstr ""
+
+#: fortran/io.cc:2210
+#, gcc-internal-format, gfc-internal-format
+msgid "ACTION type conflicts with READONLY specifier at %L"
+msgstr ""
+
+#: fortran/io.cc:2226
+#, gcc-internal-format, gfc-internal-format
+msgid "ASYNCHRONOUS= at %L not allowed in Fortran 95"
+msgstr ""
+
+#: fortran/io.cc:2245 fortran/io.cc:3919
+#, gcc-internal-format, gfc-internal-format
+msgid "BLANK= at %L not allowed in Fortran 95"
+msgstr ""
+
+#: fortran/io.cc:2273 fortran/io.cc:3897
+#, gcc-internal-format, gfc-internal-format
+msgid "DECIMAL= at %L not allowed in Fortran 95"
+msgstr ""
+
+#: fortran/io.cc:2305
+#, gcc-internal-format, gfc-internal-format
+msgid "ENCODING= at %L not allowed in Fortran 95"
+msgstr ""
+
+#: fortran/io.cc:2356 fortran/io.cc:3964
+#, gcc-internal-format, gfc-internal-format
+msgid "ROUND= at %L not allowed in Fortran 95"
+msgstr ""
+
+#: fortran/io.cc:2386
+#, gcc-internal-format, gfc-internal-format
+msgid "SIGN= at %L not allowed in Fortran 95"
+msgstr ""
+
+#: fortran/io.cc:2407
+#, gcc-internal-format, gfc-internal-format
+msgid "RECL in OPEN statement at %L must be positive"
+msgstr ""
+
+#: fortran/io.cc:2432
+#, gcc-internal-format
+msgid "The STATUS specified in OPEN statement at %L is %qs and no FILE specifier is present"
+msgstr ""
+
+#: fortran/io.cc:2443
+#, gcc-internal-format, gfc-internal-format
+msgid "The STATUS specified in OPEN statement at %L cannot have the value SCRATCH if a FILE specifier is present"
+msgstr ""
+
+#: fortran/io.cc:2454
+#, gcc-internal-format, gfc-internal-format
+msgid "UNIT specifier not allowed with NEWUNIT at %L"
+msgstr ""
+
+#: fortran/io.cc:2465
+#, gcc-internal-format, gfc-internal-format
+msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %L"
+msgstr ""
+
+#: fortran/io.cc:2472
+#, gcc-internal-format, gfc-internal-format
+msgid "OPEN statement at %L must have UNIT or NEWUNIT specified"
+msgstr ""
+
+#: fortran/io.cc:2507
+#, gcc-internal-format, gfc-internal-format
+msgid "%sspecifier at %L not allowed in OPEN statement for unformatted I/O"
+msgstr ""
+
+#: fortran/io.cc:2515
+#, gcc-internal-format, gfc-internal-format
+msgid "RECL specifier not allowed in OPEN statement at %L for stream I/O"
+msgstr ""
+
+#: fortran/io.cc:2528
+#, gcc-internal-format, gfc-internal-format
+msgid "POSITION specifier in OPEN statement at %L only allowed for stream or sequential ACCESS"
+msgstr ""
+
+#: fortran/io.cc:2581
+#, gcc-internal-format, gfc-internal-format
+msgid "OPEN statement not allowed in PURE procedure at %C"
+msgstr ""
+
+#: fortran/io.cc:2689
+#, gcc-internal-format, gfc-internal-format
+msgid "CLOSE statement not allowed in PURE procedure at %C"
+msgstr ""
+
+#: fortran/io.cc:2715
+#, gcc-internal-format, gfc-internal-format
+msgid "CLOSE statement at %L requires a UNIT number"
+msgstr ""
+
+#: fortran/io.cc:2723
+#, gcc-internal-format, gfc-internal-format
+msgid "UNIT number in CLOSE statement at %L must be non-negative"
+msgstr ""
+
+#: fortran/io.cc:2846 fortran/match.cc:3131
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement not allowed in PURE procedure at %C"
+msgstr ""
+
+#: fortran/io.cc:2876
+#, gcc-internal-format, gfc-internal-format
+msgid "UNIT number missing in statement at %L"
+msgstr ""
+
+#: fortran/io.cc:2887 fortran/io.cc:3377
+#, gcc-internal-format, gfc-internal-format
+msgid "UNIT number in statement at %L must be non-negative"
+msgstr ""
+
+#: fortran/io.cc:2920
+#, gcc-internal-format, gfc-internal-format
+msgid "FLUSH statement at %C"
+msgstr ""
+
+#: fortran/io.cc:2961
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing format with default unit at %C"
+msgstr ""
+
+#: fortran/io.cc:2981
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate UNIT specification at %C"
+msgstr ""
+
+#: fortran/io.cc:3055
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate format specification at %C"
+msgstr ""
+
+#: fortran/io.cc:3096
+#, gcc-internal-format
+msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
+msgstr ""
+
+#: fortran/io.cc:3132
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate NML specification at %C"
+msgstr ""
+
+#: fortran/io.cc:3141
+#, gcc-internal-format
+msgid "Symbol %qs at %C must be a NAMELIST group name"
+msgstr ""
+
+#: fortran/io.cc:3207
+#, gcc-internal-format, gfc-internal-format
+msgid "END tag at %C not allowed in output statement"
+msgstr ""
+
+#: fortran/io.cc:3303
+#, gcc-internal-format, gfc-internal-format
+msgid "UNIT not specified at %L"
+msgstr ""
+
+#: fortran/io.cc:3310
+#, gcc-internal-format, gfc-internal-format
+msgid "UNIT specification at %L must not be a character PARAMETER"
+msgstr ""
+
+#: fortran/io.cc:3323
+#, gcc-internal-format, gfc-internal-format
+msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
+msgstr ""
+
+#: fortran/io.cc:3345
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid form of WRITE statement at %L, UNIT required"
+msgstr ""
+
+#: fortran/io.cc:3356
+#, gcc-internal-format, gfc-internal-format
+msgid "Internal unit with vector subscript at %L"
+msgstr ""
+
+#: fortran/io.cc:3370
+#, gcc-internal-format, gfc-internal-format
+msgid "External IO UNIT cannot be an array at %L"
+msgstr ""
+
+#: fortran/io.cc:3400
+#, gcc-internal-format
+msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
+msgstr ""
+
+#: fortran/io.cc:3412
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.cc:3422 fortran/resolve.cc:16065
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr ""
+
+#: fortran/io.cc:3430
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.cc:3441
+#, gcc-internal-format, gfc-internal-format
+msgid "Comma before i/o item list at %L"
+msgstr ""
+
+#: fortran/io.cc:3451
+#, gcc-internal-format, gfc-internal-format
+msgid "ERR tag label %d at %L not defined"
+msgstr ""
+
+#: fortran/io.cc:3463
+#, gcc-internal-format, gfc-internal-format
+msgid "END tag label %d at %L not defined"
+msgstr ""
+
+#: fortran/io.cc:3475
+#, gcc-internal-format, gfc-internal-format
+msgid "EOR tag label %d at %L not defined"
+msgstr ""
+
+#: fortran/io.cc:3485
+#, gcc-internal-format, gfc-internal-format
+msgid "FORMAT label %d at %L not defined"
+msgstr ""
+
+#: fortran/io.cc:3516
+#, gcc-internal-format
+msgid "io_kind_name(): bad I/O-kind"
+msgstr ""
+
+#: fortran/io.cc:3605
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in I/O iterator at %C"
+msgstr ""
+
+#: fortran/io.cc:3637
+#, gcc-internal-format, gfc-internal-format
+msgid "Expecting variable in READ statement at %C"
+msgstr ""
+
+#: fortran/io.cc:3643
+#, gcc-internal-format, gfc-internal-format
+msgid "Expecting variable or io-implied-do in READ statement at %L"
+msgstr ""
+
+#: fortran/io.cc:3652
+#, gcc-internal-format, gfc-internal-format
+msgid "Expecting variable or io-implied-do at %L"
+msgstr ""
+
+#: fortran/io.cc:3661
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected expression in %s statement at %C"
+msgstr ""
+
+#: fortran/io.cc:3666
+#, gcc-internal-format, gfc-internal-format
+msgid "BOZ literal constant at %L cannot appear in an output IO list"
+msgstr ""
+
+#: fortran/io.cc:3814
+#, gcc-internal-format, gfc-internal-format
+msgid "Internal file at %L with namelist"
+msgstr ""
+
+#: fortran/io.cc:3829
+#, gcc-internal-format, gfc-internal-format
+msgid "IO UNIT in %s statement at %L must be an internal file in a PURE procedure"
+msgstr ""
+
+#: fortran/io.cc:3942
+#, gcc-internal-format, gfc-internal-format
+msgid "PAD= at %L not allowed in Fortran 95"
+msgstr ""
+
+#: fortran/io.cc:4011
+#, gcc-internal-format, gfc-internal-format
+msgid "DELIM= at %L not allowed in Fortran 95"
+msgstr ""
+
+#: fortran/io.cc:4185
+#, gcc-internal-format, gfc-internal-format
+msgid "PRINT namelist at %C is an extension"
+msgstr ""
+
+#: fortran/io.cc:4207
+#, gcc-internal-format, gfc-internal-format
+msgid "Comma after * at %C not allowed without I/O list"
+msgstr ""
+
+#: fortran/io.cc:4380
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected comma in I/O list at %C"
+msgstr ""
+
+#: fortran/io.cc:4447
+#, gcc-internal-format, gfc-internal-format
+msgid "PRINT statement at %C not allowed within PURE procedure"
+msgstr ""
+
+#: fortran/io.cc:4609
+#, gcc-internal-format, gfc-internal-format
+msgid "NULL() near %L cannot appear in INQUIRE statement"
+msgstr ""
+
+#: fortran/io.cc:4621 fortran/io.cc:4683
+#, gcc-internal-format, gfc-internal-format
+msgid "INQUIRE statement not allowed in PURE procedure at %C"
+msgstr ""
+
+#: fortran/io.cc:4649
+#, gcc-internal-format, gfc-internal-format
+msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
+msgstr ""
+
+#: fortran/io.cc:4659 fortran/trans-io.cc:1358
+#, gcc-internal-format, gfc-internal-format
+msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
+msgstr ""
+
+#: fortran/io.cc:4666
+#, gcc-internal-format, gfc-internal-format
+msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
+msgstr ""
+
+#: fortran/io.cc:4676
+#, gcc-internal-format, gfc-internal-format
+msgid "UNIT number in INQUIRE statement at %L cannot be %d"
+msgstr ""
+
+#: fortran/io.cc:4691
+#, gcc-internal-format, gfc-internal-format
+msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
+msgstr ""
+
+#: fortran/io.cc:4867
+#, gcc-internal-format, gfc-internal-format
+msgid "WAIT at %C not allowed in Fortran 95"
+msgstr ""
+
+#: fortran/io.cc:4873
+#, gcc-internal-format, gfc-internal-format
+msgid "WAIT statement not allowed in PURE procedure at %C"
+msgstr ""
+
+#. Reject truncation.
+#: fortran/iresolve.cc:70
+#, gcc-internal-format, gfc-internal-format
+msgid "identifier overflow: %d"
+msgstr ""
+
+#: fortran/iresolve.cc:102
+#, gcc-internal-format
+msgid "check_charlen_present(): length not set"
+msgstr ""
+
+#: fortran/iresolve.cc:3029
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
+msgstr ""
+
+#: fortran/match.cc:118
+#, gcc-internal-format
+msgid "gfc_op2string(): Bad code"
+msgstr ""
+
+#: fortran/match.cc:195
+#, gcc-internal-format
+msgid "Expected structure component or operator name after %<.%> at %C"
+msgstr ""
+
+#: fortran/match.cc:227
+#, gcc-internal-format
+msgid "%qs is neither a defined operator nor a structure component in dotted string at %C"
+msgstr ""
+
+#: fortran/match.cc:298
+#, gcc-internal-format
+msgid "Missing %qs in statement at or before %L"
+msgstr ""
+
+#: fortran/match.cc:498
+#, gcc-internal-format, gfc-internal-format
+msgid "Integer too large at %C"
+msgstr ""
+
+#: fortran/match.cc:553 fortran/parse.cc:1499
+#, gcc-internal-format, gfc-internal-format
+msgid "Too many digits in statement label at %C"
+msgstr ""
+
+#: fortran/match.cc:559
+#, gcc-internal-format, gfc-internal-format
+msgid "Statement label at %C is zero"
+msgstr ""
+
+#: fortran/match.cc:592
+#, gcc-internal-format
+msgid "Label name %qs at %C is ambiguous"
+msgstr ""
+
+#: fortran/match.cc:598
+#, gcc-internal-format
+msgid "Duplicate construct label %qs at %C"
+msgstr ""
+
+#: fortran/match.cc:634
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid character in name at %C"
+msgstr ""
+
+#: fortran/match.cc:647
+#, gcc-internal-format, gfc-internal-format
+msgid "Name at %C is too long"
+msgstr ""
+
+#: fortran/match.cc:658
+#, gcc-internal-format
+msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
+msgstr ""
+
+#: fortran/match.cc:934
+#, gcc-internal-format, gfc-internal-format
+msgid ".XOR. operator at %C"
+msgstr ""
+
+#: fortran/match.cc:989
+#, gcc-internal-format, gfc-internal-format
+msgid "Loop variable at %C cannot be an array"
+msgstr ""
+
+#: fortran/match.cc:996
+#, gcc-internal-format, gfc-internal-format
+msgid "Loop variable at %C cannot be a coarray"
+msgstr ""
+
+#: fortran/match.cc:1002
+#, gcc-internal-format, gfc-internal-format
+msgid "Loop variable at %C cannot be a sub-component"
+msgstr ""
+
+#: fortran/match.cc:1036
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected a step value in iterator at %C"
+msgstr ""
+
+#: fortran/match.cc:1048
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in iterator at %C"
+msgstr ""
+
+#: fortran/match.cc:1221
+#, gcc-internal-format, gfc-internal-format
+msgid "gfc_match(): Bad match code %c"
+msgstr ""
+
+#: fortran/match.cc:1295
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid form of PROGRAM statement at %C"
+msgstr ""
+
+#: fortran/match.cc:1339
+#, gcc-internal-format, gfc-internal-format
+msgid "BOZ literal constant at %L is neither a DATA statement value nor an actual argument of INT/REAL/DBLE/CMPLX intrinsic subprogram"
+msgstr ""
+
+#: fortran/match.cc:1348
+#, gcc-internal-format, gfc-internal-format
+msgid "Assignment to a constant expression at %C"
+msgstr ""
+
+#: fortran/match.cc:1452 fortran/match.cc:1543
+#, gcc-internal-format, gfc-internal-format
+msgid "Arithmetic IF statement at %C"
+msgstr ""
+
+#: fortran/match.cc:1499
+#, gcc-internal-format
+msgid "Missing %<(%> in IF-expression at %C"
+msgstr ""
+
+#: fortran/match.cc:1517
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in IF-expression at %C"
+msgstr ""
+
+#: fortran/match.cc:1528
+#, gcc-internal-format, gfc-internal-format
+msgid "Block label not appropriate for arithmetic IF statement at %C"
+msgstr ""
+
+#: fortran/match.cc:1566
+#, gcc-internal-format, gfc-internal-format
+msgid "Block label is not appropriate for IF statement at %C"
+msgstr ""
+
+#: fortran/match.cc:1659 fortran/match.cc:1666
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in IF-clause after %C"
+msgstr ""
+
+#: fortran/match.cc:1709
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid character(s) in ELSE statement after %C"
+msgstr ""
+
+#: fortran/match.cc:1715
+#, gcc-internal-format
+msgid "Label %qs at %C doesn't match IF label %qs"
+msgstr ""
+
+#: fortran/match.cc:1736
+#, gcc-internal-format
+msgid "Missing %<(%> in ELSE IF expression at %C"
+msgstr ""
+
+#: fortran/match.cc:1746
+#, gcc-internal-format
+msgid "Missing %<)%> in ELSE IF expression at %C"
+msgstr ""
+
+#: fortran/match.cc:1761
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing THEN in ELSE IF statement after %L"
+msgstr ""
+
+#: fortran/match.cc:1769
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in ELSE IF statement after %L"
+msgstr ""
+
+#: fortran/match.cc:1775
+#, gcc-internal-format
+msgid "Label %qs after %L doesn't match IF label %qs"
+msgstr ""
+
+#: fortran/match.cc:1836
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement CRITICAL at %C in PURE procedure"
+msgstr ""
+
+#: fortran/match.cc:1842
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement CRITICAL at %C in DO CONCURRENT block"
+msgstr ""
+
+#: fortran/match.cc:1849
+#, gcc-internal-format, gfc-internal-format
+msgid "CRITICAL statement at %C"
+msgstr ""
+
+#: fortran/match.cc:1861
+#, gcc-internal-format, gfc-internal-format
+msgid "Nested CRITICAL block at %C"
+msgstr ""
+
+#: fortran/match.cc:1913
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected association list at %C"
+msgstr ""
+
+#: fortran/match.cc:1925
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected association at %C"
+msgstr ""
+
+#: fortran/match.cc:1935
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid association target at %C"
+msgstr ""
+
+#: fortran/match.cc:1946
+#, gcc-internal-format
+msgid "Duplicate name %qs in association at %C"
+msgstr ""
+
+#: fortran/match.cc:1954
+#, gcc-internal-format, gfc-internal-format
+msgid "Association target at %C must not be coindexed"
+msgstr ""
+
+#: fortran/match.cc:1961
+#, gcc-internal-format, gfc-internal-format
+msgid "Association target at %L cannot be a BOZ literal constant"
+msgstr ""
+
+#: fortran/match.cc:1980
+#, gcc-internal-format
+msgid "Expected %<)%> or %<,%> at %C"
+msgstr ""
+
+#: fortran/match.cc:1998
+#, gcc-internal-format, gfc-internal-format
+msgid "Junk after ASSOCIATE statement at %C"
+msgstr ""
+
+#: fortran/match.cc:2120
+#, gcc-internal-format
+msgid "Derived type %qs at %L may not be ABSTRACT"
+msgstr ""
+
+#: fortran/match.cc:2192 fortran/match.cc:2264 fortran/match.cc:2287
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid type-spec at %C"
+msgstr ""
+
+#: fortran/match.cc:2382
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in FORALL iterator at %C"
+msgstr ""
+
+#: fortran/match.cc:2647
+#, gcc-internal-format, gfc-internal-format
+msgid "DO CONCURRENT construct at %C"
+msgstr ""
+
+#: fortran/match.cc:2772
+#, gcc-internal-format
+msgid "Name %qs in %s statement at %C is unknown"
+msgstr ""
+
+#: fortran/match.cc:2780
+#, gcc-internal-format
+msgid "Name %qs in %s statement at %C is not a construct name"
+msgstr ""
+
+#: fortran/match.cc:2792
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement at %C leaves CRITICAL construct"
+msgstr ""
+
+#. F2008, C821 & C845.
+#: fortran/match.cc:2800
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement at %C leaves DO CONCURRENT construct"
+msgstr ""
+
+#: fortran/match.cc:2812
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement at %C is not within a construct"
+msgstr ""
+
+#: fortran/match.cc:2815
+#, gcc-internal-format
+msgid "%s statement at %C is not within construct %qs"
+msgstr ""
+
+#: fortran/match.cc:2841
+#, gcc-internal-format
+msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
+msgstr ""
+
+#: fortran/match.cc:2846
+#, gcc-internal-format, gfc-internal-format
+msgid "EXIT statement with no do-construct-name at %C"
+msgstr ""
+
+#: fortran/match.cc:2852
+#, gcc-internal-format
+msgid "%s statement at %C is not applicable to construct %qs"
+msgstr ""
+
+#: fortran/match.cc:2860
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement at %C leaving OpenACC structured block"
+msgstr ""
+
+#: fortran/match.cc:2861
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement at %C leaving OpenMP structured block"
+msgstr ""
+
+#: fortran/match.cc:2901
+#, gcc-internal-format, gfc-internal-format
+msgid "EXIT statement at %C terminating !$ACC LOOP loop"
+msgstr ""
+
+#: fortran/match.cc:2907
+#, gcc-internal-format, gfc-internal-format
+msgid "CYCLE statement at %C to non-innermost tiled !$ACC LOOP loop"
+msgstr ""
+
+#: fortran/match.cc:2909
+#, gcc-internal-format, gfc-internal-format
+msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
+msgstr ""
+
+#: fortran/match.cc:2956
+#, gcc-internal-format, gfc-internal-format
+msgid "EXIT statement at %C terminating !$OMP DO loop"
+msgstr ""
+
+#: fortran/match.cc:2961
+#, gcc-internal-format, gfc-internal-format
+msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
+msgstr ""
+
+#: fortran/match.cc:3066
+#, gcc-internal-format, gfc-internal-format
+msgid "Blank required in %s statement near %C"
+msgstr ""
+
+#: fortran/match.cc:3089
+#, gcc-internal-format, gfc-internal-format
+msgid "STOP code at %C cannot be negative"
+msgstr ""
+
+#: fortran/match.cc:3095
+#, gcc-internal-format, gfc-internal-format
+msgid "STOP code at %C contains too many digits"
+msgstr ""
+
+#: fortran/match.cc:3111
+#, gcc-internal-format, gfc-internal-format
+msgid "QUIET= specifier for %s at %L"
+msgstr ""
+
+#: fortran/match.cc:3125
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement at %C in PURE procedure"
+msgstr ""
+
+#: fortran/match.cc:3141
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement STOP at %C in CRITICAL block"
+msgstr ""
+
+#: fortran/match.cc:3146
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement STOP at %C in DO CONCURRENT block"
+msgstr ""
+
+#: fortran/match.cc:3158
+#, gcc-internal-format, gfc-internal-format
+msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
+msgstr ""
+
+#: fortran/match.cc:3170
+#, gcc-internal-format, gfc-internal-format
+msgid "STOP code at %L must be a scalar default CHARACTER or INTEGER constant expression"
+msgstr ""
+
+#: fortran/match.cc:3177
+#, gcc-internal-format, gfc-internal-format
+msgid "STOP code at %L must be either INTEGER or CHARACTER type"
+msgstr ""
+
+#: fortran/match.cc:3184
+#, gcc-internal-format, gfc-internal-format
+msgid "STOP code at %L must be scalar"
+msgstr ""
+
+#: fortran/match.cc:3191
+#, gcc-internal-format, gfc-internal-format
+msgid "STOP code at %L must be default character KIND=%d"
+msgstr ""
+
+#: fortran/match.cc:3198
+#, gcc-internal-format, gfc-internal-format
+msgid "STOP code at %L must be default integer KIND=%d"
+msgstr ""
+
+#: fortran/match.cc:3210 fortran/resolve.cc:12659
+#, gcc-internal-format, gfc-internal-format
+msgid "QUIET specifier at %L must be a scalar LOGICAL"
+msgstr ""
+
+#: fortran/match.cc:3260
+#, gcc-internal-format, gfc-internal-format
+msgid "PAUSE statement at %C"
+msgstr ""
+
+#: fortran/match.cc:3281
+#, gcc-internal-format, gfc-internal-format
+msgid "ERROR STOP statement at %C"
+msgstr ""
+
+#: fortran/match.cc:3307
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement EVENT %s at %C in PURE procedure"
+msgstr ""
+
+#: fortran/match.cc:3322
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement EVENT %s at %C in CRITICAL block"
+msgstr ""
+
+#: fortran/match.cc:3329
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
+msgstr ""
+
+#: fortran/match.cc:3359 fortran/match.cc:3701 fortran/match.cc:3913
+#: fortran/match.cc:4465 fortran/match.cc:4836
+#, gcc-internal-format, gfc-internal-format
+msgid "Redundant STAT tag found at %L"
+msgstr ""
+
+#: fortran/match.cc:3380 fortran/match.cc:3722 fortran/match.cc:3933
+#: fortran/match.cc:4497 fortran/match.cc:4861
+#, gcc-internal-format, gfc-internal-format
+msgid "Redundant ERRMSG tag found at %L"
+msgstr ""
+
+#: fortran/match.cc:3401
+#, gcc-internal-format, gfc-internal-format
+msgid "Redundant UNTIL_COUNT tag found at %L"
+msgstr ""
+
+#: fortran/match.cc:3467
+#, gcc-internal-format, gfc-internal-format
+msgid "EVENT POST statement at %C"
+msgstr ""
+
+#: fortran/match.cc:3477
+#, gcc-internal-format, gfc-internal-format
+msgid "EVENT WAIT statement at %C"
+msgstr ""
+
+#: fortran/match.cc:3489
+#, gcc-internal-format, gfc-internal-format
+msgid "FAIL IMAGE statement at %C"
+msgstr ""
+
+#: fortran/match.cc:3513
+#, gcc-internal-format, gfc-internal-format
+msgid "FORM TEAM statement at %C"
+msgstr ""
+
+#: fortran/match.cc:3552
+#, gcc-internal-format, gfc-internal-format
+msgid "CHANGE TEAM statement at %C"
+msgstr ""
+
+#: fortran/match.cc:3582
+#, gcc-internal-format, gfc-internal-format
+msgid "END TEAM statement at %C"
+msgstr ""
+
+#: fortran/match.cc:3606
+#, gcc-internal-format, gfc-internal-format
+msgid "SYNC TEAM statement at %C"
+msgstr ""
+
+#: fortran/match.cc:3649
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement %s at %C in PURE procedure"
+msgstr ""
+
+#: fortran/match.cc:3664
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement %s at %C in CRITICAL block"
+msgstr ""
+
+#: fortran/match.cc:3671
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement %s at %C in DO CONCURRENT block"
+msgstr ""
+
+#: fortran/match.cc:3743
+#, gcc-internal-format, gfc-internal-format
+msgid "Redundant ACQUIRED_LOCK tag found at %L"
+msgstr ""
+
+#: fortran/match.cc:3808
+#, gcc-internal-format, gfc-internal-format
+msgid "LOCK statement at %C"
+msgstr ""
+
+#: fortran/match.cc:3818
+#, gcc-internal-format, gfc-internal-format
+msgid "UNLOCK statement at %C"
+msgstr ""
+
+#: fortran/match.cc:3843
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement SYNC at %C in PURE procedure"
+msgstr ""
+
+#: fortran/match.cc:3849
+#, gcc-internal-format, gfc-internal-format
+msgid "SYNC statement at %C"
+msgstr ""
+
+#: fortran/match.cc:3861
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement SYNC at %C in CRITICAL block"
+msgstr ""
+
+#: fortran/match.cc:3867
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement SYNC at %C in DO CONCURRENT block"
+msgstr ""
+
+#: fortran/match.cc:4047
+#, gcc-internal-format, gfc-internal-format
+msgid "ASSIGN statement at %C"
+msgstr ""
+
+#: fortran/match.cc:4091
+#, gcc-internal-format, gfc-internal-format
+msgid "Assigned GOTO statement at %C"
+msgstr ""
+
+#: fortran/match.cc:4135 fortran/match.cc:4186
+#, gcc-internal-format, gfc-internal-format
+msgid "Statement label list in GOTO at %C cannot be empty"
+msgstr ""
+
+#: fortran/match.cc:4196
+#, gcc-internal-format, gfc-internal-format
+msgid "Computed GOTO at %C"
+msgstr ""
+
+#: fortran/match.cc:4271
+#, gcc-internal-format, gfc-internal-format
+msgid "Error in type-spec at %L"
+msgstr ""
+
+#: fortran/match.cc:4284
+#, gcc-internal-format, gfc-internal-format
+msgid "typespec in ALLOCATE at %L"
+msgstr ""
+
+#: fortran/match.cc:4307
+#, gcc-internal-format, gfc-internal-format
+msgid "The type parameter spec list in the type-spec at %L cannot contain DEFERRED parameters"
+msgstr ""
+
+#: fortran/match.cc:4337 fortran/match.cc:4774
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected constant at %C"
+msgstr ""
+
+#: fortran/match.cc:4347
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad allocate-object at %C for a PURE procedure"
+msgstr ""
+
+#: fortran/match.cc:4362
+#, gcc-internal-format, gfc-internal-format
+msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
+msgstr ""
+
+#: fortran/match.cc:4384
+#, gcc-internal-format, gfc-internal-format
+msgid "ALLOCATE of coarray at %C in DO CONCURRENT block"
+msgstr ""
+
+#: fortran/match.cc:4389
+#, gcc-internal-format, gfc-internal-format
+msgid "ALLOCATE of coarray at %C in CRITICAL block"
+msgstr ""
+
+#: fortran/match.cc:4411
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
+msgstr ""
+
+#: fortran/match.cc:4423
+#, gcc-internal-format, gfc-internal-format
+msgid "Type of entity at %L is type incompatible with typespec"
+msgstr ""
+
+#: fortran/match.cc:4431
+#, gcc-internal-format, gfc-internal-format
+msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
+msgstr ""
+
+#: fortran/match.cc:4448
+#, gcc-internal-format, gfc-internal-format
+msgid "Shape specification for allocatable scalar at %C"
+msgstr ""
+
+#: fortran/match.cc:4475
+#, gcc-internal-format, gfc-internal-format
+msgid "STAT tag at %L cannot be a constant"
+msgstr ""
+
+#: fortran/match.cc:4491
+#, gcc-internal-format, gfc-internal-format
+msgid "ERRMSG tag at %L"
+msgstr ""
+
+#: fortran/match.cc:4514
+#, gcc-internal-format, gfc-internal-format
+msgid "SOURCE tag at %L"
+msgstr ""
+
+#: fortran/match.cc:4520
+#, gcc-internal-format, gfc-internal-format
+msgid "Redundant SOURCE tag found at %L"
+msgstr ""
+
+#: fortran/match.cc:4527
+#, gcc-internal-format, gfc-internal-format
+msgid "SOURCE tag at %L conflicts with the typespec at %L"
+msgstr ""
+
+#: fortran/match.cc:4533
+#, gcc-internal-format, gfc-internal-format
+msgid "SOURCE tag at %L with more than a single allocate object"
+msgstr ""
+
+#: fortran/match.cc:4551
+#, gcc-internal-format, gfc-internal-format
+msgid "MOLD tag at %L"
+msgstr ""
+
+#: fortran/match.cc:4557
+#, gcc-internal-format, gfc-internal-format
+msgid "Redundant MOLD tag found at %L"
+msgstr ""
+
+#: fortran/match.cc:4564
+#, gcc-internal-format, gfc-internal-format
+msgid "MOLD tag at %L conflicts with the typespec at %L"
+msgstr ""
+
+#: fortran/match.cc:4590
+#, gcc-internal-format, gfc-internal-format
+msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
+msgstr ""
+
+#: fortran/match.cc:4598
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
+msgstr ""
+
+#: fortran/match.cc:4610
+#, gcc-internal-format, gfc-internal-format
+msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
+msgstr ""
+
+#: fortran/match.cc:4677
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer object at %C shall not be coindexed"
+msgstr ""
+
+#: fortran/match.cc:4692
+#, gcc-internal-format, gfc-internal-format
+msgid "NULLIFY does not allow bounds remapping for pointer object at %C"
+msgstr ""
+
+#: fortran/match.cc:4786
+#, gcc-internal-format, gfc-internal-format
+msgid "Illegal allocate-object at %C for a PURE procedure"
+msgstr ""
+
+#: fortran/match.cc:4796
+#, gcc-internal-format, gfc-internal-format
+msgid "DEALLOCATE of coarray at %C in DO CONCURRENT block"
+msgstr ""
+
+#: fortran/match.cc:4803
+#, gcc-internal-format, gfc-internal-format
+msgid "DEALLOCATE of coarray at %C in CRITICAL block"
+msgstr ""
+
+#: fortran/match.cc:4819
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
+msgstr ""
+
+#: fortran/match.cc:4856
+#, gcc-internal-format, gfc-internal-format
+msgid "ERRMSG at %L"
+msgstr ""
+
+#: fortran/match.cc:4913
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement RETURN at %C in CRITICAL block"
+msgstr ""
+
+#: fortran/match.cc:4919
+#, gcc-internal-format, gfc-internal-format
+msgid "Image control statement RETURN at %C in DO CONCURRENT block"
+msgstr ""
+
+#: fortran/match.cc:4928
+#, gcc-internal-format, gfc-internal-format
+msgid "Alternate RETURN statement at %C is only allowed within a SUBROUTINE"
+msgstr ""
+
+#: fortran/match.cc:4959
+#, gcc-internal-format, gfc-internal-format
+msgid "RETURN statement in main program at %C"
+msgstr ""
+
+#: fortran/match.cc:4987
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected component reference at %C"
+msgstr ""
+
+#: fortran/match.cc:4996
+#, gcc-internal-format, gfc-internal-format
+msgid "Junk after CALL at %C"
+msgstr ""
+
+#: fortran/match.cc:5007
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected type-bound procedure or procedure pointer component at %C"
+msgstr ""
+
+#: fortran/match.cc:5105
+#, gcc-internal-format, gfc-internal-format
+msgid "A BOZ literal constant at %L cannot appear as an actual argument in a subroutine reference"
+msgstr ""
+
+#: fortran/match.cc:5246
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in common block name at %C"
+msgstr ""
+
+#. If we find an error, just print it and continue,
+#. cause it's just semantic, and we can see if there
+#. are more errors.
+#: fortran/match.cc:5321
+#, gcc-internal-format
+msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
+msgstr ""
+
+#: fortran/match.cc:5330
+#, gcc-internal-format
+msgid "Variable %qs in common block %qs at %C cannot be bind(c) since it is not global"
+msgstr ""
+
+#: fortran/match.cc:5337
+#, gcc-internal-format
+msgid "Symbol %qs at %C is already in a COMMON block"
+msgstr ""
+
+#: fortran/match.cc:5345
+#, gcc-internal-format
+msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
+msgstr ""
+
+#: fortran/match.cc:5356
+#, gcc-internal-format
+msgid "Symbol %qs at %C is USE associated from module %qs and cannot occur in COMMON"
+msgstr ""
+
+#: fortran/match.cc:5371
+#, gcc-internal-format
+msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
+msgstr ""
+
+#: fortran/match.cc:5378
+#, gcc-internal-format
+msgid "Symbol %qs in COMMON at %C cannot be a coarray"
+msgstr ""
+
+#: fortran/match.cc:5388
+#, gcc-internal-format
+msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
+msgstr ""
+
+#: fortran/match.cc:5434
+#, gcc-internal-format
+msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
+msgstr ""
+
+#: fortran/match.cc:5496
+#, gcc-internal-format, gfc-internal-format
+msgid "BLOCK DATA construct at %L"
+msgstr ""
+
+#: fortran/match.cc:5599
+#, gcc-internal-format
+msgid "Namelist group name %qs at %C already has a basic type of %s"
+msgstr ""
+
+#: fortran/match.cc:5607
+#, gcc-internal-format
+msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
+msgstr ""
+
+#. It is required that members of a namelist be declared
+#. before the namelist.  We check this by checking if the
+#. symbol has a defined type for IMPLICIT NONE.
+#: fortran/match.cc:5632
+#, gcc-internal-format
+msgid "Symbol %qs in namelist %qs at %C must be declared before the namelist is declared."
+msgstr ""
+
+#: fortran/match.cc:5652
+#, gcc-internal-format
+msgid "Derived type %qs at %L conflicts with namelist object %qs at %C"
+msgstr ""
+
+#: fortran/match.cc:5672
+#, gcc-internal-format
+msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
+msgstr ""
+
+#: fortran/match.cc:5815
+#, gcc-internal-format, gfc-internal-format
+msgid "Derived type component %C is not a permitted EQUIVALENCE member"
+msgstr ""
+
+#: fortran/match.cc:5823
+#, gcc-internal-format, gfc-internal-format
+msgid "Array reference in EQUIVALENCE at %C cannot be an array section"
+msgstr ""
+
+#: fortran/match.cc:5856
+#, gcc-internal-format, gfc-internal-format
+msgid "EQUIVALENCE at %C requires two or more objects"
+msgstr ""
+
+#: fortran/match.cc:5870
+#, gcc-internal-format, gfc-internal-format
+msgid "Attempt to indirectly overlap COMMON blocks %s and %s by EQUIVALENCE at %C"
+msgstr ""
+
+#: fortran/match.cc:5883
+#, gcc-internal-format, gfc-internal-format
+msgid "Expecting a comma in EQUIVALENCE at %C"
+msgstr ""
+
+#: fortran/match.cc:5888
+#, gcc-internal-format, gfc-internal-format
+msgid "EQUIVALENCE statement at %C"
+msgstr ""
+
+#: fortran/match.cc:5981
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid use of statement function argument at %L"
+msgstr ""
+
+#: fortran/match.cc:6048
+#, gcc-internal-format, gfc-internal-format
+msgid "Statement function at %L is recursive"
+msgstr ""
+
+#: fortran/match.cc:6054
+#, gcc-internal-format
+msgid "Statement function %qs at %L conflicts with function name"
+msgstr ""
+
+#: fortran/match.cc:6068
+#, gcc-internal-format, gfc-internal-format
+msgid "Statement function at %L cannot appear within an INTERFACE"
+msgstr ""
+
+#: fortran/match.cc:6073
+#, gcc-internal-format, gfc-internal-format
+msgid "Statement function at %C"
+msgstr ""
+
+#: fortran/match.cc:6198 fortran/match.cc:6214 fortran/match.cc:6233
+#, gcc-internal-format, gfc-internal-format
+msgid "Expression in CASE selector at %L cannot be %s"
+msgstr ""
+
+#: fortran/match.cc:6243 fortran/match.cc:6249
+#, gcc-internal-format, gfc-internal-format
+msgid "Expression in CASE selector at %L must be scalar"
+msgstr ""
+
+#: fortran/match.cc:6258
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected initialization expression in CASE at %C"
+msgstr ""
+
+#: fortran/match.cc:6290
+#, gcc-internal-format
+msgid "Expected block name %qs of SELECT construct at %C"
+msgstr ""
+
+#: fortran/match.cc:6654
+#, gcc-internal-format, gfc-internal-format
+msgid "SELECT TYPE at %C cannot appear in this scope"
+msgstr ""
+
+#: fortran/match.cc:6682
+#, gcc-internal-format, gfc-internal-format
+msgid "parse error in SELECT TYPE statement at %C"
+msgstr ""
+
+#: fortran/match.cc:6707
+#, gcc-internal-format, gfc-internal-format
+msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
+msgstr ""
+
+#: fortran/match.cc:6895
+#, gcc-internal-format, gfc-internal-format
+msgid "SELECT RANK statement at %C"
+msgstr ""
+
+#: fortran/match.cc:6936 fortran/match.cc:6990
+#, gcc-internal-format, gfc-internal-format
+msgid "The SELECT RANK selector at %C must be an assumed rank variable"
+msgstr ""
+
+#: fortran/match.cc:7000
+#, gcc-internal-format, gfc-internal-format
+msgid "parse error in SELECT RANK statement at %C"
+msgstr ""
+
+#: fortran/match.cc:7036
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected CASE statement at %C"
+msgstr ""
+
+#: fortran/match.cc:7088
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in CASE specification at %C"
+msgstr ""
+
+#: fortran/match.cc:7106
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected TYPE IS statement at %C"
+msgstr ""
+
+#: fortran/match.cc:7138
+#, gcc-internal-format, gfc-internal-format
+msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
+msgstr ""
+
+#: fortran/match.cc:7149
+#, gcc-internal-format, gfc-internal-format
+msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
+msgstr ""
+
+#: fortran/match.cc:7160
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in TYPE IS specification at %C"
+msgstr ""
+
+#: fortran/match.cc:7236
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in CLASS IS specification at %C"
+msgstr ""
+
+#: fortran/match.cc:7256
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected RANK statement at %C"
+msgstr ""
+
+#: fortran/match.cc:7302
+#, gcc-internal-format, gfc-internal-format
+msgid "The SELECT RANK CASE expression at %C must be a scalar, integer constant"
+msgstr ""
+
+#: fortran/match.cc:7311
+#, gcc-internal-format, gfc-internal-format
+msgid "The value of the SELECT RANK CASE expression at %C must not be less than zero or greater than %d"
+msgstr ""
+
+#: fortran/match.cc:7338
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in RANK specification at %C"
+msgstr ""
+
+#: fortran/match.cc:7460
+#, gcc-internal-format, gfc-internal-format
+msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
+msgstr ""
+
+#: fortran/match.cc:7498
+#, gcc-internal-format
+msgid "Label %qs at %C doesn't match WHERE label %qs"
+msgstr ""
+
+#: fortran/matchexp.cc:72
+#, gcc-internal-format
+msgid "Bad character %qc in OPERATOR name at %C"
+msgstr ""
+
+#: fortran/matchexp.cc:80
+#, gcc-internal-format
+msgid "The name %qs cannot be used as a defined operator at %C"
+msgstr ""
+
+#: fortran/matchexp.cc:173
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected a right parenthesis in expression at %C"
+msgstr ""
+
+#: fortran/matchexp.cc:281
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected exponent in expression at %C"
+msgstr ""
+
+#: fortran/matchexp.cc:319 fortran/matchexp.cc:324 fortran/matchexp.cc:428
+#: fortran/matchexp.cc:433
+#, gcc-internal-format, gfc-internal-format
+msgid "Extension: Unary operator following arithmetic operator (use parentheses) at %C"
+msgstr ""
+
+#: fortran/matchexp.cc:665
+#, gcc-internal-format
+msgid "match_level_4(): Bad operator"
+msgstr ""
+
+#: fortran/misc.cc:113
+#, gcc-internal-format
+msgid "gfc_basic_typename(): Undefined type"
+msgstr ""
+
+#: fortran/misc.cc:212
+#, gcc-internal-format
+msgid "gfc_typename(): Undefined type"
+msgstr ""
+
+#: fortran/misc.cc:316
+#, gcc-internal-format
+msgid "gfc_code2string(): Bad code"
+msgstr ""
+
+#: fortran/module.cc:243
+#, gcc-internal-format
+msgid "free_pi_tree(): Unresolved fixup"
+msgstr ""
+
+#: fortran/module.cc:460
+#, gcc-internal-format
+msgid "associate_integer_pointer(): Already associated"
+msgstr ""
+
+#: fortran/module.cc:544
+#, gcc-internal-format, gfc-internal-format
+msgid "module nature in USE statement at %C"
+msgstr ""
+
+#: fortran/module.cc:556
+#, gcc-internal-format, gfc-internal-format
+msgid "Module nature in USE statement at %C shall be either INTRINSIC or NON_INTRINSIC"
+msgstr ""
+
+#: fortran/module.cc:569
+#, gcc-internal-format, gfc-internal-format
+msgid "\"::\" was expected after module nature at %C but was not found"
+msgstr ""
+
+#: fortran/module.cc:579
+#, gcc-internal-format, gfc-internal-format
+msgid "\"USE :: module\" at %C"
+msgstr ""
+
+#: fortran/module.cc:638
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing generic specification in USE statement at %C"
+msgstr ""
+
+#: fortran/module.cc:649
+#, gcc-internal-format, gfc-internal-format
+msgid "Renaming operators in USE statements at %C"
+msgstr ""
+
+#: fortran/module.cc:693
+#, gcc-internal-format
+msgid "Symbol %qs at %L conflicts with the rename symbol at %L"
+msgstr ""
+
+#: fortran/module.cc:696
+#, gcc-internal-format
+msgid "Symbol %qs at %L conflicts with the symbol at %L"
+msgstr ""
+
+#: fortran/module.cc:704
+#, gcc-internal-format
+msgid "The name %qs at %C has already been used as an external module name"
+msgstr ""
+
+#: fortran/module.cc:767
+#, gcc-internal-format, gfc-internal-format
+msgid "SUBMODULE declaration at %C"
+msgstr ""
+
+#: fortran/module.cc:772
+#, gcc-internal-format, gfc-internal-format
+msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
+msgstr ""
+
+#: fortran/module.cc:847
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in SUBMODULE statement at %C"
+msgstr ""
+
+#: fortran/module.cc:1207
+#, gcc-internal-format
+msgid "Reading module %qs at line %d column %d: %s"
+msgstr ""
+
+#: fortran/module.cc:1211
+#, gcc-internal-format
+msgid "Writing module %qs at line %d column %d: %s"
+msgstr ""
+
+#: fortran/module.cc:1215
+#, gcc-internal-format
+msgid "Module %qs at line %d column %d: %s"
+msgstr ""
+
+#: fortran/module.cc:1648
+#, gcc-internal-format
+msgid "require_atom(): bad atom type required"
+msgstr ""
+
+#: fortran/module.cc:1697
+#, gcc-internal-format, gfc-internal-format
+msgid "Error writing modules file: %s"
+msgstr ""
+
+#: fortran/module.cc:1747
+#, gcc-internal-format
+msgid "write_atom(): Trying to write dab atom"
+msgstr ""
+
+#: fortran/module.cc:1968
+#, gcc-internal-format
+msgid "unquote_string(): got bad string"
+msgstr ""
+
+#: fortran/module.cc:2984
+#, gcc-internal-format
+msgid "mio_array_ref(): Unknown array ref"
+msgstr ""
+
+#: fortran/module.cc:5119
+#, gcc-internal-format, gfc-internal-format
+msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
+msgstr ""
+
+#: fortran/module.cc:5122
+#, gcc-internal-format, gfc-internal-format
+msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
+msgstr ""
+
+#: fortran/module.cc:5316
+#, gcc-internal-format
+msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
+msgstr ""
+
+#: fortran/module.cc:5453
+#, gcc-internal-format
+msgid "Mismatch in components of derived type %qs from %qs at %C: expecting %qs, but got %qs"
+msgstr ""
+
+#: fortran/module.cc:5732
+#, gcc-internal-format
+msgid "Symbol %qs referenced at %L not found in module %qs"
+msgstr ""
+
+#: fortran/module.cc:5739
+#, gcc-internal-format
+msgid "User operator %qs referenced at %L not found in module %qs"
+msgstr ""
+
+#: fortran/module.cc:5744
+#, gcc-internal-format
+msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
+msgstr ""
+
+#: fortran/module.cc:5980
+#, gcc-internal-format
+msgid "write_symbol(): bad module symbol %qs"
+msgstr ""
+
+#: fortran/module.cc:6324
+#, gcc-internal-format
+msgid "write_symtree(): Symbol not written"
+msgstr ""
+
+#: fortran/module.cc:6514
+#, gcc-internal-format
+msgid "Cannot open module file %qs for writing at %C: %s"
+msgstr ""
+
+#: fortran/module.cc:6535
+#, gcc-internal-format
+msgid "Error writing module file %qs for writing: %s"
+msgstr ""
+
+#: fortran/module.cc:6546
+#, gcc-internal-format
+msgid "Cannot delete module file %qs: %s"
+msgstr ""
+
+#: fortran/module.cc:6549
+#, gcc-internal-format
+msgid "Cannot rename module file %qs to %qs: %s"
+msgstr ""
+
+#: fortran/module.cc:6555
+#, gcc-internal-format
+msgid "Cannot delete temporary module file %qs: %s"
+msgstr ""
+
+#: fortran/module.cc:6612
+#, gcc-internal-format
+msgid "Symbol %qs at %C already declared"
+msgstr ""
+
+#: fortran/module.cc:6683
+#, gcc-internal-format, gfc-internal-format
+msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
+msgstr ""
+
+#: fortran/module.cc:6791 fortran/module.cc:7135
+#, gcc-internal-format
+msgid "The symbol %qs, referenced at %L, is not in the selected standard"
+msgstr ""
+
+#: fortran/module.cc:6919
+#, gcc-internal-format
+msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
+msgstr ""
+
+#: fortran/module.cc:6940 fortran/module.cc:6973 fortran/module.cc:7015
+#, gcc-internal-format
+msgid "Symbol %qs already declared"
+msgstr ""
+
+#: fortran/module.cc:7120
+#, gcc-internal-format
+msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
+msgstr ""
+
+#: fortran/module.cc:7142
+#, gcc-internal-format
+msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
+msgstr ""
+
+#: fortran/module.cc:7210
+#, gcc-internal-format, gfc-internal-format
+msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
+msgstr ""
+
+#: fortran/module.cc:7264
+#, gcc-internal-format
+msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
+msgstr ""
+
+#: fortran/module.cc:7290
+#, gcc-internal-format, gfc-internal-format
+msgid "USE statement at %C has no ONLY qualifier"
+msgstr ""
+
+#: fortran/module.cc:7319
+#, gcc-internal-format, gfc-internal-format
+msgid "ISO_FORTRAN_ENV intrinsic module at %C"
+msgstr ""
+
+#: fortran/module.cc:7331
+#, gcc-internal-format, gfc-internal-format
+msgid "ISO_C_BINDING module at %C"
+msgstr ""
+
+#: fortran/module.cc:7344
+#, gcc-internal-format
+msgid "Cannot find an intrinsic module named %qs at %C"
+msgstr ""
+
+#: fortran/module.cc:7350
+#, gcc-internal-format, gfc-internal-format
+msgid "IEEE_FEATURES module at %C"
+msgstr ""
+
+#: fortran/module.cc:7356
+#, gcc-internal-format, gfc-internal-format
+msgid "IEEE_EXCEPTIONS module at %C"
+msgstr ""
+
+#: fortran/module.cc:7362
+#, gcc-internal-format, gfc-internal-format
+msgid "IEEE_ARITHMETIC module at %C"
+msgstr ""
+
+#: fortran/module.cc:7372
+#, gcc-internal-format
+msgid "Cannot open module file %qs for reading at %C: %s"
+msgstr ""
+
+#: fortran/module.cc:7375
+#, gcc-internal-format
+msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
+msgstr ""
+
+#: fortran/module.cc:7386
+#, gcc-internal-format
+msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
+msgstr ""
+
+#: fortran/module.cc:7409
+#, gcc-internal-format
+msgid "File %qs opened at %C is not a GNU Fortran module file"
+msgstr ""
+
+#: fortran/module.cc:7417
+#, gcc-internal-format
+msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
+msgstr ""
+
+#: fortran/module.cc:7434
+#, gcc-internal-format
+msgid "Cannot USE a submodule that is currently built"
+msgstr ""
+
+#: fortran/module.cc:7436
+#, gcc-internal-format
+msgid "Cannot USE a module that is currently built"
+msgstr ""
+
+#: fortran/openmp.cc:150 fortran/openmp.cc:7113
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk at %C"
+msgstr ""
+
+#: fortran/openmp.cc:429
+#, gcc-internal-format
+msgid "%<omp_all_memory%> at %C not permitted in this clause"
+msgstr ""
+
+#: fortran/openmp.cc:474
+#, gcc-internal-format, gfc-internal-format
+msgid "List item shall not be coindexed at %C"
+msgstr ""
+
+#: fortran/openmp.cc:493
+#, gcc-internal-format
+msgid "%qs at %L is part of the common block %</%s/%> and may only be specificed implicitly via the named common block"
+msgstr ""
+
+#: fortran/openmp.cc:518 fortran/openmp.cc:619 fortran/openmp.cc:949
+#: fortran/openmp.cc:6165
+#, gcc-internal-format, gfc-internal-format
+msgid "COMMON block /%s/ not found at %C"
+msgstr ""
+
+#: fortran/openmp.cc:557 fortran/openmp.cc:647
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in OpenMP variable list at %C"
+msgstr ""
+
+#: fortran/openmp.cc:674
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in OpenMP detach clause at %C"
+msgstr ""
+
+#: fortran/openmp.cc:703
+#, gcc-internal-format
+msgid "%<omp_all_memory%> used with dependence-type other than OUT or INOUT at %C"
+msgstr ""
+
+#: fortran/openmp.cc:756
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in OpenMP SINK dependence-type list at %C"
+msgstr ""
+
+#: fortran/openmp.cc:818
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in OpenACC expression list at %C"
+msgstr ""
+
+#: fortran/openmp.cc:885
+#, gcc-internal-format
+msgid "Unexpected OpenACC parallelism."
+msgstr ""
+
+#: fortran/openmp.cc:917
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable at %C is an element of a COMMON block"
+msgstr ""
+
+#: fortran/openmp.cc:977
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after !$ACC DECLARE at %C"
+msgstr ""
+
+#: fortran/openmp.cc:987
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in !$ACC DECLARE list at %C"
+msgstr ""
+
+#: fortran/openmp.cc:1242
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected INTEGER type at %L"
+msgstr ""
+
+#: fortran/openmp.cc:1256
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected identifier at %C"
+msgstr ""
+
+#: fortran/openmp.cc:1261
+#, gcc-internal-format
+msgid "Same identifier %qs specified again at %C"
+msgstr ""
+
+#: fortran/openmp.cc:1288
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected range-specification at %C"
+msgstr ""
+
+#: fortran/openmp.cc:1398
+#, gcc-internal-format, gfc-internal-format
+msgid "Comma expected at %C"
+msgstr ""
+
+#: fortran/openmp.cc:1510
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP DECLARE REDUCTION %s not found at %L"
+msgstr ""
+
+#: fortran/openmp.cc:1570
+#, gcc-internal-format, gfc-internal-format
+msgid "Unknown directive at %L"
+msgstr ""
+
+#: fortran/openmp.cc:1572
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid combined or composite directive at %L"
+msgstr ""
+
+#: fortran/openmp.cc:1580
+#, gcc-internal-format
+msgid "Invalid %qs directive at %L in %s clause: declarative, informational and meta directives not permitted"
+msgstr ""
+
+#: fortran/openmp.cc:1612
+#, gcc-internal-format
+msgid "Expected %<,%> or %<)%> at %C"
+msgstr ""
+
+#: fortran/openmp.cc:1638 fortran/openmp.cc:1648
+#, gcc-internal-format
+msgid "%qs directive mentioned multiple times in %s clause in %s directive at %L"
+msgstr ""
+
+#: fortran/openmp.cc:1656
+#, gcc-internal-format
+msgid "%qs directive mentioned both times in ABSENT and CONTAINS clauses in %s directive at %L"
+msgstr ""
+
+#: fortran/openmp.cc:1746
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate %s modifier at %L in USES_ALLOCATORS clause"
+msgstr ""
+
+#: fortran/openmp.cc:1780
+#, gcc-internal-format
+msgid "Unexpected %<(%> at %C"
+msgstr ""
+
+#: fortran/openmp.cc:1827
+#, gcc-internal-format
+msgid "Duplicated %qs clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:1834
+#, gcc-internal-format
+msgid "Expected %<(%> after %qs at %C"
+msgstr ""
+
+#: fortran/openmp.cc:1841
+#, gcc-internal-format
+msgid "Invalid expression after %<%s(%> at %C"
+msgstr ""
+
+#: fortran/openmp.cc:1902
+#, gcc-internal-format, gfc-internal-format
+msgid "Clause expected at %C after trailing comma"
+msgstr ""
+
+#: fortran/openmp.cc:1972 fortran/openmp.cc:2008 fortran/openmp.cc:2418
+#: fortran/openmp.cc:2443
+#, gcc-internal-format
+msgid "Expected %<:%> at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2032
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected variable list at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2056
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected COMPILATION or EXECUTION in AT clause at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2117
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected TEAMS, PARALLEL or THREAD as binding in BIND at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2148
+#, gcc-internal-format, gfc-internal-format
+msgid "COLLAPSE clause argument not constant positive integer at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2251
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected ALLOC, TO, FROM, TOFROM, FIRSTPRIVATE, PRESENT, NONE or DEFAULT at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2273
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected SCALAR, AGGREGATE, ALLOCATABLE, POINTER or ALL at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2306
+#, gcc-internal-format, gfc-internal-format
+msgid "DEFAULTMAP at %C but prior DEFAULTMAP with unspecified category"
+msgstr ""
+
+#: fortran/openmp.cc:2309
+#, gcc-internal-format, gfc-internal-format
+msgid "DEFAULTMAP at %C but prior DEFAULTMAP for category %s"
+msgstr ""
+
+#: fortran/openmp.cc:2345
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected NONE or PRESENT in DEFAULT clause at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2348
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected NONE, FIRSTPRIVATE, PRIVATE or SHARED in DEFAULT clause at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2398
+#, gcc-internal-format, gfc-internal-format
+msgid "ITERATOR may not be combined with SOURCE at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2404
+#, gcc-internal-format, gfc-internal-format
+msgid "SOURCE at %C not permitted as dependence-type for this directive"
+msgstr ""
+
+#: fortran/openmp.cc:2410
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicated clause with SOURCE dependence-type at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2425
+#, gcc-internal-format
+msgid "Expected %<)%> or %<omp_cur_iteration)%> at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2437
+#, gcc-internal-format, gfc-internal-format
+msgid "SINK at %C not permitted as dependence-type for this directive"
+msgstr ""
+
+#: fortran/openmp.cc:2448
+#, gcc-internal-format, gfc-internal-format
+msgid "ITERATOR may not be combined with SINK at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2462
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected dependence-type SINK or SOURCE at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2479
+#, gcc-internal-format
+msgid "%<omp_all_memory%> used with DEPEND kind other than OUT or INOUT at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2517 fortran/openmp.cc:2552
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected integer expression at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2533
+#, gcc-internal-format
+msgid "%<ancestor%> device modifier not preceded by %<requires%> directive with %<reverse_offload%> clause at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2545
+#, gcc-internal-format
+msgid "the %<device%> clause expression must evaluate to %<1%> at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2558
+#, gcc-internal-format
+msgid "Expected integer expression or a single device-modifier %<device_num%> or %<ancestor%> at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2588
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected HOST, NOHOST or ANY at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2643
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected SEQ_CST, ACQUIRE or RELAXED at %C"
+msgstr ""
+
+#: fortran/openmp.cc:2831
+#, gcc-internal-format, gfc-internal-format
+msgid "INDIRECT clause at %C requires a constant logical expression"
+msgstr ""
+
+#: fortran/openmp.cc:3018
+#, gcc-internal-format
+msgid "Multiple %qs modifiers specified at %C"
+msgstr ""
+
+#: fortran/openmp.cc:3128
+#, gcc-internal-format
+msgid "too many %<always%> modifiers at %L"
+msgstr ""
+
+#: fortran/openmp.cc:3134
+#, gcc-internal-format
+msgid "too many %<close%> modifiers at %L"
+msgstr ""
+
+#: fortran/openmp.cc:3140
+#, gcc-internal-format
+msgid "too many %<present%> modifiers at %L"
+msgstr ""
+
+#: fortran/openmp.cc:3331
+#, gcc-internal-format
+msgid "Expected ORDER(CONCURRENT) at %C with optional %<reproducible%> or %<unconstrained%> modifier"
+msgstr ""
+
+#: fortran/openmp.cc:3356
+#, gcc-internal-format, gfc-internal-format
+msgid "ORDERED clause argument not constant positive integer at %C"
+msgstr ""
+
+#: fortran/openmp.cc:3646
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected FATAL or WARNING in SEVERITY clause at %C"
+msgstr ""
+
+#: fortran/openmp.cc:3839
+#, gcc-internal-format, gfc-internal-format
+msgid "Failed to match clause at %C"
+msgstr ""
+
+#: fortran/openmp.cc:4022
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid clause in module with !$ACC DECLARE at %L"
+msgstr ""
+
+#: fortran/openmp.cc:4032
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable is USE-associated with !$ACC DECLARE at %L"
+msgstr ""
+
+#: fortran/openmp.cc:4041
+#, gcc-internal-format
+msgid "Variable %qs shall be declared in the same scoping unit as !$ACC DECLARE at %L"
+msgstr ""
+
+#: fortran/openmp.cc:4049
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-size dummy array with !$ACC DECLARE at %L"
+msgstr ""
+
+#: fortran/openmp.cc:4098
+#, gcc-internal-format
+msgid "%<acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:4146
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid argument to !$ACC WAIT at %C"
+msgstr ""
+
+#: fortran/openmp.cc:4153
+#, gcc-internal-format, gfc-internal-format
+msgid "WAIT clause at %L requires a scalar INTEGER expression"
+msgstr ""
+
+#: fortran/openmp.cc:4201
+#, gcc-internal-format, gfc-internal-format
+msgid "ACC CACHE directive must be inside of loop %C"
+msgstr ""
+
+#: fortran/openmp.cc:4270
+#, gcc-internal-format, gfc-internal-format
+msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
+msgstr ""
+
+#: fortran/openmp.cc:4304
+#, gcc-internal-format
+msgid "Invalid NAME %qs in !$ACC ROUTINE ( NAME ) at %C"
+msgstr ""
+
+#: fortran/openmp.cc:4312
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
+msgstr ""
+
+#: fortran/openmp.cc:4319
+#, gcc-internal-format
+msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting %<)%> after NAME"
+msgstr ""
+
+#: fortran/openmp.cc:4334
+#, gcc-internal-format, gfc-internal-format
+msgid "Multiple loop axes specified for routine at %C"
+msgstr ""
+
+#: fortran/openmp.cc:4345
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic symbol specified in !$ACC ROUTINE ( NAME ) at %C marked with incompatible GANG, WORKER, or VECTOR clause"
+msgstr ""
+
+#: fortran/openmp.cc:4353
+#, gcc-internal-format, gfc-internal-format
+msgid "Intrinsic symbol specified in !$ACC ROUTINE ( NAME ) at %C marked with incompatible NOHOST clause"
+msgstr ""
+
+#: fortran/openmp.cc:4374 fortran/openmp.cc:4402
+#, gcc-internal-format, gfc-internal-format
+msgid "!$ACC ROUTINE already applied at %C"
+msgstr ""
+
+#: fortran/openmp.cc:4419
+#, gcc-internal-format, gfc-internal-format
+msgid "!$ACC ROUTINE with GANG, WORKER, or VECTOR clause is not permitted in PURE procedure at %C"
+msgstr ""
+
+#: fortran/openmp.cc:4598
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected ALIGN or ALLOCATOR clause at %C"
+msgstr ""
+
+#: fortran/openmp.cc:4606
+#, gcc-internal-format, gfc-internal-format
+msgid "Sorry, structure-element list item at %L in ALLOCATE directive is not yet supported"
+msgstr ""
+
+#: fortran/openmp.cc:4609
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected expression as list item at %L in ALLOCATE directive"
+msgstr ""
+
+#: fortran/openmp.cc:4680
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ASSUMES at %C must be in the specification part of a subprogram or module"
+msgstr ""
+
+#: fortran/openmp.cc:4747
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after $OMP CRITICAL statement at %C"
+msgstr ""
+
+#: fortran/openmp.cc:4769
+#, gcc-internal-format
+msgid "Expected %<( depobj )%> at %C"
+msgstr ""
+
+#: fortran/openmp.cc:4787
+#, gcc-internal-format
+msgid "Expected IN, OUT, INOUT, INOUTSET or MUTEXINOUTSET followed by %<)%> at %C"
+msgstr ""
+
+#: fortran/openmp.cc:4801
+#, gcc-internal-format, gfc-internal-format
+msgid "The same depend object should be used as DEPOBJ argument at %L and as DESTROY argument at %L"
+msgstr ""
+
+#: fortran/openmp.cc:4815
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected DEPEND, UPDATE, or DESTROY clause at %C"
+msgstr ""
+
+#: fortran/openmp.cc:4820
+#, gcc-internal-format, gfc-internal-format
+msgid "DEPEND clause at %L of OMP DEPOBJ construct shall not have dependence-type DEPOBJ"
+msgstr ""
+
+#: fortran/openmp.cc:4828
+#, gcc-internal-format, gfc-internal-format
+msgid "DEPEND clause at %L of OMP DEPOBJ construct shall have only a single locator"
+msgstr ""
+
+#: fortran/openmp.cc:4954 fortran/openmp.cc:9206
+#, gcc-internal-format, gfc-internal-format
+msgid "MESSAGE clause at %L requires a scalar default-kind CHARACTER expression"
+msgstr ""
+
+#: fortran/openmp.cc:4961
+#, gcc-internal-format, gfc-internal-format
+msgid "Constant character expression required in MESSAGE clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:4967
+#, gcc-internal-format, gfc-internal-format
+msgid "$OMP ERROR encountered at %L: %s"
+msgstr ""
+
+#: fortran/openmp.cc:4986
+#, gcc-internal-format, gfc-internal-format
+msgid "$OMP ERROR encountered at %L"
+msgstr ""
+
+#: fortran/openmp.cc:5014
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected SEQ_CST, AQC_REL, RELEASE, or ACQUIRE at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5023
+#, gcc-internal-format, gfc-internal-format
+msgid "List specified together with memory order clause in FLUSH directive at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5031
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after $OMP FLUSH statement at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5431 fortran/openmp.cc:11778
+#, gcc-internal-format, gfc-internal-format
+msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
+msgstr ""
+
+#: fortran/openmp.cc:5435 fortran/openmp.cc:11782
+#, gcc-internal-format, gfc-internal-format
+msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
+msgstr ""
+
+#: fortran/openmp.cc:5440
+#, gcc-internal-format, gfc-internal-format
+msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
+msgstr ""
+
+#: fortran/openmp.cc:5442
+#, gcc-internal-format, gfc-internal-format
+msgid "Previous !$OMP DECLARE REDUCTION at %L"
+msgstr ""
+
+#: fortran/openmp.cc:5462
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5499
+#, gcc-internal-format, gfc-internal-format
+msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5514
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5539
+#, gcc-internal-format, gfc-internal-format
+msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
+msgstr ""
+
+#: fortran/openmp.cc:5542
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
+msgstr ""
+
+#: fortran/openmp.cc:5548
+#, gcc-internal-format, gfc-internal-format
+msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in %s clause"
+msgstr ""
+
+#: fortran/openmp.cc:5554
+#, gcc-internal-format, gfc-internal-format
+msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO or ENTER clause and later in LINK clause"
+msgstr ""
+
+#: fortran/openmp.cc:5568 fortran/openmp.cc:5623
+#, gcc-internal-format
+msgid "List item %qs at %L set in previous OMP DECLARE TARGET directive to a different DEVICE_TYPE"
+msgstr ""
+
+#: fortran/openmp.cc:5577 fortran/openmp.cc:5631
+#, gcc-internal-format, gfc-internal-format
+msgid "DEVICE_TYPE must be ANY when used with INDIRECT at %L"
+msgstr ""
+
+#: fortran/openmp.cc:5587
+#, gcc-internal-format, gfc-internal-format
+msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in %s clause"
+msgstr ""
+
+#: fortran/openmp.cc:5593
+#, gcc-internal-format, gfc-internal-format
+msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO or ENTER clause and later in LINK clause"
+msgstr ""
+
+#: fortran/openmp.cc:5597
+#, gcc-internal-format, gfc-internal-format
+msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
+msgstr ""
+
+#: fortran/openmp.cc:5606
+#, gcc-internal-format, gfc-internal-format
+msgid "COMMON at %L set in previous OMP DECLARE TARGET directive to a different DEVICE_TYPE"
+msgstr ""
+
+#: fortran/openmp.cc:5641
+#, gcc-internal-format, gfc-internal-format
+msgid "OMP DECLARE TARGET directive at %L with only DEVICE_TYPE or INDIRECT clauses is ignored"
+msgstr ""
+
+#: fortran/openmp.cc:5652
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
+msgstr ""
+
+#. FIXME: constant integer expressions.
+#: fortran/openmp.cc:5691
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected trait-property-extension at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5706 fortran/openmp.cc:5803 fortran/openmp.cc:5934
+#: fortran/openmp.cc:6084 fortran/openmp.cc:6112
+#, gcc-internal-format
+msgid "expected %<)%> at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5728
+#, gcc-internal-format, gfc-internal-format
+msgid "expected trait selector name at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5747
+#, gcc-internal-format
+msgid "unknown selector %qs for context selector set %qs at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5765
+#, gcc-internal-format
+msgid "selector %qs does not accept any properties at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5774
+#, gcc-internal-format
+msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5781 fortran/openmp.cc:5944 fortran/openmp.cc:6036
+#: fortran/openmp.cc:6103
+#, gcc-internal-format
+msgid "expected %<(%> at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5789
+#, gcc-internal-format
+msgid "%<score%> argument must be constant integer expression at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5797
+#, gcc-internal-format
+msgid "%<score%> argument must be non-negative at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5809
+#, gcc-internal-format, gfc-internal-format
+msgid "expected : at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5831
+#, gcc-internal-format, gfc-internal-format
+msgid "expected identifier at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5850
+#, gcc-internal-format, gfc-internal-format
+msgid "expected identifier or string literal at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5871
+#, gcc-internal-format, gfc-internal-format
+msgid "expected expression at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5883
+#, gcc-internal-format, gfc-internal-format
+msgid "property must be a constant logical expression at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5886
+#, gcc-internal-format, gfc-internal-format
+msgid "property must be a constant integer expression at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5898
+#, gcc-internal-format, gfc-internal-format
+msgid "property must be a conforming device number at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5912
+#, gcc-internal-format, gfc-internal-format
+msgid "expected simd clause at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5985
+#, gcc-internal-format, gfc-internal-format
+msgid "expected context selector set name at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5992
+#, gcc-internal-format
+msgid "expected %<=%> at %C"
+msgstr ""
+
+#: fortran/openmp.cc:5999
+#, gcc-internal-format
+msgid "expected %<{%> at %C"
+msgstr ""
+
+#: fortran/openmp.cc:6014
+#, gcc-internal-format
+msgid "expected %<}%> at %C"
+msgstr ""
+
+#: fortran/openmp.cc:6043
+#, gcc-internal-format, gfc-internal-format
+msgid "expected name at %C"
+msgstr ""
+
+#: fortran/openmp.cc:6054
+#, gcc-internal-format, gfc-internal-format
+msgid "expected variant name at %C"
+msgstr ""
+
+#: fortran/openmp.cc:6094
+#, gcc-internal-format
+msgid "expected %<match%> at %C"
+msgstr ""
+
+#: fortran/openmp.cc:6145
+#, gcc-internal-format, gfc-internal-format
+msgid "Threadprivate variable at %C is an element of a COMMON block"
+msgstr ""
+
+#: fortran/openmp.cc:6182
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after OMP THREADPRIVATE at %C"
+msgstr ""
+
+#: fortran/openmp.cc:6189
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
+msgstr ""
+
+#: fortran/openmp.cc:6295
+#, gcc-internal-format, gfc-internal-format
+msgid "Program unit at %L has OpenMP device constructs/routines but does not set !$OMP REQUIRES REVERSE_OFFLOAD but other program units do"
+msgstr ""
+
+#: fortran/openmp.cc:6300
+#, gcc-internal-format, gfc-internal-format
+msgid "Program unit at %L has OpenMP device constructs/routines but does not set !$OMP REQUIRES UNIFIED_ADDRESS but other program units do"
+msgstr ""
+
+#: fortran/openmp.cc:6305
+#, gcc-internal-format, gfc-internal-format
+msgid "Program unit at %L has OpenMP device constructs/routines but does not set !$OMP REQUIRES UNIFIED_SHARED_MEMORY but other program units do"
+msgstr ""
+
+#: fortran/openmp.cc:6331
+#, gcc-internal-format
+msgid "!$OMP REQUIRES clause %qs specified via module %qs use at %L comes after using a device construct/routine"
+msgstr ""
+
+#: fortran/openmp.cc:6335
+#, gcc-internal-format
+msgid "!$OMP REQUIRES clause %qs specified at %L comes after using a device construct/routine"
+msgstr ""
+
+#: fortran/openmp.cc:6358
+#, gcc-internal-format
+msgid "!$OMP REQUIRES clause %<atomic_default_mem_order(%s)%> specified via module %qs use at %L overrides a previous %<atomic_default_mem_order(%s)%> (which might be through using a module)"
+msgstr ""
+
+#: fortran/openmp.cc:6363
+#, gcc-internal-format
+msgid "!$OMP REQUIRES clause %<atomic_default_mem_order(%s)%> specified at %L overrides a previous %<atomic_default_mem_order(%s)%> (which might be through using a module)"
+msgstr ""
+
+#: fortran/openmp.cc:6374
+#, gcc-internal-format
+msgid "!$OMP REQUIRES clause %<atomic_default_mem_order(%s)%> specified via module %qs use at %L but same clause is not specified for the program unit"
+msgstr ""
+
+#: fortran/openmp.cc:6379
+#, gcc-internal-format
+msgid "!$OMP REQUIRES clause %qs specified via module %qs use at %L but same clause is not specified for the program unit"
+msgstr ""
+
+#: fortran/openmp.cc:6408
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP REQUIRES at %C must appear in the specification part of a program unit"
+msgstr ""
+
+#: fortran/openmp.cc:6486
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected ACQ_REL, ACQUIRE, RELAXED, RELEASE or SEQ_CST for ATOMIC_DEFAULT_MEM_ORDER clause at %C"
+msgstr ""
+
+#: fortran/openmp.cc:6502
+#, gcc-internal-format, gfc-internal-format
+msgid "Clause expected at %C"
+msgstr ""
+
+#: fortran/openmp.cc:6508
+#, gcc-internal-format
+msgid "%qs clause at %L specified more than once"
+msgstr ""
+
+#: fortran/openmp.cc:6511
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected UNIFIED_ADDRESS, UNIFIED_SHARED_MEMORY, DYNAMIC_ALLOCATORS, REVERSE_OFFLOAD, or ATOMIC_DEFAULT_MEM_ORDER clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:6537
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected INCLUSIVE or EXCLUSIVE clause at %C"
+msgstr ""
+
+#: fortran/openmp.cc:6543
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after !$OMP SCAN at %C"
+msgstr ""
+
+#: fortran/openmp.cc:6742
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after TASKYIELD clause at %C"
+msgstr ""
+
+#: fortran/openmp.cc:6830
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after $OMP MASTER statement at %C"
+msgstr ""
+
+#: fortran/openmp.cc:6862
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after $OMP NOTHING statement at %C"
+msgstr ""
+
+#: fortran/openmp.cc:6897 fortran/openmp.cc:6900 fortran/openmp.cc:6903
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC at %L with %s clause is incompatible with READ or WRITE"
+msgstr ""
+
+#: fortran/openmp.cc:6907
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC at %L with %s clause requires %s clause"
+msgstr ""
+
+#: fortran/openmp.cc:6937
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC WRITE at %L incompatible with ACQUIRES clause implicitly provided by a REQUIRES directive"
+msgstr ""
+
+#: fortran/openmp.cc:6948
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC READ at %L incompatible with RELEASE clause implicitly provided by a REQUIRES directive"
+msgstr ""
+
+#: fortran/openmp.cc:6966
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC READ at %L incompatible with RELEASE clause"
+msgstr ""
+
+#: fortran/openmp.cc:6976
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC WRITE at %L incompatible with ACQUIRE clause"
+msgstr ""
+
+#: fortran/openmp.cc:7013
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after !$ACC ATOMIC statement at %C"
+msgstr ""
+
+#: fortran/openmp.cc:7028
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after $OMP BARRIER statement at %C"
+msgstr ""
+
+#: fortran/openmp.cc:7084
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected construct-type PARALLEL, SECTIONS, DO or TASKGROUP in $OMP CANCELLATION POINT statement at %C"
+msgstr ""
+
+#: fortran/openmp.cc:7090
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
+msgstr ""
+
+#: fortran/openmp.cc:7111
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected junk after NOWAIT clause at %C"
+msgstr ""
+
+#: fortran/openmp.cc:7150
+#, gcc-internal-format, gfc-internal-format
+msgid "%s clause at %L requires a scalar INTEGER expression"
+msgstr ""
+
+#: fortran/openmp.cc:7162
+#, gcc-internal-format, gfc-internal-format
+msgid "INTEGER expression of %s clause at %L must be positive"
+msgstr ""
+
+#: fortran/openmp.cc:7174
+#, gcc-internal-format, gfc-internal-format
+msgid "INTEGER expression of %s clause at %L must be non-negative"
+msgstr ""
+
+#: fortran/openmp.cc:7185
+#, gcc-internal-format
+msgid "Cray pointer object %qs of derived type in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7188
+#, gcc-internal-format
+msgid "Cray pointee object %qs of derived type in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7194 fortran/openmp.cc:9074
+#, gcc-internal-format
+msgid "POINTER object %qs of polymorphic type in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7199
+#, gcc-internal-format
+msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7204
+#, gcc-internal-format
+msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7214 fortran/openmp.cc:8559 fortran/openmp.cc:8836
+#, gcc-internal-format
+msgid "Assumed size array %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7217
+#, gcc-internal-format
+msgid "Assumed rank array %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7233 fortran/openmp.cc:8823
+#, gcc-internal-format
+msgid "POINTER object %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7238 fortran/openmp.cc:9078
+#, gcc-internal-format
+msgid "Cray pointer object %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7243 fortran/openmp.cc:9081
+#, gcc-internal-format
+msgid "Cray pointee object %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7248 fortran/openmp.cc:9069
+#, gcc-internal-format
+msgid "ALLOCATABLE object %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7251
+#, gcc-internal-format
+msgid "VALUE object %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7294
+#, gcc-internal-format, gfc-internal-format
+msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7343
+#, gcc-internal-format, gfc-internal-format
+msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7379
+#, gcc-internal-format
+msgid "Unexpected function-result variable %qs at %L in declarative !$OMP ALLOCATE"
+msgstr ""
+
+#: fortran/openmp.cc:7385
+#, gcc-internal-format
+msgid "Procedure pointer %qs not supported with !$OMP ALLOCATE at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7391
+#, gcc-internal-format
+msgid "Argument %qs at %L to declarative !$OMP ALLOCATE directive must be a variable"
+msgstr ""
+
+#: fortran/openmp.cc:7398
+#, gcc-internal-format
+msgid "Argument %qs at %L to declarative !$OMP ALLOCATE shall be in the same scope as the variable declaration"
+msgstr ""
+
+#: fortran/openmp.cc:7405
+#, gcc-internal-format
+msgid "Unexpected dummy argument %qs as argument at %L to declarative !$OMP ALLOCATE"
+msgstr ""
+
+#: fortran/openmp.cc:7411
+#, gcc-internal-format
+msgid "Unexpected coarray argument %qs as argument at %L to declarative !$OMP ALLOCATE"
+msgstr ""
+
+#: fortran/openmp.cc:7419
+#, gcc-internal-format
+msgid "Duplicated common block %</%s/%> in !$OMP ALLOCATE at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7426
+#, gcc-internal-format
+msgid "Duplicated variable %qs in !$OMP ALLOCATE at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7437
+#, gcc-internal-format
+msgid "Sorry, EQUIVALENCE object %qs not supported with !$OMP ALLOCATE at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7446
+#, gcc-internal-format
+msgid "Sorry, Cray pointers and pointees such as %qs are not supported with !$OMP ALLOCATE at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7455
+#, gcc-internal-format
+msgid "Unexpected allocatable variable %qs at %L in declarative !$OMP ALLOCATE directive"
+msgstr ""
+
+#: fortran/openmp.cc:7460
+#, gcc-internal-format
+msgid "Unexpected pointer variable %qs at %L in declarative !$OMP ALLOCATE directive"
+msgstr ""
+
+#: fortran/openmp.cc:7471 fortran/openmp.cc:8026
+#, gcc-internal-format, gfc-internal-format
+msgid "ALIGN requires a scalar positive constant integer alignment expression at %L that is a power of two"
+msgstr ""
+
+#: fortran/openmp.cc:7486
+#, gcc-internal-format
+msgid "An ALLOCATOR clause is required as the list item %<%s%s%s%> at %L has the SAVE attribute"
+msgstr ""
+
+#: fortran/openmp.cc:7491
+#, gcc-internal-format
+msgid "Predefined allocator required in ALLOCATOR clause at %L as the list item %<%s%s%s%> at %L has the SAVE attribute"
+msgstr ""
+
+#: fortran/openmp.cc:7505 fortran/openmp.cc:8010
+#, gcc-internal-format
+msgid "Expected integer expression of the %<omp_allocator_handle_kind%> kind at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7521
+#, gcc-internal-format, gfc-internal-format
+msgid "HOLDS expression at %L must be a scalar logical expression"
+msgstr ""
+
+#: fortran/openmp.cc:7557
+#, gcc-internal-format, gfc-internal-format
+msgid "ORDERED clause parameter is less than COLLAPSE at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7560
+#, gcc-internal-format, gfc-internal-format
+msgid "ORDER clause must not be used together ORDERED at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7567 fortran/openmp.cc:7578 fortran/resolve.cc:11318
+#: fortran/resolve.cc:12887
+#, gcc-internal-format, gfc-internal-format
+msgid "IF clause at %L requires a scalar LOGICAL expression"
+msgstr ""
+
+#: fortran/openmp.cc:7582
+#, gcc-internal-format, gfc-internal-format
+msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
+msgstr ""
+
+#: fortran/openmp.cc:7707
+#, gcc-internal-format, gfc-internal-format
+msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
+msgstr ""
+
+#: fortran/openmp.cc:7717
+#, gcc-internal-format, gfc-internal-format
+msgid "SELF clause at %L requires a scalar LOGICAL expression"
+msgstr ""
+
+#: fortran/openmp.cc:7726
+#, gcc-internal-format, gfc-internal-format
+msgid "FINAL clause at %L requires a scalar LOGICAL expression"
+msgstr ""
+
+#: fortran/openmp.cc:7736
+#, gcc-internal-format, gfc-internal-format
+msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
+msgstr ""
+
+#: fortran/openmp.cc:7741
+#, gcc-internal-format, gfc-internal-format
+msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
+msgstr ""
+
+#: fortran/openmp.cc:7748
+#, gcc-internal-format, gfc-internal-format
+msgid "Both MONOTONIC and NONMONOTONIC schedule modifiers specified at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7751
+#, gcc-internal-format, gfc-internal-format
+msgid "NONMONOTONIC schedule modifier specified with ORDERED clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7760
+#, gcc-internal-format, gfc-internal-format
+msgid "DEPOBJ in DEPOBJ construct at %L shall be a scalar integer of OMP_DEPEND_KIND kind"
+msgstr ""
+
+#: fortran/openmp.cc:7781
+#, gcc-internal-format
+msgid "Variable %qs is not a dummy argument at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7816
+#, gcc-internal-format
+msgid "Object %qs is not a variable at %L; parameters cannot be and need not be copied"
+msgstr ""
+
+#: fortran/openmp.cc:7820
+#, gcc-internal-format
+msgid "Object %qs is not a variable at %L; parameters cannot be and need not be mapped"
+msgstr ""
+
+#: fortran/openmp.cc:7825 fortran/openmp.cc:11441
+#, gcc-internal-format
+msgid "Object %qs is not a variable at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7836
+#, gcc-internal-format
+msgid "%<inscan%> REDUCTION clause on construct other than DO, SIMD, DO SIMD, PARALLEL DO, PARALLEL DO SIMD at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7840
+#, gcc-internal-format
+msgid "ORDERED clause specified together with %<inscan%> REDUCTION clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7843
+#, gcc-internal-format
+msgid "SCHEDULE clause specified together with %<inscan%> REDUCTION clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7874 fortran/openmp.cc:7886 fortran/openmp.cc:7907
+#: fortran/openmp.cc:7919 fortran/openmp.cc:7942 fortran/openmp.cc:7950
+#: fortran/openmp.cc:7971 fortran/openmp.cc:7982 fortran/openmp.cc:7994
+#: fortran/openmp.cc:8229 fortran/openmp.cc:11465
+#, gcc-internal-format
+msgid "Symbol %qs present on multiple clauses at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7915
+#, gcc-internal-format
+msgid "Symbol %qs has mixed component and non-component accesses at %L"
+msgstr ""
+
+#: fortran/openmp.cc:7965
+#, gcc-internal-format
+msgid "Symbol %qs present on both data and map clauses at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8051
+#, gcc-internal-format
+msgid "%qs appears more than once in %<allocate%> at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8093
+#, gcc-internal-format
+msgid "%qs specified in %<allocate%> clause at %L but not in an explicit privatization clause"
+msgstr ""
+
+#: fortran/openmp.cc:8121
+#, gcc-internal-format
+msgid "Unexpected coarray %qs in %<allocate%> at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8135
+#, gcc-internal-format
+msgid "%qs specified in %<allocate%> at %L but not in the associated ALLOCATE statement"
+msgstr ""
+
+#: fortran/openmp.cc:8169
+#, gcc-internal-format
+msgid "%qs listed in %<allocate%> statement at %L but it is neither explicitly in listed in the %<!$OMP ALLOCATE%> directive nor exists a directive without argument list"
+msgstr ""
+
+#: fortran/openmp.cc:8180
+#, gcc-internal-format
+msgid "Unexpected coarray %qs in %<allocate%> at %L, implicitly listed in %<!$OMP ALLOCATE%> at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8205
+#, gcc-internal-format
+msgid "ALLOCATORS directive at %L inside a target region must specify an ALLOCATOR modifier for %qs"
+msgstr ""
+
+#: fortran/openmp.cc:8209
+#, gcc-internal-format
+msgid "ALLOCATE directive at %L inside a target region must specify an ALLOCATOR clause for %qs"
+msgstr ""
+
+#: fortran/openmp.cc:8213
+#, gcc-internal-format, gfc-internal-format
+msgid "ALLOCATE directive at %L inside a target region must specify an ALLOCATOR clause"
+msgstr ""
+
+#: fortran/openmp.cc:8236
+#, gcc-internal-format
+msgid "Array %qs is not permitted in reduction at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8249
+#, gcc-internal-format
+msgid "Symbol %qs present on both FROM and TO clauses at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8267
+#, gcc-internal-format
+msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8273
+#, gcc-internal-format, gfc-internal-format
+msgid "NOWAIT clause must not be used with COPYPRIVATE clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8278
+#, gcc-internal-format
+msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8281
+#, gcc-internal-format
+msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8289
+#, gcc-internal-format
+msgid "THREADPRIVATE object %qs in SHARED clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8292
+#, gcc-internal-format
+msgid "Cray pointee %qs in SHARED clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8295
+#, gcc-internal-format
+msgid "Associate name %qs in SHARED clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8301
+#, gcc-internal-format
+msgid "DETACH event handle %qs in SHARED clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8316
+#, gcc-internal-format
+msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8326
+#, gcc-internal-format
+msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
+msgstr ""
+
+#: fortran/openmp.cc:8352
+#, gcc-internal-format, gfc-internal-format
+msgid "Scalar integer expression for range begin expected at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8358
+#, gcc-internal-format, gfc-internal-format
+msgid "Scalar integer expression for range end expected at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8364
+#, gcc-internal-format, gfc-internal-format
+msgid "Scalar integer expression for range step expected at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8369
+#, gcc-internal-format, gfc-internal-format
+msgid "Nonzero range step expected at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8382
+#, gcc-internal-format, gfc-internal-format
+msgid "Dependence-type SINK used together with SOURCE on the same construct at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8392
+#, gcc-internal-format, gfc-internal-format
+msgid "SINK addend not a constant integer at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8398
+#, gcc-internal-format
+msgid "omp_cur_iteration at %L requires %<-1%> as logical offset"
+msgstr ""
+
+#: fortran/openmp.cc:8408
+#, gcc-internal-format
+msgid "Locator %qs at %L in DEPEND clause of depobj type shall be a scalar integer of OMP_DEPEND_KIND kind"
+msgstr ""
+
+#: fortran/openmp.cc:8419
+#, gcc-internal-format, gfc-internal-format
+msgid "Locator at %L in DEPEND clause of depobj type shall be a scalar integer of OMP_DEPEND_KIND kind"
+msgstr ""
+
+#: fortran/openmp.cc:8463
+#, gcc-internal-format, gfc-internal-format
+msgid "Array is not contiguous at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8478
+#, gcc-internal-format
+msgid "%qs clause argument must be ALLOCATABLE or a POINTER at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8490
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected substring reference in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8498
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected complex-parts designator reference in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8507 fortran/openmp.cc:8525
+#, gcc-internal-format
+msgid "%qs in %s clause at %L is not a proper array section"
+msgstr ""
+
+#: fortran/openmp.cc:8517
+#, gcc-internal-format, gfc-internal-format
+msgid "Stride should not be specified for array section in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8539
+#, gcc-internal-format
+msgid "%qs in %s clause at %L is a zero size array section"
+msgstr ""
+
+#: fortran/openmp.cc:8565
+#, gcc-internal-format
+msgid "List item %qs with allocatable components is not permitted in map clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8591
+#, gcc-internal-format, gfc-internal-format
+msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8622
+#, gcc-internal-format, gfc-internal-format
+msgid "TARGET ENTER DATA with map-type other than TO, TOFROM or ALLOC on MAP clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8651
+#, gcc-internal-format, gfc-internal-format
+msgid "TARGET EXIT DATA with map-type other than FROM, TOFROM, RELEASE, or DELETE on MAP clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8667 fortran/openmp.cc:8807
+#, gcc-internal-format
+msgid "THREADPRIVATE object %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8670 fortran/openmp.cc:8810
+#, gcc-internal-format
+msgid "Cray pointee %qs in %s clause at %L"
+msgstr ""
+
+#. Non-TARGET (i.e. DISPATCH) requires a C_PTR.
+#: fortran/openmp.cc:8682
+#, gcc-internal-format
+msgid "List item %qs in %s clause at %L must be of TYPE(C_PTR)"
+msgstr ""
+
+#: fortran/openmp.cc:8739
+#, gcc-internal-format
+msgid "Memspace %qs at %L in USES_ALLOCATORS must be a predefined memory space"
+msgstr ""
+
+#: fortran/openmp.cc:8747
+#, gcc-internal-format
+msgid "Allocator %qs at %L in USES_ALLOCATORS must be a scalar integer of kind %<omp_allocator_handle_kind%>"
+msgstr ""
+
+#: fortran/openmp.cc:8755
+#, gcc-internal-format
+msgid "Allocator %qs at %L in USES_ALLOCATORS must either a variable or a predefined allocator"
+msgstr ""
+
+#: fortran/openmp.cc:8760
+#, gcc-internal-format
+msgid "A memory space or traits array may not be specified for predefined allocator %qs at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8771
+#, gcc-internal-format
+msgid "Traits array %qs in USES_ALLOCATORS %L must be a one-dimensional named constant array of type %<omp_alloctrait%>"
+msgstr ""
+
+#: fortran/openmp.cc:8801
+#, gcc-internal-format
+msgid "%<inscan%> and non-%<inscan%> %<reduction%> clauses on the same construct at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8813
+#, gcc-internal-format
+msgid "Associate name %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8820
+#, gcc-internal-format
+msgid "Procedure pointer %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8826
+#, gcc-internal-format
+msgid "Cray pointer %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8839
+#, gcc-internal-format
+msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
+msgstr ""
+
+#. case OMP_LIST_REDUCTION:
+#: fortran/openmp.cc:8849
+#, gcc-internal-format
+msgid "INTENT(IN) POINTER %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8860
+#, gcc-internal-format
+msgid "DETACH event handle %qs in %s clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8884
+#, gcc-internal-format, gfc-internal-format
+msgid "Only DEFAULT permitted as reduction-modifier in REDUCTION clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:8977
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9005
+#, gcc-internal-format, gfc-internal-format
+msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9011
+#, gcc-internal-format, gfc-internal-format
+msgid "LINEAR clause modifier other than VAL used on DO or SIMD construct at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9019
+#, gcc-internal-format
+msgid "LINEAR variable %qs must be INTEGER at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9024
+#, gcc-internal-format
+msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9035
+#, gcc-internal-format
+msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
+msgstr ""
+
+#: fortran/openmp.cc:9052
+#, gcc-internal-format
+msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
+msgstr ""
+
+#: fortran/openmp.cc:9086
+#, gcc-internal-format
+msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
+msgstr ""
+
+#: fortran/openmp.cc:9146
+#, gcc-internal-format, gfc-internal-format
+msgid "NUM_TEAMS lower bound at %L larger than upper bound at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9159
+#, gcc-internal-format, gfc-internal-format
+msgid "Value of HINT clause at %L shall be a valid constant hint expression"
+msgstr ""
+
+#: fortran/openmp.cc:9169
+#, gcc-internal-format, gfc-internal-format
+msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
+msgstr ""
+
+#: fortran/openmp.cc:9199
+#, gcc-internal-format, gfc-internal-format
+msgid "Incompatible use of TILE and COLLAPSE at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9223
+#, gcc-internal-format, gfc-internal-format
+msgid "TARGET DATA must contain at least one MAP, USE_DEVICE_PTR, or USE_DEVICE_ADDR clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9226
+#, gcc-internal-format, gfc-internal-format
+msgid "%s must contain at least one MAP clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9236
+#, gcc-internal-format
+msgid "%qs at %L should be a scalar of type integer(kind=omp_event_handle_kind)"
+msgstr ""
+
+#: fortran/openmp.cc:9241
+#, gcc-internal-format, gfc-internal-format
+msgid "The event handle at %L must not be an array element"
+msgstr ""
+
+#: fortran/openmp.cc:9245
+#, gcc-internal-format, gfc-internal-format
+msgid "The event handle at %L must not be part of a derived type or class"
+msgstr ""
+
+#: fortran/openmp.cc:9249
+#, gcc-internal-format
+msgid "%<DETACH%> clause at %L must not be used together with %<MERGEABLE%> clause"
+msgstr ""
+
+#: fortran/openmp.cc:9256
+#, gcc-internal-format
+msgid "%<host_data%> construct at %L requires %<use_device%> clause"
+msgstr ""
+
+#: fortran/openmp.cc:9410
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected IF at %L in atomic compare capture"
+msgstr ""
+
+#: fortran/openmp.cc:9418
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected ELSE at %L in atomic compare capture"
+msgstr ""
+
+#: fortran/openmp.cc:9530
+#, gcc-internal-format
+msgid "Expected %<==%>, %<.EQ.%> or %<.EQV.%> atomic comparison expression at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9536
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected scalar intrinsic variable at %L in atomic comparison"
+msgstr ""
+
+#: fortran/openmp.cc:9544
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected scalar intrinsic expression at %L in atomic comparison"
+msgstr ""
+
+#: fortran/openmp.cc:9552
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9561
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC statement must assign an expression of intrinsic type at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9568
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9585
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9590
+#, gcc-internal-format, gfc-internal-format
+msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9602
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC capture-statement must set a scalar variable of intrinsic type at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9610
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC capture-statement requires a scalar variable of intrinsic type at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9620
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9636
+#, gcc-internal-format
+msgid "For !$OMP ATOMIC COMPARE, the first operand in comparison at %L must be the variable %qs that the update statement writes into at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9644
+#, gcc-internal-format, gfc-internal-format
+msgid "expr in !$OMP ATOMIC COMPARE assignment var = expr must be scalar and cannot reference var at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9662
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC UPDATE at %L with FAIL clause requiries either the COMPARE clause or using the intrinsic MIN/MAX procedure"
+msgstr ""
+
+#: fortran/openmp.cc:9689
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9737
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9751
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9784
+#, gcc-internal-format, gfc-internal-format
+msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9808
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9815
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9838
+#, gcc-internal-format
+msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9845
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9853
+#, gcc-internal-format
+msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9871
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9876
+#, gcc-internal-format, gfc-internal-format
+msgid "unexpected !$OMP ATOMIC expression at %L"
+msgstr ""
+
+#: fortran/openmp.cc:9978
+#, gcc-internal-format, gfc-internal-format
+msgid "With INSCAN at %L, expected loop body with !$OMP SCAN between two structured block sequences"
+msgstr ""
+
+#: fortran/openmp.cc:9985
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP SCAN at %L with zero executable statements in preceding structured block sequence"
+msgstr ""
+
+#: fortran/openmp.cc:9992
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP SCAN at %L with zero executable statements in succeeding structured block sequence"
+msgstr ""
+
+#: fortran/openmp.cc:10206
+#, gcc-internal-format, gfc-internal-format
+msgid "%s cannot contain loop in intervening code at %L"
+msgstr ""
+
+#: fortran/openmp.cc:10286
+#, gcc-internal-format, gfc-internal-format
+msgid "%s cannot contain OpenMP directive in intervening code at %L"
+msgstr ""
+
+#: fortran/openmp.cc:10298 fortran/openmp.cc:10324
+#, gcc-internal-format, gfc-internal-format
+msgid "%s cannot contain OpenMP API call in intervening code at %L"
+msgstr ""
+
+#: fortran/openmp.cc:10852
+#, gcc-internal-format, gfc-internal-format
+msgid "%s cannot be a DO WHILE or DO without loop control at %L"
+msgstr ""
+
+#: fortran/openmp.cc:10858
+#, gcc-internal-format, gfc-internal-format
+msgid "%s cannot be a DO CONCURRENT loop at %L"
+msgstr ""
+
+#: fortran/openmp.cc:10865
+#, gcc-internal-format, gfc-internal-format
+msgid "%s iteration variable must be of type integer at %L"
+msgstr ""
+
+#: fortran/openmp.cc:10872
+#, gcc-internal-format, gfc-internal-format
+msgid "%s iteration variable must not be THREADPRIVATE at %L"
+msgstr ""
+
+#: fortran/openmp.cc:10887
+#, gcc-internal-format, gfc-internal-format
+msgid "%s iteration variable present on clause other than PRIVATE, LASTPRIVATE or ALLOCATE at %L"
+msgstr ""
+
+#: fortran/openmp.cc:10891
+#, gcc-internal-format, gfc-internal-format
+msgid "%s iteration variable present on clause other than PRIVATE, LASTPRIVATE, ALLOCATE or LINEAR at %L"
+msgstr ""
+
+#: fortran/openmp.cc:10898
+#, gcc-internal-format, gfc-internal-format
+msgid "%s iteration variable used in more than one loop at %L"
+msgstr ""
+
+#: fortran/openmp.cc:10904
+#, gcc-internal-format, gfc-internal-format
+msgid "%s iteration variable at %L is bound in intervening code"
+msgstr ""
+
+#: fortran/openmp.cc:10913
+#, gcc-internal-format, gfc-internal-format
+msgid "%s loop start expression not in canonical form at %L"
+msgstr ""
+
+#: fortran/openmp.cc:10920
+#, gcc-internal-format, gfc-internal-format
+msgid "%s loop start expression at %L uses variable bound in intervening code"
+msgstr ""
+
+#: fortran/openmp.cc:10929
+#, gcc-internal-format, gfc-internal-format
+msgid "%s loop end expression not in canonical form at %L"
+msgstr ""
+
+#: fortran/openmp.cc:10936
+#, gcc-internal-format, gfc-internal-format
+msgid "%s loop end expression at %L uses variable bound in intervening code"
+msgstr ""
+
+#: fortran/openmp.cc:10943
+#, gcc-internal-format, gfc-internal-format
+msgid "%s loop bounds reference different iteration variables at %L"
+msgstr ""
+
+#: fortran/openmp.cc:10949
+#, gcc-internal-format, gfc-internal-format
+msgid "%s loop increment not in canonical form at %L"
+msgstr ""
+
+#: fortran/openmp.cc:10956
+#, gcc-internal-format, gfc-internal-format
+msgid "%s loop increment expression at %L uses variable bound in intervening code"
+msgstr ""
+
+#. Parse error, can't recover from this.
+#: fortran/openmp.cc:10974
+#, gcc-internal-format, gfc-internal-format
+msgid "not enough DO loops for collapsed %s (level %d) at %L"
+msgstr ""
+
+#: fortran/openmp.cc:10986
+#, gcc-internal-format, gfc-internal-format
+msgid "%s inner loops must be perfectly nested with ORDERED clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:10993
+#, gcc-internal-format, gfc-internal-format
+msgid "%s inner loops must be perfectly nested with REDUCTION INSCAN clause at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11220 fortran/openmp.cc:11233
+#, gcc-internal-format, gfc-internal-format
+msgid "The %s directive cannot be specified within a %s region at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11252
+#, gcc-internal-format, gfc-internal-format
+msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11258
+#, gcc-internal-format, gfc-internal-format
+msgid "!$ACC LOOP cannot be a DO CONCURRENT loop at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11264
+#, gcc-internal-format, gfc-internal-format
+msgid "!$ACC LOOP iteration variable must be of type integer at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11280
+#, gcc-internal-format, gfc-internal-format
+msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11292
+#, gcc-internal-format, gfc-internal-format
+msgid "%s !$ACC LOOP loops not perfectly nested at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11302 fortran/openmp.cc:11311
+#, gcc-internal-format, gfc-internal-format
+msgid "not enough DO loops for %s !$ACC LOOP at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11327
+#, gcc-internal-format, gfc-internal-format
+msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11348
+#, gcc-internal-format, gfc-internal-format
+msgid "TILE requires constant expression at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11448
+#, gcc-internal-format
+msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11495
+#, gcc-internal-format
+msgid "NAME %qs does not refer to a subroutine or function in !$ACC ROUTINE ( NAME ) at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11501
+#, gcc-internal-format
+msgid "NAME %qs invalid in !$ACC ROUTINE ( NAME ) at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11569
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP TARGET region at %L with a nested TEAMS at %L may not contain any other statement, declaration or directive outside of the single TEAMS construct"
+msgstr ""
+
+#: fortran/openmp.cc:11573
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP TARGET region at %L with a nested TEAMS may not contain any other statement, declaration or directive outside of the single TEAMS construct"
+msgstr ""
+
+#: fortran/openmp.cc:11667
+#, gcc-internal-format, gfc-internal-format
+msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
+msgstr ""
+
+#: fortran/openmp.cc:11681
+#, gcc-internal-format, gfc-internal-format
+msgid "OMP CRITICAL at %L with HINT clause requires a NAME, except when omp_sync_hint_none is used"
+msgstr ""
+
+#: fortran/openmp.cc:11687
+#, gcc-internal-format
+msgid "Unexpected !$OMP SCAN at %L outside loop construct with %<inscan%> REDUCTION clause"
+msgstr ""
+
+#: fortran/openmp.cc:11708
+#, gcc-internal-format
+msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11732
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11740
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11769
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11791
+#, gcc-internal-format, gfc-internal-format
+msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11807
+#, gcc-internal-format, gfc-internal-format
+msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11822
+#, gcc-internal-format, gfc-internal-format
+msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11832
+#, gcc-internal-format, gfc-internal-format
+msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
+msgstr ""
+
+#: fortran/openmp.cc:11840
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
+msgstr ""
+
+#: fortran/options.cc:290
+#, gcc-internal-format
+msgid "%<-fexcess-precision=standard%> for Fortran"
+msgstr ""
+
+#: fortran/options.cc:292
+#, gcc-internal-format
+msgid "%<-fexcess-precision=16%> for Fortran"
+msgstr ""
+
+#: fortran/options.cc:386
+#, gcc-internal-format
+msgid "Reading file %qs as free form"
+msgstr ""
+
+#: fortran/options.cc:396
+#, gcc-internal-format
+msgid "%<-fd-lines-as-comments%> has no effect in free form"
+msgstr ""
+
+#: fortran/options.cc:399
+#, gcc-internal-format
+msgid "%<-fd-lines-as-code%> has no effect in free form"
+msgstr ""
+
+#: fortran/options.cc:436
+#, gcc-internal-format
+msgid "Flag %<-fno-automatic%> overwrites %<-fmax-stack-var-size=%d%>"
+msgstr ""
+
+#: fortran/options.cc:439
+#, gcc-internal-format
+msgid "Flag %<-fno-automatic%> overwrites %<-frecursive%>"
+msgstr ""
+
+#: fortran/options.cc:442
+#, gcc-internal-format
+msgid "Flag %<-fno-automatic%> overwrites %<-frecursive%> implied by %qs"
+msgstr ""
+
+#: fortran/options.cc:445
+#, gcc-internal-format
+msgid "Flag %<-frecursive%> overwrites %<-fmax-stack-var-size=%d%>"
+msgstr ""
+
+#: fortran/options.cc:448
+#, gcc-internal-format
+msgid "Flag %<-fmax-stack-var-size=%d%> overwrites %<-frecursive%> implied by %qs"
+msgstr ""
+
+#: fortran/options.cc:507
+#, gcc-internal-format
+msgid "Fixed line length must be at least seven"
+msgstr ""
+
+#: fortran/options.cc:510
+#, gcc-internal-format
+msgid "Free line length must be at least three"
+msgstr ""
+
+#: fortran/options.cc:513
+#, gcc-internal-format, gfc-internal-format
+msgid "Maximum subrecord length cannot exceed %d"
+msgstr ""
+
+#: fortran/options.cc:532
+#, gcc-internal-format
+msgid "gfortran: Only one %<-J%> option allowed"
+msgstr ""
+
+#: fortran/options.cc:607
+#, gcc-internal-format
+msgid "Argument to %<-ffpe-trap%> is not valid: %s"
+msgstr ""
+
+#: fortran/options.cc:609
+#, gcc-internal-format
+msgid "Argument to %<-ffpe-summary%> is not valid: %s"
+msgstr ""
+
+#: fortran/options.cc:658
+#, gcc-internal-format
+msgid "Argument to %<-fcheck%> is not valid: %s"
+msgstr ""
+
+#: fortran/options.cc:723
+#, gcc-internal-format, gfc-internal-format
+msgid "Maximum supported identifier length is %d"
+msgstr ""
+
+#: fortran/options.cc:738
+#, gcc-internal-format
+msgid "Unrecognized option to %<-finit-logical%>: %s"
+msgstr ""
+
+#: fortran/options.cc:754
+#, gcc-internal-format
+msgid "The value of n in %<-finit-character=n%> must be between 0 and 127"
+msgstr ""
+
+#: fortran/parse.cc:655
+#, gcc-internal-format, gfc-internal-format
+msgid "Unclassifiable statement at %C"
+msgstr ""
+
+#: fortran/parse.cc:719
+#, gcc-internal-format, gfc-internal-format
+msgid "OpenACC directives other than ROUTINE may not appear in PURE procedures at %C"
+msgstr ""
+
+#: fortran/parse.cc:785
+#, gcc-internal-format, gfc-internal-format
+msgid "Unclassifiable OpenACC directive at %C"
+msgstr ""
+
+#: fortran/parse.cc:817
+#, gcc-internal-format
+msgid "%qs directive at %L must either have a variable argument or, if associated with an ALLOCATE stmt, must be preceded by an executable statement or OpenMP construct"
+msgstr ""
+
+#: fortran/parse.cc:829
+#, gcc-internal-format
+msgid "Structure-component expression at %L in %qs directive not permitted in declarative directive; as directive associated with an ALLOCATE stmt it must be preceded by an executable statement or OpenMP construct"
+msgstr ""
+
+#: fortran/parse.cc:855
+#, gcc-internal-format
+msgid "%qs directive at %L associated with an ALLOCATE stmt must be preceded by an executable statement or OpenMP construct; note the variables in the list all have the allocatable or pointer attribute"
+msgstr ""
+
+#: fortran/parse.cc:1023 fortran/parse.cc:1325
+#, gcc-internal-format, gfc-internal-format
+msgid "OpenMP directive at %C is not pure and thus may not appear in a PURE procedure"
+msgstr ""
+
+#: fortran/parse.cc:1296
+#, gcc-internal-format, gfc-internal-format
+msgid "Unclassifiable OpenMP directive at %C"
+msgstr ""
+
+#: fortran/parse.cc:1312
+#, gcc-internal-format
+msgid "OpenMP ERROR directive at %L with %<at(execution)%> clause in a PURE procedure"
+msgstr ""
+
+#: fortran/parse.cc:1440
+#, gcc-internal-format, gfc-internal-format
+msgid "Unclassifiable GCC directive at %C"
+msgstr ""
+
+#: fortran/parse.cc:1442
+#, gcc-internal-format, gfc-internal-format
+msgid "Unclassifiable GCC directive at %C, ignored"
+msgstr ""
+
+#: fortran/parse.cc:1502 fortran/parse.cc:1729
+#, gcc-internal-format, gfc-internal-format
+msgid "Zero is not a valid statement label at %C"
+msgstr ""
+
+#: fortran/parse.cc:1509 fortran/parse.cc:1721
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-numeric character in statement label at %C"
+msgstr ""
+
+#: fortran/parse.cc:1521 fortran/parse.cc:1770
+#, gcc-internal-format, gfc-internal-format
+msgid "Semicolon at %C needs to be preceded by statement"
+msgstr ""
+
+#: fortran/parse.cc:1528 fortran/parse.cc:1785
+#, gcc-internal-format, gfc-internal-format
+msgid "Statement label without statement at %L"
+msgstr ""
+
+#: fortran/parse.cc:1591 fortran/parse.cc:1772
+#, gcc-internal-format, gfc-internal-format
+msgid "Fortran 2008: Semicolon at %C without preceding statement"
+msgstr ""
+
+#: fortran/parse.cc:1614 fortran/parse.cc:1748
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad continuation line at %C"
+msgstr ""
+
+#: fortran/parse.cc:2060
+#, gcc-internal-format, gfc-internal-format
+msgid "FORMAT statement at %L does not have a statement label"
+msgstr ""
+
+#: fortran/parse.cc:2975
+#, gcc-internal-format
+msgid "gfc_ascii_statement(): Bad statement code"
+msgstr ""
+
+#: fortran/parse.cc:3124
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected %s statement at %C"
+msgstr ""
+
+#: fortran/parse.cc:3281
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement at %C cannot follow %s statement at %L"
+msgstr ""
+
+#: fortran/parse.cc:3298
+#, gcc-internal-format
+msgid "Unexpected end of file in %qs"
+msgstr ""
+
+#: fortran/parse.cc:3333
+#, gcc-internal-format
+msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
+msgstr ""
+
+#: fortran/parse.cc:3336
+#, gcc-internal-format
+msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
+msgstr ""
+
+#: fortran/parse.cc:3356
+#, gcc-internal-format, gfc-internal-format
+msgid "Components in TYPE at %C must precede CONTAINS"
+msgstr ""
+
+#: fortran/parse.cc:3360
+#, gcc-internal-format, gfc-internal-format
+msgid "Type-bound procedure at %C"
+msgstr ""
+
+#: fortran/parse.cc:3368
+#, gcc-internal-format, gfc-internal-format
+msgid "GENERIC binding at %C"
+msgstr ""
+
+#: fortran/parse.cc:3376
+#, gcc-internal-format, gfc-internal-format
+msgid "FINAL procedure declaration at %C"
+msgstr ""
+
+#: fortran/parse.cc:3388
+#, gcc-internal-format, gfc-internal-format
+msgid "Derived type definition at %C with empty CONTAINS section"
+msgstr ""
+
+#: fortran/parse.cc:3398 fortran/parse.cc:3853
+#, gcc-internal-format, gfc-internal-format
+msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
+msgstr ""
+
+#: fortran/parse.cc:3405
+#, gcc-internal-format, gfc-internal-format
+msgid "PRIVATE statement at %C must precede procedure bindings"
+msgstr ""
+
+#: fortran/parse.cc:3412 fortran/parse.cc:3866
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate PRIVATE statement at %C"
+msgstr ""
+
+#: fortran/parse.cc:3422
+#, gcc-internal-format, gfc-internal-format
+msgid "SEQUENCE statement at %C must precede CONTAINS"
+msgstr ""
+
+#: fortran/parse.cc:3426
+#, gcc-internal-format, gfc-internal-format
+msgid "Already inside a CONTAINS block at %C"
+msgstr ""
+
+#: fortran/parse.cc:3545
+#, gcc-internal-format, gfc-internal-format
+msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
+msgstr ""
+
+#: fortran/parse.cc:3551
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
+msgstr ""
+
+#: fortran/parse.cc:3556
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
+msgstr ""
+
+#: fortran/parse.cc:3560
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
+msgstr ""
+
+#: fortran/parse.cc:3565
+#, gcc-internal-format, gfc-internal-format
+msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
+msgstr ""
+
+#: fortran/parse.cc:3572
+#, gcc-internal-format, gfc-internal-format
+msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
+msgstr ""
+
+#: fortran/parse.cc:3582
+#, gcc-internal-format, gfc-internal-format
+msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
+msgstr ""
+
+#: fortran/parse.cc:3588
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
+msgstr ""
+
+#: fortran/parse.cc:3593
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
+msgstr ""
+
+#: fortran/parse.cc:3597
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
+msgstr ""
+
+#: fortran/parse.cc:3602
+#, gcc-internal-format, gfc-internal-format
+msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
+msgstr ""
+
+#: fortran/parse.cc:3609
+#, gcc-internal-format, gfc-internal-format
+msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
+msgstr ""
+
+#: fortran/parse.cc:3661
+#, gcc-internal-format, gfc-internal-format
+msgid "failed to create map component '%s'"
+msgstr ""
+
+#: fortran/parse.cc:3694
+#, gcc-internal-format, gfc-internal-format
+msgid "failed to create union component '%s'"
+msgstr ""
+
+#: fortran/parse.cc:3749
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in nested structure declaration at %C"
+msgstr ""
+
+#: fortran/parse.cc:3836
+#, gcc-internal-format, gfc-internal-format
+msgid "FINAL declaration at %C must be inside CONTAINS"
+msgstr ""
+
+#: fortran/parse.cc:3844
+#, gcc-internal-format, gfc-internal-format
+msgid "Derived type definition at %C without components"
+msgstr ""
+
+#: fortran/parse.cc:3860
+#, gcc-internal-format, gfc-internal-format
+msgid "PRIVATE statement at %C must precede structure components"
+msgstr ""
+
+#: fortran/parse.cc:3877
+#, gcc-internal-format, gfc-internal-format
+msgid "SEQUENCE statement at %C must precede structure components"
+msgstr ""
+
+#: fortran/parse.cc:3883
+#, gcc-internal-format, gfc-internal-format
+msgid "SEQUENCE attribute at %C already specified in TYPE statement"
+msgstr ""
+
+#: fortran/parse.cc:3888
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate SEQUENCE statement at %C"
+msgstr ""
+
+#: fortran/parse.cc:3898
+#, gcc-internal-format, gfc-internal-format
+msgid "CONTAINS block in derived type definition at %C"
+msgstr ""
+
+#: fortran/parse.cc:3956
+#, gcc-internal-format, gfc-internal-format
+msgid "ENUM declaration at %C has no ENUMERATORS"
+msgstr ""
+
+#: fortran/parse.cc:4043
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected %s statement in INTERFACE block at %C"
+msgstr ""
+
+#: fortran/parse.cc:4068
+#, gcc-internal-format
+msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
+msgstr ""
+
+#: fortran/parse.cc:4099
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected %s statement at %C in INTERFACE body"
+msgstr ""
+
+#: fortran/parse.cc:4117
+#, gcc-internal-format
+msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
+msgstr ""
+
+#: fortran/parse.cc:4256
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement is not allowed inside of BLOCK at %C"
+msgstr ""
+
+#: fortran/parse.cc:4288
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement is not allowed inside of BLOCK DATA at %C"
+msgstr ""
+
+#: fortran/parse.cc:4372
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement must appear in a MODULE"
+msgstr ""
+
+#: fortran/parse.cc:4380
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement at %C follows another accessibility specification"
+msgstr ""
+
+#: fortran/parse.cc:4432
+#, gcc-internal-format
+msgid "Bad kind expression for function %qs at %L"
+msgstr ""
+
+#: fortran/parse.cc:4436
+#, gcc-internal-format
+msgid "The type for function %qs at %L is not accessible"
+msgstr ""
+
+#: fortran/parse.cc:4496
+#, gcc-internal-format, gfc-internal-format
+msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
+msgstr ""
+
+#: fortran/parse.cc:4518
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected %s statement in WHERE block at %C"
+msgstr ""
+
+#: fortran/parse.cc:4577
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected %s statement in FORALL block at %C"
+msgstr ""
+
+#: fortran/parse.cc:4628
+#, gcc-internal-format, gfc-internal-format
+msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
+msgstr ""
+
+#: fortran/parse.cc:4646
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate ELSE statements at %L and %C"
+msgstr ""
+
+#: fortran/parse.cc:4707
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
+msgstr ""
+
+#: fortran/parse.cc:4791
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
+msgstr ""
+
+#: fortran/parse.cc:4867
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected RANK or RANK DEFAULT following SELECT RANK at %C"
+msgstr ""
+
+#: fortran/parse.cc:4931
+#, gcc-internal-format
+msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
+msgstr ""
+
+#: fortran/parse.cc:4964
+#, gcc-internal-format, gfc-internal-format
+msgid "End of nonblock DO statement at %C is within another block"
+msgstr ""
+
+#: fortran/parse.cc:4974
+#, gcc-internal-format, gfc-internal-format
+msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
+msgstr ""
+
+#: fortran/parse.cc:5000
+#, gcc-internal-format, gfc-internal-format
+msgid "CRITICAL block inside of OpenACC region at %C"
+msgstr ""
+
+#: fortran/parse.cc:5001
+#, gcc-internal-format, gfc-internal-format
+msgid "CRITICAL block inside of OpenMP region at %C"
+msgstr ""
+
+#: fortran/parse.cc:5027
+#, gcc-internal-format, gfc-internal-format
+msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
+msgstr ""
+
+#: fortran/parse.cc:5096 fortran/parse.cc:5977
+#, gcc-internal-format, gfc-internal-format
+msgid "BLOCK construct at %C"
+msgstr ""
+
+#: fortran/parse.cc:5131
+#, gcc-internal-format, gfc-internal-format
+msgid "ASSOCIATE construct at %C"
+msgstr ""
+
+#: fortran/parse.cc:5410
+#, gcc-internal-format, gfc-internal-format
+msgid "Statement label in ENDDO at %C doesn't match DO label"
+msgstr ""
+
+#: fortran/parse.cc:5426
+#, gcc-internal-format, gfc-internal-format
+msgid "Named block DO at %L requires matching ENDDO name"
+msgstr ""
+
+#: fortran/parse.cc:5583 fortran/parse.cc:6135 fortran/parse.cc:6153
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicated NOWAIT clause on %s and %s at %C"
+msgstr ""
+
+#: fortran/parse.cc:5684 fortran/parse.cc:5746
+#, gcc-internal-format, gfc-internal-format
+msgid "OpenACC directive inside of CRITICAL block at %C"
+msgstr ""
+
+#: fortran/parse.cc:5721
+#, gcc-internal-format, gfc-internal-format
+msgid "Expecting %s at %C"
+msgstr ""
+
+#: fortran/parse.cc:5765
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected DO loop at %C"
+msgstr ""
+
+#: fortran/parse.cc:5785
+#, gcc-internal-format, gfc-internal-format
+msgid "Redundant !$ACC END LOOP at %C"
+msgstr ""
+
+#: fortran/parse.cc:5835
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statements at %L and %L have both no list item but only one may"
+msgstr ""
+
+#: fortran/parse.cc:5855
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected %s at %C; expected ALLOCATE or %s statement"
+msgstr ""
+
+#: fortran/parse.cc:5858
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected %s at %C; expected ALLOCATE statement after %s"
+msgstr ""
+
+#: fortran/parse.cc:6146
+#, gcc-internal-format, gfc-internal-format
+msgid "Name after !$omp critical and !$omp end critical does not match at %C"
+msgstr ""
+
+#: fortran/parse.cc:6221
+#, gcc-internal-format, gfc-internal-format
+msgid "%s statement at %C cannot terminate a non-block DO loop"
+msgstr ""
+
+#: fortran/parse.cc:6235
+#, gcc-internal-format, gfc-internal-format
+msgid "DATA statement at %C after the first executable statement"
+msgstr ""
+
+#: fortran/parse.cc:6391
+#, gcc-internal-format
+msgid "%<GCC unroll%> directive not at the start of a loop at %C"
+msgstr ""
+
+#: fortran/parse.cc:6394
+#, gcc-internal-format
+msgid "%<GCC ivdep%> directive not at the start of a loop at %C"
+msgstr ""
+
+#: fortran/parse.cc:6397
+#, gcc-internal-format
+msgid "%<GCC vector%> directive not at the start of a loop at %C"
+msgstr ""
+
+#: fortran/parse.cc:6400
+#, gcc-internal-format
+msgid "%<GCC novector%> directive not at the start of a loop at %C"
+msgstr ""
+
+#: fortran/parse.cc:6516
+#, gcc-internal-format
+msgid "Contained procedure %qs at %C is already ambiguous"
+msgstr ""
+
+#: fortran/parse.cc:6573
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected %s statement in CONTAINS section at %C"
+msgstr ""
+
+#: fortran/parse.cc:6598
+#, gcc-internal-format, gfc-internal-format
+msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
+msgstr ""
+
+#: fortran/parse.cc:6712
+#, gcc-internal-format, gfc-internal-format
+msgid "CONTAINS statement at %C is already in a contained program unit"
+msgstr ""
+
+#: fortran/parse.cc:6764
+#, gcc-internal-format
+msgid "Global binding name %qs at %L is already being used as a %s at %L"
+msgstr ""
+
+#: fortran/parse.cc:6768
+#, gcc-internal-format
+msgid "Global name %qs at %L is already being used as a %s at %L"
+msgstr ""
+
+#: fortran/parse.cc:6774
+#, gcc-internal-format
+msgid "Global binding name %qs at %L is already being used at %L"
+msgstr ""
+
+#: fortran/parse.cc:6777
+#, gcc-internal-format
+msgid "Global name %qs at %L is already being used at %L"
+msgstr ""
+
+#: fortran/parse.cc:6799
+#, gcc-internal-format, gfc-internal-format
+msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
+msgstr ""
+
+#: fortran/parse.cc:6825
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected %s statement in BLOCK DATA at %C"
+msgstr ""
+
+#: fortran/parse.cc:6928
+#, gcc-internal-format, gfc-internal-format
+msgid "Unexpected %s statement in MODULE at %C"
+msgstr ""
+
+#. If we see a duplicate main program, shut down.  If the second
+#. instance is an implied main program, i.e. data decls or executable
+#. statements, we're in for lots of errors.
+#: fortran/parse.cc:7429
+#, gcc-internal-format, gfc-internal-format
+msgid "Two main PROGRAMs at %L and %C"
+msgstr ""
+
+#: fortran/primary.cc:103
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing kind-parameter at %C"
+msgstr ""
+
+#: fortran/primary.cc:136
+#, gcc-internal-format
+msgid "gfc_check_digit(): bad radix"
+msgstr ""
+
+#: fortran/primary.cc:279
+#, gcc-internal-format, gfc-internal-format
+msgid "Integer kind %d at %C not available"
+msgstr ""
+
+#: fortran/primary.cc:288
+#, gcc-internal-format
+msgid "Integer too big for its kind at %C. This check can be disabled with the option %<-fno-range-check%>"
+msgstr ""
+
+#: fortran/primary.cc:316
+#, gcc-internal-format, gfc-internal-format
+msgid "Hollerith constant at %C"
+msgstr ""
+
+#: fortran/primary.cc:323
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid Hollerith constant: %L must contain at least one character"
+msgstr ""
+
+#: fortran/primary.cc:329
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid Hollerith constant: Integer kind at %L should be default"
+msgstr ""
+
+#: fortran/primary.cc:349
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid Hollerith constant at %L contains a wide character"
+msgstr ""
+
+#: fortran/primary.cc:435
+#, gcc-internal-format, gfc-internal-format
+msgid "Hexadecimal constant at %L uses nonstandard X instead of Z"
+msgstr ""
+
+#: fortran/primary.cc:444
+#, gcc-internal-format, gfc-internal-format
+msgid "Empty set of digits in BOZ constant at %C"
+msgstr ""
+
+#: fortran/primary.cc:450
+#, gcc-internal-format, gfc-internal-format
+msgid "Illegal character in BOZ constant at %C"
+msgstr ""
+
+#: fortran/primary.cc:473
+#, gcc-internal-format, gfc-internal-format
+msgid "BOZ constant at %C uses nonstandard postfix syntax"
+msgstr ""
+
+#: fortran/primary.cc:498
+#, gcc-internal-format, gfc-internal-format
+msgid "BOZ used outside a DATA statement at %L"
+msgstr ""
+
+#: fortran/primary.cc:589
+#, gcc-internal-format
+msgid "exponent-letter %<q%> in real-literal-constant at %C"
+msgstr ""
+
+#: fortran/primary.cc:594
+#, gcc-internal-format
+msgid "Extension: exponent-letter %<q%> in real-literal-constant at %C"
+msgstr ""
+
+#: fortran/primary.cc:615
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing exponent in real number at %C"
+msgstr ""
+
+#: fortran/primary.cc:693
+#, gcc-internal-format
+msgid "Real number at %C has a %<d%> exponent and an explicit kind"
+msgstr ""
+
+#: fortran/primary.cc:703
+#, gcc-internal-format
+msgid "Real number at %C has a %<q%> exponent and an explicit kind"
+msgstr ""
+
+#: fortran/primary.cc:717
+#, gcc-internal-format
+msgid "Invalid exponent-letter %<q%> in real-literal-constant at %C"
+msgstr ""
+
+#: fortran/primary.cc:730
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid real kind %d at %C"
+msgstr ""
+
+#: fortran/primary.cc:745
+#, gcc-internal-format, gfc-internal-format
+msgid "Real constant overflows its kind at %C"
+msgstr ""
+
+#: fortran/primary.cc:750
+#, gcc-internal-format, gfc-internal-format
+msgid "Real constant underflows its kind at %C"
+msgstr ""
+
+#: fortran/primary.cc:755
+#, gcc-internal-format
+msgid "gfc_range_check() returned bad value"
+msgstr ""
+
+#: fortran/primary.cc:803
+#, gcc-internal-format
+msgid "Non-significant digits in %qs number at %C, maybe incorrect KIND"
+msgstr ""
+
+#: fortran/primary.cc:895
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in SUBSTRING specification at %C"
+msgstr ""
+
+#: fortran/primary.cc:1095
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid kind %d for CHARACTER constant at %C"
+msgstr ""
+
+#: fortran/primary.cc:1116
+#, gcc-internal-format, gfc-internal-format
+msgid "Unterminated character constant beginning at %C"
+msgstr ""
+
+#: fortran/primary.cc:1146
+#, gcc-internal-format
+msgid "Character %qs in string at %C is not representable in character kind %d"
+msgstr ""
+
+#: fortran/primary.cc:1159
+#, gcc-internal-format
+msgid "match_string_constant(): Delimiter not found"
+msgstr ""
+
+#: fortran/primary.cc:1193
+msgid "Substring start index (%td) at %L below 1"
+msgstr ""
+
+#: fortran/primary.cc:1199
+msgid "Substring end index (%td) at %L exceeds string length"
+msgstr ""
+
+#: fortran/primary.cc:1284
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad kind for logical constant at %C"
+msgstr ""
+
+#: fortran/primary.cc:1328
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected PARAMETER symbol in complex constant at %C"
+msgstr ""
+
+#: fortran/primary.cc:1339
+#, gcc-internal-format, gfc-internal-format
+msgid "Numeric PARAMETER required in complex constant at %C"
+msgstr ""
+
+#: fortran/primary.cc:1345
+#, gcc-internal-format, gfc-internal-format
+msgid "Scalar PARAMETER required in complex constant at %C"
+msgstr ""
+
+#: fortran/primary.cc:1349
+#, gcc-internal-format, gfc-internal-format
+msgid "PARAMETER symbol in complex constant at %C"
+msgstr ""
+
+#: fortran/primary.cc:1372
+#, gcc-internal-format
+msgid "gfc_match_sym_complex_part(): Bad type"
+msgstr ""
+
+#: fortran/primary.cc:1379
+#, gcc-internal-format, gfc-internal-format
+msgid "Error converting PARAMETER constant in complex constant at %C"
+msgstr ""
+
+#: fortran/primary.cc:1511
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in COMPLEX constant at %C"
+msgstr ""
+
+#: fortran/primary.cc:1638
+#, gcc-internal-format
+msgid "Namelist %qs cannot be an argument at %L"
+msgstr ""
+
+#: fortran/primary.cc:1740
+#, gcc-internal-format
+msgid "Keyword %qs at %C has already appeared in the current argument list"
+msgstr ""
+
+#: fortran/primary.cc:1807
+#, gcc-internal-format, gfc-internal-format
+msgid "argument list function at %C"
+msgstr ""
+
+#: fortran/primary.cc:1881
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected alternate return label at %C"
+msgstr ""
+
+#: fortran/primary.cc:1928
+#, gcc-internal-format, gfc-internal-format
+msgid "Missing keyword name in actual argument list at %C"
+msgstr ""
+
+#: fortran/primary.cc:1974
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in argument list at %C"
+msgstr ""
+
+#: fortran/primary.cc:1995
+#, gcc-internal-format
+msgid "extend_ref(): Bad tail"
+msgstr ""
+
+#: fortran/primary.cc:2097
+#, gcc-internal-format
+msgid "Array section designator, e.g. %<(:)%>, is required besides the coarray designator %<[...]%> at %C"
+msgstr ""
+
+#: fortran/primary.cc:2105
+#, gcc-internal-format
+msgid "Coarray designator at %C but %qs is not a coarray"
+msgstr ""
+
+#: fortran/primary.cc:2338
+#, gcc-internal-format
+msgid "Symbol %qs at %C has no IMPLICIT type"
+msgstr ""
+
+#: fortran/primary.cc:2345
+#, gcc-internal-format
+msgid "Unexpected %<%c%> for nonderived-type variable %qs at %C"
+msgstr ""
+
+#: fortran/primary.cc:2366
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected structure component name at %C"
+msgstr ""
+
+#: fortran/primary.cc:2387 fortran/primary.cc:2562
+#, gcc-internal-format, gfc-internal-format
+msgid "RE or IM part_ref at %C"
+msgstr ""
+
+#: fortran/primary.cc:2439 fortran/primary.cc:2567
+#, gcc-internal-format, gfc-internal-format
+msgid "The RE or IM part_ref at %C must be applied to a COMPLEX expression"
+msgstr ""
+
+#: fortran/primary.cc:2446 fortran/primary.cc:2580
+#, gcc-internal-format, gfc-internal-format
+msgid "The LEN part_ref at %C must be applied to a CHARACTER expression"
+msgstr ""
+
+#: fortran/primary.cc:2505
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected argument list at %C"
+msgstr ""
+
+#: fortran/primary.cc:2523
+#, gcc-internal-format
+msgid "%qs at %C is not an inquiry reference to an intrinsic type component %qs"
+msgstr ""
+
+#: fortran/primary.cc:2526
+#, gcc-internal-format
+msgid "%qs at %C is not an inquiry reference to an intrinsic type component"
+msgstr ""
+
+#: fortran/primary.cc:2596
+#, gcc-internal-format, gfc-internal-format
+msgid "The KIND part_ref at %C must be applied to an expression of intrinsic type"
+msgstr ""
+
+#: fortran/primary.cc:2624
+#, gcc-internal-format
+msgid "Procedure pointer component %qs requires an argument list at %C"
+msgstr ""
+
+#: fortran/primary.cc:2727
+#, gcc-internal-format, gfc-internal-format
+msgid "Nonpolymorphic reference to abstract type at %C"
+msgstr ""
+
+#: fortran/primary.cc:2734
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindexed procedure-pointer component at %C"
+msgstr ""
+
+#: fortran/primary.cc:2772
+#, gcc-internal-format
+msgid "gfc_variable_attr(): Expression isn't a variable"
+msgstr ""
+
+#: fortran/primary.cc:2990
+#, gcc-internal-format
+msgid "gfc_caf_attr(): Expression isn't a variable"
+msgstr ""
+
+#: fortran/primary.cc:3047
+#, gcc-internal-format
+msgid "gfc_caf_attr(): Bad array reference"
+msgstr ""
+
+#: fortran/primary.cc:3226
+#, gcc-internal-format
+msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
+msgstr ""
+
+#: fortran/primary.cc:3237
+#, gcc-internal-format, gfc-internal-format
+msgid "Structure constructor with missing optional arguments at %C"
+msgstr ""
+
+#: fortran/primary.cc:3246
+#, gcc-internal-format
+msgid "No initializer for component %qs given in the structure constructor at %C"
+msgstr ""
+
+#: fortran/primary.cc:3294
+#, gcc-internal-format
+msgid "Cannot construct ABSTRACT type %qs at %L"
+msgstr ""
+
+#: fortran/primary.cc:3314
+#, gcc-internal-format, gfc-internal-format
+msgid "Structure constructor with named arguments at %C"
+msgstr ""
+
+#: fortran/primary.cc:3329
+#, gcc-internal-format, gfc-internal-format
+msgid "Component initializer without name after component named %s at %L"
+msgstr ""
+
+#: fortran/primary.cc:3334
+#, gcc-internal-format, gfc-internal-format
+msgid "Too many components in structure constructor at %L"
+msgstr ""
+
+#: fortran/primary.cc:3393
+msgid "CHARACTER expression will be truncated in constructor (%td/%td) at %L"
+msgstr ""
+
+#: fortran/primary.cc:3411
+#, gcc-internal-format
+msgid "Component %qs is initialized twice in the structure constructor at %L"
+msgstr ""
+
+#: fortran/primary.cc:3423
+#, gcc-internal-format
+msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
+msgstr ""
+
+#: fortran/primary.cc:3477
+#, gcc-internal-format
+msgid "component %qs at %L has already been set by a parent derived type constructor"
+msgstr ""
+
+#: fortran/primary.cc:3642
+#, gcc-internal-format, gfc-internal-format
+msgid "%%LOC() as an rvalue at %C"
+msgstr ""
+
+#: fortran/primary.cc:3701
+#, gcc-internal-format
+msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
+msgstr ""
+
+#: fortran/primary.cc:3732 fortran/primary.cc:4134
+#, gcc-internal-format, gfc-internal-format
+msgid "Symbol at %C is not appropriate for an expression"
+msgstr ""
+
+#: fortran/primary.cc:3837
+#, gcc-internal-format
+msgid "Unexpected use of subroutine name %qs at %C"
+msgstr ""
+
+#: fortran/primary.cc:3869
+#, gcc-internal-format
+msgid "Statement function %qs requires argument list at %C"
+msgstr ""
+
+#: fortran/primary.cc:3872
+#, gcc-internal-format
+msgid "Function %qs requires an argument list at %C"
+msgstr ""
+
+#: fortran/primary.cc:3922
+#, gcc-internal-format
+msgid "Missing argument to %qs at %C"
+msgstr ""
+
+#: fortran/primary.cc:3935
+#, gcc-internal-format, gfc-internal-format
+msgid "The leftmost part-ref in a data-ref cannot be a function reference at %C"
+msgstr ""
+
+#: fortran/primary.cc:4090
+#, gcc-internal-format
+msgid "Missing argument list in function %qs at %C"
+msgstr ""
+
+#: fortran/primary.cc:4204
+#, gcc-internal-format
+msgid "Derived type %qs cannot be used as a variable at %C"
+msgstr ""
+
+#: fortran/primary.cc:4245
+#, gcc-internal-format, gfc-internal-format
+msgid "Named constant at %C in an EQUIVALENCE"
+msgstr ""
+
+#: fortran/primary.cc:4250
+#, gcc-internal-format
+msgid "PARAMETER %qs shall not appear in a DATA statement at %C"
+msgstr ""
+
+#: fortran/primary.cc:4286
+#, gcc-internal-format
+msgid "%qs at %C is not a variable"
+msgstr ""
+
+#: fortran/resolve.cc:114
+#, gcc-internal-format
+msgid "%qs at %L is of the ABSTRACT type %qs"
+msgstr ""
+
+#: fortran/resolve.cc:117
+#, gcc-internal-format
+msgid "ABSTRACT type %qs used at %L"
+msgstr ""
+
+#: fortran/resolve.cc:134
+#, gcc-internal-format
+msgid "Interface %qs at %L is declared in a later PROCEDURE statement"
+msgstr ""
+
+#: fortran/resolve.cc:147
+#, gcc-internal-format
+msgid "Interface %qs at %L may not be generic"
+msgstr ""
+
+#: fortran/resolve.cc:154
+#, gcc-internal-format
+msgid "Interface %qs at %L may not be a statement function"
+msgstr ""
+
+#: fortran/resolve.cc:163
+#, gcc-internal-format
+msgid "Intrinsic procedure %qs not allowed in PROCEDURE statement at %L"
+msgstr ""
+
+#: fortran/resolve.cc:169
+#, gcc-internal-format
+msgid "Interface %qs at %L must be explicit"
+msgstr ""
+
+#: fortran/resolve.cc:191
+#, gcc-internal-format
+msgid "PROCEDURE %qs at %L may not be used as its own interface"
+msgstr ""
+
+#: fortran/resolve.cc:292
+#, gcc-internal-format
+msgid "Alternate return specifier in elemental subroutine %qs at %L is not allowed"
+msgstr ""
+
+#: fortran/resolve.cc:296
+#, gcc-internal-format
+msgid "Alternate return specifier in function %qs at %L is not allowed"
+msgstr ""
+
+#: fortran/resolve.cc:308
+#, gcc-internal-format
+msgid "Self-referential argument %qs at %L is not allowed"
+msgstr ""
+
+#: fortran/resolve.cc:380
+#, gcc-internal-format
+msgid "Dummy procedure %qs of PURE procedure at %L must also be PURE"
+msgstr ""
+
+#: fortran/resolve.cc:390
+#, gcc-internal-format
+msgid "Argument %qs of pure function %qs at %L with VALUE attribute but without INTENT(IN)"
+msgstr ""
+
+#: fortran/resolve.cc:395
+#, gcc-internal-format
+msgid "Argument %qs of pure function %qs at %L must be INTENT(IN) or VALUE"
+msgstr ""
+
+#: fortran/resolve.cc:403
+#, gcc-internal-format
+msgid "Argument %qs of pure subroutine %qs at %L with VALUE attribute but without INTENT"
+msgstr ""
+
+#: fortran/resolve.cc:408
+#, gcc-internal-format
+msgid "Argument %qs of pure subroutine %qs at %L must have its INTENT specified or have the VALUE attribute"
+msgstr ""
+
+#: fortran/resolve.cc:418
+#, gcc-internal-format
+msgid "INTENT(OUT) argument %qs of pure procedure %qs at %L may not be polymorphic"
+msgstr ""
+
+#: fortran/resolve.cc:451
+#, gcc-internal-format
+msgid "Coarray dummy argument %qs at %L to elemental procedure"
+msgstr ""
+
+#: fortran/resolve.cc:459
+#, gcc-internal-format
+msgid "Argument %qs of elemental procedure at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.cc:468
+#, gcc-internal-format
+msgid "Argument %qs of elemental procedure at %L cannot have the ALLOCATABLE attribute"
+msgstr ""
+
+#: fortran/resolve.cc:478
+#, gcc-internal-format
+msgid "Argument %qs of elemental procedure at %L cannot have the POINTER attribute"
+msgstr ""
+
+#: fortran/resolve.cc:486
+#, gcc-internal-format
+msgid "Dummy procedure %qs not allowed in elemental procedure %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:495
+#, gcc-internal-format
+msgid "Argument %qs of elemental procedure %qs at %L must have its INTENT specified or have the VALUE attribute"
+msgstr ""
+
+#. F03:C1263 (R1238) The function-name and each dummy-arg-name
+#. shall be specified, explicitly or implicitly, to be scalar.
+#: fortran/resolve.cc:510
+#, gcc-internal-format
+msgid "Argument %qs of statement function %qs at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.cc:521
+#, gcc-internal-format
+msgid "Character-valued argument %qs of statement function at %L must have constant length"
+msgstr ""
+
+#: fortran/resolve.cc:571
+#, gcc-internal-format
+msgid "Contained procedure %qs at %L has the same name as its encompassing procedure"
+msgstr ""
+
+#: fortran/resolve.cc:591
+#, gcc-internal-format
+msgid "Contained function %qs at %L has no IMPLICIT type"
+msgstr ""
+
+#: fortran/resolve.cc:594
+#, gcc-internal-format
+msgid "Result %qs of contained function %qs at %L has no IMPLICIT type"
+msgstr ""
+
+#: fortran/resolve.cc:620
+#, gcc-internal-format
+msgid "Character-valued module procedure %qs at %L must not be assumed length"
+msgstr ""
+
+#: fortran/resolve.cc:622
+#, gcc-internal-format
+msgid "Character-valued internal function %qs at %L must not be assumed length"
+msgstr ""
+
+#: fortran/resolve.cc:795
+#, gcc-internal-format, gfc-internal-format
+msgid "Function %s at %L has entries with mismatched array specifications"
+msgstr ""
+
+#: fortran/resolve.cc:806
+#, gcc-internal-format, gfc-internal-format
+msgid "Function %s at %L has entry %s with mismatched characteristics"
+msgstr ""
+
+#: fortran/resolve.cc:821
+#, gcc-internal-format, gfc-internal-format
+msgid "Function %s at %L with entries returning variables of different string lengths"
+msgstr ""
+
+#: fortran/resolve.cc:853
+#, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s cannot be an array in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:857
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s cannot be an array in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:864
+#, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s cannot be a POINTER in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:868
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s cannot be a POINTER in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:875
+#, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:879
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s cannot be ALLOCATABLE in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:917
+#, gcc-internal-format, gfc-internal-format
+msgid "FUNCTION result %s cannot be of type %s in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:922
+#, gcc-internal-format, gfc-internal-format
+msgid "ENTRY result %s cannot be of type %s in FUNCTION %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:973
+#, gcc-internal-format
+msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
+msgstr ""
+
+#: fortran/resolve.cc:977
+#, gcc-internal-format
+msgid "Global entity %qs at %L cannot appear in a COMMON block"
+msgstr ""
+
+#: fortran/resolve.cc:987
+#, gcc-internal-format, gfc-internal-format
+msgid "COMMON block at %L"
+msgstr ""
+
+#: fortran/resolve.cc:994
+#, gcc-internal-format
+msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
+msgstr ""
+
+#: fortran/resolve.cc:998
+#, gcc-internal-format
+msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
+msgstr ""
+
+#: fortran/resolve.cc:1005
+#, gcc-internal-format
+msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
+msgstr ""
+
+#: fortran/resolve.cc:1010
+#, gcc-internal-format
+msgid "Automatic object %qs at %L cannot appear in COMMON at %L"
+msgstr ""
+
+#: fortran/resolve.cc:1022
+#, gcc-internal-format
+msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
+msgstr ""
+
+#: fortran/resolve.cc:1026
+#, gcc-internal-format
+msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
+msgstr ""
+
+#: fortran/resolve.cc:1030
+#, gcc-internal-format
+msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
+msgstr ""
+
+#: fortran/resolve.cc:1074
+#, gcc-internal-format
+msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
+msgstr ""
+
+#: fortran/resolve.cc:1088
+#, gcc-internal-format
+msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
+msgstr ""
+
+#: fortran/resolve.cc:1096
+#, gcc-internal-format
+msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
+msgstr ""
+
+#: fortran/resolve.cc:1118
+#, gcc-internal-format
+msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
+msgstr ""
+
+#: fortran/resolve.cc:1139
+#, gcc-internal-format
+msgid "COMMON block %qs at %L is used as PARAMETER at %L"
+msgstr ""
+
+#: fortran/resolve.cc:1143
+#, gcc-internal-format
+msgid "COMMON block %qs at %L cannot have the EXTERNAL attribute"
+msgstr ""
+
+#: fortran/resolve.cc:1147
+#, gcc-internal-format
+msgid "COMMON block %qs at %L is also an intrinsic procedure"
+msgstr ""
+
+#: fortran/resolve.cc:1151
+#, gcc-internal-format
+msgid "COMMON block %qs at %L that is also a function result"
+msgstr ""
+
+#: fortran/resolve.cc:1156
+#, gcc-internal-format
+msgid "COMMON block %qs at %L that is also a global procedure"
+msgstr ""
+
+#: fortran/resolve.cc:1223
+#, gcc-internal-format
+msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
+msgstr ""
+
+#: fortran/resolve.cc:1366
+#, gcc-internal-format, gfc-internal-format
+msgid "The rank of the element in the structure constructor at %L does not match that of the component (%d/%d)"
+msgstr ""
+
+#: fortran/resolve.cc:1387
+#, gcc-internal-format
+msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
+msgstr ""
+
+#: fortran/resolve.cc:1422
+#, gcc-internal-format
+msgid "Unequal character lengths (%wd/%wd) for pointer component %qs in constructor at %L"
+msgstr ""
+
+#: fortran/resolve.cc:1467
+#, gcc-internal-format
+msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
+msgstr ""
+
+#: fortran/resolve.cc:1501
+#, gcc-internal-format
+msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
+msgstr ""
+
+#: fortran/resolve.cc:1520
+#, gcc-internal-format
+msgid "Bad array spec of component %qs referenced in structure constructor at %L"
+msgstr ""
+
+#: fortran/resolve.cc:1533
+#, gcc-internal-format
+msgid "The shape of component %qs in the structure constructor at %L differs from the shape of the declared component for dimension %d (%ld/%ld)"
+msgstr ""
+
+#: fortran/resolve.cc:1554
+#, gcc-internal-format
+msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
+msgstr ""
+
+#: fortran/resolve.cc:1583
+#, gcc-internal-format
+msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
+msgstr ""
+
+#: fortran/resolve.cc:1709
+#, gcc-internal-format
+msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:1771
+#, gcc-internal-format
+msgid "%qs at %L is ambiguous"
+msgstr ""
+
+#: fortran/resolve.cc:1775
+#, gcc-internal-format
+msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
+msgstr ""
+
+#: fortran/resolve.cc:1896
+#, gcc-internal-format
+msgid "Type specified for intrinsic function %qs at %L is ignored"
+msgstr ""
+
+#: fortran/resolve.cc:1909
+#, gcc-internal-format
+msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
+msgstr ""
+
+#: fortran/resolve.cc:1920
+#, gcc-internal-format
+msgid "%qs declared INTRINSIC at %L does not exist"
+msgstr ""
+
+#: fortran/resolve.cc:1933
+#, gcc-internal-format
+msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
+msgstr ""
+
+#: fortran/resolve.cc:1971
+#, gcc-internal-format
+msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
+msgstr ""
+
+#: fortran/resolve.cc:1976 fortran/resolve.cc:6852
+#, gcc-internal-format
+msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
+msgstr ""
+
+#: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
+#, gcc-internal-format, gfc-internal-format
+msgid "Label %d referenced at %L is never defined"
+msgstr ""
+
+#: fortran/resolve.cc:2067
+#, gcc-internal-format
+msgid "Derived type %qs is used as an actual argument at %L"
+msgstr ""
+
+#: fortran/resolve.cc:2085
+#, gcc-internal-format
+msgid "Statement function %qs at %L is not allowed as an actual argument"
+msgstr ""
+
+#: fortran/resolve.cc:2093
+#, gcc-internal-format
+msgid "Intrinsic %qs at %L is not allowed as an actual argument"
+msgstr ""
+
+#: fortran/resolve.cc:2100
+#, gcc-internal-format
+msgid "Internal procedure %qs is used as actual argument at %L"
+msgstr ""
+
+#: fortran/resolve.cc:2108
+#, gcc-internal-format
+msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
+msgstr ""
+
+#: fortran/resolve.cc:2135
+#, gcc-internal-format
+msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:2157
+#, gcc-internal-format
+msgid "Symbol %qs at %L is ambiguous"
+msgstr ""
+
+#: fortran/resolve.cc:2220
+#, gcc-internal-format, gfc-internal-format
+msgid "By-value argument at %L is not of numeric type"
+msgstr ""
+
+#: fortran/resolve.cc:2227
+#, gcc-internal-format, gfc-internal-format
+msgid "By-value argument at %L cannot be an array or an array section"
+msgstr ""
+
+#: fortran/resolve.cc:2241
+#, gcc-internal-format, gfc-internal-format
+msgid "By-value argument at %L is not allowed in this context"
+msgstr ""
+
+#: fortran/resolve.cc:2253
+#, gcc-internal-format, gfc-internal-format
+msgid "Passing internal procedure at %L by location not allowed"
+msgstr ""
+
+#: fortran/resolve.cc:2264
+#, gcc-internal-format
+msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
+msgstr ""
+
+#: fortran/resolve.cc:2273
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindexed actual argument at %L with ultimate pointer component"
+msgstr ""
+
+#: fortran/resolve.cc:2420
+#, gcc-internal-format
+msgid "%qs at %L is an array and OPTIONAL; If it is not present, then it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (Fortran 2018, 15.5.2.12)"
+msgstr ""
+
+#: fortran/resolve.cc:2459
+#, gcc-internal-format
+msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
+msgstr ""
+
+#: fortran/resolve.cc:2733
+#, gcc-internal-format
+msgid "Return type mismatch of function %qs at %L (%s/%s)"
+msgstr ""
+
+#: fortran/resolve.cc:2760
+#, gcc-internal-format
+msgid "Interface mismatch in global procedure %qs at %L: %s"
+msgstr ""
+
+#: fortran/resolve.cc:2866
+#, gcc-internal-format
+msgid "There is no specific function for the generic %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:2886
+#, gcc-internal-format
+msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
+msgstr ""
+
+#: fortran/resolve.cc:2924
+#, gcc-internal-format
+msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
+msgstr ""
+
+#: fortran/resolve.cc:2979
+#, gcc-internal-format
+msgid "Unable to resolve the specific function %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:3056
+#, gcc-internal-format
+msgid "Missing explicit declaration with EXTERNAL attribute for symbol %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:3088
+#, gcc-internal-format
+msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
+msgstr ""
+
+#: fortran/resolve.cc:3092 fortran/resolve.cc:18167
+#, gcc-internal-format
+msgid "Function %qs at %L has no IMPLICIT type"
+msgstr ""
+
+#: fortran/resolve.cc:3216
+#, gcc-internal-format
+msgid "Reference to impure function %qs at %L inside a FORALL %s"
+msgstr ""
+
+#: fortran/resolve.cc:3223
+#, gcc-internal-format
+msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
+msgstr ""
+
+#: fortran/resolve.cc:3230
+#, gcc-internal-format
+msgid "Reference to impure function %qs at %L within a PURE procedure"
+msgstr ""
+
+#: fortran/resolve.cc:3297
+#, gcc-internal-format
+msgid "Unexpected junk after %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:3308
+#, gcc-internal-format
+msgid "%qs at %L is not a function"
+msgstr ""
+
+#: fortran/resolve.cc:3316 fortran/resolve.cc:3831
+#, gcc-internal-format
+msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
+msgstr ""
+
+#: fortran/resolve.cc:3328
+#, gcc-internal-format
+msgid "ABSTRACT INTERFACE %qs at %L must not have an assumed character length result (F2008: C418)"
+msgstr ""
+
+#. Internal procedures are taken care of in resolve_contained_fntype.
+#: fortran/resolve.cc:3371
+#, gcc-internal-format
+msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
+msgstr ""
+
+#: fortran/resolve.cc:3405
+#, gcc-internal-format
+msgid "resolve_function(): bad function type"
+msgstr ""
+
+#: fortran/resolve.cc:3419
+#, gcc-internal-format, gfc-internal-format
+msgid "A BOZ literal constant at %L cannot appear as an actual argument in a function reference"
+msgstr ""
+
+#: fortran/resolve.cc:3435
+#, gcc-internal-format
+msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
+msgstr ""
+
+#: fortran/resolve.cc:3497
+#, gcc-internal-format
+msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
+msgstr ""
+
+#: fortran/resolve.cc:3501
+#, gcc-internal-format
+msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
+msgstr ""
+
+#: fortran/resolve.cc:3559
+#, gcc-internal-format
+msgid "Using function %qs at %L is deprecated"
+msgstr ""
+
+#: fortran/resolve.cc:3575
+#, gcc-internal-format
+msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
+msgstr ""
+
+#: fortran/resolve.cc:3581
+#, gcc-internal-format
+msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
+msgstr ""
+
+#: fortran/resolve.cc:3587
+#, gcc-internal-format
+msgid "Subroutine call to %qs at %L is not PURE"
+msgstr ""
+
+#: fortran/resolve.cc:3655
+#, gcc-internal-format
+msgid "There is no specific subroutine for the generic %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:3664
+#, gcc-internal-format
+msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
+msgstr ""
+
+#: fortran/resolve.cc:3699
+#, gcc-internal-format
+msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
+msgstr ""
+
+#: fortran/resolve.cc:3744
+#, gcc-internal-format
+msgid "Unable to resolve the specific subroutine %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:3802
+#, gcc-internal-format
+msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
+msgstr ""
+
+#: fortran/resolve.cc:3841
+#, gcc-internal-format
+msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
+msgstr ""
+
+#: fortran/resolve.cc:3845
+#, gcc-internal-format
+msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
+msgstr ""
+
+#: fortran/resolve.cc:3890
+#, gcc-internal-format
+msgid "resolve_subroutine(): bad function type"
+msgstr ""
+
+#: fortran/resolve.cc:3907
+#, gcc-internal-format
+msgid "Using subroutine %qs at %L is deprecated"
+msgstr ""
+
+#: fortran/resolve.cc:3934
+#, gcc-internal-format, gfc-internal-format
+msgid "Shapes for operands at %L and %L are not conformable"
+msgstr ""
+
+#: fortran/resolve.cc:3986
+#, gcc-internal-format
+msgid "logical_to_bitwise(): Bad intrinsic"
+msgstr ""
+
+#: fortran/resolve.cc:4089
+#, gcc-internal-format
+msgid "Impure function %qs at %L might not be evaluated"
+msgstr ""
+
+#: fortran/resolve.cc:4093
+#, gcc-internal-format, gfc-internal-format
+msgid "Impure function at %L might not be evaluated"
+msgstr ""
+
+#: fortran/resolve.cc:4180
+#, gcc-internal-format
+msgid "BOZ literal constant at %L cannot be an operand of unary operator %qs"
+msgstr ""
+
+#: fortran/resolve.cc:4204
+#, gcc-internal-format
+msgid "Operands at %L and %L cannot appear as operands of binary operator %qs"
+msgstr ""
+
+#: fortran/resolve.cc:4389 fortran/resolve.cc:4404
+#, gcc-internal-format, gfc-internal-format
+msgid "BOZ literal constant near %L cannot appear as an operand of a relational operator"
+msgstr ""
+
+#: fortran/resolve.cc:4454
+#, gcc-internal-format, gfc-internal-format
+msgid "Equality comparison for %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:4456
+#, gcc-internal-format, gfc-internal-format
+msgid "Inequality comparison for %s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:4516
+#, gcc-internal-format
+msgid "resolve_operator(): Bad intrinsic"
+msgstr ""
+
+#: fortran/resolve.cc:4802
+#, gcc-internal-format, gfc-internal-format
+msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
+msgstr ""
+
+#: fortran/resolve.cc:4807
+#, gcc-internal-format, gfc-internal-format
+msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
+msgstr ""
+
+#: fortran/resolve.cc:4817
+#, gcc-internal-format, gfc-internal-format
+msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
+msgstr ""
+
+#: fortran/resolve.cc:4822
+#, gcc-internal-format, gfc-internal-format
+msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
+msgstr ""
+
+#: fortran/resolve.cc:4843
+#, gcc-internal-format, gfc-internal-format
+msgid "Illegal stride of zero at %L"
+msgstr ""
+
+#: fortran/resolve.cc:4860
+#, gcc-internal-format, gfc-internal-format
+msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
+msgstr ""
+
+#: fortran/resolve.cc:4868
+#, gcc-internal-format, gfc-internal-format
+msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
+msgstr ""
+
+#: fortran/resolve.cc:4884
+#, gcc-internal-format, gfc-internal-format
+msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
+msgstr ""
+
+#: fortran/resolve.cc:4893
+#, gcc-internal-format, gfc-internal-format
+msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
+msgstr ""
+
+#: fortran/resolve.cc:4909
+#, gcc-internal-format
+msgid "check_dimension(): Bad array reference"
+msgstr ""
+
+#: fortran/resolve.cc:4932
+#, gcc-internal-format, gfc-internal-format
+msgid "Rightmost upper bound of assumed size array section not specified at %L"
+msgstr ""
+
+#: fortran/resolve.cc:4942
+#, gcc-internal-format, gfc-internal-format
+msgid "Rank mismatch in array reference at %L (%d/%d)"
+msgstr ""
+
+#: fortran/resolve.cc:4950
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
+msgstr ""
+
+#: fortran/resolve.cc:4966
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindex of codimension %d must be a scalar at %L"
+msgstr ""
+
+#: fortran/resolve.cc:4994
+#, gcc-internal-format, gfc-internal-format
+msgid "Array index at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.cc:5000
+#, gcc-internal-format, gfc-internal-format
+msgid "Array index at %L must be of INTEGER type, found %s"
+msgstr ""
+
+#: fortran/resolve.cc:5006
+#, gcc-internal-format, gfc-internal-format
+msgid "REAL array index at %L"
+msgstr ""
+
+#: fortran/resolve.cc:5046
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument dim at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.cc:5053
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument dim at %L must be of INTEGER type"
+msgstr ""
+
+#: fortran/resolve.cc:5113
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid array reference of a non-array entity at %L"
+msgstr ""
+
+#: fortran/resolve.cc:5127
+#, gcc-internal-format
+msgid "find_array_spec(): unused as(1)"
+msgstr ""
+
+#: fortran/resolve.cc:5139
+#, gcc-internal-format
+msgid "find_array_spec(): unused as(2)"
+msgstr ""
+
+#: fortran/resolve.cc:5184
+#, gcc-internal-format, gfc-internal-format
+msgid "Array index at %L is an array of rank %d"
+msgstr ""
+
+#: fortran/resolve.cc:5282
+#, gcc-internal-format, gfc-internal-format
+msgid "Substring start index at %L must be of type INTEGER"
+msgstr ""
+
+#: fortran/resolve.cc:5289
+#, gcc-internal-format, gfc-internal-format
+msgid "Substring start index at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.cc:5311
+#, gcc-internal-format, gfc-internal-format
+msgid "Substring end index at %L must be of type INTEGER"
+msgstr ""
+
+#: fortran/resolve.cc:5318
+#, gcc-internal-format, gfc-internal-format
+msgid "Substring end index at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.cc:5338
+#, gcc-internal-format, gfc-internal-format
+msgid "Substring end index at %L is too large"
+msgstr ""
+
+#: fortran/resolve.cc:5529
+#, gcc-internal-format
+msgid "resolve_ref(): Bad array reference"
+msgstr ""
+
+#: fortran/resolve.cc:5543
+#, gcc-internal-format, gfc-internal-format
+msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
+msgstr ""
+
+#: fortran/resolve.cc:5553
+#, gcc-internal-format, gfc-internal-format
+msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
+msgstr ""
+
+#: fortran/resolve.cc:5601
+#, gcc-internal-format, gfc-internal-format
+msgid "Two or more part references with nonzero rank must not be specified at %L"
+msgstr ""
+
+#: fortran/resolve.cc:5693
+#, gcc-internal-format
+msgid "gfc_expression_rank(): Two array specs"
+msgstr ""
+
+#: fortran/resolve.cc:5790
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
+msgstr ""
+
+#: fortran/resolve.cc:5800
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-type variable %s at %L may only be used as actual argument"
+msgstr ""
+
+#. FIXME: It doesn't work reliably as inquiry_argument is not set
+#. for all inquiry functions in resolve_function; the reason is
+#. that the function-name resolution happens too late in that
+#. function.
+#: fortran/resolve.cc:5810
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
+msgstr ""
+
+#: fortran/resolve.cc:5829
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-rank variable %s at %L may only be used as actual argument"
+msgstr ""
+
+#. FIXME: It doesn't work reliably as inquiry_argument is not set
+#. for all inquiry functions in resolve_function; the reason is
+#. that the function-name resolution happens too late in that
+#. function.
+#: fortran/resolve.cc:5839
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
+msgstr ""
+
+#: fortran/resolve.cc:5850
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
+msgstr ""
+
+#: fortran/resolve.cc:5859
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-type variable %s at %L shall not have a subobject reference"
+msgstr ""
+
+#: fortran/resolve.cc:5875
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
+msgstr ""
+
+#: fortran/resolve.cc:5935
+#, gcc-internal-format
+msgid "Scalar variable %qs has an array reference at %L"
+msgstr ""
+
+#: fortran/resolve.cc:6080
+#, gcc-internal-format
+msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
+msgstr ""
+
+#: fortran/resolve.cc:6085
+#, gcc-internal-format
+msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
+msgstr ""
+
+#: fortran/resolve.cc:6155
+#, gcc-internal-format, gfc-internal-format
+msgid "Polymorphic subobject of coindexed object at %L"
+msgstr ""
+
+#: fortran/resolve.cc:6168
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
+msgstr ""
+
+#: fortran/resolve.cc:6184
+#, gcc-internal-format
+msgid "Using variable %qs at %L is deprecated"
+msgstr ""
+
+#: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid array reference at %L"
+msgstr ""
+
+#: fortran/resolve.cc:6433
+#, gcc-internal-format
+msgid "%qs at %L is host associated at %L into a contained procedure with an internal procedure of the same name"
+msgstr ""
+
+#: fortran/resolve.cc:6611 fortran/resolve.cc:6763
+#, gcc-internal-format, gfc-internal-format
+msgid "Error in typebound call at %L"
+msgstr ""
+
+#: fortran/resolve.cc:6727
+#, gcc-internal-format, gfc-internal-format
+msgid "Passed-object at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.cc:6734
+#, gcc-internal-format
+msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
+msgstr ""
+
+#: fortran/resolve.cc:6773
+#, gcc-internal-format
+msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
+msgstr ""
+
+#: fortran/resolve.cc:6782
+#, gcc-internal-format, gfc-internal-format
+msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
+msgstr ""
+
+#. Nothing matching found!
+#: fortran/resolve.cc:6977
+#, gcc-internal-format
+msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:7011
+#, gcc-internal-format
+msgid "%qs at %L should be a SUBROUTINE"
+msgstr ""
+
+#: fortran/resolve.cc:7063
+#, gcc-internal-format
+msgid "%qs at %L should be a FUNCTION"
+msgstr ""
+
+#: fortran/resolve.cc:7598
+#, gcc-internal-format
+msgid "gfc_resolve_expr(): Bad expression type"
+msgstr ""
+
+#: fortran/resolve.cc:7631
+#, gcc-internal-format, gfc-internal-format
+msgid "%s at %L must be a scalar"
+msgstr ""
+
+#: fortran/resolve.cc:7641
+#, gcc-internal-format, gfc-internal-format
+msgid "%s at %L must be integer"
+msgstr ""
+
+#: fortran/resolve.cc:7645 fortran/resolve.cc:7652
+#, gcc-internal-format, gfc-internal-format
+msgid "%s at %L must be INTEGER"
+msgstr ""
+
+#: fortran/resolve.cc:7707
+#, gcc-internal-format, gfc-internal-format
+msgid "Step expression in DO loop at %L cannot be zero"
+msgstr ""
+
+#: fortran/resolve.cc:7730
+#, gcc-internal-format, gfc-internal-format
+msgid "DO loop at %L will be executed zero times"
+msgstr ""
+
+#: fortran/resolve.cc:7747
+#, gcc-internal-format, gfc-internal-format
+msgid "DO loop at %L is undefined as it overflows"
+msgstr ""
+
+#: fortran/resolve.cc:7753
+#, gcc-internal-format, gfc-internal-format
+msgid "DO loop at %L is undefined as it underflows"
+msgstr ""
+
+#: fortran/resolve.cc:7814
+#, gcc-internal-format, gfc-internal-format
+msgid "FORALL index-name at %L must be a scalar INTEGER"
+msgstr ""
+
+#: fortran/resolve.cc:7819
+#, gcc-internal-format, gfc-internal-format
+msgid "FORALL start expression at %L must be a scalar INTEGER"
+msgstr ""
+
+#: fortran/resolve.cc:7826
+#, gcc-internal-format, gfc-internal-format
+msgid "FORALL end expression at %L must be a scalar INTEGER"
+msgstr ""
+
+#: fortran/resolve.cc:7834
+#, gcc-internal-format, gfc-internal-format
+msgid "FORALL stride expression at %L must be a scalar %s"
+msgstr ""
+
+#: fortran/resolve.cc:7839
+#, gcc-internal-format, gfc-internal-format
+msgid "FORALL stride expression at %L cannot be zero"
+msgstr ""
+
+#: fortran/resolve.cc:7852
+#, gcc-internal-format
+msgid "FORALL index %qs may not appear in triplet specification at %L"
+msgstr ""
+
+#: fortran/resolve.cc:7957 fortran/resolve.cc:8255
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
+msgstr ""
+
+#: fortran/resolve.cc:7965 fortran/resolve.cc:8218
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindexed allocatable object at %L"
+msgstr ""
+
+#: fortran/resolve.cc:8075
+#, gcc-internal-format, gfc-internal-format
+msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
+msgstr ""
+
+#: fortran/resolve.cc:8106
+#, gcc-internal-format, gfc-internal-format
+msgid "Source-expr at %L and allocate-object at %L must have the same shape"
+msgstr ""
+
+#: fortran/resolve.cc:8266
+#, gcc-internal-format, gfc-internal-format
+msgid "Type of entity at %L is type incompatible with source-expr at %L"
+msgstr ""
+
+#: fortran/resolve.cc:8278
+#, gcc-internal-format, gfc-internal-format
+msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
+msgstr ""
+
+#: fortran/resolve.cc:8292
+#, gcc-internal-format, gfc-internal-format
+msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
+msgstr ""
+
+#: fortran/resolve.cc:8317
+#, gcc-internal-format, gfc-internal-format
+msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
+msgstr ""
+
+#: fortran/resolve.cc:8330
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
+msgstr ""
+
+#: fortran/resolve.cc:8348
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
+msgstr ""
+
+#: fortran/resolve.cc:8432 fortran/resolve.cc:8447
+#, gcc-internal-format, gfc-internal-format
+msgid "Array specification required in ALLOCATE statement at %L"
+msgstr ""
+
+#: fortran/resolve.cc:8439
+#, gcc-internal-format, gfc-internal-format
+msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
+msgstr ""
+
+#: fortran/resolve.cc:8464
+#, gcc-internal-format, gfc-internal-format
+msgid "Coarray specification required in ALLOCATE statement at %L"
+msgstr ""
+
+#: fortran/resolve.cc:8474 fortran/resolve.cc:8576
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad coarray specification in ALLOCATE statement at %L"
+msgstr ""
+
+#: fortran/resolve.cc:8480
+#, gcc-internal-format, gfc-internal-format
+msgid "Upper cobound is less than lower cobound at %L"
+msgstr ""
+
+#: fortran/resolve.cc:8492
+#, gcc-internal-format, gfc-internal-format
+msgid "Upper cobound is less than lower cobound of 1 at %L"
+msgstr ""
+
+#: fortran/resolve.cc:8503 fortran/resolve.cc:8531
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad array specification in ALLOCATE statement at %L"
+msgstr ""
+
+#: fortran/resolve.cc:8550
+#, gcc-internal-format
+msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
+msgstr ""
+
+#: fortran/resolve.cc:8565
+#, gcc-internal-format
+msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
+msgstr ""
+
+#: fortran/resolve.cc:8607
+#, gcc-internal-format, gfc-internal-format
+msgid "Stat-variable at %L must be a scalar INTEGER variable"
+msgstr ""
+
+#: fortran/resolve.cc:8636
+#, gcc-internal-format, gfc-internal-format
+msgid "Stat-variable at %L shall not be %sd within the same %s statement"
+msgstr ""
+
+#: fortran/resolve.cc:8649
+#, gcc-internal-format, gfc-internal-format
+msgid "ERRMSG at %L is useless without a STAT tag"
+msgstr ""
+
+#: fortran/resolve.cc:8663
+#, gcc-internal-format, gfc-internal-format
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
+msgstr ""
+
+#: fortran/resolve.cc:8692
+#, gcc-internal-format, gfc-internal-format
+msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
+msgstr ""
+
+#: fortran/resolve.cc:8724
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocate-object at %L also appears at %L"
+msgstr ""
+
+#: fortran/resolve.cc:8730 fortran/resolve.cc:8736
+#, gcc-internal-format, gfc-internal-format
+msgid "Allocate-object at %L is subobject of object at %L"
+msgstr ""
+
+#. The cases overlap, or they are the same
+#. element in the list.  Either way, we must
+#. issue an error and get the next case from P.
+#. FIXME: Sort P and Q by line number.
+#: fortran/resolve.cc:8964
+#, gcc-internal-format, gfc-internal-format
+msgid "CASE label at %L overlaps with CASE label at %L"
+msgstr ""
+
+#: fortran/resolve.cc:9015
+#, gcc-internal-format, gfc-internal-format
+msgid "Expression in CASE statement at %L must be of type %s"
+msgstr ""
+
+#: fortran/resolve.cc:9026
+#, gcc-internal-format, gfc-internal-format
+msgid "Expression in CASE statement at %L must be of kind %d"
+msgstr ""
+
+#: fortran/resolve.cc:9039
+#, gcc-internal-format, gfc-internal-format
+msgid "Expression in CASE statement at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.cc:9085
+#, gcc-internal-format, gfc-internal-format
+msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
+msgstr ""
+
+#: fortran/resolve.cc:9104
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of SELECT statement at %L cannot be %s"
+msgstr ""
+
+#: fortran/resolve.cc:9114
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of SELECT statement at %L must be a scalar expression"
+msgstr ""
+
+#: fortran/resolve.cc:9132 fortran/resolve.cc:9140
+#, gcc-internal-format, gfc-internal-format
+msgid "Expression in CASE statement at %L is not in the range of %s"
+msgstr ""
+
+#: fortran/resolve.cc:9202 fortran/resolve.cc:9966
+#, gcc-internal-format, gfc-internal-format
+msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
+msgstr ""
+
+#: fortran/resolve.cc:9228
+#, gcc-internal-format, gfc-internal-format
+msgid "Logical range in CASE statement at %L is not allowed"
+msgstr ""
+
+#: fortran/resolve.cc:9241
+#, gcc-internal-format, gfc-internal-format
+msgid "Constant logical value in CASE statement is repeated at %L"
+msgstr ""
+
+#: fortran/resolve.cc:9256
+#, gcc-internal-format, gfc-internal-format
+msgid "Range specification at %L can never be matched"
+msgstr ""
+
+#: fortran/resolve.cc:9359
+#, gcc-internal-format, gfc-internal-format
+msgid "Logical SELECT CASE block at %L has more that two cases"
+msgstr ""
+
+#: fortran/resolve.cc:9421
+#, gcc-internal-format
+msgid "Associating entity %qs at %L is a procedure pointer"
+msgstr ""
+
+#: fortran/resolve.cc:9430
+#, gcc-internal-format
+msgid "Derived type %qs cannot be used as a variable at %L"
+msgstr ""
+
+#: fortran/resolve.cc:9447
+#, gcc-internal-format
+msgid "Associating entity %qs at %L is a procedure name"
+msgstr ""
+
+#: fortran/resolve.cc:9463
+#, gcc-internal-format, gfc-internal-format
+msgid "Associating selector-expression at %L yields a procedure"
+msgstr ""
+
+#: fortran/resolve.cc:9517
+#, gcc-internal-format, gfc-internal-format
+msgid "Selector at %L cannot be NULL()"
+msgstr ""
+
+#: fortran/resolve.cc:9522
+#, gcc-internal-format, gfc-internal-format
+msgid "Selector at %L has no type"
+msgstr ""
+
+#: fortran/resolve.cc:9580
+#, gcc-internal-format
+msgid "Associate-name %qs at %L is used as array"
+msgstr ""
+
+#: fortran/resolve.cc:9591
+#, gcc-internal-format, gfc-internal-format
+msgid "CLASS selector at %L needs a temporary which is not yet implemented"
+msgstr ""
+
+#: fortran/resolve.cc:9830
+#, gcc-internal-format, gfc-internal-format
+msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
+msgstr ""
+
+#: fortran/resolve.cc:9874 fortran/resolve.cc:9886
+#, gcc-internal-format, gfc-internal-format
+msgid "Selector at %L must not be coindexed"
+msgstr ""
+
+#: fortran/resolve.cc:9915
+#, gcc-internal-format, gfc-internal-format
+msgid "TYPE IS at %L overlaps with TYPE IS at %L"
+msgstr ""
+
+#: fortran/resolve.cc:9928
+#, gcc-internal-format
+msgid "Derived type %qs at %L must be extensible"
+msgstr ""
+
+#: fortran/resolve.cc:9941
+#, gcc-internal-format
+msgid "Derived type %qs at %L must be an extension of %qs"
+msgstr ""
+
+#: fortran/resolve.cc:9944
+#, gcc-internal-format
+msgid "Unexpected intrinsic type %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:9954
+#, gcc-internal-format, gfc-internal-format
+msgid "The type-spec at %L shall specify that each length type parameter is assumed"
+msgstr ""
+
+#: fortran/resolve.cc:10201
+#, gcc-internal-format, gfc-internal-format
+msgid "Double CLASS IS block in SELECT TYPE statement at %L"
+msgstr ""
+
+#: fortran/resolve.cc:10334
+#, gcc-internal-format, gfc-internal-format
+msgid "RANK DEFAULT at %L is repeated at %L"
+msgstr ""
+
+#: fortran/resolve.cc:10343
+#, gcc-internal-format, gfc-internal-format
+msgid "RANK (*) at %L is repeated at %L"
+msgstr ""
+
+#: fortran/resolve.cc:10346
+#, gcc-internal-format, gfc-internal-format
+msgid "RANK (%i) at %L is repeated at %L"
+msgstr ""
+
+#: fortran/resolve.cc:10356
+#, gcc-internal-format, gfc-internal-format
+msgid "RANK (*) at %L cannot be used with the pointer or allocatable selector at %L"
+msgstr ""
+
+#: fortran/resolve.cc:10465
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid context for NULL () intrinsic at %L"
+msgstr ""
+
+#: fortran/resolve.cc:10519
+#, gcc-internal-format, gfc-internal-format
+msgid "DTIO %s procedure at %L must be recursive"
+msgstr ""
+
+#: fortran/resolve.cc:10529
+#, gcc-internal-format, gfc-internal-format
+msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
+msgstr ""
+
+#: fortran/resolve.cc:10542
+#, gcc-internal-format, gfc-internal-format
+msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
+msgstr ""
+
+#: fortran/resolve.cc:10551
+#, gcc-internal-format, gfc-internal-format
+msgid "Data transfer element at %L cannot have procedure pointer components"
+msgstr ""
+
+#: fortran/resolve.cc:10558
+#, gcc-internal-format, gfc-internal-format
+msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
+msgstr ""
+
+#: fortran/resolve.cc:10569
+#, gcc-internal-format, gfc-internal-format
+msgid "Data transfer element at %L cannot have PRIVATE components"
+msgstr ""
+
+#: fortran/resolve.cc:10575
+#, gcc-internal-format, gfc-internal-format
+msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
+msgstr ""
+
+#: fortran/resolve.cc:10593
+#, gcc-internal-format, gfc-internal-format
+msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
+msgstr ""
+
+#: fortran/resolve.cc:10650
+#, gcc-internal-format, gfc-internal-format
+msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
+msgstr ""
+
+#: fortran/resolve.cc:10660
+#, gcc-internal-format, gfc-internal-format
+msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
+msgstr ""
+
+#: fortran/resolve.cc:10664
+#, gcc-internal-format, gfc-internal-format
+msgid "Event variable argument at %L must be a coarray or coindexed"
+msgstr ""
+
+#: fortran/resolve.cc:10667
+#, gcc-internal-format, gfc-internal-format
+msgid "Event variable argument at %L must be a coarray but not coindexed"
+msgstr ""
+
+#: fortran/resolve.cc:10674 fortran/resolve.cc:10796
+#, gcc-internal-format, gfc-internal-format
+msgid "STAT= argument at %L must be a scalar INTEGER variable"
+msgstr ""
+
+#: fortran/resolve.cc:10686 fortran/resolve.cc:10808
+#, gcc-internal-format, gfc-internal-format
+msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
+msgstr ""
+
+#: fortran/resolve.cc:10698
+#, gcc-internal-format, gfc-internal-format
+msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
+msgstr ""
+
+#: fortran/resolve.cc:10711
+#, gcc-internal-format, gfc-internal-format
+msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
+msgstr ""
+
+#: fortran/resolve.cc:10772
+#, gcc-internal-format, gfc-internal-format
+msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
+msgstr ""
+
+#: fortran/resolve.cc:10776 fortran/resolve.cc:10786
+#, gcc-internal-format, gfc-internal-format
+msgid "Imageset argument at %L must between 1 and num_images()"
+msgstr ""
+
+#: fortran/resolve.cc:10839
+#, gcc-internal-format, gfc-internal-format
+msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
+msgstr ""
+
+#: fortran/resolve.cc:10849
+#, gcc-internal-format, gfc-internal-format
+msgid "Branch at %L may result in an infinite loop"
+msgstr ""
+
+#. Note: A label at END CRITICAL does not leave the CRITICAL
+#. construct as END CRITICAL is still part of it.
+#: fortran/resolve.cc:10866 fortran/resolve.cc:10889
+#, gcc-internal-format, gfc-internal-format
+msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
+msgstr ""
+
+#: fortran/resolve.cc:10870 fortran/resolve.cc:10895
+#, gcc-internal-format, gfc-internal-format
+msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
+msgstr ""
+
+#. The label is not in an enclosing block, so illegal.  This was
+#. allowed in Fortran 66, so we allow it as extension.  No
+#. further checks are necessary in this case.
+#: fortran/resolve.cc:10910
+#, gcc-internal-format, gfc-internal-format
+msgid "Label at %L is not in the same block as the GOTO statement at %L"
+msgstr ""
+
+#: fortran/resolve.cc:10982
+#, gcc-internal-format, gfc-internal-format
+msgid "WHERE mask at %L has inconsistent shape"
+msgstr ""
+
+#: fortran/resolve.cc:10998
+#, gcc-internal-format, gfc-internal-format
+msgid "WHERE assignment target at %L has inconsistent shape"
+msgstr ""
+
+#: fortran/resolve.cc:11011 fortran/resolve.cc:11103
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
+msgstr ""
+
+#: fortran/resolve.cc:11021 fortran/resolve.cc:11113
+#, gcc-internal-format, gfc-internal-format
+msgid "Unsupported statement inside WHERE at %L"
+msgstr ""
+
+#: fortran/resolve.cc:11052
+#, gcc-internal-format, gfc-internal-format
+msgid "Assignment to a FORALL index variable at %L"
+msgstr ""
+
+#: fortran/resolve.cc:11061
+#, gcc-internal-format
+msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
+msgstr ""
+
+#: fortran/resolve.cc:11218
+#, gcc-internal-format, gfc-internal-format
+msgid "FORALL construct at %L"
+msgstr ""
+
+#: fortran/resolve.cc:11239
+#, gcc-internal-format, gfc-internal-format
+msgid "FORALL index-name at %L must be a scalar variable of type integer"
+msgstr ""
+
+#: fortran/resolve.cc:11249
+#, gcc-internal-format, gfc-internal-format
+msgid "An outer FORALL construct already has an index with this name %L"
+msgstr ""
+
+#: fortran/resolve.cc:11326
+#, gcc-internal-format, gfc-internal-format
+msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
+msgstr ""
+
+#: fortran/resolve.cc:11444
+#, gcc-internal-format
+msgid "gfc_resolve_blocks(): Bad block type"
+msgstr ""
+
+#: fortran/resolve.cc:11507
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
+msgstr ""
+
+#: fortran/resolve.cc:11568
+#, gcc-internal-format
+msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
+msgstr ""
+
+#: fortran/resolve.cc:11600
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
+msgstr ""
+
+#. F2008, C1283 (4).
+#: fortran/resolve.cc:11606
+#, gcc-internal-format, gfc-internal-format
+msgid "In a pure subprogram an INTENT(IN) dummy argument shall not be used as the expr at %L of an intrinsic assignment statement in which the variable is of a derived type if the derived type has a pointer component at any level of component selection."
+msgstr ""
+
+#: fortran/resolve.cc:11618
+#, gcc-internal-format, gfc-internal-format
+msgid "Assignment to coindexed variable at %L in a PURE procedure"
+msgstr ""
+
+#: fortran/resolve.cc:11650
+#, gcc-internal-format, gfc-internal-format
+msgid "Assignment to polymorphic coarray at %L is not permitted"
+msgstr ""
+
+#: fortran/resolve.cc:11654
+#, gcc-internal-format, gfc-internal-format
+msgid "Assignment to an allocatable polymorphic variable at %L"
+msgstr ""
+
+#: fortran/resolve.cc:11659
+#, gcc-internal-format
+msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
+msgstr ""
+
+#: fortran/resolve.cc:11666
+#, gcc-internal-format
+msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for %<=%> operator"
+msgstr ""
+
+#: fortran/resolve.cc:11677
+#, gcc-internal-format, gfc-internal-format
+msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
+msgstr ""
+
+#: fortran/resolve.cc:12100
+#, gcc-internal-format, gfc-internal-format
+msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
+msgstr ""
+
+#. Even if standard does not support this feature, continue to build
+#. the two statements to avoid upsetting frontend_passes.c.
+#: fortran/resolve.cc:12404
+#, gcc-internal-format, gfc-internal-format
+msgid "Pointer procedure assignment at %L"
+msgstr ""
+
+#: fortran/resolve.cc:12416
+#, gcc-internal-format, gfc-internal-format
+msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
+msgstr ""
+
+#: fortran/resolve.cc:12501
+#, gcc-internal-format
+msgid "TEAM argument to %qs at %L must be a scalar expression of type TEAM_TYPE"
+msgstr ""
+
+#: fortran/resolve.cc:12692
+#, gcc-internal-format, gfc-internal-format
+msgid "TEAM NUMBER argument to FORM TEAM at %L must be a scalar INTEGER"
+msgstr ""
+
+#: fortran/resolve.cc:12728
+#, gcc-internal-format, gfc-internal-format
+msgid "ASSIGNED GOTO statement at %L requires a scalar INTEGER variable"
+msgstr ""
+
+#: fortran/resolve.cc:12732
+#, gcc-internal-format
+msgid "Variable %qs has not been assigned a target label at %L"
+msgstr ""
+
+#: fortran/resolve.cc:12743
+#, gcc-internal-format, gfc-internal-format
+msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
+msgstr ""
+
+#: fortran/resolve.cc:12781
+#, gcc-internal-format, gfc-internal-format
+msgid "Expected intrinsic assignment in OMP WORKSHARE at %L"
+msgstr ""
+
+#: fortran/resolve.cc:12823
+#, gcc-internal-format, gfc-internal-format
+msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
+msgstr ""
+
+#: fortran/resolve.cc:12870
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid NULL at %L"
+msgstr ""
+
+#: fortran/resolve.cc:12874
+#, gcc-internal-format, gfc-internal-format
+msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
+msgstr ""
+
+#: fortran/resolve.cc:12935
+#, gcc-internal-format
+msgid "gfc_resolve_code(): No expression on DO WHILE"
+msgstr ""
+
+#: fortran/resolve.cc:12940
+#, gcc-internal-format, gfc-internal-format
+msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
+msgstr ""
+
+#: fortran/resolve.cc:13024
+#, gcc-internal-format, gfc-internal-format
+msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
+msgstr ""
+
+#: fortran/resolve.cc:13128
+#, gcc-internal-format
+msgid "gfc_resolve_code(): Bad statement code"
+msgstr ""
+
+#: fortran/resolve.cc:13149
+#, gcc-internal-format
+msgid "Using parameter %qs declared at %L is deprecated"
+msgstr ""
+
+#: fortran/resolve.cc:13243
+#, gcc-internal-format
+msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
+msgstr ""
+
+#. This can only happen if the variable is defined in a module - if it
+#. isn't the same module, reject it.
+#: fortran/resolve.cc:13257
+#, gcc-internal-format
+msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
+msgstr ""
+
+#. Print an error if the procedure is defined multiple times; we have to
+#. exclude references to the same procedure via module association or
+#. multiple checks for the same procedure.
+#: fortran/resolve.cc:13276
+#, gcc-internal-format
+msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
+msgstr ""
+
+#: fortran/resolve.cc:13362
+#, gcc-internal-format, gfc-internal-format
+msgid "String length at %L is too large"
+msgstr ""
+
+#: fortran/resolve.cc:13600
+#, gcc-internal-format
+msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
+msgstr ""
+
+#: fortran/resolve.cc:13604
+#, gcc-internal-format
+msgid "Scalar object %qs at %L may not be ALLOCATABLE"
+msgstr ""
+
+#: fortran/resolve.cc:13612
+#, gcc-internal-format
+msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
+msgstr ""
+
+#: fortran/resolve.cc:13623
+#, gcc-internal-format
+msgid "Array %qs at %L cannot have a deferred shape"
+msgstr ""
+
+#: fortran/resolve.cc:13641
+#, gcc-internal-format
+msgid "Type %qs of CLASS variable %qs at %L is not extensible"
+msgstr ""
+
+#: fortran/resolve.cc:13653
+#, gcc-internal-format
+msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
+msgstr ""
+
+#: fortran/resolve.cc:13686
+#, gcc-internal-format
+msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
+msgstr ""
+
+#: fortran/resolve.cc:13708
+#, gcc-internal-format
+msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
+msgstr ""
+
+#: fortran/resolve.cc:13741
+#, gcc-internal-format
+msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
+msgstr ""
+
+#. F08:C541. The shape of an array defined in a main program or module
+#. * needs to be constant.
+#: fortran/resolve.cc:13777
+#, gcc-internal-format
+msgid "The module or main program array %qs at %L must have constant shape"
+msgstr ""
+
+#: fortran/resolve.cc:13802
+#, gcc-internal-format, gfc-internal-format
+msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
+msgstr ""
+
+#: fortran/resolve.cc:13823
+#, gcc-internal-format
+msgid "%qs at %L must have constant character length in this context"
+msgstr ""
+
+#: fortran/resolve.cc:13830
+#, gcc-internal-format
+msgid "COMMON variable %qs at %L must have constant character length"
+msgstr ""
+
+#: fortran/resolve.cc:13878
+#, gcc-internal-format
+msgid "Allocatable %qs at %L cannot have an initializer"
+msgstr ""
+
+#: fortran/resolve.cc:13881
+#, gcc-internal-format
+msgid "External %qs at %L cannot have an initializer"
+msgstr ""
+
+#: fortran/resolve.cc:13884
+#, gcc-internal-format
+msgid "Dummy %qs at %L cannot have an initializer"
+msgstr ""
+
+#: fortran/resolve.cc:13887
+#, gcc-internal-format
+msgid "Intrinsic %qs at %L cannot have an initializer"
+msgstr ""
+
+#: fortran/resolve.cc:13890
+#, gcc-internal-format
+msgid "Function result %qs at %L cannot have an initializer"
+msgstr ""
+
+#: fortran/resolve.cc:13893
+#, gcc-internal-format
+msgid "Automatic array %qs at %L cannot have an initializer"
+msgstr ""
+
+#: fortran/resolve.cc:13935
+#, gcc-internal-format, gfc-internal-format
+msgid "%s at %L"
+msgstr ""
+
+#: fortran/resolve.cc:13967
+#, gcc-internal-format
+msgid "Character-valued statement function %qs at %L must have constant length"
+msgstr ""
+
+#: fortran/resolve.cc:13990
+#, gcc-internal-format
+msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
+msgstr ""
+
+#: fortran/resolve.cc:14012
+#, gcc-internal-format
+msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
+msgstr ""
+
+#: fortran/resolve.cc:14030
+#, gcc-internal-format
+msgid "Function %qs at %L cannot have an initializer"
+msgstr ""
+
+#: fortran/resolve.cc:14042
+#, gcc-internal-format
+msgid "External object %qs at %L may not have an initializer"
+msgstr ""
+
+#: fortran/resolve.cc:14052
+#, gcc-internal-format
+msgid "ELEMENTAL function %qs at %L must have a scalar result"
+msgstr ""
+
+#: fortran/resolve.cc:14062
+#, gcc-internal-format
+msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
+msgstr ""
+
+#: fortran/resolve.cc:14081
+#, gcc-internal-format
+msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
+msgstr ""
+
+#: fortran/resolve.cc:14085
+#, gcc-internal-format
+msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
+msgstr ""
+
+#: fortran/resolve.cc:14089
+#, gcc-internal-format
+msgid "CHARACTER(*) function %qs at %L cannot be pure"
+msgstr ""
+
+#: fortran/resolve.cc:14093
+#, gcc-internal-format
+msgid "CHARACTER(*) function %qs at %L cannot be recursive"
+msgstr ""
+
+#: fortran/resolve.cc:14106
+#, gcc-internal-format
+msgid "CHARACTER(*) function %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:14117
+#, gcc-internal-format
+msgid "Procedure pointer %qs at %L shall not be elemental"
+msgstr ""
+
+#: fortran/resolve.cc:14123
+#, gcc-internal-format
+msgid "Dummy procedure %qs at %L shall not be elemental"
+msgstr ""
+
+#: fortran/resolve.cc:14143
+#, gcc-internal-format
+msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
+msgstr ""
+
+#: fortran/resolve.cc:14200
+#, gcc-internal-format
+msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:14206
+#, gcc-internal-format
+msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:14212
+#, gcc-internal-format
+msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:14220
+#, gcc-internal-format
+msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:14226
+#, gcc-internal-format
+msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
+msgstr ""
+
+#: fortran/resolve.cc:14269
+#, gcc-internal-format, gfc-internal-format
+msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
+msgstr ""
+
+#: fortran/resolve.cc:14277
+#, gcc-internal-format, gfc-internal-format
+msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
+msgstr ""
+
+#: fortran/resolve.cc:14285
+#, gcc-internal-format, gfc-internal-format
+msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
+msgstr ""
+
+#: fortran/resolve.cc:14294
+#, gcc-internal-format
+msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
+msgstr ""
+
+#: fortran/resolve.cc:14318
+#, gcc-internal-format
+msgid "Interface of %qs at %L must be explicit"
+msgstr ""
+
+#: fortran/resolve.cc:14388
+#, gcc-internal-format
+msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
+msgstr ""
+
+#: fortran/resolve.cc:14397
+#, gcc-internal-format, gfc-internal-format
+msgid "FINAL procedure at %L must have exactly one argument"
+msgstr ""
+
+#: fortran/resolve.cc:14405 fortran/resolve.cc:14422
+#, gcc-internal-format
+msgid "Argument of FINAL procedure at %L must be of type %qs"
+msgstr ""
+
+#: fortran/resolve.cc:14413
+#, gcc-internal-format, gfc-internal-format
+msgid "FINAL procedure at %L with assumed rank argument must be the only finalizer with the same kind/type (F2018: C790)"
+msgstr ""
+
+#: fortran/resolve.cc:14430
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of FINAL procedure at %L must not be a POINTER"
+msgstr ""
+
+#: fortran/resolve.cc:14436
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
+msgstr ""
+
+#: fortran/resolve.cc:14442
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
+msgstr ""
+
+#: fortran/resolve.cc:14450
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
+msgstr ""
+
+#: fortran/resolve.cc:14459
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
+msgstr ""
+
+#: fortran/resolve.cc:14481
+#, gcc-internal-format
+msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
+msgstr ""
+
+#: fortran/resolve.cc:14518
+#, gcc-internal-format
+msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one unless an assumed rank finalizer has been declared"
+msgstr ""
+
+#: fortran/resolve.cc:14559
+#, gcc-internal-format
+msgid "%qs and %qs cannot be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:14595
+#, gcc-internal-format
+msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
+msgstr ""
+
+#: fortran/resolve.cc:14654
+#, gcc-internal-format
+msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:14666
+#, gcc-internal-format
+msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
+msgstr ""
+
+#: fortran/resolve.cc:14694
+#, gcc-internal-format
+msgid "GENERIC %qs at %L cannot overwrite specific binding with the same name"
+msgstr ""
+
+#: fortran/resolve.cc:14750
+#, gcc-internal-format, gfc-internal-format
+msgid "Type-bound operator at %L cannot be NOPASS"
+msgstr ""
+
+#: fortran/resolve.cc:14962
+#, gcc-internal-format
+msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
+msgstr ""
+
+#: fortran/resolve.cc:15005
+#, gcc-internal-format
+msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
+msgstr ""
+
+#: fortran/resolve.cc:15019
+#, gcc-internal-format
+msgid "Procedure %qs with PASS at %L must have at least one argument"
+msgstr ""
+
+#: fortran/resolve.cc:15033 fortran/resolve.cc:15575
+#, gcc-internal-format
+msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:15042
+#, gcc-internal-format
+msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
+msgstr ""
+
+#: fortran/resolve.cc:15052
+#, gcc-internal-format
+msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
+msgstr ""
+
+#: fortran/resolve.cc:15094
+#, gcc-internal-format
+msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
+msgstr ""
+
+#: fortran/resolve.cc:15104
+#, gcc-internal-format
+msgid "Passed-object dummy argument of %qs at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.cc:15110
+#, gcc-internal-format
+msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
+msgstr ""
+
+#: fortran/resolve.cc:15116
+#, gcc-internal-format
+msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
+msgstr ""
+
+#: fortran/resolve.cc:15145
+#, gcc-internal-format
+msgid "Procedure %qs at %L has the same name as a component of %qs"
+msgstr ""
+
+#: fortran/resolve.cc:15155
+#, gcc-internal-format
+msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
+msgstr ""
+
+#: fortran/resolve.cc:15250
+#, gcc-internal-format
+msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
+msgstr ""
+
+#: fortran/resolve.cc:15355
+#, gcc-internal-format
+msgid "Coarray component %qs at %L must be allocatable with deferred shape"
+msgstr ""
+
+#: fortran/resolve.cc:15364
+#, gcc-internal-format
+msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
+msgstr ""
+
+#: fortran/resolve.cc:15374
+#, gcc-internal-format
+msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
+msgstr ""
+
+#: fortran/resolve.cc:15399
+#, gcc-internal-format
+msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
+msgstr ""
+
+#: fortran/resolve.cc:15410
+#, gcc-internal-format
+msgid "Component %qs of BIND(C) type at %L must have length one"
+msgstr ""
+
+#: fortran/resolve.cc:15508
+#, gcc-internal-format
+msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
+msgstr ""
+
+#: fortran/resolve.cc:15522
+#, gcc-internal-format
+msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
+msgstr ""
+
+#: fortran/resolve.cc:15538
+#, gcc-internal-format
+msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
+msgstr ""
+
+#: fortran/resolve.cc:15548
+#, gcc-internal-format
+msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
+msgstr ""
+
+#: fortran/resolve.cc:15557
+#, gcc-internal-format
+msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
+msgstr ""
+
+#: fortran/resolve.cc:15566
+#, gcc-internal-format
+msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
+msgstr ""
+
+#: fortran/resolve.cc:15608
+#, gcc-internal-format
+msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
+msgstr ""
+
+#: fortran/resolve.cc:15621
+#, gcc-internal-format
+msgid "Character length of component %qs needs to be a constant specification expression at %L"
+msgstr ""
+
+#: fortran/resolve.cc:15632
+#, gcc-internal-format
+msgid "Character length expression of component %qs at %L must be of INTEGER type, found %s"
+msgstr ""
+
+#: fortran/resolve.cc:15645
+#, gcc-internal-format
+msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
+msgstr ""
+
+#: fortran/resolve.cc:15678
+#, gcc-internal-format
+msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
+msgstr ""
+
+#: fortran/resolve.cc:15686
+#, gcc-internal-format, gfc-internal-format
+msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
+msgstr ""
+
+#: fortran/resolve.cc:15695
+#, gcc-internal-format, gfc-internal-format
+msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
+msgstr ""
+
+#: fortran/resolve.cc:15781
+#, gcc-internal-format, gfc-internal-format
+msgid "Conflicting initializers in union at %L and %L"
+msgstr ""
+
+#: fortran/resolve.cc:15826
+#, gcc-internal-format
+msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
+msgstr ""
+
+#: fortran/resolve.cc:15839
+#, gcc-internal-format
+msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
+msgstr ""
+
+#: fortran/resolve.cc:15903
+#, gcc-internal-format
+msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:15936
+#, gcc-internal-format
+msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
+msgstr ""
+
+#: fortran/resolve.cc:15950
+#, gcc-internal-format
+msgid "Derived type %qs at %L has not been declared"
+msgstr ""
+
+#: fortran/resolve.cc:16018
+#, gcc-internal-format
+msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
+msgstr ""
+
+#: fortran/resolve.cc:16024
+#, gcc-internal-format
+msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:16030
+#, gcc-internal-format
+msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:16038
+#, gcc-internal-format
+msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:16055
+#, gcc-internal-format
+msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:16077
+#, gcc-internal-format
+msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:16088
+#, gcc-internal-format
+msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:16115
+#, gcc-internal-format
+msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:16134
+#, gcc-internal-format
+msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
+msgstr ""
+
+#: fortran/resolve.cc:16150
+#, gcc-internal-format
+msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
+msgstr ""
+
+#: fortran/resolve.cc:16161
+#, gcc-internal-format, gfc-internal-format
+msgid "Incompatible derived type in PARAMETER at %L"
+msgstr ""
+
+#: fortran/resolve.cc:16169
+#, gcc-internal-format
+msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
+msgstr ""
+
+#: fortran/resolve.cc:16221
+#, gcc-internal-format
+msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
+msgstr ""
+
+#: fortran/resolve.cc:16233
+#, gcc-internal-format
+msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
+msgstr ""
+
+#: fortran/resolve.cc:16240
+#, gcc-internal-format
+msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
+msgstr ""
+
+#: fortran/resolve.cc:16299
+#, gcc-internal-format, gfc-internal-format
+msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
+msgstr ""
+
+#: fortran/resolve.cc:16312
+#, gcc-internal-format
+msgid "%<omp_all_memory%>, declared at %L, may only be used in the OpenMP DEPEND clause"
+msgstr ""
+
+#: fortran/resolve.cc:16370
+#, gcc-internal-format, gfc-internal-format
+msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
+msgstr ""
+
+#: fortran/resolve.cc:16373
+#, gcc-internal-format, gfc-internal-format
+msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
+msgstr ""
+
+#: fortran/resolve.cc:16470
+#, gcc-internal-format
+msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
+msgstr ""
+
+#: fortran/resolve.cc:16491
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad specification for assumed size array at %L"
+msgstr ""
+
+#: fortran/resolve.cc:16505
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed size array at %L must be a dummy argument"
+msgstr ""
+
+#: fortran/resolve.cc:16508
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed shape array at %L must be a dummy argument"
+msgstr ""
+
+#: fortran/resolve.cc:16518
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-rank array at %L must be a dummy argument"
+msgstr ""
+
+#: fortran/resolve.cc:16525
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
+msgstr ""
+
+#: fortran/resolve.cc:16538
+#, gcc-internal-format, gfc-internal-format
+msgid "Symbol at %L is not a DUMMY variable"
+msgstr ""
+
+#: fortran/resolve.cc:16544
+#, gcc-internal-format
+msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
+msgstr ""
+
+#: fortran/resolve.cc:16554
+#, gcc-internal-format
+msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
+msgstr ""
+
+#: fortran/resolve.cc:16563
+#, gcc-internal-format
+msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
+msgstr ""
+
+#: fortran/resolve.cc:16576 fortran/resolve.cc:16753
+#, gcc-internal-format
+msgid "The derived type %qs at %L is of type %qs, which has not been defined"
+msgstr ""
+
+#: fortran/resolve.cc:16590
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
+msgstr ""
+
+#: fortran/resolve.cc:16599
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
+msgstr ""
+
+#: fortran/resolve.cc:16608
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
+msgstr ""
+
+#: fortran/resolve.cc:16616
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
+msgstr ""
+
+#: fortran/resolve.cc:16623
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
+msgstr ""
+
+#: fortran/resolve.cc:16643
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
+msgstr ""
+
+#: fortran/resolve.cc:16650
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
+msgstr ""
+
+#: fortran/resolve.cc:16657
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
+msgstr ""
+
+#: fortran/resolve.cc:16664
+#, gcc-internal-format, gfc-internal-format
+msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
+msgstr ""
+
+#: fortran/resolve.cc:16690
+#, gcc-internal-format
+msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
+msgstr ""
+
+#: fortran/resolve.cc:16700
+#, gcc-internal-format
+msgid "BIND(C) Variable %qs at %L must have length one"
+msgstr ""
+
+#: fortran/resolve.cc:16779
+#, gcc-internal-format
+msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
+msgstr ""
+
+#: fortran/resolve.cc:16794
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
+msgstr ""
+
+#: fortran/resolve.cc:16807
+#, gcc-internal-format, gfc-internal-format
+msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
+msgstr ""
+
+#: fortran/resolve.cc:16825
+#, gcc-internal-format
+msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
+msgstr ""
+
+#: fortran/resolve.cc:16837
+#, gcc-internal-format
+msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
+msgstr ""
+
+#: fortran/resolve.cc:16846
+#, gcc-internal-format
+msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
+msgstr ""
+
+#: fortran/resolve.cc:16859
+#, gcc-internal-format
+msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
+msgstr ""
+
+#: fortran/resolve.cc:16868
+#, gcc-internal-format
+msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
+msgstr ""
+
+#: fortran/resolve.cc:16881
+#, gcc-internal-format
+msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
+msgstr ""
+
+#: fortran/resolve.cc:16897
+#, gcc-internal-format
+msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
+msgstr ""
+
+#: fortran/resolve.cc:16905
+#, gcc-internal-format
+msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
+msgstr ""
+
+#: fortran/resolve.cc:16912
+#, gcc-internal-format
+msgid "Allocatable coarray variable %qs at %L must have deferred shape"
+msgstr ""
+
+#: fortran/resolve.cc:16925
+#, gcc-internal-format
+msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
+msgstr ""
+
+#: fortran/resolve.cc:16934
+#, gcc-internal-format
+msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
+msgstr ""
+
+#: fortran/resolve.cc:16950
+#, gcc-internal-format
+msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
+msgstr ""
+
+#: fortran/resolve.cc:16956
+#, gcc-internal-format
+msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
+msgstr ""
+
+#: fortran/resolve.cc:16981
+#, gcc-internal-format
+msgid "Namelist %qs cannot be an argument to subroutine or function at %L"
+msgstr ""
+
+#: fortran/resolve.cc:17041
+#, gcc-internal-format, gfc-internal-format
+msgid "Threadprivate at %L isn't SAVEd"
+msgstr ""
+
+#: fortran/resolve.cc:17053
+#, gcc-internal-format
+msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
+msgstr ""
+
+#: fortran/resolve.cc:17160
+#, gcc-internal-format, gfc-internal-format
+msgid "Expecting definable entity near %L"
+msgstr ""
+
+#: fortran/resolve.cc:17168
+#, gcc-internal-format
+msgid "BLOCK DATA element %qs at %L must be in COMMON"
+msgstr ""
+
+#: fortran/resolve.cc:17175
+#, gcc-internal-format
+msgid "DATA array %qs at %L must be specified in a previous declaration"
+msgstr ""
+
+#: fortran/resolve.cc:17182
+#, gcc-internal-format
+msgid "DATA element %qs at %L cannot have a coindex"
+msgstr ""
+
+#: fortran/resolve.cc:17198
+#, gcc-internal-format
+msgid "DATA element %qs at %L is a pointer and so must be a full array"
+msgstr ""
+
+#: fortran/resolve.cc:17205
+#, gcc-internal-format, gfc-internal-format
+msgid "DATA object near %L has the pointer attribute and the corresponding DATA value is not a valid initial-data-target"
+msgstr ""
+
+#: fortran/resolve.cc:17214
+#, gcc-internal-format
+msgid "DATA element %qs at %L cannot have the ALLOCATABLE attribute"
+msgstr ""
+
+#: fortran/resolve.cc:17276
+#, gcc-internal-format, gfc-internal-format
+msgid "Nonconstant array section at %L in DATA statement"
+msgstr ""
+
+#: fortran/resolve.cc:17289
+#, gcc-internal-format, gfc-internal-format
+msgid "DATA statement at %L has more variables than values"
+msgstr ""
+
+#: fortran/resolve.cc:17365
+#, gcc-internal-format, gfc-internal-format
+msgid "Non-constant character length at %L in DATA statement"
+msgstr ""
+
+#: fortran/resolve.cc:17393
+#, gcc-internal-format, gfc-internal-format
+msgid "start of implied-do loop at %L could not be simplified to a constant value"
+msgstr ""
+
+#: fortran/resolve.cc:17401
+#, gcc-internal-format, gfc-internal-format
+msgid "end of implied-do loop at %L could not be simplified to a constant value"
+msgstr ""
+
+#: fortran/resolve.cc:17409
+#, gcc-internal-format, gfc-internal-format
+msgid "step of implied-do loop at %L could not be simplified to a constant value"
+msgstr ""
+
+#: fortran/resolve.cc:17416
+#, gcc-internal-format, gfc-internal-format
+msgid "step of implied-do loop at %L shall not be zero"
+msgstr ""
+
+#: fortran/resolve.cc:17541
+#, gcc-internal-format, gfc-internal-format
+msgid "DATA statement at %L has more values than variables"
+msgstr ""
+
+#: fortran/resolve.cc:17707
+#, gcc-internal-format, gfc-internal-format
+msgid "Label %d at %L defined but not used"
+msgstr ""
+
+#: fortran/resolve.cc:17713
+#, gcc-internal-format, gfc-internal-format
+msgid "Label %d at %L defined but cannot be used"
+msgstr ""
+
+#: fortran/resolve.cc:17797
+#, gcc-internal-format
+msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
+msgstr ""
+
+#: fortran/resolve.cc:17806
+#, gcc-internal-format
+msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
+msgstr ""
+
+#: fortran/resolve.cc:17814
+#, gcc-internal-format
+msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
+msgstr ""
+
+#: fortran/resolve.cc:17830
+#, gcc-internal-format
+msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
+msgstr ""
+
+#: fortran/resolve.cc:17933
+#, gcc-internal-format, gfc-internal-format
+msgid "Syntax error in EQUIVALENCE statement at %L"
+msgstr ""
+
+#: fortran/resolve.cc:17948
+#, gcc-internal-format, gfc-internal-format
+msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
+msgstr ""
+
+#: fortran/resolve.cc:17973
+#, gcc-internal-format
+msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
+msgstr ""
+
+#: fortran/resolve.cc:17982
+#, gcc-internal-format
+msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
+msgstr ""
+
+#: fortran/resolve.cc:18057
+#, gcc-internal-format
+msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
+msgstr ""
+
+#: fortran/resolve.cc:18068
+#, gcc-internal-format
+msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
+msgstr ""
+
+#: fortran/resolve.cc:18079
+#, gcc-internal-format, gfc-internal-format
+msgid "Substring at %L has length zero"
+msgstr ""
+
+#: fortran/resolve.cc:18110
+#, gcc-internal-format
+msgid "Self reference in character length expression for %qs at %L"
+msgstr ""
+
+#: fortran/resolve.cc:18177
+#, gcc-internal-format
+msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
+msgstr ""
+
+#: fortran/resolve.cc:18190
+#, gcc-internal-format
+msgid "ENTRY %qs at %L has no IMPLICIT type"
+msgstr ""
+
+#: fortran/resolve.cc:18212
+#, gcc-internal-format
+msgid "User operator procedure %qs at %L must be a FUNCTION"
+msgstr ""
+
+#: fortran/resolve.cc:18222
+#, gcc-internal-format
+msgid "User operator procedure %qs at %L cannot be assumed character length"
+msgstr ""
+
+#: fortran/resolve.cc:18230
+#, gcc-internal-format
+msgid "User operator procedure %qs at %L must have at least one argument"
+msgstr ""
+
+#: fortran/resolve.cc:18244
+#, gcc-internal-format, gfc-internal-format
+msgid "First argument of operator interface at %L cannot be optional"
+msgstr ""
+
+#: fortran/resolve.cc:18262
+#, gcc-internal-format, gfc-internal-format
+msgid "Second argument of operator interface at %L cannot be optional"
+msgstr ""
+
+#: fortran/resolve.cc:18269
+#, gcc-internal-format, gfc-internal-format
+msgid "Operator interface at %L must have, at most, two arguments"
+msgstr ""
+
+#: fortran/resolve.cc:18351
+#, gcc-internal-format
+msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
+msgstr ""
+
+#: fortran/scanner.cc:309
+#, gcc-internal-format
+msgid "Include directory %qs: %s"
+msgstr ""
+
+#: fortran/scanner.cc:313
+#, gcc-internal-format
+msgid "Nonexistent include directory %qs"
+msgstr ""
+
+#: fortran/scanner.cc:318
+#, gcc-internal-format
+msgid "%qs is not a directory"
+msgstr ""
+
+#: fortran/scanner.cc:792
+#, gcc-internal-format, gfc-internal-format
+msgid "!$ACC at %C starts a commented line as it neither is followed by a space nor is a continuation line"
+msgstr ""
+
+#: fortran/scanner.cc:832
+#, gcc-internal-format, gfc-internal-format
+msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
+msgstr ""
+
+#: fortran/scanner.cc:1011
+#, gcc-internal-format, gfc-internal-format
+msgid "Ignoring '!$omx' vendor-extension sentinel at %C"
+msgstr ""
+
+#: fortran/scanner.cc:1323 fortran/scanner.cc:1526
+#, gcc-internal-format, gfc-internal-format
+msgid "Line truncated at %L"
+msgstr ""
+
+#: fortran/scanner.cc:1387 fortran/scanner.cc:1616
+#, gcc-internal-format, gfc-internal-format
+msgid "Limit of %d continuations exceeded in statement at %C"
+msgstr ""
+
+#: fortran/scanner.cc:1466 fortran/scanner.cc:1575
+#, gcc-internal-format, gfc-internal-format
+msgid "Wrong OpenACC continuation at %C: expected !$ACC, got !$OMP"
+msgstr ""
+
+#: fortran/scanner.cc:1468 fortran/scanner.cc:1577
+#, gcc-internal-format, gfc-internal-format
+msgid "Wrong OpenMP continuation at %C: expected !$OMP, got !$ACC"
+msgstr ""
+
+#: fortran/scanner.cc:1481
+#, gcc-internal-format
+msgid "Missing %<&%> in continued character constant at %C"
+msgstr ""
+
+#: fortran/scanner.cc:1767
+#, gcc-internal-format, gfc-internal-format
+msgid "Nonconforming tab character at %C"
+msgstr ""
+
+#: fortran/scanner.cc:1778
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid character 0x%s at %C"
+msgstr ""
+
+#: fortran/scanner.cc:1867 fortran/scanner.cc:1870
+#, gcc-internal-format
+msgid "%<&%> not allowed by itself in line %d"
+msgstr ""
+
+#: fortran/scanner.cc:1960
+#, gcc-internal-format, gfc-internal-format
+msgid "Nonconforming tab character in column %d of line %d"
+msgstr ""
+
+#: fortran/scanner.cc:2189
+#, gcc-internal-format
+msgid "file %qs left but not entered"
+msgstr ""
+
+#: fortran/scanner.cc:2231
+#, gcc-internal-format
+msgid "Illegal preprocessor directive"
+msgstr ""
+
+#: fortran/scanner.cc:2554
+#, gcc-internal-format
+msgid "File %qs is being included recursively"
+msgstr ""
+
+#: fortran/scanner.cc:2566
+#, gcc-internal-format
+msgid "Cannot open file %qs"
+msgstr ""
+
+#: fortran/scanner.cc:2576
+#, gcc-internal-format
+msgid "Cannot open included file %qs"
+msgstr ""
+
+#: fortran/scanner.cc:2578
+#, gcc-internal-format
+msgid "Cannot open pre-included file %qs"
+msgstr ""
+
+#: fortran/scanner.cc:2586 fortran/scanner.cc:2588
+#, gcc-internal-format
+msgid "Included file %qs is not a regular file"
+msgstr ""
+
+#: fortran/simplify.cc:92
+#, gcc-internal-format, gfc-internal-format
+msgid "Result of %s overflows its kind at %L"
+msgstr ""
+
+#: fortran/simplify.cc:97
+#, gcc-internal-format, gfc-internal-format
+msgid "Result of %s underflows its kind at %L"
+msgstr ""
+
+#: fortran/simplify.cc:102
+#, gcc-internal-format, gfc-internal-format
+msgid "Result of %s is NaN at %L"
+msgstr ""
+
+#: fortran/simplify.cc:106
+#, gcc-internal-format, gfc-internal-format
+msgid "Result of %s gives range error for its kind at %L"
+msgstr ""
+
+#: fortran/simplify.cc:129
+#, gcc-internal-format, gfc-internal-format
+msgid "KIND parameter of %s at %L must be an initialization expression"
+msgstr ""
+
+#: fortran/simplify.cc:137
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid KIND parameter of %s at %L"
+msgstr ""
+
+#: fortran/simplify.cc:788
+#, gcc-internal-format
+msgid "gfc_simplify_abs(): Bad type"
+msgstr ""
+
+#: fortran/simplify.cc:809
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of %s function at %L is negative"
+msgstr ""
+
+#: fortran/simplify.cc:816
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of %s function at %L outside of range [0,127]"
+msgstr ""
+
+#: fortran/simplify.cc:834
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of %s function at %L is too large for the collating sequence of kind %d"
+msgstr ""
+
+#: fortran/simplify.cc:871
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of ACOS at %L must be between -1 and 1"
+msgstr ""
+
+#: fortran/simplify.cc:885
+#, gcc-internal-format
+msgid "in gfc_simplify_acos(): Bad type"
+msgstr ""
+
+#: fortran/simplify.cc:904
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of ACOSH at %L must not be less than 1"
+msgstr ""
+
+#: fortran/simplify.cc:919
+#, gcc-internal-format
+msgid "in gfc_simplify_acosh(): Bad type"
+msgstr ""
+
+#: fortran/simplify.cc:1148
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of ASIN at %L must be between -1 and 1"
+msgstr ""
+
+#: fortran/simplify.cc:1162
+#, gcc-internal-format
+msgid "in gfc_simplify_asin(): Bad type"
+msgstr ""
+
+#: fortran/simplify.cc:1197
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of ACOSD at %L must be between -1 and 1"
+msgstr ""
+
+#: fortran/simplify.cc:1223
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of ASIND at %L must be between -1 and 1"
+msgstr ""
+
+#: fortran/simplify.cc:1275
+#, gcc-internal-format
+msgid "in gfc_simplify_asinh(): Bad type"
+msgstr ""
+
+#: fortran/simplify.cc:1303
+#, gcc-internal-format
+msgid "in gfc_simplify_atan(): Bad type"
+msgstr ""
+
+#: fortran/simplify.cc:1324
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of ATANH at %L must be inside the range -1 to 1"
+msgstr ""
+
+#: fortran/simplify.cc:1338
+#, gcc-internal-format
+msgid "in gfc_simplify_atanh(): Bad type"
+msgstr ""
+
+#: fortran/simplify.cc:1355
+#, gcc-internal-format, gfc-internal-format
+msgid "If first argument of ATAN2 at %L is zero, then the second argument must not be zero"
+msgstr ""
+
+#: fortran/simplify.cc:1447
+#, gcc-internal-format, gfc-internal-format
+msgid "Result of BESSEL_YN is -INF at %L"
+msgstr ""
+
+#: fortran/simplify.cc:1813
+#, gcc-internal-format
+msgid "gfc_simplify_dcmplx(): Bad type (x)"
+msgstr ""
+
+#: fortran/simplify.cc:1832
+#, gcc-internal-format
+msgid "gfc_simplify_dcmplx(): Bad type (y)"
+msgstr ""
+
+#: fortran/simplify.cc:1899
+#, gcc-internal-format, gfc-internal-format
+msgid "If first argument of ATAN2D at %L is zero, then the second argument must not be zero"
+msgstr ""
+
+#: fortran/simplify.cc:1934
+#, gcc-internal-format
+msgid "in gfc_simplify_cos(): Bad type"
+msgstr ""
+
+#: fortran/simplify.cc:2402
+#, gcc-internal-format
+msgid "gfc_simplify_dim(): Bad type"
+msgstr ""
+
+#: fortran/simplify.cc:2976
+#, gcc-internal-format
+msgid "in gfc_simplify_exp(): Bad type"
+msgstr ""
+
+#: fortran/simplify.cc:3194
+#, gcc-internal-format
+msgid "gfc_simplify_floor(): Bad kind"
+msgstr ""
+
+#: fortran/simplify.cc:3307
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of IACHAR at %L must be of length one"
+msgstr ""
+
+#: fortran/simplify.cc:3315
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of IACHAR function at %L outside of range 0..127"
+msgstr ""
+
+#: fortran/simplify.cc:3443
+#, gcc-internal-format, gfc-internal-format
+msgid "Sum of second and third arguments of IBITS exceeds bit size at %L"
+msgstr ""
+
+#: fortran/simplify.cc:3467
+#, gcc-internal-format
+msgid "IBITS: Bad bit"
+msgstr ""
+
+#: fortran/simplify.cc:3528
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of ICHAR at %L must be of length one"
+msgstr ""
+
+#. Left shift, as in SHIFTL.
+#: fortran/simplify.cc:3840 fortran/simplify.cc:3848
+#, gcc-internal-format, gfc-internal-format
+msgid "Second argument of %s is negative at %L"
+msgstr ""
+
+#: fortran/simplify.cc:3860
+#, gcc-internal-format, gfc-internal-format
+msgid "Magnitude of second argument of %s exceeds bit size at %L"
+msgstr ""
+
+#: fortran/simplify.cc:3988
+#, gcc-internal-format, gfc-internal-format
+msgid "Magnitude of second argument of ISHFTC exceeds BIT_SIZE of first argument at %C"
+msgstr ""
+
+#: fortran/simplify.cc:3991
+#, gcc-internal-format, gfc-internal-format
+msgid "Absolute value of SHIFT shall be less than or equal to SIZE at %C"
+msgstr ""
+
+#: fortran/simplify.cc:4338 fortran/simplify.cc:4471
+#, gcc-internal-format, gfc-internal-format
+msgid "DIM argument at %L is out of bounds"
+msgstr ""
+
+#: fortran/simplify.cc:4729
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of LOG at %L cannot be less than or equal to zero"
+msgstr ""
+
+#: fortran/simplify.cc:4742
+#, gcc-internal-format, gfc-internal-format
+msgid "Complex argument of LOG at %L cannot be zero"
+msgstr ""
+
+#: fortran/simplify.cc:4753
+#, gcc-internal-format
+msgid "gfc_simplify_log: bad type"
+msgstr ""
+
+#: fortran/simplify.cc:4770
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of LOG10 at %L cannot be less than or equal to zero"
+msgstr ""
+
+#: fortran/simplify.cc:5123
+#, gcc-internal-format
+msgid "simplify_min_max(): Bad type in arglist"
+msgstr ""
+
+#: fortran/simplify.cc:6045 fortran/simplify.cc:6053
+#, gcc-internal-format
+msgid "Argument %qs of MOD at %L shall not be zero"
+msgstr ""
+
+#: fortran/simplify.cc:6059
+#, gcc-internal-format
+msgid "gfc_simplify_mod(): Bad arguments"
+msgstr ""
+
+#: fortran/simplify.cc:6097 fortran/simplify.cc:6105
+#, gcc-internal-format
+msgid "Argument %qs of MODULO at %L shall not be zero"
+msgstr ""
+
+#: fortran/simplify.cc:6111
+#, gcc-internal-format
+msgid "gfc_simplify_modulo(): Bad arguments"
+msgstr ""
+
+#: fortran/simplify.cc:6183
+#, gcc-internal-format, gfc-internal-format
+msgid "Result of NEAREST is NaN at %L"
+msgstr ""
+
+#: fortran/simplify.cc:6760
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
+msgstr ""
+
+#: fortran/simplify.cc:6816
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
+msgstr ""
+
+#: fortran/simplify.cc:6853
+#, gcc-internal-format, gfc-internal-format
+msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
+msgstr ""
+
+#: fortran/simplify.cc:6911
+#, gcc-internal-format, gfc-internal-format
+msgid "The SHAPE array for the RESHAPE intrinsic at %L has a negative value %d for dimension %d"
+msgstr ""
+
+#: fortran/simplify.cc:6936
+#, gcc-internal-format, gfc-internal-format
+msgid "Shapes of ORDER at %L and SHAPE at %L are different"
+msgstr ""
+
+#: fortran/simplify.cc:6950
+#, gcc-internal-format, gfc-internal-format
+msgid "Sizes of ORDER at %L and SHAPE at %L are different"
+msgstr ""
+
+#: fortran/simplify.cc:6965
+#, gcc-internal-format, gfc-internal-format
+msgid "Element with a value of %d in ORDER at %L must be in the range [1, ..., %d] for the RESHAPE intrinsic near %L"
+msgstr ""
+
+#: fortran/simplify.cc:6976
+#, gcc-internal-format, gfc-internal-format
+msgid "ORDER at %L is not a permutation of the size of SHAPE at %L"
+msgstr ""
+
+#: fortran/simplify.cc:7038
+#, gcc-internal-format, gfc-internal-format
+msgid "Reshaped array too large at %C"
+msgstr ""
+
+#: fortran/simplify.cc:7159
+#, gcc-internal-format, gfc-internal-format
+msgid "Result of SCALE overflows its kind at %L"
+msgstr ""
+
+#: fortran/simplify.cc:7634
+#, gcc-internal-format, gfc-internal-format
+msgid "DIM argument (%d) to intrinsic SIZE at %L out of range (1:%d)"
+msgstr ""
+
+#: fortran/simplify.cc:7759
+#, gcc-internal-format
+msgid "Bad type in gfc_simplify_sign"
+msgstr ""
+
+#: fortran/simplify.cc:7788
+#, gcc-internal-format
+msgid "in gfc_simplify_sin(): Bad type"
+msgstr ""
+
+#: fortran/simplify.cc:7926 fortran/simplify.cc:8209
+#, gcc-internal-format
+msgid "Failure getting length of a constant array."
+msgstr ""
+
+#: fortran/simplify.cc:7936
+#, gcc-internal-format
+msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
+msgstr ""
+
+#: fortran/simplify.cc:8003
+#, gcc-internal-format, gfc-internal-format
+msgid "Simplification of SPREAD at %C not yet implemented"
+msgstr ""
+
+#: fortran/simplify.cc:8027
+#, gcc-internal-format, gfc-internal-format
+msgid "Argument of SQRT at %L has a negative value"
+msgstr ""
+
+#: fortran/simplify.cc:8043
+#, gcc-internal-format, gfc-internal-format
+msgid "invalid argument of SQRT at %L"
+msgstr ""
+
+#: fortran/simplify.cc:8390
+#, gcc-internal-format, gfc-internal-format
+msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
+msgstr ""
+
+#: fortran/simplify.cc:8413
+#, gcc-internal-format, gfc-internal-format
+msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
+msgstr ""
+
+#: fortran/simplify.cc:8913
+#, gcc-internal-format
+msgid "Character %qs in string at %L cannot be converted into character kind %d"
+msgstr ""
+
+#: fortran/st.cc:303
+#, gcc-internal-format
+msgid "gfc_free_statement(): Bad statement"
+msgstr ""
+
+#: fortran/symbol.cc:141
+#, gcc-internal-format, gfc-internal-format
+msgid "IMPLICIT NONE (type) statement at %L following an IMPLICIT statement"
+msgstr ""
+
+#: fortran/symbol.cc:178
+#, gcc-internal-format
+msgid "Letter %qc already set in IMPLICIT statement at %C"
+msgstr ""
+
+#: fortran/symbol.cc:200
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot specify IMPLICIT at %C after IMPLICIT NONE"
+msgstr ""
+
+#: fortran/symbol.cc:210
+#, gcc-internal-format
+msgid "Letter %qc already has an IMPLICIT type at %C"
+msgstr ""
+
+#: fortran/symbol.cc:234
+#, gcc-internal-format
+msgid "Option %<-fallow-leading-underscore%> is for use only by gfortran developers, and should not be used for implicitly typed variables"
+msgstr ""
+
+#: fortran/symbol.cc:239
+#, gcc-internal-format
+msgid "gfc_get_default_type(): Bad symbol %qs"
+msgstr ""
+
+#: fortran/symbol.cc:309
+#, gcc-internal-format
+msgid "gfc_set_default_type(): symbol already has a type"
+msgstr ""
+
+#: fortran/symbol.cc:319
+#, gcc-internal-format
+msgid "Symbol %qs at %L has no IMPLICIT type; did you mean %qs?"
+msgstr ""
+
+#: fortran/symbol.cc:323
+#, gcc-internal-format
+msgid "Symbol %qs at %L has no IMPLICIT type"
+msgstr ""
+
+#. BIND(C) variables should not be implicitly declared.
+#: fortran/symbol.cc:343
+#, gcc-internal-format
+msgid "Implicitly declared BIND(C) variable %qs at %L may not be C interoperable"
+msgstr ""
+
+#. Dummy args to a BIND(C) routine may not be interoperable if
+#. they are implicitly typed.
+#: fortran/symbol.cc:359
+#, gcc-internal-format
+msgid "Implicitly declared variable %qs at %L may not be C interoperable but it is a dummy argument to the BIND(C) procedure %qs at %L"
+msgstr ""
+
+#: fortran/symbol.cc:400
+#, gcc-internal-format
+msgid "Function result %qs at %L has no IMPLICIT type"
+msgstr ""
+
+#: fortran/symbol.cc:420 fortran/symbol.cc:925 fortran/symbol.cc:1802
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute conflicts with %s attribute at %L"
+msgstr ""
+
+#: fortran/symbol.cc:426 fortran/symbol.cc:928
+#, gcc-internal-format
+msgid "%s attribute conflicts with %s attribute in %qs at %L"
+msgstr ""
+
+#: fortran/symbol.cc:508
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute not allowed in BLOCK DATA program unit at %L"
+msgstr ""
+
+#: fortran/symbol.cc:533
+#, gcc-internal-format, gfc-internal-format
+msgid "Namelist group name at %L cannot have the SAVE attribute"
+msgstr ""
+
+#: fortran/symbol.cc:552
+#, gcc-internal-format
+msgid "internal procedure %qs at %L conflicts with DUMMY argument"
+msgstr ""
+
+#: fortran/symbol.cc:585
+#, gcc-internal-format, gfc-internal-format
+msgid "Procedure pointer at %C"
+msgstr ""
+
+#: fortran/symbol.cc:797
+#, gcc-internal-format, gfc-internal-format
+msgid "%s attribute applied to %s %s at %L"
+msgstr ""
+
+#: fortran/symbol.cc:804
+#, gcc-internal-format, gfc-internal-format
+msgid "BIND(C) applied to %s %s at %L"
+msgstr ""
+
+#: fortran/symbol.cc:972
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot change attributes of USE-associated symbol at %L"
+msgstr ""
+
+#: fortran/symbol.cc:975
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot change attributes of USE-associated symbol %s at %L"
+msgstr ""
+
+#: fortran/symbol.cc:991
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate %s attribute specified at %L"
+msgstr ""
+
+#: fortran/symbol.cc:1033
+#, gcc-internal-format, gfc-internal-format
+msgid "ALLOCATABLE specified outside of INTERFACE body at %L"
+msgstr ""
+
+#: fortran/symbol.cc:1050
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate AUTOMATIC attribute specified at %L"
+msgstr ""
+
+#: fortran/symbol.cc:1074
+#, gcc-internal-format
+msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
+msgstr ""
+
+#: fortran/symbol.cc:1100
+#, gcc-internal-format
+msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
+msgstr ""
+
+#: fortran/symbol.cc:1263
+#, gcc-internal-format, gfc-internal-format
+msgid "Cray Pointee at %L appears in multiple pointer() statements"
+msgstr ""
+
+#: fortran/symbol.cc:1282
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate PROTECTED attribute specified at %L"
+msgstr ""
+
+#: fortran/symbol.cc:1315
+#, gcc-internal-format, gfc-internal-format
+msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
+msgstr ""
+
+#: fortran/symbol.cc:1327
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate SAVE attribute specified at %L"
+msgstr ""
+
+#: fortran/symbol.cc:1347
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate VALUE attribute specified at %L"
+msgstr ""
+
+#: fortran/symbol.cc:1366
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate VOLATILE attribute specified at %L"
+msgstr ""
+
+#: fortran/symbol.cc:1378
+#, gcc-internal-format, gfc-internal-format
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr ""
+
+#: fortran/symbol.cc:1399
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
+msgstr ""
+
+#: fortran/symbol.cc:1798
+#, gcc-internal-format
+msgid "%s attribute of %qs conflicts with %s attribute at %L"
+msgstr ""
+
+#: fortran/symbol.cc:1835
+#, gcc-internal-format, gfc-internal-format
+msgid ""
+"%s procedure at %L is already declared as %s procedure. \n"
+"F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
+msgstr ""
+
+#: fortran/symbol.cc:1843
+#, gcc-internal-format, gfc-internal-format
+msgid "%s procedure at %L is already declared as %s procedure"
+msgstr ""
+
+#: fortran/symbol.cc:1878
+#, gcc-internal-format, gfc-internal-format
+msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
+msgstr ""
+
+#: fortran/symbol.cc:1902
+#, gcc-internal-format, gfc-internal-format
+msgid "ACCESS specification at %L was already specified"
+msgstr ""
+
+#: fortran/symbol.cc:1919
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate BIND attribute specified at %L"
+msgstr ""
+
+#: fortran/symbol.cc:1926
+#, gcc-internal-format, gfc-internal-format
+msgid "BIND(C) at %L"
+msgstr ""
+
+#: fortran/symbol.cc:1942
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate EXTENDS attribute specified at %L"
+msgstr ""
+
+#: fortran/symbol.cc:1946
+#, gcc-internal-format, gfc-internal-format
+msgid "EXTENDS at %L"
+msgstr ""
+
+#: fortran/symbol.cc:1972
+#, gcc-internal-format
+msgid "Symbol %qs at %L already has an explicit interface"
+msgstr ""
+
+#: fortran/symbol.cc:1979
+#, gcc-internal-format
+msgid "%qs at %L has attributes specified outside its INTERFACE body"
+msgstr ""
+
+#: fortran/symbol.cc:2017
+#, gcc-internal-format
+msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
+msgstr ""
+
+#: fortran/symbol.cc:2021 fortran/symbol.cc:2024
+#, gcc-internal-format
+msgid "Symbol %qs at %L already has basic type of %s"
+msgstr ""
+
+#: fortran/symbol.cc:2031
+#, gcc-internal-format
+msgid "Procedure %qs at %L may not have basic type of %s"
+msgstr ""
+
+#: fortran/symbol.cc:2043
+#, gcc-internal-format
+msgid "Symbol %qs at %L cannot have a type"
+msgstr ""
+
+#: fortran/symbol.cc:2288
+#, gcc-internal-format
+msgid "Component %qs at %C already in the parent type at %L"
+msgstr ""
+
+#: fortran/symbol.cc:2373
+#, gcc-internal-format
+msgid "Symbol %qs at %C is ambiguous"
+msgstr ""
+
+#: fortran/symbol.cc:2405
+#, gcc-internal-format
+msgid "Derived type %qs at %C is being used before it is defined"
+msgstr ""
+
+#: fortran/symbol.cc:2615
+#, gcc-internal-format
+msgid "Component %qs at %C is a PRIVATE component of %qs"
+msgstr ""
+
+#: fortran/symbol.cc:2636
+#, gcc-internal-format
+msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
+msgstr ""
+
+#: fortran/symbol.cc:2640
+#, gcc-internal-format
+msgid "%qs at %C is not a member of the %qs structure"
+msgstr ""
+
+#: fortran/symbol.cc:2804
+#, gcc-internal-format, gfc-internal-format
+msgid "Duplicate statement label %d at %L and %L"
+msgstr ""
+
+#: fortran/symbol.cc:2815
+#, gcc-internal-format, gfc-internal-format
+msgid "Label %d at %C already referenced as branch target"
+msgstr ""
+
+#: fortran/symbol.cc:2825
+#, gcc-internal-format, gfc-internal-format
+msgid "Label %d at %C already referenced as a format label"
+msgstr ""
+
+#: fortran/symbol.cc:2832
+#, gcc-internal-format, gfc-internal-format
+msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
+msgstr ""
+
+#: fortran/symbol.cc:2873
+#, gcc-internal-format, gfc-internal-format
+msgid "Label %d at %C previously used as a FORMAT label"
+msgstr ""
+
+#: fortran/symbol.cc:2882
+#, gcc-internal-format, gfc-internal-format
+msgid "Label %d at %C previously used as branch target"
+msgstr ""
+
+#: fortran/symbol.cc:2889
+#, gcc-internal-format, gfc-internal-format
+msgid "Shared DO termination label %d at %C"
+msgstr ""
+
+#: fortran/symbol.cc:2893
+#, gcc-internal-format, gfc-internal-format
+msgid "Labeled DO statement at %L"
+msgstr ""
+
+#: fortran/symbol.cc:3284
+#, gcc-internal-format
+msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
+msgstr ""
+
+#: fortran/symbol.cc:3287
+#, gcc-internal-format
+msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
+msgstr ""
+
+#. Symbol is from another namespace.
+#: fortran/symbol.cc:3532
+#, gcc-internal-format
+msgid "Symbol %qs at %C has already been host associated"
+msgstr ""
+
+#: fortran/symbol.cc:4586
+#, gcc-internal-format
+msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
+msgstr ""
+
+#: fortran/symbol.cc:4599
+#, gcc-internal-format
+msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
+msgstr ""
+
+#: fortran/symbol.cc:4617
+#, gcc-internal-format
+msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
+msgstr ""
+
+#: fortran/symbol.cc:4638
+#, gcc-internal-format
+msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
+msgstr ""
+
+#: fortran/symbol.cc:4648
+#, gcc-internal-format
+msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
+msgstr ""
+
+#: fortran/symbol.cc:4659
+#, gcc-internal-format
+msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
+msgstr ""
+
+#: fortran/symbol.cc:4698
+#, gcc-internal-format
+msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
+msgstr ""
+
+#: fortran/symbol.cc:4708
+#, gcc-internal-format
+msgid "Component %qs in derived type %qs at %L may not be C interoperable"
+msgstr ""
+
+#: fortran/symbol.cc:4720
+#, gcc-internal-format
+msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
+msgstr ""
+
+#: fortran/symbol.cc:5224 fortran/symbol.cc:5229
+#, gcc-internal-format
+msgid "Symbol %qs is used before it is typed at %L"
+msgstr ""
+
+#: fortran/target-memory.cc:137
+#, gcc-internal-format
+msgid "Invalid expression in gfc_element_size."
+msgstr ""
+
+#: fortran/target-memory.cc:361
+#, gcc-internal-format
+msgid "Invalid expression in gfc_target_encode_expr."
+msgstr ""
+
+#: fortran/target-memory.cc:637
+#, gcc-internal-format
+msgid "Invalid expression in gfc_target_interpret_expr."
+msgstr ""
+
+#: fortran/target-memory.cc:710
+#, gcc-internal-format, gfc-internal-format
+msgid "Overlapping unequal initializers in EQUIVALENCE at %L"
+msgstr ""
+
+#: fortran/target-memory.cc:713
+#, gcc-internal-format, gfc-internal-format
+msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
+msgstr ""
+
+#: fortran/trans-array.cc:2340 fortran/trans-expr.cc:9859
+#, gcc-internal-format, gfc-internal-format
+msgid "The structure constructor at %C has been finalized. This feature was removed by f08/0011. Use -std=f2018 or -std=gnu to eliminate the finalization."
+msgstr ""
+
+#. Problems occur when we get something like
+#. integer :: a(lots) = (/(i, i=1, lots)/)
+#: fortran/trans-array.cc:6620
+#, gcc-internal-format
+msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
+msgstr ""
+
+#: fortran/trans-array.cc:8876
+#, gcc-internal-format
+msgid "Creating array temporary at %L for argument %qs"
+msgstr ""
+
+#: fortran/trans-array.cc:12255
+#, gcc-internal-format, gfc-internal-format
+msgid "bad expression type during walk (%d)"
+msgstr ""
+
+#: fortran/trans-common.cc:411
+#, gcc-internal-format
+msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%wu vs %wu bytes)"
+msgstr ""
+
+#: fortran/trans-common.cc:819
+#, gcc-internal-format
+msgid "get_mpz(): Not an integer constant"
+msgstr ""
+
+#: fortran/trans-common.cc:847
+#, gcc-internal-format
+msgid "element_number(): Bad dimension type"
+msgstr ""
+
+#: fortran/trans-common.cc:917
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad array reference at %L"
+msgstr ""
+
+#: fortran/trans-common.cc:925
+#, gcc-internal-format, gfc-internal-format
+msgid "Illegal reference type at %L as EQUIVALENCE object"
+msgstr ""
+
+#: fortran/trans-common.cc:965
+#, gcc-internal-format
+msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
+msgstr ""
+
+#. Aligning this field would misalign a previous field.
+#: fortran/trans-common.cc:1154
+#, gcc-internal-format
+msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
+msgstr ""
+
+#: fortran/trans-common.cc:1219
+#, gcc-internal-format
+msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
+msgstr ""
+
+#: fortran/trans-common.cc:1234
+#, gcc-internal-format
+msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
+msgstr ""
+
+#: fortran/trans-common.cc:1250
+#, gcc-internal-format
+msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use %<-fno-align-commons%>"
+msgstr ""
+
+#: fortran/trans-common.cc:1256
+#, gcc-internal-format
+msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use %<-fno-align-commons%>"
+msgstr ""
+
+#: fortran/trans-common.cc:1277
+#, gcc-internal-format
+msgid "COMMON %qs at %L does not exist"
+msgstr ""
+
+#: fortran/trans-common.cc:1286
+#, gcc-internal-format
+msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
+msgstr ""
+
+#: fortran/trans-common.cc:1291
+#, gcc-internal-format
+msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
+msgstr ""
+
+#: fortran/trans-const.cc:336
+#, gcc-internal-format, gfc-internal-format
+msgid "Assigning value other than 0 or 1 to LOGICAL has undefined result at %L"
+msgstr ""
+
+#: fortran/trans-const.cc:402
+#, gcc-internal-format, gfc-internal-format
+msgid "non-constant initialization expression at %L"
+msgstr ""
+
+#: fortran/trans-decl.cc:763
+#, gcc-internal-format
+msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, moved from stack to static storage. This makes the procedure unsafe when called recursively, or concurrently from multiple threads. Consider increasing the %<-fmax-stack-var-size=%> limit (or use %<-frecursive%>, which implies unlimited %<-fmax-stack-var-size%>) - or change the code to use an ALLOCATABLE array. If the variable is never accessed concurrently, this warning can be ignored, and the variable could also be declared with the SAVE attribute."
+msgstr ""
+
+#: fortran/trans-decl.cc:1800
+#, gcc-internal-format, gfc-internal-format
+msgid "%s at %L has no default type"
+msgstr ""
+
+#: fortran/trans-decl.cc:1804
+#, gcc-internal-format
+msgid "intrinsic variable which isn't a procedure"
+msgstr ""
+
+#: fortran/trans-decl.cc:4565 fortran/trans-decl.cc:7958
+#, gcc-internal-format
+msgid "Return value of function %qs at %L not set"
+msgstr ""
+
+#: fortran/trans-decl.cc:5110
+#, gcc-internal-format
+msgid "Deferred type parameter not yet supported"
+msgstr ""
+
+#: fortran/trans-decl.cc:5225
+#, gcc-internal-format
+msgid "Sorry, !$OMP allocate for COMMON block variable %qs at %L not supported"
+msgstr ""
+
+#: fortran/trans-decl.cc:5232
+#, gcc-internal-format
+msgid "Sorry, !$OMP allocate for variable %qs at %L with SAVE attribute not yet implemented"
+msgstr ""
+
+#: fortran/trans-decl.cc:5438
+#, gcc-internal-format
+msgid "backend decl for module variable %qs already exists"
+msgstr ""
+
+#: fortran/trans-decl.cc:5451
+#, gcc-internal-format
+msgid "Unused PRIVATE module variable %qs declared at %L"
+msgstr ""
+
+#: fortran/trans-decl.cc:6073
+#, gcc-internal-format
+msgid "Symbol %qs at %L has the WEAK attribute but is a dummy argument"
+msgstr ""
+
+#: fortran/trans-decl.cc:6076
+#, gcc-internal-format
+msgid "Symbol %qs at %L has the WEAK attribute but is a local variable"
+msgstr ""
+
+#: fortran/trans-decl.cc:6091
+#, gcc-internal-format
+msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
+msgstr ""
+
+#: fortran/trans-decl.cc:6097
+#, gcc-internal-format
+msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
+msgstr ""
+
+#: fortran/trans-decl.cc:6108 fortran/trans-decl.cc:6259
+#, gcc-internal-format
+msgid "Unused dummy argument %qs at %L"
+msgstr ""
+
+#: fortran/trans-decl.cc:6124
+#, gcc-internal-format
+msgid "Unused module variable %qs which has been explicitly imported at %L"
+msgstr ""
+
+#: fortran/trans-decl.cc:6143
+#, gcc-internal-format
+msgid "Unused variable %qs declared at %L"
+msgstr ""
+
+#: fortran/trans-decl.cc:6192
+#, gcc-internal-format
+msgid "Unused parameter %qs declared at %L"
+msgstr ""
+
+#: fortran/trans-decl.cc:6196
+#, gcc-internal-format
+msgid "Unused parameter %qs which has been explicitly imported at %L"
+msgstr ""
+
+#: fortran/trans-decl.cc:6226
+#, gcc-internal-format
+msgid "Return value %qs of function %qs declared at %L not set"
+msgstr ""
+
+#: fortran/trans-decl.cc:6823
+#, gcc-internal-format, gfc-internal-format
+msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
+msgstr ""
+
+#: fortran/trans-expr.cc:1134
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot compute the length of the char array at %L."
+msgstr ""
+
+#: fortran/trans-expr.cc:1942
+#, gcc-internal-format, gfc-internal-format
+msgid "Code for reallocating the allocatable variable at %L will be added"
+msgstr ""
+
+#: fortran/trans-expr.cc:2278
+#, gcc-internal-format, gfc-internal-format
+msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
+msgstr ""
+
+#: fortran/trans-expr.cc:2287
+#, gcc-internal-format, gfc-internal-format
+msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
+msgstr ""
+
+#: fortran/trans-expr.cc:3986
+#, gcc-internal-format
+msgid "Unknown intrinsic op"
+msgstr ""
+
+#: fortran/trans-expr.cc:5505
+#, gcc-internal-format, gfc-internal-format
+msgid "Unknown argument list function at %L"
+msgstr ""
+
+#: fortran/trans-expr.cc:10437
+#, gcc-internal-format, gfc-internal-format
+msgid "If bounds remapping is specified at %L, the pointer target shall not be NULL"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:944
+#, gcc-internal-format
+msgid "Intrinsic function %qs (%d) not recognized"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:2449 fortran/trans-intrinsic.cc:2998
+#: fortran/trans-intrinsic.cc:3201
+#, gcc-internal-format
+msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:12383 fortran/trans-stmt.cc:1104
+#, gcc-internal-format, gfc-internal-format
+msgid "Sorry, the event component of derived type at %L is not yet supported"
+msgstr ""
+
+#: fortran/trans-intrinsic.cc:12390
+#, gcc-internal-format, gfc-internal-format
+msgid "The event variable at %L shall not be coindexed"
+msgstr ""
+
+#: fortran/trans-io.cc:1993
+#, gcc-internal-format
+msgid "build_dt: format with namelist"
+msgstr ""
+
+#: fortran/trans-io.cc:2534
+#, gcc-internal-format, gfc-internal-format
+msgid "Bad IO basetype (%d)"
+msgstr ""
+
+#: fortran/trans-openmp.cc:881 fortran/trans-openmp.cc:1398
+#, gcc-internal-format
+msgid "Sorry, polymorphic arrays not yet supported for firstprivate"
+msgstr ""
+
+#: fortran/trans-openmp.cc:1552
+#, gcc-internal-format
+msgid "implicit mapping of assumed size array %qD"
+msgstr ""
+
+#: fortran/trans-openmp.cc:3296
+#, gcc-internal-format
+msgid "optional class parameter"
+msgstr ""
+
+#: fortran/trans-openmp.cc:3712
+#, gcc-internal-format
+msgid "unhandled expression type"
+msgstr ""
+
+#: fortran/trans-openmp.cc:3992
+#, gcc-internal-format
+msgid "unhandled expression"
+msgstr ""
+
+#: fortran/trans-openmp.cc:4114
+#, gcc-internal-format
+msgid "%<uses_allocators%> clause with traits and memory spaces"
+msgstr ""
+
+#: fortran/trans-openmp.cc:5038
+#, gcc-internal-format
+msgid "%<!$OMP %s%> at %L requires %<-fopenmp-allocators%>"
+msgstr ""
+
+#: fortran/trans-openmp.cc:5041
+#, gcc-internal-format
+msgid "All files that might deallocate such a variable must be compiled with %<-fopenmp-allocators%>"
+msgstr ""
+
+#: fortran/trans-openmp.cc:5044
+#, gcc-internal-format
+msgid "This includes explicit DEALLOCATE, reallocation on intrinsic assignment, INTENT(OUT) for allocatable dummy arguments, and reallocation of allocatable components allocated with an OpenMP allocator"
+msgstr ""
+
+#: fortran/trans-openmp.cc:5621 fortran/trans-openmp.cc:5641
+#, gcc-internal-format
+msgid "non-rectangular loop nest with non-constant step for %qs"
+msgstr ""
+
+#: fortran/trans-openmp.cc:5643
+#, gcc-internal-format
+msgid "Used here"
+msgstr ""
+
+#: fortran/trans-openmp.cc:7165
+#, gcc-internal-format
+msgid "%qs specified in 'allocate' clause at %L but not in an explicit privatization clause"
+msgstr ""
+
+#: fortran/trans-openmp.cc:8065
+#, gcc-internal-format
+msgid "gfc_trans_omp_workshare(): Bad statement code"
+msgstr ""
+
+#: fortran/trans-openmp.cc:8368
+#, gcc-internal-format, gfc-internal-format
+msgid "The base name for 'declare variant' must be specified at %L "
+msgstr ""
+
+#: fortran/trans-openmp.cc:8378
+#, gcc-internal-format, gfc-internal-format
+msgid "The base name at %L does not match the name of the current procedure"
+msgstr ""
+
+#: fortran/trans-openmp.cc:8381
+#, gcc-internal-format, gfc-internal-format
+msgid "The base name at %L must not be an entry name"
+msgstr ""
+
+#: fortran/trans-openmp.cc:8384
+#, gcc-internal-format, gfc-internal-format
+msgid "The base name at %L must not be a generic name"
+msgstr ""
+
+#: fortran/trans-openmp.cc:8387
+#, gcc-internal-format, gfc-internal-format
+msgid "The base name at %L must not be a procedure pointer"
+msgstr ""
+
+#: fortran/trans-openmp.cc:8390
+#, gcc-internal-format, gfc-internal-format
+msgid "The base procedure at %L must have an explicit interface"
+msgstr ""
+
+#: fortran/trans-openmp.cc:8503
+#, gcc-internal-format
+msgid "Cannot find symbol %qs"
+msgstr ""
+
+#: fortran/trans-openmp.cc:8514
+#, gcc-internal-format
+msgid "variant %qs at %L is not a function or subroutine"
+msgstr ""
+
+#: fortran/trans-openmp.cc:8528
+#, gcc-internal-format
+msgid "variant %qs and base %qs at %L have incompatible types: %s"
+msgstr ""
+
+#: fortran/trans-stmt.cc:576
+#, gcc-internal-format, gfc-internal-format
+msgid "An alternate return at %L without a * dummy argument"
+msgstr ""
+
+#: fortran/trans-stmt.cc:908
+#, gcc-internal-format, gfc-internal-format
+msgid "Sorry, the lock component of derived type at %L is not yet supported"
+msgstr ""
+
+#: fortran/trans-stmt.cc:1367
+#, gcc-internal-format, gfc-internal-format
+msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
+msgstr ""
+
+#: fortran/trans-stmt.cc:3710
+#, gcc-internal-format
+msgid "gfc_trans_select(): Bad type for case expr."
+msgstr ""
+
+#: fortran/trans-types.cc:537
+#, gcc-internal-format
+msgid "%<-fconvert=r16_ieee%> or %<-fconvert=r16_ibm%> not supported on this architecture"
+msgstr ""
+
+#: fortran/trans-types.cc:550
+#, gcc-internal-format
+msgid "INTEGER(KIND=8) is not available for %<-fdefault-integer-8%> option"
+msgstr ""
+
+#: fortran/trans-types.cc:559
+#, gcc-internal-format
+msgid "INTEGER(KIND=8) is not available for %<-finteger-4-integer-8%> option"
+msgstr ""
+
+#: fortran/trans-types.cc:578
+#, gcc-internal-format
+msgid "REAL(KIND=8) is not available for %<-fdefault-real-8%> option"
+msgstr ""
+
+#: fortran/trans-types.cc:586
+#, gcc-internal-format
+msgid "REAL(KIND=10) is not available for %<-fdefault-real-10%> option"
+msgstr ""
+
+#: fortran/trans-types.cc:594
+#, gcc-internal-format
+msgid "REAL(KIND=16) is not available for %<-fdefault-real-16%> option"
+msgstr ""
+
+#: fortran/trans-types.cc:602
+#, gcc-internal-format
+msgid "REAL(KIND=8) is not available for %<-freal-4-real-8%> option"
+msgstr ""
+
+#: fortran/trans-types.cc:610
+#, gcc-internal-format
+msgid "REAL(KIND=10) is not available for %<-freal-4-real-10%> option"
+msgstr ""
+
+#: fortran/trans-types.cc:618
+#, gcc-internal-format
+msgid "REAL(KIND=16) is not available for %<-freal-4-real-16%> option"
+msgstr ""
+
+#: fortran/trans-types.cc:649
+#, gcc-internal-format
+msgid "REAL(KIND=4) is not available for %<-freal-8-real-4%> option"
+msgstr ""
+
+#: fortran/trans-types.cc:657
+#, gcc-internal-format
+msgid "REAL(KIND=10) is not available for %<-freal-8-real-10%> option"
+msgstr ""
+
+#: fortran/trans-types.cc:665
+#, gcc-internal-format
+msgid "REAL(KIND=10) is not available for %<-freal-8-real-16%> option"
+msgstr ""
+
+#: fortran/trans-types.cc:807
+#, gcc-internal-format
+msgid "gfc_validate_kind(): Got bad type"
+msgstr ""
+
+#: fortran/trans-types.cc:811
+#, gcc-internal-format
+msgid "gfc_validate_kind(): Got bad kind"
+msgstr ""
+
+#: fortran/trans.cc:2683
+#, gcc-internal-format
+msgid "gfc_trans_code(): Bad statement code"
+msgstr ""
+
+#: go/gofrontend/embed.cc:278
+#, gcc-internal-format
+msgid "invalid embedcfg: not a JSON object"
+msgstr ""
+
+#: go/gofrontend/embed.cc:285
+#, gcc-internal-format
+msgid "invalid embedcfg: missing Patterns"
+msgstr ""
+
+#: go/gofrontend/embed.cc:290
+#, gcc-internal-format
+msgid "invalid embedcfg: Patterns is not a JSON object"
+msgstr ""
+
+#: go/gofrontend/embed.cc:297
+#, gcc-internal-format
+msgid "invalid embedcfg: missing Files"
+msgstr ""
+
+#: go/gofrontend/embed.cc:302
+#, gcc-internal-format
+msgid "invalid embedcfg: Files is not a JSON object"
+msgstr ""
+
+#: go/gofrontend/embed.cc:312
+#, gcc-internal-format
+msgid "invalid embedcfg: Patterns entry is not an array"
+msgstr ""
+
+#: go/gofrontend/embed.cc:324
+#, gcc-internal-format
+msgid "invalid embedcfg: duplicate Patterns entry"
+msgstr ""
+
+#: go/gofrontend/embed.cc:336
+#, gcc-internal-format
+msgid "invalid embedcfg: Files entry is not a string"
+msgstr ""
+
+#: go/gofrontend/embed.cc:354
+#, gcc-internal-format
+msgid "empty file"
+msgstr ""
+
+#: go/gofrontend/embed.cc:392 go/gofrontend/embed.cc:521
+#, gcc-internal-format
+msgid "expected %<\"%>"
+msgstr ""
+
+#: go/gofrontend/embed.cc:475
+#, gcc-internal-format
+msgid "expected %<,%> or %<]%>"
+msgstr ""
+
+#: go/gofrontend/embed.cc:507
+#, gcc-internal-format
+msgid "invalid JSON syntax"
+msgstr ""
+
+#: go/gofrontend/embed.cc:539 go/gofrontend/embed.cc:582
+#: go/gofrontend/embed.cc:616
+#, gcc-internal-format
+msgid "unterminated string"
+msgstr "დაუსრულებელი სტრიქონი"
+
+#: go/gofrontend/embed.cc:596
+#, gcc-internal-format
+msgid "invalid hex digit"
+msgstr ""
+
+#: go/gofrontend/embed.cc:605
+#, gcc-internal-format
+msgid "unrecognized string escape"
+msgstr ""
+
+#: go/gofrontend/embed.cc:626
+#, gcc-internal-format
+msgid "extraneous data at end of file"
+msgstr ""
+
+#: go/gofrontend/embed.cc:646
+#, gcc-internal-format
+msgid "unexpected EOF"
+msgstr ""
+
+#: lto/lto-common.cc:2030
+#, gcc-internal-format
+msgid "bytecode stream: garbage at the end of symbols section"
+msgstr ""
+
+#: lto/lto-common.cc:2057
+#, gcc-internal-format
+msgid "could not parse hex number"
+msgstr ""
+
+#: lto/lto-common.cc:2089
+#, gcc-internal-format, gfc-internal-format
+msgid "unexpected file name %s in linker resolution file. Expected %s"
+msgstr ""
+
+#: lto/lto-common.cc:2098
+#, gcc-internal-format
+msgid "could not parse file offset"
+msgstr ""
+
+#: lto/lto-common.cc:2101
+#, gcc-internal-format
+msgid "unexpected offset"
+msgstr ""
+
+#: lto/lto-common.cc:2122
+#, gcc-internal-format
+msgid "invalid line in the resolution file"
+msgstr ""
+
+#: lto/lto-common.cc:2144
+#, gcc-internal-format
+msgid "invalid resolution in the resolution file"
+msgstr ""
+
+#: lto/lto-common.cc:2150
+#, gcc-internal-format
+msgid "resolution sub id %wx not in object file"
+msgstr ""
+
+#: lto/lto-common.cc:2267
+#, gcc-internal-format
+msgid "bytecode stream in file %qs generated with GCC compiler older than 10.0"
+msgstr ""
+
+#: lto/lto-common.cc:2287
+#, gcc-internal-format
+msgid "cannot read %<LTO_section_decls%> from %s"
+msgstr ""
+
+#: lto/lto-common.cc:2408
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot open %s"
+msgstr ""
+
+#: lto/lto-common.cc:2429
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot map %s"
+msgstr ""
+
+#: lto/lto-common.cc:2440
+#, gcc-internal-format, gfc-internal-format
+msgid "Cannot read %s"
+msgstr ""
+
+#: lto/lto-common.cc:2757
+#, gcc-internal-format
+msgid "could not open symbol resolution file: %m"
+msgstr ""
+
+#: lto/lto-common.cc:2882
+#, gcc-internal-format, gfc-internal-format
+msgid "missing resolution data for %s"
+msgstr ""
+
+#: lto/lto-common.cc:2919
+#, gcc-internal-format
+msgid "errors during merging of translation units"
+msgstr ""
+
+#: lto/lto-dump.cc:256
+#, gcc-internal-format
+msgid "Level not found, use none, slim, blocks, vops."
+msgstr ""
+
+#: lto/lto-dump.cc:270
+#, gcc-internal-format
+msgid "Function not found."
+msgstr ""
+
+#: lto/lto-dump.cc:349 lto/lto-dump.cc:359
+#, gcc-internal-format
+msgid "Not configured with %<--enable-gather-detailed-mem-stats%>."
+msgstr ""
+
+#: lto/lto-lang.cc:324
+#, gcc-internal-format
+msgid "%s:%s: %E: %E"
+msgstr ""
+
+#: lto/lto-lang.cc:879
+#, gcc-internal-format
+msgid "%<-fwpa%> and %<-fltrans%> are mutually exclusive"
+msgstr ""
+
+#: lto/lto-lang.cc:913
+#, gcc-internal-format
+msgid "%<-flinker-output=rel%> and %<-fltrans%> are mutually exclusive"
+msgstr ""
+
+#: lto/lto-object.cc:106
+#, gcc-internal-format, gfc-internal-format
+msgid "open %s failed: %s"
+msgstr ""
+
+#: lto/lto-object.cc:150
+#, gcc-internal-format, gfc-internal-format
+msgid "%s: %s: %s"
+msgstr ""
+
+#: lto/lto-object.cc:191
+#, gcc-internal-format, gfc-internal-format
+msgid "close: %s"
+msgstr ""
+
+#: lto/lto-object.cc:247
+#, gcc-internal-format, gfc-internal-format
+msgid "two or more sections for %s"
+msgstr ""
+
+#: lto/lto-partition.cc:535
+#, gcc-internal-format
+msgid "min partition size cannot be greater than max partition size"
+msgstr ""
+
+#: lto/lto-symtab.cc:169
+#, gcc-internal-format
+msgid "%qD is defined with tls model %s"
+msgstr ""
+
+#: lto/lto-symtab.cc:171
+#, gcc-internal-format, gfc-internal-format
+msgid "previously defined here as %s"
+msgstr ""
+
+#: lto/lto-symtab.cc:474
+#, gcc-internal-format
+msgid "multiple prevailing defs for %qE"
+msgstr ""
+
+#: lto/lto-symtab.cc:492
+#, gcc-internal-format
+msgid "%qD has already been defined"
+msgstr ""
+
+#: lto/lto-symtab.cc:494
+#, gcc-internal-format
+msgid "previously defined here"
+msgstr "ადრე აქ იყო აღწერილი"
+
+#: lto/lto-symtab.cc:720
+#, gcc-internal-format
+msgid "%qD violates the C++ One Definition Rule"
+msgstr ""
+
+#: lto/lto-symtab.cc:726
+#, gcc-internal-format
+msgid "type of %qD does not match original declaration"
+msgstr ""
+
+#: lto/lto-symtab.cc:746
+#, gcc-internal-format
+msgid "alignment of %qD is bigger than original declaration"
+msgstr ""
+
+#: lto/lto-symtab.cc:752
+#, gcc-internal-format
+msgid "size of %qD differ from the size of original declaration"
+msgstr ""
+
+#: lto/lto-symtab.cc:757
+#, gcc-internal-format
+msgid "%qD was previously declared here"
+msgstr ""
+
+#: lto/lto-symtab.cc:760
+#, gcc-internal-format
+msgid "code may be misoptimized unless %<-fno-strict-aliasing%> is used"
+msgstr ""
+
+#: lto/lto-symtab.cc:846
+#, gcc-internal-format
+msgid "variable %qD redeclared as function"
+msgstr ""
+
+#: lto/lto-symtab.cc:853
+#, gcc-internal-format
+msgid "function %qD redeclared as variable"
+msgstr ""
+
+#: lto/lto-symtab.cc:865
+#, gcc-internal-format
+msgid "previously declared here"
+msgstr ""
+
+#: lto/lto.cc:174
+#, gcc-internal-format
+msgid "%<lto_obj_file_open()%> failed"
+msgstr ""
+
+#: lto/lto.cc:206
+#, gcc-internal-format
+msgid "waitpid failed"
+msgstr "waitpid -ის შეცდომა"
+
+#: lto/lto.cc:209
+#, gcc-internal-format
+msgid "streaming subprocess failed"
+msgstr ""
+
+#: lto/lto.cc:212
+#, gcc-internal-format
+msgid "streaming subprocess was killed by signal"
+msgstr ""
+
+#: lto/lto.cc:319
+#, gcc-internal-format
+msgid "no LTRANS output list filename provided"
+msgstr ""
+
+#: lto/lto.cc:427
+#, gcc-internal-format
+msgid "opening LTRANS output list %s: %m"
+msgstr ""
+
+#: lto/lto.cc:434
+#, gcc-internal-format
+msgid "writing to LTRANS output list %s: %m"
+msgstr ""
+
+#: lto/lto.cc:444
+#, gcc-internal-format
+msgid "closing LTRANS output list %s: %m"
+msgstr ""
+
+#: m2/gm2-lang.cc:1137
+#, gcc-internal-format
+msgid "cannot convert expression, only base types can be converted"
+msgstr ""
+
+#. Not found, probably a user typo.
+#: m2/gm2spec.cc:346
+#, gcc-internal-format
+msgid "%qs is not a valid Modula-2 system library name or abbreviation"
+msgstr ""
+
+#: m2/gm2spec.cc:724 m2/gm2spec.cc:732
+#, gcc-internal-format
+msgid "%qs and %qs cannot both be enabled"
+msgstr ""
+
+#: m2/gm2-gcc/m2assert.cc:40
+#, gcc-internal-format
+msgid "the location value is corrupt"
+msgstr ""
+
+#: m2/gm2-gcc/m2builtins.cc:46
+#, gcc-internal-format
+msgid "%s:%d:assertion of condition %qs failed"
+msgstr ""
+
+#: m2/gm2-gcc/m2builtins.cc:52
+#, gcc-internal-format, gfc-internal-format
+msgid "%s:%d:%s"
+msgstr ""
+
+#: m2/gm2-gcc/m2convert.cc:111
+#, gcc-internal-format
+msgid "negative integer implicitly converted to unsigned type"
+msgstr ""
+
+#: m2/gm2-gcc/m2convert.cc:118
+#, gcc-internal-format
+msgid "conversion of unsigned constant value to negative integer"
+msgstr ""
+
+#: m2/gm2-gcc/m2convert.cc:199 m2/gm2-gcc/m2convert.cc:203
+#, gcc-internal-format
+msgid "conversion to %qT alters %qT constant value"
+msgstr ""
+
+#: m2/gm2-gcc/m2convert.cc:224 m2/gm2-gcc/m2convert.cc:228
+#, gcc-internal-format
+msgid "conversion to %qT from %qT may alter its value"
+msgstr ""
+
+#: m2/gm2-gcc/m2convert.cc:260
+#, gcc-internal-format
+msgid "large integer implicitly truncated to unsigned type"
+msgstr ""
+
+#: m2/gm2-gcc/m2convert.cc:266 m2/gm2-gcc/m2convert.cc:272
+#: m2/gm2-gcc/m2convert.cc:281
+#, gcc-internal-format
+msgid "overflow in implicit constant conversion"
+msgstr ""
+
+#: m2/gm2-gcc/m2decl.cc:122
+#, gcc-internal-format
+msgid "storage size of %qD has not been resolved"
+msgstr ""
+
+#: m2/gm2-gcc/m2decl.cc:125
+#, gcc-internal-format
+msgid "inconsistent because %qs"
+msgstr ""
+
+#: m2/gm2-gcc/m2decl.cc:312
+#, gcc-internal-format
+msgid "constant %qs is too large"
+msgstr ""
+
+#: m2/gm2-gcc/m2expr.cc:2617
+#, gcc-internal-format
+msgid "not expecting different types to binary operator"
+msgstr ""
+
+#: m2/gm2-gcc/m2expr.cc:2875
+#, gcc-internal-format
+msgid "cannot take the address of this expression"
+msgstr ""
+
+#: m2/gm2-gcc/m2expr.cc:3642
+#, gcc-internal-format
+msgid "argument to CAP is not a constant or variable of type CHAR"
+msgstr ""
+
+#: m2/gm2-gcc/m2expr.cc:3922 m2/gm2-gcc/m2expr.cc:4028
+#: m2/gm2-gcc/m2expr.cc:4037
+#, gcc-internal-format
+msgid "constant literal %qs exceeds internal ZTYPE range"
+msgstr ""
+
+#: m2/gm2-gcc/m2expr.cc:3957
+#, gcc-internal-format
+msgid "constant literal %qs contains %qc, expected 0 or 1"
+msgstr ""
+
+#: m2/gm2-gcc/m2expr.cc:3972 m2/gm2-gcc/m2expr.cc:3984
+#, gcc-internal-format
+msgid "constant literal %qs contains %qc, expected %qs"
+msgstr ""
+
+#: m2/gm2-gcc/m2expr.cc:4003
+#, gcc-internal-format
+msgid "constant literal %qs contains %qc, expected %qs or %qs"
+msgstr ""
+
+#: m2/gm2-gcc/m2expr.cc:4069
+#, gcc-internal-format
+msgid "%qs applied to a void type"
+msgstr ""
+
+#: m2/gm2-gcc/m2expr.cc:4090 m2/gm2-gcc/m2expr.cc:4134
+#, gcc-internal-format
+msgid "%qs applied to an incomplete type"
+msgstr ""
+
+#: m2/gm2-gcc/m2linemap.cc:332
+#, gcc-internal-format
+msgid "memory allocation failed in vasprintf"
+msgstr ""
+
+#: m2/gm2-gcc/m2linemap.cc:364 rust/rust-diagnostics.cc:166
+#, gcc-internal-format, gfc-internal-format
+msgid "at %s, %s"
+msgstr ""
+
+#: m2/gm2-gcc/m2statement.cc:563
+#, gcc-internal-format
+msgid "internal error: not expecting operand1 to be a constant set"
+msgstr ""
+
+#: m2/gm2-gcc/m2statement.cc:957
+#, gcc-internal-format
+msgid "expecting one and only one label to be declared"
+msgstr ""
+
+#: m2/gm2-gcc/m2treelib.cc:286
+#, gcc-internal-format
+msgid "field number exceeds definition of set"
+msgstr ""
+
+#: m2/gm2-gcc/m2treelib.cc:291
+#, gcc-internal-format
+msgid "field number out of range trying to access set element"
+msgstr ""
+
+#: m2/gm2-gcc/m2type.cc:224
+#, gcc-internal-format
+msgid "array declaration canonicalization has failed"
+msgstr ""
+
+#: m2/gm2-gcc/m2type.cc:315
+#, gcc-internal-format
+msgid "low bound for the array is outside the ztype limits"
+msgstr ""
+
+#: m2/gm2-gcc/m2type.cc:317
+#, gcc-internal-format
+msgid "high bound for the array is outside the ztype limits"
+msgstr ""
+
+#: m2/gm2-gcc/m2type.cc:909
+#, gcc-internal-format
+msgid "set base type must be an ordinal type"
+msgstr ""
+
+#: m2/gm2-gcc/m2type.cc:938
+#, gcc-internal-format
+msgid "ordinal type expected"
+msgstr ""
+
+#: m2/gm2-gcc/m2type.cc:947
+#, gcc-internal-format
+msgid "range limits are not of the same type"
+msgstr ""
+
+#. This enum is a named one that has been declared already.
+#: m2/gm2-gcc/m2type.cc:1989
+#, gcc-internal-format
+msgid "redeclaration of enum %qs"
+msgstr ""
+
+#: m2/gm2-gcc/m2type.cc:2055
+#, gcc-internal-format
+msgid "enumeration values exceed range of integer"
+msgstr ""
+
+#: m2/gm2-gcc/m2type.cc:2289
+#, gcc-internal-format
+msgid "set type cannot be initialized with a %qs"
+msgstr ""
+
+#: m2/gm2-gcc/m2type.cc:2296
+#, gcc-internal-format
+msgid "set type does not take another integer value"
+msgstr ""
+
+#: m2/gm2-gcc/m2type.cc:2421
+#, gcc-internal-format
+msgid "array cannot be initialized with a %qs"
+msgstr ""
+
+#: m2/gm2-gcc/m2type.cc:2427
+#, gcc-internal-format
+msgid "array type must be initialized"
+msgstr ""
+
+#: m2/gm2-gcc/m2type.cc:2434
+#, gcc-internal-format
+msgid "array element value must be the same type as its declaration"
+msgstr ""
+
+#: m2/gm2-gcc/m2type.cc:2497
+#, gcc-internal-format
+msgid "low bound for the subrange has overflowed"
+msgstr ""
+
+#: m2/gm2-gcc/m2type.cc:2499
+#, gcc-internal-format
+msgid "high bound for the subrange has overflowed"
+msgstr ""
+
+#: m2/gm2-gcc/m2type.cc:2796
+#, gcc-internal-format
+msgid "requested alignment is not a constant"
+msgstr ""
+
+#: m2/gm2-gcc/m2type.cc:2798
+#, gcc-internal-format
+msgid "requested alignment is not a power of 2"
+msgstr ""
+
+#: m2/gm2-gcc/m2type.cc:2800
+#, gcc-internal-format
+msgid "requested alignment is too large"
+msgstr ""
+
+#: m2/gm2-gcc/m2type.cc:2826
+#, gcc-internal-format
+msgid "alignment may not be specified for %qD"
+msgstr ""
+
+#: objc/objc-act.cc:426 objc/objc-act.cc:6965
+#, gcc-internal-format
+msgid "%<@end%> missing in implementation context"
+msgstr ""
+
+#: objc/objc-act.cc:579
+#, gcc-internal-format
+msgid "class attributes are not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.cc:594
+#, gcc-internal-format
+msgid "category attributes are not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.cc:597
+#, gcc-internal-format
+msgid "category attributes are not available in this version of the compiler, (ignored)"
+msgstr ""
+
+#: objc/objc-act.cc:603
+#, gcc-internal-format
+msgid "class extensions are not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.cc:617
+#, gcc-internal-format
+msgid "class extension for class %qE declared after its %<@implementation%>"
+msgstr ""
+
+#: objc/objc-act.cc:632
+#, gcc-internal-format
+msgid "protocol attributes are not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.cc:697
+#, gcc-internal-format
+msgid "%<@end%> must appear in an @implementation context"
+msgstr ""
+
+#: objc/objc-act.cc:706
+#, gcc-internal-format
+msgid "%<@package%> is not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.cc:708
+#, gcc-internal-format
+msgid "%<@package%> presently has the same effect as %<@public%>"
+msgstr ""
+
+#: objc/objc-act.cc:719
+#, gcc-internal-format
+msgid "%<@optional%> is not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.cc:721
+#, gcc-internal-format
+msgid "%<@required%> is not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.cc:729
+#, gcc-internal-format
+msgid "%<@optional%> is allowed in @protocol context only"
+msgstr ""
+
+#: objc/objc-act.cc:731
+#, gcc-internal-format
+msgid "%<@required%> is allowed in @protocol context only"
+msgstr ""
+
+#. FIXME: we probably ought to bail out at this point.
+#: objc/objc-act.cc:854
+#, gcc-internal-format
+msgid "%<@property%> is not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.cc:859
+#, gcc-internal-format
+msgid "property declaration not in %<@interface%>, %<@protocol%> or %<category%> context"
+msgstr ""
+
+#: objc/objc-act.cc:870
+#, gcc-internal-format
+msgid "properties must be named"
+msgstr ""
+
+#: objc/objc-act.cc:878
+#, gcc-internal-format
+msgid "property cannot be an array"
+msgstr ""
+
+#. A @property is not an actual variable, but it is a way to
+#. describe a pair of accessor methods, so its type (which is
+#. the type of the return value of the getter and the first
+#. argument of the setter) can't be a bitfield (as return values
+#. and arguments of functions cannot be bitfields).  The
+#. underlying instance variable could be a bitfield, but that is
+#. a different matter.
+#: objc/objc-act.cc:891
+#, gcc-internal-format
+msgid "property cannot be a bit-field"
+msgstr ""
+
+#: objc/objc-act.cc:915
+#, gcc-internal-format
+msgid "multiple property %qE methods specified, the latest one will be used"
+msgstr ""
+
+#: objc/objc-act.cc:917
+#, gcc-internal-format
+msgid "previous specification"
+msgstr ""
+
+#: objc/objc-act.cc:932
+#, gcc-internal-format
+msgid "%qE attribute conflicts with %qE attribute"
+msgstr ""
+
+#: objc/objc-act.cc:934
+#, gcc-internal-format
+msgid "%qE specified here"
+msgstr ""
+
+#: objc/objc-act.cc:940
+#, gcc-internal-format
+msgid "duplicate %qE attribute"
+msgstr ""
+
+#: objc/objc-act.cc:941
+#, gcc-internal-format
+msgid "first specified here"
+msgstr ""
+
+#: objc/objc-act.cc:968
+#, gcc-internal-format
+msgid "%<readonly%> attribute conflicts with %<setter%> attribute"
+msgstr ""
+
+#: objc/objc-act.cc:971
+#, gcc-internal-format
+msgid "%<setter%> specified here"
+msgstr ""
+
+#: objc/objc-act.cc:1050
+#, gcc-internal-format
+msgid "object property %qD has no %<assign%>, %<retain%> or %<copy%> attribute; assuming %<assign%>"
+msgstr ""
+
+#: objc/objc-act.cc:1053
+#, gcc-internal-format
+msgid "%<assign%> can be unsafe for Objective-C objects; please state explicitly if you need it"
+msgstr ""
+
+#: objc/objc-act.cc:1070
+#, gcc-internal-format
+msgid "%qE attribute is only valid for Objective-C objects"
+msgstr ""
+
+#: objc/objc-act.cc:1128
+#, gcc-internal-format
+msgid "redeclaration of property %qD"
+msgstr ""
+
+#: objc/objc-act.cc:1131 objc/objc-act.cc:1197 objc/objc-act.cc:1208
+#: objc/objc-act.cc:1222 objc/objc-act.cc:1233 objc/objc-act.cc:1245
+#: objc/objc-act.cc:1282 objc/objc-act.cc:7752 objc/objc-act.cc:7815
+#: objc/objc-act.cc:7838 objc/objc-act.cc:7852 objc/objc-act.cc:7870
+#: objc/objc-act.cc:7969
+#, gcc-internal-format
+msgid "originally specified here"
+msgstr ""
+
+#: objc/objc-act.cc:1193
+#, gcc-internal-format
+msgid "%<nonatomic%> attribute of property %qD conflicts with previous declaration"
+msgstr ""
+
+#: objc/objc-act.cc:1204
+#, gcc-internal-format
+msgid "%<getter%> attribute of property %qD conflicts with previous declaration"
+msgstr ""
+
+#: objc/objc-act.cc:1218
+#, gcc-internal-format
+msgid "%<setter%> attribute of property %qD conflicts with previous declaration"
+msgstr ""
+
+#: objc/objc-act.cc:1230
+#, gcc-internal-format
+msgid "assign semantics attributes of property %qD conflict with previous declaration"
+msgstr ""
+
+#: objc/objc-act.cc:1241
+#, gcc-internal-format
+msgid "%<readonly%> attribute of property %qD conflicts with previous declaration"
+msgstr ""
+
+#: objc/objc-act.cc:1280
+#, gcc-internal-format
+msgid "type of property %qD conflicts with previous declaration"
+msgstr ""
+
+#: objc/objc-act.cc:1323
+#, gcc-internal-format
+msgid "nullability specifier %qE cannot be applied to non-pointer type %qT"
+msgstr ""
+
+#: objc/objc-act.cc:1328
+#, gcc-internal-format
+msgid "nullability specifier %qE cannot be applied to multi-level pointer type %qT"
+msgstr ""
+
+#: objc/objc-act.cc:1781
+#, gcc-internal-format
+msgid "the dot syntax is not available in Objective-C 1.0"
+msgstr ""
+
+#. We know that 'class_name' is an Objective-C class name as the
+#. parser won't call this function if it is not.  This is only a
+#. double-check for safety.
+#: objc/objc-act.cc:1797
+#, gcc-internal-format
+msgid "could not find class %qE"
+msgstr ""
+
+#. Again, this should never happen, but we do check.
+#: objc/objc-act.cc:1805
+#, gcc-internal-format
+msgid "could not find interface for class %qE"
+msgstr ""
+
+#: objc/objc-act.cc:1811 objc/objc-act.cc:7147
+#, gcc-internal-format
+msgid "class %qE is unavailable"
+msgstr ""
+
+#: objc/objc-act.cc:1813 objc/objc-act.cc:7004 objc/objc-act.cc:7149
+#, gcc-internal-format
+msgid "class %qE is deprecated"
+msgstr ""
+
+#: objc/objc-act.cc:1842
+#, gcc-internal-format
+msgid "could not find setter/getter for %qE in class %qE"
+msgstr ""
+
+#: objc/objc-act.cc:1892
+#, gcc-internal-format
+msgid "%qs property cannot be set"
+msgstr ""
+
+#: objc/objc-act.cc:2160
+#, gcc-internal-format
+msgid "method declaration not in @interface context"
+msgstr ""
+
+#: objc/objc-act.cc:2164
+#, gcc-internal-format
+msgid "method attributes are not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.cc:2184
+#, gcc-internal-format
+msgid "method definition not in @implementation context"
+msgstr ""
+
+#: objc/objc-act.cc:2197
+#, gcc-internal-format
+msgid "method attributes cannot be specified in @implementation context"
+msgstr ""
+
+#: objc/objc-act.cc:2427
+#, gcc-internal-format
+msgid "class %qs does not implement the %qE protocol"
+msgstr ""
+
+#: objc/objc-act.cc:2430
+#, gcc-internal-format
+msgid "type %qs does not conform to the %qE protocol"
+msgstr ""
+
+#: objc/objc-act.cc:2725
+#, gcc-internal-format
+msgid "comparison of distinct Objective-C types lacks a cast"
+msgstr ""
+
+#: objc/objc-act.cc:2729
+#, gcc-internal-format
+msgid "initialization from distinct Objective-C type"
+msgstr ""
+
+#: objc/objc-act.cc:2733
+#, gcc-internal-format
+msgid "assignment from distinct Objective-C type"
+msgstr ""
+
+#: objc/objc-act.cc:2737
+#, gcc-internal-format
+msgid "distinct Objective-C type in return"
+msgstr ""
+
+#: objc/objc-act.cc:2741
+#, gcc-internal-format
+msgid "passing argument %d of %qE from distinct Objective-C type"
+msgstr ""
+
+#: objc/objc-act.cc:2884
+#, gcc-internal-format
+msgid "statically allocated instance of Objective-C class %qE"
+msgstr ""
+
+#: objc/objc-act.cc:2893
+#, gcc-internal-format
+msgid "redeclaration of Objective-C class %qs"
+msgstr ""
+
+#. This case happens when we are given an 'interface' which
+#. is not a valid class name.  For example if a typedef was
+#. used, and 'interface' really is the identifier of the
+#. typedef, but when you resolve it you don't get an
+#. Objective-C class, but something else, such as 'int'.
+#. This is an error; protocols make no sense unless you use
+#. them with Objective-C objects.
+#: objc/objc-act.cc:2935
+#, gcc-internal-format
+msgid "only Objective-C object types can be qualified with a protocol"
+msgstr ""
+
+#: objc/objc-act.cc:2999
+#, gcc-internal-format
+msgid "protocol %qE has circular dependency"
+msgstr ""
+
+#: objc/objc-act.cc:3032 objc/objc-act.cc:5866
+#, gcc-internal-format
+msgid "cannot find protocol declaration for %qE"
+msgstr ""
+
+#: objc/objc-act.cc:3342 objc/objc-act.cc:3997 objc/objc-act.cc:6578
+#: objc/objc-act.cc:7055 objc/objc-act.cc:7140 objc/objc-act.cc:7195
+#, gcc-internal-format
+msgid "cannot find interface declaration for %qE"
+msgstr ""
+
+#: objc/objc-act.cc:3346
+#, gcc-internal-format
+msgid "interface %qE does not have valid constant string layout"
+msgstr ""
+
+#: objc/objc-act.cc:3351
+#, gcc-internal-format
+msgid "cannot find reference tag for class %qE"
+msgstr ""
+
+#: objc/objc-act.cc:3496
+#, gcc-internal-format
+msgid "%qE is not an Objective-C class name or alias"
+msgstr ""
+
+#: objc/objc-act.cc:3511 objc/objc-act.cc:3542 objc/objc-act.cc:6959
+#: objc/objc-act.cc:8305 objc/objc-act.cc:8361
+#, gcc-internal-format
+msgid "Objective-C declarations may only appear in global scope"
+msgstr ""
+
+#: objc/objc-act.cc:3516
+#, gcc-internal-format
+msgid "cannot find class %qE"
+msgstr ""
+
+#: objc/objc-act.cc:3518
+#, gcc-internal-format
+msgid "class %qE already exists"
+msgstr ""
+
+#: objc/objc-act.cc:3560 objc/objc-act.cc:7020
+#, gcc-internal-format
+msgid "%qE redeclared as different kind of symbol"
+msgstr ""
+
+#: objc/objc-act.cc:3562 objc/objc-act.cc:4148 objc/objc-act.cc:4176
+#: objc/objc-act.cc:4231 objc/objc-act.cc:7022
+#, gcc-internal-format
+msgid "previous declaration of %q+D"
+msgstr ""
+
+#: objc/objc-act.cc:3851
+#, gcc-internal-format
+msgid "strong-cast assignment has been intercepted"
+msgstr ""
+
+#: objc/objc-act.cc:3893
+#, gcc-internal-format
+msgid "strong-cast may possibly be needed"
+msgstr ""
+
+#: objc/objc-act.cc:3903
+#, gcc-internal-format
+msgid "instance variable assignment has been intercepted"
+msgstr ""
+
+#: objc/objc-act.cc:3922
+#, gcc-internal-format
+msgid "pointer arithmetic for garbage-collected objects not allowed"
+msgstr ""
+
+#: objc/objc-act.cc:3928
+#, gcc-internal-format
+msgid "global/static variable assignment has been intercepted"
+msgstr ""
+
+#: objc/objc-act.cc:4145 objc/objc-act.cc:4173 objc/objc-act.cc:4228
+#, gcc-internal-format
+msgid "duplicate instance variable %q+D"
+msgstr ""
+
+#: objc/objc-act.cc:4288
+#, gcc-internal-format
+msgid "%<-fobjc-exceptions%> is required to enable Objective-C exception syntax"
+msgstr ""
+
+#: objc/objc-act.cc:4372
+#, gcc-internal-format
+msgid "%<@catch%> parameter is not a known Objective-C class type"
+msgstr ""
+
+#: objc/objc-act.cc:4378
+#, gcc-internal-format
+msgid "%<@catch%> parameter cannot be protocol-qualified"
+msgstr ""
+
+#: objc/objc-act.cc:4423
+#, gcc-internal-format
+msgid "exception of type %<%T%> will be caught"
+msgstr ""
+
+#: objc/objc-act.cc:4425
+#, gcc-internal-format
+msgid "   by earlier handler for %<%T%>"
+msgstr ""
+
+#: objc/objc-act.cc:4472
+#, gcc-internal-format
+msgid "%<@try%> without %<@catch%> or %<@finally%>"
+msgstr ""
+
+#: objc/objc-act.cc:4501
+#, gcc-internal-format
+msgid "%<@throw%> (rethrow) used outside of a %<@catch%> block"
+msgstr ""
+
+#: objc/objc-act.cc:4514
+#, gcc-internal-format
+msgid "%<@throw%> argument is not an object"
+msgstr ""
+
+#: objc/objc-act.cc:4535
+#, gcc-internal-format
+msgid "%<@synchronized%> argument is not an object"
+msgstr ""
+
+#: objc/objc-act.cc:4745
+#, gcc-internal-format
+msgid "%s %qs"
+msgstr ""
+
+#: objc/objc-act.cc:4768 objc/objc-act.cc:4793
+#, gcc-internal-format
+msgid "inconsistent instance variable specification"
+msgstr ""
+
+#: objc/objc-act.cc:4848
+#, gcc-internal-format
+msgid "cannot use an object as parameter to a method"
+msgstr ""
+
+#: objc/objc-act.cc:4892
+#, gcc-internal-format
+msgid "method argument attributes are not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.cc:5267
+#, gcc-internal-format
+msgid "multiple methods named %<%c%E%> found"
+msgstr ""
+
+#: objc/objc-act.cc:5270
+#, gcc-internal-format
+msgid "using %<%c%s%>"
+msgstr ""
+
+#: objc/objc-act.cc:5279
+#, gcc-internal-format
+msgid "multiple selectors named %<%c%E%> found"
+msgstr ""
+
+#: objc/objc-act.cc:5282
+#, gcc-internal-format
+msgid "found %<%c%s%>"
+msgstr ""
+
+#: objc/objc-act.cc:5291
+#, gcc-internal-format
+msgid "also found %<%c%s%>"
+msgstr ""
+
+#. If 'rtype' is NULL_TREE at this point it means that
+#. we have seen no @interface corresponding to that
+#. class name, only a @class declaration (alternatively,
+#. this was a call such as [objc_getClass("SomeClass")
+#. alloc], where we've never seen the @interface of
+#. SomeClass).  So, we have a class name (class_tree)
+#. but no actual details of the class methods.  We won't
+#. be able to check that the class responds to the
+#. method, and we will have to guess the method
+#. prototype.  Emit a warning, then keep going (this
+#. will use any method with a matching name, as if the
+#. receiver was of type 'Class').
+#. We could not find an @interface declaration, and
+#. there are no protocols attached to the receiver,
+#. so we can't complete the check that the receiver
+#. responds to the method, and we can't retrieve the
+#. method prototype.  But, because the receiver has
+#. a well-specified class, the programmer did want
+#. this check to be performed.  Emit a warning, then
+#. keep going as if it was an 'id'.  To remove the
+#. warning, either include an @interface for the
+#. class, or cast the receiver to 'id'.  Note that
+#. rtype is an IDENTIFIER_NODE at this point.
+#: objc/objc-act.cc:5579 objc/objc-act.cc:5714
+#, gcc-internal-format
+msgid "%<@interface%> of class %qE not found"
+msgstr ""
+
+#: objc/objc-act.cc:5588
+#, gcc-internal-format
+msgid "no super class declared in @interface for %qE"
+msgstr ""
+
+#: objc/objc-act.cc:5639
+#, gcc-internal-format
+msgid "found %<-%E%> instead of %<+%E%> in protocol(s)"
+msgstr ""
+
+#. We have a type, but it's not an Objective-C type (!).
+#: objc/objc-act.cc:5751
+#, gcc-internal-format
+msgid "invalid receiver type %qs"
+msgstr ""
+
+#: objc/objc-act.cc:5768
+#, gcc-internal-format
+msgid "%<%c%E%> not found in protocol(s)"
+msgstr ""
+
+#: objc/objc-act.cc:5782
+#, gcc-internal-format
+msgid "%qE may not respond to %<%c%E%>"
+msgstr ""
+
+#: objc/objc-act.cc:5790
+#, gcc-internal-format
+msgid "no %<%c%E%> method found"
+msgstr ""
+
+#: objc/objc-act.cc:5797
+#, gcc-internal-format
+msgid "(messages without a matching method signature will be assumed to return %<id%> and accept %<...%> as arguments)"
+msgstr ""
+
+#: objc/objc-act.cc:5915
+#, gcc-internal-format
+msgid "undeclared selector %qE"
+msgstr ""
+
+#. Historically, a class method that produced objects (factory
+#. method) would assign `self' to the instance that it
+#. allocated.  This would effectively turn the class method into
+#. an instance method.  Following this assignment, the instance
+#. variables could be accessed.  That practice, while safe,
+#. violates the simple rule that a class method should not refer
+#. to an instance variable.  It's better to catch the cases
+#. where this is done unknowingly than to support the above
+#. paradigm.
+#: objc/objc-act.cc:5939
+#, gcc-internal-format
+msgid "instance variable %qE accessed in class method"
+msgstr ""
+
+#: objc/objc-act.cc:6169 objc/objc-act.cc:6189
+#, gcc-internal-format
+msgid "method %<%c%E%> declared %<@optional%> and %<@required%> at the same time"
+msgstr ""
+
+#: objc/objc-act.cc:6173
+#, gcc-internal-format
+msgid "previous declaration of %<%c%E%> as %<@required%>"
+msgstr ""
+
+#: objc/objc-act.cc:6193
+#, gcc-internal-format
+msgid "previous declaration of %<%c%E%> as %<@optional%>"
+msgstr ""
+
+#: objc/objc-act.cc:6253
+#, gcc-internal-format
+msgid "duplicate declaration of method %<%c%E%> with conflicting types"
+msgstr ""
+
+#: objc/objc-act.cc:6257
+#, gcc-internal-format
+msgid "previous declaration of %<%c%E%>"
+msgstr ""
+
+#: objc/objc-act.cc:6294
+#, gcc-internal-format
+msgid "duplicate interface declaration for category %<%E(%E)%>"
+msgstr ""
+
+#: objc/objc-act.cc:6382
+#, gcc-internal-format
+msgid "illegal reference type specified for instance variable %qs"
+msgstr ""
+
+#: objc/objc-act.cc:6393
+#, gcc-internal-format
+msgid "instance variable %qs has unknown size"
+msgstr ""
+
+#: objc/objc-act.cc:6414
+#, gcc-internal-format
+msgid "instance variable %qs uses flexible array member"
+msgstr ""
+
+#: objc/objc-act.cc:6441
+#, gcc-internal-format
+msgid "type %qE has no default constructor to call"
+msgstr ""
+
+#: objc/objc-act.cc:6447
+#, gcc-internal-format
+msgid "destructor for %qE shall not be run either"
+msgstr ""
+
+#. Vtable pointers are Real Bad(tm), since Obj-C cannot
+#. initialize them.
+#: objc/objc-act.cc:6459
+#, gcc-internal-format
+msgid "type %qE has virtual member functions"
+msgstr ""
+
+#: objc/objc-act.cc:6460
+#, gcc-internal-format
+msgid "illegal aggregate type %qE specified for instance variable %qs"
+msgstr ""
+
+#: objc/objc-act.cc:6470
+#, gcc-internal-format
+msgid "type %qE has a user-defined constructor"
+msgstr ""
+
+#: objc/objc-act.cc:6472
+#, gcc-internal-format
+msgid "type %qE has a user-defined destructor"
+msgstr ""
+
+#: objc/objc-act.cc:6476
+#, gcc-internal-format
+msgid "C++ constructors and destructors will not be invoked for Objective-C fields"
+msgstr ""
+
+#: objc/objc-act.cc:6607
+#, gcc-internal-format
+msgid "instance variable %qE is declared private"
+msgstr ""
+
+#: objc/objc-act.cc:6618
+#, gcc-internal-format
+msgid "instance variable %qE is %s; this will be a hard error in the future"
+msgstr ""
+
+#: objc/objc-act.cc:6625
+#, gcc-internal-format
+msgid "instance variable %qE is declared %s"
+msgstr ""
+
+#: objc/objc-act.cc:6736 objc/objc-act.cc:6851
+#, gcc-internal-format
+msgid "incomplete implementation of class %qE"
+msgstr ""
+
+#: objc/objc-act.cc:6740 objc/objc-act.cc:6855
+#, gcc-internal-format
+msgid "incomplete implementation of category %qE"
+msgstr ""
+
+#: objc/objc-act.cc:6749 objc/objc-act.cc:6863
+#, gcc-internal-format
+msgid "method definition for %<%c%E%> not found"
+msgstr ""
+
+#: objc/objc-act.cc:6904
+#, gcc-internal-format
+msgid "%s %qE does not fully implement the %qE protocol"
+msgstr ""
+
+#: objc/objc-act.cc:6994
+#, gcc-internal-format
+msgid "cannot find interface declaration for %qE, superclass of %qE"
+msgstr ""
+
+#: objc/objc-act.cc:7002
+#, gcc-internal-format
+msgid "class %qE is not available"
+msgstr ""
+
+#: objc/objc-act.cc:7035
+#, gcc-internal-format
+msgid "reimplementation of class %qE"
+msgstr ""
+
+#: objc/objc-act.cc:7068
+#, gcc-internal-format
+msgid "conflicting super class name %qE"
+msgstr ""
+
+#: objc/objc-act.cc:7071
+#, gcc-internal-format
+msgid "previous declaration of %qE"
+msgstr ""
+
+#: objc/objc-act.cc:7073
+#, gcc-internal-format
+msgid "previous declaration"
+msgstr "წინა დეკლარაცია"
+
+#: objc/objc-act.cc:7085
+#, gcc-internal-format
+msgid "class %qE defined without specifying a base class"
+msgstr ""
+
+#: objc/objc-act.cc:7092 objc/objc-act.cc:7094
+#, gcc-internal-format
+msgid "duplicate interface declaration for class %qE"
+msgstr ""
+
+#: objc/objc-act.cc:7419 objc/objc-act.cc:7615
+#, gcc-internal-format
+msgid "cannot find instance variable associated with property"
+msgstr ""
+
+#. TODO: This should be caught much earlier than this.
+#: objc/objc-act.cc:7581
+#, gcc-internal-format
+msgid "invalid setter, it must have one argument"
+msgstr ""
+
+#: objc/objc-act.cc:7745 objc/objc-act.cc:7962
+#, gcc-internal-format
+msgid "property %qs already specified in %<@dynamic%>"
+msgstr ""
+
+#: objc/objc-act.cc:7748 objc/objc-act.cc:7965
+#, gcc-internal-format
+msgid "property %qs already specified in %<@synthesize%>"
+msgstr ""
+
+#: objc/objc-act.cc:7762 objc/objc-act.cc:7979
+#, gcc-internal-format
+msgid "no declaration of property %qs found in the interface"
+msgstr ""
+
+#: objc/objc-act.cc:7789
+#, gcc-internal-format
+msgid "ivar %qs used by %<@synthesize%> declaration must be an existing ivar"
+msgstr ""
+
+#: objc/objc-act.cc:7810
+#, gcc-internal-format
+msgid "property %qs is using instance variable %qs of incompatible type"
+msgstr ""
+
+#: objc/objc-act.cc:7832
+#, gcc-internal-format
+msgid "%<assign%> property %qs is using bit-field instance variable %qs"
+msgstr ""
+
+#: objc/objc-act.cc:7846
+#, gcc-internal-format
+msgid "%<atomic%> property %qs is using bit-field instance variable %qs"
+msgstr ""
+
+#: objc/objc-act.cc:7865
+#, gcc-internal-format
+msgid "property %qs is using the same instance variable as property %qs"
+msgstr ""
+
+#: objc/objc-act.cc:7906
+#, gcc-internal-format
+msgid "%<@synthesize%> is not available in Objective-C 1.0"
+msgstr ""
+
+#. We can get here only in Objective-C; the Objective-C++ parser
+#. detects the problem while parsing, outputs the error
+#. "misplaced '@synthesize' Objective-C++ construct" and skips
+#. the declaration.
+#: objc/objc-act.cc:7917
+#, gcc-internal-format
+msgid "%<@synthesize%> not in @implementation context"
+msgstr ""
+
+#: objc/objc-act.cc:7923
+#, gcc-internal-format
+msgid "%<@synthesize%> cannot be used in categories"
+msgstr ""
+
+#: objc/objc-act.cc:7932
+#, gcc-internal-format
+msgid "%<@synthesize%> requires the @interface of the class to be available"
+msgstr ""
+
+#: objc/objc-act.cc:8015
+#, gcc-internal-format
+msgid "%<@dynamic%> is not available in Objective-C 1.0"
+msgstr ""
+
+#. We can get here only in Objective-C; the Objective-C++ parser
+#. detects the problem while parsing, outputs the error
+#. "misplaced '@dynamic' Objective-C++ construct" and skips the
+#. declaration.
+#: objc/objc-act.cc:8026
+#, gcc-internal-format
+msgid "%<@dynamic%> not in @implementation context"
+msgstr ""
+
+#: objc/objc-act.cc:8048
+#, gcc-internal-format
+msgid "%<@dynamic%> requires the @interface of the class to be available"
+msgstr ""
+
+#: objc/objc-act.cc:8248
+#, gcc-internal-format
+msgid "definition of protocol %qE not found"
+msgstr ""
+
+#: objc/objc-act.cc:8275
+#, gcc-internal-format
+msgid "protocol %qE is unavailable"
+msgstr ""
+
+#. It would be nice to use warn_deprecated_use() here, but
+#. we are using TREE_CHAIN (which is supposed to be the
+#. TYPE_STUB_DECL for a TYPE) for something different.
+#: objc/objc-act.cc:8281
+#, gcc-internal-format
+msgid "protocol %qE is deprecated"
+msgstr ""
+
+#: objc/objc-act.cc:8408
+#, gcc-internal-format
+msgid "duplicate declaration for protocol %qE"
+msgstr ""
+
+#: objc/objc-act.cc:8932
+#, gcc-internal-format
+msgid "conflicting types for %<%c%s%>"
+msgstr ""
+
+#: objc/objc-act.cc:8936
+#, gcc-internal-format
+msgid "previous declaration of %<%c%s%>"
+msgstr ""
+
+#: objc/objc-act.cc:9038
+#, gcc-internal-format
+msgid "no super class declared in interface for %qE"
+msgstr ""
+
+#: objc/objc-act.cc:9065
+#, gcc-internal-format
+msgid "%<[super ...]%> must appear in a method context"
+msgstr ""
+
+#: objc/objc-act.cc:9105
+#, gcc-internal-format
+msgid "method possibly missing a [super dealloc] call"
+msgstr ""
+
+#: objc/objc-act.cc:9573
+#, gcc-internal-format
+msgid "instance variable %qs is declared private"
+msgstr ""
+
+#: objc/objc-act.cc:9626
+#, gcc-internal-format
+msgid "local declaration of %qE hides instance variable"
+msgstr ""
+
+#. This can happen if DECL_ARTIFICIAL (*expr_p), but
+#. should be impossible for real properties, which always
+#. have a getter.
+#: objc/objc-act.cc:9670
+#, gcc-internal-format
+msgid "no %qs getter found"
+msgstr ""
+
+#: objc/objc-act.cc:9917
+#, gcc-internal-format
+msgid "fast enumeration is not available in Objective-C 1.0"
+msgstr ""
+
+#: objc/objc-act.cc:9927
+#, gcc-internal-format
+msgid "iterating variable in fast enumeration is not an object"
+msgstr ""
+
+#: objc/objc-act.cc:9933
+#, gcc-internal-format
+msgid "collection in fast enumeration is not an object"
+msgstr ""
+
+#: objc/objc-encoding.cc:130
+#, gcc-internal-format
+msgid "type %qT does not have a known size"
+msgstr ""
+
+#: objc/objc-encoding.cc:721
+#, gcc-internal-format
+msgid "unknown type %<%T%> found during Objective-C encoding"
+msgstr ""
+
+#. Do not do any encoding, produce an error and keep going.
+#: objc/objc-encoding.cc:804
+#, gcc-internal-format
+msgid "trying to encode non-integer type as a bit-field"
+msgstr ""
+
+#: objc/objc-gnu-runtime-abi-01.cc:134
+#, gcc-internal-format
+msgid "%<-fobjc-gc%> is ignored for %<-fgnu-runtime%>"
+msgstr ""
+
+#: objc/objc-gnu-runtime-abi-01.cc:142
+#, gcc-internal-format
+msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fgnu-runtime%>"
+msgstr ""
+
+#: objc/objc-gnu-runtime-abi-01.cc:2162 objc/objc-next-runtime-abi-01.cc:2822
+#: objc/objc-next-runtime-abi-02.cc:3840
+#, gcc-internal-format
+msgid "non-objective-c type %qT cannot be caught"
+msgstr ""
+
+#: objc/objc-next-runtime-abi-01.cc:146
+#, gcc-internal-format
+msgid "%<-fobjc-sjlj-exceptions%> is the only supported exceptions system for %<-fnext-runtime%> with %<-fobjc-abi-version%> argument less than 2"
+msgstr ""
+
+#: objc/objc-next-runtime-abi-02.cc:246
+#, gcc-internal-format
+msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> greater than 1"
+msgstr ""
+
+#: objc/objc-runtime-shared-support.cc:423
+#, gcc-internal-format
+msgid "creating selector for nonexistent method %qE"
+msgstr ""
+
+#: rust/backend/rust-constexpr.cc:1676
+#, gcc-internal-format
+msgid "array size expression is not supported yet"
+msgstr ""
+
+#: rust/backend/rust-constexpr.cc:1803
+#, gcc-internal-format
+msgid "constant folding not supported for this tree code"
+msgstr ""
+
+#: rust/backend/rust-constexpr.cc:2480
+#, gcc-internal-format
+msgid "cast from %qT is not allowed"
+msgstr ""
+
+#: rust/backend/rust-constexpr.cc:2753
+#, gcc-internal-format
+msgid "modification of %qE is not a constant expression"
+msgstr ""
+
+#: rust/backend/rust-constexpr.cc:6172
+#, gcc-internal-format
+msgid "%qD declared %<thread_local%> in %<constexpr%> context"
+msgstr ""
+
+#: rust/backend/rust-constexpr.cc:6181
+#, gcc-internal-format
+msgid "%qD declared %<static%> in %<constexpr%> context"
+msgstr ""
+
+#: rust/backend/rust-tree.cc:616
+#, gcc-internal-format
+msgid "ignoring return value of %qD, that must be used: %<%s%>"
+msgstr ""
+
+#: rust/backend/rust-tree.cc:617
+#, gcc-internal-format
+msgid "ignoring return value of %qD, that must be used"
+msgstr ""
+
+#: rust/backend/rust-tree.cc:633
+#, gcc-internal-format
+msgid "ignoring returned value of type %qT, that must be used: %<%s%>"
+msgstr ""
+
+#: rust/backend/rust-tree.cc:634
+#, gcc-internal-format
+msgid "ignoring returned value of type %qT, that must be used"
+msgstr ""
+
+#: rust/checks/lints/rust-lint-unused-var.cc:51
+#, gcc-internal-format
+msgid "unused name %qE"
+msgstr ""
+
+#: rust/resolve/rust-ast-resolve-expr.cc:167
+#, gcc-internal-format, gfc-internal-format
+msgid "are you trying to break %s? how dare you?"
+msgstr ""

commit d3c14d408664076014a225cbe7d69b7c2ee3e92d
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Thu Aug 29 02:25:52 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 00e43a06f4d..0b8bcefbecd 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240828
+20240829
diff --git a/gcc/po/ChangeLog b/gcc/po/ChangeLog
index 8ba0a78ce36..01dce13aa15 100644
--- a/gcc/po/ChangeLog
+++ b/gcc/po/ChangeLog
@@ -1,3 +1,7 @@
+2024-08-28  Joseph Myers  <josmyers@redhat.com>
+
+	* ka.po: New file.
+
 2024-08-27  Joseph Myers  <josmyers@redhat.com>
 
 	* zh_CN.po: Update.
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index a2ffda55dc8..d52ac026607 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,20 @@
+2024-08-28  Xi Ruoyao  <xry111@xry111.site>
+
+	Backported from master:
+	2024-08-10  Xi Ruoyao  <xry111@xry111.site>
+
+	PR testsuite/70150
+	* gcc.target/i386/fentryname3.c (dg-final): Revert r13-1614
+	change.
+
+2024-08-28  Xi Ruoyao  <xry111@xry111.site>
+
+	Backported from master:
+	2024-08-10  Xi Ruoyao  <xry111@xry111.site>
+
+	PR testsuite/70150
+	* gcc.target/i386/pr113689-1.c (dg-options): Add -no-pie.
+
 2024-08-22  liuhongt  <hongtao.liu@intel.com>
 
 	Backported from master:

commit 552c7c12e32e6f09269c794b5c2b053e40beeb41
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Fri Aug 30 02:30:04 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 0b8bcefbecd..8021f79746d 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240829
+20240830

commit 5999dd8a610acbaff9dfb6bdeb67f33380336132
Author: Harald Anlauf <anlauf@gmx.de>
Date:   Thu Aug 29 21:21:39 2024

    Fortran: fix ICE with use with rename of namelist member [PR116530]
    
    gcc/fortran/ChangeLog:
    
            PR fortran/116530
            * trans-io.cc (transfer_namelist_element): Prevent NULL pointer
            dereference.
    
    gcc/testsuite/ChangeLog:
    
            PR fortran/116530
            * gfortran.dg/use_rename_12.f90: New test.
    
    (cherry picked from commit 6bfeba12c86b4d0dae27d99b484f64774dd49398)

diff --git a/gcc/fortran/trans-io.cc b/gcc/fortran/trans-io.cc
index ee2cc560cdf..0c5a1714be6 100644
--- a/gcc/fortran/trans-io.cc
+++ b/gcc/fortran/trans-io.cc
@@ -1692,7 +1692,8 @@ transfer_namelist_element (stmtblock_t * block, const char * var_name,
   gcc_assert (sym || c);
 
   /* Build the namelist object name.  */
-  if (sym && !sym->attr.use_only && sym->attr.use_rename)
+  if (sym && !sym->attr.use_only && sym->attr.use_rename
+      && sym->ns->use_stmts->rename)
     string = gfc_build_cstring_const (sym->ns->use_stmts->rename->local_name);
   else
     string = gfc_build_cstring_const (var_name);
diff --git a/gcc/testsuite/gfortran.dg/use_rename_12.f90 b/gcc/testsuite/gfortran.dg/use_rename_12.f90
new file mode 100644
index 00000000000..0447d5fe150
--- /dev/null
+++ b/gcc/testsuite/gfortran.dg/use_rename_12.f90
@@ -0,0 +1,27 @@
+! { dg-do compile }
+! PR fortran/116530 - ICE with member of namelist renamed by use module
+!
+! Reported by philippe.wautelet at cnrs.fr 
+
+module mod_nml1
+  implicit none
+  logical :: ldiag
+  namelist /nam_nml1/ldiag
+end module mod_nml1
+
+module mod_interm
+  use mod_nml1
+end module mod_interm
+
+program ice_nml
+  use mod_nml1,        ldiag_nml1 => ldiag
+  use mod_nml1, only : ldiag_only => ldiag
+  use mod_interm
+  implicit none
+  integer :: ilu = 10
+  read(unit=ilu,nml=nam_nml1)
+  write(unit=*,nml=nam_nml1)
+  print *, ldiag
+  print *, ldiag_nml1
+  print *, ldiag_only
+end program ice_nml

commit 657bf4a01b45cd58fd4758c8b7a80e60d4ac4299
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Sat Aug 31 02:22:43 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 8021f79746d..7036fab4770 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240830
+20240831
diff --git a/gcc/fortran/ChangeLog b/gcc/fortran/ChangeLog
index a16a51a786e..25c8473186e 100644
--- a/gcc/fortran/ChangeLog
+++ b/gcc/fortran/ChangeLog
@@ -1,3 +1,12 @@
+2024-08-30  Harald Anlauf  <anlauf@gmx.de>
+
+	Backported from master:
+	2024-08-29  Harald Anlauf  <anlauf@gmx.de>
+
+	PR fortran/116530
+	* trans-io.cc (transfer_namelist_element): Prevent NULL pointer
+	dereference.
+
 2024-08-06  Jakub Jelinek  <jakub@redhat.com>
 
 	Backported from master:
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index d52ac026607..682b6ca98e1 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,11 @@
+2024-08-30  Harald Anlauf  <anlauf@gmx.de>
+
+	Backported from master:
+	2024-08-29  Harald Anlauf  <anlauf@gmx.de>
+
+	PR fortran/116530
+	* gfortran.dg/use_rename_12.f90: New test.
+
 2024-08-28  Xi Ruoyao  <xry111@xry111.site>
 
 	Backported from master:

commit a2e32a8856e6b9870ba8a25bf62242c51cbdbf46
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Sun Sep 1 02:36:10 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 7036fab4770..42eedaf32c0 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240831
+20240901

commit db4d81090b4f61998c393376c68eb97e38f5ed21
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Mon Sep 2 02:25:48 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 42eedaf32c0..18af8d7e288 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240901
+20240902

commit ba9a3f105ea552a22d08f2d54dfdbef16af7c99e
Author: liuhongt <hongtao.liu@intel.com>
Date:   Thu Aug 29 05:39:20 2024

    Check avx upper register for parallel.
    
    For function arguments/return, when it's BLK mode, it's put in a
    parallel with an expr_list, and the expr_list contains the real mode
    and registers.
    Current ix86_check_avx_upper_register only checked for SSE_REG_P, and
    failed to handle that. The patch extend the handle to each subrtx.
    
    gcc/ChangeLog:
    
            PR target/116512
            * config/i386/i386.cc (ix86_check_avx_upper_register): Iterate
            subrtx to scan for avx upper register.
            (ix86_check_avx_upper_stores): Inline old
            ix86_check_avx_upper_register.
            (ix86_avx_u128_mode_needed): Ditto, and replace
            FOR_EACH_SUBRTX with call to new
            ix86_check_avx_upper_register.
    
    gcc/testsuite/ChangeLog:
    
            * gcc.target/i386/pr116512.c: New test.
    
    (cherry picked from commit ab214ef734bfc3dcffcf79ff9e1dd651c2b40566)

diff --git a/gcc/config/i386/i386.cc b/gcc/config/i386/i386.cc
index 288c69467d6..feefbe322de 100644
--- a/gcc/config/i386/i386.cc
+++ b/gcc/config/i386/i386.cc
@@ -15027,9 +15027,19 @@ ix86_dirflag_mode_needed (rtx_insn *insn)
 static bool
 ix86_check_avx_upper_register (const_rtx exp)
 {
-  return (SSE_REG_P (exp)
-	  && !EXT_REX_SSE_REG_P (exp)
-	  && GET_MODE_BITSIZE (GET_MODE (exp)) > 128);
+  /* construct_container may return a parallel with expr_list
+     which contains the real reg and mode  */
+  subrtx_iterator::array_type array;
+  FOR_EACH_SUBRTX (iter, array, exp, NONCONST)
+    {
+      const_rtx x = *iter;
+      if (SSE_REG_P (x)
+	  && !EXT_REX_SSE_REG_P (x)
+	  && GET_MODE_BITSIZE (GET_MODE (x)) > 128)
+	return true;
+    }
+
+  return false;
 }
 
 /* Check if a 256bit or 512bit AVX register is referenced in stores.   */
@@ -15037,7 +15047,9 @@ ix86_check_avx_upper_register (const_rtx exp)
 static void
 ix86_check_avx_upper_stores (rtx dest, const_rtx, void *data)
 {
-  if (ix86_check_avx_upper_register (dest))
+  if (SSE_REG_P (dest)
+      && !EXT_REX_SSE_REG_P (dest)
+      && GET_MODE_BITSIZE (GET_MODE (dest)) > 128)
     {
       bool *used = (bool *) data;
       *used = true;
@@ -15096,14 +15108,14 @@ ix86_avx_u128_mode_needed (rtx_insn *insn)
       return AVX_U128_CLEAN;
     }
 
-  subrtx_iterator::array_type array;
-
   rtx set = single_set (insn);
   if (set)
     {
       rtx dest = SET_DEST (set);
       rtx src = SET_SRC (set);
-      if (ix86_check_avx_upper_register (dest))
+      if (SSE_REG_P (dest)
+	  && !EXT_REX_SSE_REG_P (dest)
+	  && GET_MODE_BITSIZE (GET_MODE (dest)) > 128)
 	{
 	  /* This is an YMM/ZMM load.  Return AVX_U128_DIRTY if the
 	     source isn't zero.  */
@@ -15114,9 +15126,8 @@ ix86_avx_u128_mode_needed (rtx_insn *insn)
 	}
       else
 	{
-	  FOR_EACH_SUBRTX (iter, array, src, NONCONST)
-	    if (ix86_check_avx_upper_register (*iter))
-	      return AVX_U128_DIRTY;
+	  if (ix86_check_avx_upper_register (src))
+	    return AVX_U128_DIRTY;
 	}
 
       /* This isn't YMM/ZMM load/store.  */
@@ -15127,9 +15138,8 @@ ix86_avx_u128_mode_needed (rtx_insn *insn)
      Hardware changes state only when a 256bit register is written to,
      but we need to prevent the compiler from moving optimal insertion
      point above eventual read from 256bit or 512 bit register.  */
-  FOR_EACH_SUBRTX (iter, array, PATTERN (insn), NONCONST)
-    if (ix86_check_avx_upper_register (*iter))
-      return AVX_U128_DIRTY;
+  if (ix86_check_avx_upper_register (PATTERN (insn)))
+    return AVX_U128_DIRTY;
 
   return AVX_U128_ANY;
 }
diff --git a/gcc/testsuite/gcc.target/i386/pr116512.c b/gcc/testsuite/gcc.target/i386/pr116512.c
new file mode 100644
index 00000000000..c2bc6c91b64
--- /dev/null
+++ b/gcc/testsuite/gcc.target/i386/pr116512.c
@@ -0,0 +1,26 @@
+/* { dg-do compile } */
+/* { dg-options "-march=x86-64-v4 -O2" } */
+/* { dg-final { scan-assembler-not "vzeroupper" { target { ! ia32 } } } } */
+
+#include <immintrin.h>
+
+struct B {
+  union {
+    __m512 f;
+    __m512i s;
+  };
+};
+
+struct B foo(int n) {
+  struct B res;
+  res.s = _mm512_set1_epi32(n);
+
+  return res;
+}
+
+__m512i bar(int n) {
+  struct B res;
+  res.s = _mm512_set1_epi32(n);
+
+  return res.s;
+}

commit 2ac3806d5465db5eb333926e8341a14b6baa2496
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Tue Sep 3 02:32:49 2024

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 6749e3e5f9a..eef1a754730 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,17 @@
+2024-09-02  liuhongt  <hongtao.liu@intel.com>
+
+	Backported from master:
+	2024-08-30  liuhongt  <hongtao.liu@intel.com>
+
+	PR target/116512
+	* config/i386/i386.cc (ix86_check_avx_upper_register): Iterate
+	subrtx to scan for avx upper register.
+	(ix86_check_avx_upper_stores): Inline old
+	ix86_check_avx_upper_register.
+	(ix86_avx_u128_mode_needed): Ditto, and replace
+	FOR_EACH_SUBRTX with call to new
+	ix86_check_avx_upper_register.
+
 2024-08-22  liuhongt  <hongtao.liu@intel.com>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 18af8d7e288..a1e4e7fb875 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240902
+20240903
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 682b6ca98e1..d158bd2f0ee 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,10 @@
+2024-09-02  liuhongt  <hongtao.liu@intel.com>
+
+	Backported from master:
+	2024-08-30  liuhongt  <hongtao.liu@intel.com>
+
+	* gcc.target/i386/pr116512.c: New test.
+
 2024-08-30  Harald Anlauf  <anlauf@gmx.de>
 
 	Backported from master:

commit 59157c038d683e91c419a1fadd5f91f15218f57b
Author: Haochen Jiang <haochen.jiang@intel.com>
Date:   Mon Sep 2 09:00:22 2024

    i386: Fix vfpclassph non-optimizied intrin
    
    The intrin for non-optimized got a typo in mask type, which will cause
    the high bits of __mmask32 being unexpectedly zeroed.
    
    The test does not fail under O0 with current 1b since the testcase is
    wrong. We need to include avx512-mask-type.h after SIZE is defined, or
    it will always be __mmask8. I will write a seperate patch to fix that
    on trunk ONLY.
    
    gcc/ChangeLog:
    
            * config/i386/avx512fp16intrin.h
            (_mm512_mask_fpclass_ph_mask): Correct mask type to __mmask32.
            (_mm512_fpclass_ph_mask): Ditto.
    
    gcc/testsuite/ChangeLog:
    
            * gcc.target/i386/avx512fp16-vfpclassph-1c.c: New test.

diff --git a/gcc/config/i386/avx512fp16intrin.h b/gcc/config/i386/avx512fp16intrin.h
index f86050b2087..e8baebd41d3 100644
--- a/gcc/config/i386/avx512fp16intrin.h
+++ b/gcc/config/i386/avx512fp16intrin.h
@@ -3961,11 +3961,11 @@ _mm512_fpclass_ph_mask (__m512h __A, const int __imm)
 #else
 #define _mm512_mask_fpclass_ph_mask(u, x, c)				\
   ((__mmask32) __builtin_ia32_fpclassph512_mask ((__v32hf) (__m512h) (x), \
-						 (int) (c),(__mmask8)(u)))
+						 (int) (c),(__mmask32)(u)))
 
 #define _mm512_fpclass_ph_mask(x, c)                                    \
   ((__mmask32) __builtin_ia32_fpclassph512_mask ((__v32hf) (__m512h) (x), \
-						 (int) (c),(__mmask8)-1))
+						 (int) (c),(__mmask32)-1))
 #endif /* __OPIMTIZE__ */
 
 /* Intrinsics vgetexpph.  */
diff --git a/gcc/testsuite/gcc.target/i386/avx512fp16-vfpclassph-1c.c b/gcc/testsuite/gcc.target/i386/avx512fp16-vfpclassph-1c.c
new file mode 100644
index 00000000000..4739f1228e3
--- /dev/null
+++ b/gcc/testsuite/gcc.target/i386/avx512fp16-vfpclassph-1c.c
@@ -0,0 +1,77 @@
+/* { dg-do run } */
+/* { dg-options "-O0 -mavx512fp16" } */
+/* { dg-require-effective-target avx512fp16 } */
+
+#define AVX512FP16
+#include "avx512f-helper.h"
+
+#include <math.h>
+#include <limits.h>
+#include <float.h>
+#define SIZE (AVX512F_LEN / 16)
+#include "avx512f-mask-type.h"
+
+#ifndef __FPCLASSPH__
+#define __FPCLASSPH__
+int check_fp_class_hp (_Float16 src, int imm)
+{
+  int qNaN_res = isnan (src);
+  int sNaN_res = isnan (src);
+  int Pzero_res = (src == 0.0);
+  int Nzero_res = (src == -0.0);
+  int PInf_res = (isinf (src) == 1);
+  int NInf_res = (isinf (src) == -1);
+  int Denorm_res = (fpclassify (src) == FP_SUBNORMAL);
+  int FinNeg_res = __builtin_finite (src) && (src < 0);
+
+  int result = (((imm & 1) && qNaN_res)
+		|| (((imm >> 1) & 1) && Pzero_res)
+		|| (((imm >> 2) & 1) && Nzero_res)
+		|| (((imm >> 3) & 1) && PInf_res)
+		|| (((imm >> 4) & 1) && NInf_res)
+		|| (((imm >> 5) & 1) && Denorm_res)
+		|| (((imm >> 6) & 1) && FinNeg_res)
+		|| (((imm >> 7) & 1) && sNaN_res));
+  return result;
+}
+#endif
+
+MASK_TYPE
+CALC (_Float16 *s1, int imm)
+{
+  int i;
+  MASK_TYPE res = 0;
+
+  for (i = 0; i < SIZE; i++)
+    if (check_fp_class_hp(s1[i], imm))
+      res = res | (1 << i);
+
+  return res;
+}
+
+void
+TEST (void)
+{
+  int i;
+  UNION_TYPE (AVX512F_LEN, h) src;
+  MASK_TYPE res1, res2, res_ref = 0;
+  MASK_TYPE mask = MASK_VALUE;
+
+  src.a[SIZE - 1] = NAN;
+  src.a[SIZE - 2] = 1.0 / 0.0;
+  for (i = 0; i < SIZE - 2; i++)
+    {
+      src.a[i] = -24.43 + 0.6 * i;
+    }
+
+  res1 = INTRINSIC (_fpclass_ph_mask) (src.x, 0xFF);
+  res2 = INTRINSIC (_mask_fpclass_ph_mask) (mask, src.x, 0xFF);
+
+  res_ref = CALC (src.a, 0xFF);
+
+  if (res_ref != res1)
+    abort ();
+
+  if ((mask & res_ref) != res2)
+    abort ();
+}

commit 5c1955f563a5776529841608bee03de2a45d19a1
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Wed Sep 4 02:27:51 2024

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index eef1a754730..a494e6dc39a 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,9 @@
+2024-09-03  Haochen Jiang  <haochen.jiang@intel.com>
+
+	* config/i386/avx512fp16intrin.h
+	(_mm512_mask_fpclass_ph_mask): Correct mask type to __mmask32.
+	(_mm512_fpclass_ph_mask): Ditto.
+
 2024-09-02  liuhongt  <hongtao.liu@intel.com>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index a1e4e7fb875..301a37d563d 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240903
+20240904
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index d158bd2f0ee..56d4aad7f9b 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,7 @@
+2024-09-03  Haochen Jiang  <haochen.jiang@intel.com>
+
+	* gcc.target/i386/avx512fp16-vfpclassph-1c.c: New test.
+
 2024-09-02  liuhongt  <hongtao.liu@intel.com>
 
 	Backported from master:

commit 66eb7b752ab61c02348d6af10945af3ff92b6d77
Author: H.J. Lu <hjl.tools@gmail.com>
Date:   Wed Aug 21 16:25:25 2024

    Update LDPT_REGISTER_CLAIM_FILE_HOOK_V2 linker plugin hook
    
    This hook allows the BFD linker plugin to distinguish calls to
    claim_file_handler that know the object is being used by the linker
    (from ldmain.c:add_archive_element), from calls that don't know it's
    being used by the linker (from elf_link_is_defined_archive_symbol); in
    the latter case, the plugin should avoid including the unused LTO archive
    members in link output.  To get the proper support for archives with LTO
    common symbols, the linker fix
    
    commit a6f8fe0a9e9cbe871652e46ba7c22d5e9fb86208
    Author: H.J. Lu <hjl.tools@gmail.com>
    Date:   Wed Aug 14 20:50:02 2024 -0700
    
        lto: Don't include unused LTO archive members in output
    
    is required.
    
            PR lto/116361
            * lto-plugin.c (claim_file_handler_v2): Rename claimed to
            can_be_claimed.  Include the LTO object only if it is known to
            be included in link output.
    
    Signed-off-by: H.J. Lu <hjl.tools@gmail.com>
    (cherry picked from commit a98dd536b1017c2b814a3465206c6c01b2890998)

diff --git a/lto-plugin/lto-plugin.c b/lto-plugin/lto-plugin.c
index 152648338b9..61b0de62f52 100644
--- a/lto-plugin/lto-plugin.c
+++ b/lto-plugin/lto-plugin.c
@@ -1191,16 +1191,19 @@ process_offload_section (void *data, const char *name, off_t offset, off_t len)
   return 1;
 }
 
-/* Callback used by a linker to check if the plugin will claim FILE. Writes
-   the result in CLAIMED.  If KNOWN_USED, the object is known by the linker
-   to be used, or an older API version is in use that does not provide that
-   information; otherwise, the linker is only determining whether this is
-   a plugin object and it should not be registered as having offload data if
-   not claimed by the plugin.  */
+/* Callback used by a linker to check if the plugin can claim FILE.
+   Writes the result in CAN_BE_CLAIMED.  If KNOWN_USED != 0, the object
+   is known by the linker to be included in link output, or an older API
+   version is in use that does not provide that information.  Otherwise,
+   the linker is only determining whether this is a plugin object and
+   only the symbol table is needed by the linker.  In this case, the
+   object should not be included in link output and this function will
+   be called by the linker again with KNOWN_USED != 0 after the linker
+   decides the object should be included in link output. */
 
 static enum ld_plugin_status
-claim_file_handler_v2 (const struct ld_plugin_input_file *file, int *claimed,
-		       int known_used)
+claim_file_handler_v2 (const struct ld_plugin_input_file *file,
+		       int *can_be_claimed, int known_used)
 {
   enum ld_plugin_status status;
   struct plugin_objfile obj;
@@ -1229,7 +1232,7 @@ claim_file_handler_v2 (const struct ld_plugin_input_file *file, int *claimed,
     }
   lto_file.handle = file->handle;
 
-  *claimed = 0;
+  *can_be_claimed = 0;
   obj.file = file;
   obj.found = 0;
   obj.offload = false;
@@ -1286,15 +1289,19 @@ claim_file_handler_v2 (const struct ld_plugin_input_file *file, int *claimed,
 			      lto_file.symtab.syms);
       check (status == LDPS_OK, LDPL_FATAL, "could not add symbols");
 
-      LOCK_SECTION;
-      num_claimed_files++;
-      claimed_files =
-	xrealloc (claimed_files,
-		  num_claimed_files * sizeof (struct plugin_file_info));
-      claimed_files[num_claimed_files - 1] = lto_file;
-      UNLOCK_SECTION;
+      /* Include it only if it is known to be used for link output.  */
+      if (known_used)
+	{
+	  LOCK_SECTION;
+	  num_claimed_files++;
+	  claimed_files =
+	    xrealloc (claimed_files,
+		      num_claimed_files * sizeof (struct plugin_file_info));
+	  claimed_files[num_claimed_files - 1] = lto_file;
+	  UNLOCK_SECTION;
+	}
 
-      *claimed = 1;
+      *can_be_claimed = 1;
     }
 
   LOCK_SECTION;
@@ -1310,10 +1317,10 @@ claim_file_handler_v2 (const struct ld_plugin_input_file *file, int *claimed,
   /* If this is an LTO file without offload, and it is the first LTO file, save
      the pointer to the last offload file in the list.  Further offload LTO
      files will be inserted after it, if any.  */
-  if (*claimed && !obj.offload && offload_files_last_lto == NULL)
+  if (*can_be_claimed && !obj.offload && offload_files_last_lto == NULL)
     offload_files_last_lto = offload_files_last;
 
-  if (obj.offload && (known_used || obj.found > 0))
+  if (obj.offload && known_used && obj.found > 0)
     {
       /* Add file to the list.  The order must be exactly the same as the final
 	 order after recompilation and linking, otherwise host and target tables
@@ -1324,7 +1331,9 @@ claim_file_handler_v2 (const struct ld_plugin_input_file *file, int *claimed,
       ofld->name = lto_file.name;
       ofld->next = NULL;
 
-      if (*claimed && offload_files_last_lto == NULL && file->offset != 0
+      if (*can_be_claimed
+	  && offload_files_last_lto == NULL
+	  && file->offset != 0
 	  && gold_version == -1)
 	{
 	  /* ld only: insert first LTO file from the archive after the last real
@@ -1341,7 +1350,7 @@ claim_file_handler_v2 (const struct ld_plugin_input_file *file, int *claimed,
 	      offload_files->next = ofld;
 	    }
 	}
-      else if (*claimed && offload_files_last_lto != NULL)
+      else if (*can_be_claimed && offload_files_last_lto != NULL)
 	{
 	  /* Insert LTO file after the last LTO file in the list.  */
 	  ofld->next = offload_files_last_lto->next;
@@ -1356,7 +1365,7 @@ claim_file_handler_v2 (const struct ld_plugin_input_file *file, int *claimed,
 	offload_files_last = ofld;
       if (file->offset == 0)
 	offload_files_last_obj = ofld;
-      if (*claimed)
+      if (*can_be_claimed)
 	offload_files_last_lto = ofld;
       num_offload_files++;
     }

commit 0562522e1290da08bc5a89182b9ae80c3cc9d1db
Author: H.J. Lu <hjl.tools@gmail.com>
Date:   Fri Aug 23 14:36:45 2024

    lto: Don't check obj.found for offload section
    
    obj.found is the number of LTO symbols.  We should include the offload
    section when it is used by linker even if there are no LTO symbols.
    
            PR lto/116361
            * lto-plugin.c (claim_file_handler_v2): Don't check obj.found
            for the offload section.
    
    Signed-off-by: H.J. Lu <hjl.tools@gmail.com>
    (cherry picked from commit cb51e0b236c7d492af2033582230e78d8b55290f)

diff --git a/lto-plugin/lto-plugin.c b/lto-plugin/lto-plugin.c
index 61b0de62f52..c564b36eb92 100644
--- a/lto-plugin/lto-plugin.c
+++ b/lto-plugin/lto-plugin.c
@@ -1320,7 +1320,7 @@ claim_file_handler_v2 (const struct ld_plugin_input_file *file,
   if (*can_be_claimed && !obj.offload && offload_files_last_lto == NULL)
     offload_files_last_lto = offload_files_last;
 
-  if (obj.offload && known_used && obj.found > 0)
+  if (obj.offload && known_used)
     {
       /* Add file to the list.  The order must be exactly the same as the final
 	 order after recompilation and linking, otherwise host and target tables

commit c6e04d1f92fc3b4215e7c179da5d4a51356f69a8
Author: Andrew Carlotti <andrew.carlotti@arm.com>
Date:   Tue Aug 13 17:15:11 2024

    aarch64: Refactor check_required_extensions
    
    Replace TARGET_GENERAL_REGS_ONLY check with an explicit check that
    aarch64_isa_flags enables all required extensions.  This will be more
    flexible when repurposing this function for non-SVE intrinsics.
    
    gcc/ChangeLog:
    
            * config/aarch64/aarch64-sve-builtins.cc
            (check_required_registers): Remove target check and rename to...
            (report_missing_registers): ...this.
            (check_required_extensions): Refactor.

diff --git a/gcc/config/aarch64/aarch64-sve-builtins.cc b/gcc/config/aarch64/aarch64-sve-builtins.cc
index f3983a123e3..46bd9bc5a35 100644
--- a/gcc/config/aarch64/aarch64-sve-builtins.cc
+++ b/gcc/config/aarch64/aarch64-sve-builtins.cc
@@ -1094,27 +1094,19 @@ report_missing_extension (location_t location, tree fndecl,
   reported_missing_extension_p = true;
 }
 
-/* Check whether the registers required by SVE function fndecl are available.
-   Report an error against LOCATION and return false if not.  */
-static bool
-check_required_registers (location_t location, tree fndecl)
+/* Report an error against LOCATION that the user has tried to use
+   function FNDECL when non-general registers are disabled.  */
+static void
+report_missing_registers (location_t location, tree fndecl)
 {
   /* Avoid reporting a slew of messages for a single oversight.  */
   if (reported_missing_registers_p)
-    return false;
-
-  if (TARGET_GENERAL_REGS_ONLY)
-    {
-      /* SVE registers are not usable when -mgeneral-regs-only option
-	 is specified.  */
-      error_at (location,
-		"ACLE function %qD is incompatible with the use of %qs",
-		fndecl, "-mgeneral-regs-only");
-      reported_missing_registers_p = true;
-      return false;
-    }
+    return;
 
-  return true;
+  error_at (location,
+	    "ACLE function %qD is incompatible with the use of %qs",
+	    fndecl, "-mgeneral-regs-only");
+  reported_missing_registers_p = true;
 }
 
 /* Check whether all the AARCH64_FL_* values in REQUIRED_EXTENSIONS are
@@ -1124,9 +1116,19 @@ static bool
 check_required_extensions (location_t location, tree fndecl,
 			   aarch64_feature_flags required_extensions)
 {
+  if ((required_extensions & ~aarch64_isa_flags) == 0)
+    return true;
+
   auto missing_extensions = required_extensions & ~aarch64_asm_isa_flags;
+
   if (missing_extensions == 0)
-    return check_required_registers (location, fndecl);
+    {
+      /* All required extensions are enabled in aarch64_asm_isa_flags, so the
+	 error must be the use of general-regs-only.  */
+      report_missing_registers (location, fndecl);
+      return false;
+    }
+
 
   if (missing_extensions & AARCH64_FL_SM_OFF)
     {

commit 422c3f1965d76a541385bdc419a4e1c46f007525
Author: Andrew Carlotti <andrew.carlotti@arm.com>
Date:   Tue Jul 18 17:40:58 2023

    aarch64: Move check_required_extensions
    
    Move SVE extension checking functionality to aarch64-builtins.cc, so
    that it can be shared by non-SVE intrinsics.
    
    gcc/ChangeLog:
    
            * config/aarch64/aarch64-sve-builtins.cc (check_builtin_call)
            (expand_builtin): Update calls to the below.
            (report_missing_extension, report_missing_registers)
            (check_required_extensions): Move out of aarch64_sve namespace,
            rename, and move into...
            * config/aarch64/aarch64-builtins.cc (aarch64_report_missing_extension)
            (aarch64_report_missing_registers)
            (aarch64_check_required_extensions) ...here.
            * config/aarch64/aarch64-protos.h (aarch64_check_required_extensions):
            Add prototype.

diff --git a/gcc/config/aarch64/aarch64-builtins.cc b/gcc/config/aarch64/aarch64-builtins.cc
index 75d21de1401..ad3986ce002 100644
--- a/gcc/config/aarch64/aarch64-builtins.cc
+++ b/gcc/config/aarch64/aarch64-builtins.cc
@@ -2098,6 +2098,106 @@ aarch64_general_builtin_decl (unsigned code, bool)
   return aarch64_builtin_decls[code];
 }
 
+/* True if we've already complained about attempts to use functions
+   when the required extension is disabled.  */
+static bool reported_missing_extension_p;
+
+/* True if we've already complained about attempts to use functions
+   which require registers that are missing.  */
+static bool reported_missing_registers_p;
+
+/* Report an error against LOCATION that the user has tried to use
+   function FNDECL when extension EXTENSION is disabled.  */
+static void
+aarch64_report_missing_extension (location_t location, tree fndecl,
+				  const char *extension)
+{
+  /* Avoid reporting a slew of messages for a single oversight.  */
+  if (reported_missing_extension_p)
+    return;
+
+  error_at (location, "ACLE function %qD requires ISA extension %qs",
+	    fndecl, extension);
+  inform (location, "you can enable %qs using the command-line"
+	  " option %<-march%>, or by using the %<target%>"
+	  " attribute or pragma", extension);
+  reported_missing_extension_p = true;
+}
+
+/* Report an error against LOCATION that the user has tried to use
+   function FNDECL when non-general registers are disabled.  */
+static void
+aarch64_report_missing_registers (location_t location, tree fndecl)
+{
+  /* Avoid reporting a slew of messages for a single oversight.  */
+  if (reported_missing_registers_p)
+    return;
+
+  error_at (location,
+	    "ACLE function %qD is incompatible with the use of %qs",
+	    fndecl, "-mgeneral-regs-only");
+  reported_missing_registers_p = true;
+}
+
+/* Check whether all the AARCH64_FL_* values in REQUIRED_EXTENSIONS are
+   enabled, given that those extensions are required for function FNDECL.
+   Report an error against LOCATION if not.  */
+bool
+aarch64_check_required_extensions (location_t location, tree fndecl,
+				   aarch64_feature_flags required_extensions)
+{
+  if ((required_extensions & ~aarch64_isa_flags) == 0)
+    return true;
+
+  auto missing_extensions = required_extensions & ~aarch64_asm_isa_flags;
+
+  if (missing_extensions == 0)
+    {
+      /* All required extensions are enabled in aarch64_asm_isa_flags, so the
+	 error must be the use of general-regs-only.  */
+      aarch64_report_missing_registers (location, fndecl);
+      return false;
+    }
+
+  if (missing_extensions & AARCH64_FL_SM_OFF)
+    {
+      error_at (location, "ACLE function %qD cannot be called when"
+		" SME streaming mode is enabled", fndecl);
+      return false;
+    }
+
+  if (missing_extensions & AARCH64_FL_SM_ON)
+    {
+      error_at (location, "ACLE function %qD can only be called when"
+		" SME streaming mode is enabled", fndecl);
+      return false;
+    }
+
+  if (missing_extensions & AARCH64_FL_ZA_ON)
+    {
+      error_at (location, "ACLE function %qD can only be called from"
+		" a function that has %qs state", fndecl, "za");
+      return false;
+    }
+
+  static const struct {
+    aarch64_feature_flags flag;
+    const char *name;
+  } extensions[] = {
+#define AARCH64_OPT_EXTENSION(EXT_NAME, IDENT, C, D, E, F) \
+    { AARCH64_FL_##IDENT, EXT_NAME },
+#include "aarch64-option-extensions.def"
+  };
+
+  for (unsigned int i = 0; i < ARRAY_SIZE (extensions); ++i)
+    if (missing_extensions & extensions[i].flag)
+      {
+	aarch64_report_missing_extension (location, fndecl, extensions[i].name);
+	return false;
+      }
+  gcc_unreachable ();
+}
+
 bool
 aarch64_general_check_builtin_call (location_t location, vec<location_t>,
 			    unsigned int code, tree fndecl,
diff --git a/gcc/config/aarch64/aarch64-protos.h b/gcc/config/aarch64/aarch64-protos.h
index 42639e9efcf..5d067cb64b4 100644
--- a/gcc/config/aarch64/aarch64-protos.h
+++ b/gcc/config/aarch64/aarch64-protos.h
@@ -1008,6 +1008,8 @@ tree aarch64_general_builtin_rsqrt (unsigned int);
 void handle_arm_acle_h (void);
 void handle_arm_neon_h (void);
 
+bool aarch64_check_required_extensions (location_t, tree,
+					aarch64_feature_flags);
 bool aarch64_general_check_builtin_call (location_t, vec<location_t>,
 					 unsigned int, tree, unsigned int,
 					 tree *);
diff --git a/gcc/config/aarch64/aarch64-sve-builtins.cc b/gcc/config/aarch64/aarch64-sve-builtins.cc
index 46bd9bc5a35..e0458f7c1f6 100644
--- a/gcc/config/aarch64/aarch64-sve-builtins.cc
+++ b/gcc/config/aarch64/aarch64-sve-builtins.cc
@@ -947,14 +947,6 @@ static hash_table<registered_function_hasher> *function_table;
    are IDENTIFIER_NODEs.  */
 static GTY(()) hash_map<tree, registered_function *> *overload_names[2];
 
-/* True if we've already complained about attempts to use functions
-   when the required extension is disabled.  */
-static bool reported_missing_extension_p;
-
-/* True if we've already complained about attempts to use functions
-   which require registers that are missing.  */
-static bool reported_missing_registers_p;
-
 /* Record that TYPE is an ABI-defined SVE type that contains NUM_ZR SVE vectors
    and NUM_PR SVE predicates.  MANGLED_NAME, if nonnull, is the ABI-defined
    mangling of the type.  ACLE_NAME is the <arm_sve.h> name of the type.  */
@@ -1076,98 +1068,6 @@ lookup_fndecl (tree fndecl)
   return &(*registered_functions)[subcode]->instance;
 }
 
-/* Report an error against LOCATION that the user has tried to use
-   function FNDECL when extension EXTENSION is disabled.  */
-static void
-report_missing_extension (location_t location, tree fndecl,
-			  const char *extension)
-{
-  /* Avoid reporting a slew of messages for a single oversight.  */
-  if (reported_missing_extension_p)
-    return;
-
-  error_at (location, "ACLE function %qD requires ISA extension %qs",
-	    fndecl, extension);
-  inform (location, "you can enable %qs using the command-line"
-	  " option %<-march%>, or by using the %<target%>"
-	  " attribute or pragma", extension);
-  reported_missing_extension_p = true;
-}
-
-/* Report an error against LOCATION that the user has tried to use
-   function FNDECL when non-general registers are disabled.  */
-static void
-report_missing_registers (location_t location, tree fndecl)
-{
-  /* Avoid reporting a slew of messages for a single oversight.  */
-  if (reported_missing_registers_p)
-    return;
-
-  error_at (location,
-	    "ACLE function %qD is incompatible with the use of %qs",
-	    fndecl, "-mgeneral-regs-only");
-  reported_missing_registers_p = true;
-}
-
-/* Check whether all the AARCH64_FL_* values in REQUIRED_EXTENSIONS are
-   enabled, given that those extensions are required for function FNDECL.
-   Report an error against LOCATION if not.  */
-static bool
-check_required_extensions (location_t location, tree fndecl,
-			   aarch64_feature_flags required_extensions)
-{
-  if ((required_extensions & ~aarch64_isa_flags) == 0)
-    return true;
-
-  auto missing_extensions = required_extensions & ~aarch64_asm_isa_flags;
-
-  if (missing_extensions == 0)
-    {
-      /* All required extensions are enabled in aarch64_asm_isa_flags, so the
-	 error must be the use of general-regs-only.  */
-      report_missing_registers (location, fndecl);
-      return false;
-    }
-
-
-  if (missing_extensions & AARCH64_FL_SM_OFF)
-    {
-      error_at (location, "ACLE function %qD cannot be called when"
-		" SME streaming mode is enabled", fndecl);
-      return false;
-    }
-
-  if (missing_extensions & AARCH64_FL_SM_ON)
-    {
-      error_at (location, "ACLE function %qD can only be called when"
-		" SME streaming mode is enabled", fndecl);
-      return false;
-    }
-
-  if (missing_extensions & AARCH64_FL_ZA_ON)
-    {
-      error_at (location, "ACLE function %qD can only be called from"
-		" a function that has %qs state", fndecl, "za");
-      return false;
-    }
-
-  static const struct {
-    aarch64_feature_flags flag;
-    const char *name;
-  } extensions[] = {
-#define AARCH64_OPT_EXTENSION(EXT_NAME, IDENT, C, D, E, F) \
-    { AARCH64_FL_##IDENT, EXT_NAME },
-#include "aarch64-option-extensions.def"
-  };
-
-  for (unsigned int i = 0; i < ARRAY_SIZE (extensions); ++i)
-    if (missing_extensions & extensions[i].flag)
-      {
-	report_missing_extension (location, fndecl, extensions[i].name);
-	return false;
-      }
-  gcc_unreachable ();
-}
 
 /* Report that LOCATION has a call to FNDECL in which argument ARGNO
    was not an integer constant expression.  ARGNO counts from zero.  */
@@ -4763,7 +4663,8 @@ check_builtin_call (location_t location, vec<location_t>, unsigned int code,
 		    tree fndecl, unsigned int nargs, tree *args)
 {
   const registered_function &rfn = *(*registered_functions)[code];
-  if (!check_required_extensions (location, rfn.decl, rfn.required_extensions))
+  if (!aarch64_check_required_extensions (location, rfn.decl,
+					  rfn.required_extensions))
     return false;
   return function_checker (location, rfn.instance, fndecl,
 			   TREE_TYPE (rfn.decl), nargs, args).check ();
@@ -4786,8 +4687,8 @@ rtx
 expand_builtin (unsigned int code, tree exp, rtx target)
 {
   registered_function &rfn = *(*registered_functions)[code];
-  if (!check_required_extensions (EXPR_LOCATION (exp), rfn.decl,
-				  rfn.required_extensions))
+  if (!aarch64_check_required_extensions (EXPR_LOCATION (exp), rfn.decl,
+					  rfn.required_extensions))
     return target;
   return function_expander (rfn.instance, rfn.decl, exp, target).expand ();
 }

commit 0a3a0d4a5e32e9b914b5c5cc283ee485adc6cd11
Author: Andrew Carlotti <andrew.carlotti@arm.com>
Date:   Thu Oct 26 16:43:44 2023

    aarch64: Fix tme intrinsic availability
    
    The availability of tme intrinsics was previously gated at both
    initialisation time (using global target options) and usage time
    (accounting for function-specific target options).  This patch removes
    the check at initialisation time, and also moves the intrinsics out of
    the header file to allow for better error messages (matching the
    existing error messages for SVE intrinsics).
    
    gcc/ChangeLog:
    
            PR target/112108
            * config/aarch64/aarch64-builtins.cc (aarch64_init_tme_builtins):
            Define intrinsic names directly.
            (aarch64_general_init_builtins): Move tme initialisation...
            (handle_arm_acle_h): ...to here, and remove feature check.
            (aarch64_general_check_builtin_call): Check tme intrinsics.
            * config/aarch64/arm_acle.h (__tstart, __tcommit, __tcancel)
            (__ttest): Remove.
            (_TMFAILURE_*): Define unconditionally.
    
    gcc/testsuite/ChangeLog:
    
            PR target/112108
            * gcc.target/aarch64/acle/tme_guard-1.c: New test.
            * gcc.target/aarch64/acle/tme_guard-2.c: New test.
            * gcc.target/aarch64/acle/tme_guard-3.c: New test.
            * gcc.target/aarch64/acle/tme_guard-4.c: New test.

diff --git a/gcc/config/aarch64/aarch64-builtins.cc b/gcc/config/aarch64/aarch64-builtins.cc
index ad3986ce002..70437641219 100644
--- a/gcc/config/aarch64/aarch64-builtins.cc
+++ b/gcc/config/aarch64/aarch64-builtins.cc
@@ -1709,21 +1709,17 @@ aarch64_init_tme_builtins (void)
     = build_function_type_list (void_type_node, uint64_type_node, NULL);
 
   aarch64_builtin_decls[AARCH64_TME_BUILTIN_TSTART]
-    = aarch64_general_add_builtin ("__builtin_aarch64_tstart",
-				   ftype_uint64_void,
-				   AARCH64_TME_BUILTIN_TSTART);
+    = aarch64_general_simulate_builtin ("__tstart", ftype_uint64_void,
+					AARCH64_TME_BUILTIN_TSTART);
   aarch64_builtin_decls[AARCH64_TME_BUILTIN_TTEST]
-    = aarch64_general_add_builtin ("__builtin_aarch64_ttest",
-				   ftype_uint64_void,
-				   AARCH64_TME_BUILTIN_TTEST);
+    = aarch64_general_simulate_builtin ("__ttest", ftype_uint64_void,
+					AARCH64_TME_BUILTIN_TTEST);
   aarch64_builtin_decls[AARCH64_TME_BUILTIN_TCOMMIT]
-    = aarch64_general_add_builtin ("__builtin_aarch64_tcommit",
-				   ftype_void_void,
-				   AARCH64_TME_BUILTIN_TCOMMIT);
+    = aarch64_general_simulate_builtin ("__tcommit", ftype_void_void,
+					AARCH64_TME_BUILTIN_TCOMMIT);
   aarch64_builtin_decls[AARCH64_TME_BUILTIN_TCANCEL]
-    = aarch64_general_add_builtin ("__builtin_aarch64_tcancel",
-				   ftype_void_uint64,
-				   AARCH64_TME_BUILTIN_TCANCEL);
+    = aarch64_general_simulate_builtin ("__tcancel", ftype_void_uint64,
+					AARCH64_TME_BUILTIN_TCANCEL);
 }
 
 /* Add builtins for Random Number instructions.  */
@@ -1986,6 +1982,7 @@ handle_arm_acle_h (void)
 {
   if (TARGET_LS64)
     aarch64_init_ls64_builtins ();
+  aarch64_init_tme_builtins ();
 }
 
 /* Initialize fpsr fpcr getters and setters.  */
@@ -2078,9 +2075,6 @@ aarch64_general_init_builtins (void)
   if (!TARGET_ILP32)
     aarch64_init_pauth_hint_builtins ();
 
-  if (TARGET_TME)
-    aarch64_init_tme_builtins ();
-
   if (TARGET_MEMTAG)
     aarch64_init_memtag_builtins ();
 
@@ -2203,6 +2197,7 @@ aarch64_general_check_builtin_call (location_t location, vec<location_t>,
 			    unsigned int code, tree fndecl,
 			    unsigned int nargs ATTRIBUTE_UNUSED, tree *args)
 {
+  tree decl = aarch64_builtin_decls[code];
   switch (code)
     {
     case AARCH64_RSR:
@@ -2215,15 +2210,29 @@ aarch64_general_check_builtin_call (location_t location, vec<location_t>,
     case AARCH64_WSR64:
     case AARCH64_WSRF:
     case AARCH64_WSRF64:
-      tree addr = STRIP_NOPS (args[0]);
-      if (TREE_CODE (TREE_TYPE (addr)) != POINTER_TYPE
-	  || TREE_CODE (addr) != ADDR_EXPR
-	  || TREE_CODE (TREE_OPERAND (addr, 0)) != STRING_CST)
-	{
-	  error_at (location, "first argument to %qD must be a string literal",
-		    fndecl);
-	  return false;
-	}
+      {
+	tree addr = STRIP_NOPS (args[0]);
+	if (TREE_CODE (TREE_TYPE (addr)) != POINTER_TYPE
+	    || TREE_CODE (addr) != ADDR_EXPR
+	    || TREE_CODE (TREE_OPERAND (addr, 0)) != STRING_CST)
+	  {
+	    error_at (location,
+		      "first argument to %qD must be a string literal",
+		      fndecl);
+	    return false;
+	  }
+	break;
+      }
+
+    case AARCH64_TME_BUILTIN_TSTART:
+    case AARCH64_TME_BUILTIN_TCOMMIT:
+    case AARCH64_TME_BUILTIN_TTEST:
+    case AARCH64_TME_BUILTIN_TCANCEL:
+      return aarch64_check_required_extensions (location, decl,
+						AARCH64_FL_TME);
+
+    default:
+      break;
     }
   /* Default behavior.  */
   return true;
diff --git a/gcc/config/aarch64/arm_acle.h b/gcc/config/aarch64/arm_acle.h
index 2aa681090fa..2d84ab1bd3f 100644
--- a/gcc/config/aarch64/arm_acle.h
+++ b/gcc/config/aarch64/arm_acle.h
@@ -252,10 +252,7 @@ __crc32d (uint32_t __a, uint64_t __b)
 
 #pragma GCC pop_options
 
-#ifdef __ARM_FEATURE_TME
-#pragma GCC push_options
-#pragma GCC target ("+nothing+tme")
-
+/* Constants for TME failure reason.  */
 #define _TMFAILURE_REASON     0x00007fffu
 #define _TMFAILURE_RTRY       0x00008000u
 #define _TMFAILURE_CNCL       0x00010000u
@@ -268,37 +265,6 @@ __crc32d (uint32_t __a, uint64_t __b)
 #define _TMFAILURE_INT        0x00800000u
 #define _TMFAILURE_TRIVIAL    0x01000000u
 
-__extension__ extern __inline uint64_t
-__attribute__ ((__always_inline__, __gnu_inline__, __artificial__))
-__tstart (void)
-{
-  return __builtin_aarch64_tstart ();
-}
-
-__extension__ extern __inline void
-__attribute__ ((__always_inline__, __gnu_inline__, __artificial__))
-__tcommit (void)
-{
-  __builtin_aarch64_tcommit ();
-}
-
-__extension__ extern __inline void
-__attribute__ ((__always_inline__, __gnu_inline__, __artificial__))
-__tcancel (const uint64_t __reason)
-{
-  __builtin_aarch64_tcancel (__reason);
-}
-
-__extension__ extern __inline uint64_t
-__attribute__ ((__always_inline__, __gnu_inline__, __artificial__))
-__ttest (void)
-{
-  return __builtin_aarch64_ttest ();
-}
-
-#pragma GCC pop_options
-#endif
-
 #ifdef __ARM_FEATURE_LS64
 typedef __arm_data512_t data512_t;
 #endif
diff --git a/gcc/testsuite/gcc.target/aarch64/acle/tme_guard-1.c b/gcc/testsuite/gcc.target/aarch64/acle/tme_guard-1.c
new file mode 100644
index 00000000000..9894d3341f6
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/acle/tme_guard-1.c
@@ -0,0 +1,9 @@
+/* { dg-do compile } */
+/* { dg-additional-options "-march=armv8-a" } */
+
+#include <arm_acle.h>
+
+void foo (void)
+{
+  __tcommit (); /* { dg-error {ACLE function '__tcommit' requires ISA extension 'tme'} } */
+}
diff --git a/gcc/testsuite/gcc.target/aarch64/acle/tme_guard-2.c b/gcc/testsuite/gcc.target/aarch64/acle/tme_guard-2.c
new file mode 100644
index 00000000000..4e3d69712b1
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/acle/tme_guard-2.c
@@ -0,0 +1,10 @@
+/* { dg-do compile } */
+/* { dg-additional-options "-march=armv8-a" } */
+
+#include <arm_acle.h>
+
+#pragma GCC target("arch=armv8-a+tme")
+void foo (void)
+{
+  __tcommit ();
+}
diff --git a/gcc/testsuite/gcc.target/aarch64/acle/tme_guard-3.c b/gcc/testsuite/gcc.target/aarch64/acle/tme_guard-3.c
new file mode 100644
index 00000000000..5f480ebb820
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/acle/tme_guard-3.c
@@ -0,0 +1,9 @@
+/* { dg-do compile } */
+/* { dg-additional-options "-march=armv8-a+tme -mgeneral-regs-only" } */
+
+#include <arm_acle.h>
+
+void foo (void)
+{
+  __tcommit ();
+}
diff --git a/gcc/testsuite/gcc.target/aarch64/acle/tme_guard-4.c b/gcc/testsuite/gcc.target/aarch64/acle/tme_guard-4.c
new file mode 100644
index 00000000000..bf4d368370c
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/acle/tme_guard-4.c
@@ -0,0 +1,10 @@
+/* { dg-do compile } */
+/* { dg-additional-options "-march=armv8-a+tme" } */
+
+#include <arm_acle.h>
+
+#pragma GCC target("arch=armv8-a")
+void foo (void)
+{
+  __tcommit (); /* { dg-error {ACLE function '__tcommit' requires ISA extension 'tme'} } */
+}

commit 8485606056ed3ca0d0acf6e0d943975e9173e7cd
Author: Andrew Carlotti <andrew.carlotti@arm.com>
Date:   Tue Jul 18 21:09:38 2023

    aarch64: Fix memtag intrinsic availability
    
    The availability of memtag intrinsics and data types were determined
    solely by the globally specified architecture features, which did not
    reflect any changes specified in target pragmas or attributes.
    
    This patch removes the initialisation-time guards for the intrinsics,
    and replaces them with checks at use time. It also removes the macro
    indirection from the header file - this simplifies the header, and
    allows the missing extension error reporting to find the user-facing
    intrinsic names.
    
    gcc/ChangeLog:
    
            PR target/112108
            * config/aarch64/aarch64-builtins.cc (aarch64_init_memtag_builtins):
            Define intrinsic names directly.
            (aarch64_general_init_builtins): Move memtag intialisation...
            (handle_arm_acle_h): ...to here, and remove feature check.
            (aarch64_general_check_builtin_call): Check memtag intrinsics.
            * config/aarch64/arm_acle.h (__arm_mte_create_random_tag)
            (__arm_mte_exclude_tag, __arm_mte_ptrdiff)
            (__arm_mte_increment_tag, __arm_mte_set_tag, __arm_mte_get_tag):
            Remove.
    
    gcc/testsuite/ChangeLog:
    
            PR target/112108
            * gcc.target/aarch64/acle/memtag_guard-1.c: New test.
            * gcc.target/aarch64/acle/memtag_guard-2.c: New test.
            * gcc.target/aarch64/acle/memtag_guard-3.c: New test.
            * gcc.target/aarch64/acle/memtag_guard-4.c: New test.

diff --git a/gcc/config/aarch64/aarch64-builtins.cc b/gcc/config/aarch64/aarch64-builtins.cc
index 70437641219..ba04424645d 100644
--- a/gcc/config/aarch64/aarch64-builtins.cc
+++ b/gcc/config/aarch64/aarch64-builtins.cc
@@ -1850,27 +1850,27 @@ aarch64_init_memtag_builtins (void)
 
 #define AARCH64_INIT_MEMTAG_BUILTINS_DECL(F, N, I, T) \
   aarch64_builtin_decls[AARCH64_MEMTAG_BUILTIN_##F] \
-    = aarch64_general_add_builtin ("__builtin_aarch64_memtag_"#N, \
-				   T, AARCH64_MEMTAG_BUILTIN_##F); \
+    = aarch64_general_simulate_builtin ("__arm_mte_"#N, T, \
+					AARCH64_MEMTAG_BUILTIN_##F); \
   aarch64_memtag_builtin_data[AARCH64_MEMTAG_BUILTIN_##F - \
 			      AARCH64_MEMTAG_BUILTIN_START - 1] = \
 				{T, CODE_FOR_##I};
 
   fntype = build_function_type_list (ptr_type_node, ptr_type_node,
 				     uint64_type_node, NULL);
-  AARCH64_INIT_MEMTAG_BUILTINS_DECL (IRG, irg, irg, fntype);
+  AARCH64_INIT_MEMTAG_BUILTINS_DECL (IRG, create_random_tag, irg, fntype);
 
   fntype = build_function_type_list (uint64_type_node, ptr_type_node,
 				     uint64_type_node, NULL);
-  AARCH64_INIT_MEMTAG_BUILTINS_DECL (GMI, gmi, gmi, fntype);
+  AARCH64_INIT_MEMTAG_BUILTINS_DECL (GMI, exclude_tag, gmi, fntype);
 
   fntype = build_function_type_list (ptrdiff_type_node, ptr_type_node,
 				     ptr_type_node, NULL);
-  AARCH64_INIT_MEMTAG_BUILTINS_DECL (SUBP, subp, subp, fntype);
+  AARCH64_INIT_MEMTAG_BUILTINS_DECL (SUBP, ptrdiff, subp, fntype);
 
   fntype = build_function_type_list (ptr_type_node, ptr_type_node,
 				     unsigned_type_node, NULL);
-  AARCH64_INIT_MEMTAG_BUILTINS_DECL (INC_TAG, inc_tag, addg, fntype);
+  AARCH64_INIT_MEMTAG_BUILTINS_DECL (INC_TAG, increment_tag, addg, fntype);
 
   fntype = build_function_type_list (void_type_node, ptr_type_node, NULL);
   AARCH64_INIT_MEMTAG_BUILTINS_DECL (SET_TAG, set_tag, stg, fntype);
@@ -1983,6 +1983,7 @@ handle_arm_acle_h (void)
   if (TARGET_LS64)
     aarch64_init_ls64_builtins ();
   aarch64_init_tme_builtins ();
+  aarch64_init_memtag_builtins ();
 }
 
 /* Initialize fpsr fpcr getters and setters.  */
@@ -2075,9 +2076,6 @@ aarch64_general_init_builtins (void)
   if (!TARGET_ILP32)
     aarch64_init_pauth_hint_builtins ();
 
-  if (TARGET_MEMTAG)
-    aarch64_init_memtag_builtins ();
-
   if (in_lto_p)
     handle_arm_acle_h ();
 }
@@ -2234,7 +2232,12 @@ aarch64_general_check_builtin_call (location_t location, vec<location_t>,
     default:
       break;
     }
-  /* Default behavior.  */
+
+  if (code >= AARCH64_MEMTAG_BUILTIN_START
+      && code <= AARCH64_MEMTAG_BUILTIN_END)
+    return aarch64_check_required_extensions (location, decl,
+					      AARCH64_FL_MEMTAG);
+
   return true;
 }
 
diff --git a/gcc/config/aarch64/arm_acle.h b/gcc/config/aarch64/arm_acle.h
index 2d84ab1bd3f..ab043267913 100644
--- a/gcc/config/aarch64/arm_acle.h
+++ b/gcc/config/aarch64/arm_acle.h
@@ -287,29 +287,6 @@ __rndrrs (uint64_t *__res)
 
 #pragma GCC pop_options
 
-#pragma GCC push_options
-#pragma GCC target ("+nothing+memtag")
-
-#define __arm_mte_create_random_tag(__ptr, __u64_mask) \
-  __builtin_aarch64_memtag_irg(__ptr, __u64_mask)
-
-#define __arm_mte_exclude_tag(__ptr, __u64_excluded) \
-  __builtin_aarch64_memtag_gmi(__ptr, __u64_excluded)
-
-#define __arm_mte_ptrdiff(__ptr_a, __ptr_b) \
-  __builtin_aarch64_memtag_subp(__ptr_a, __ptr_b)
-
-#define __arm_mte_increment_tag(__ptr, __u_offset) \
-  __builtin_aarch64_memtag_inc_tag(__ptr, __u_offset)
-
-#define __arm_mte_set_tag(__tagged_address) \
-  __builtin_aarch64_memtag_set_tag(__tagged_address)
-
-#define __arm_mte_get_tag(__address) \
-  __builtin_aarch64_memtag_get_tag(__address)
-
-#pragma GCC pop_options
-
 #define __arm_rsr(__regname) \
   __builtin_aarch64_rsr (__regname)
 
diff --git a/gcc/testsuite/gcc.target/aarch64/acle/memtag_guard-1.c b/gcc/testsuite/gcc.target/aarch64/acle/memtag_guard-1.c
new file mode 100644
index 00000000000..4a34c37f44f
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/acle/memtag_guard-1.c
@@ -0,0 +1,9 @@
+/* { dg-do compile } */
+/* { dg-additional-options "-march=armv8.5-a" } */
+
+#include <arm_acle.h>
+
+void foo (int * p)
+{
+  __arm_mte_set_tag (p); /* { dg-error {ACLE function '__arm_mte_set_tag' requires ISA extension 'memtag'} } */
+}
diff --git a/gcc/testsuite/gcc.target/aarch64/acle/memtag_guard-2.c b/gcc/testsuite/gcc.target/aarch64/acle/memtag_guard-2.c
new file mode 100644
index 00000000000..bf06b284dad
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/acle/memtag_guard-2.c
@@ -0,0 +1,10 @@
+/* { dg-do compile } */
+/* { dg-additional-options "-march=armv8.5-a" } */
+
+#include <arm_acle.h>
+
+#pragma GCC target("arch=armv8.5-a+memtag")
+void foo (int * p)
+{
+  __arm_mte_set_tag (p);
+}
diff --git a/gcc/testsuite/gcc.target/aarch64/acle/memtag_guard-3.c b/gcc/testsuite/gcc.target/aarch64/acle/memtag_guard-3.c
new file mode 100644
index 00000000000..1f4ffa454a7
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/acle/memtag_guard-3.c
@@ -0,0 +1,9 @@
+/* { dg-do compile } */
+/* { dg-additional-options "-march=armv8.5-a+memtag -mgeneral-regs-only" } */
+
+#include <arm_acle.h>
+
+void foo (int * p)
+{
+  __arm_mte_set_tag (p);
+}
diff --git a/gcc/testsuite/gcc.target/aarch64/acle/memtag_guard-4.c b/gcc/testsuite/gcc.target/aarch64/acle/memtag_guard-4.c
new file mode 100644
index 00000000000..a1cd45ec79d
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/acle/memtag_guard-4.c
@@ -0,0 +1,10 @@
+/* { dg-do compile } */
+/* { dg-additional-options "-march=armv8.5-a+memtag" } */
+
+#include <arm_acle.h>
+
+#pragma GCC target("arch=armv8.5-a")
+void foo (int * p)
+{
+  __arm_mte_set_tag (p); /* { dg-error {ACLE function '__arm_mte_set_tag' requires ISA extension 'memtag'} } */
+}

commit 9899be7d5380c732b56ba155d4a9e192a2c483b1
Author: Andrew Carlotti <andrew.carlotti@arm.com>
Date:   Thu Oct 26 16:45:15 2023

    aarch64: Fix ls64 intrinsic availability
    
    The availability of ls64 intrinsics and data types were determined
    solely by the globally specified architecture features, which did not
    reflect any changes specified in target pragmas or attributes.
    
    This patch removes the initialisation-time guards for the intrinsics,
    and replaces them with checks at use time. We also get better error
    messages when ls64 is not available (matching the existing error
    messages for SVE intrinsics).
    
    The data512_t type is made always available; this is consistent with the
    present behaviour for Neon fp16/bf16 types.
    
    gcc/ChangeLog:
    
            PR target/112108
            * config/aarch64/aarch64-builtins.cc (handle_arm_acle_h): Remove
            feature check at initialisation.
            (aarch64_general_check_builtin_call): Check ls64 intrinsics.
            * config/aarch64/arm_acle.h: (data512_t) Make always available.
    
    gcc/testsuite/ChangeLog:
    
            PR target/112108
            * gcc.target/aarch64/acle/ls64_guard-1.c: New test.
            * gcc.target/aarch64/acle/ls64_guard-2.c: New test.
            * gcc.target/aarch64/acle/ls64_guard-3.c: New test.
            * gcc.target/aarch64/acle/ls64_guard-4.c: New test.

diff --git a/gcc/config/aarch64/aarch64-builtins.cc b/gcc/config/aarch64/aarch64-builtins.cc
index ba04424645d..d5b5700d25d 100644
--- a/gcc/config/aarch64/aarch64-builtins.cc
+++ b/gcc/config/aarch64/aarch64-builtins.cc
@@ -1980,8 +1980,7 @@ aarch64_init_data_intrinsics (void)
 void
 handle_arm_acle_h (void)
 {
-  if (TARGET_LS64)
-    aarch64_init_ls64_builtins ();
+  aarch64_init_ls64_builtins ();
   aarch64_init_tme_builtins ();
   aarch64_init_memtag_builtins ();
 }
@@ -2229,6 +2228,13 @@ aarch64_general_check_builtin_call (location_t location, vec<location_t>,
       return aarch64_check_required_extensions (location, decl,
 						AARCH64_FL_TME);
 
+    case AARCH64_LS64_BUILTIN_LD64B:
+    case AARCH64_LS64_BUILTIN_ST64B:
+    case AARCH64_LS64_BUILTIN_ST64BV:
+    case AARCH64_LS64_BUILTIN_ST64BV0:
+      return aarch64_check_required_extensions (location, decl,
+						AARCH64_FL_LS64);
+
     default:
       break;
     }
diff --git a/gcc/config/aarch64/arm_acle.h b/gcc/config/aarch64/arm_acle.h
index ab043267913..ab4e7e60e04 100644
--- a/gcc/config/aarch64/arm_acle.h
+++ b/gcc/config/aarch64/arm_acle.h
@@ -265,9 +265,7 @@ __crc32d (uint32_t __a, uint64_t __b)
 #define _TMFAILURE_INT        0x00800000u
 #define _TMFAILURE_TRIVIAL    0x01000000u
 
-#ifdef __ARM_FEATURE_LS64
 typedef __arm_data512_t data512_t;
-#endif
 
 #pragma GCC push_options
 #pragma GCC target ("+nothing+rng")
diff --git a/gcc/testsuite/gcc.target/aarch64/acle/ls64_guard-1.c b/gcc/testsuite/gcc.target/aarch64/acle/ls64_guard-1.c
new file mode 100644
index 00000000000..7dfc193a293
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/acle/ls64_guard-1.c
@@ -0,0 +1,9 @@
+/* { dg-do compile } */
+/* { dg-additional-options "-march=armv8.6-a" } */
+
+#include <arm_acle.h>
+
+data512_t foo (void * p)
+{
+  return __arm_ld64b (p); /* { dg-error {ACLE function '__arm_ld64b' requires ISA extension 'ls64'} } */
+}
diff --git a/gcc/testsuite/gcc.target/aarch64/acle/ls64_guard-2.c b/gcc/testsuite/gcc.target/aarch64/acle/ls64_guard-2.c
new file mode 100644
index 00000000000..3ede05a81f0
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/acle/ls64_guard-2.c
@@ -0,0 +1,10 @@
+/* { dg-do compile } */
+/* { dg-additional-options "-march=armv8.6-a" } */
+
+#include <arm_acle.h>
+
+#pragma GCC target("arch=armv8-a+ls64")
+data512_t foo (void * p)
+{
+  return __arm_ld64b (p);
+}
diff --git a/gcc/testsuite/gcc.target/aarch64/acle/ls64_guard-3.c b/gcc/testsuite/gcc.target/aarch64/acle/ls64_guard-3.c
new file mode 100644
index 00000000000..e0fccdad7be
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/acle/ls64_guard-3.c
@@ -0,0 +1,9 @@
+/* { dg-do compile } */
+/* { dg-additional-options "-march=armv8-a+ls64 -mgeneral-regs-only" } */
+
+#include <arm_acle.h>
+
+data512_t foo (void * p)
+{
+  return __arm_ld64b (p);
+}
diff --git a/gcc/testsuite/gcc.target/aarch64/acle/ls64_guard-4.c b/gcc/testsuite/gcc.target/aarch64/acle/ls64_guard-4.c
new file mode 100644
index 00000000000..af1d9a4241f
--- /dev/null
+++ b/gcc/testsuite/gcc.target/aarch64/acle/ls64_guard-4.c
@@ -0,0 +1,10 @@
+/* { dg-do compile } */
+/* { dg-additional-options "-march=armv8-a+ls64" } */
+
+#include <arm_acle.h>
+
+#pragma GCC target("arch=armv8.6-a")
+data512_t foo (void * p)
+{
+  return __arm_ld64b (p); /* { dg-error {ACLE function '__arm_ld64b' requires ISA extension 'ls64'} } */
+}

commit 3b8a67b0cfc072f027eab24fb72d48d10cc890b4
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Tue Aug 20 17:52:22 2024

    libstdc++: Fix std::variant to reject array types [PR116381]
    
    For the backport, rejecting array types is only done in strict modes.
    
    libstdc++-v3/ChangeLog:
    
            PR libstdc++/116381
            * include/std/variant (variant): Fix conditions for
            static_assert to match the spec.
            * testsuite/20_util/variant/types_neg.cc: New test.
    
    (cherry picked from commit 1e10b3b8825ee398f077500af6ae1f5db180983a)

diff --git a/libstdc++-v3/include/std/variant b/libstdc++-v3/include/std/variant
index 4e56134a6f7..834bb548f13 100644
--- a/libstdc++-v3/include/std/variant
+++ b/libstdc++-v3/include/std/variant
@@ -1374,10 +1374,13 @@ namespace __variant
 
       static_assert(sizeof...(_Types) > 0,
 		    "variant must have at least one alternative");
-      static_assert(!(std::is_reference_v<_Types> || ...),
-		    "variant must have no reference alternative");
-      static_assert(!(std::is_void_v<_Types> || ...),
-		    "variant must have no void alternative");
+#ifdef __STRICT_ANSI__
+      static_assert(((std::is_object_v<_Types> && !is_array_v<_Types>) && ...),
+		    "variant alternatives must be non-array object types");
+#else
+      static_assert((std::is_object_v<_Types> && ...),
+		    "variant alternatives must be object types");
+#endif
 
       using _Base = __detail::__variant::_Variant_base<_Types...>;
 
diff --git a/libstdc++-v3/testsuite/20_util/variant/types_neg.cc b/libstdc++-v3/testsuite/20_util/variant/types_neg.cc
new file mode 100644
index 00000000000..7d970e961c2
--- /dev/null
+++ b/libstdc++-v3/testsuite/20_util/variant/types_neg.cc
@@ -0,0 +1,18 @@
+// { dg-do compile { target c++17 } }
+// { dg-add-options strict_std }
+
+# include <variant>
+
+std::variant<> v0; // { dg-error "here" }
+// { dg-error "must have at least one alternative" "" { target *-*-* } 0 }
+std::variant<int, void> v1; // { dg-error "here" }
+std::variant<int, const void> v2; // { dg-error "here" }
+std::variant<int, int&> v3; // { dg-error "here" }
+std::variant<int, void()> v4; // { dg-error "here" }
+std::variant<int, int[]> v5; // { dg-error "here" }
+std::variant<int, int[1]> v6; // { dg-error "here" }
+// { dg-error "must be non-array object types" "" { target *-*-* } 0 }
+
+// All of variant's base classes are instantiated before checking any
+// static_assert, so we get lots of errors before the expected errors above.
+// { dg-excess-errors "" }

commit 469602619d32c24382c6f1c3e3d95c3db606c770
Author: Dhruv Chawla <dhruvc@nvidia.com>
Date:   Mon Aug 26 07:39:19 2024

    libstdc++: Add missing feature-test macro in various headers
    
    version.syn#2 requires various headers to define
    __cpp_lib_allocator_traits_is_always_equal. Currently, only <memory> was
    defining this macro. Implement fixes for the other headers as well.
    
    Signed-off-by: Dhruv Chawla <dhruvc@nvidia.com>
    
    libstdc++-v3/ChangeLog:
    
            * include/std/deque: Define macro
            __glibcxx_want_allocator_traits_is_always_equal.
            * include/std/forward_list: Likewise.
            * include/std/list: Likewise.
            * include/std/map: Likewise.
            * include/std/scoped_allocator: Likewise.
            * include/std/set: Likewise.
            * include/std/string: Likewise.
            * include/std/unordered_map: Likewise.
            * include/std/unordered_set: Likewise.
            * include/std/vector: Likewise.
            * testsuite/20_util/headers/memory/version.cc: New test.
            * testsuite/20_util/scoped_allocator/version.cc: Likewise.
            * testsuite/21_strings/headers/string/version.cc: Likewise.
            * testsuite/23_containers/deque/version.cc: Likewise.
            * testsuite/23_containers/forward_list/version.cc: Likewise.
            * testsuite/23_containers/list/version.cc: Likewise.
            * testsuite/23_containers/map/version.cc: Likewise.
            * testsuite/23_containers/set/version.cc: Likewise.
            * testsuite/23_containers/unordered_map/version.cc: Likewise.
            * testsuite/23_containers/unordered_set/version.cc: Likewise.
            * testsuite/23_containers/vector/version.cc: Likewise.
    
    (cherry picked from commit efe6efb6f315c7f97be8a850e0a84ff7f6651d85)

diff --git a/libstdc++-v3/include/std/deque b/libstdc++-v3/include/std/deque
index 0bf8309c19a..69f8c0dcdcc 100644
--- a/libstdc++-v3/include/std/deque
+++ b/libstdc++-v3/include/std/deque
@@ -68,6 +68,7 @@
 #include <bits/range_access.h>
 #include <bits/deque.tcc>
 
+#define __glibcxx_want_allocator_traits_is_always_equal
 #define __glibcxx_want_erase_if
 #define __glibcxx_want_nonmember_container_access
 #include <bits/version.h>
diff --git a/libstdc++-v3/include/std/forward_list b/libstdc++-v3/include/std/forward_list
index 5ac74360808..dfd7d48d121 100644
--- a/libstdc++-v3/include/std/forward_list
+++ b/libstdc++-v3/include/std/forward_list
@@ -45,6 +45,7 @@
 # include <debug/forward_list>
 #endif
 
+#define __glibcxx_want_allocator_traits_is_always_equal
 #define __glibcxx_want_erase_if
 #define __glibcxx_want_incomplete_container_elements
 #define __glibcxx_want_list_remove_return_type
diff --git a/libstdc++-v3/include/std/list b/libstdc++-v3/include/std/list
index fce4e3d925b..ff632fc1ab2 100644
--- a/libstdc++-v3/include/std/list
+++ b/libstdc++-v3/include/std/list
@@ -69,6 +69,7 @@
 # include <debug/list>
 #endif
 
+#define __glibcxx_want_allocator_traits_is_always_equal
 #define __glibcxx_want_erase_if
 #define __glibcxx_want_incomplete_container_elements
 #define __glibcxx_want_list_remove_return_type
diff --git a/libstdc++-v3/include/std/map b/libstdc++-v3/include/std/map
index 4a96e59a5bc..6520d9f744f 100644
--- a/libstdc++-v3/include/std/map
+++ b/libstdc++-v3/include/std/map
@@ -69,6 +69,7 @@
 # include <debug/map>
 #endif
 
+#define __glibcxx_want_allocator_traits_is_always_equal
 #define __glibcxx_want_erase_if
 #define __glibcxx_want_generic_associative_lookup
 #define __glibcxx_want_map_try_emplace
diff --git a/libstdc++-v3/include/std/scoped_allocator b/libstdc++-v3/include/std/scoped_allocator
index dbe7bf3cbf6..532a44691ba 100644
--- a/libstdc++-v3/include/std/scoped_allocator
+++ b/libstdc++-v3/include/std/scoped_allocator
@@ -43,6 +43,9 @@
 # include <bits/uses_allocator_args.h>
 #endif
 
+#define __glibcxx_want_allocator_traits_is_always_equal
+#include <bits/version.h>
+
 namespace std _GLIBCXX_VISIBILITY(default)
 {
 _GLIBCXX_BEGIN_NAMESPACE_VERSION
diff --git a/libstdc++-v3/include/std/set b/libstdc++-v3/include/std/set
index bf2474c7eb2..95cc8005a19 100644
--- a/libstdc++-v3/include/std/set
+++ b/libstdc++-v3/include/std/set
@@ -69,6 +69,7 @@
 # include <debug/set>
 #endif
 
+#define __glibcxx_want_allocator_traits_is_always_equal
 #define __glibcxx_want_erase_if
 #define __glibcxx_want_generic_associative_lookup
 #define __glibcxx_want_node_extract
diff --git a/libstdc++-v3/include/std/string b/libstdc++-v3/include/std/string
index 55144409cca..8db0802a282 100644
--- a/libstdc++-v3/include/std/string
+++ b/libstdc++-v3/include/std/string
@@ -54,6 +54,7 @@
 #include <bits/basic_string.h>
 #include <bits/basic_string.tcc>
 
+#define __glibcxx_want_allocator_traits_is_always_equal
 #define __glibcxx_want_constexpr_char_traits
 #define __glibcxx_want_constexpr_string
 #define __glibcxx_want_erase_if
diff --git a/libstdc++-v3/include/std/unordered_map b/libstdc++-v3/include/std/unordered_map
index ea6129d6494..f9a948c3873 100644
--- a/libstdc++-v3/include/std/unordered_map
+++ b/libstdc++-v3/include/std/unordered_map
@@ -46,6 +46,7 @@
 # include <debug/unordered_map>
 #endif
 
+#define __glibcxx_want_allocator_traits_is_always_equal
 #define __glibcxx_want_erase_if
 #define __glibcxx_want_generic_unordered_lookup
 #define __glibcxx_want_node_extract
diff --git a/libstdc++-v3/include/std/unordered_set b/libstdc++-v3/include/std/unordered_set
index a48fe0cd563..aa5b702ff4d 100644
--- a/libstdc++-v3/include/std/unordered_set
+++ b/libstdc++-v3/include/std/unordered_set
@@ -46,6 +46,7 @@
 # include <debug/unordered_set>
 #endif
 
+#define __glibcxx_want_allocator_traits_is_always_equal
 #define __glibcxx_want_erase_if
 #define __glibcxx_want_generic_unordered_lookup
 #define __glibcxx_want_node_extract
diff --git a/libstdc++-v3/include/std/vector b/libstdc++-v3/include/std/vector
index a1f7ef86824..906c1627935 100644
--- a/libstdc++-v3/include/std/vector
+++ b/libstdc++-v3/include/std/vector
@@ -76,6 +76,7 @@
 # include <debug/vector>
 #endif
 
+#define __glibcxx_want_allocator_traits_is_always_equal
 #define __glibcxx_want_constexpr_vector
 #define __glibcxx_want_erase_if
 #define __glibcxx_want_incomplete_container_elements
diff --git a/libstdc++-v3/testsuite/20_util/headers/memory/version.cc b/libstdc++-v3/testsuite/20_util/headers/memory/version.cc
new file mode 100644
index 00000000000..c82c9a018e0
--- /dev/null
+++ b/libstdc++-v3/testsuite/20_util/headers/memory/version.cc
@@ -0,0 +1,8 @@
+// { dg-do preprocess { target c++17 } }
+// { dg-add-options no_pch }
+
+#include <memory>
+
+#if __cpp_lib_allocator_traits_is_always_equal != 201411L
+# error "Feature-test macro __cpp_lib_allocator_traits_is_always_equal has wrong value in <version>"
+#endif
diff --git a/libstdc++-v3/testsuite/20_util/scoped_allocator/version.cc b/libstdc++-v3/testsuite/20_util/scoped_allocator/version.cc
new file mode 100644
index 00000000000..c5a1b11a739
--- /dev/null
+++ b/libstdc++-v3/testsuite/20_util/scoped_allocator/version.cc
@@ -0,0 +1,8 @@
+// { dg-do preprocess { target c++17 } }
+// { dg-add-options no_pch }
+
+#include <scoped_allocator>
+
+#if __cpp_lib_allocator_traits_is_always_equal != 201411L
+# error "Feature-test macro __cpp_lib_allocator_traits_is_always_equal has wrong value in <version>"
+#endif
diff --git a/libstdc++-v3/testsuite/21_strings/headers/string/version.cc b/libstdc++-v3/testsuite/21_strings/headers/string/version.cc
new file mode 100644
index 00000000000..a546b75b3fe
--- /dev/null
+++ b/libstdc++-v3/testsuite/21_strings/headers/string/version.cc
@@ -0,0 +1,8 @@
+// { dg-do preprocess { target c++17 } }
+// { dg-add-options no_pch }
+
+#include <string>
+
+#if __cpp_lib_allocator_traits_is_always_equal != 201411L
+# error "Feature-test macro __cpp_lib_allocator_traits_is_always_equal has wrong value in <version>"
+#endif
diff --git a/libstdc++-v3/testsuite/23_containers/deque/version.cc b/libstdc++-v3/testsuite/23_containers/deque/version.cc
new file mode 100644
index 00000000000..09d71cb935d
--- /dev/null
+++ b/libstdc++-v3/testsuite/23_containers/deque/version.cc
@@ -0,0 +1,8 @@
+// { dg-do preprocess { target c++17 } }
+// { dg-add-options no_pch }
+
+#include <deque>
+
+#if __cpp_lib_allocator_traits_is_always_equal != 201411L
+# error "Feature-test macro __cpp_lib_allocator_traits_is_always_equal has wrong value in <version>"
+#endif
diff --git a/libstdc++-v3/testsuite/23_containers/forward_list/version.cc b/libstdc++-v3/testsuite/23_containers/forward_list/version.cc
new file mode 100644
index 00000000000..7a0203978f0
--- /dev/null
+++ b/libstdc++-v3/testsuite/23_containers/forward_list/version.cc
@@ -0,0 +1,8 @@
+// { dg-do preprocess { target c++17 } }
+// { dg-add-options no_pch }
+
+#include <forward_list>
+
+#if __cpp_lib_allocator_traits_is_always_equal != 201411L
+# error "Feature-test macro __cpp_lib_allocator_traits_is_always_equal has wrong value in <version>"
+#endif
diff --git a/libstdc++-v3/testsuite/23_containers/list/version.cc b/libstdc++-v3/testsuite/23_containers/list/version.cc
new file mode 100644
index 00000000000..3ac63e06d90
--- /dev/null
+++ b/libstdc++-v3/testsuite/23_containers/list/version.cc
@@ -0,0 +1,8 @@
+// { dg-do preprocess { target c++17 } }
+// { dg-add-options no_pch }
+
+#include <list>
+
+#if __cpp_lib_allocator_traits_is_always_equal != 201411L
+# error "Feature-test macro __cpp_lib_allocator_traits_is_always_equal has wrong value in <version>"
+#endif
diff --git a/libstdc++-v3/testsuite/23_containers/map/version.cc b/libstdc++-v3/testsuite/23_containers/map/version.cc
new file mode 100644
index 00000000000..31a228d365d
--- /dev/null
+++ b/libstdc++-v3/testsuite/23_containers/map/version.cc
@@ -0,0 +1,8 @@
+// { dg-do preprocess { target c++17 } }
+// { dg-add-options no_pch }
+
+#include <map>
+
+#if __cpp_lib_allocator_traits_is_always_equal != 201411L
+# error "Feature-test macro __cpp_lib_allocator_traits_is_always_equal has wrong value in <version>"
+#endif
diff --git a/libstdc++-v3/testsuite/23_containers/set/version.cc b/libstdc++-v3/testsuite/23_containers/set/version.cc
new file mode 100644
index 00000000000..eb49b2353c3
--- /dev/null
+++ b/libstdc++-v3/testsuite/23_containers/set/version.cc
@@ -0,0 +1,8 @@
+// { dg-do preprocess { target c++17 } }
+// { dg-add-options no_pch }
+
+#include <set>
+
+#if __cpp_lib_allocator_traits_is_always_equal != 201411L
+# error "Feature-test macro __cpp_lib_allocator_traits_is_always_equal has wrong value in <version>"
+#endif
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_map/version.cc b/libstdc++-v3/testsuite/23_containers/unordered_map/version.cc
new file mode 100644
index 00000000000..946d7c295d5
--- /dev/null
+++ b/libstdc++-v3/testsuite/23_containers/unordered_map/version.cc
@@ -0,0 +1,8 @@
+// { dg-do preprocess { target c++17 } }
+// { dg-add-options no_pch }
+
+#include <unordered_map>
+
+#if __cpp_lib_allocator_traits_is_always_equal != 201411L
+# error "Feature-test macro __cpp_lib_allocator_traits_is_always_equal has wrong value in <version>"
+#endif
diff --git a/libstdc++-v3/testsuite/23_containers/unordered_set/version.cc b/libstdc++-v3/testsuite/23_containers/unordered_set/version.cc
new file mode 100644
index 00000000000..d22adfb420e
--- /dev/null
+++ b/libstdc++-v3/testsuite/23_containers/unordered_set/version.cc
@@ -0,0 +1,8 @@
+// { dg-do preprocess { target c++17 } }
+// { dg-add-options no_pch }
+
+#include <unordered_set>
+
+#if __cpp_lib_allocator_traits_is_always_equal != 201411L
+# error "Feature-test macro __cpp_lib_allocator_traits_is_always_equal has wrong value in <version>"
+#endif
diff --git a/libstdc++-v3/testsuite/23_containers/vector/version.cc b/libstdc++-v3/testsuite/23_containers/vector/version.cc
new file mode 100644
index 00000000000..0c8e4150abc
--- /dev/null
+++ b/libstdc++-v3/testsuite/23_containers/vector/version.cc
@@ -0,0 +1,8 @@
+// { dg-do preprocess { target c++17 } }
+// { dg-add-options no_pch }
+
+#include <vector>
+
+#if __cpp_lib_allocator_traits_is_always_equal != 201411L
+# error "Feature-test macro __cpp_lib_allocator_traits_is_always_equal has wrong value in <version>"
+#endif

commit ee37d750262579a81799c5b56fe1ab936a840120
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Mon Sep 2 12:29:13 2024

    libstdc++: Specialize std::disable_sized_sentinel_for for std::move_iterator [PR116549]
    
    LWG 3736 added a partial specialization of this variable template for
    two std::move_iterator types. This is needed for the case where the
    types satisfy std::sentinel_for and are subtractable, but do not model
    the semantics requirements of std::sized_sentinel_for.
    
    libstdc++-v3/ChangeLog:
    
            PR libstdc++/116549
            * include/bits/stl_iterator.h (disable_sized_sentinel_for):
            Define specialization for two move_iterator types, as per LWG
            3736.
            * testsuite/24_iterators/move_iterator/lwg3736.cc: New test.
    
    (cherry picked from commit 819deae0a5bee079a7d5582fafaa098c26144ae8)

diff --git a/libstdc++-v3/include/bits/stl_iterator.h b/libstdc++-v3/include/bits/stl_iterator.h
index d3823057270..20c0319f3a7 100644
--- a/libstdc++-v3/include/bits/stl_iterator.h
+++ b/libstdc++-v3/include/bits/stl_iterator.h
@@ -1822,6 +1822,14 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
     { return _ReturnType(__i); }
 
 #if __cplusplus > 201703L && __glibcxx_concepts
+  // _GLIBCXX_RESOLVE_LIB_DEFECTS
+  // 3736.  move_iterator missing disable_sized_sentinel_for specialization
+  template<typename _Iterator1, typename _Iterator2>
+    requires (!sized_sentinel_for<_Iterator1, _Iterator2>)
+    inline constexpr bool
+    disable_sized_sentinel_for<move_iterator<_Iterator1>,
+			       move_iterator<_Iterator2>> = true;
+
   // [iterators.common] Common iterators
 
   namespace __detail
diff --git a/libstdc++-v3/testsuite/24_iterators/move_iterator/lwg3736.cc b/libstdc++-v3/testsuite/24_iterators/move_iterator/lwg3736.cc
new file mode 100644
index 00000000000..eaf791b3089
--- /dev/null
+++ b/libstdc++-v3/testsuite/24_iterators/move_iterator/lwg3736.cc
@@ -0,0 +1,52 @@
+// { dg-do compile { target c++20 } }
+
+// 3736.  move_iterator missing disable_sized_sentinel_for specialization
+
+#include <iterator>
+
+template<typename Iter> using MoveIter = std::move_iterator<Iter>;
+
+using std::sized_sentinel_for;
+using std::disable_sized_sentinel_for;
+
+// These assertions always passed, even without LWG 3736:
+static_assert(sized_sentinel_for<MoveIter<int*>, MoveIter<int*>>);
+static_assert(sized_sentinel_for<MoveIter<int*>, MoveIter<const int*>>);
+static_assert(not sized_sentinel_for<MoveIter<int*>, MoveIter<long*>>);
+static_assert(not sized_sentinel_for<MoveIter<int*>, std::default_sentinel_t>);
+static_assert(not disable_sized_sentinel_for<MoveIter<int*>, MoveIter<int*>>);
+
+// These types don't satisfy sized_sentinel_for anyway (because the subtraction
+// is ill-formed) but LWG 3736 makes the variable template explicitly false:
+static_assert(disable_sized_sentinel_for<MoveIter<int*>, MoveIter<long*>>);
+
+struct Iter
+{
+  using iterator_category = std::random_access_iterator_tag;
+  using value_type = int;
+  using pointer = int*;
+  using reference = int&;
+  using difference_type = long;
+
+  Iter() = default;
+  Iter& operator++();
+  Iter operator++(int);
+  Iter& operator--();
+  Iter operator--(int);
+  reference operator*() const;
+  pointer operator->() const;
+  Iter& operator+=(difference_type);
+  Iter& operator-=(difference_type);
+  friend Iter operator+(Iter, difference_type);
+  friend Iter operator+(difference_type, Iter);
+  friend Iter operator-(Iter, difference_type);
+  friend difference_type operator-(Iter, Iter);
+  bool operator==(Iter) const;
+};
+
+// Specialize the variable template so that Iter is not its own sized sentinel:
+template<> constexpr bool std::disable_sized_sentinel_for<Iter, Iter> = true;
+static_assert( not sized_sentinel_for<Iter, Iter> );
+
+// LWG 3736 means that affects std::move_iterator<Iter> as well:
+static_assert( not sized_sentinel_for<MoveIter<Iter>, MoveIter<Iter>> );

commit ec1bcd176339d43fd1ab3211f65915824ba1f26b
Author: Lennox Shou Hao Ho <lennoxhoe@gmail.com>
Date:   Mon Jul 29 22:09:27 2024

    libstdc++: Fix fs::hard_link_count behaviour on MinGW [PR113663]
    
    std::filesystem::hard_link_count() always returns 1 on
    mingw-w64ucrt-11.0.1-r3 on Windows 10 19045
    
    hard_link_count() queries _wstat64() on MinGW-w64
    The MSFT documentation claims _wstat64() will always return 1 *non*-NTFS volumes
    https://learn.microsoft.com/en-us/previous-versions/visualstudio/visual-studio-2013/14h5k7ff(v=vs.120)
    
    My tests suggest that is not always true -
    hard_link_count()/_wstat64() still returns 1 on NTFS.
    GetFileInformationByHandle does return the correct result of 2.
    Please see the PR for a minimal repro.
    
    This patch changes the Windows implementation to always call
    GetFileInformationByHandle.
    
            PR libstdc++/113663
    
    libstdc++-v3/ChangeLog:
    
            * src/c++17/fs_ops.cc (fs::equivalent): Moved helper class
            auto_handle to anonymous namespace as auto_win_file_handle.
            (fs::hard_link_count): Changed Windows implementation to use
            information provided by GetFileInformationByHandle which is more
            reliable.
            * testsuite/27_io/filesystem/operations/hard_link_count.cc: New
            test.
    
    Signed-off-by: "Lennox" Shou Hao Ho <lennoxhoe@gmail.com>
    Reviewed-by: Jonathan Wakely <jwakely@redhat.com>
    (cherry picked from commit 658193658f05e9a8ebf0bce8bab15555f43bfee1)

diff --git a/libstdc++-v3/src/c++17/fs_ops.cc b/libstdc++-v3/src/c++17/fs_ops.cc
index 07bc2a0fa88..81227c49dfd 100644
--- a/libstdc++-v3/src/c++17/fs_ops.cc
+++ b/libstdc++-v3/src/c++17/fs_ops.cc
@@ -822,6 +822,34 @@ fs::equivalent(const path& p1, const path& p2)
   return result;
 }
 
+#if _GLIBCXX_FILESYSTEM_IS_WINDOWS
+namespace
+{
+  // An RAII type that opens a handle for an existing file.
+  struct auto_win_file_handle
+  {
+    explicit
+    auto_win_file_handle(const fs::path& p_)
+    : handle(CreateFileW(p_.c_str(), 0,
+			 FILE_SHARE_DELETE | FILE_SHARE_READ | FILE_SHARE_WRITE,
+			 0, OPEN_EXISTING, FILE_FLAG_BACKUP_SEMANTICS, 0))
+    { }
+
+    ~auto_win_file_handle()
+    { if (*this) CloseHandle(handle); }
+
+    explicit operator bool() const
+    { return handle != INVALID_HANDLE_VALUE; }
+
+    bool get_info()
+    { return GetFileInformationByHandle(handle, &info); }
+
+    HANDLE handle;
+    BY_HANDLE_FILE_INFORMATION info;
+  };
+}
+#endif
+
 bool
 fs::equivalent(const path& p1, const path& p2, error_code& ec) noexcept
 {
@@ -858,27 +886,8 @@ fs::equivalent(const path& p1, const path& p2, error_code& ec) noexcept
       if (st1.st_mode != st2.st_mode || st1.st_dev != st2.st_dev)
 	return false;
 
-      struct auto_handle {
-	explicit auto_handle(const path& p_)
-	: handle(CreateFileW(p_.c_str(), 0,
-	      FILE_SHARE_DELETE | FILE_SHARE_READ | FILE_SHARE_WRITE,
-	      0, OPEN_EXISTING, FILE_FLAG_BACKUP_SEMANTICS, 0))
-	{ }
-
-	~auto_handle()
-	{ if (*this) CloseHandle(handle); }
-
-	explicit operator bool() const
-	{ return handle != INVALID_HANDLE_VALUE; }
-
-	bool get_info()
-	{ return GetFileInformationByHandle(handle, &info); }
-
-	HANDLE handle;
-	BY_HANDLE_FILE_INFORMATION info;
-      };
-      auto_handle h1(p1);
-      auto_handle h2(p2);
+      auto_win_file_handle h1(p1);
+      auto_win_file_handle h2(p2);
       if (!h1 || !h2)
 	{
 	  if (!h1 && !h2)
@@ -982,7 +991,13 @@ fs::hard_link_count(const path& p)
 std::uintmax_t
 fs::hard_link_count(const path& p, error_code& ec) noexcept
 {
-#ifdef _GLIBCXX_HAVE_SYS_STAT_H
+#if _GLIBCXX_FILESYSTEM_IS_WINDOWS
+  auto_win_file_handle h(p);
+  if (h && h.get_info())
+    return static_cast<uintmax_t>(h.info.nNumberOfLinks);
+  ec = __last_system_error();
+  return static_cast<uintmax_t>(-1);
+#elif defined _GLIBCXX_HAVE_SYS_STAT_H
   return do_stat(p, ec, std::mem_fn(&stat_type::st_nlink),
 		 static_cast<uintmax_t>(-1));
 #else
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/hard_link_count.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/hard_link_count.cc
new file mode 100644
index 00000000000..8b2fb4f190e
--- /dev/null
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/hard_link_count.cc
@@ -0,0 +1,37 @@
+// { dg-do run { target c++17 } }
+// { dg-require-filesystem-ts "" }
+
+#include <filesystem>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+namespace fs = std::filesystem;
+
+void test01()
+{
+  // PR libstdc++/113663
+
+  fs::path p1 = __gnu_test::nonexistent_path();
+  VERIFY( !fs::exists(p1) );
+
+  __gnu_test::scoped_file f1(p1);
+  VERIFY( fs::exists(p1) );
+
+  VERIFY( fs::hard_link_count(p1) == 1 );
+
+  fs::path p2 = __gnu_test::nonexistent_path();
+  VERIFY( !fs::exists(p2) );
+
+  fs::create_hard_link(p1, p2);
+  __gnu_test::scoped_file f2(p2, __gnu_test::scoped_file::adopt_file);
+  VERIFY( fs::exists(p2) );
+
+  VERIFY( fs::hard_link_count(p1) == 2 );
+  VERIFY( fs::hard_link_count(p2) == 2 );
+}
+
+int
+main()
+{
+  test01();
+}

commit 35c98149a5c7af9159fa7615d8d827b3aaa3cc97
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Tue Jul 30 11:55:55 2024

    libstdc++: Fix overwriting files with fs::copy_file on Windows
    
    There are no inode numbers on Windows filesystems, so stat_type::st_ino
    is always zero and the check for equivalent files in do_copy_file was
    incorrectly identifying distinct files as equivalent. This caused
    copy_file to incorrectly report errors when trying to overwrite existing
    files.
    
    The fs::equivalent function already does the right thing on Windows, so
    factor that logic out into a new function that can be reused by
    fs::copy_file.
    
    The tests for fs::copy_file were quite inadequate, so this also adds
    checks for that function's error conditions.
    
    libstdc++-v3/ChangeLog:
    
            * src/c++17/fs_ops.cc (auto_win_file_handle): Change constructor
            parameter from const path& to const wchar_t*.
            (fs::equiv_files): New function.
            (fs::equivalent): Use equiv_files.
            * src/filesystem/ops-common.h (fs::equiv_files): Declare.
            (do_copy_file): Use equiv_files.
            * src/filesystem/ops.cc (fs::equiv_files): Define.
            (fs::copy, fs::equivalent): Use equiv_files.
            * testsuite/27_io/filesystem/operations/copy.cc: Test
            overwriting directory contents recursively.
            * testsuite/27_io/filesystem/operations/copy_file.cc: Test
            overwriting existing files.
    
    (cherry picked from commit 017e3f89b081e4828a588a3bd27b5feacea042b7)

diff --git a/libstdc++-v3/src/c++17/fs_ops.cc b/libstdc++-v3/src/c++17/fs_ops.cc
index 81227c49dfd..9606afa9f1f 100644
--- a/libstdc++-v3/src/c++17/fs_ops.cc
+++ b/libstdc++-v3/src/c++17/fs_ops.cc
@@ -350,7 +350,7 @@ fs::copy(const path& from, const path& to, copy_options options,
   f = make_file_status(from_st);
 
   if (exists(t) && !is_other(t) && !is_other(f)
-      && to_st.st_dev == from_st.st_dev && to_st.st_ino == from_st.st_ino)
+      && fs::equiv_files(from.c_str(), from_st, to.c_str(), to_st, ec))
     {
       ec = std::make_error_code(std::errc::file_exists);
       return;
@@ -829,8 +829,8 @@ namespace
   struct auto_win_file_handle
   {
     explicit
-    auto_win_file_handle(const fs::path& p_)
-    : handle(CreateFileW(p_.c_str(), 0,
+    auto_win_file_handle(const wchar_t* p)
+    : handle(CreateFileW(p, 0,
 			 FILE_SHARE_DELETE | FILE_SHARE_READ | FILE_SHARE_WRITE,
 			 0, OPEN_EXISTING, FILE_FLAG_BACKUP_SEMANTICS, 0))
     { }
@@ -850,6 +850,44 @@ namespace
 }
 #endif
 
+#ifdef _GLIBCXX_HAVE_SYS_STAT_H
+#ifdef NEED_DO_COPY_FILE // Only define this once, not in cow-fs_ops.o too
+bool
+fs::equiv_files([[maybe_unused]] const char_type* p1, const stat_type& st1,
+		[[maybe_unused]] const char_type* p2, const stat_type& st2,
+		[[maybe_unused]] error_code& ec)
+{
+#if ! _GLIBCXX_FILESYSTEM_IS_WINDOWS
+  // For POSIX the device ID and inode number uniquely identify a file.
+  return st1.st_dev == st2.st_dev && st1.st_ino == st2.st_ino;
+#else
+  // For Windows st_ino is not set, so can't be used to distinguish files.
+  // We can compare modes and device IDs as a cheap initial check:
+  if (st1.st_mode != st2.st_mode || st1.st_dev != st2.st_dev)
+    return false;
+
+  // Need to use GetFileInformationByHandle to get more info about the files.
+  auto_win_file_handle h1(p1);
+  auto_win_file_handle h2(p2);
+  if (!h1 || !h2)
+    {
+      if (!h1 && !h2)
+	ec = __last_system_error();
+      return false;
+    }
+  if (!h1.get_info() || !h2.get_info())
+    {
+      ec = __last_system_error();
+      return false;
+    }
+  return h1.info.dwVolumeSerialNumber == h2.info.dwVolumeSerialNumber
+	   && h1.info.nFileIndexHigh == h2.info.nFileIndexHigh
+	   && h1.info.nFileIndexLow == h2.info.nFileIndexLow;
+#endif // _GLIBCXX_FILESYSTEM_IS_WINDOWS
+}
+#endif // NEED_DO_COPY_FILE
+#endif // _GLIBCXX_HAVE_SYS_STAT_H
+
 bool
 fs::equivalent(const path& p1, const path& p2, error_code& ec) noexcept
 {
@@ -881,30 +919,7 @@ fs::equivalent(const path& p1, const path& p2, error_code& ec) noexcept
       ec.clear();
       if (is_other(s1) || is_other(s2))
 	return false;
-#if _GLIBCXX_FILESYSTEM_IS_WINDOWS
-      // st_ino is not set, so can't be used to distinguish files
-      if (st1.st_mode != st2.st_mode || st1.st_dev != st2.st_dev)
-	return false;
-
-      auto_win_file_handle h1(p1);
-      auto_win_file_handle h2(p2);
-      if (!h1 || !h2)
-	{
-	  if (!h1 && !h2)
-	    ec = __last_system_error();
-	  return false;
-	}
-      if (!h1.get_info() || !h2.get_info())
-	{
-	  ec = __last_system_error();
-	  return false;
-	}
-      return h1.info.dwVolumeSerialNumber == h2.info.dwVolumeSerialNumber
-	&& h1.info.nFileIndexHigh == h2.info.nFileIndexHigh
-	&& h1.info.nFileIndexLow == h2.info.nFileIndexLow;
-#else
-      return st1.st_dev == st2.st_dev && st1.st_ino == st2.st_ino;
-#endif
+      return fs::equiv_files(p1.c_str(), st1, p2.c_str(), st2, ec);
     }
   else if (!exists(s1) || !exists(s2))
     ec = std::make_error_code(std::errc::no_such_file_or_directory);
@@ -992,7 +1007,7 @@ std::uintmax_t
 fs::hard_link_count(const path& p, error_code& ec) noexcept
 {
 #if _GLIBCXX_FILESYSTEM_IS_WINDOWS
-  auto_win_file_handle h(p);
+  auto_win_file_handle h(p.c_str());
   if (h && h.get_info())
     return static_cast<uintmax_t>(h.info.nNumberOfLinks);
   ec = __last_system_error();
diff --git a/libstdc++-v3/src/filesystem/ops-common.h b/libstdc++-v3/src/filesystem/ops-common.h
index d917fddbeb1..1be8d754d6f 100644
--- a/libstdc++-v3/src/filesystem/ops-common.h
+++ b/libstdc++-v3/src/filesystem/ops-common.h
@@ -303,7 +303,6 @@ namespace __gnu_posix
   {
     bool skip, update, overwrite;
   };
-
 #endif // _GLIBCXX_HAVE_SYS_STAT_H
 
 } // namespace filesystem
@@ -327,6 +326,12 @@ _GLIBCXX_BEGIN_NAMESPACE_FILESYSTEM
 	   std::error_code&);
 
 
+  // Test whether two files are the same file.
+  bool
+  equiv_files(const char_type*, const stat_type&,
+	      const char_type*, const stat_type&,
+	      error_code&);
+
   inline file_type
   make_file_type(const stat_type& st) noexcept
   {
@@ -400,6 +405,7 @@ _GLIBCXX_BEGIN_NAMESPACE_FILESYSTEM
     return true;
   }
 #endif
+
 #if defined _GLIBCXX_USE_SENDFILE && ! defined _GLIBCXX_FILESYSTEM_IS_WINDOWS
   bool
   copy_file_sendfile(int fd_in, int fd_out, size_t length) noexcept
@@ -428,6 +434,7 @@ _GLIBCXX_BEGIN_NAMESPACE_FILESYSTEM
     return true;
   }
 #endif
+
   bool
   do_copy_file(const char_type* from, const char_type* to,
 	       std::filesystem::copy_options_existing_file options,
@@ -489,8 +496,7 @@ _GLIBCXX_BEGIN_NAMESPACE_FILESYSTEM
 	    return false;
 	  }
 
-	if (to_st->st_dev == from_st->st_dev
-	    && to_st->st_ino == from_st->st_ino)
+	if (equiv_files(from, *from_st, to, *to_st, ec))
 	  {
 	    ec = std::make_error_code(std::errc::file_exists);
 	    return false;
diff --git a/libstdc++-v3/src/filesystem/ops.cc b/libstdc++-v3/src/filesystem/ops.cc
index 4d23a804da0..c430f58c47a 100644
--- a/libstdc++-v3/src/filesystem/ops.cc
+++ b/libstdc++-v3/src/filesystem/ops.cc
@@ -257,6 +257,20 @@ namespace
 
 } // namespace
 
+#ifdef _GLIBCXX_HAVE_SYS_STAT_H
+#ifdef NEED_DO_COPY_FILE // Only define this once, not in cow-ops.o too
+bool
+fs::equiv_files([[maybe_unused]] const char_type* p1, const stat_type& st1,
+		[[maybe_unused]] const char_type* p2, const stat_type& st2,
+		[[maybe_unused]] error_code& ec)
+{
+  // For POSIX the device ID and inode number uniquely identify a file.
+  // This doesn't work on Windows (see equiv_files in src/c++17/fs_ops.cc).
+  return st1.st_dev == st2.st_dev && st1.st_ino == st2.st_ino;
+}
+#endif
+#endif
+
 void
 fs::copy(const path& from, const path& to, copy_options options,
 	 error_code& ec) noexcept
@@ -293,7 +307,7 @@ fs::copy(const path& from, const path& to, copy_options options,
   f = make_file_status(from_st);
 
   if (exists(t) && !is_other(t) && !is_other(f)
-      && to_st.st_dev == from_st.st_dev && to_st.st_ino == from_st.st_ino)
+      && fs::equiv_files(from.c_str(), from_st, to.c_str(), to_st, ec))
     {
       ec = std::make_error_code(std::errc::file_exists);
       return;
@@ -763,7 +777,7 @@ fs::equivalent(const path& p1, const path& p2, error_code& ec) noexcept
       ec.clear();
       if (is_other(s1) || is_other(s2))
 	return false;
-      return st1.st_dev == st2.st_dev && st1.st_ino == st2.st_ino;
+      return fs::equiv_files(p1.c_str(), st1, p2.c_str(), st2, ec);
     }
   else if (!exists(s1) || !exists(s2))
     ec = std::make_error_code(std::errc::no_such_file_or_directory);
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/copy.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/copy.cc
index 777a9b8402e..893f32297ae 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/copy.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/copy.cc
@@ -216,6 +216,15 @@ test_pr99290()
   }
 #endif
 
+  // https://github.com/msys2/MSYS2-packages/issues/1937
+  auto copy_opts
+    = fs::copy_options::overwrite_existing | fs::copy_options::recursive;
+  copy(source, dest, copy_opts, ec);
+  VERIFY( !ec );
+
+  auto ch = std::ifstream{dest/"file"}.get();
+  VERIFY( ch == 'a' );
+
   remove_all(dir);
 }
 
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/copy_file.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/copy_file.cc
index e3a1219fa6e..af643151044 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/copy_file.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/copy_file.cc
@@ -76,8 +76,130 @@ test01()
   remove(to);
 }
 
+void
+test_directory()
+{
+  std::error_code ec;
+
+  auto dir = __gnu_test::nonexistent_path();
+  auto file = __gnu_test::nonexistent_path();
+
+  // error condition: is_regular_file(from) is false
+  create_directory(dir);
+  bool b = copy_file(dir, file, ec);
+  VERIFY( !b );
+  VERIFY( ec == std::errc::invalid_argument );
+  VERIFY( !exists(file) );
+  VERIFY( is_directory(dir) );
+
+  ec = std::make_error_code(std::errc::address_in_use);
+  // error condition: exists(to) is true and is_regular_file(to) is false
+  std::ofstream{file} << "regular file";
+  b = copy_file(file, dir, ec);
+  VERIFY( !b );
+  VERIFY( ec == std::errc::invalid_argument );
+  VERIFY( exists(file) );
+  VERIFY( is_directory(dir) );
+
+  remove(dir);
+  remove(file);
+}
+
+void
+test_existing()
+{
+  using std::filesystem::copy_options;
+  std::error_code ec;
+
+  auto from = __gnu_test::nonexistent_path();
+  auto to = from;
+
+  // error condition: exists(to) is true and equivalent(from, to) is true
+  std::ofstream{from} << "source";
+  bool b = copy_file(from, to, ec);
+  VERIFY( !b );
+  VERIFY( ec == std::errc::file_exists );
+
+  to = __gnu_test::nonexistent_path();
+  std::ofstream{to} << "overwrite me";
+
+  // error condition: exists(to) is true and options == copy_options::none
+  b = copy_file(from, to, ec);
+  VERIFY( !b );
+  VERIFY( ec == std::errc::file_exists );
+  VERIFY( file_size(to) != file_size(from) );
+
+#if __cpp_exceptions
+  try
+  {
+    (void) copy_file(from, to);
+    VERIFY(false);
+  }
+  catch (const std::filesystem::filesystem_error& e)
+  {
+    std::string_view msg = e.what();
+    VERIFY( msg.find(from.string()) != msg.npos );
+    VERIFY( msg.find(to.string()) != msg.npos );
+    VERIFY( e.code() == std::errc::file_exists );
+  }
+  VERIFY( file_size(to) == 12 );
+#endif
+
+  b = copy_file(from, to, copy_options::skip_existing, ec);
+  VERIFY( !b );
+  VERIFY( !ec );
+  VERIFY( file_size(to) != file_size(from) );
+
+  b = copy_file(from, to, copy_options::skip_existing); // doesn't throw
+  VERIFY( !b );
+  VERIFY( file_size(to) != file_size(from) );
+
+  b = copy_file(from, to, copy_options::overwrite_existing, ec);
+  VERIFY( b );
+  VERIFY( !ec );
+  VERIFY( file_size(to) == file_size(from) );
+
+  std::ofstream{to} << "overwrite me again";
+  b = copy_file(from, to, copy_options::overwrite_existing); // doesn't throw
+  VERIFY( b );
+  VERIFY( file_size(to) == file_size(from) );
+
+  ec = std::make_error_code(std::errc::address_in_use);
+  auto time = last_write_time(from);
+  std::ofstream{to} << "touched";
+  last_write_time(to, time + std::chrono::seconds(60));
+  b = copy_file(from, to, copy_options::update_existing, ec);
+  VERIFY( !b );
+  VERIFY( !ec );
+  VERIFY( file_size(to) != file_size(from) );
+
+  b = copy_file(from, to, copy_options::update_existing); // doesn't throw
+  VERIFY( !b );
+  VERIFY( file_size(to) != file_size(from) );
+
+  ec = std::make_error_code(std::errc::address_in_use);
+  time = last_write_time(to);
+  std::ofstream{from} << "touched more recently";
+  last_write_time(from, time + std::chrono::seconds(60));
+  b = copy_file(from, to, copy_options::update_existing, ec);
+  VERIFY( b );
+  VERIFY( !ec );
+  VERIFY( file_size(to) == file_size(from) );
+
+  time = last_write_time(to);
+  std::ofstream{from} << "touched even more recently";
+  last_write_time(from, time + std::chrono::seconds(60));
+  b = copy_file(from, to, copy_options::update_existing); // doesn't throw
+  VERIFY( b );
+  VERIFY( file_size(to) == file_size(from) );
+
+  remove(from);
+  remove(to);
+}
+
 int
 main()
 {
   test01();
+  test_existing();
 }

commit a054ba563bde3dc834c5efac72b91c2803e4e289
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Mon Sep 2 13:16:49 2024

    libstdc++: Fix error handling in fs::hard_link_count for Windows
    
    The recent change to use auto_win_file_handle for
    std::filesystem::hard_link_count caused a regression. The
    std::error_code argument should be cleared if no error occurs, but this
    no longer happens. Add a call to ec.clear() in fs::hard_link_count to
    fix this.
    
    Also change the auto_win_file_handle class to take a reference to the
    std::error_code and set it if an error occurs, to slightly simplify the
    control flow in the fs::equiv_files function.
    
    libstdc++-v3/ChangeLog:
    
            * src/c++17/fs_ops.cc (auto_win_file_handle): Add error_code&
            member and set it if CreateFileW or GetFileInformationByHandle
            fails.
            (fs::equiv_files) [_GLIBCXX_FILESYSTEM_IS_WINDOWS]: Simplify
            control flow.
            (fs::hard_link_count) [_GLIBCXX_FILESYSTEM_IS_WINDOWS]: Clear ec
            on success.
            * testsuite/27_io/filesystem/operations/hard_link_count.cc:
            Check error handling.
    
    (cherry picked from commit 71b1639c67b91554420cc38eb4c82323e535c816)

diff --git a/libstdc++-v3/src/c++17/fs_ops.cc b/libstdc++-v3/src/c++17/fs_ops.cc
index 9606afa9f1f..946fefd9e44 100644
--- a/libstdc++-v3/src/c++17/fs_ops.cc
+++ b/libstdc++-v3/src/c++17/fs_ops.cc
@@ -829,23 +829,37 @@ namespace
   struct auto_win_file_handle
   {
     explicit
-    auto_win_file_handle(const wchar_t* p)
+    auto_win_file_handle(const wchar_t* p, std::error_code& ec) noexcept
     : handle(CreateFileW(p, 0,
 			 FILE_SHARE_DELETE | FILE_SHARE_READ | FILE_SHARE_WRITE,
-			 0, OPEN_EXISTING, FILE_FLAG_BACKUP_SEMANTICS, 0))
-    { }
+			 0, OPEN_EXISTING, FILE_FLAG_BACKUP_SEMANTICS, 0)),
+      ec(ec)
+    {
+      if (handle == INVALID_HANDLE_VALUE)
+	ec = std::__last_system_error();
+    }
 
     ~auto_win_file_handle()
     { if (*this) CloseHandle(handle); }
 
-    explicit operator bool() const
+    explicit operator bool() const noexcept
     { return handle != INVALID_HANDLE_VALUE; }
 
-    bool get_info()
-    { return GetFileInformationByHandle(handle, &info); }
+    bool get_info() noexcept
+    {
+      if (GetFileInformationByHandle(handle, &info))
+	return true;
+      ec = std::__last_system_error();
+      return false;
+    }
 
     HANDLE handle;
     BY_HANDLE_FILE_INFORMATION info;
+    // Like errno, we only set this on error and never clear it.
+    // This propagates an error_code to the caller when something goes wrong,
+    // but the caller should not assume a non-zero ec means an error happened
+    // unless they explicitly cleared it before passing it to our constructor.
+    std::error_code& ec;
   };
 }
 #endif
@@ -866,23 +880,14 @@ fs::equiv_files([[maybe_unused]] const char_type* p1, const stat_type& st1,
   if (st1.st_mode != st2.st_mode || st1.st_dev != st2.st_dev)
     return false;
 
-  // Need to use GetFileInformationByHandle to get more info about the files.
-  auto_win_file_handle h1(p1);
-  auto_win_file_handle h2(p2);
-  if (!h1 || !h2)
-    {
-      if (!h1 && !h2)
-	ec = __last_system_error();
-      return false;
-    }
-  if (!h1.get_info() || !h2.get_info())
-    {
-      ec = __last_system_error();
-      return false;
-    }
-  return h1.info.dwVolumeSerialNumber == h2.info.dwVolumeSerialNumber
-	   && h1.info.nFileIndexHigh == h2.info.nFileIndexHigh
-	   && h1.info.nFileIndexLow == h2.info.nFileIndexLow;
+  // Use GetFileInformationByHandle to get more info about the files.
+  if (auto_win_file_handle h1{p1, ec})
+    if (auto_win_file_handle h2{p2, ec})
+      if (h1.get_info() && h2.get_info())
+	return h1.info.dwVolumeSerialNumber == h2.info.dwVolumeSerialNumber
+		 && h1.info.nFileIndexHigh == h2.info.nFileIndexHigh
+		 && h1.info.nFileIndexLow == h2.info.nFileIndexLow;
+  return false;
 #endif // _GLIBCXX_FILESYSTEM_IS_WINDOWS
 }
 #endif // NEED_DO_COPY_FILE
@@ -1007,10 +1012,12 @@ std::uintmax_t
 fs::hard_link_count(const path& p, error_code& ec) noexcept
 {
 #if _GLIBCXX_FILESYSTEM_IS_WINDOWS
-  auto_win_file_handle h(p.c_str());
+  auto_win_file_handle h(p.c_str(), ec);
   if (h && h.get_info())
-    return static_cast<uintmax_t>(h.info.nNumberOfLinks);
-  ec = __last_system_error();
+    {
+      ec.clear();
+      return static_cast<uintmax_t>(h.info.nNumberOfLinks);
+    }
   return static_cast<uintmax_t>(-1);
 #elif defined _GLIBCXX_HAVE_SYS_STAT_H
   return do_stat(p, ec, std::mem_fn(&stat_type::st_nlink),
diff --git a/libstdc++-v3/testsuite/27_io/filesystem/operations/hard_link_count.cc b/libstdc++-v3/testsuite/27_io/filesystem/operations/hard_link_count.cc
index 8b2fb4f190e..4bff39ca308 100644
--- a/libstdc++-v3/testsuite/27_io/filesystem/operations/hard_link_count.cc
+++ b/libstdc++-v3/testsuite/27_io/filesystem/operations/hard_link_count.cc
@@ -30,8 +30,32 @@ void test01()
   VERIFY( fs::hard_link_count(p2) == 2 );
 }
 
+void
+test02()
+{
+  std::error_code ec;
+  fs::path p1 = __gnu_test::nonexistent_path();
+  VERIFY( fs::hard_link_count(p1, ec) == -1 );
+  VERIFY( ec == std::errc::no_such_file_or_directory );
+
+#if __cpp_exceptions
+  try {
+    fs::hard_link_count(p1); // { dg-warning "ignoring return value" }
+    VERIFY( false );
+  } catch (const fs::filesystem_error& e) {
+    VERIFY( e.path1() == p1 );
+    VERIFY( e.path2().empty() );
+  }
+#endif
+
+  __gnu_test::scoped_file f1(p1);
+  fs::hard_link_count(f1.path, ec);  // { dg-warning "ignoring return value" }
+  VERIFY( !ec ); // Should be cleared on success.
+}
+
 int
 main()
 {
   test01();
+  test02();
 }

commit 0c4a95e9f51a4d7d68574579afe6de9dcea58db2
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Thu Sep 5 02:22:17 2024

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index a494e6dc39a..8bc41ae0aaa 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,56 @@
+2024-09-04  Andrew Carlotti  <andrew.carlotti@arm.com>
+
+	PR target/112108
+	* config/aarch64/aarch64-builtins.cc (handle_arm_acle_h): Remove
+	feature check at initialisation.
+	(aarch64_general_check_builtin_call): Check ls64 intrinsics.
+	* config/aarch64/arm_acle.h: (data512_t) Make always available.
+
+2024-09-04  Andrew Carlotti  <andrew.carlotti@arm.com>
+
+	PR target/112108
+	* config/aarch64/aarch64-builtins.cc (aarch64_init_memtag_builtins):
+	Define intrinsic names directly.
+	(aarch64_general_init_builtins): Move memtag intialisation...
+	(handle_arm_acle_h): ...to here, and remove feature check.
+	(aarch64_general_check_builtin_call): Check memtag intrinsics.
+	* config/aarch64/arm_acle.h (__arm_mte_create_random_tag)
+	(__arm_mte_exclude_tag, __arm_mte_ptrdiff)
+	(__arm_mte_increment_tag, __arm_mte_set_tag, __arm_mte_get_tag):
+	Remove.
+
+2024-09-04  Andrew Carlotti  <andrew.carlotti@arm.com>
+
+	PR target/112108
+	* config/aarch64/aarch64-builtins.cc (aarch64_init_tme_builtins):
+	Define intrinsic names directly.
+	(aarch64_general_init_builtins): Move tme initialisation...
+	(handle_arm_acle_h): ...to here, and remove feature check.
+	(aarch64_general_check_builtin_call): Check tme intrinsics.
+	* config/aarch64/arm_acle.h (__tstart, __tcommit, __tcancel)
+	(__ttest): Remove.
+	(_TMFAILURE_*): Define unconditionally.
+
+2024-09-04  Andrew Carlotti  <andrew.carlotti@arm.com>
+
+	* config/aarch64/aarch64-sve-builtins.cc (check_builtin_call)
+	(expand_builtin): Update calls to the below.
+	(report_missing_extension, report_missing_registers)
+	(check_required_extensions): Move out of aarch64_sve namespace,
+	rename, and move into...
+	* config/aarch64/aarch64-builtins.cc (aarch64_report_missing_extension)
+	(aarch64_report_missing_registers)
+	(aarch64_check_required_extensions) ...here.
+	* config/aarch64/aarch64-protos.h (aarch64_check_required_extensions):
+	Add prototype.
+
+2024-09-04  Andrew Carlotti  <andrew.carlotti@arm.com>
+
+	* config/aarch64/aarch64-sve-builtins.cc
+	(check_required_registers): Remove target check and rename to...
+	(report_missing_registers): ...this.
+	(check_required_extensions): Refactor.
+
 2024-09-03  Haochen Jiang  <haochen.jiang@intel.com>
 
 	* config/i386/avx512fp16intrin.h
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 301a37d563d..c8bedcac256 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240904
+20240905
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 56d4aad7f9b..6f349aee248 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,27 @@
+2024-09-04  Andrew Carlotti  <andrew.carlotti@arm.com>
+
+	PR target/112108
+	* gcc.target/aarch64/acle/ls64_guard-1.c: New test.
+	* gcc.target/aarch64/acle/ls64_guard-2.c: New test.
+	* gcc.target/aarch64/acle/ls64_guard-3.c: New test.
+	* gcc.target/aarch64/acle/ls64_guard-4.c: New test.
+
+2024-09-04  Andrew Carlotti  <andrew.carlotti@arm.com>
+
+	PR target/112108
+	* gcc.target/aarch64/acle/memtag_guard-1.c: New test.
+	* gcc.target/aarch64/acle/memtag_guard-2.c: New test.
+	* gcc.target/aarch64/acle/memtag_guard-3.c: New test.
+	* gcc.target/aarch64/acle/memtag_guard-4.c: New test.
+
+2024-09-04  Andrew Carlotti  <andrew.carlotti@arm.com>
+
+	PR target/112108
+	* gcc.target/aarch64/acle/tme_guard-1.c: New test.
+	* gcc.target/aarch64/acle/tme_guard-2.c: New test.
+	* gcc.target/aarch64/acle/tme_guard-3.c: New test.
+	* gcc.target/aarch64/acle/tme_guard-4.c: New test.
+
 2024-09-03  Haochen Jiang  <haochen.jiang@intel.com>
 
 	* gcc.target/i386/avx512fp16-vfpclassph-1c.c: New test.
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index f05ec03c85e..fa511f0dc09 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,99 @@
+2024-09-04  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-09-03  Jonathan Wakely  <jwakely@redhat.com>
+
+	* src/c++17/fs_ops.cc (auto_win_file_handle): Add error_code&
+	member and set it if CreateFileW or GetFileInformationByHandle
+	fails.
+	(fs::equiv_files) [_GLIBCXX_FILESYSTEM_IS_WINDOWS]: Simplify
+	control flow.
+	(fs::hard_link_count) [_GLIBCXX_FILESYSTEM_IS_WINDOWS]: Clear ec
+	on success.
+	* testsuite/27_io/filesystem/operations/hard_link_count.cc:
+	Check error handling.
+
+2024-09-04  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-07-30  Jonathan Wakely  <jwakely@redhat.com>
+
+	* src/c++17/fs_ops.cc (auto_win_file_handle): Change constructor
+	parameter from const path& to const wchar_t*.
+	(fs::equiv_files): New function.
+	(fs::equivalent): Use equiv_files.
+	* src/filesystem/ops-common.h (fs::equiv_files): Declare.
+	(do_copy_file): Use equiv_files.
+	* src/filesystem/ops.cc (fs::equiv_files): Define.
+	(fs::copy, fs::equivalent): Use equiv_files.
+	* testsuite/27_io/filesystem/operations/copy.cc: Test
+	overwriting directory contents recursively.
+	* testsuite/27_io/filesystem/operations/copy_file.cc: Test
+	overwriting existing files.
+
+2024-09-04  Lennox Shou Hao Ho  <lennoxhoe@gmail.com>
+
+	Backported from master:
+	2024-07-30  Lennox Shou Hao Ho  <lennoxhoe@gmail.com>
+
+	PR libstdc++/113663
+	* src/c++17/fs_ops.cc (fs::equivalent): Moved helper class
+	auto_handle to anonymous namespace as auto_win_file_handle.
+	(fs::hard_link_count): Changed Windows implementation to use
+	information provided by GetFileInformationByHandle which is more
+	reliable.
+	* testsuite/27_io/filesystem/operations/hard_link_count.cc: New
+	test.
+
+2024-09-04  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-09-03  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/116549
+	* include/bits/stl_iterator.h (disable_sized_sentinel_for):
+	Define specialization for two move_iterator types, as per LWG
+	3736.
+	* testsuite/24_iterators/move_iterator/lwg3736.cc: New test.
+
+2024-09-04  Dhruv Chawla  <dhruvc@nvidia.com>
+
+	Backported from master:
+	2024-09-03  Dhruv Chawla  <dhruvc@nvidia.com>
+
+	* include/std/deque: Define macro
+	__glibcxx_want_allocator_traits_is_always_equal.
+	* include/std/forward_list: Likewise.
+	* include/std/list: Likewise.
+	* include/std/map: Likewise.
+	* include/std/scoped_allocator: Likewise.
+	* include/std/set: Likewise.
+	* include/std/string: Likewise.
+	* include/std/unordered_map: Likewise.
+	* include/std/unordered_set: Likewise.
+	* include/std/vector: Likewise.
+	* testsuite/20_util/headers/memory/version.cc: New test.
+	* testsuite/20_util/scoped_allocator/version.cc: Likewise.
+	* testsuite/21_strings/headers/string/version.cc: Likewise.
+	* testsuite/23_containers/deque/version.cc: Likewise.
+	* testsuite/23_containers/forward_list/version.cc: Likewise.
+	* testsuite/23_containers/list/version.cc: Likewise.
+	* testsuite/23_containers/map/version.cc: Likewise.
+	* testsuite/23_containers/set/version.cc: Likewise.
+	* testsuite/23_containers/unordered_map/version.cc: Likewise.
+	* testsuite/23_containers/unordered_set/version.cc: Likewise.
+	* testsuite/23_containers/vector/version.cc: Likewise.
+
+2024-09-04  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-08-21  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/116381
+	* include/std/variant (variant): Fix conditions for
+	static_assert to match the spec.
+	* testsuite/20_util/variant/types_neg.cc: New test.
+
 2024-08-03  Jonathan Wakely  <jwakely@redhat.com>
 
 	Backported from master:
diff --git a/lto-plugin/ChangeLog b/lto-plugin/ChangeLog
index 780225c49de..c4a59473f67 100644
--- a/lto-plugin/ChangeLog
+++ b/lto-plugin/ChangeLog
@@ -1,3 +1,22 @@
+2024-09-04  H.J. Lu  <hjl.tools@gmail.com>
+
+	Backported from master:
+	2024-08-23  H.J. Lu  <hjl.tools@gmail.com>
+
+	PR lto/116361
+	* lto-plugin.c (claim_file_handler_v2): Don't check obj.found
+	for the offload section.
+
+2024-09-04  H.J. Lu  <hjl.tools@gmail.com>
+
+	Backported from master:
+	2024-08-22  H.J. Lu  <hjl.tools@gmail.com>
+
+	PR lto/116361
+	* lto-plugin.c (claim_file_handler_v2): Rename claimed to
+	can_be_claimed.  Include the LTO object only if it is known to
+	be included in link output.
+
 2024-08-01  Release Manager
 
 	* GCC 14.2.0 released.

commit 040b979a08843806ea930a8d839dd94301323ebe
Author: Tamar Christina <tamar.christina@arm.com>
Date:   Thu Sep 5 11:36:02 2024

    testsuite: remove -fwrapv from signbit-5.c
    
    The meaning of the testcase was changed by passing it -fwrapv.  The reason for
    the test failures on some platform was because the test was testing some
    implementation defined behavior wrt INT_MIN in generic code.
    
    Instead of using -fwrapv this just removes the border case from the test so
    all the values now have a defined semantic.  It still relies on the handling of
    shifting a negative value right, but that wasn't changed with -fwrapv anyway.
    
    The -fwrapv case is being handled already by other testcases.
    
    gcc/testsuite/ChangeLog:
    
            * gcc.dg/signbit-5.c: Remove -fwrapv and change INT_MIN to INT_MIN+1.
    
    (cherry picked from commit 67eaf67360e434dd5969e1c66f043e3c751f9f52)

diff --git a/gcc/testsuite/gcc.dg/signbit-5.c b/gcc/testsuite/gcc.dg/signbit-5.c
index 2bca640f930..e778f91ca33 100644
--- a/gcc/testsuite/gcc.dg/signbit-5.c
+++ b/gcc/testsuite/gcc.dg/signbit-5.c
@@ -1,5 +1,5 @@
 /* { dg-do run } */
-/* { dg-options "-O3 -fwrapv" } */
+/* { dg-options "-O3" } */
 
 /* This test does not work when the truth type does not match vector type.  */
 /* { dg-additional-options "-march=armv8-a" { target aarch64_sve } } */
@@ -44,8 +44,8 @@ int main ()
   TYPE a[N];
   TYPE b[N];
 
-  a[0] = INT_MIN;
-  b[0] = INT_MIN;
+  a[0] = INT_MIN+1;
+  b[0] = INT_MIN+1;
 
   for (int i = 1; i < N; ++i)
     {

commit 6fb41c27b62b5774108455d13f5b7a67c9cbdfa3
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Wed Aug 7 20:14:31 2024

    Don't call clean_symbol_name in create_tmp_var_name [PR116219]
    
    SRA adds fancy names like offset$D94316$_M_impl$D93629$_M_start
    where the numbers in there are DECL_UIDs if there are unnamed
    FIELD_DECLs etc.
    Because -g0 vs. -g can cause differences between the exact DECL_UID
    values (add bigger gaps in between them, corresponding decls should
    still be ordered the same based on DECL_UID) we make sure such
    decls have DECL_NAMELESS set and depending on exact options either don't
    dump such names at all or dump_fancy_name sanitizes the D123456$ parts in
    there to Dxxxx$.
    Unfortunately in tons of places we then use get_name to grab either user
    names or these SRA created names and use that as argument to
    create_tmp_var{,_name,_raw} to base other artificial temporary names based
    on that.  Those are DECL_NAMELESS too, but unfortunately create_tmp_var_name
    starting with
    https://gcc.gnu.org/git/?p=gcc.git&a=commit;h=725494f6e4121eace43b7db1202f8ecbf52a8276
    calls clean_symbol_name which replaces the $s in there with _s and thus
    dump_fancy_name doesn't sanitize it anymore.
    
    I don't see any discussion of that commit (originally to TM branch, later
    merged) on the mailing list, but from
       DECL_NAME (new_decl)
         = create_tmp_var_name (IDENTIFIER_POINTER (DECL_NAME (old_decl)));
    -  SET_DECL_ASSEMBLER_NAME (new_decl, NULL_TREE);
    +  SET_DECL_ASSEMBLER_NAME (new_decl, DECL_NAME (new_decl));
    snippet elsewhere in that commit it seems create_tmp_var_name was used at
    that point also to determine function names of clones, so presumably the
    clean_symbol_name at that point was to ensure the symbol could be emitted
    into assembly, maybe in case DECL_NAME is something like C++ operators or
    whatever could have there undesirable characters.
    
    Anyway, we don't do that for years anymore, already GCC 4.5 uses for such
    purposes clone_function_name which starts of DECL_ASSEMBLER_NAME of the old
    function and appends based on supportable symbol suffix separators the
    separator and some suffix and/or number, so that part doesn't go through
    create_tmp_var_name.
    
    I don't see problems with having the $ and . etc. characters in the names
    intended just to make dumps more readable, after all, we already are using
    those in the SRA created names.  Those names shouldn't make it into the
    assembly in any way, neither debug info nor assembly labels.
    
    There is one theoretical case, where the gimplifier promotes automatic
    vars into TREE_STATIC ones and therefore those can then appear in assembly,
    just in case it would be on e.g. SRA created names and regimplified later.
    Because no cases of promotion of DECL_NAMELESS vars to static was observed in
    {x86_64,i686,powerpc64le}-linux bootstraps/regtests, the code simply uses
    C.NNN names for DECL_NAMELESS vars like it does for !DECL_NAME vars.
    
    Richi mentioned on IRC that the non-cleaned up names might make things
    harder to feed stuff back to the GIMPLE FE, but if so, I think it should be
    the dumping for GIMPLE FE purposes that cleans those up (but at that point
    it should also verify if some such cleaned up names don't collide with
    others and somehow deal with those).
    
    2024-08-07  Jakub Jelinek  <jakub@redhat.com>
    
            PR c++/116219
            * gimple-expr.cc (remove_suffix): Formatting fixes.
            (create_tmp_var_name): Don't call clean_symbol_name.
            * gimplify.cc (gimplify_init_constructor): When promoting automatic
            DECL_NAMELESS vars to static, don't preserve their DECL_NAME.
    
    (cherry picked from commit 165e3e7c3ba884345647c0f1c9a3a57a03383651)

diff --git a/gcc/gimple-expr.cc b/gcc/gimple-expr.cc
index f8d7185530c..0477c9d5f44 100644
--- a/gcc/gimple-expr.cc
+++ b/gcc/gimple-expr.cc
@@ -406,14 +406,12 @@ remove_suffix (char *name, int len)
 {
   int i;
 
-  for (i = 2;  i < 7 && len > i;  i++)
-    {
-      if (name[len - i] == '.')
-	{
-	  name[len - i] = '\0';
-	  break;
-	}
-    }
+  for (i = 2; i < 7 && len > i; i++)
+    if (name[len - i] == '.')
+      {
+	name[len - i] = '\0';
+	break;
+      }
 }
 
 /* Create a new temporary name with PREFIX.  Return an identifier.  */
@@ -430,8 +428,6 @@ create_tmp_var_name (const char *prefix)
       char *preftmp = ASTRDUP (prefix);
 
       remove_suffix (preftmp, strlen (preftmp));
-      clean_symbol_name (preftmp);
-
       prefix = preftmp;
     }
 
diff --git a/gcc/gimplify.cc b/gcc/gimplify.cc
index 457b33a4293..5753eb90ff5 100644
--- a/gcc/gimplify.cc
+++ b/gcc/gimplify.cc
@@ -5598,7 +5598,7 @@ gimplify_init_constructor (tree *expr_p, gimple_seq *pre_p, gimple_seq *post_p,
 
 	    DECL_INITIAL (object) = ctor;
 	    TREE_STATIC (object) = 1;
-	    if (!DECL_NAME (object))
+	    if (!DECL_NAME (object) || DECL_NAMELESS (object))
 	      DECL_NAME (object) = create_tmp_var_name ("C");
 	    walk_tree (&DECL_INITIAL (object), force_labels_r, NULL, NULL);
 

commit 73afc3e47e235f3a68abb1c7ce52a9d82003bdab
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Tue Sep 3 10:20:44 2024

    lower-bitint: Fix up __builtin_{add,sub}_overflow{,_p} bitint lowering [PR116501]
    
    The following testcase is miscompiled.  The problem is in the last_ovf step.
    The second operand has signed _BitInt(513) type but has the MSB clear,
    so range_to_prec returns 512 for it (i.e. it fits into unsigned
    _BitInt(512)).  Because of that the last step actually doesn't need to get
    the most significant bit from the second operand, but the code was deciding
    what to use purely from TYPE_UNSIGNED (type1) - if unsigned, use 0,
    otherwise sign-extend the last processed bit; but that in this case was set.
    We don't want to treat the positive operand as if it was negative regardless
    of the bit below that precision, and precN >= 0 indicates that the operand
    is in the [0, inf) range.
    
    2024-09-03  Jakub Jelinek  <jakub@redhat.com>
    
            PR tree-optimization/116501
            * gimple-lower-bitint.cc (bitint_large_huge::lower_addsub_overflow):
            In the last_ovf case, use build_zero_cst operand not just when
            TYPE_UNSIGNED (typeN), but also when precN >= 0.
    
            * gcc.dg/torture/bitint-73.c: New test.
    
    (cherry picked from commit d4d75a83007e884bfcd632ea3b3269704496f048)

diff --git a/gcc/gimple-lower-bitint.cc b/gcc/gimple-lower-bitint.cc
index b10593035c3..58deaf253e9 100644
--- a/gcc/gimple-lower-bitint.cc
+++ b/gcc/gimple-lower-bitint.cc
@@ -4192,7 +4192,7 @@ bitint_large_huge::lower_addsub_overflow (tree obj, gimple *stmt)
       else
 	{
 	  m_data_cnt = data_cnt;
-	  if (TYPE_UNSIGNED (type0))
+	  if (TYPE_UNSIGNED (type0) || prec0 >= 0)
 	    rhs1 = build_zero_cst (m_limb_type);
 	  else
 	    {
@@ -4210,7 +4210,7 @@ bitint_large_huge::lower_addsub_overflow (tree obj, gimple *stmt)
 		  rhs1 = add_cast (m_limb_type, gimple_assign_lhs (g));
 		}
 	    }
-	  if (TYPE_UNSIGNED (type1))
+	  if (TYPE_UNSIGNED (type1) || prec1 >= 0)
 	    rhs2 = build_zero_cst (m_limb_type);
 	  else
 	    {
diff --git a/gcc/testsuite/gcc.dg/torture/bitint-73.c b/gcc/testsuite/gcc.dg/torture/bitint-73.c
new file mode 100644
index 00000000000..1e15f391257
--- /dev/null
+++ b/gcc/testsuite/gcc.dg/torture/bitint-73.c
@@ -0,0 +1,20 @@
+/* PR tree-optimization/116501 */
+/* { dg-do run { target bitint575 } } */
+/* { dg-options "-std=c23" } */
+/* { dg-skip-if "" { ! run_expensive_tests }  { "*" } { "-O0" "-O2" } } */
+/* { dg-skip-if "" { ! run_expensive_tests } { "-flto" } { "" } } */
+
+_BitInt (4) a;
+
+int
+foo (_BitInt(513) b)
+{
+  return __builtin_sub_overflow_p (a, b, (_BitInt (511)) 0);
+}
+
+int
+main ()
+{
+  if (!foo (0xffffffffffffffff0000000000000000ffffffffffffffff0000000000000000ffffffffffffffff0000000000000000ffffffffffffffff0000000000000000wb))
+    __builtin_abort ();
+}

commit 24909512101d59807f6d23a9963d64390eca8f60
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Thu Sep 5 12:20:57 2024

    libsanitizer: On aarch64 use hint #34 in prologue of libsanitizer functions
    
    When gcc is built with -mbranch-protection=standard, running sanitized
    programs doesn't work properly on bti enabled kernels.
    
    This has been fixed upstream with
    https://github.com/llvm/llvm-project/pull/84061
    
    The following patch cherry picks that from upstream.
    
    For trunk we should eventually do a full merge from upstream, but I'm hoping
    they will first fix up the _BitInt libubsan support mess.
    
    2024-09-05  Jakub Jelinek  <jakub@redhat.com>
    
            * sanitizer_common/sanitizer_asm.h: Cherry-pick llvm-project revision
            1c792d24e0a228ad49cc004a1c26bbd7cd87f030.
            * interception/interception.h: Likewise.
    
    (cherry picked from commit 2379cbb94b2668227c237c94c82e3c49fe39fd0f)

diff --git a/libsanitizer/interception/interception.h b/libsanitizer/interception/interception.h
index 58e969378a9..73135b34bee 100644
--- a/libsanitizer/interception/interception.h
+++ b/libsanitizer/interception/interception.h
@@ -204,11 +204,11 @@ const interpose_substitution substitution_##func_name[]             \
        ".type  " SANITIZER_STRINGIFY(TRAMPOLINE(func)) ", "                    \
          ASM_TYPE_FUNCTION_STR "\n"                                            \
        SANITIZER_STRINGIFY(TRAMPOLINE(func)) ":\n"                             \
-       SANITIZER_STRINGIFY(CFI_STARTPROC) "\n"                                 \
+       C_ASM_STARTPROC "\n"                                                    \
        C_ASM_TAIL_CALL(SANITIZER_STRINGIFY(TRAMPOLINE(func)),                  \
                        "__interceptor_"                                        \
                          SANITIZER_STRINGIFY(ASM_PREEMPTIBLE_SYM(func))) "\n"  \
-       SANITIZER_STRINGIFY(CFI_ENDPROC) "\n"                                   \
+       C_ASM_ENDPROC "\n"                                                      \
        ".size  " SANITIZER_STRINGIFY(TRAMPOLINE(func)) ", "                    \
             ".-" SANITIZER_STRINGIFY(TRAMPOLINE(func)) "\n"                    \
      );
diff --git a/libsanitizer/sanitizer_common/sanitizer_asm.h b/libsanitizer/sanitizer_common/sanitizer_asm.h
index 3af66a4e449..30e9d15184e 100644
--- a/libsanitizer/sanitizer_common/sanitizer_asm.h
+++ b/libsanitizer/sanitizer_common/sanitizer_asm.h
@@ -42,6 +42,16 @@
 # define CFI_RESTORE(reg)
 #endif
 
+#if defined(__aarch64__) && defined(__ARM_FEATURE_BTI_DEFAULT)
+# define ASM_STARTPROC CFI_STARTPROC; hint #34
+# define C_ASM_STARTPROC SANITIZER_STRINGIFY(CFI_STARTPROC) "\nhint #34"
+#else
+# define ASM_STARTPROC CFI_STARTPROC
+# define C_ASM_STARTPROC SANITIZER_STRINGIFY(CFI_STARTPROC)
+#endif
+#define ASM_ENDPROC CFI_ENDPROC
+#define C_ASM_ENDPROC SANITIZER_STRINGIFY(CFI_ENDPROC)
+
 #if defined(__x86_64__) || defined(__i386__) || defined(__sparc__)
 # define ASM_TAIL_CALL jmp
 #elif defined(__arm__) || defined(__aarch64__) || defined(__mips__) || \
@@ -114,9 +124,9 @@
          .globl __interceptor_trampoline_##name;                               \
          ASM_TYPE_FUNCTION(__interceptor_trampoline_##name);                   \
          __interceptor_trampoline_##name:                                      \
-                 CFI_STARTPROC;                                                \
+                 ASM_STARTPROC;                                                \
                  ASM_TAIL_CALL ASM_PREEMPTIBLE_SYM(__interceptor_##name);      \
-                 CFI_ENDPROC;                                                  \
+                 ASM_ENDPROC;                                                  \
          ASM_SIZE(__interceptor_trampoline_##name)
 #  define ASM_INTERCEPTOR_TRAMPOLINE_SUPPORT 1
 # endif  // Architecture supports interceptor trampoline

commit 6abedee0d4c8d40d412a358a3f6cb6090772d286
Author: H.J. Lu <hjl.tools@gmail.com>
Date:   Tue Aug 27 22:11:39 2024

    ipa: Don't disable function parameter analysis for fat LTO
    
    Update analyze_parms not to disable function parameter analysis for
    -ffat-lto-objects.  Tested on x86-64, there are no differences in zstd
    with "-O2 -flto=auto" -g "vs -O2 -flto=auto -g -ffat-lto-objects".
    
            PR ipa/116410
            * ipa-modref.cc (analyze_parms): Always analyze function parameter
            for LTO.
    
    Signed-off-by: H.J. Lu <hjl.tools@gmail.com>
    (cherry picked from commit 2f1689ea8e631ebb4ff3720d56ef0362f5898ff6)

diff --git a/gcc/ipa-modref.cc b/gcc/ipa-modref.cc
index 37221215a65..10344fbb4b5 100644
--- a/gcc/ipa-modref.cc
+++ b/gcc/ipa-modref.cc
@@ -2969,7 +2969,7 @@ analyze_parms (modref_summary *summary, modref_summary_lto *summary_lto,
 		summary->arg_flags.safe_grow_cleared (count, true);
 	      summary->arg_flags[parm_index] = EAF_UNUSED;
 	    }
-	  else if (summary_lto)
+	  if (summary_lto)
 	    {
 	      if (parm_index >= summary_lto->arg_flags.length ())
 		summary_lto->arg_flags.safe_grow_cleared (count, true);
@@ -3028,7 +3028,7 @@ analyze_parms (modref_summary *summary, modref_summary_lto *summary_lto,
 		summary->arg_flags.safe_grow_cleared (count, true);
 	      summary->arg_flags[parm_index] = flags;
 	    }
-	  else if (summary_lto)
+	  if (summary_lto)
 	    {
 	      if (parm_index >= summary_lto->arg_flags.length ())
 		summary_lto->arg_flags.safe_grow_cleared (count, true);

commit fe668633f6b5819ba04d80f13343ee7f5bba1c5b
Author: Marek Polacek <polacek@redhat.com>
Date:   Thu Sep 5 19:01:59 2024

    c++: vtable referring to "unavailable" virtual fn [PR116606]
    
    mark_vtable_entries already has
    
       /* It's OK for the vtable to refer to deprecated virtual functions.  */
       warning_sentinel w(warn_deprecated_decl);
    
    but that doesn't cover __attribute__((unavailable)).  We can use the
    following override to cover both.
    
            PR c++/116606
    
    gcc/cp/ChangeLog:
    
            * decl2.cc (mark_vtable_entries): Temporarily override deprecated_state to
            UNAVAILABLE_DEPRECATED_SUPPRESS.  Remove a warning_sentinel.
    
    gcc/testsuite/ChangeLog:
    
            * g++.dg/ext/attr-unavailable-13.C: New test.
    
    (cherry picked from commit d9d34f9a91371dea4bab0b54b2d7f762a6cc23e0)

diff --git a/gcc/cp/decl2.cc b/gcc/cp/decl2.cc
index af2e08c8a63..f6c760338cc 100644
--- a/gcc/cp/decl2.cc
+++ b/gcc/cp/decl2.cc
@@ -2172,7 +2172,8 @@ static void
 mark_vtable_entries (tree decl, vec<tree> &consteval_vtables)
 {
   /* It's OK for the vtable to refer to deprecated virtual functions.  */
-  warning_sentinel w(warn_deprecated_decl);
+  auto du = make_temp_override (deprecated_state,
+				UNAVAILABLE_DEPRECATED_SUPPRESS);
 
   bool consteval_seen = false;
 
diff --git a/gcc/testsuite/g++.dg/ext/attr-unavailable-13.C b/gcc/testsuite/g++.dg/ext/attr-unavailable-13.C
new file mode 100644
index 00000000000..9ca40005419
--- /dev/null
+++ b/gcc/testsuite/g++.dg/ext/attr-unavailable-13.C
@@ -0,0 +1,8 @@
+// PR c++/116606
+// { dg-do compile }
+
+struct C {
+    __attribute__((unavailable)) virtual void f() {}
+};
+
+C c;

commit aedf6f810eee108d4b6c41dbd4bd113ca04c1b6c
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Fri Sep 6 02:22:34 2024

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 8bc41ae0aaa..4773a468197 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,33 @@
+2024-09-05  H.J. Lu  <hjl.tools@gmail.com>
+
+	Backported from master:
+	2024-09-03  H.J. Lu  <hjl.tools@gmail.com>
+
+	PR ipa/116410
+	* ipa-modref.cc (analyze_parms): Always analyze function parameter
+	for LTO.
+
+2024-09-05  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2024-09-03  Jakub Jelinek  <jakub@redhat.com>
+
+	PR tree-optimization/116501
+	* gimple-lower-bitint.cc (bitint_large_huge::lower_addsub_overflow):
+	In the last_ovf case, use build_zero_cst operand not just when
+	TYPE_UNSIGNED (typeN), but also when precN >= 0.
+
+2024-09-05  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2024-08-07  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/116219
+	* gimple-expr.cc (remove_suffix): Formatting fixes.
+	(create_tmp_var_name): Don't call clean_symbol_name.
+	* gimplify.cc (gimplify_init_constructor): When promoting automatic
+	DECL_NAMELESS vars to static, don't preserve their DECL_NAME.
+
 2024-09-04  Andrew Carlotti  <andrew.carlotti@arm.com>
 
 	PR target/112108
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index c8bedcac256..a2aca132dd9 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240905
+20240906
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index ebb02354925..4fce475fab5 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -1,3 +1,12 @@
+2024-09-05  Marek Polacek  <polacek@redhat.com>
+
+	Backported from master:
+	2024-09-05  Marek Polacek  <polacek@redhat.com>
+
+	PR c++/116606
+	* decl2.cc (mark_vtable_entries): Temporarily override deprecated_state to
+	UNAVAILABLE_DEPRECATED_SUPPRESS.  Remove a warning_sentinel.
+
 2024-08-19  Marek Polacek  <polacek@redhat.com>
 
 	Backported from master:
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 6f349aee248..736537b0cf0 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,26 @@
+2024-09-05  Marek Polacek  <polacek@redhat.com>
+
+	Backported from master:
+	2024-09-05  Marek Polacek  <polacek@redhat.com>
+
+	PR c++/116606
+	* g++.dg/ext/attr-unavailable-13.C: New test.
+
+2024-09-05  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2024-09-03  Jakub Jelinek  <jakub@redhat.com>
+
+	PR tree-optimization/116501
+	* gcc.dg/torture/bitint-73.c: New test.
+
+2024-09-05  Tamar Christina  <tamar.christina@arm.com>
+
+	Backported from master:
+	2024-09-05  Tamar Christina  <tamar.christina@arm.com>
+
+	* gcc.dg/signbit-5.c: Remove -fwrapv and change INT_MIN to INT_MIN+1.
+
 2024-09-04  Andrew Carlotti  <andrew.carlotti@arm.com>
 
 	PR target/112108
diff --git a/libsanitizer/ChangeLog b/libsanitizer/ChangeLog
index 95f65b6d182..f858bb3f6bb 100644
--- a/libsanitizer/ChangeLog
+++ b/libsanitizer/ChangeLog
@@ -1,3 +1,12 @@
+2024-09-05  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2024-09-05  Jakub Jelinek  <jakub@redhat.com>
+
+	* sanitizer_common/sanitizer_asm.h: Cherry-pick llvm-project revision
+	1c792d24e0a228ad49cc004a1c26bbd7cd87f030.
+	* interception/interception.h: Likewise.
+
 2024-08-01  Release Manager
 
 	* GCC 14.2.0 released.

commit d4d7c4e21984b2705a1c51cde9162c1b1a0e73f0
Author: Joseph Myers <josmyers@redhat.com>
Date:   Fri Sep 6 18:15:12 2024

    Update gcc uk.po
    
            * uk.po: Update.

diff --git a/gcc/po/uk.po b/gcc/po/uk.po
index 5c63b7eb8fa..c3f49a81439 100644
--- a/gcc/po/uk.po
+++ b/gcc/po/uk.po
@@ -3,14 +3,14 @@
 # This file is distributed under the same license as the gcc package.
 #
 # Yuri Chornoivan <yurchor@ukr.net>, 2015, 2016, 2017, 2018, 2019, 2020, 2021, 2022.
-# Volodymyr M. Lisivka <vlisivka@gmail.com>, 2023.
+# Volodymyr M. Lisivka <vlisivka@gmail.com>, 2023. 2024.
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 13.2.0\n"
+"Project-Id-Version: gcc 14.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
 "POT-Creation-Date: 2024-07-25 16:23+0000\n"
-"PO-Revision-Date: 2023-07-28 15:23+0300\n"
-"Last-Translator: Volodymyr Lisivka <vlisivka@gmail.com>\n"
+"PO-Revision-Date: 2024-09-06 12:23+0300\n"
+"Last-Translator: Volodymyr M. Lisivka <vlisivka@gmail.com>\n"
 "Language-Team: Ukrainian <trans-uk@lists.fedoraproject.org>\n"
 "Language: uk\n"
 "MIME-Version: 1.0\n"
@@ -317,10 +317,8 @@ msgid "-install_name only allowed with -dynamiclib"
 msgstr "-install_name дозволяється тільки з -dynamiclib"
 
 #: config/darwin.h:191
-#, fuzzy
-#| msgid "-bundle not allowed with -dynamiclib"
 msgid "-bundle not allowed with -shared"
-msgstr "-bundle не дозволяється з -dynamiclib"
+msgstr "-bundle не дозволено разом з -shared"
 
 #: config/darwin.h:192
 msgid "-bundle not allowed with -dynamiclib"
@@ -1024,7 +1022,7 @@ msgstr "Встановити приватний доступ за замовчу
 #: fortran/lang.opt:721
 #, no-c-format
 msgid "Handle OpenMP allocators for allocatables and pointers."
-msgstr ""
+msgstr "Обробляйте алокатори OpenMP для виділених та вказівників."
 
 #: fortran/lang.opt:725
 #, no-c-format
@@ -1179,10 +1177,9 @@ msgid "Conform to the ISO Fortran 2018 standard."
 msgstr "Відповідати стандарту ISO Fortran 2018."
 
 #: fortran/lang.opt:896
-#, fuzzy, no-c-format
-#| msgid "Conform to the ISO Fortran 2003 standard."
+#, no-c-format
 msgid "Conform to the ISO Fortran 2023 standard."
-msgstr "Відповідати стандарту ISO Fortran 2003."
+msgstr "Відповідати стандарту ISO Fortran 2023."
 
 #: fortran/lang.opt:900
 #, no-c-format
@@ -1222,7 +1219,7 @@ msgstr "-frust-crate=<імʼя>             Встановити назву кр
 #: rust/lang.opt:67
 #, no-c-format
 msgid "-frust-extern=              Specify where an external library is located"
-msgstr ""
+msgstr "-frust-extern=              Вкажіть, де розташована зовнішня бібліотека."
 
 #: rust/lang.opt:71
 #, no-c-format
@@ -1230,10 +1227,9 @@ msgid "Dump various Rust front end internals."
 msgstr "Вивести різні внутрішні елементи передньої частини Rust."
 
 #: rust/lang.opt:75
-#, fuzzy, no-c-format
-#| msgid "-frust-dump-<type>\tDump Rust frontend internal information."
+#, no-c-format
 msgid "-frust-dump-<type>              Dump Rust frontend internal information."
-msgstr "-frust-dump-<тип>\tВивести внутрішню інформацію передньої частини Rust."
+msgstr "-frust-dump-<тип>              Вивести внутрішню інформацію фронтенду Rust."
 
 #: rust/lang.opt:79
 #, no-c-format
@@ -1241,21 +1237,19 @@ msgid "Enable experimental compilation of Rust files at your own risk"
 msgstr "Увімкнути експериментальну компіляцію файлів Rust на власний ризик"
 
 #: rust/lang.opt:83
-#, fuzzy, no-c-format
-#| msgid "-frust-max-recursion-depth=integer"
+#, no-c-format
 msgid "-frust-max-recursion-depth=<integer>"
-msgstr "-frust-max-recursion-depth=ціле"
+msgstr "-frust-max-recursion-depth=<ціле число>"
 
 #: rust/lang.opt:87
 #, no-c-format
 msgid "-frust-crate-type=[bin|lib|rlib|dylib|cdylib|staticlib|proc-macro]     Crate type to emit"
-msgstr ""
+msgstr "-frust-crate-type=[bin|lib|rlib|dylib|cdylib|staticlib|proc-macro]     Тип крейту для випуску."
 
 #: rust/lang.opt:115
-#, fuzzy, no-c-format
-#| msgid "-frust-mangling=[legacy|v0]     Choose which version to use for name mangling"
+#, no-c-format
 msgid "-frust-mangling=[legacy|v0]     Version to use for name mangling"
-msgstr "-frust-mangling=[legacy|v0]     Виберіть, яку версію використовувати для декорування імен"
+msgstr "-frust-mangling=[legacy|v0]     Версія для використання при зміні імен"
 
 #: rust/lang.opt:128
 #, no-c-format
@@ -1263,16 +1257,14 @@ msgid "-frust-cfg=<name>             Set a config expansion option"
 msgstr "-frust-cfg=<імʼя>             Встановити параметр розширення конфігурації"
 
 #: rust/lang.opt:132
-#, fuzzy, no-c-format
-#| msgid "-frust-edition=[2015|2018|2021]             Choose which edition to use when compiling rust code"
+#, no-c-format
 msgid "-frust-edition=[2015|2018|2021]             Edition to use when compiling rust code"
-msgstr "-frust-edition=[2015|2018|2021]             Виберіть, яку редакцію використовувати при компіляції коду rust"
+msgstr "-frust-edition=[2015|2018|2021]             Видання, яке використовується при компіляції коду Rust."
 
 #: rust/lang.opt:148
-#, fuzzy, no-c-format
-#| msgid "Flag to enable embeding metadata directly into object files"
+#, no-c-format
 msgid "Enable embedding metadata directly into object files"
-msgstr "Прапорець для включення метаданих безпосередньо в обʼєктні файли"
+msgstr "Увімкнути вбудовування метаданих безпосередньо у файли об'єктів"
 
 #: rust/lang.opt:152
 #, no-c-format
@@ -1280,20 +1272,19 @@ msgid "-frust-metadata-output=<path.rox>  Path to output crate metadata"
 msgstr "-frust-metadata-output=<шлях.rox>  Шлях до вихідних метаданих ящика"
 
 #: rust/lang.opt:160
-#, fuzzy, no-c-format
-#| msgid "-frust-compile-until=[ast|attributecheck|expansion|nameresolution|lowering|typecheck|privacy|unsafety|const|copimlation|end]             When to stop in the pipeline when compiling Rust code"
+#, no-c-format
 msgid "-frust-compile-until=[ast|attributecheck|expansion|astvalidation|featuregating|nameresolution|lowering|typecheck|privacy|unsafety|const|borrowcheck|compilation|end]             The pipeline will run up until this stage when compiling Rust code"
-msgstr "-frust-compile-until=[ast|attributecheck|expansion|nameresolution|lowering|typecheck|privacy|unsafety|const|copimlation|end]             Коли зупинитися в конвеєрі під час компіляції коду Rust"
+msgstr "-frust-compile-until=[ast|attributecheck|expansion|astvalidation|featuregating|nameresolution|lowering|typecheck|privacy|unsafety|const|borrowcheck|compilation|end]             Конвеєр буде виконуватися до цього етапу під час компіляції коду Rust."
 
 #: rust/lang.opt:209
 #, no-c-format
 msgid "Use the temporary and experimental name resolution pipeline instead of the stable one"
-msgstr ""
+msgstr "Використовуйте тимчасовий та експериментальний конвеєр розв'язання імені замість стабільного конвеєра."
 
 #: rust/lang.opt:213
 #, no-c-format
 msgid "Use the WIP borrow checker."
-msgstr ""
+msgstr "Використовуйте перевірку позичання в розробці (WIP)."
 
 #: c-family/c.opt:182
 #, no-c-format
@@ -1388,18 +1379,17 @@ msgstr "-MT <ціль>\tДодати ціль, яка не вимагає цит
 #: c-family/c.opt:261
 #, no-c-format
 msgid "Structured format for output dependency information.  Supported (\"p1689r5\")."
-msgstr ""
+msgstr "Структурований формат для виведення інформації про залежності. Підтримується (\"p1689r5\")."
 
 #: c-family/c.opt:265
-#, fuzzy, no-c-format
-#| msgid "Generate C++ Module dependency information."
+#, no-c-format
 msgid "File for output dependency information."
-msgstr "Генерувати інформацію про залежності модулів C++."
+msgstr "Файл для виведення інформації про залежності."
 
 #: c-family/c.opt:269
 #, no-c-format
 msgid "-fdeps-target=obj.o Output file for the compile step."
-msgstr ""
+msgstr "-fdeps-target=obj.o Вихідний файл для кроку компіляції."
 
 #: c-family/c.opt:273
 #, no-c-format
@@ -1469,7 +1459,7 @@ msgstr "Попереджати про будь-яке використання a
 #: c-family/c.opt:340
 #, no-c-format
 msgid "Warn when allocating insufficient storage for the target type of the assigned pointer."
-msgstr ""
+msgstr "Попереджати при виділенні недостатньої пам'яті для типу призначення вказаного покажчика."
 
 #: c-family/c.opt:344
 #, no-c-format
@@ -1547,16 +1537,14 @@ msgid "Warn when a built-in preprocessor macro is undefined or redefined."
 msgstr "Попереджувати, коли вбудований макрос препроцесора не визначений або перевизначений."
 
 #: c-family/c.opt:438
-#, fuzzy, no-c-format
-#| msgid "Warn about features not present in ISO C11, but present in ISO C2X."
+#, no-c-format
 msgid "Warn about features not present in ISO C11, but present in ISO C23."
-msgstr "Попереджувати про функції, які відсутні в ISO C11, але присутні в ISO C2X."
+msgstr "Попереджати про функції, які відсутні в стандарті ISO C11, але присутні в стандарті ISO C23."
 
 #: c-family/c.opt:442
-#, fuzzy, no-c-format
-#| msgid "Deprecated in favor of -std=c11."
+#, no-c-format
 msgid "Deprecated in favor of -Wc11-c23-compat."
-msgstr "Застарілий на користь -std=c11."
+msgstr "Застаріле на користь -Wc11-c23-compat."
 
 #: c-family/c.opt:446
 #, no-c-format
@@ -1619,16 +1607,14 @@ msgid "Warn about C++23 constructs in code compiled with an older standard."
 msgstr "Попереджувати про використання конструкцій C++23 у коді, скомпільованому зі старішим стандартом."
 
 #: c-family/c.opt:503
-#, fuzzy, no-c-format
-#| msgid "Warn about C++20 constructs in code compiled with an older standard."
+#, no-c-format
 msgid "Warn about C++26 constructs in code compiled with an older standard."
-msgstr "Попереджувати про використання конструкцій C++20 у коді, скомпільованому зі старішим стандартом."
+msgstr "Попереджати про використання конструкцій C++26 у коді, який компілюється зі стандартом нижчої версії."
 
 #: c-family/c.opt:507
-#, fuzzy, no-c-format
-#| msgid "Warn about suspicious divisions of two sizeof expressions that don't work correctly with pointers."
+#, no-c-format
 msgid "Warn about suspicious calls to calloc-like functions where sizeof expression is the earlier size argument and not the latter."
-msgstr "Попереджувати про підозрілі ділення двох виразів sizeof, які не працюють правильно з вказівниками."
+msgstr "Попереджати про підозрілі виклики функцій подібних на calloc, де вираз sizeof є першим аргументом розміру, а не останнім."
 
 #: c-family/c.opt:511
 #, no-c-format
@@ -1643,7 +1629,7 @@ msgstr "Попереджувати про приведення, які відк
 #: c-family/c.opt:519
 #, no-c-format
 msgid "Warn about a cast to reference type that does not use a related user-defined conversion function."
-msgstr ""
+msgstr "Попереджати про приведення до типу посилання, яке не використовує пов'язану користувацьку функцію перетворення."
 
 #: c-family/c.opt:523 c-family/c.opt:527
 #, no-c-format
@@ -1753,10 +1739,9 @@ msgid "Warn when a declaration is found after a statement."
 msgstr "Попереджати, коли після оператора знайдено оголошення."
 
 #: c-family/c.opt:616
-#, fuzzy, no-c-format
-#| msgid "Warn about unprototyped function declarations."
+#, no-c-format
 msgid "Warn for missing parameter types in function declarations."
-msgstr "Попереджати про непрототиповані оголошення функцій."
+msgstr "Попереджати про відсутність типів параметрів у оголошеннях функцій."
 
 #: c-family/c.opt:620
 #, no-c-format
@@ -1836,7 +1821,7 @@ msgstr "Попереджувати про порушення правил сти
 #: c-family/c.opt:687
 #, no-c-format
 msgid "Warn if an additional enum-base is used in an elaborated-type-specifier."
-msgstr ""
+msgstr "Попереджати, якщо використовується додаткова база перерахування в уточненому визначенні типу."
 
 #: c-family/c.opt:691
 #, no-c-format
@@ -1886,7 +1871,7 @@ msgstr "Попереджувати про крапку з комою після
 #: c-family/c.opt:735
 #, no-c-format
 msgid "Warn when a structure containing a C99 flexible array member as the last field is not at the end of another structure."
-msgstr ""
+msgstr "Попереджати, якщо структура, з гнучким масивом C99 в останньому полі, не є останнім полем іншої структури."
 
 #: c-family/c.opt:740
 #, no-c-format
@@ -1969,10 +1954,9 @@ msgid "Warn when __builtin_frame_address or __builtin_return_address is used uns
 msgstr "Попереджувати, коли __builtin_frame_address або __builtin_return_address використовуються небезпечно."
 
 #: c-family/c.opt:811
-#, fuzzy, no-c-format
-#| msgid "global module fragment contents must be from preprocessor inclusion"
+#, no-c-format
 msgid "Warn about the global module fragment not containing only preprocessing directives."
-msgstr "вміст глобального фрагмента модуля повинен бути з препроцесорного включення"
+msgstr "Попереджати про глобальний фрагмент модуля, який містить не лише директиви препроцесора."
 
 #: c-family/c.opt:815
 #, no-c-format
@@ -2175,10 +2159,9 @@ msgid "Warn when the template keyword is missing after a member access token in
 msgstr "Попереджувати, коли ключове слово «template» відсутнє після токена доступу до члена в залежному виразі доступу до члена, якщо цей член є шаблоном."
 
 #: c-family/c.opt:1002
-#, fuzzy, no-c-format
-#| msgid "Warn about global functions without previous declarations."
+#, no-c-format
 msgid "Warn about global variables without previous declarations."
-msgstr "Попереджати про глобальні функції без попередніх оголошень."
+msgstr "Попереджати про глобальні змінні без попередніх оголошень."
 
 #: c-family/c.opt:1009
 #, no-c-format
@@ -2266,10 +2249,9 @@ msgid "Warn about potentially suboptimal choices related to OpenACC parallelism.
 msgstr "Попереджувати про потенційно неоптимальні вибори, повʼязані з паралелізмом OpenACC."
 
 #: c-family/c.opt:1109
-#, fuzzy, no-c-format
-#| msgid "Warn about \"suspicious\" constructs."
+#, no-c-format
 msgid "Warn about suspicious OpenMP code."
-msgstr "Попереджати про «підозрілі» конструкції."
+msgstr "Попереджати про підозрілий код OpenMP."
 
 #: c-family/c.opt:1113
 #, no-c-format
@@ -2299,7 +2281,7 @@ msgstr "Попереджати про перевизначення ініціа
 #: c-family/c.opt:1137
 #, no-c-format
 msgid "Warn if the named return value optimization is not performed although it is allowed."
-msgstr ""
+msgstr "Повідомляти, якщо оптимізація повернення значення за ім'ям не виконується, хоча це дозволено."
 
 #: c-family/c.opt:1141
 #, no-c-format
@@ -2409,7 +2391,7 @@ msgstr "Попереджувати, коли аргумент, передани
 #: c-family/c.opt:1234
 #, no-c-format
 msgid "Warn whenever void-returning functions return a non-void expressions, or a return expression is missing in a function not returning void."
-msgstr ""
+msgstr "Попереджати, коли функції, які не повертають значення, містяьт вираз повернення значення, або, навпаки, відсутній вираз повернення значення у функції, що має повернути значення."
 
 #: c-family/c.opt:1238
 #, no-c-format
@@ -2502,10 +2484,9 @@ msgid "Warn about suspicious length parameters to certain string functions if th
 msgstr "Попереджувати про підозрілі параметри довжини для деяких функцій рядків, якщо аргумент використовує sizeof."
 
 #: c-family/c.opt:1323
-#, fuzzy, no-c-format
-#| msgid "Warn about inproper usages of flexible array members according to the level of -fstrict-flex-arrays."
+#, no-c-format
 msgid "Warn about improper usages of flexible array members according to the level of -fstrict-flex-arrays."
-msgstr "Попереджувати про неправильне використання гнучких елементів масиву залежно від рівня -fstrict-flex-arrays."
+msgstr "Попереджати про неправильне використання гнучких масивів залежно від рівня -fstrict-flex-arrays."
 
 #: c-family/c.opt:1328
 #, no-c-format
@@ -2608,10 +2589,9 @@ msgid "Warn if a comparison always evaluates to true or false."
 msgstr "Попереджати, якщо порівняння завжди оцінюється як true або false."
 
 #: c-family/c.opt:1421
-#, fuzzy, no-c-format
-#| msgid "template-id not allowed for destructor"
+#, no-c-format
 msgid "Warn about simple-template-id in a constructor or destructor."
-msgstr "template-id не дозволено для деструктора"
+msgstr "Попереджати про simple-template-id у конструкторі або деструкторі."
 
 #: c-family/c.opt:1425
 #, no-c-format
@@ -2920,10 +2900,9 @@ msgid "Print hierarchical comparisons when template types are mismatched."
 msgstr "Друкувати ієрархічні порівняння, коли типи шаблонів не збігаються."
 
 #: c-family/c.opt:1826
-#, fuzzy, no-c-format
-#| msgid "default argument mismatch in overload resolution"
+#, no-c-format
 msgid "Note all candidates during overload resolution failure."
-msgstr "несумісність аргументу за замовчуванням при вирішенні перевантаження"
+msgstr "Зазначати всіх кандидатів під час невдачі розподілу перевантаження."
 
 #: c-family/c.opt:1830
 #, no-c-format
@@ -3013,7 +2992,7 @@ msgstr "Припускати нормальне середовище викон
 #: c-family/c.opt:1923
 #, no-c-format
 msgid "Implement P2564 for consteval propagation."
-msgstr ""
+msgstr "Реалізувати P2564 для розповсюдження consteval."
 
 #: c-family/c.opt:1927
 #, no-c-format
@@ -3086,10 +3065,9 @@ msgid "Warn about macros that have conflicting header units definitions."
 msgstr "Попереджати про макроси, які мають конфліктні визначення одиниць заголовка."
 
 #: c-family/c.opt:2000
-#, fuzzy, no-c-format
-#| msgid "Warn when a pointer is compared with a zero character constant."
+#, no-c-format
 msgid "Warn if pointers of distinct types are compared without a cast."
-msgstr "Попереджати, коли вказівник порівнюється з нульовою символьною константою."
+msgstr "Попереджати, якщо порівнюються вказівники різних типів без приведення типу."
 
 #: c-family/c.opt:2004
 #, no-c-format
@@ -3132,10 +3110,9 @@ msgid "Implement resolution of DR 150 for matching of template template argument
 msgstr "Реалізувати вирішення DR 150 для відповідності аргументів шаблону шаблону."
 
 #: c-family/c.opt:2051
-#, fuzzy, no-c-format
-#| msgid "Generate code for NeXT (Apple Mac OS X) runtime environment."
+#, no-c-format
 msgid "Generate code for NeXT (Apple macOS) runtime environment."
-msgstr "Генерувати код для середовища виконання NeXT (Apple Mac OS X)."
+msgstr "Генерувати код для середовища виконання NeXT (Apple macOS)."
 
 #: c-family/c.opt:2055
 #, no-c-format
@@ -3528,10 +3505,9 @@ msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete s
 msgstr "Відповідати проекту стандарту C++ ISO 2023 (експериментальна та неповна підтримка)."
 
 #: c-family/c.opt:2488 c-family/c.opt:2492
-#, fuzzy, no-c-format
-#| msgid "Conform to the ISO 2023 C++ draft standard (experimental and incomplete support)."
+#, no-c-format
 msgid "Conform to the ISO 2026 C++ draft standard (experimental and incomplete support)."
-msgstr "Відповідати проекту стандарту C++ ISO 2023 (експериментальна та неповна підтримка)."
+msgstr "Відповідати чернетці стандарту ISO 2026 C++ (експериментальна та неповна підтримка)."
 
 #: c-family/c.opt:2496 c-family/c.opt:2650
 #, no-c-format
@@ -3550,16 +3526,14 @@ msgid "Conform to the ISO 2017 C standard (published in 2018)."
 msgstr "Відповідність стандарту C ISO 2017 (опубліковано в 2018 році)."
 
 #: c-family/c.opt:2512 c-family/c.opt:2662
-#, fuzzy, no-c-format
-#| msgid "Conform to the ISO 202X C standard draft (experimental and incomplete support)."
+#, no-c-format
 msgid "Conform to the ISO 2023 C standard draft (expected to be published in 2024) (experimental and incomplete support)."
-msgstr "Відповідність проекту стандарту C ISO 202X (експериментальна та неповна підтримка)."
+msgstr "Відповідати чернетці стандарту ISO 2023 C (очікується публікація у 2024 році) (експериментальна та неповна підтримка)."
 
 #: c-family/c.opt:2516
-#, fuzzy, no-c-format
-#| msgid "Deprecated in favor of -std=c11."
+#, no-c-format
 msgid "Deprecated in favor of -std=c23."
-msgstr "Застарілий на користь -std=c11."
+msgstr "Застарів на користь -std=c23."
 
 #: c-family/c.opt:2520 c-family/c.opt:2524 c-family/c.opt:2634
 #, no-c-format
@@ -3622,10 +3596,9 @@ msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimen
 msgstr "Відповідати проекту стандарту C++ ISO 2023 з розширеннями GNU (експериментальна та неповна підтримка)."
 
 #: c-family/c.opt:2586 c-family/c.opt:2590
-#, fuzzy, no-c-format
-#| msgid "Conform to the ISO 2023 C++ draft standard with GNU extensions (experimental and incomplete support)."
+#, no-c-format
 msgid "Conform to the ISO 2026 C++ draft standard with GNU extensions (experimental and incomplete support)."
-msgstr "Відповідати проекту стандарту C++ ISO 2023 з розширеннями GNU (експериментальна та неповна підтримка)."
+msgstr "Відповідати чернетці стандарту ISO 2026 C++ з розширеннями GNU (експериментальна та неповна підтримка)."
 
 #: c-family/c.opt:2594
 #, no-c-format
@@ -3643,16 +3616,14 @@ msgid "Conform to the ISO 2017 C standard (published in 2018) with GNU extension
 msgstr "Відповідати стандарту C ISO 2017 (опублікованому в 2018 році) з розширеннями GNU."
 
 #: c-family/c.opt:2610
-#, fuzzy, no-c-format
-#| msgid "Conform to the ISO 202X C standard draft with GNU extensions (experimental and incomplete support)."
+#, no-c-format
 msgid "Conform to the ISO 2023 C standard draft (expected to be published in 2024) with GNU extensions (experimental and incomplete support)."
-msgstr "Відповідати проекту стандарту C ISO 202X з розширеннями GNU (експериментальна та неповна підтримка)."
+msgstr "Відповідати чернетці стандарту ISO 2023 C (очікується публікація у 2024 році) з розширеннями GNU (експериментальна та неповна підтримка)."
 
 #: c-family/c.opt:2614
-#, fuzzy, no-c-format
-#| msgid "Deprecated in favor of -std=gnu11."
+#, no-c-format
 msgid "Deprecated in favor of -std=gnu23."
-msgstr "Застарілий на користь -std=gnu11."
+msgstr "Застарів на користь -std=gnu23."
 
 #: c-family/c.opt:2618 c-family/c.opt:2622
 #, no-c-format
@@ -4072,7 +4043,7 @@ msgstr "Звʼязати стандартну бібліотеку D динам
 #: m2/lang.opt:35
 #, no-c-format
 msgid "turns on case statement label compile time checking when using an expression of an enum type."
-msgstr ""
+msgstr "Увімкнути перевірку міток оператора case під час компіляції, коли використовується вираз типу enum."
 
 #: m2/lang.opt:39
 #, no-c-format
@@ -4097,12 +4068,12 @@ msgstr "додаткова перевірка семантики під час 
 #: m2/lang.opt:55
 #, no-c-format
 msgid "turns on compile time analysis in the first basic block of a procedure detecting access to uninitialized data."
-msgstr ""
+msgstr "Увімкнути аналіз під час компіляції в першому базовому блоці процедури для виявлення доступу до даних без початкового значення."
 
 #: m2/lang.opt:59
 #, no-c-format
 msgid "turns on compile time analysis to detect access to uninitialized variables, the checking can be specified by: known,cond,all."
-msgstr ""
+msgstr "Увімкнути аналіз коду під час компіляції для виявлення звернень до неініціалізованих змінних. Тип перевірки: known,cond,all."
 
 #: m2/lang.opt:63
 #, no-c-format
@@ -4140,16 +4111,14 @@ msgid "turn on internal debugging of the compiler (internal switch)"
 msgstr "увімкнути внутрішнє налагодження компілятора (внутрішній перемикач)"
 
 #: m2/lang.opt:95
-#, fuzzy, no-c-format
-#| msgid "turn on internal debugging of the compiler (internal switch)"
+#, no-c-format
 msgid "turn on tracing of procedure line numbers (internal switch)"
-msgstr "увімкнути внутрішнє налагодження компілятора (внутрішній перемикач)"
+msgstr "увімкнути трасування номерів рядків процедур (внутрішній перемикач)"
 
 #: m2/lang.opt:99
-#, fuzzy, no-c-format
-#| msgid "recognise the specified suffix as a definition module filename"
+#, no-c-format
 msgid "recognize the specified suffix as a definition module filename"
-msgstr "визнати вказаний суфікс як імʼя файлу модуля визначення"
+msgstr "розпізнавати вказаний суфікс як ім'я файлу модуля визначення"
 
 #: m2/lang.opt:103
 #, no-c-format
@@ -4192,10 +4161,9 @@ msgid "set all location values to a specific value (internal switch)"
 msgstr "встановити всі значення розташування на певне значення (внутрішній перемикач)"
 
 #: m2/lang.opt:135
-#, fuzzy, no-c-format
-#| msgid "turn on internal debugging of the compiler (internal switch)"
+#, no-c-format
 msgid "turn on internal debug tracing for quad,token,line,all (internal switch)"
-msgstr "увімкнути внутрішнє налагодження компілятора (внутрішній перемикач)"
+msgstr "увімкнути внутрішнє налагодження трасування для quad,token,line,all (внутрішній перемикач)"
 
 #: m2/lang.opt:139
 #, no-c-format
@@ -4238,10 +4206,9 @@ msgid "compile all implementation modules and program module at once"
 msgstr "компілювати всі модулі реалізації та модуль програми одночасно"
 
 #: m2/lang.opt:175
-#, fuzzy, no-c-format
-#| msgid "recognise the specified suffix as implementation and module filenames"
+#, no-c-format
 msgid "recognize the specified suffix as implementation and module filenames"
-msgstr "визнати вказаний суфікс як імена файлів реалізації та модуля"
+msgstr "розпізнавати вказаний суфікс як ім'я файлу реалізації та модуля"
 
 #: m2/lang.opt:179
 #, no-c-format
@@ -4344,10 +4311,9 @@ msgid "optimize non var unbounded parameters by passing it by reference, providi
 msgstr "оптимізувати незмінні незвʼязані параметри, передаючи їх за посиланням, за умови, що вони не змінюються у процедурі, яка їх викликає."
 
 #: m2/lang.opt:263
-#, fuzzy, no-c-format
-#| msgid "orders the initialization/finalializations for scaffold-static or force linking of modules if scaffold-dynamic"
+#, no-c-format
 msgid "orders the initialization/finalizations for scaffold-static or force linking of modules if scaffold-dynamic"
-msgstr "впорядковує ініціалізацію/фіналізацію для статичного риштування або примусового звʼязування модулів, якщо риштування динамічне"
+msgstr "впорядковує ініціалізацію/фіналізації для scaffold-static або примусове зв'язування модулів, якщо scaffold-dynamic"
 
 #: m2/lang.opt:271
 #, no-c-format
@@ -4402,7 +4368,7 @@ msgstr "-fgo-embedcfg=<файл>\tВивести списком вбудован
 #: go/lang.opt:66
 #, no-c-format
 msgid "-fgo-importcfg=<file>\tProvide file that tells where to find imports."
-msgstr ""
+msgstr "-fgo-importcfg=<файл>\tВкажіть файл, який вказує, де знайти імпорти."
 
 #: go/lang.opt:70
 #, no-c-format
@@ -4487,22 +4453,22 @@ msgstr "Максимальна глибина вибухнутих вузлів,
 #: analyzer/analyzer.opt:59
 #, no-c-format
 msgid "The number of bytes at which to ellipsize string literals in analyzer text art diagrams."
-msgstr ""
+msgstr "Кількість байтів для початку скорочення рядкових літералів у текстових діаграмах аналізатора."
 
 #: analyzer/analyzer.opt:63
 #, no-c-format
 msgid "The number of literal bytes to show at the head of a string literal in text art when ellipsizing it."
-msgstr ""
+msgstr "Кількість літеральних байтів для показу на початку рядкового літералу у текстовому мистецтві при його скороченні."
 
 #: analyzer/analyzer.opt:67
 #, no-c-format
 msgid "The number of literal bytes to show at the tail of a string literal in text art when ellipsizing it."
-msgstr ""
+msgstr "Кількість літеральних байтів для показу в кінці рядкового літералу у текстових схема при його скороченні (обрізанні)."
 
 #: analyzer/analyzer.opt:71
 #, no-c-format
 msgid "The ideal width in characters of text art diagrams generated by the analyzer."
-msgstr ""
+msgstr "Ідеальна ширина у символах текстових схем, згенерованих аналізатором."
 
 #: analyzer/analyzer.opt:75
 #, no-c-format
@@ -4585,10 +4551,9 @@ msgid "Warn about code paths in which floating-point arithmetic is used in locat
 msgstr "Попереджувати про шляхи коду, в яких використовується плаваюча точка арифметика в місцях, де потрібні точні обчислення."
 
 #: analyzer/analyzer.opt:139
-#, fuzzy, no-c-format
-#| msgid "Warn about code paths which appear to lead to infinite recursion."
+#, no-c-format
 msgid "Warn about code paths which appear to lead to an infinite loop."
-msgstr "Попереджувати про шляхи коду, які, здається, призводять до безкінечної рекурсії."
+msgstr "Попереджати про шляхи коду, які здаються ведуть до нескінченного циклу."
 
 #: analyzer/analyzer.opt:143
 #, no-c-format
@@ -4616,10 +4581,9 @@ msgid "Warn about code paths in which a write or read to a buffer is out-of-boun
 msgstr "Попереджувати про шляхи коду, в яких запис або читання в буфер виходить за межі."
 
 #: analyzer/analyzer.opt:163
-#, fuzzy, no-c-format
-#| msgid "Warn about code paths in which a write or read to a buffer is out-of-bounds."
+#, no-c-format
 msgid "Warn about code paths in which undefined behavior would occur due to overlapping buffers."
-msgstr "Попереджувати про шляхи коду, в яких запис або читання в буфер виходить за межі."
+msgstr "Попереджати про шляхи коду, в яких виникає невизначена поведінка через буфери які перекриваються."
 
 #: analyzer/analyzer.opt:167
 #, no-c-format
@@ -4697,10 +4661,9 @@ msgid "Warn about code paths in which an unsanitized value is used as a size."
 msgstr "Попереджувати про шляхи коду, в яких невідфільтроване значення використовується як розмір."
 
 #: analyzer/analyzer.opt:227
-#, fuzzy, no-c-format
-#| msgid "Warn about code paths in which a va_list is used after va_end."
+#, no-c-format
 msgid "Warn about code paths in which a call is made to strtok with undefined behavior."
-msgstr "Попереджувати про шляхи коду, в яких va_list використовується після va_end."
+msgstr "Попереджати про шляхи коду, в яких викликається strtok з невизначеною поведінкою."
 
 #: analyzer/analyzer.opt:231
 #, no-c-format
@@ -4748,10 +4711,9 @@ msgid "Warn about code paths in which an uninitialized value is used."
 msgstr "Попереджувати про шляхи коду, в яких використовується неініціалізоване значення."
 
 #: analyzer/analyzer.opt:267
-#, fuzzy, no-c-format
-#| msgid "Warn if the code is too complicated for the analyzer to fully explore."
+#, no-c-format
 msgid "Warn if expressions are too complicated for the analyzer to fully track."
-msgstr "Попереджувати, якщо код занадто складний для повного дослідження аналізатором."
+msgstr "Попереджати, якщо вирази занадто складні для повного відстеження аналізатором."
 
 #: analyzer/analyzer.opt:271
 #, no-c-format
@@ -4766,7 +4728,7 @@ msgstr "Обмежити роботу аналізатора лише вказа
 #: analyzer/analyzer.opt:279
 #, no-c-format
 msgid "Add extra annotations to diagrams."
-msgstr ""
+msgstr "Додати додаткові анотації до схем."
 
 #: analyzer/analyzer.opt:283
 #, no-c-format
@@ -4806,7 +4768,7 @@ msgstr "Увімкнути транзитивність обмежень під
 #: analyzer/analyzer.opt:311
 #, no-c-format
 msgid "Show events within system headers in analyzer execution paths."
-msgstr ""
+msgstr "Показати події всередині системних заголовків у шляхах виконання аналізатора."
 
 #: analyzer/analyzer.opt:315
 #, no-c-format
@@ -4879,10 +4841,9 @@ msgid "Dump various analyzer internals to SRCFILE.*.fg.dot and SRCFILE.*.tg.dot.
 msgstr "Зберегти різноманітні внутрішні дані аналізатора у файли SRCFILE.*.fg.dot та SRCFILE.*.tg.dot."
 
 #: analyzer/analyzer.opt:371
-#, fuzzy, no-c-format
-#| msgid "Dump various analyzer internals to SRCFILE.analyzer.txt."
+#, no-c-format
 msgid "Dump various analyzer internals to SRCFILE.*.infinite-loop.dot."
-msgstr "Вивантажте різні внутрішні частини аналізатора в SRCFILE.analyzer.txt."
+msgstr "Вивантажити різні внутрішні дані аналізатора до SRCFILE.*.infinite-loop.dot."
 
 #: analyzer/analyzer.opt:375
 #, no-c-format
@@ -5280,10 +5241,9 @@ msgid "-image_base <address>\tSpecify <address> as the base address for a dylib
 msgstr "-image_base <адреса>\tВказати <адресу> як базову адресу для dylib або пакету."
 
 #: config/darwin.opt:214
-#, fuzzy, no-c-format
-#| msgid "-init <symbol_name>\tThe symbol <symbol_name> will be used as the first initialiser for a dylib."
+#, no-c-format
 msgid "-init <symbol_name>\tThe symbol <symbol_name> will be used as the first initializer for a dylib."
-msgstr "-init <імʼя_символу>\tСимвол <імʼя_символу> буде використовуватися як перший ініціалізатор для dylib."
+msgstr "-init <symbol_name>\tСимвол <symbol_name> буде використовуватися як перший ініціалізатор для dylib."
 
 #: config/darwin.opt:218
 #, no-c-format
@@ -5321,10 +5281,9 @@ msgid "Do not add a default symbol exports to modules or dynamic libraries."
 msgstr "Не додавати експорт символів за замовчуванням до модулів або динамічних бібліотек."
 
 #: config/darwin.opt:246
-#, fuzzy, no-c-format
-#| msgid "Do not add a default symbol exports to modules or dynamic libraries."
+#, no-c-format
 msgid "Do not add default run paths (for the compiler library directories) to executables, modules or dynamic libraries."
-msgstr "Не додавати експорт символів за замовчуванням до модулів або динамічних бібліотек."
+msgstr "Не додавати шляхи за замовчуванням (для каталогів бібліотек компілятора) до виконуваних файлів, модулів або динамічних бібліотек."
 
 #: config/darwin.opt:250
 #, no-c-format
@@ -5872,7 +5831,7 @@ msgstr "-march=\tГенерувати код для заданої RISC-V ISA (
 #: config/riscv/riscv.opt:91
 #, no-c-format
 msgid "-march=help\tPrint supported -march extensions."
-msgstr ""
+msgstr "-march=help\tНадрукувати підтримувані розширення -march."
 
 #: config/riscv/riscv.opt:103 config/mips/mips.opt:430
 #, no-c-format
@@ -5927,10 +5886,9 @@ msgid "Take advantage of linker relaxations to reduce the number of instructions
 msgstr "Скористайтеся можливостями розслаблення звʼязувача, щоб зменшити кількість інструкцій, необхідних для матеріалізації адрес символів."
 
 #: config/riscv/riscv.opt:155
-#, fuzzy, no-c-format
-#| msgid "Enable the CSR checking for the ISA-dependent CRS and the read-only CSR. The ISA-dependent CSR are only valid when the specific ISA is set.  The read-only CSR can not be written by the CSR instructions."
+#, no-c-format
 msgid "Enable the CSR checking for the ISA-dependent CSR and the read-only CSR. The ISA-dependent CSR are only valid when the specific ISA is set.  The read-only CSR can not be written by the CSR instructions."
-msgstr "Увімкнути перевірку CSR для залежних від ISA CRS та для CSR, доступних тільки для читання. Залежні від ISA CRS є дійсними лише тоді, коли встановлено конкретний ISA. CSR, доступні тільки для читання, не можна записувати за допомогою інструкцій CSR."
+msgstr "Увімкнути перевірку CSR для ISA-залежних CSR та тільки для читання CSR. ISA-залежні CSR дійсні лише при встановленій конкретній ISA. Тільки для читання CSR не можуть бути записані інструкціями CSR."
 
 #: config/riscv/riscv.opt:161 config/aarch64/aarch64.opt:141
 #: config/i386/i386.opt:420
@@ -5989,10 +5947,9 @@ msgid "Set the version of RISC-V ISA spec."
 msgstr "Встановити версію специфікації RISC-V ISA."
 
 #: config/riscv/riscv.opt:511
-#, fuzzy, no-c-format
-#| msgid "Enable conditional move instruction usage."
+#, no-c-format
 msgid "Enable conditional moves unconditionally."
-msgstr "Увімкнути використання умовних команд переміщення."
+msgstr "Увімкнути умовні переміщення без умов."
 
 #: config/riscv/riscv.opt:515
 #, no-c-format
@@ -6000,48 +5957,44 @@ msgid "Always inline subword atomic operations."
 msgstr "Завжди вбудовувати під-словні атомні операції."
 
 #: config/riscv/riscv.opt:519
-#, fuzzy, no-c-format
-#| msgid "Use caller save register across calls if possible."
+#, no-c-format
 msgid "Inline strcmp calls if possible."
-msgstr "Використовувати реєстр збереження викликача під час викликів, якщо це можливо."
+msgstr "Використовувати вбудований strcmp, якщо це можливо."
 
 #: config/riscv/riscv.opt:523
-#, fuzzy, no-c-format
-#| msgid "Use caller save register across calls if possible."
+#, no-c-format
 msgid "Inline strncmp calls if possible."
-msgstr "Використовувати реєстр збереження викликача під час викликів, якщо це можливо."
+msgstr "Використовувати вбудований strncmp, якщо це можливо."
 
 #: config/riscv/riscv.opt:527
-#, fuzzy, no-c-format
-#| msgid "Reduce stack alignment on call sites if possible."
+#, no-c-format
 msgid "Inline strlen calls if possible."
-msgstr "Зменшити вирівнювання стеку на місцях виклику, якщо це можливо."
+msgstr "Використовувати вбудований strlen, якщо це можливо."
 
 #: config/riscv/riscv.opt:531
 #, no-c-format
 msgid "Max number of bytes to compare as part of inlined strcmp/strncmp routines (default: 64)."
-msgstr ""
+msgstr "Максимальна кількість байтів для порівняння як частини вбудованих функцій strcmp/strncmp (за замовчуванням: 64)."
 
 #: config/riscv/riscv.opt:535
 #, no-c-format
 msgid "The RVV possible LMUL (-mrvv-max-lmul=):"
-msgstr ""
+msgstr "Можливий LMUL для RVV (-mrvv-max-lmul=):"
 
 #: config/riscv/riscv.opt:554
 #, no-c-format
 msgid "-mrvv-max-lmul=<string>\tSet the RVV LMUL of auto-vectorization."
-msgstr ""
+msgstr "-mrvv-max-lmul=<значення>\tВстановити максимальний множник довжини вектора RVV (LMUL) для автовекторизації."
 
 #: config/riscv/riscv.opt:561
-#, fuzzy, no-c-format
-#| msgid "Valid arguments to -mstringop-strategy=:"
+#, no-c-format
 msgid "Valid arguments to -param=vsetvl-strategy=:"
-msgstr "Дійсні аргументи для -mstringop-strategy=."
+msgstr "Дійсні аргументи для -param=vsetvl-strategy=:"
 
 #: config/riscv/riscv.opt:574
 #, no-c-format
 msgid "-param=vsetvl-strategy=<string>\tSet the optimization level of VSETVL insert pass."
-msgstr ""
+msgstr "-param=vsetvl-strategy=<рядок>\tВстановити рівень оптимізації етапу вставки VSETVL."
 
 #: config/riscv/riscv.opt:578 config/i386/i386.opt:496
 #, no-c-format
@@ -6049,22 +6002,19 @@ msgid "Valid arguments to -mstringop-strategy=:"
 msgstr "Дійсні аргументи для -mstringop-strategy=."
 
 #: config/riscv/riscv.opt:594
-#, fuzzy, no-c-format
-#| msgid "Specify memset expansion strategy when expected size is known."
+#, no-c-format
 msgid "Specify stringop expansion strategy."
-msgstr "Вказати стратегію розширення memset, коли відомий очікуваний розмір."
+msgstr "Вказати стратегію розгортання операцій з рядками (stringop)."
 
 #: config/riscv/riscv.opt:598
-#, fuzzy, no-c-format
-#| msgid "The possible SVE vector lengths:"
+#, no-c-format
 msgid "The possible RVV vector register lengths:"
-msgstr "Можливі довжини векторів SVE:"
+msgstr "Можливі довжини регістрів векторів RVV:"
 
 #: config/riscv/riscv.opt:608
-#, fuzzy, no-c-format
-#| msgid "-msve-vector-bits=<number>\tSet the number of bits in an SVE vector register."
+#, no-c-format
 msgid "-mrvv-vector-bits=<string>\tSet the kind of bits for an RVV vector register."
-msgstr "-msve-vector-bits=<число>\tВстановити кількість бітів у регістрі вектора SVE."
+msgstr "-mrvv-vector-bits=<рядок>\tВстановити тип бітів для регістра вектора RVV."
 
 #: config/riscv/riscv.opt:612 config/aarch64/aarch64.opt:49
 #: config/loongarch/loongarch.opt:283
@@ -6224,16 +6174,14 @@ msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
 msgstr "Обхід для помилки ARM Cortex-A53 з номером 843419."
 
 #: config/aarch64/aarch64.opt:102
-#, fuzzy, no-c-format
-#| msgid "Specify how to access the thread pointer."
+#, no-c-format
 msgid "The register used to access the thread pointer:"
-msgstr "Вказати, як отримати доступ до вказівника потоку."
+msgstr "Регістр, який використовується для доступу до вказівника потоку (thread pointer):"
 
 #: config/aarch64/aarch64.opt:133
-#, fuzzy, no-c-format
-#| msgid "Specify thread pointer register number."
+#, no-c-format
 msgid "Specify the thread pointer register."
-msgstr "Вказати номер реєстра вказівника потоку."
+msgstr "Вказати регістр вказівника потоку (thread pointer)."
 
 #: config/aarch64/aarch64.opt:137
 #, no-c-format
@@ -6313,7 +6261,7 @@ msgstr "Увімкнути наближення ділення. Увімкнен
 #: config/aarch64/aarch64.opt:254
 #, no-c-format
 msgid "Specify when to enable an early register allocation pass.  The possibilities are: all functions, functions that have access to strided multi-register instructions, and no functions."
-msgstr ""
+msgstr "Вкажіть, коли увімкнути ранній етап розподілу регістрів. Можливості: всі функції, функції, які мають доступ до інструкцій з кроковим доступом до пам'яті для багатореєстрових операцій, і жодні функції."
 
 #: config/aarch64/aarch64.opt:260
 #, no-c-format
@@ -6338,12 +6286,12 @@ msgstr "Генерувати код для відстеження, коли пр
 #: config/aarch64/aarch64.opt:294
 #, no-c-format
 msgid "Enable the copy of the AArch64 load/store pair fusion pass that runs before register allocation."
-msgstr ""
+msgstr "Увімкнути оптимізацію пари операцій завантаження/зберігання AArch64, яка виконується перед розподілом регістрів."
 
 #: config/aarch64/aarch64.opt:299
 #, no-c-format
 msgid "Enable the copy of the AArch64 load/store pair fusion pass that runs after register allocation."
-msgstr ""
+msgstr "Включити оптимізацію пари операцій завантаження/збереження для архітектури AArch64, яка виконується після розподілу регістрів."
 
 #: config/aarch64/aarch64.opt:318
 #, no-c-format
@@ -6363,7 +6311,7 @@ msgstr "Генерувати локальні виклики до атомних
 #: config/aarch64/aarch64.opt:337
 #, no-c-format
 msgid "When vectorizing, consider using multiple different approaches and use the cost model to choose the cheapest one."
-msgstr ""
+msgstr "При векторизації розглядайте можливість використання декількох різних підходів і використовуйте модель коштів для вибору найдешевшого."
 
 #: config/aarch64/aarch64.opt:342
 #, no-c-format
@@ -6398,22 +6346,22 @@ msgstr "Обмежити, наскільки далеко автовектори
 #: config/aarch64/aarch64.opt:372
 #, no-c-format
 msgid "--param=aarch64-ldp-policy=[default|always|never|aligned] Fine-grained policy for load pairs."
-msgstr ""
+msgstr "--param=aarch64-ldp-policy=[default|always|never|aligned] Деталізована політика для пар інструкцій завантаження в архітектурі ARM64."
 
 #: config/aarch64/aarch64.opt:376
 #, no-c-format
 msgid "--param=aarch64-stp-policy=[default|always|never|aligned] Fine-grained policy for store pairs."
-msgstr ""
+msgstr "--param=aarch64-stp-policy=[default|always|never|aligned] Деталізована політика для пар інструкцій збереження в архітектурі ARM64."
 
 #: config/aarch64/aarch64.opt:395
 #, no-c-format
 msgid "Limit on number of alias checks performed when attempting to form an ldp/stp."
-msgstr ""
+msgstr "Обмеження на кількість перевірок псевдонімів, які виконуються при спробі утворити ldp/stp."
 
 #: config/aarch64/aarch64.opt:399
 #, no-c-format
 msgid "Param to control which writeback opportunities we try to handle in the load/store pair fusion pass.  A value of zero disables writeback handling.  One means we try to form pairs involving one or more existing individual writeback accesses where possible.  A value of two means we also try to opportunistically form writeback opportunities by folding in trailing destructive updates of the base register used by a pair."
-msgstr ""
+msgstr "Параметр для керування тими можливостями запису, які ми намагаємося обробити на етапі злиття пар завантаження/збереження. Значення нуль вимкне обробку запису. Один означає, що ми намагаємося формувати пари, які включають один або кілька існуючих окремих доступів до запису, де це можливо. Значення два також означає, що ми намагаємося випадково формувати можливості запису шляхом згортання в кінці руйнівних оновлень регістра бази, який використовується парою."
 
 #: config/linux.opt:24
 #, no-c-format
@@ -6707,10 +6655,9 @@ msgid "Assume labels and symbols can be addressed using 16 bit absolute addresse
 msgstr "Припускається, що мітки та символи можуть бути адресовані за допомогою абсолютних адрес 16 біт."
 
 #: config/epiphany/epiphany.opt:108
-#, fuzzy, no-c-format
-#| msgid "A floatig point to integer truncation may be replaced with rounding to save mode switching."
+#, no-c-format
 msgid "A floating point to integer truncation may be replaced with rounding to save mode switching."
-msgstr "Обрізання з плаваючої точки до цілого числа може бути замінено округленням для збереження перемикання режимів."
+msgstr "Обрізання з плаваючої точки до цілого числа може бути замінено округленням для економії перемикання режимів."
 
 #: config/epiphany/epiphany.opt:112
 #, no-c-format
@@ -7017,7 +6964,7 @@ msgstr "Помістити переміщені дані тільки для ч
 #: config/i386/mingw.opt:23
 #, no-c-format
 msgid "Preprocess, compile or link with specified C RunTime DLL library."
-msgstr ""
+msgstr "Проходити попередню обробку, компілювати або з'єднувати з вказаною бібліотекою DLL C Runtime."
 
 #: config/i386/mingw.opt:33
 #, no-c-format
@@ -7112,10 +7059,9 @@ msgid "Branches are this expensive (arbitrary units)."
 msgstr "Гілки коштують так дорого (довільні одиниці)."
 
 #: config/i386/i386.opt:300
-#, fuzzy, no-c-format
-#| msgid "-mlarge-data-threshold=<number>\tData greater than given threshold will go into .ldata section in x86-64 medium model."
+#, no-c-format
 msgid "-mlarge-data-threshold=<number>\tData greater than given threshold will go into a large data section in x86-64 medium and large code models."
-msgstr "-mlarge-data-threshold=<число>\tДані, більші за вказаний поріг, будуть розміщені в розділі .ldata в середньому моделі x86-64."
+msgstr "-mlarge-data-threshold=<число>\tДані, розмір яких перевищує заданий поріг, будуть розміщені в секції великих даних у моделях коду x86-64 medium і large."
 
 #: config/i386/i386.opt:304
 #, no-c-format
@@ -7370,7 +7316,7 @@ msgstr "Відома бажана довжина вектора регістра
 #: config/i386/i386.opt:652
 #, no-c-format
 msgid "Enable floating-point status flags setting SSE vector operations on partial vectors."
-msgstr ""
+msgstr "Увімкнути встановлення прапорів статусу плаваючої точки для векторних операцій SSE на часткових векторах."
 
 #: config/i386/i386.opt:656
 #, no-c-format
@@ -7385,7 +7331,7 @@ msgstr "Максимальна кількість бітів, яку можна
 #: config/i386/i386.opt:664
 #, no-c-format
 msgid "Optimize noreturn functions by not saving callee-saved registers used in the function."
-msgstr ""
+msgstr "Оптимізувати функції без повернення шляхом не зберігання використовуваних у них регістрів, які зберігаються викликаними функціями."
 
 #: config/i386/i386.opt:670
 #, no-c-format
@@ -8053,74 +7999,64 @@ msgid "Support AMX-COMPLEX built-in functions and code generation."
 msgstr "Підтримка вбудованих функцій та генерація коду для AMX-COMPLEX."
 
 #: config/i386/i386.opt:1307
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVXVNNIINT8 built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVXVNNIINT16 built-in functions and code generation."
-msgstr "Підтримка вбудованих функцій та генерація коду для MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 та AVXVNNIINT8."
+msgstr "Підтримка вбудованих функцій та генерація коду для MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 і AVXVNNIINT16."
 
 #: config/i386/i386.opt:1312
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and SM3 built-in functions and code generation."
-msgstr "Підтримка вбудованих функцій і генерація коду для MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX і FMA."
+msgstr "Підтримка вбудованих функцій та генерація коду для MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX і SM3."
 
 #: config/i386/i386.opt:1317
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and SHA512 built-in functions and code generation."
-msgstr "Підтримка вбудованих функцій та генерація коду для MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX та AVX2."
+msgstr "Підтримка вбудованих функцій та генерація коду для MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX і SHA512."
 
 #: config/i386/i386.opt:1322
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and SM4 built-in functions and code generation."
-msgstr "Підтримка вбудованих функцій і генерація коду для MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX і FMA."
+msgstr "Підтримка вбудованих функцій та генерація коду для MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX і SM4."
 
 #: config/i386/i386.opt:1327
-#, fuzzy, no-c-format
-#| msgid "Enable vectorization on trees."
+#, no-c-format
 msgid "Enable vectorization for gather instruction."
-msgstr "Увімкнути векторизацію на деревах."
+msgstr "Увімкнути векторизацію для інструкції збору (gather)."
 
 #: config/i386/i386.opt:1331
-#, fuzzy, no-c-format
-#| msgid "Enable vectorization on trees."
+#, no-c-format
 msgid "Enable vectorization for scatter instruction."
-msgstr "Увімкнути векторизацію на деревах."
+msgstr "Увімкнути векторизацію для інструкції розсіювання (scatter)."
 
 #: config/i386/i386.opt:1335
 #, no-c-format
 msgid "Support code generation for APX features, including EGPR, PUSH2POP2, NDD and PPX."
-msgstr ""
+msgstr "Підтримка генерації коду для функцій APX, включаючи EGPR, PUSH2POP2, NDD та PPX."
 
 #: config/i386/i386.opt:1364
 #, no-c-format
 msgid "Enable GPR32 in inline asm when APX_F enabled."
-msgstr ""
+msgstr "Увімкнути GPR32 у встроєному асемблерному коді, коли включено APX_F."
 
 #: config/i386/i386.opt:1368
-#, fuzzy, no-c-format
-#| msgid "Support BMI2 built-in functions and code generation."
+#, no-c-format
 msgid "Support 512 bit vector built-in functions and code generation."
-msgstr "Підтримка вбудованих функцій BMI2 та генерація коду."
+msgstr "Підтримка вбудованих функцій та генерація коду для векторів довжиною 512 біт."
 
 #: config/i386/i386.opt:1372
-#, fuzzy, no-c-format
-#| msgid "Support AES built-in functions and code generation."
+#, no-c-format
 msgid "Support USER_MSR built-in functions and code generation."
-msgstr "Підтримка вбудованих функцій AES та генерація коду."
+msgstr "Підтримка вбудованих функцій та генерація коду для USER_MSR."
 
 #: config/i386/i386.opt:1376 config/i386/i386.opt:1386
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, and AVX10.1 built-in functions and code generation."
-msgstr "Підтримка вбудованих функцій та генерація коду для MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 та AVX512F."
+msgstr "Підтримка вбудованих функцій MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 та AVX10.1 і генерація коду."
 
 #: config/i386/i386.opt:1381
-#, fuzzy, no-c-format
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F built-in functions and code generation."
+#, no-c-format
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, and AVX10.1-512 built-in functions and code generation."
-msgstr "Підтримка вбудованих функцій та генерація коду для MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 та AVX512F."
+msgstr "Підтримка вбудованих функцій MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 та AVX10.1-512 і генерація коду."
 
 #: config/pa/pa64-hpux.opt:23
 #, no-c-format
@@ -8489,44 +8425,39 @@ msgid "Assume the VxWorks vThreads environment."
 msgstr "Припустимо середовище VxWorks vThreads."
 
 #: config/avr/avr.opt:23
-#, fuzzy, no-c-format
-#| msgid "Use subroutines for function prologues and epilogues."
+#, no-c-format
 msgid "Optimization. Use subroutines for function prologues and epilogues."
-msgstr "Використовуйте підпрограми для прологів та епілогів функцій."
+msgstr "Оптимізація. Використовувати підпрограми для прологів і епілогів функцій."
 
 #: config/avr/avr.opt:27
-#, fuzzy, no-c-format
-#| msgid "-mmcu=MCU\tSelect the target MCU."
+#, no-c-format
 msgid "-mmcu=<MCU>\tSelect the target MCU."
-msgstr "-mmcu=МКП\tВиберати цільовий МКП."
+msgstr "-mmcu=<MCU>\tВибрати цільовий мікроконтролер (MCU)."
 
 #: config/avr/avr.opt:31
-#, fuzzy, no-c-format
-#| msgid "Allow usage of __gcc_isr pseudo instructions in ISR prologues and epilogues."
+#, no-c-format
 msgid "Optimization. Allow usage of __gcc_isr pseudo instructions in ISR prologues and epilogues."
-msgstr "Дозволити використання псевдоінструкцій __gcc_isr в прологах та епілогах обробників переривань."
+msgstr "Оптимізація. Дозволяє використання псевдоінструкцій __gcc_isr у прологах і епілогах переривань (ISR)."
 
 #: config/avr/avr.opt:35
-#, fuzzy, no-c-format
-#| msgid "Set the number of 64 KiB flash segments."
+#, no-c-format
 msgid "This option is used internally. Set the number of 64 KiB flash segments."
-msgstr "Встановити кількість сегментів флеш-памʼяті розміром 64 Кб."
+msgstr "Ця опція використовується внутрішньо. Встановлює кількість сегментів флеш-пам'яті по 64 КіБ."
 
 #: config/avr/avr.opt:39
 #, no-c-format
 msgid "This option is used internally. Indicate presence of a processor erratum.  Do not skip 32-bit instructions."
-msgstr ""
+msgstr "Ця опція використовується внутрішньо. Вказує на присутність помилки процесора знайденої пізніше. Не пропускати 32 бітні інструкції."
 
 #: config/avr/avr.opt:43
-#, fuzzy, no-c-format
-#| msgid "Enable Read-Modify-Write (RMW) instructions support/use."
+#, no-c-format
 msgid "This option is used internally. Enable Read-Modify-Write (RMW) instructions support/use."
-msgstr "Увімкнути підтримку/використання інструкцій Read-Modify-Write (RMW)."
+msgstr "Ця опція використовується внутрішньо. Увімкнути підтримку/використання інструкцій читання-модифікації-запису (RMW)."
 
 #: config/avr/avr.opt:53
 #, no-c-format
 msgid "This option is used internally for multilib generation and selection.  Assume RJMP / RCALL can target all program memory."
-msgstr ""
+msgstr "Ця опція використовується внутрішньо для генерації та вибору мультибібліотек. Припустити, що RJMP / RCALL може адресувати всю програмну пам'ять."
 
 #: config/avr/avr.opt:57
 #, no-c-format
@@ -8539,16 +8470,14 @@ msgid "Change the stack pointer without disabling interrupts."
 msgstr "Змінити вказівник стеку без вимкнення переривань."
 
 #: config/avr/avr.opt:65
-#, fuzzy, no-c-format
-#| msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 0."
+#, no-c-format
 msgid "-mbranch-cost=<cost>\tOptimization. Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 0."
-msgstr "Встановити вартість гілок для умовних гілкових інструкцій. Розумні значення - це невеликі, не відʼємні цілі числа. За замовчуванням вартість гілки дорівнює 0."
+msgstr "-mbranch-cost=<вартість>\tОптимізація. Встановлює вартість для інструкцій умовних гілок. Розумні значення - це невеликі, невід'ємні цілі числа. Вартість гілки за замовчуванням дорівнює 0."
 
 #: config/avr/avr.opt:69
-#, fuzzy, no-c-format
-#| msgid "Treat main as if it had attribute OS_task."
+#, no-c-format
 msgid "Optimization. Treat main as if it had attribute OS_task."
-msgstr "Трактувати main так, ніби вона мала атрибут OS_task."
+msgstr "Оптимізація. Обробляти головну функцію так, ніби вона має атрибут OS_task."
 
 #: config/avr/avr.opt:79
 #, no-c-format
@@ -8556,10 +8485,9 @@ msgid "Change only the low 8 bits of the stack pointer."
 msgstr "Змінити лише нижні 8 біт вказівника стеку."
 
 #: config/avr/avr.opt:83
-#, fuzzy, no-c-format
-#| msgid "Relax branches."
+#, no-c-format
 msgid "Optimization. Relax branches."
-msgstr "Розслабити гілки."
+msgstr "Оптимізація. Розслаблення гілок."
 
 #: config/avr/avr.opt:87
 #, no-c-format
@@ -8567,41 +8495,39 @@ msgid "Make the linker relaxation machine assume that a program counter wrap-aro
 msgstr "Зробити машину розслаблення лінкера припускає, що відбувається обгортання лічильника програми."
 
 #: config/avr/avr.opt:91
-#, fuzzy, no-c-format
-#| msgid "Accumulate outgoing function arguments and acquire/release the needed stack space for outgoing function arguments in function prologue/epilogue.  Without this option, outgoing arguments are pushed before calling a function and popped afterwards.  This option can lead to reduced code size for functions that call many functions that get their arguments on the stack like, for example printf."
+#, no-c-format
 msgid "Optimization. Accumulate outgoing function arguments and acquire/release the needed stack space for outgoing function arguments in function prologue/epilogue.  Without this option, outgoing arguments are pushed before calling a function and popped afterwards.  This option can lead to reduced code size for functions that call many functions that get their arguments on the stack like, for example printf."
-msgstr "Накопичувати вихідні аргументи функції та здобудьте / звільніть необхідний простір стеку для вихідних аргументів функції в пролог / епілог функції. Без цієї опції вихідні аргументи викликаються перед викликом функції та видаляються після цього. Ця опція може призвести до зменшення розміру коду для функцій, які викликають багато функцій, які отримують свої аргументи зі стеку, наприклад, printf."
+msgstr "Оптимізація. Накопичувати вихідні аргументи функції та отримувати/звільняти необхідний стековий простір для вихідних аргументів функції в пролозі/епілозі функції. Без цієї опції вихідні аргументи поміщаються на стек перед викликом функції та знімаються після цього. Ця опція може призвести до зменшення розміру коду для функцій, які викликають багато функцій, які отримують свої аргументи зі стеку, наприклад printf."
 
 #: config/avr/avr.opt:95
-#, fuzzy, no-c-format
-#| msgid "When accessing RAM, use X as imposed by the hardware, i.e. just use pre-decrement, post-increment and indirect addressing with the X register.  Without this option, the compiler may assume that there is an addressing mode X+const similar to Y+const and Z+const and emit instructions to emulate such an addressing mode for X."
+#, no-c-format
 msgid "Optimization. When accessing RAM, use X as imposed by the hardware, i.e. just use pre-decrement, post-increment and indirect addressing with the X register.  Without this option, the compiler may assume that there is an addressing mode X+const similar to Y+const and Z+const and emit instructions to emulate such an addressing mode for X."
-msgstr "При доступі до ОЗП використовувати X, як вимагає апаратне забезпечення, тобто використовувати переддекремент, післяінкремент та непряме звертання з використанням регістра X. Без цієї опції компілятор може припустити, що існує режим адресації X+const, подібний до Y+const та Z+const, і генерувати інструкції для емуляції такого режиму адресації для X."
+msgstr "Оптимізація. При доступі до RAM використовувати X, як це вимагає апаратне забезпечення, тобто використовувати тільки перед-декремент, після-інкремент та непряме адресування з регістром X. Без цієї опції компілятор може припустити, що існує режим адресації X+const, схожий на Y+const і Z+const, і видавати інструкції для емуляції такого режиму адресації для X."
 
 #: config/avr/avr.opt:99
 #, no-c-format
 msgid "This option is used internally. The device has the bitfield NVMCTRL_CTRLB.FLMAP."
-msgstr ""
+msgstr "Ця опція використовується внутрішньо. Пристрій має бітове поле NVMCTRL_CTRLB.FLMAP."
 
 #: config/avr/avr.opt:103
 #, no-c-format
 msgid "The device has the .rodata section located in the RAM area."
-msgstr ""
+msgstr "Пристрій має секцію тільки для читання .rodata, розташовану у RAM-області."
 
 #: config/avr/avr.opt:108
 #, no-c-format
 msgid "This option is used internally for multilib generation and selection. The device has no SPH special function register."
-msgstr ""
+msgstr "Ця опція використовується внутрішньо для генерації та вибору мультибібліотек. Пристрій не має спеціального функціонального регістра SPH."
 
 #: config/avr/avr.opt:112
 #, no-c-format
 msgid "Optimization. Split register additions from load/store instructions. Most useful on Reduced Tiny."
-msgstr ""
+msgstr "Оптимізація. Розділити регістрові додавання від інструкцій завантаження/збереження. Найкорисніше на Reduced Tiny."
 
 #: config/avr/avr.opt:116
 #, no-c-format
 msgid "-mfuse-add=<0,2>\tOptimization. Split register additions from load/store instructions. Most useful on Reduced Tiny."
-msgstr ""
+msgstr "-mfuse-add=<0,2>\tОптимізація. Відділити регістрові додавання від інструкцій завантаження/збереження. Найкорисніше на Reduced Tiny."
 
 #: config/avr/avr.opt:120
 #, no-c-format
@@ -8619,10 +8545,9 @@ msgid "Allow to use truncation instead of rounding towards zero for fractional f
 msgstr "Дозволити використовувати обрізку замість округлення до нуля для дробових фіксованих типів."
 
 #: config/avr/avr.opt:132
-#, fuzzy, no-c-format
-#| msgid "Assume that all data in static storage can be accessed by LDS / STS.  This option is only useful for reduced Tiny devices."
+#, no-c-format
 msgid "Assume that all data in static storage can be accessed by LDS / STS instructions.  This option is only useful for reduced Tiny devices like ATtiny40."
-msgstr "Припускати, що всі дані у статичному сховищі можна отримати за допомогою LDS / STS. Ця опція корисна лише для зменшених пристроїв Tiny."
+msgstr "Припустити, що всі дані у статичному зберіганні можуть бути доступні інструкціями LDS / STS. Ця опція корисна тільки для зменшених пристроїв Tiny, таких як ATtiny40."
 
 #: config/avr/avr.opt:136
 #, no-c-format
@@ -8937,7 +8862,7 @@ msgstr "Зберігайте всі регістри аргументів у с
 #: config/s390/s390.opt:335
 #, no-c-format
 msgid "Assume external symbols, whose natural alignment would be 1, to be potentially unaligned.  By default all symbols without explicit alignment are assumed to reside on a 2 byte boundary as mandated by the IBM Z ABI."
-msgstr ""
+msgstr "Припустити, що зовнішні символи, які мають природнє вирівнювання 1, можуть бути невирівняними. За замовчуванням всі символи без явного вирівнювання вважаються розташованими на межі 2 байтів, як вимагається IBM Z ABI."
 
 #: config/rl78/rl78.opt:27 config/rx/elf.opt:26 config/csky/csky.opt:198
 #, no-c-format
@@ -10243,32 +10168,29 @@ msgid "Allow hardware floating-point instructions to cover both 32-bit and 64-bi
 msgstr "Дозволити апаратним інструкціям з плаваючою комою охоплювати як 32-бітні, так і 64-бітні операції."
 
 #: config/loongarch/loongarch.opt:81
-#, fuzzy, no-c-format
-#| msgid "FPU types of LoongArch:"
+#, no-c-format
 msgid "SIMD extension levels of LoongArch:"
-msgstr "Типи FPU LoongArch:"
+msgstr "Рівні розширень SIMD для LoongArch:"
 
 #: config/loongarch/loongarch.opt:94
-#, fuzzy, no-c-format
-#| msgid "-march=ISA\tGenerate code for the given ISA."
+#, no-c-format
 msgid "-msimd=SIMD\tGenerate code for the given SIMD extension."
-msgstr "-march=ISA\tГенерувати код для заданого ISA."
+msgstr "-msimd=SIMD\tГенерувати код для заданого розширення SIMD."
 
 #: config/loongarch/loongarch.opt:98
 #, no-c-format
 msgid "Enable LoongArch SIMD Extension (LSX, 128-bit)."
-msgstr ""
+msgstr "Увімкнути розширення LoongArch SIMD (LSX, 128 біт)."
 
 #: config/loongarch/loongarch.opt:102
 #, no-c-format
 msgid "Enable LoongArch Advanced SIMD Extension (LASX, 256-bit)."
-msgstr ""
+msgstr "Увімкнути розширення LoongArch Advanced SIMD (LASX, 256 біт)."
 
 #: config/loongarch/loongarch.opt:107
-#, fuzzy, no-c-format
-#| msgid "LoongArch CPU types:"
+#, no-c-format
 msgid "LoongArch ARCH presets:"
-msgstr "Типи процесорів LoongArch:"
+msgstr "Попередньо встановлені налаштування LoongArch ARCH:"
 
 #: config/loongarch/loongarch.opt:132
 #, no-c-format
@@ -10276,10 +10198,9 @@ msgid "-march=PROCESSOR\tGenerate code for the given PROCESSOR ISA."
 msgstr "-march=PROCESSOR\tГенерувати код для вказаного ISA процесора."
 
 #: config/loongarch/loongarch.opt:136
-#, fuzzy, no-c-format
-#| msgid "LoongArch CPU types:"
+#, no-c-format
 msgid "LoongArch TUNE presets:"
-msgstr "Типи процесорів LoongArch:"
+msgstr "Попередньо встановлені налаштування LoongArch TUNE:"
 
 #: config/loongarch/loongarch.opt:155
 #, no-c-format
@@ -10327,10 +10248,9 @@ msgid "-mmax-inline-memcpy-size=SIZE\tSet the max size of memcpy to inline, defa
 msgstr "-mmax-inline-memcpy-size=SIZE\tВстановити максимальний розмір memcpy для вбудовування, за замовчуванням 1024."
 
 #: config/loongarch/loongarch.opt:214 config/mips/mips.opt:150
-#, fuzzy, no-c-format
-#| msgid "The code model option names for -mcmodel:"
+#, no-c-format
 msgid "The code model option names for -mexplicit-relocs:"
-msgstr "Назви опцій моделі коду для -mcmodel:"
+msgstr "Назви опцій моделі коду для -mexplicit-relocs:"
 
 #: config/loongarch/loongarch.opt:227 config/mips/mips.opt:163
 #, no-c-format
@@ -10338,16 +10258,14 @@ msgid "Use %reloc() assembly operators."
 msgstr "Використовувати оператори збірки %reloc()."
 
 #: config/loongarch/loongarch.opt:231 config/mips/mips.opt:167
-#, fuzzy, no-c-format
-#| msgid "Use %reloc() assembly operators."
+#, no-c-format
 msgid "Use %reloc() assembly operators (for backward compatibility)."
-msgstr "Використовувати оператори збірки %reloc()."
+msgstr "Використовувати оператори асемблера %reloc() (для зворотньої сумісності)."
 
 #: config/loongarch/loongarch.opt:239
-#, fuzzy, no-c-format
-#| msgid "Generate software reciprocal divide and square root for better throughput."
+#, no-c-format
 msgid "Generate approximate reciprocal divide and square root for better throughput."
-msgstr "Генерувати програмне ділення зворотним значенням та квадратний корінь для кращої продуктивності."
+msgstr "Генерувати приблизне ділення зворотним значенням та квадратний корінь для кращої продуктивності."
 
 #: config/loongarch/loongarch.opt:270
 #, no-c-format
@@ -10355,44 +10273,39 @@ msgid "Avoid using the GOT to access external symbols."
 msgstr "Уникати використання GOT для доступу до зовнішніх символів."
 
 #: config/loongarch/loongarch.opt:279
-#, fuzzy, no-c-format
-#| msgid "Enable relaxing in the assembler."
+#, no-c-format
 msgid "Pass -mrelax or -mno-relax option to the assembler."
-msgstr "Увімкнути розслаблення в асемблері."
+msgstr "Передати опцію -mrelax або -mno-relax асемблеру."
 
 #: config/loongarch/loongarch.opt:297
-#, fuzzy, no-c-format
-#| msgid "Used to limit unroll factor which indicates how much the autovectorizer may unroll a loop.  The default value is 4."
+#, no-c-format
 msgid "Used to limit unroll factor which indicates how much the autovectorizer may unroll a loop.  The default value is 6."
-msgstr "Використовується для обмеження фактора розгортання, який вказує, наскільки автоматичний векторизатор може розгорнути цикл. Значення за замовчуванням - 4."
+msgstr "Використовується для обмеження фактора розгортання, який вказує на те, на скільки автовекторизатор може розгорнути цикл. Значення за замовчуванням дорівнює 6."
 
 #: config/loongarch/loongarch.opt:315
-#, fuzzy, no-c-format
-#| msgid "Support flag-preserving add-carry instructions."
+#, no-c-format
 msgid "Support frecipe.{s/d} and frsqrte.{s/d} instructions."
-msgstr "Підтримка інструкцій збереження прапорців при додаванні з переносом."
+msgstr "Підтримка інструкцій frecipe.{s/d} та frsqrte.{s/d}."
 
 #: config/loongarch/loongarch.opt:319
 #, no-c-format
 msgid "Support div.w[u] and mod.w[u] instructions with inputs not sign-extended."
-msgstr ""
+msgstr "Підтримка інструкцій div.w[u] та mod.w[u] з входами, які не розширені знаком."
 
 #: config/loongarch/loongarch.opt:323
-#, fuzzy, no-c-format
-#| msgid "Support XSAVEC instructions."
+#, no-c-format
 msgid "Support am{swap/add}[_db].{b/h} instructions."
-msgstr "Підтримка інструкцій XSAVEC."
+msgstr "Підтримка інструкцій am{swap/add}[_db].{b/h}."
 
 #: config/loongarch/loongarch.opt:327
-#, fuzzy, no-c-format
-#| msgid "Support XSAVEC instructions."
+#, no-c-format
 msgid "Support amcas[_db].{b/h/w/d} instructions."
-msgstr "Підтримка інструкцій XSAVEC."
+msgstr "Підтримка інструкцій amcas[_db].{b/h/w/d}."
 
 #: config/loongarch/loongarch.opt:331
 #, no-c-format
 msgid "Do not need load-load barriers (dbar 0x700)."
-msgstr ""
+msgstr "Не потрібні бар'єри завантаження-завантаження (dbar 0x700)."
 
 #: config/or1k/elf.opt:28
 #, no-c-format
@@ -12570,16 +12483,14 @@ msgid "Warn about invalid OpenACC dimensions."
 msgstr "Попереджати про недійсні розміри OpenACC."
 
 #: config/gcn/gcn.opt:101
-#, fuzzy, no-c-format
-#| msgid "SRAM-ECC modes:"
+#, no-c-format
 msgid "SRAM-ECC and XNACK modes:"
-msgstr "Режими SRAM-ECC:"
+msgstr "Режими SRAM-ECC та XNACK:"
 
 #: config/gcn/gcn.opt:117
-#, fuzzy, no-c-format
-#| msgid "Compile for devices requiring XNACK enabled. Default off."
+#, no-c-format
 msgid "Compile for devices requiring XNACK enabled. Default \"any\" if USM is supported."
-msgstr "Компілювати для пристроїв, які вимагають увімкнення XNACK. За замовчуванням вимкнено."
+msgstr "Скомпілювати для пристроїв, які вимагають включеного XNACK. За замовчуванням \"any\", якщо підтримується USM."
 
 #: config/gcn/gcn.opt:121
 #, no-c-format
@@ -12589,7 +12500,7 @@ msgstr "Компілювати для пристроїв з увімкненою
 #: config/gcn/gcn.opt:125
 #, no-c-format
 msgid "--param=gcn-preferred-vectorization-factor=[default,32,64]\tPreferred vectorization factor."
-msgstr ""
+msgstr "--param=gcn-preferred-vectorization-factor=[default,32,64]\tБажаний фактор векторизації."
 
 #: config/fr30/fr30.opt:23
 #, no-c-format
@@ -12637,50 +12548,44 @@ msgid "Enable 32-bit jump instructions."
 msgstr "Увімкнути 32-бітні інструкції переходу."
 
 #: config/bpf/bpf.opt:64
-#, fuzzy, no-c-format
-#| msgid "Enable asan store operations protection."
+#, no-c-format
 msgid "Enable general atomic operations introduced in v3 ISA."
-msgstr "Увімкнути захист операцій збереження asan."
+msgstr "Увімкнути загальні атомарні операції, введені у v3 ISA."
 
 #: config/bpf/bpf.opt:68
-#, fuzzy, no-c-format
-#| msgid "Enable 32-bit jump instructions."
+#, no-c-format
 msgid "Enable byte swap instructions."
-msgstr "Увімкнути 32-бітні інструкції переходу."
+msgstr "Увімкнути інструкції обміну байтів."
 
 #: config/bpf/bpf.opt:72
-#, fuzzy, no-c-format
-#| msgid "Enable divide and modulus instructions."
+#, no-c-format
 msgid "Enable signed division and modulus instructions."
-msgstr "Увімкнути інструкції ділення та залишку."
+msgstr "Увімкнути інструкції ділення та взяття залишку зі знаком."
 
 #: config/bpf/bpf.opt:76
-#, fuzzy, no-c-format
-#| msgid "Enable divide and modulus instructions."
+#, no-c-format
 msgid "Enable signed move and memory load instructions."
-msgstr "Увімкнути інструкції ділення та залишку."
+msgstr "Увімкнути інструкції переміщення та завантаження пам'яті зі знаком."
 
 #: config/bpf/bpf.opt:80
 #, no-c-format
 msgid "Select the eBPF ISA version to target in code generation."
-msgstr ""
+msgstr "Вибрати версію eBPF ISA для генерації коду."
 
 #: config/bpf/bpf.opt:84
-#, fuzzy, no-c-format
-#| msgid "Known PTX ISA versions (for use with the -mptx= option):"
+#, no-c-format
 msgid "Valid ISA versions (for use with the -mcpu= option)"
-msgstr "Відомі версії PTX ISA (для використання з опцією -mptx=):"
+msgstr "Дійсні версії ISA (для використання з опцією -mcpu=)"
 
 #: config/bpf/bpf.opt:104
-#, fuzzy, no-c-format
-#| msgid "Known assembler dialects (for use with the -masm= option):"
+#, no-c-format
 msgid "Known assembler dialects (for use with the -masm= option)"
-msgstr "Відомі діалекти асемблера (для використання з опцією -masm=):"
+msgstr "Відомі діалекти асемблера (для використання з опцією -masm=)"
 
 #: config/bpf/bpf.opt:114
 #, no-c-format
 msgid "-minline-memops-threshold=<number> Maximum size of memset/memmove/memcpy to inline, larger sizes will use a library call."
-msgstr ""
+msgstr "-minline-memops-threshold=<number> Максимальний розмір memset/memmove/memcpy для вбудовування, більші розміри будуть використовувати виклик бібліотеки."
 
 #: config/mips/mips.opt:32
 #, no-c-format
@@ -12763,10 +12668,9 @@ msgid "Use Enhanced Virtual Addressing instructions."
 msgstr "Використовуйте інструкції покращеного віртуального адресування."
 
 #: config/mips/mips.opt:171
-#, fuzzy, no-c-format
-#| msgid "Does nothing.  Preserved for backward compatibility."
+#, no-c-format
 msgid "Don't use %reloc() assembly operators (for backward compatibility)."
-msgstr "Нічого не робить. Зберігається для забезпечення сумісності з попередніми версіями."
+msgstr "Не використовувати оператори асемблера %reloc() (для зворотної сумісності)."
 
 #: config/mips/mips.opt:175
 #, no-c-format
@@ -13029,10 +12933,9 @@ msgid "Optimize lui/addiu address loads."
 msgstr "Оптимізуйте завантаження адреси lui/addiu."
 
 #: config/mips/mips.opt:406
-#, fuzzy, no-c-format
-#| msgid "Enable MUL instructions."
+#, no-c-format
 msgid "Enable the MIPS16e V2 instructions."
-msgstr "Увімкнути інструкції MUL."
+msgstr "Увімкнути інструкції MIPS16e V2."
 
 #: config/mips/mips.opt:410
 #, no-c-format
@@ -13055,22 +12958,19 @@ msgid "Use 4-operand madd.s/madd.d and related instructions where applicable."
 msgstr "Використовуйте 4-операндні інструкції madd.s/madd.d та повʼязані інструкції там, де це можливо."
 
 #: config/mips/mips.opt:434
-#, fuzzy, no-c-format
-#| msgid "Generate code with unaligned load store, valid for MIPS R6."
+#, no-c-format
 msgid "Don't generate code with unaligned load store, only valid for MIPS R6."
-msgstr "Генерувати код з незбалансованим завантаженням та зберіганням, дійсним для MIPS R6."
+msgstr "Не генерувати код з невирівняними завантаженням та збереженням, тільки дійсний для MIPS R6."
 
 #: config/mips/mips.opt:438
-#, fuzzy, no-c-format
-#| msgid "Generate code with unaligned load store, valid for MIPS R6."
+#, no-c-format
 msgid "Generate code with unaligned load store for R6 (alias of -mno-strict-align)."
-msgstr "Генерувати код з незбалансованим завантаженням та зберіганням, дійсним для MIPS R6."
+msgstr "Генерувати код з невирівняними завантаженням та збереженням для R6 (аліас -mno-strict-align)."
 
 #: config/mips/mips.opt:442
-#, fuzzy, no-c-format
-#| msgid "Generate code with unaligned load store, valid for MIPS R6."
+#, no-c-format
 msgid "Don't generate code with unaligned load store for R6 (alias of -mstrict-align)."
-msgstr "Генерувати код з незбалансованим завантаженням та зберіганням, дійсним для MIPS R6."
+msgstr "Не генерувати код з невирівняними завантаженням та збереженням для R6 (аліас -mstrict-align)."
 
 #: config/mips/mips.opt:450
 #, no-c-format
@@ -13520,7 +13420,7 @@ msgstr "Увімкнути опкоди ENTER_S та LEAVE_S для ARCv2."
 #: config/vxworks-smp.opt:25
 #, no-c-format
 msgid "Select VxWorks SMP C runtimes for linking."
-msgstr ""
+msgstr "Вибрати середовище виконання C для VxWorks SMP для зв'язування."
 
 #: lto/lang.opt:50
 #, no-c-format
@@ -13780,7 +13680,7 @@ msgstr "Попереджати, коли намагаєтесь звільнит
 #: common.opt:639
 #, no-c-format
 msgid "Warn when -fhardened did not enable an option from its set."
-msgstr ""
+msgstr "Попереджати, коли -fhardened не ввімкнув параметр з його набору."
 
 #: common.opt:650
 #, no-c-format
@@ -13923,10 +13823,9 @@ msgid "Warn about functions which might be candidates for __attribute__((malloc)
 msgstr "Попереджати про функції, які можуть бути кандидатами на __attribute__((malloc))."
 
 #: common.opt:790
-#, fuzzy, no-c-format
-#| msgid "Warn about functions which might be candidates for __attribute__((noreturn))."
+#, no-c-format
 msgid "Warn about functions which might be candidates for __attribute__((returns_nonnull))."
-msgstr "Попереджати про функції, які можуть бути кандидатами на __attribute__((noreturn))."
+msgstr "Попереджати про функції, які можуть бути кандидатами для __attribute__((returns_nonnull))."
 
 #: common.opt:794
 #, no-c-format
@@ -14026,7 +13925,7 @@ msgstr "Попереджувати, якщо функція закінчуєть
 #: common.opt:875
 #, no-c-format
 msgid "Warn when a conditional has too many terms and condition coverage profiling gives up instrumenting the expression."
-msgstr ""
+msgstr "Попереджати, коли умовна конструкція має занадто багато умов, і профілювання покриття умов припиняє інструментування виразу через надмірну складність."
 
 #: common.opt:880
 #, no-c-format
@@ -14271,7 +14170,7 @@ msgstr "Виконати оптимізацію копіювання реєст
 #: common.opt:1268
 #, no-c-format
 msgid "Fold instructions calculating memory offsets to the memory access instruction if possible."
-msgstr ""
+msgstr "Згорнути інструкції для обчислення зміщення пам'яті до інструкції доступу до пам'яті, якщо це можливо."
 
 #: common.opt:1272
 #, no-c-format
@@ -14384,10 +14283,9 @@ msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr "-fdiagnostics-color=[never|always|auto]\tКолірувати діагностику."
 
 #: common.opt:1399
-#, fuzzy, no-c-format
-#| msgid "Enable verbose output."
+#, no-c-format
 msgid "Enable formatting of JSON output."
-msgstr "Увімкнути розширений вивід."
+msgstr "Увімкнути форматування вихідних даних у форматі JSON."
 
 #: common.opt:1403
 #, no-c-format
@@ -14462,7 +14360,7 @@ msgstr "Показати глибину стеку подій у шляхах."
 #: common.opt:1530
 #, no-c-format
 msgid "-fdiagnostics-text-art-charset=[none|ascii|unicode|emoji]\tDetermine which characters to use in text arg diagrams."
-msgstr ""
+msgstr "-fdiagnostics-text-art-charset=[none|ascii|unicode|emoji]\tВизначити, які символи використовувати в текстових схемах."
 
 #: common.opt:1549
 #, no-c-format
@@ -14727,7 +14625,7 @@ msgstr "Увімкнути вгадування ймовірностей гіл
 #: common.opt:1839
 #, no-c-format
 msgid "Enable various security-relevant flags."
-msgstr ""
+msgstr "Увімкнути різні прапори, що стосуються безпеки."
 
 #: common.opt:1843
 #, no-c-format
@@ -14740,31 +14638,29 @@ msgid "Harden conditional branches by checking reversed conditions."
 msgstr "Посилити умовні гілки, перевіряючи зворотні умови."
 
 #: common.opt:1851
-#, fuzzy, no-c-format
-#| msgid "Harden conditionals not used in branches, checking reversed conditions."
+#, no-c-format
 msgid "Harden control flow by recording and checking execution paths."
-msgstr "Посилити умови, які не використовуються в гілках, перевіряючи зворотні умови."
+msgstr "Затвердити потік керування, записуючи та перевіряючи шляхи виконання."
 
 #: common.opt:1855
-#, fuzzy, no-c-format
-#| msgid "disable pass %s for function %s"
+#, no-c-format
 msgid "Disable CFR in leaf functions."
-msgstr "вимкнути прохід %s для функції %s"
+msgstr "Вимкнути CFR у листкових функціях."
 
 #: common.opt:1859
 #, no-c-format
 msgid "Check CFR execution paths also before calls followed by returns of their results."
-msgstr ""
+msgstr "Також перевіряти шляхи виконання CFR перед викликами, за якими слідують повернення їх результатів."
 
 #: common.opt:1863
 #, no-c-format
 msgid "Check CFR execution paths also when exiting a function through an exception."
-msgstr ""
+msgstr "Також перевіряти шляхи виконання (CFR) при виході з функції через виняток."
 
 #: common.opt:1867
 #, no-c-format
 msgid "-fhardcfr-check-noreturn-calls=[always|no-xthrow|nothrow|never]\tCheck CFR execution paths also before calling noreturn functions."
-msgstr ""
+msgstr "-fhardcfr-check-noreturn-calls=[always|no-xthrow|nothrow|never]\tТакож перевіряти шляхи виконання (CFR) перед викликом функцій, які не повертають значення."
 
 #: common.opt:1890
 #, no-c-format
@@ -14834,7 +14730,7 @@ msgstr "Вбудовувати операції __atomic, коли є послі
 #: common.opt:1973
 #, no-c-format
 msgid "-finline-stringops[=memcmp|memcpy|memmove|memset] Expand supported mem/str operations inline, even if against optimization."
-msgstr ""
+msgstr "-finline-stringops[=memcmp|memcpy|memmove|memset] Розгортати підтримувані операції з пам'яттю та рядками вбудовано, навіть якщо це суперечить оптимізації."
 
 #: common.opt:2004
 #, no-c-format
@@ -15082,10 +14978,9 @@ msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per l
 msgstr "-fmessage-length=<кількість>\tОбмежити діагностику до <кількості> символів на рядок. 0 пригнічує перенесення рядків."
 
 #: common.opt:2284
-#, fuzzy, no-c-format
-#| msgid "Align the start of functions."
+#, no-c-format
 msgid "Align the start of every function."
-msgstr "Вирівняти початок функцій."
+msgstr "Вирівняти початок кожної функції."
 
 #: common.opt:2288
 #, no-c-format
@@ -15273,10 +15168,9 @@ msgid "Insert arc-based program profiling code."
 msgstr "Вставити код профілювання програми на основі дуг."
 
 #: common.opt:2474
-#, fuzzy, no-c-format
-#| msgid "Insert arc-based program profiling code."
+#, no-c-format
 msgid "Insert condition coverage profiling code."
-msgstr "Вставити код профілювання програми на основі дуг."
+msgstr "Вставити код профілювання покриття умов."
 
 #: common.opt:2478
 #, no-c-format
@@ -15726,34 +15620,32 @@ msgstr "Трактувати переповнення зі знаком як н
 #: common.opt:2940
 #, no-c-format
 msgid "Disable stack scrub entirely, disregarding strub attributes."
-msgstr ""
+msgstr "Вимикає повністю очищення стека, не враховуючи атрибути strub."
 
 #: common.opt:2944
 #, no-c-format
 msgid "Enable stack scrub as per attributes, with strict call checking."
-msgstr ""
+msgstr "Увімкнути очищення стека відповідно до атрибутів, з жорсткою перевіркою викликів."
 
 #: common.opt:2953
 #, no-c-format
 msgid "Restore default strub mode: as per attributes, with relaxed checking."
-msgstr ""
+msgstr "Відновити типовий режим strub: відповідно до атрибутів, з розслабленою перевіркою."
 
 #: common.opt:2957
-#, fuzzy, no-c-format
-#| msgid "Enable hwasan instrumentation of builtin functions."
+#, no-c-format
 msgid "Enable stack scrubbing for all viable functions."
-msgstr "Увімкнути інструментування вбудованих функцій hwasan."
+msgstr "Увімкнути очищення стеку для всіх придатних функцій."
 
 #: common.opt:2961
 #, no-c-format
 msgid "Enable at-calls stack scrubbing for all viable functions."
-msgstr ""
+msgstr "Увімкнути очищення стека при викликах для всіх придатних функцій."
 
 #: common.opt:2965
-#, fuzzy, no-c-format
-#| msgid "Enable interrupt stack instructions."
+#, no-c-format
 msgid "Enable internal stack scrubbing for all viable functions."
-msgstr "Увімкнути інструкції стеку переривань."
+msgstr "Увімкнути внутрішнє очищення стеку для всіх придатних функцій."
 
 #: common.opt:2969
 #, no-c-format
@@ -15808,7 +15700,7 @@ msgstr "Для цілей, які зазвичай потребують трам
 #: common.opt:3025
 #, no-c-format
 msgid "Whether trampolines are generated in executable memory rather than executable stack."
-msgstr ""
+msgstr "Чи генеруються трампліни в виконуваній пам'яті, а не виконуваному стеку."
 
 #: common.opt:3043
 #, no-c-format
@@ -16211,10 +16103,9 @@ msgid "Assume assembler support for view in (DWARF2+) .loc directives."
 msgstr "Припускати підтримку асемблером перегляду в директивах .loc (DWARF2+)."
 
 #: common.opt:3492
-#, fuzzy, no-c-format
-#| msgid "Generate debug information in VMS format."
+#, no-c-format
 msgid "Generate debug information in CodeView format."
-msgstr "Створити відлагоджувальну інформацію у форматі VMS."
+msgstr "Згенерувати інформацію про налагодження у форматі CodeView."
 
 #: common.opt:3512
 #, no-c-format
@@ -16544,7 +16435,7 @@ msgstr "Коефіцієнт масштабування, який застосо
 #: params.opt:139
 #, no-c-format
 msgid "Whether the target fully pipelines FMA instructions.  If non-zero, reassociation considers the benefit of parallelizing FMA's multiplication part and addition part, assuming FMUL and FMA use the same units that can also do FADD."
-msgstr ""
+msgstr "Чи повністю підтримує цільова платформа конвеєрну обробку інструкцій FMA? Якщо значення не нульове, переасоціація враховує вигоду від паралельного виконання множення та додавання в інструкції FMA, припускаючи, що FMUL і FMA використовують однакові блоки обчислення, які також можуть виконувати FADD."
 
 #: params.opt:146
 #, no-c-format
@@ -16599,12 +16490,12 @@ msgstr "Максимальна кількість параметрів в SCoP."
 #: params.opt:186
 #, no-c-format
 msgid "Maximum number of blocks for -fharden-control-flow-redundancy."
-msgstr ""
+msgstr "Максимальна кількість блоків для -fharden-control-flow-redundancy."
 
 #: params.opt:190
 #, no-c-format
 msgid "Maximum number of blocks for in-line -fharden-control-flow-redundancy."
-msgstr ""
+msgstr "Максимальна кількість блоків для вбудованого -fharden-control-flow-redundancy."
 
 #: params.opt:194
 #, no-c-format
@@ -16697,10 +16588,9 @@ msgid "Maximum size of a list of values associated with each parameter for inter
 msgstr "Максимальний розмір списку значень, повʼязаних з кожним параметром для міжпроцедурного поширення констант."
 
 #: params.opt:266
-#, fuzzy, no-c-format
-#| msgid "When using profile feedback, use the edge at this percentage position in frequncy histogram as the bases for IPA-CP heuristics."
+#, no-c-format
 msgid "When using profile feedback, use the edge at this percentage position in frequency histogram as the bases for IPA-CP heuristics."
-msgstr "При використанні профілю зворотного звʼязку, використовуйте ребро на цій відсотковій позиції в гістограмі частот як основу для евристик IPA-CP."
+msgstr "При використанні профілю зворотного зв'язку використовуйте ребро на цій позиції в гістограмі частоти як основу для евристик IPA-CP."
 
 #: params.opt:270
 #, no-c-format
@@ -17665,13 +17555,12 @@ msgstr "Максимальна кількість вкладених викли
 #: params.opt:1126
 #, no-c-format
 msgid "Maximum number of predicates anded for each predicate ored in the normalized predicate chain."
-msgstr ""
+msgstr "Максимальна кількість предикатів, об'єднаних AND для кожного предиката, об'єднаного OR у нормалізованому ланцюжку предикатів."
 
 #: params.opt:1131
-#, fuzzy, no-c-format
-#| msgid "Maximum number of bases stored in each modref tree."
+#, no-c-format
 msgid "Maximum number of predicates ored in the normalized predicate chain."
-msgstr "Максимальна кількість баз, збережених у кожному дереві modref."
+msgstr "Максимальна кількість предикатів, об'єднаних у нормалізованому ланцюжку предикатів."
 
 #: params.opt:1135
 #, no-c-format
@@ -17759,22 +17648,19 @@ msgid "Enable loop vectorization of floating point inductions."
 msgstr "Увімкнути векторизацію петлі для плаваючої точки."
 
 #: params.opt:1203
-#, fuzzy, no-c-format
-#| msgid "Maximum number of basic blocks before EVRP uses a sparse cache."
+#, no-c-format
 msgid "Maximum number of basic blocks before VRP uses a sparse bitmap cache."
-msgstr "Максимальна кількість базових блоків, перед тим як EVRP використовує розріджений кеш."
+msgstr "Максимальна кількість базових блоків перед тим, як VRP використовуватиме розріджений бітовий масив кешу."
 
 #: params.opt:1207
-#, fuzzy, no-c-format
-#| msgid "Maximum number of outgoing edges in a switch before EVRP will not process it."
+#, no-c-format
 msgid "Maximum number of outgoing edges in a switch before VRP will not process it."
-msgstr "Максимальна кількість вихідних ребер у перемикачі, перед тим як EVRP не буде обробляти його."
+msgstr "Максимальна кількість вихідних ребер у перемикачі, перед тим як VRP не обробить його."
 
 #: params.opt:1211
-#, fuzzy, no-c-format
-#| msgid "Maximum number of basic blocks before EVRP uses a sparse cache."
+#, no-c-format
 msgid "Maximum number of basic blocks for VRP to use a basic cache vector."
-msgstr "Максимальна кількість базових блоків, перед тим як EVRP використовує розріджений кеш."
+msgstr "Максимальна кількість базових блоків для використання VRP з базовим вектором кешу."
 
 #: cfgrtl.cc:2837
 msgid "flow control insn inside a basic block"
@@ -18596,10 +18482,9 @@ msgstr ""
 "\n"
 
 #: gcov-tool.cc:595
-#, fuzzy, c-format
-#| msgid "Copyright %s 2023 Free Software Foundation, Inc.\n"
+#, c-format
 msgid "Copyright %s 2024 Free Software Foundation, Inc.\n"
-msgstr "Авторське право %s 2023 Free Software Foundation, Inc.\n"
+msgstr "Авторське право %s 2024 Free Software Foundation, Inc.\n"
 
 #: gcov.cc:969
 #, c-format
@@ -18641,18 +18526,13 @@ msgstr ""
 "                                    а не відсотки\n"
 
 #: gcov.cc:975
-#, fuzzy, c-format
-#| msgid ""
-#| "  -c, --branch-counts             Output counts of branches taken\n"
-#| "                                    rather than percentages\n"
+#, c-format
 msgid ""
 "  -g, --conditions                Include modified condition/decision\n"
 "                                    coverage in output\n"
 msgstr ""
-"  -c, --branch-counts             Вивести кількість виконаних гілок\n"
-"                                    замість відсотків\n"
-"  -c, --branch-counts             Виводити кількість виконаних гілок,\n"
-"                                    а не відсотки\n"
+"  -g, --conditions                Включити змінене покриття умов/рішень\n"
+"                                    у виводі\n"
 
 #: gcov.cc:977
 #, c-format
@@ -18787,10 +18667,9 @@ msgid "gcov %s%s\n"
 msgstr "gcov %s%s\n"
 
 #: gcov.cc:1013
-#, fuzzy, c-format
-#| msgid "collect2 version %s\n"
+#, c-format
 msgid "JSON format version: %s\n"
-msgstr "версія collect2 %s\n"
+msgstr "Версія формату JSON: %s\n"
 
 #: gcov.cc:1454
 #, c-format
@@ -18858,10 +18737,9 @@ msgid "%s:already seen blocks for '%s'\n"
 msgstr "%s:вже бачені блоки для '%s'\n"
 
 #: gcov.cc:2064
-#, fuzzy, c-format
-#| msgid "%s:already seen blocks for '%s'\n"
+#, c-format
 msgid "%s:already seen conditions for '%s'\n"
-msgstr "%s:вже бачені блоки для '%s'\n"
+msgstr "%s: вже бачили умови для '%s'\n"
 
 #: gcov.cc:2115 gcov.cc:2244
 #, c-format
@@ -18964,16 +18842,14 @@ msgid "No calls\n"
 msgstr "Немає викликів\n"
 
 #: gcov.cc:2688
-#, fuzzy, c-format
-#| msgid "Lines executed:%s of %d\n"
+#, c-format
 msgid "Condition outcomes covered:%s of %d\n"
-msgstr "Виконано рядків:%s з %d\n"
+msgstr "Наслідки умов покриті:%s з %d\n"
 
 #: gcov.cc:2693
-#, fuzzy, c-format
-#| msgid "bad condition code"
+#, c-format
 msgid "No conditions\n"
-msgstr "неправильний код умови"
+msgstr "Немає умов\n"
 
 #: gcov.cc:2913
 #, c-format
@@ -18983,13 +18859,12 @@ msgstr "%s: немає рядків для '%s'\n"
 #: gcov.cc:3049
 #, c-format
 msgid "condition outcomes covered %d/%d\n"
-msgstr ""
+msgstr "наслідки умов покриті %d/%d\n"
 
 #: gcov.cc:3062
-#, fuzzy, c-format
-#| msgid "unconditional %2d taken %s\n"
+#, c-format
 msgid "condition %2u not covered (%s%s)\n"
-msgstr "безумовний %2d виконаний %s\n"
+msgstr "умова %2u не покрита (%s%s)\n"
 
 #: gcov.cc:3076
 #, c-format
@@ -19651,10 +19526,9 @@ msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "несумісний операнд з регістром з плаваючою комою / векторним для '%%%c'"
 
 #: config/aarch64/aarch64.cc:12130
-#, fuzzy, c-format
-#| msgid "incompatible register operand for '%%%c'"
+#, c-format
 msgid "incompatible operand for '%%%c'"
-msgstr "несумісний операнд з регістром для '%%%c'"
+msgstr "несумісний операнд для '%%%c'"
 
 #: config/aarch64/aarch64.cc:12150
 #, c-format
@@ -19807,22 +19681,19 @@ msgid "invalid operand to %%p code"
 msgstr "недійсний операнд для коду %%p"
 
 #: config/arc/arc.cc:4941
-#, fuzzy, c-format
-#| msgid "invalid operand to %%s code"
+#, c-format
 msgid "invalid operand for %%s code"
 msgstr "недійсний операнд для коду %%s"
 
 #: config/arc/arc.cc:4959
-#, fuzzy, c-format
-#| msgid "invalid operand to %%N code"
+#, c-format
 msgid "invalid operand for %%N code"
-msgstr "неправильний операнд для коду %%N"
+msgstr "недійсний операнд для коду %%N"
 
 #: config/arc/arc.cc:4972
-#, fuzzy, c-format
-#| msgid "invalid operand to %%N code"
+#, c-format
 msgid "invalid operand for %%N or %%S code"
-msgstr "неправильний операнд для коду %%N"
+msgstr "недійсний операнд для коду %%N або %%S"
 
 #: config/arc/arc.cc:4994 config/m32r/m32r.cc:2081
 #, c-format
@@ -20389,40 +20260,28 @@ msgid "unknown insn mode"
 msgstr "невідомий режим інструкції"
 
 #: config/i386/i386.cc:23777
-#, fuzzy
-#| msgid "invalid conversion from type %<bfloat16_t%>"
 msgid "invalid conversion from type %<__bf16%> without option %<-msse2%>"
-msgstr "недійсне перетворення з типу %<bfloat16_t%>"
+msgstr "недійсне перетворення з типу %<__bf16%> без опції %<-msse2%>"
 
 #: config/i386/i386.cc:23780
-#, fuzzy
-#| msgid "invalid conversion from type %<bfloat16_t%>"
 msgid "invalid conversion from type %<_Float16%> without option %<-msse2%>"
-msgstr "недійсне перетворення з типу %<bfloat16_t%>"
+msgstr "недійсне перетворення з типу %<_Float16%> без опції %<-msse2%>"
 
 #: config/i386/i386.cc:23783
-#, fuzzy
-#| msgid "invalid conversion to type %<bfloat16_t%>"
 msgid "invalid conversion to type %<__bf16%> without option %<-msse2%>"
-msgstr "недійсне перетворення до типу %<bfloat16_t%>"
+msgstr "недійсне перетворення до типу %<__bf16%> без опції %<-msse2%>"
 
 #: config/i386/i386.cc:23786
-#, fuzzy
-#| msgid "invalid conversion to type %<bfloat16_t%>"
 msgid "invalid conversion to type %<_Float16%> without option %<-msse2%>"
-msgstr "недійсне перетворення до типу %<bfloat16_t%>"
+msgstr "недійсне перетворення до типу %<_Float16%> без опції %<-msse2%>"
 
 #: config/i386/i386.cc:23824 config/i386/i386.cc:23849
-#, fuzzy
-#| msgid "operation not permitted on type %<bfloat16_t%>"
 msgid "operation not permitted on type %<__bf16%> without option %<-msse2%>"
-msgstr "операція не дозволена для типу %<bfloat16_t%>"
+msgstr "операція не дозволена для типу %<__bf16%> без опції %<-msse2%>"
 
 #: config/i386/i386.cc:23827 config/i386/i386.cc:23853
-#, fuzzy
-#| msgid "operation not permitted on type %<bfloat16_t%>"
 msgid "operation not permitted on type %<_Float16%> without option %<-msse2%>"
-msgstr "операція не дозволена для типу %<bfloat16_t%>"
+msgstr "операція не дозволена для типу %<_Float16%> без опції %<-msse2%>"
 
 #: config/ia64/ia64.cc:5470
 #, c-format
@@ -21055,10 +20914,9 @@ msgid "'o' operand is not constant"
 msgstr "операнд 'o' не є константою"
 
 #: config/stormy16/stormy16.cc:1980
-#, fuzzy, c-format
-#| msgid "'B' operand is not constant"
+#, c-format
 msgid "'h' operand is not SImode register"
-msgstr "операнд 'B' не є константою"
+msgstr "Операнд 'h' не є регістром типу SImode"
 
 #: config/stormy16/stormy16.cc:1988
 #, c-format
@@ -21516,10 +21374,8 @@ msgid "In lambda function"
 msgstr "У функції-лямбді"
 
 #: cp/error.cc:3713
-#, fuzzy
-#| msgid "In static member function %qD"
 msgid "In explicit object member function %qD"
-msgstr "У статичній функції-члені %qD"
+msgstr "У явній членській функції об'єкта %qD"
 
 #: cp/error.cc:3715
 msgid "In member function %qD"
@@ -21718,16 +21574,12 @@ msgstr ""
 "\n"
 
 #: fortran/error.cc:1043
-#, fuzzy
-#| msgid "new in Fortran 2003"
 msgid "Prohibited in Fortran 2023:"
-msgstr "новий у Fortran 2003"
+msgstr "Заборонено в Fortran 2023:"
 
 #: fortran/error.cc:1045
-#, fuzzy
-#| msgid "Fortran 2018:"
 msgid "Fortran 2023:"
-msgstr "Fortran 2018:"
+msgstr "Fortran 2023:"
 
 #: fortran/error.cc:1047
 msgid "Fortran 2018 deleted feature:"
@@ -21823,10 +21675,8 @@ msgid "new in Fortran 2018"
 msgstr "новий у Fortran 2018"
 
 #: fortran/intrinsic.cc:4896
-#, fuzzy
-#| msgid "new in Fortran 2003"
 msgid "new in Fortran 2023"
-msgstr "новий у Fortran 2003"
+msgstr "нове в Fortran 2023"
 
 #: fortran/intrinsic.cc:4900
 msgid "a GNU Fortran extension"
@@ -22359,10 +22209,8 @@ msgid "value computed is not used"
 msgstr "обчислене значення не використовується"
 
 #: go/gofrontend/expressions.cc:1986
-#, fuzzy
-#| msgid "expected function name"
 msgid "unexpected reference to package"
-msgstr "мало бути вказано назву функції"
+msgstr "неочікуване посилання на пакет"
 
 #: go/gofrontend/expressions.cc:3840 go/gofrontend/expressions.cc:3856
 msgid "constant refers to itself"
@@ -22544,33 +22392,27 @@ msgstr "кількість результатів не відповідає кі
 
 #: go/gofrontend/expressions.cc:14671
 msgid "invalid 3-index slice of object that is not a slice"
-msgstr ""
+msgstr "Недійсний 3-індексний зріз об'єкта, який не є зрізом"
 
 #: go/gofrontend/expressions.cc:14674
 msgid "attempt to slice object that is not array, slice, or string"
-msgstr ""
+msgstr "Спроба використовувати зріз на об'єкті, який не є масивом, зрізом або рядком"
 
 #: go/gofrontend/expressions.cc:14677
 msgid "attempt to index object that is not array, slice, string, or map"
-msgstr ""
+msgstr "Спроба індексувати об'єкт, який не є масивом, зрізом, рядком або мапою"
 
 #: go/gofrontend/expressions.cc:14730
-#, fuzzy
-#| msgid "expected integer expression"
 msgid "attempt to index type expression"
-msgstr "очікувався цілочисельний вираз"
+msgstr "спроба індексувати вираз типу"
 
 #: go/gofrontend/expressions.cc:14757
-#, fuzzy
-#| msgid "invalid left hand side of assignment"
 msgid "invalid 3-index slice of string"
-msgstr "неприпустима ліва сторона присвоєння"
+msgstr "недійсний 3-індексний зріз рядка"
 
 #: go/gofrontend/expressions.cc:14770
-#, fuzzy
-#| msgid "invalid use of type"
 msgid "invalid slice of map"
-msgstr "неприпустиме використання типу"
+msgstr "недійсний зріз мапи"
 
 #: go/gofrontend/expressions.cc:14779 go/gofrontend/expressions.cc:15970
 msgid "incompatible type for map index"
@@ -22582,15 +22424,15 @@ msgstr "очікується інтерфейс або вказівник на 
 
 #: go/gofrontend/expressions.cc:18212
 msgid "may only omit types within composite literals of slice, array, or map type"
-msgstr ""
+msgstr "Тип можна пропускати лише в складних літералах типу зрізів, масивів або мап."
 
 #: go/gofrontend/expressions.cc:18306 go/gofrontend/expressions.cc:18618
 msgid "map composite literal must have keys"
-msgstr ""
+msgstr "Складний літерал мапи має містити ключі"
 
 #: go/gofrontend/expressions.cc:18651
 msgid "expected struct, slice, array, or map type for composite literal"
-msgstr ""
+msgstr "очікується тип структури, зрізу, масиву або мапи для складеного літералу"
 
 #: go/gofrontend/expressions.cc:19266 go/gofrontend/statements.cc:2121
 msgid "type assertion only valid for interface types"
@@ -22619,20 +22461,16 @@ msgid "cannot fallthrough final case in switch"
 msgstr "неможливо перейти до останнього випадку в операторі вибору"
 
 #: go/gofrontend/statements.cc:1288
-#, fuzzy
-#| msgid "cannot use %qs as a call-used register"
 msgid "cannot use %<_%> as value"
-msgstr "не можна використовувати %qs як регістр, що використовується при виклику"
+msgstr "неможливо використовувати %<_%> як значення"
 
 #: go/gofrontend/statements.cc:1300 go/gofrontend/statements.cc:2528
 msgid "invalid left hand side of assignment"
 msgstr "неприпустима ліва сторона присвоєння"
 
 #: go/gofrontend/statements.cc:1309
-#, fuzzy
-#| msgid "incompatible types in binary expression"
 msgid "incompatible type in binary expression"
-msgstr "несумісні типи в бінарному виразі"
+msgstr "несумісні типи у бінарному виразі"
 
 #: go/gofrontend/statements.cc:1555
 msgid "use of untyped nil"
@@ -22643,10 +22481,8 @@ msgid "expected map index on right hand side"
 msgstr "очікуваний індекс мапи на правій стороні"
 
 #: go/gofrontend/statements.cc:2534
-#, fuzzy
-#| msgid "no pre-increment operator for type"
 msgid "increment or decrement of non-numeric type"
-msgstr "немає оператора преінкремента для цього типу"
+msgstr "збільшення або зменшення нечислового типу"
 
 #: go/gofrontend/statements.cc:3449 go/gofrontend/statements.cc:3464
 msgid "not enough arguments to return"
@@ -22814,7 +22650,7 @@ msgstr "метод %s%s%s має позначку go:nointerface"
 #: rust/resolve/rust-ast-resolve-expr.cc:140
 #, c-format
 msgid "You have broken GCC Rust. This is a feature.\n"
-msgstr ""
+msgstr "Ви поламали GCC Rust. Це особливість.\n"
 
 #: lto-streamer.h:1033
 #, gcc-internal-format, gfc-internal-format
@@ -23127,10 +22963,9 @@ msgid "Unrecognized option: %qs"
 msgstr "Невідома опція: %qs"
 
 #: rust/lang.opt:90
-#, fuzzy, gcc-internal-format
-#| msgid "unknown lam type %qs"
+#, gcc-internal-format
 msgid "unknown crate type: '%qs'"
-msgstr "невідомий тип lam %qs"
+msgstr "невідомий тип крейту: '%qs'"
 
 #: rust/lang.opt:118
 #, gcc-internal-format
@@ -23179,16 +23014,14 @@ msgid "missing makefile target after %qs"
 msgstr "відсутня ціль makefile після %qs"
 
 #: c-family/c.opt:260
-#, fuzzy, gcc-internal-format
-#| msgid "missing path after %qs"
+#, gcc-internal-format
 msgid "missing format after %qs"
-msgstr "відсутній шлях після %qs"
+msgstr "відсутній формат після %qs"
 
 #: c-family/c.opt:264
-#, fuzzy, gcc-internal-format
-#| msgid "missing path after %qs"
+#, gcc-internal-format
 msgid "missing output path after %qs"
-msgstr "відсутній шлях після %qs"
+msgstr "відсутній шлях виводу після %qs"
 
 #: c-family/c.opt:311
 #, gcc-internal-format
@@ -23266,10 +23099,9 @@ msgid "unknown pointer size model %qs"
 msgstr "невідома модель розміру вказівника %qs"
 
 #: config/aarch64/aarch64.opt:379
-#, fuzzy, gcc-internal-format
-#| msgid "unknown TLS model %qs"
+#, gcc-internal-format
 msgid "unknown LDP/STP policy %qs"
-msgstr "невідома модель TLS %qs"
+msgstr "невідома політика LDP/STP %qs"
 
 #: config/i386/i386.opt:340
 #, gcc-internal-format
@@ -23289,27 +23121,27 @@ msgstr "%<-msse5%> було видалено"
 #: config/i386/i386.opt:745
 #, gcc-internal-format
 msgid "AVX512PF support will be removed in GCC 15"
-msgstr ""
+msgstr "Підтримку AVX512PF буде вилучено у GCC 15"
 
 #: config/i386/i386.opt:749
 #, gcc-internal-format
 msgid "AVX512ER support will be removed in GCC 15"
-msgstr ""
+msgstr "Підтримку AVX512ER буде вилучено у GCC 15"
 
 #: config/i386/i386.opt:777
 #, gcc-internal-format
 msgid "AVX5124FMAPS support will be removed in GCC 15"
-msgstr ""
+msgstr "Підтримку AVX5124FMAPS буде вилучено у GCC 15"
 
 #: config/i386/i386.opt:781
 #, gcc-internal-format
 msgid "AVX5124VNNIW support will be removed in GCC 15"
-msgstr ""
+msgstr "Підтримку AVX5124VNNIW буде вилучено у GCC 15"
 
 #: config/i386/i386.opt:976
 #, gcc-internal-format
 msgid "PREFETCHWT1 support will be removed in GCC 15"
-msgstr ""
+msgstr "Підтримку PREFETCHWT1 буде вилучено у GCC 15"
 
 #: config/i386/i386.opt:1290
 #, gcc-internal-format
@@ -23344,7 +23176,7 @@ msgstr "використання старого darwin ABI"
 #: config/rs6000/rs6000.opt:475
 #, gcc-internal-format
 msgid "Do not use %<-mpower8-internal%>; use %<-mcpu=power8%> instead"
-msgstr ""
+msgstr "Не використовуйте %<-mpower8-internal%>; використовуйте %<-mcpu=power8%>"
 
 #: config/fused-madd.opt:22
 #, gcc-internal-format
@@ -23390,10 +23222,9 @@ msgid "unknown floating point contraction style %qs"
 msgstr "невідомий стиль скорочення з плаваючою комою %qs"
 
 #: common.opt:1870
-#, fuzzy, gcc-internal-format
-#| msgid "unknown Live-Patching Level %qs"
+#, gcc-internal-format
 msgid "unknown hardcfr noreturn checking level %qs"
-msgstr "невідомий рівень живого латання %qs"
+msgstr "невідомий рівень перевірки hardcfr noreturn %qs"
 
 #: common.opt:1905
 #, gcc-internal-format
@@ -23403,7 +23234,7 @@ msgstr "невідомий рівень повторного використа
 #: common.opt:1977
 #, gcc-internal-format
 msgid "unavailable stringop for inlining %qs"
-msgstr ""
+msgstr "недоступний stringop для вбудовування %qs"
 
 #: common.opt:2008
 #, gcc-internal-format
@@ -23466,10 +23297,9 @@ msgid "unknown TLS model %qs"
 msgstr "невідома модель TLS %qs"
 
 #: common.opt:3029
-#, fuzzy, gcc-internal-format
-#| msgid "unknown rust mangling option %qs"
+#, gcc-internal-format
 msgid "unknown trampoline implementation %qs"
-msgstr "невідома опція декорування rust %qs"
+msgstr "невідома реалізація трампліну %qs"
 
 #: common.opt:3351
 #, gcc-internal-format
@@ -24962,10 +24792,9 @@ msgid "%<alias%> attribute ignored because function is defined"
 msgstr "атрибут %<alias%> ігнорується, оскільки функція визначена"
 
 #: cgraphunit.cc:923
-#, fuzzy, gcc-internal-format
-#| msgid "%<always_inline%> function might not be inlinable"
+#, gcc-internal-format
 msgid "%<always_inline%> function might not be inlinable unless also declared %<inline%>"
-msgstr "Функцію %<always_inline%> може бути неможливо вбудувати"
+msgstr "функція %<always_inline%> може не бути вбудованою, якщо також не оголошена як %<inline%>"
 
 #: cgraphunit.cc:949
 #, gcc-internal-format
@@ -25219,10 +25048,9 @@ msgid "pointer value used where a floating-point was expected"
 msgstr "значення вказівника використовується там, де очікувався дійсний числовий тип"
 
 #: convert.cc:338
-#, fuzzy, gcc-internal-format
-#| msgid "pointer value used where a floating-point was expected"
+#, gcc-internal-format
 msgid "vector value used where a floating-point was expected"
-msgstr "значення вказівника використовується там, де очікувався дійсний числовий тип"
+msgstr "використано векторне значення там, де очікується число з плаваючою точкою"
 
 #: convert.cc:342
 #, gcc-internal-format
@@ -25701,16 +25529,12 @@ msgid "cannot read spec file %qs: %m"
 msgstr "не вдалося прочитати файл специфікації %qs: %m"
 
 #: gcc.cc:2412 gcc.cc:2432
-#, fuzzy
-#| msgid "specs %%include syntax malformed after %ld characters"
 msgid "specs %%include syntax malformed after %td characters"
-msgstr "синтаксис %%include в специфікаціях неправильний після %ld символів"
+msgstr "синтаксис специфікацій %%include неправильно сформований після %td символів"
 
 #: gcc.cc:2458 gcc.cc:2467 gcc.cc:2477 gcc.cc:2487
-#, fuzzy
-#| msgid "specs %%rename syntax malformed after %ld characters"
 msgid "specs %%rename syntax malformed after %td characters"
-msgstr "синтаксис %%rename в специфікаціях неправильний після %ld символів"
+msgstr "синтаксис специфікацій %%rename неправильно сформований після %td символів"
 
 #: gcc.cc:2497
 #, gcc-internal-format, gfc-internal-format
@@ -25723,16 +25547,12 @@ msgid "%s: attempt to rename spec %qs to already defined spec %qs"
 msgstr "%s: спроба перейменувати специфікацію %qs на вже визначену специфікацію %qs"
 
 #: gcc.cc:2527
-#, fuzzy
-#| msgid "specs unknown %% command after %ld characters"
 msgid "specs unknown %% command after %td characters"
-msgstr "невідома команда %% в специфікаціях після %ld символів"
+msgstr "невідома команда специфікацій %% після %td символів"
 
 #: gcc.cc:2539 gcc.cc:2553
-#, fuzzy
-#| msgid "specs file malformed after %ld characters"
 msgid "specs file malformed after %td characters"
-msgstr "неправильний формат файлу специфікацій після %ld символів"
+msgstr "файл специфікацій неправильно сформований після %td символів"
 
 #: gcc.cc:2608
 #, gcc-internal-format
@@ -25808,7 +25628,7 @@ msgstr "%qs - невідома опція %<-save-temps%>"
 #: gcc.cc:5024
 #, gcc-internal-format
 msgid "linker hardening options not enabled by %<-fhardened%> because other link options were specified on the command line"
-msgstr ""
+msgstr "параметри захисту зв'язувача не ввімкнені через %<-fhardened%>, оскільки були вказані інші параметри зв'язування у командному рядку"
 
 #: gcc.cc:5048 toplev.cc:714
 #, gcc-internal-format
@@ -26359,17 +26179,17 @@ msgstr "%s не підтримується на цій цілі"
 #: gimple-harden-control-flow.cc:97
 #, gcc-internal-format
 msgid "%qD calls %<setjmp%> or similar, %<-fharden-control-flow-redundancy%> is not supported"
-msgstr ""
+msgstr "%qD викликає %<setjmp%> або щось подібне, %<-fharden-control-flow-redundancy%> не підтримується"
 
 #: gimple-harden-control-flow.cc:110
 #, gcc-internal-format
 msgid "%qD receives nonlocal gotos, %<-fharden-control-flow-redundancy%> is not supported"
-msgstr ""
+msgstr "%qD отримує нелокальнi переходи, %<-fharden-control-flow-redundancy%> не підтримується"
 
 #: gimple-harden-control-flow.cc:121
 #, gcc-internal-format
 msgid "%qD has more than %u blocks, the requested maximum for %<-fharden-control-flow-redundancy%>"
-msgstr ""
+msgstr "%qD має більше ніж %u блоків, максимум, який ви зазначили для %<-fharden-control-flow-redundancy%>"
 
 #: gimple-ssa-isolate-paths.cc:290
 #, gcc-internal-format
@@ -27866,10 +27686,9 @@ msgid "gimple check: expected %s(%s), have %s(%s) in %s, at %s:%d"
 msgstr "перевірка gimple: очікувалося %s(%s), отримано %s(%s) в %s, на %s:%d"
 
 #: gimplify.cc:1426
-#, fuzzy, gcc-internal-format
-#| msgid "%<allocate%> clause must specify an allocator here"
+#, gcc-internal-format
 msgid "%<allocate%> directive for %qD inside a target region must specify an %<allocator%> clause"
-msgstr "замикання %<allocate%> повинна вказувати алокатор тут"
+msgstr "Директива %<allocate%> для %qD всередині цільового регіону повинна вказати клаузу %<allocator%>"
 
 #: gimplify.cc:2298
 #, gcc-internal-format
@@ -27969,16 +27788,14 @@ msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qE не вказано в області %qs конструкції OpenACC"
 
 #: gimplify.cc:8154
-#, fuzzy, gcc-internal-format
-#| msgid "enclosing OpenACC %qs construct"
+#, gcc-internal-format
 msgid "enclosing OpenACC %qs construct and"
-msgstr "оточуюча область %qs конструкції OpenACC"
+msgstr "обмеження конструкції OpenACC %qs і"
 
 #: gimplify.cc:8157
-#, fuzzy, gcc-internal-format
-#| msgid "enclosing OpenACC %qs construct"
+#, gcc-internal-format
 msgid "enclosing OpenACC %qs construct with %qs clause"
-msgstr "оточуюча область %qs конструкції OpenACC"
+msgstr "обмеження конструкції OpenACC %qs з клаузою %qs"
 
 #: gimplify.cc:8227
 #, gcc-internal-format
@@ -28724,109 +28541,104 @@ msgid "function %qs, parameter %u, is used but does not have any certain IPA-SRA
 msgstr "функція %qs, параметр %u, використовується, але не має жодного визначеного доступу IPA-SRA"
 
 #: ipa-strub.cc:622
-#, fuzzy, gcc-internal-format
-#| msgid "pass %s does not support cloning"
+#, gcc-internal-format
 msgid "at-calls %<strub%> does not support call to %qD"
-msgstr "прохід %s не підтримує клонування"
+msgstr "at-calls %<strub%> не підтримує виклику до %qD"
 
 #: ipa-strub.cc:656
 #, gcc-internal-format
 msgid "%qD is not eligible for %<strub%> on the target system"
-msgstr ""
+msgstr "%qD не відповідає вимогам %<strub%> на системі призначення"
 
 #: ipa-strub.cc:660
-#, fuzzy, gcc-internal-format
-#| msgid "unsupported constant address:"
+#, gcc-internal-format
 msgid "unsupported %<strub%> call on the target system"
-msgstr "непідтримувана адреса константи:"
+msgstr "непідтримуваний виклик %<strub%> на цільовій системі"
 
 #: ipa-strub.cc:686
 #, gcc-internal-format
 msgid "%qD is not eligible for %<strub%> because %<-fsplit-stack%> is enabled"
-msgstr ""
+msgstr "%qD не відповідає вимогам для %<strub%>, оскільки ввімкнено %<-fsplit-stack%>"
 
 #: ipa-strub.cc:699
 #, gcc-internal-format
 msgid "%qD is not eligible for %<strub%> because of attribute %<noipa%>"
-msgstr ""
+msgstr "%qD не відповідає вимогам для %<strub%>, через атрибут %<noipa%>"
 
 #: ipa-strub.cc:714
 #, gcc-internal-format
 msgid "%qD is not eligible for %<strub%> because of attribute %<simd%>"
-msgstr ""
+msgstr "%qD не відповідає вимогам для %<strub%>, через атрибут %<simd%>"
 
 #: ipa-strub.cc:848
 #, gcc-internal-format
 msgid "%qD is not eligible for internal %<strub%> because of attribute %<noclone%>"
-msgstr ""
+msgstr "%qD не підходить для внутрішнього %<strub%>, через атрибут %<noclone%>"
 
 #: ipa-strub.cc:872
 #, gcc-internal-format
 msgid "%qD is not eligible for internal %<strub%> because it calls %qD"
-msgstr ""
+msgstr "%qD не підходить для внутрішнього %<strub%>, оскільки викликає %qD"
 
 #: ipa-strub.cc:886
 #, gcc-internal-format
 msgid "%qD is not eligible for internal %<strub%> because it contains a non-local goto target"
-msgstr ""
+msgstr "%qD не підходить для внутрішнього %<strub%>, оскільки містить нелокальну ціль goto"
 
 #: ipa-strub.cc:899
 #, gcc-internal-format
 msgid "%qD is not eligible for internal %<strub%> because the address of a local label escapes"
-msgstr ""
+msgstr "%qD не підходить для внутрішнього %<strub%>, оскільки адреса локальної мітки перевищує межі"
 
 #: ipa-strub.cc:938
-#, fuzzy, gcc-internal-format
-#| msgid "%s does not support force_nonfallthru"
+#, gcc-internal-format
 msgid "internal %<strub%> does not support forced labels"
-msgstr "%s не підтримує параметр force_nonfallthru"
+msgstr "внутрішній %<strub%> не підтримує примусові мітки"
 
 #: ipa-strub.cc:952
-#, fuzzy, gcc-internal-format
-#| msgid "too many arguments for format"
+#, gcc-internal-format
 msgid "%qD has too many arguments for internal %<strub%>"
-msgstr "забагато аргументів для формату"
+msgstr "%qD має забагато аргументів для внутрішнього %<strub%>"
 
 #: ipa-strub.cc:1229
 #, gcc-internal-format
 msgid "%qD requires %<strub%>, but no viable %<strub%> mode was found"
-msgstr ""
+msgstr "%qD вимагає %<strub%>, але не знайдено відповідного режиму %<strub%>"
 
 #: ipa-strub.cc:1325
 #, gcc-internal-format
 msgid "%<strub%> mode %qE selected for %qD, when %qE was requested"
-msgstr ""
+msgstr "Вибраний режим %<strub%> %qE для %qD, хоча було запитано %qE."
 
 #: ipa-strub.cc:1334
 #, gcc-internal-format
 msgid "the incompatible selection was determined by ultimate alias target %qD"
-msgstr ""
+msgstr "Несумісний вибір встановлено для кінцевої мети псевдоніма %qD"
 
 #: ipa-strub.cc:1681
 #, gcc-internal-format
 msgid "indirect non-%<strub%> call in %<strub%> context %qD"
-msgstr ""
+msgstr "Непрямий виклик не-%<strub%> у контексті %<strub%> %qD"
 
 #: ipa-strub.cc:1700
 #, gcc-internal-format
 msgid "calling %<always_inline%> %<strub%> %qD in non-%<strub%> context %qD"
-msgstr ""
+msgstr "Викликається %<always_inline%> %<strub%> %qD у контексті, який не є %<strub%> %qD"
 
 #: ipa-strub.cc:1710
 #, gcc-internal-format
 msgid "calling non-%<strub%> %qD in %<strub%> context %qD"
-msgstr ""
+msgstr "Викликається %qD, що не є %<strub%> у контексті %<strub%> %qD"
 
 #: ipa-strub.cc:1714
 #, gcc-internal-format
 msgid "calling %qD using non-%<strub%> type %qT in %<strub%> context %qD"
-msgstr ""
+msgstr "викликається %qD за допомогою не-%<strub%> типу %qT у контексті %<strub%> %qD"
 
 #: ipa-strub.cc:2839
-#, fuzzy, gcc-internal-format
-#| msgid "failed to load pendings for %<%E%s%E%>"
+#, gcc-internal-format
 msgid "failed to split %qD for %<strub%>"
-msgstr "не вдалося завантажити очікувані одиниці для %<%E%s%E%>"
+msgstr "не вдалося розділити %qD для %<strub%>"
 
 #: ira.cc:2441 ira.cc:2463
 #, gcc-internal-format
@@ -28869,10 +28681,9 @@ msgid "maximum number of generated reload insns per insn achieved (%d)"
 msgstr "досягнуто максимальну кількість згенерованих перезавантажень інструкцій на одну інструкцію (%d)"
 
 #: lra.cc:546
-#, fuzzy, gcc-internal-format
-#| msgid "%<asm%> operand has impossible constraints"
+#, gcc-internal-format
 msgid "%<asm%> operand has impossible constraints or there are not enough registers"
-msgstr "операнд %<asm%> має неможливі обмеження"
+msgstr "операнд %<asm%> має неможливі обмеження або недостатньо регістрів"
 
 #: lto-cgraph.cc:1171
 #, gcc-internal-format
@@ -29223,10 +29034,9 @@ msgid "invalid OpenMP non-rectangular loop step; %<(%E - %E) * %E%> is not a mul
 msgstr "недійсний не-прямокутний крок циклу OpenMP; %<(%E - %E) * %E%> не є кратним кроку %d циклу %qE"
 
 #: omp-general.cc:1283
-#, fuzzy, gcc-internal-format
-#| msgid "array size expression is not supported yet"
+#, gcc-internal-format
 msgid "%<target_device%> selector set is not supported yet"
-msgstr "вираз розміру масиву ще не підтримується"
+msgstr "набір селекторів %<target_device%> ще не підтримується"
 
 #: omp-general.cc:1288
 #, gcc-internal-format
@@ -29549,10 +29359,9 @@ msgid "OpenMP runtime API call %qD in a region with %<device(ancestor)%> clause"
 msgstr "Виклик API OpenMP %qD у регіоні з замиканням %<device(ancestor)%>"
 
 #: omp-low.cc:9791
-#, fuzzy, gcc-internal-format
-#| msgid "ignoring sink clause with offset that is not a multiple of the loop step"
+#, gcc-internal-format
 msgid "ignoring %<sink%> clause with offset that is not a multiple of the loop step"
-msgstr "ігнорування замикання sink з зміщенням, яке не є кратним кроку циклу"
+msgstr "ігнорування умови %<sink%> з зсувом, який не є кратним кроку циклу"
 
 #: omp-low.cc:9814
 #, gcc-internal-format
@@ -29912,12 +29721,12 @@ msgstr "якорі розділів повинні бути вимкнені, к
 #: opts.cc:1105
 #, gcc-internal-format
 msgid "%<-ftrivial-auto-var-init=zero%> is not enabled by %<-fhardened%> because it was specified on the command line"
-msgstr ""
+msgstr "%<-ftrivial-auto-var-init=zero%> не увімкнено %<-fhardened%>, оскільки було задано в командному рядку"
 
 #: opts.cc:1155
 #, gcc-internal-format
 msgid "%<-fstack-protector-strong%> is not enabled by %<-fhardened%> because it was specified on the command line"
-msgstr ""
+msgstr "%<-fstack-protector-strong%> не увімкнено %<-fhardened%>, оскільки було задано в командному рядку"
 
 #: opts.cc:1200
 #, gcc-internal-format
@@ -31064,16 +30873,14 @@ msgid "global destructors not supported on this target"
 msgstr "глобальні деструктори не підтримуються на цій платформі"
 
 #: targhooks.cc:1810
-#, fuzzy, gcc-internal-format
-#| msgid "target attribute is not supported on this machine"
+#, gcc-internal-format
 msgid "%<target%> attribute is not supported on this machine"
-msgstr "атрибут цільової платформи не підтримується на цій машині"
+msgstr "атрибут %<target%> не підтримується на цій машині"
 
 #: targhooks.cc:1822
-#, fuzzy, gcc-internal-format
-#| msgid "target attribute is not supported on this machine"
+#, gcc-internal-format
 msgid "%<target_version%> attribute is not supported on this machine"
-msgstr "атрибут цільової платформи не підтримується на цій машині"
+msgstr "атрибут %<target_version%> не підтримується на цій машині"
 
 #: targhooks.cc:1836
 #, gcc-internal-format
@@ -31221,10 +31028,9 @@ msgid "%<-fassociative-math%> disabled; other options take precedence"
 msgstr "%<-fassociative-math%> вимкнено; інші параметри мають пріоритет"
 
 #: toplev.cc:1578
-#, fuzzy, gcc-internal-format
-#| msgid "%<-fdata-sections%> not supported for this target"
+#, gcc-internal-format
 msgid "%<-fhardened%> not supported for this target"
-msgstr "%<-fdata-sections%> не підтримується для цільової системи"
+msgstr "%<-fhardened%> не підтримується для цієї мети"
 
 #: toplev.cc:1587
 #, gcc-internal-format
@@ -31234,7 +31040,7 @@ msgstr "%<-fstack-clash-protection%> не підтримується на ціл
 #: toplev.cc:1600
 #, gcc-internal-format
 msgid "%<-fstack-clash-protection%> is not enabled by %<-fhardened%> because %<-fstack-check%> was specified on the command line"
-msgstr ""
+msgstr "%<-fstack-clash-protection%> не увімкнено %<-fhardened%>, оскільки %<-fstack-check%> було вказано у командному рядку"
 
 #: toplev.cc:1610
 #, gcc-internal-format
@@ -31492,10 +31298,9 @@ msgid "%qs in gimple IL"
 msgstr "%qs в GIMPLE-IL"
 
 #: tree-cfg.cc:3361
-#, fuzzy, gcc-internal-format
-#| msgid "used struct type value where scalar is required"
+#, gcc-internal-format
 msgid "%qs as base where non-register is required"
-msgstr "використано значення типу «struct», де потрібний скаляр"
+msgstr "%qs як база, де потрібна нерегістрова змінна"
 
 #: tree-cfg.cc:3376
 #, gcc-internal-format
@@ -31769,10 +31574,9 @@ msgid "invalid operand in %qs"
 msgstr "недійсний операнд в %qs"
 
 #: tree-cfg.cc:4680
-#, fuzzy, gcc-internal-format
-#| msgid "invalid argument in option %qs"
+#, gcc-internal-format
 msgid "invalid %qs size argument in load"
-msgstr "недійсний аргумент в опції %qs"
+msgstr "недійсний розмір аргументу %qs у завантаженні"
 
 #: tree-cfg.cc:4699 tree-cfg.cc:4725
 #, gcc-internal-format
@@ -31990,33 +31794,29 @@ msgid "fallthru to exit from bb %d"
 msgstr "перехід до виходу з блоку бази %d"
 
 #: tree-cfg.cc:5711
-#, fuzzy, gcc-internal-format
-#| msgid "extra brace group at end of initializer"
+#, gcc-internal-format
 msgid "entry block count not initialized"
-msgstr "додаткова група фігурних дужок в кінці ініціалізатора"
+msgstr "кількість вхідних блоків не ініціалізована"
 
 #: tree-cfg.cc:5717
-#, fuzzy, gcc-internal-format
-#| msgid "extra brace group at end of initializer"
+#, gcc-internal-format
 msgid "exit block count not initialized"
-msgstr "додаткова група фігурних дужок в кінці ініціалізатора"
+msgstr "кількість вихідних блоків не ініціалізована"
 
 #: tree-cfg.cc:5724
 #, gcc-internal-format
 msgid "probability of edge from entry block not initialized"
-msgstr ""
+msgstr "Ймовірно не ініціалізоване ребро з блоку входу"
 
 #: tree-cfg.cc:5739
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qE is not initialized"
+#, gcc-internal-format, gfc-internal-format
 msgid "count of bb %d not initialized"
-msgstr "%qE не ініціалізовано"
+msgstr "кількість bb %d не ініціалізована"
 
 #: tree-cfg.cc:5745
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Uninitialized probability of edge %i->%i"
+#, gcc-internal-format, gfc-internal-format
 msgid "probability of edge %d->%d not initialized"
-msgstr "Незініціалізована ймовірність ребра %i->%i"
+msgstr "ймовірність ребра %d->%d не ініціалізована"
 
 #: tree-cfg.cc:5765
 #, gcc-internal-format
@@ -32049,16 +31849,14 @@ msgid "label %qD in the middle of basic block %d"
 msgstr "мітка %qD посередині базового блоку %d"
 
 #: tree-cfg.cc:5830
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "returns_twice call is %s in basic block %d"
+#, gcc-internal-format, gfc-internal-format
 msgid "returns_twice call is not last in basic block %d"
-msgstr "виклик returns_twice є %s в базовому блоку %d"
+msgstr "виклик returns_twice не є останнім в основному блоку %d"
 
 #: tree-cfg.cc:5839
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "returns_twice call is %s in basic block %d"
+#, gcc-internal-format, gfc-internal-format
 msgid "returns_twice call is not first in basic block %d"
-msgstr "виклик returns_twice є %s в базовому блоку %d"
+msgstr "виклик returns_twice не є першим в основному блоку %d"
 
 #: tree-cfg.cc:5871
 #, gcc-internal-format, gfc-internal-format
@@ -32305,7 +32103,7 @@ msgstr "%s з %s викликається в %s"
 #: tree-profile.cc:899
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many conditions (found %u); giving up coverage"
-msgstr ""
+msgstr "Забагато умов (знайдено %u); відмова від тестування покриття"
 
 #: tree-profile.cc:1757
 #, gcc-internal-format
@@ -33344,10 +33142,9 @@ msgid "initializer for floating value is not a floating constant"
 msgstr "ініціалізатор для значення з плаваючою комою не є плаваючою константою"
 
 #: varasm.cc:5342
-#, fuzzy, gcc-internal-format
-#| msgid "initializer for floating value is not a floating constant"
+#, gcc-internal-format
 msgid "initializer for %<_BitInt(%d)%> value is not an integer constant"
-msgstr "ініціалізатор для значення з плаваючою комою не є плаваючою константою"
+msgstr "ініціалізатор для значення %<_BitInt(%d)%> не є константою типу цілого"
 
 #: varasm.cc:5725
 #, gcc-internal-format
@@ -33541,28 +33338,24 @@ msgid "%qE attribute with unsupported boolean precision"
 msgstr "Атрибут %qE з непідтримуваною точністю для булевого типу"
 
 #: c-family/c-attribs.cc:1059
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only supported on boolean types"
+#, gcc-internal-format
 msgid "%qE attribute only supported in C"
-msgstr "Атрибут %qE підтримується лише для булевих типів"
+msgstr "атрибут %qE підтримується тільки в мові C"
 
 #: c-family/c-attribs.cc:1066
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only supported on boolean types"
+#, gcc-internal-format
 msgid "%qE attribute only supported on integral types"
-msgstr "Атрибут %qE підтримується лише для булевих типів"
+msgstr "атрибут %qE підтримується тільки для цілочисельних типів"
 
 #: c-family/c-attribs.cc:1087 c-family/c-attribs.cc:1103
-#, fuzzy, gcc-internal-format
-#| msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
+#, gcc-internal-format
 msgid "overflows in conversion from %qT to %qT changes value from %qE to %qE"
-msgstr "переповнення при перетворенні з %qT на %qT змінює значення з %qE на %qE"
+msgstr "переповнення при конверсії з %qT до %qT змінює значення з %qE на %qE"
 
 #: c-family/c-attribs.cc:1112
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument value %qE refers to parameter type %qT"
+#, gcc-internal-format
 msgid "%qE attribute requires different values for %<false%> and %<true%> for type %qT"
-msgstr "Значення аргументу атрибуту %qE %qE посилається на тип параметра %qT"
+msgstr "%qE атрибут вимагає різних значень для %<false%> та %<true%> для типу %qT"
 
 #: c-family/c-attribs.cc:1152
 #, gcc-internal-format
@@ -33581,28 +33374,24 @@ msgid "%qE argument not a string"
 msgstr "Аргумент %qE не є рядком"
 
 #: c-family/c-attribs.cc:1555 ada/gcc-interface/utils.cc:6793
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored on objects of type %qT"
+#, gcc-internal-format
 msgid "%qE attribute ignored because of argument %qE"
-msgstr "Атрибут %qE ігнорується на обʼєктах типу %qT"
+msgstr "атрибут %qE ігнорується через аргумент %qE"
 
 #: c-family/c-attribs.cc:1576 ada/gcc-interface/utils.cc:6814
-#, fuzzy, gcc-internal-format
-#| msgid "ignoring attribute %qE because it conflicts with attribute %qs"
+#, gcc-internal-format
 msgid "ignoring attribute %qE because of excess arguments starting at %qE"
-msgstr "атрибут %qE ігнорується, оскільки він конфліктує з атрибутом %qs"
+msgstr "ігнорування атрибуту %qE через надлишкові аргументи, починаючи з %qE"
 
 #: c-family/c-attribs.cc:1590 ada/gcc-interface/utils.cc:6828
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute does not apply to types"
+#, gcc-internal-format
 msgid "attribute %qE does not apply to elements of non-scalar type %qT"
-msgstr "атрибут %qE не застосовується до типів"
+msgstr "атрибут %qE не застосовується до елементів нескалярного типу %qT"
 
 #: c-family/c-attribs.cc:1595 ada/gcc-interface/utils.cc:6833
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute does not apply to types"
+#, gcc-internal-format
 msgid "attribute %qE does not apply to fields of aggregate type %qT"
-msgstr "атрибут %qE не застосовується до типів"
+msgstr "атрибут %qE не застосовується до полів агрегатного типу %qT"
 
 #: c-family/c-attribs.cc:1661
 #, gcc-internal-format
@@ -34391,10 +34180,9 @@ msgid "%qE cannot be applied to non-pointer type %qT"
 msgstr "атрибут %qE не може бути застосований до типу %qT, який не є вказівником"
 
 #: c-family/c-attribs.cc:6247
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument %qE is not recognised"
+#, gcc-internal-format
 msgid "%qE attribute argument %qE is not recognized"
-msgstr "аргумент атрибута %qE, %qE, не розпізнано"
+msgstr "аргумент атрибуту %qE не розпізнається: %qE"
 
 #: c-family/c-attribs.cc:6262
 #, gcc-internal-format
@@ -34833,16 +34621,14 @@ msgid "argument %u in call to function %qE has pointer to %qs type (%qT)"
 msgstr "аргумент %u у виклику функції %qE є вказівником на тип %qs (%qT)"
 
 #: c-family/c-common.cc:6536 c-family/c-common.cc:6621
-#, fuzzy, gcc-internal-format
-#| msgid "argument 3 in call to function %qE has enumerated type"
+#, gcc-internal-format
 msgid "argument %u in call to function %qE has enumerated type"
-msgstr "аргумент 3 у виклику функції %qE є типом з перелічуванням"
+msgstr "аргумент %u у виклику функції %qE має перерахований тип"
 
 #: c-family/c-common.cc:6542 c-family/c-common.cc:6627
-#, fuzzy, gcc-internal-format
-#| msgid "argument 3 in call to function %qE has boolean type"
+#, gcc-internal-format
 msgid "argument %u in call to function %qE has boolean type"
-msgstr "аргумент 3 у виклику функції %qE має тип boolean"
+msgstr "аргумент %u у виклику функції %qE має булевий тип"
 
 #: c-family/c-common.cc:6555
 #, gcc-internal-format
@@ -34855,22 +34641,19 @@ msgid "argument %u in call to function %qE points to incomplete type"
 msgstr "аргумент %u у виклику функції %qE посилається на неповний тип"
 
 #: c-family/c-common.cc:6605
-#, fuzzy, gcc-internal-format
-#| msgid "argument %u in call to function %qE does not have pointer type"
+#, gcc-internal-format
 msgid "argument %u in call to function %qE does not have %<int%> type"
-msgstr "аргумент %u у виклику функції %qE не має типу вказівника"
+msgstr "аргумент %u у виклику функції %qE не має типу %<int%>"
 
 #: c-family/c-common.cc:6636
-#, fuzzy, gcc-internal-format
-#| msgid "argument 3 in call to function %qE has enumerated type"
+#, gcc-internal-format
 msgid "argument 1 in call to function %qE has unsigned type"
-msgstr "аргумент 3 у виклику функції %qE є типом з перелічуванням"
+msgstr "аргумент 1 у виклику функції %qE має беззнаковий тип"
 
 #: c-family/c-common.cc:6643
-#, fuzzy, gcc-internal-format
-#| msgid "argument 3 in call to function %qE has enumerated type"
+#, gcc-internal-format
 msgid "argument 1 in call to function %qE has signed type"
-msgstr "аргумент 3 у виклику функції %qE є типом з перелічуванням"
+msgstr "Аргумент 1 у виклику функції %qE має знаковий тип"
 
 #: c-family/c-common.cc:6906 rust/backend/rust-tree.cc:3601
 #, gcc-internal-format
@@ -35670,22 +35453,19 @@ msgid "stray %<\\%o%> in program"
 msgstr "зайвий %<\\%o%> в програмі"
 
 #: c-family/c-lex.cc:1034
-#, fuzzy, gcc-internal-format
-#| msgid "integer constant is too large for %<unsigned long%> type"
+#, gcc-internal-format
 msgid "integer constant is too large for %<unsigned _BitInt(%d)%> type"
-msgstr "цілочисельна константа занадто велика для типу %<unsigned long%>"
+msgstr "ціле число завелике для типу %<unsigned _BitInt(%d)%>"
 
 #: c-family/c-lex.cc:1037
-#, fuzzy, gcc-internal-format
-#| msgid "integer constant is too large for %<unsigned long%> type"
+#, gcc-internal-format
 msgid "integer constant is too large for %<_BitInt(%d)%> type"
-msgstr "цілочисельна константа занадто велика для типу %<unsigned long%>"
+msgstr "ціле число завелике для типу %<_BitInt(%d)%>"
 
 #: c-family/c-lex.cc:1045 c/c-decl.cc:12737
-#, fuzzy, gcc-internal-format
-#| msgid "%<__int%d%> is not supported on this target"
+#, gcc-internal-format
 msgid "%<_BitInt(%d)%> is not supported on this target"
-msgstr "%<__int%d%> не підтримується на цій платформі"
+msgstr "%<_BitInt(%d)%> не підтримується на цій платформі"
 
 #: c-family/c-lex.cc:1097
 #, gcc-internal-format
@@ -35723,10 +35503,9 @@ msgid "non-standard suffix on floating constant"
 msgstr "нестандартний суфікс на плаваючій константі"
 
 #: c-family/c-lex.cc:1243 c-family/c-lex.cc:1247 c-family/c-lex.cc:1252
-#, fuzzy, gcc-internal-format
-#| msgid "non-standard suffix on floating constant"
+#, gcc-internal-format
 msgid "non-standard suffix on floating constant before C23"
-msgstr "нестандартний суфікс на плаваючій константі"
+msgstr "нестандартний суфікс у плаваючій константі перед C23"
 
 #: c-family/c-lex.cc:1259
 #, gcc-internal-format
@@ -35906,24 +35685,22 @@ msgstr "два різних зовнішніх ітераційних змінн
 #: c-family/c-omp.cc:1820
 #, gcc-internal-format
 msgid "variable %qD used as loop variable is bound in intervening code"
-msgstr ""
+msgstr "змінна %qD, що використовується як змінна циклу, прив'язана в проміжному коді"
 
 #: c-family/c-omp.cc:1824
-#, fuzzy, gcc-internal-format
-#| msgid "variable %qD has initializer but incomplete type"
+#, gcc-internal-format
 msgid "variable %qD used in initializer is bound in intervening code"
-msgstr "змінна %qD має ініціалізатор, але неповний тип"
+msgstr "змінна %qD, використовувана в ініціалізаторі, прив'язана у проміжному коді"
 
 #: c-family/c-omp.cc:1828
-#, fuzzy, gcc-internal-format
-#| msgid "register variable %qD used in nested function"
+#, gcc-internal-format
 msgid "variable %qD used in end test is bound in intervening code"
-msgstr "зареєстрована змінна %qD використовується у вкладеній функції"
+msgstr "змінна %qD, використовувана в кінцевій перевірці, прив'язана у проміжному коді"
 
 #: c-family/c-omp.cc:1832
 #, gcc-internal-format
 msgid "variable %qD used in increment expression is bound in intervening code"
-msgstr ""
+msgstr "Змінна %qD, що використовується у виразі інкременту, прив'язана в проміжному коді"
 
 #: c-family/c-omp.cc:2436
 #, gcc-internal-format
@@ -35984,7 +35761,7 @@ msgstr "застаріла опція %<-I-%> використовується,
 #: c-family/c-opts.cc:373
 #, gcc-internal-format
 msgid "%<-fdeps-format=%> unknown format %<%s%>"
-msgstr ""
+msgstr "%<-fdeps-format=%> невідомий формат %<%s%>"
 
 #: c-family/c-opts.cc:455
 #, gcc-internal-format
@@ -36059,7 +35836,7 @@ msgstr "зовнішні функції ініціалізації TLS не пі
 #: c-family/c-opts.cc:1149
 #, gcc-internal-format
 msgid "%<-fconcepts-ts%> is deprecated and will be removed in GCC 15; please convert your code to C++20 concepts"
-msgstr ""
+msgstr "%<-fconcepts-ts%> застаріло і буде видалено в GCC 15; будь ласка, перепишіть ваш код на концепції C++20"
 
 #: c-family/c-opts.cc:1158
 #, gcc-internal-format
@@ -36084,7 +35861,7 @@ msgstr "не вдалося відкрити файл залежностей %s:
 #: c-family/c-opts.cc:1381
 #, gcc-internal-format
 msgid "%<-MF%> and %<-fdeps-file=%> cannot share an output file %s: %m"
-msgstr ""
+msgstr "%<-MF%> і %<-fdeps-file=%> не можуть писати в один вихідний файл %s: %m"
 
 #: c-family/c-opts.cc:1391
 #, gcc-internal-format
@@ -36119,17 +35896,17 @@ msgstr "%<-fdirectives-only%> несумісний з %<-traditional%>"
 #: c-family/c-opts.cc:1634
 #, gcc-internal-format
 msgid "%<_FORTIFY_SOURCE%> is not enabled by %<-fhardened%> because optimizations are turned off"
-msgstr ""
+msgstr "%<_FORTIFY_SOURCE%> не включено через %<-fhardened%>, оскільки оптимізації вимкнені"
 
 #: c-family/c-opts.cc:1638
 #, gcc-internal-format
 msgid "%<_FORTIFY_SOURCE%> is not enabled by %<-fhardened%> because it was specified in %<-D%> or %<-U%>"
-msgstr ""
+msgstr "%<_FORTIFY_SOURCE%> не включено через %<-fhardened%>, оскільки воно було вказано в %<-D%> або %<-U%>"
 
 #: c-family/c-opts.cc:1644
 #, gcc-internal-format
 msgid "%<_GLIBCXX_ASSERTIONS%> is not enabled by %<-fhardened%> because it was specified in %<-D%> or %<-U%>"
-msgstr ""
+msgstr "%<_GLIBCXX_ASSERTIONS%> не включено через %<-fhardened%>, оскільки воно було вказано в %<-D%> або %<-U%>"
 
 #: c-family/c-opts.cc:1768
 #, gcc-internal-format
@@ -36422,16 +36199,14 @@ msgid "%<#pragma GCC optimize%> string is badly formed"
 msgstr "Рядок %<#pragma GCC optimize%> має неправильний формат"
 
 #: c-family/c-pragma.cc:1211
-#, fuzzy, gcc-internal-format
-#| msgid "junk at end of %<#pragma push_options%>"
+#, gcc-internal-format
 msgid "junk at end of %<#pragma GCC push_options%>"
-msgstr "Сміття в кінці %<#pragma push_options%>"
+msgstr "непотрібний символ у кінці %<#pragma GCC push_options%>"
 
 #: c-family/c-pragma.cc:1248
-#, fuzzy, gcc-internal-format
-#| msgid "junk at end of %<#pragma pop_options%>"
+#, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pop_options%>"
-msgstr "Сміття в кінці %<#pragma pop_options%>"
+msgstr "непотрібний символ у кінці %<#pragma GCC pop_options%>"
 
 #: c-family/c-pragma.cc:1255
 #, gcc-internal-format
@@ -37224,21 +36999,19 @@ msgid "%<memset%> used with length equal to number of elements without multiplic
 msgstr "%<memset%> використовується з довжиною, рівною кількості елементів без множення на розмір елемента"
 
 #: c-family/c-warn.cc:2290
-#, fuzzy, gcc-internal-format
-#| msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
+#, gcc-internal-format
 msgid "%qD sizes specified with %<sizeof%> in the earlier argument and not in the later argument"
-msgstr "переривання службового режиму може мати лише аргумент вказівника та необовʼязковий аргумент цілого числа"
+msgstr "Розміри %qD, вказані з використанням %<sizeof%> у ранішому аргументі, не вказані у пізнішому аргументі"
 
 #: c-family/c-warn.cc:2292
 #, gcc-internal-format
 msgid "earlier argument should specify number of elements, later size of each element"
-msgstr ""
+msgstr "Раніший аргумент повинен вказувати кількість елементів, а пізніше - розмір кожного елемента"
 
 #: c-family/c-warn.cc:2331
-#, fuzzy, gcc-internal-format
-#| msgid "floating point overflow in expression %qE of type %qT results in %qE"
+#, gcc-internal-format
 msgid "allocation of insufficient size %qE for type %qT with size %qE"
-msgstr "переповнення числа з плаваючою комою в виразі %qE типу %qT призводить до %qE"
+msgstr "виділення недостатнього розміру %qE для типу %qT з розміром %qE"
 
 #: c-family/c-warn.cc:2408
 #, gcc-internal-format
@@ -37475,16 +37248,14 @@ msgid "comparison between two arrays"
 msgstr "порівняння між двома масивами"
 
 #: c-family/c-warn.cc:3832
-#, fuzzy, gcc-internal-format
-#| msgid "use unary %<+%> which decays operands to pointers or %<&%D[0] %s &%D[0]%> to compare the addresses"
+#, gcc-internal-format
 msgid "use unary %<+%> which decays operands to pointers or %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
-msgstr "використовуйте унарний оператор %<+%>, який перетворює операнди в вказівники, або %<&%D[0] %s &%D[0]%>, щоб порівняти адреси"
+msgstr "використовуйте унарний %<+%>, який розпадає операнди на вказівники, або %<&%s%E%s[0] %s &%s%E%s[0]%>, щоб порівняти адреси"
 
 #: c-family/c-warn.cc:3839
-#, fuzzy, gcc-internal-format
-#| msgid "use %<&%D[0] %s &%D[0]%> to compare the addresses"
+#, gcc-internal-format
 msgid "use %<&%s%E%s[0] %s &%s%E%s[0]%> to compare the addresses"
-msgstr "використовуйте %<&%D[0] %s &%D[0]%>, щоб порівняти адреси"
+msgstr "використовуйте %<&%s%E%s[0] %s &%s%E%s[0]%>, щоб порівняти адреси"
 
 #: c-family/c-warn.cc:3901
 #, gcc-internal-format
@@ -37522,10 +37293,9 @@ msgid "too many input files"
 msgstr "забагато вхідних файлів"
 
 #: c-family/known-headers.cc:322
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is defined in header %qs; did you forget to %<#include %s%>?"
+#, gcc-internal-format
 msgid "%qs is defined in header %qs; this is probably fixable by adding %<#include %s%>"
-msgstr "%qs визначено в заголовку %qs; ви забули %<#include %s%>?"
+msgstr "%qs визначено в заголовку %qs; це, ймовірно, можна виправити додаванням %<#include %s%>"
 
 #: common/config/aarch64/aarch64-common.cc:415 config/aarch64/aarch64.cc:18539
 #, gcc-internal-format
@@ -37722,27 +37492,24 @@ msgid "%<-march=%s%>: extension %qs appear more than one time"
 msgstr "%<-march=%s%>: розширення %qs зустрічається більше одного разу"
 
 #: common/config/riscv/riscv-common.cc:683
-#, fuzzy, gcc-internal-format
-#| msgid "%<-march=%s%>: extension %qs appear more than one time"
+#, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs is unsupported standard single letter extension"
-msgstr "%<-march=%s%>: розширення %qs зустрічається більше одного разу"
+msgstr "%<-march=%s%>: розширення %qs є непідтримуваним стандартним однолітерним розширенням"
 
 #: common/config/riscv/riscv-common.cc:691
-#, fuzzy, gcc-internal-format
-#| msgid "%<-march=%s%>: extension %qs appear more than one time"
+#, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'z' but is unsupported standard extension"
-msgstr "%<-march=%s%>: розширення %qs зустрічається більше одного разу"
+msgstr "%<-march=%s%>: розширення %qs починається з 'z', але є непідтримуваним стандартним розширенням"
 
 #: common/config/riscv/riscv-common.cc:699
 #, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 's' but is unsupported standard supervisor extension"
-msgstr ""
+msgstr "%<-march=%s%>: розширення %qs починається з 's', але це непідтримуване стандартне розширення супервізора"
 
 #: common/config/riscv/riscv-common.cc:707
-#, fuzzy, gcc-internal-format
-#| msgid "%<-march=%s%>: extension %qs appear more than one time"
+#, gcc-internal-format
 msgid "%<-march=%s%>: extension %qs starts with 'x' but is unsupported non-standard extension"
-msgstr "%<-march=%s%>: розширення %qs зустрічається більше одного разу"
+msgstr "%<-march=%s%>: розширення %qs починається з 'x', але є непідтримуваним нестандартним розширенням"
 
 #: common/config/riscv/riscv-common.cc:955
 #, gcc-internal-format
@@ -37775,16 +37542,14 @@ msgid "%<-march=%s%>: first ISA subset must be %<e%>, %<i%> or %<g%>"
 msgstr "%<-march=%s%>: перший піднабір ISA повинен бути %<e%>, %<i%> або %<g%>"
 
 #: common/config/riscv/riscv-common.cc:1097
-#, fuzzy, gcc-internal-format
-#| msgid "%<-march=%s%>: expect number after %<%dp%>"
+#, gcc-internal-format
 msgid "%<-march=%s%>: Not single-letter extension. %<%c%>"
-msgstr "%<-march=%s%>: після %<%dp%> очікується число"
+msgstr "%<-march=%s%>: Не однолітерне розширення. %<%c%>"
 
 #: common/config/riscv/riscv-common.cc:1228
-#, fuzzy, gcc-internal-format
-#| msgid "%<-march=%s%>: extension %qs appear more than one time"
+#, gcc-internal-format
 msgid "%<-march=%s%>: zcf extension supports in rv32 only"
-msgstr "%<-march=%s%>: розширення %qs зустрічається більше одного разу"
+msgstr "%<-march=%s%>: розширення zcf підтримується тільки в rv32"
 
 #: common/config/riscv/riscv-common.cc:1233
 #, gcc-internal-format
@@ -37792,28 +37557,24 @@ msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
 msgstr "%<-march=%s%>: конфлікт z*inx з розширеннями з плаваючою комою"
 
 #: common/config/riscv/riscv-common.cc:1239
-#, fuzzy, gcc-internal-format
-#| msgid "%<-march=%s%>: extension %qs appear more than one time"
+#, gcc-internal-format
 msgid "%<-march=%s%>: h extension requires i extension"
-msgstr "%<-march=%s%>: розширення %qs зустрічається більше одного разу"
+msgstr "%<-march=%s%>: розширення h вимагає розширення i"
 
 #: common/config/riscv/riscv-common.cc:1244
-#, fuzzy, gcc-internal-format
-#| msgid "%<-mcpu=%s%> conflicts with %<-march=%s%>"
+#, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmt"
-msgstr "%<-mcpu=%s%> конфліктує з %<-march=%s%>"
+msgstr "%<-march=%s%>: zcd конфліктує з zcmt"
 
 #: common/config/riscv/riscv-common.cc:1246
-#, fuzzy, gcc-internal-format
-#| msgid "%<-mcpu=%s%> conflicts with %<-march=%s%>"
+#, gcc-internal-format
 msgid "%<-march=%s%>: zcd conflicts with zcmp"
-msgstr "%<-mcpu=%s%> конфліктує з %<-march=%s%>"
+msgstr "%<-march=%s%>: zcd конфліктує з zcmp"
 
 #: common/config/riscv/riscv-common.cc:1255
-#, fuzzy, gcc-internal-format
-#| msgid "%<-march=%s%>: z*inx conflicts with floating-point extensions"
+#, gcc-internal-format
 msgid "%<-march=%s%>: xtheadvector conflicts with vector extension or its sub-extensions"
-msgstr "%<-march=%s%>: конфлікт z*inx з розширеннями з плаваючою комою"
+msgstr "%<-march=%s%>: xtheadvector конфліктує з векторним розширенням або його підрозширеннями"
 
 #: common/config/riscv/riscv-common.cc:1352
 #, gcc-internal-format
@@ -37826,10 +37587,9 @@ msgid "%<-march=%s%>: %s must separate with %<_%>"
 msgstr "%<-march=%s%>: %s повинно бути розділено знаком %<_%>"
 
 #: common/config/riscv/riscv-common.cc:1426
-#, fuzzy, gcc-internal-format
-#| msgid "%<-march=%s%>: name of %s must be more than 1 letter"
+#, gcc-internal-format
 msgid "%<-march=%s%>: i, e or g must be the first extension"
-msgstr "%<-march=%s%>: імʼя %s повинно бути більше, ніж 1 літера"
+msgstr "%<-march=%s%>: i, e або g повинні бути першим розширенням"
 
 #: common/config/riscv/riscv-common.cc:1759
 #, gcc-internal-format
@@ -38048,10 +37808,9 @@ msgid "%<-gsplit-dwarf%> is not supported on this platform, ignored"
 msgstr "%<-gsplit-dwarf%> не підтримується на цій платформі, проігноровано"
 
 #: config/darwin.cc:3449
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is not supported, now cmodel is set to %qs"
+#, gcc-internal-format
 msgid "%<-g3%> is not supported by the debug linker in use (set to 2)"
-msgstr "%qs не підтримується, зараз cmodel встановлено на %qs"
+msgstr "%<-g3%> не підтримується використовуваним зв'язувачем налагоджувача (встановлено в 2)"
 
 #: config/darwin.cc:3541
 #, gcc-internal-format
@@ -38164,10 +37923,9 @@ msgid "PIC is only supported for RTPs"
 msgstr "PIC підтримується лише для RTP"
 
 #: config/aarch64/aarch64-builtins.cc:2123
-#, fuzzy, gcc-internal-format
-#| msgid "argument %d must be an unsigned literal"
+#, gcc-internal-format
 msgid "first argument to %qD must be a string literal"
-msgstr "аргумент %d повинен бути беззнаковим літералом"
+msgstr "перший аргумент для %qD повинен бути літералом рядка"
 
 #: config/aarch64/aarch64-builtins.cc:2254
 #: config/aarch64/aarch64-builtins.cc:2488 config/arm/arm-builtins.cc:3146
@@ -38193,31 +37951,27 @@ msgstr "аргумент повинен бути 16-бітною констан
 #: config/aarch64/aarch64-builtins.cc:2701
 #, gcc-internal-format
 msgid "128-bit system register support requires the %<d128%> extension"
-msgstr ""
+msgstr "Підтримка 128-бітних системних регістрів вимагає розширення %<d128%>"
 
 #: config/aarch64/aarch64-builtins.cc:2716
-#, fuzzy, gcc-internal-format
-#| msgid "invalid register name for %q+D"
+#, gcc-internal-format
 msgid "invalid system register name provided"
-msgstr "недійсне імʼя регістру для %q+D"
+msgstr "надано недійсну назву системного регістру"
 
 #: config/aarch64/aarch64-builtins.cc:2730
-#, fuzzy, gcc-internal-format
-#| msgid "invalid register name for %q+D"
+#, gcc-internal-format
 msgid "invalid system register name %qs"
-msgstr "недійсне імʼя регістру для %q+D"
+msgstr "недійсна назва системного регістра %qs"
 
 #: config/aarch64/aarch64-builtins.cc:2810
-#, fuzzy, gcc-internal-format
-#| msgid "for statement expected"
+#, gcc-internal-format
 msgid "Constant-type argument expected"
-msgstr "очікувалася конструкція for"
+msgstr "Очікується аргумент константного типу"
 
 #: config/aarch64/aarch64-builtins.cc:2816
-#, fuzzy, gcc-internal-format
-#| msgid "argument %d must be a constant immediate in range [0,15]"
+#, gcc-internal-format
 msgid "argument %d must be a constant immediate in range [%wd,%wd]"
-msgstr "аргумент %d повинен бути константою негайною в діапазоні [0,15]"
+msgstr "аргумент %d повинен бути константною негайною величиною в діапазоні [%wd,%wd]"
 
 #: config/aarch64/aarch64-builtins.cc:2895
 #, gcc-internal-format
@@ -38270,17 +38024,17 @@ msgstr "Функція ACLE %qD несумісна з використанням
 #: config/aarch64/aarch64-sve-builtins.cc:1133
 #, gcc-internal-format
 msgid "ACLE function %qD cannot be called when SME streaming mode is enabled"
-msgstr ""
+msgstr "ACLE функція %qD не може бути викликана коли включений потік SME"
 
 #: config/aarch64/aarch64-sve-builtins.cc:1140
 #, gcc-internal-format
 msgid "ACLE function %qD can only be called when SME streaming mode is enabled"
-msgstr ""
+msgstr "ACLE функція %qD може бути викликана тільки коли включений потік SME."
 
 #: config/aarch64/aarch64-sve-builtins.cc:1147
 #, gcc-internal-format
 msgid "ACLE function %qD can only be called from a function that has %qs state"
-msgstr ""
+msgstr "ACLE функція %qD може бути викликана тільки з функції, яка має стан %qs"
 
 #: config/aarch64/aarch64-sve-builtins.cc:1175
 #: config/arm/arm-mve-builtins.cc:571
@@ -38290,10 +38044,9 @@ msgid "argument %d of %qE must be an integer constant expression"
 msgstr "аргумент %d функції %qE повинен бути цілочисельним константним виразом"
 
 #: config/aarch64/aarch64-sve-builtins.cc:1188
-#, fuzzy, gcc-internal-format
-#| msgid "passing %wd to argument %d of %qE, which expects either %wd or %wd"
+#, gcc-internal-format
 msgid "passing %wd to argument %d of %qE, which expects the value %wd"
-msgstr "передача %wd в аргумент %d %qE, який очікує або %wd або %wd"
+msgstr "передача %wd до аргументу %d функції %qE, яка очікує значення %wd"
 
 #: config/aarch64/aarch64-sve-builtins.cc:1191
 #: config/arm/arm-mve-builtins.cc:583
@@ -38335,21 +38088,19 @@ msgstr[1] "передача одного вектора %qT в аргумент
 msgstr[2] "передача одного вектора %qT в аргумент %d %qE, який очікує кортеж з %d векторів"
 
 #: config/aarch64/aarch64-sve-builtins.cc:1806
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT instead of the expected %qT to argument %d of %qE, after passing %qT to argument %d"
+#, gcc-internal-format
 msgid "passing tuple %qT to argument %d of %qE after passing single vector %qT to argument %d"
-msgstr "передача %qT замість очікуваного %qT до аргументу %d функції %qE, після передачі %qT до аргументу %d"
+msgstr "передача кортежу %qT до аргументу %d функції %qE після передачі одиничного вектора %qT до аргументу %d"
 
 #: config/aarch64/aarch64-sve-builtins.cc:1811
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT instead of the expected %qT to argument %d of %qE, after passing %qT to argument %d"
+#, gcc-internal-format
 msgid "passing single vector %qT to argument %d of %qE after passing tuple %qT to argument %d"
-msgstr "передача %qT замість очікуваного %qT до аргументу %d функції %qE, після передачі %qT до аргументу %d"
+msgstr "передача одиничного вектора %qT до аргументу %d функції %qE після передачі кортежу %qT до аргументу %d"
 
 #: config/aarch64/aarch64-sve-builtins.cc:1816
 #, gcc-internal-format
 msgid "passing mismatched tuple types %qT and %qT to arguments %d and %d of %qE"
-msgstr ""
+msgstr "передача несумісних типів кортежів %qT і %qT у якості аргументів %d і %d до %qE"
 
 #: config/aarch64/aarch64-sve-builtins.cc:1827
 #: config/arm/arm-mve-builtins.cc:1104
@@ -38358,16 +38109,14 @@ msgid "%qE has no form that takes %qT arguments"
 msgstr "%qE не має форми, яка приймає аргументи %qT"
 
 #: config/aarch64/aarch64-sve-builtins.cc:1888
-#, fuzzy, gcc-internal-format
-#| msgid "%qE has no form that takes %qT arguments"
+#, gcc-internal-format
 msgid "%qE has no form that takes %qT and %qT arguments"
-msgstr "%qE не має форми, яка приймає аргументи %qT"
+msgstr "у %qE немає форми, що приймає аргументи %qT і %qT"
 
 #: config/aarch64/aarch64-sve-builtins.cc:1950
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT to argument %d of %qE, which expects %qs or %qs"
+#, gcc-internal-format
 msgid "passing %qT to argument %d of %qE, which expects an %qs or %qs"
-msgstr "передача %qT в аргумент %d %qE, який очікує %qs або %qs"
+msgstr "передача %qT до аргументу %d функції %qE, яка очікує %qs або %qs"
 
 #: config/aarch64/aarch64-sve-builtins.cc:1981
 #, gcc-internal-format
@@ -38375,16 +38124,14 @@ msgid "passing %qT to argument %d of %qE, which expects a 32-bit or 64-bit integ
 msgstr "передача %qT в аргумент %d %qE, який очікує тип цілого числа 32 або 64 біт"
 
 #: config/aarch64/aarch64-sve-builtins.cc:2000
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT to argument %d of %qE, which expects a vector of %d-bit integers"
+#, gcc-internal-format
 msgid "passing %qT and %qT to arguments %d and %d of %qE, which expects a pair of 64-bit integers"
-msgstr "передача %qT в аргумент %d %qE, який очікує вектор цілочисельних %d біт"
+msgstr "передача %qT і %qT до аргументів %d і %d функції %qE, яка очікує пару 64-бітних цілих чисел"
 
 #: config/aarch64/aarch64-sve-builtins.cc:2024
-#, fuzzy, gcc-internal-format
-#| msgid "size mismatch in argument %d of %qE"
+#, gcc-internal-format
 msgid "passing mismatched integer types %qT and %qT to arguments %d and %d of %qE"
-msgstr "невідповідність розміру в аргументі %d з %qE"
+msgstr "передача несумісних цілочисельних типів %qT і %qT до аргументів %d і %d функції %qE"
 
 #: config/aarch64/aarch64-sve-builtins.cc:2045
 #: config/arm/arm-mve-builtins.cc:1157
@@ -38408,16 +38155,14 @@ msgid "passing %qT to argument %d of %qE, which expects a pointer to 32-bit or 6
 msgstr "передача %qT в аргумент %d %qE, який очікує вказівник на 32-бітні або 64-бітні елементи"
 
 #: config/aarch64/aarch64-sve-builtins.cc:2107
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT to argument %d of %qE, which expects a single SVE vector rather than a tuple"
+#, gcc-internal-format
 msgid "passing %qT to argument %d of %qE, which expects an SVE type rather than a scalar type"
-msgstr "передача %qT в аргумент %d %qE, який очікує один SVE вектор, а не кортеж"
+msgstr "передача %qT до аргументу %d функції %qE, яка очікує тип SVE замість скалярного типу"
 
 #: config/aarch64/aarch64-sve-builtins.cc:2111
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT to argument %d of %qE, which expects an SVE tuple type"
+#, gcc-internal-format
 msgid "passing %qT to argument %d of %qE, which expects an SVE type"
-msgstr "передача %qT в аргумент %d %qE, який очікує типу кортежу SVE"
+msgstr "передача %qT до аргументу %d функції %qE, яка очікує тип SVE"
 
 #: config/aarch64/aarch64-sve-builtins.cc:2156
 #, gcc-internal-format
@@ -38425,10 +38170,9 @@ msgid "passing %qT to argument %d of %qE, which expects a vector of integers"
 msgstr "передача %qT в аргумент %d %qE, який очікує вектора цілочисельних"
 
 #: config/aarch64/aarch64-sve-builtins.cc:2186
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT to argument %d of %qE, which expects an SVE vector type"
+#, gcc-internal-format
 msgid "passing %qT to argument %d of %qE, which expects a 128 bit NEON vector type"
-msgstr "передача %qT в аргумент %d %qE, який очікує тип SVE вектора"
+msgstr "передача %qT до аргументу %d функції %qE, яка очікує тип вектора NEON з 128 біт"
 
 #: config/aarch64/aarch64-sve-builtins.cc:2203
 #: config/aarch64/aarch64-sve-builtins.cc:2501
@@ -38445,12 +38189,12 @@ msgstr "передача %qT до аргументу %d функції %qE, як
 #: config/aarch64/aarch64-sve-builtins.cc:2266
 #, gcc-internal-format
 msgid "operations on multiple vectors must be predicated by %qs rather than %qs"
-msgstr ""
+msgstr "Операції над декількома векторами повинні визначатися за допомогою %qs, а не %qs"
 
 #: config/aarch64/aarch64-sve-builtins.cc:2269
 #, gcc-internal-format
 msgid "operations on single vectors must be predicated by %qs rather than %qs"
-msgstr ""
+msgstr "операції над одиничними векторами повинні визначатися за допомогою %qs, а не %qs"
 
 #: config/aarch64/aarch64-sve-builtins.cc:2285
 #: config/arm/arm-mve-builtins.cc:1248
@@ -38473,10 +38217,9 @@ msgid "passing %qT to argument %d of %qE, but argument %d had type %qT"
 msgstr "передача %qT до аргументу %d функції %qE, але аргумент %d має тип %qT"
 
 #: config/aarch64/aarch64-sve-builtins.cc:2445
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT to argument %d of %qE, but argument %d had type %qT"
+#, gcc-internal-format
 msgid "passing %qT to argument %d of %qE, but argument %d was a tuple of %qT"
-msgstr "передача %qT до аргументу %d функції %qE, але аргумент %d має тип %qT"
+msgstr "передача %qT до аргументу %d функції %qE, але аргумент %d був кортежем з %qT"
 
 #: config/aarch64/aarch64-sve-builtins.cc:2469
 #: config/arm/arm-mve-builtins.cc:1384
@@ -38485,10 +38228,9 @@ msgid "passing %qT to argument %d of %qE, which expects a vector of %d-bit eleme
 msgstr "передача %qT до аргументу %d функції %qE, яка очікує вектор з елементів %d біт"
 
 #: config/aarch64/aarch64-sve-builtins.cc:2474
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT to argument %d of %qE, which expects a vector of %d-bit elements"
+#, gcc-internal-format
 msgid "passing %qT to argument %d of %qE, which expects vectors of %d-bit elements"
-msgstr "передача %qT до аргументу %d функції %qE, яка очікує вектор з елементів %d біт"
+msgstr "передача %qT до аргументу %d функції %qE, яка очікує вектори з елементів по %d біт"
 
 #: config/aarch64/aarch64-sve-builtins.cc:2487
 #: config/arm/arm-mve-builtins.cc:1396
@@ -38499,18 +38241,16 @@ msgstr "передача %qT до аргументу %d функції %qE, як
 #. Translation note: could also be written "expects a tuple of
 #. signed integer vectors".
 #: config/aarch64/aarch64-sve-builtins.cc:2493
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT to argument %d of %qE, which expects a vector of signed integers"
+#, gcc-internal-format
 msgid "passing %qT to argument %d of %qE, which expects vectors of signed integers"
-msgstr "передача %qT до аргументу %d функції %qE, яка очікує вектор зі знакових цілочисельних"
+msgstr "передача %qT до аргументу %d функції %qE, яка очікує вектори зі знакових цілих чисел"
 
 #. Translation note: could also be written "expects a tuple of
 #. unsigned integer vectors".
 #: config/aarch64/aarch64-sve-builtins.cc:2507
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT to argument %d of %qE, which expects a vector of unsigned integers"
+#, gcc-internal-format
 msgid "passing %qT to argument %d of %qE, which expects vectors of unsigned integers"
-msgstr "передача %qT в аргумент %d функції %qE, яка очікує вектор беззнакових цілих чисел"
+msgstr "передача %qT в аргумент %d для %qE, який очікує вектори беззнакових цілих чисел"
 
 #: config/aarch64/aarch64-sve-builtins.cc:2527
 #: config/arm/arm-mve-builtins.cc:1423
@@ -38537,10 +38277,9 @@ msgid "passing %qT to argument %d of %qE, which expects %qs"
 msgstr "передача %qT до аргументу %d функції %qE, яка очікує %qs"
 
 #: config/aarch64/aarch64-sve-builtins.cc:2616
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT to argument %d of %qE, which expects a scalar pointer"
+#, gcc-internal-format
 msgid "passing %qT to argument %d of %qE, which does not accept scalars for this combination of arguments"
-msgstr "передача %qT до аргументу %d функції %qE, яка очікує скалярний вказівник"
+msgstr "передача %qT в аргумент %d для %qE, який не приймає скаляри для цього поєднання аргументів"
 
 #: config/aarch64/aarch64-sve-builtins.cc:2632
 #: config/arm/arm-mve-builtins.cc:1556
@@ -38642,10 +38381,9 @@ msgid "passing %qT to argument %d of %qE, but its %qT form does not accept scala
 msgstr "передача %qT в аргумент %d %qE, але його форма %qT не приймає скаляри"
 
 #: config/aarch64/aarch64-sve-builtins.cc:3166
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT to argument %d of %qE, but its %qT form does not accept scalars"
+#, gcc-internal-format
 msgid "passing %qT to argument %d of %qE, but its %qT form does not accept single vectors"
-msgstr "передача %qT в аргумент %d %qE, але його форма %qT не приймає скаляри"
+msgstr "передача %qT в аргумент %d для %qE, але його форма %qT не приймає одиничні вектори"
 
 #: config/aarch64/aarch64-sve-builtins.cc:4660
 #: config/arm/arm-mve-builtins.cc:466 config/arm/arm-mve-builtins.cc:491
@@ -38655,10 +38393,9 @@ msgid "duplicate definition of %qs"
 msgstr "подвійне визначення %qs"
 
 #: config/aarch64/aarch64-sve-builtins.cc:4717
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is defined with tls model %s"
+#, gcc-internal-format
 msgid "%qs defined without first defining %qs"
-msgstr "%qD визначено з моделлю tls %s"
+msgstr "%qs визначено без попереднього визначення %qs"
 
 #: config/aarch64/aarch64-sve-builtins.cc:4868
 #, gcc-internal-format
@@ -38742,16 +38479,14 @@ msgid "capture by copy of SVE type %qT"
 msgstr "захоплення копіюванням типу SVE %qT"
 
 #: config/aarch64/aarch64.cc:637
-#, fuzzy, gcc-internal-format
-#| msgid "third argument to function %qE must be a constant integer"
+#, gcc-internal-format
 msgid "the arguments to %qE must be constant strings"
-msgstr "третій аргумент функції %qE повинен бути цілою сталою"
+msgstr "аргументи для %qE повинні бути константними рядками"
 
 #: config/aarch64/aarch64.cc:645
-#, fuzzy, gcc-internal-format
-#| msgid "unrecognized string escape"
+#, gcc-internal-format
 msgid "unrecognized state string %qs"
-msgstr "нерозпізнаний рядковий екранування"
+msgstr "нерозпізнаний рядок стану %qs"
 
 #: config/aarch64/aarch64.cc:729
 #, gcc-internal-format
@@ -38761,19 +38496,17 @@ msgstr "атрибут %qE не може бути застосований до
 #: config/aarch64/aarch64.cc:756
 #, gcc-internal-format
 msgid "cannot create a new %qs scope since %qs is shared with callers"
-msgstr ""
+msgstr "неможливо створити новий обсяг %qs, оскільки %qs ділиться з викликами"
 
 #: config/aarch64/aarch64.cc:772
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute applies only to functions"
+#, gcc-internal-format
 msgid "%qE attribute applies only to function definitions"
-msgstr "атрибут %qE застосовується лише до функцій"
+msgstr "атрибут %qE застосовується тільки до визначень функцій"
 
 #: config/aarch64/aarch64.cc:818
-#, fuzzy, gcc-internal-format
-#| msgid "inconsistent because %qs"
+#, gcc-internal-format
 msgid "inconsistent attributes for state %qs"
-msgstr "неспівмірні через %qs"
+msgstr "несумісні атрибути для стану %qs"
 
 #: config/aarch64/aarch64.cc:1307
 #, gcc-internal-format
@@ -38825,10 +38558,9 @@ msgstr "передача параметра для аргументу типу %
 
 #: config/aarch64/aarch64.cc:7028 config/aarch64/aarch64.cc:7107
 #: config/aarch64/aarch64.cc:21328
-#, fuzzy, gcc-internal-format
-#| msgid "parameter passing for argument of type %qT changed in GCC 13.1"
+#, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 14.1"
-msgstr "передача параметра для аргументу типу %qT змінена в GCC 13.1"
+msgstr "передача параметрів для аргументу типу %qT змінилася в GCC 14.1"
 
 #: config/aarch64/aarch64.cc:7039 config/aarch64/aarch64.cc:7117
 #: config/aarch64/aarch64.cc:21336 config/arm/arm.cc:7342
@@ -38853,30 +38585,29 @@ msgid "stack probes for SVE frames"
 msgstr "перевірка стеку для фреймів SVE"
 
 #: config/aarch64/aarch64.cc:11149
-#, fuzzy, gcc-internal-format
-#| msgid "ACLE function %qD requires ISA extension %qs"
+#, gcc-internal-format
 msgid "calling a streaming function requires the ISA extension %qs"
-msgstr "Функція ACLE %qD вимагає розширення ISA %qs"
+msgstr "виклик потокової функції вимагає розширення ISA %qs"
 
 #: config/aarch64/aarch64.cc:11158 config/aarch64/aarch64.cc:11162
 #, gcc-internal-format
 msgid "call to a function that shares %qs state from a function that has no %qs state"
-msgstr ""
+msgstr "виклик функції, яка ділиться станом %qs, з функції, що не має стану %qs"
 
 #: config/aarch64/aarch64.cc:11165
 #, gcc-internal-format
 msgid "call to a function that shares SME state from a function that has no SME state"
-msgstr ""
+msgstr "виклик функції, яка ділиться станом SME, з функції, що не має стану SME"
 
 #: config/aarch64/aarch64.cc:11223
 #, gcc-internal-format
 msgid "call to a function that shares state other than %qs from a function that has %qs state"
-msgstr ""
+msgstr "виклик функції, яка ділиться станом, крім %qs, з функції, що має стан %qs"
 
 #: config/aarch64/aarch64.cc:11225
 #, gcc-internal-format
 msgid "use %<__arm_preserves(\"za\")%> if the callee preserves ZA"
-msgstr ""
+msgstr "використовуйте %<__arm_preserves(\"za\")%>, якщо функція, яку викликають, зберігає ZA."
 
 #: config/aarch64/aarch64.cc:17932
 #, gcc-internal-format
@@ -38936,16 +38667,14 @@ msgid "%<-fsanitize=shadow-call-stack%> requires %<-ffixed-x18%>"
 msgstr "%<-fsanitize=shadow-call-stack%> потребує %<-ffixed-x18%>"
 
 #: config/aarch64/aarch64.cc:18310
-#, fuzzy, gcc-internal-format
-#| msgid "ACLE function %qD requires ISA extension %qs"
+#, gcc-internal-format
 msgid "streaming functions require the ISA extension %qs"
-msgstr "Функція ACLE %qD вимагає розширення ISA %qs"
+msgstr "потокові функції вимагають розширення ISA %qs"
 
 #: config/aarch64/aarch64.cc:18312
-#, fuzzy, gcc-internal-format
-#| msgid "ACLE function %qD requires ISA extension %qs"
+#, gcc-internal-format
 msgid "functions with SME state require the ISA extension %qs"
-msgstr "Функція ACLE %qD вимагає розширення ISA %qs"
+msgstr "функції з станом SME вимагають розширення ISA %qs"
 
 #: config/aarch64/aarch64.cc:18406
 #, gcc-internal-format
@@ -38963,10 +38692,9 @@ msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "відсутнє імʼя процесора в %<-mcpu=%s%>"
 
 #: config/aarch64/aarch64.cc:18546
-#, fuzzy, gcc-internal-format
-#| msgid "did you mean %<-mcpu=%s%>?"
+#, gcc-internal-format
 msgid "did you mean %<-march=%s%>?"
-msgstr "ви мали на увазі %<-mcpu=%s%>?"
+msgstr "ви мали на увазі %<-march=%s%>?"
 
 #: config/aarch64/aarch64.cc:18549
 #, gcc-internal-format
@@ -39019,10 +38747,9 @@ msgid "unknown value %qs for %<-mtune%>"
 msgstr "невідоме значення %qs для %<-mtune%>"
 
 #: config/aarch64/aarch64.cc:18847
-#, fuzzy, gcc-internal-format
-#| msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch"
+#, gcc-internal-format
 msgid "switch %<-mcpu=%s%> conflicts with %<-march=%s%> switch and resulted in options %<%s%> being added"
-msgstr "перемикач %<-mcpu=%s%> конфліктує з перемикачем %<-march=%s%>"
+msgstr "перемикач %<-mcpu=%s%> конфліктує з перемикачем %<-march=%s%> і призвело до додавання опцій %<%s%>"
 
 #: config/aarch64/aarch64.cc:18903
 #, gcc-internal-format
@@ -39045,10 +38772,9 @@ msgid "code model %qs not supported in ilp32 mode"
 msgstr "модель коду %qs не підтримується в режимі ilp32"
 
 #: config/aarch64/aarch64.cc:19084
-#, fuzzy, gcc-internal-format
-#| msgid "ACLE function %qD requires ISA extension %qs"
+#, gcc-internal-format
 msgid "functions with %qs state require the ISA extension %qs"
-msgstr "Функція ACLE %qD вимагає розширення ISA %qs"
+msgstr "функції з станом %qs вимагають розширення ISA %qs"
 
 #: config/aarch64/aarch64.cc:19187
 #, gcc-internal-format
@@ -39133,34 +38859,29 @@ msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "некоректна прагма або атрибут %<target(\"%s\")%>"
 
 #: config/aarch64/aarch64.cc:19801
-#, fuzzy, gcc-internal-format
-#| msgid "attribute %<fallthrough%> specified multiple times"
+#, gcc-internal-format
 msgid "attribute %<target_version%> has multiple values"
-msgstr "атрибут %<fallthrough%> вказано кілька разів"
+msgstr "атрибут %<target_version%> має кілька значень"
 
 #: config/aarch64/aarch64.cc:19809
-#, fuzzy, gcc-internal-format
-#| msgid "attribute %<target%> argument not a string"
+#, gcc-internal-format
 msgid "attribute %<target_version%> argument not a string"
-msgstr "аргумент атрибуту %<target%> не є рядком"
+msgstr "аргумент атрибуту %<target_version%> не є рядком"
 
 #: config/aarch64/aarch64.cc:19831
-#, fuzzy, gcc-internal-format
-#| msgid "missing value in %<target()%> pragma or attribute"
+#, gcc-internal-format
 msgid "missing value in %<target_version%> attribute"
-msgstr "відсутнє значення в директиві або атрибуті %<target()%>"
+msgstr "відсутнє значення в атрибуті %<target_version%>"
 
 #: config/aarch64/aarch64.cc:19835
-#, fuzzy, gcc-internal-format
-#| msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
+#, gcc-internal-format
 msgid "invalid feature modifier %qs of value %qs in %<target_version%> attribute"
-msgstr "недійсний модифікатор функції %qs зі значенням %qs в директиві або атрибуті %<target()%>"
+msgstr "недійсний модифікатор функції %qs з значенням %qs в атрибуті %<target_version%>"
 
 #: config/aarch64/aarch64.cc:19841
-#, fuzzy, gcc-internal-format
-#| msgid "invalid feature modifier %qs of value %qs in %<target()%> pragma or attribute"
+#, gcc-internal-format
 msgid "duplicate feature modifier %qs of value %qs in %<target_version%> attribute"
-msgstr "недійсний модифікатор функції %qs зі значенням %qs в директиві або атрибуті %<target()%>"
+msgstr "дублікат модифікатора функції %qs з значенням %qs в атрибуті %<target_version%>"
 
 #: config/aarch64/aarch64.cc:20420 config/i386/i386-features.cc:3521
 #: config/i386/i386-features.cc:3790
@@ -39200,10 +38921,9 @@ msgid "unsupported simdlen %wd"
 msgstr "непідтримувана simdlen %wd"
 
 #: config/aarch64/aarch64.cc:28763
-#, fuzzy, gcc-internal-format
-#| msgid "GCC does not currently support return type %qT for %<simd%> functions"
+#, gcc-internal-format
 msgid "GCC does not currently support return type %qT for simd"
-msgstr "GCC наразі не підтримує тип повернення %qT для функцій %<simd%>"
+msgstr "GCC наразі не підтримує тип повернення %qT для simd"
 
 #: config/aarch64/aarch64.cc:28767 config/i386/i386.cc:25315
 #, gcc-internal-format
@@ -39211,10 +38931,9 @@ msgid "unsupported return type %qT for simd"
 msgstr "непідтримуваний тип повернення %qT для simd"
 
 #: config/aarch64/aarch64.cc:28797
-#, fuzzy, gcc-internal-format
-#| msgid "GCC does not currently support argument type %qT for %<simd%> functions"
+#, gcc-internal-format
 msgid "GCC does not currently support argument type %qT for simd"
-msgstr "GCC наразі не підтримує тип аргументу %qT для функцій %<simd%>"
+msgstr "GCC наразі не підтримує тип аргументу %qT для simd"
 
 #: config/aarch64/aarch64.cc:28801 config/i386/i386.cc:25346
 #, gcc-internal-format
@@ -39227,32 +38946,29 @@ msgid "GCC does not currently support simdlen %wd for type %qT"
 msgstr "GCC наразі не підтримує simdlen %wd для типу %qT"
 
 #: config/aarch64/aarch64.cc:28871
-#, fuzzy, gcc-internal-format
-#| msgid "GCC does not currently support simdlen %wd for type %qT"
+#, gcc-internal-format
 msgid "GCC does not currently support a simdclone with simdlens %wd and %wd for these types."
-msgstr "GCC наразі не підтримує simdlen %wd для типу %qT"
+msgstr "GCC наразі не підтримує simdclone з simdlens %wd і %wd для цих типів."
 
 #: config/aarch64/aarch64.cc:28961
-#, fuzzy, gcc-internal-format
-#| msgid "type attributes ignored after type is already defined"
+#, gcc-internal-format
 msgid "cannot apply attribute %qs to %q+D after the function has been defined"
-msgstr "атрибути типу ігноруються після вже визначеного типу"
+msgstr "неможливо застосувати атрибут %qs до %q+D після того, як функція була визначена"
 
 #: config/aarch64/aarch64.cc:28963
-#, fuzzy, gcc-internal-format
-#| msgid "%qD defined here"
+#, gcc-internal-format
 msgid "%q+D defined here"
-msgstr "%qD визначено тут"
+msgstr "%q+D визначено тут"
 
 #: config/aarch64/aarch64.cc:29421
 #, gcc-internal-format
 msgid "non-local gotos in functions with SME state"
-msgstr ""
+msgstr "нелокальні переходи в функціях з станом SME"
 
 #: config/aarch64/aarch64.cc:29730
 #, gcc-internal-format
 msgid "catching non-call exceptions in functions with SME state"
-msgstr ""
+msgstr "перехоплення невикликових винятків у функціях з станом SME"
 
 #: config/alpha/alpha.cc:420
 #, gcc-internal-format
@@ -39597,21 +39313,19 @@ msgid "invalid type for %<asm%> flag output"
 msgstr "недійсний тип для виводу прапорця %<asm%>"
 
 #: config/arm/aarch-common.cc:714
-#, fuzzy, gcc-internal-format
-#| msgid "missing filename after %qs"
+#, gcc-internal-format
 msgid "missing feature or flag for %<%s%>"
-msgstr "відсутнє імʼя файлу після %qs"
+msgstr "відсутня функція або прапорець для %<%s%>"
 
 #: config/arm/aarch-common.cc:716
-#, fuzzy, gcc-internal-format
-#| msgid "invalid argument %<%s%> for %<-mharden-sls=%>"
+#, gcc-internal-format
 msgid "invalid argument %<%s%> for %<%s%>"
-msgstr "недійсний аргумент %<%s%> для %<-mharden-sls=%>"
+msgstr "недійсний аргумент %<%s%> для %<%s%>"
 
 #: config/arm/aarch-common.cc:727
 #, gcc-internal-format
 msgid "argument %<%s%> can only appear alone in %<%s%>"
-msgstr ""
+msgstr "аргумент %<%s%> може з'являтися тільки окремо в %<%s%>"
 
 #: config/arm/arm-builtins.cc:3125
 #, gcc-internal-format, gfc-internal-format
@@ -39726,10 +39440,9 @@ msgid "%<#pragma GCC arm%> requires a string parameter"
 msgstr "%<#pragma GCC arm%> потребує рядковий параметр"
 
 #: config/arm/arm-c.cc:156
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma GCC arm%> requires a string parameter"
+#, gcc-internal-format
 msgid "%<#pragma GCC arm \"arm_mve.h\"%> requires a boolean parameter"
-msgstr "%<#pragma GCC arm%> потребує рядковий параметр"
+msgstr "Директива %<#pragma GCC arm \"arm_mve.h\"%> вимагає булевий параметр"
 
 #: config/arm/arm-c.cc:160
 #, gcc-internal-format
@@ -39742,34 +39455,29 @@ msgid "this definition requires the MVE ISA extension"
 msgstr "ця визначення потребує розширення MVE ISA"
 
 #: config/arm/arm-mve-builtins.cc:560
-#, fuzzy, gcc-internal-format
-#| msgid "you can enable %qs using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
+#, gcc-internal-format
 msgid "you can enable mve.fp by using the command-line option %<-march%>, or by using the %<target%> attribute or pragma"
-msgstr "Ви можете увімкнути %qs, використовуючи параметр командного рядка %<-march%>, або за допомогою атрибуту або pragma %<target%>"
+msgstr "ви можете увімкнути mve.fp, використовуючи опцію командного рядка %<-march%>, або за допомогою атрибута %<target%> або директиви pragma"
 
 #: config/arm/arm-mve-builtins.cc:1166
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT to argument %d of %qE, but %qT is not a valid SVE element type"
+#, gcc-internal-format
 msgid "passing %qT to argument %d of %qE, but %qT is not a valid MVE element type"
-msgstr "передача %qT в аргумент %d %qE, але %qT не є дійсним типом елемента SVE"
+msgstr "передача %qT в аргумент %d функції %qE, але %qT не є дійсним типом елемента MVE"
 
 #: config/arm/arm-mve-builtins.cc:1200
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT to argument %d of %qE, which expects a single SVE vector rather than a tuple"
+#, gcc-internal-format
 msgid "passing %qT to argument %d of %qE, which expects a single MVE vector rather than a tuple"
-msgstr "передача %qT в аргумент %d %qE, який очікує один SVE вектор, а не кортеж"
+msgstr "передача %qT в аргумент %d функції %qE, яка очікує один вектор MVE замість кортежу"
 
 #: config/arm/arm-mve-builtins.cc:1220
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT to argument %d of %qE, which expects an SVE vector type"
+#, gcc-internal-format
 msgid "passing %qT to argument %d of %qE, which expects an MVE vector type"
-msgstr "передача %qT в аргумент %d %qE, який очікує тип SVE вектора"
+msgstr "передача %qT в аргумент %d функції %qE, яка очікує тип вектора MVE"
 
 #: config/arm/arm-mve-builtins.cc:1223
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT to argument %d of %qE, which expects an SVE tuple type"
+#, gcc-internal-format
 msgid "passing %qT to argument %d of %qE, which expects an MVE tuple type"
-msgstr "передача %qT в аргумент %d %qE, який очікує типу кортежу SVE"
+msgstr "передача %qT в аргумент %d функції %qE, яка очікує тип кортежу MVE"
 
 #: config/arm/arm-mve-builtins.cc:1290
 #, gcc-internal-format
@@ -40195,10 +39903,9 @@ msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/inter
 msgstr "%qs є зарезервованим ідентифікатором в AVR-LibC. Розгляньте %<#include <avr/interrupt.h>%> перед використанням макросу %qs"
 
 #: config/avr/avr.cc:1513
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is a reserved identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+#, gcc-internal-format
 msgid "%qs is a deprecated identifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> or %<#include <compat/deprecated.h>%> before using the %qs macro"
-msgstr "%qs є зарезервованим ідентифікатором в AVR-LibC. Розгляньте %<#include <avr/interrupt.h>%> перед використанням макросу %qs"
+msgstr "%qs є застарілим ідентифікатором в AVR-LibC. Розгляньте можливість використання %<#include <avr/interrupt.h>%> або %<#include <compat/deprecated.h>%> перед використанням макросу %qs"
 
 #: config/avr/avr.cc:1734
 #, gcc-internal-format
@@ -40241,10 +39948,9 @@ msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "атрибут %qE підтримується тільки для зменшених ядер Tiny"
 
 #: config/avr/avr.cc:11355
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute address out of range"
+#, gcc-internal-format
 msgid "%qE attribute address out of range 0x%x%s0x%x"
-msgstr "адреса атрибуту %qE поза межами діапазону"
+msgstr "Адреса атрибуту %qE виходить за межі діапазону 0x%x%s0x%x"
 
 #: config/avr/avr.cc:11369
 #, gcc-internal-format
@@ -40277,10 +39983,9 @@ msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr "Вказівник, що спрямовується на адресний простір %qs, повинен бути const в %s %q+D"
 
 #: config/avr/avr.cc:11666
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to variables in static storage"
+#, gcc-internal-format
 msgid "variable %q+D with attribute %qs must be located in static storage"
-msgstr "атрибут %qE застосовується тільки до змінних у статичному сховищі"
+msgstr "Змінна %q+D з атрибутом %qs повинна розташовуватися у статичному сховищі"
 
 #: config/avr/avr.cc:11717
 #, gcc-internal-format
@@ -40288,10 +39993,9 @@ msgid "variable %q+D must be const in order to be put into read-only section by
 msgstr "Змінна %q+D повинна бути константою, щоб бути поміщеною в розділ тільки для читання за допомогою %qs"
 
 #: config/avr/avr.cc:11878
-#, fuzzy, gcc-internal-format
-#| msgid "static IO declaration for %q+D needs an address"
+#, gcc-internal-format
 msgid "static attribute %qs declaration for %q+D needs an address"
-msgstr "Статичне оголошення IO для %q+D потребує адресу"
+msgstr "Оголошення статичного атрибуту %qs для %q+D потребує адреси"
 
 #: config/avr/avr.cc:11967
 #, gcc-internal-format
@@ -40314,10 +40018,9 @@ msgstr "Неініціалізована змінна %q+D поміщена в 
 #. address attribute are determined by the attribute, not by
 #. some initializer.
 #: config/avr/avr.cc:12120
-#, fuzzy, gcc-internal-format
-#| msgid "Allocatable %qs at %L cannot have an initializer"
+#, gcc-internal-format
 msgid "variable %q+D with attribute %qs must not have an initializer"
-msgstr "Змінна з можливістю виділення %qs у %L не може мати ініціалізатора"
+msgstr "змінна %q+D з атрибутом %qs не повинна мати ініціалізатора"
 
 #: config/avr/avr.cc:12173
 #, gcc-internal-format
@@ -40493,32 +40196,29 @@ msgid "invalid argument to built-in function"
 msgstr "недійсний аргумент вбудованої функції"
 
 #: config/bpf/bpf.cc:1065
-#, fuzzy, gcc-internal-format
-#| msgid "invalid argument to built-in function %s"
+#, gcc-internal-format
 msgid "invalid built-in function at expansion"
-msgstr "неприпустимий аргумент для вбудованої функції %s"
+msgstr "недійсна вбудована функція при розгортанні"
 
 #: config/bpf/bpf.cc:1287 config/bpf/bpf.cc:1290
-#, fuzzy, gcc-internal-format
-#| msgid "second argument to %<__builtin_prefetch%> must be a constant"
+#, gcc-internal-format
 msgid "could not inline call to %<__builtin_%s%>: size must be constant"
-msgstr "другий аргумент для %<__builtin_prefetch%> повинен бути константою"
+msgstr "неможливо вставити виклик до %<__builtin_%s%>: розмір повинен бути сталим"
 
 #: config/bpf/bpf.cc:1318 config/bpf/bpf.cc:1321
 #, gcc-internal-format
 msgid "could not inline call to %<__builtin_%s%>: too many bytes, use %<-minline-memops-threshold%>"
-msgstr ""
+msgstr "неможливо вбудувати виклик до %<__builtin_%s%>: забагато байтів, використовуйте %<-minline-memops-threshold%>"
 
 #: config/bpf/bpf.cc:1371 config/bpf/bpf.cc:1374
-#, fuzzy, gcc-internal-format
-#| msgid "second argument to %<__builtin_prefetch%> must be a constant"
+#, gcc-internal-format
 msgid "could not inline call to %<__builtin_memset%>: size must be constant"
-msgstr "другий аргумент для %<__builtin_prefetch%> повинен бути константою"
+msgstr "неможливо вставити виклик до %<__builtin_memset%>: розмір повинен бути сталим"
 
 #: config/bpf/bpf.cc:1402 config/bpf/bpf.cc:1405
 #, gcc-internal-format
 msgid "could not inline call to %<__builtin_memset%>: too many bytes, use %<-minline-memops-threshold%>"
-msgstr ""
+msgstr "неможливо вбудувати виклик до %<__builtin_memset%>: забагато байтів, використовуйте %<-minline-memops-threshold%>"
 
 #: config/c6x/c6x.cc:245
 #, gcc-internal-format
@@ -40732,10 +40432,9 @@ msgid "stack frame must be smaller than 64K"
 msgstr "рамка стеку повинна бути меншою за 64K"
 
 #: config/gcn/gcn.cc:175
-#, fuzzy, gcc-internal-format
-#| msgid "%<-msmart%> is incompatible with %<-mhigh-registers%>"
+#, gcc-internal-format
 msgid "%<-mxnack=on%> is incompatible with %<-march=%s%>"
-msgstr "%<-msmart%> несумісний з %<-mhigh-registers%>"
+msgstr "%<-mxnack=on%> несумісний з %<-march=%s%>"
 
 #: config/gcn/gcn.cc:292
 #, gcc-internal-format
@@ -40813,46 +40512,39 @@ msgid "%d bytes of gang-private data-share memory exhausted (increase with %<-mg
 msgstr "вичерпано %d байтів приватної памʼяті для обміну даними між групами (можна збільшити за допомогою %<-mgang-private-size=%d%>, наприклад)"
 
 #: config/gcn/mkoffload.cc:168
-#, fuzzy, gcc-internal-format
-#| msgid "deleting file %s: %m"
+#, gcc-internal-format
 msgid "deleting file %qs: %m"
-msgstr "видалення файлу %s: %m"
+msgstr "видалення файлу %qs: %m"
 
 #: config/gcn/mkoffload.cc:877
-#, fuzzy, gcc-internal-format
-#| msgid "unrecognized argument in option %qs"
+#, gcc-internal-format
 msgid "unrecognized argument in option %<-march=%s%>"
-msgstr "невпізнаний аргумент в опції %qs"
+msgstr "нерозпізнаний аргумент у опції %<-march=%s%>"
 
 #: config/gcn/mkoffload.cc:901
-#, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %<-march=%> switch are: %s"
+#, gcc-internal-format
 msgid "valid arguments to %<-march=%> are: %s"
-msgstr "допустимі аргументи для перемикача %<-march=%> це: %s"
+msgstr "дійсні аргументи для %<-march=%> є: %s"
 
 #: config/gcn/mkoffload.cc:904
-#, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %<-march=%> switch are: %s"
+#, gcc-internal-format
 msgid "valid argument to %<-march=%> is %qs"
-msgstr "допустимі аргументи для перемикача %<-march=%> це: %s"
+msgstr "дійсний аргумент для %<-march=%> є %qs"
 
 #: config/gcn/mkoffload.cc:940
-#, fuzzy, gcc-internal-format
-#| msgid "COLLECT_GCC must be set."
+#, gcc-internal-format
 msgid "%<COLLECT_GCC%> must be set"
-msgstr "необхідно встановити COLLECT_GCC."
+msgstr "%<COLLECT_GCC%> повинен бути встановлений"
 
 #: config/gcn/mkoffload.cc:986
-#, fuzzy, gcc-internal-format
-#| msgid "offload compiler %s not found"
+#, gcc-internal-format
 msgid "offload compiler %qs not found"
-msgstr "компілятор віддаленого виконання %s не знайдено"
+msgstr "компілятор для відкладеної обробки %qs не знайдено"
 
 #: config/gcn/mkoffload.cc:1008
-#, fuzzy, gcc-internal-format
-#| msgid "unrecognizable argument of option "
+#, gcc-internal-format
 msgid "unrecognizable argument of option %<"
-msgstr "нерозпізнаний аргумент опції "
+msgstr "нерозпізнаваний аргумент опції %<"
 
 #: config/gcn/mkoffload.cc:1060 config/nvptx/mkoffload.cc:753
 #, gcc-internal-format
@@ -40860,16 +40552,14 @@ msgid "either %<-fopenacc%> or %<-fopenmp%> must be set"
 msgstr "необхідно встановити або %<-fopenacc%>, або %<-fopenmp%>"
 
 #: config/gcn/mkoffload.cc:1112
-#, fuzzy, gcc-internal-format
-#| msgid "unhandled expression"
+#, gcc-internal-format
 msgid "unhandled architecture"
-msgstr "невідомий вираз"
+msgstr "необроблена архітектура"
 
 #: config/gcn/mkoffload.cc:1152 config/gcn/mkoffload.cc:1304
-#, fuzzy, gcc-internal-format
-#| msgid "cannot open %s"
+#, gcc-internal-format
 msgid "cannot open %qs"
-msgstr "не вдається відкрити %s"
+msgstr "неможливо відкрити %qs"
 
 #: config/gcn/mkoffload.cc:1290 config/nvptx/mkoffload.cc:843
 #, gcc-internal-format
@@ -41202,22 +40892,22 @@ msgstr "%<target(\"tune=x86-64\")%> застаріло; використовуй
 #: config/i386/i386-options.cc:2131
 #, gcc-internal-format
 msgid "%<-mtune=knl%> support will be removed in GCC 15"
-msgstr ""
+msgstr "Підтримка опції %<-mtune=knl%> буде вилучено в GCC 15"
 
 #: config/i386/i386-options.cc:2132
 #, gcc-internal-format
 msgid "%<target(\"tune=knl\")%> support will be removed in GCC 15"
-msgstr ""
+msgstr "Підтримка %<target(\"tune=knl\")%> буде вилучено в GCC 15"
 
 #: config/i386/i386-options.cc:2137
 #, gcc-internal-format
 msgid "%<-mtune=knm%> support will be removed in GCC 15"
-msgstr ""
+msgstr "Підтримка %<-mtune=knm%> буде вилучено в GCC 15"
 
 #: config/i386/i386-options.cc:2138
 #, gcc-internal-format
 msgid "%<target(\"tune=knm\")%> support will be removed in GCC 15"
-msgstr ""
+msgstr "Підтримка %<target(\"tune=knm\")%> буде вилучена в GCC 15"
 
 #. rep; movq isn't available in 32-bit code.
 #: config/i386/i386-options.cc:2165
@@ -41226,16 +40916,14 @@ msgid "%<-mstringop-strategy=rep_8byte%> not supported for 32-bit code"
 msgstr "%<-mstringop-strategy=rep_8byte%> не підтримується для 32-бітного коду"
 
 #: config/i386/i386-options.cc:2170
-#, fuzzy, gcc-internal-format
-#| msgid "%<-muintr%> not supported for 32-bit code"
+#, gcc-internal-format
 msgid "%<-mapxf%> is not supported for 32-bit code"
-msgstr "%<-muintr%> не підтримується для 32-бітного коду"
+msgstr "%<-mapxf%> не підтримується для 32-бітного коду"
 
 #: config/i386/i386-options.cc:2172
-#, fuzzy, gcc-internal-format
-#| msgid "%<-mlam=%> option: [u48|u57] not supported for 32-bit code"
+#, gcc-internal-format
 msgid "%<-mapx-features=%> option is not supported for 32-bit code"
-msgstr "Опція %<-mlam=%>: [u48|u57] не підтримується для 32-бітного коду"
+msgstr "Опція %<-mapx-features=%> не підтримується для 32-бітного коду"
 
 #: config/i386/i386-options.cc:2175
 #, gcc-internal-format
@@ -41275,7 +40963,7 @@ msgstr "%<-mabi=%s%> не підтримується з %<-fsanitize=thread%>"
 #: config/i386/i386-options.cc:2223
 #, gcc-internal-format
 msgid "%<-mlam=u48%> is not compatible with Hardware-assisted AddressSanitizer, override to %<-mlam=u57%>"
-msgstr ""
+msgstr "%<-mlam=u48%> не сумісний з Санітаром Адрес з апаратною підтримкою (Hardware-assisted AddressSanitizer), перевизначено на %<-mlam=u57%>"
 
 #: config/i386/i386-options.cc:2243 config/i386/i386-options.cc:2252
 #: config/i386/i386-options.cc:2264 config/i386/i386-options.cc:2275
@@ -41327,22 +41015,22 @@ msgstr "Вибраний вами процесор не підтримує на
 #: config/i386/i386-options.cc:2354
 #, gcc-internal-format
 msgid "%<-march=knl%> support will be removed in GCC 15"
-msgstr ""
+msgstr "Підтримка %<-march=knl%> буде вилучена в GCC 15"
 
 #: config/i386/i386-options.cc:2355
 #, gcc-internal-format
 msgid "%<target(\"arch=knl\")%> support will be removed in GCC 15"
-msgstr ""
+msgstr "Підтримка %<target(\"arch=knl\")%> буде вилучена в GCC 15"
 
 #: config/i386/i386-options.cc:2360
 #, gcc-internal-format
 msgid "%<-march=knm%> support will be removed in GCC 15"
-msgstr ""
+msgstr "Підтримка %<-march=knm%> буде вилучена в GCC 15"
 
 #: config/i386/i386-options.cc:2361
 #, gcc-internal-format
 msgid "%<target(\"arch=knm\")%> support will be removed in GCC 15"
-msgstr ""
+msgstr "Підтримка %<target(\"arch=knm\")%> буде вилучена в GCC 15"
 
 #: config/i386/i386-options.cc:2438
 #, gcc-internal-format
@@ -41437,7 +41125,7 @@ msgstr "%<target(\"rtd\")%> ігнорується в 64-бітному режи
 #: config/i386/i386-options.cc:2702
 #, gcc-internal-format
 msgid "%<-mno-evex512%> or %<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10.1-512 is available"
-msgstr ""
+msgstr "%<-mno-evex512%> або %<-mno-avx512XXX%> не може вимкнути інструкції AVX10, коли доступний AVX10.1-512"
 
 #. We should not emit 512 bit instructions under AVX10.1-256
 #. when EVEX512 is enabled w/o any AVX512 features enabled.
@@ -41445,22 +41133,22 @@ msgstr ""
 #: config/i386/i386-options.cc:2716
 #, gcc-internal-format
 msgid "Using %<-mevex512%> without any AVX512 features enabled together with AVX10.1 only will not enable any AVX512 or AVX10.1-512 features, using 256 as max vector size"
-msgstr ""
+msgstr "Використання %<-mevex512%> без увімкнення інструкцій AVX512 разом з AVX10.1 не активує ні інструкції AVX512, ні інструкції AVX10.1-512. Максимальна довжина вектора - 256."
 
 #: config/i386/i386-options.cc:2723 config/i386/i386-options.cc:2729
 #, gcc-internal-format
 msgid "Vector size conflicts between AVX10.1 and AVX512, using 512 as max vector size"
-msgstr ""
+msgstr "Довжина вектора конфліктує між AVX10.1 та AVX512, використовується 512 як максимальна довжина вектора."
 
 #: config/i386/i386-options.cc:2737
 #, gcc-internal-format
 msgid "%<-mno-avx512XXX%> cannot disable AVX10 instructions when AVX10 is available"
-msgstr ""
+msgstr "%<-mno-avx512XXX%> не може вимкнути інструкції AVX10, коли доступний AVX10"
 
 #: config/i386/i386-options.cc:2747
 #, gcc-internal-format
 msgid "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> cannot disable AVX512 instructions when %<-mavx512XXX%>"
-msgstr ""
+msgstr "%<-mno-avx10.1, -mno-avx10.1-256, -mno-avx10.1-512%> не може вимкнути інструкції AVX512 при %<-mavx512XXX%>"
 
 #: config/i386/i386-options.cc:2802
 #, gcc-internal-format
@@ -41565,7 +41253,7 @@ msgstr "%qs не є дійсним базовим регістром в %<-mstac
 #: config/i386/i386-options.cc:3271
 #, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not enabled by %<-fhardened%> because it was specified on the command line"
-msgstr ""
+msgstr "%<-fcf-protection=full%> не увімкнено через %<-fhardened%>, оскільки було вказано на командному рядку"
 
 #: config/i386/i386-options.cc:3280
 #, gcc-internal-format
@@ -41810,10 +41498,9 @@ msgid "the ABI of passing C structures with zero-width bit-fields has changed in
 msgstr "ABI передачі C-структур з біт-полями нульової ширини змінився в GCC %{12.1%}"
 
 #: config/i386/i386.cc:2725 config/i386/i386.cc:4094 config/i386/i386.cc:4104
-#, fuzzy, gcc-internal-format
-#| msgid "SSE register return with SSE disabled"
+#, gcc-internal-format
 msgid "SSE register return with SSE2 disabled"
-msgstr "Повернення регістра SSE з вимкненим SSE"
+msgstr "Повернення регістру SSE з вимкненим SSE2"
 
 #: config/i386/i386.cc:2727
 #, gcc-internal-format
@@ -41821,10 +41508,9 @@ msgid "SSE register return with SSE disabled"
 msgstr "Повернення регістра SSE з вимкненим SSE"
 
 #: config/i386/i386.cc:2734
-#, fuzzy, gcc-internal-format
-#| msgid "SSE register argument with SSE disabled"
+#, gcc-internal-format
 msgid "SSE register argument with SSE2 disabled"
-msgstr "Аргумент регістра SSE з вимкненим SSE"
+msgstr "Регістр SSE аргументу з вимкненим SSE2"
 
 #: config/i386/i386.cc:2736
 #, gcc-internal-format
@@ -41928,10 +41614,9 @@ msgid "the alignment of %<_Atomic %T%> fields changed in %{GCC 11.1%}"
 msgstr "вирівнювання полів %<_Atomic %T%> змінилося в %{GCC 11.1%}"
 
 #: config/i386/i386.cc:22847
-#, fuzzy, gcc-internal-format
-#| msgid "no low registers available for popping high registers"
+#, gcc-internal-format
 msgid "no register available for profiling %<-mcmodel=large%s%>"
-msgstr "немає доступних нижніх регістрів для викидання високих регістрів"
+msgstr "Немає доступного регістру для профілювання %<-mcmodel=large%s%>"
 
 #: config/i386/i386.cc:22943
 #, gcc-internal-format
@@ -41939,10 +41624,9 @@ msgid "profiling %<-mcmodel=large%> with PIC is not supported"
 msgstr "профілювання %<-mcmodel=large%> з PIC не підтримується"
 
 #: config/i386/i386.cc:23802
-#, fuzzy, gcc-internal-format
-#| msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC V13, be careful of implicit conversion between %<__bf16%> and %<short%>; a explicit bitcast may be needed here"
+#, gcc-internal-format
 msgid "%<__bfloat16%> is redefined from typedef %<short%> to real %<__bf16%> since GCC 13.1, be careful of implicit conversion between %<__bf16%> and %<short%>; an explicit bitcast may be needed here"
-msgstr "%<__bfloat16%> переозначено з typedef %<short%> на real %<__bf16%> після версії GCC V13, будьте обережні з неявним перетворенням між %<__bf16%> та %<short%>; можливо, тут потрібне явне побітове приведення"
+msgstr "З версії GCC 13.1 тип %<__bfloat16%> перевизначено з typedef %<short%> на реальний %<__bf16%>, будьте обережні з неявним перетворенням між %<__bf16%> та %<short%>; можливо, тут потрібне явне перетворення бітів"
 
 #: config/i386/i386.cc:25252
 #, gcc-internal-format
@@ -42046,10 +41730,9 @@ msgid "failed to expand built-in function"
 msgstr "не вдалося розгорнути вбудовану функцію"
 
 #: config/loongarch/loongarch-builtins.cc:3116
-#, fuzzy, gcc-internal-format
-#| msgid "built-in function %qD takes one argument only"
+#, gcc-internal-format
 msgid "built-in function %qD is not enabled"
-msgstr "вбудована функція %qD приймає лише один аргумент"
+msgstr "Вбудована функція %qD не активована"
 
 #: config/loongarch/loongarch-cpu.cc:115
 #, gcc-internal-format
@@ -42057,31 +41740,29 @@ msgid "unknown processor ID %<0x%x%>, some tuning parameters will fall back to d
 msgstr "невідомий ідентифікатор процесора %<0x%x%>, деякі параметри налаштування будуть використовувати значення за замовчуванням"
 
 #: config/loongarch/loongarch-cpu.cc:144
-#, fuzzy, gcc-internal-format
-#| msgid "unknown base architecture %<0x%x%>, %qs failed"
+#, gcc-internal-format
 msgid "unknown native base architecture %<0x%x%>, %qs failed"
-msgstr "невідома базова архітектура %<0x%x%>, %qs не вдалося"
+msgstr "Невідома базова архітектура %<0x%x%>, операція %qs не вдалася"
 
 #: config/loongarch/loongarch-cpu.cc:173
-#, fuzzy, gcc-internal-format
-#| msgid "unknown FPU type %<0x%x%>, %qs failed"
+#, gcc-internal-format
 msgid "unknown native FPU type %<0x%x%>, %qs failed"
-msgstr "невідомий тип FPU %<0x%x%>, %qs не вдалося"
+msgstr "Невідомий тип вбудованої FPU %<0x%x%>, операція %qs не вдалася"
 
 #: config/loongarch/loongarch-cpu.cc:180
 #, gcc-internal-format
 msgid "floating-point unit %qs differs from PRID preset %qs"
-msgstr ""
+msgstr "одиниця з плаваючою комою %qs відрізняється від наперед заданого значення PRID %qs"
 
 #: config/loongarch/loongarch-cpu.cc:204
 #, gcc-internal-format
 msgid "unknown SIMD extension (%qs disabled while %qs is enabled), disabling SIMD"
-msgstr ""
+msgstr "невідоме розширення SIMD (%qs вимкнуто, тоді як %qs увімкнено), вимикаємо SIMD"
 
 #: config/loongarch/loongarch-cpu.cc:242
 #, gcc-internal-format
 msgid "detected base architecture %qs, but some of its features are not detected; the detected base architecture may be unreliable, only detected features will be enabled"
-msgstr ""
+msgstr "Виявлено базову архітектуру %qs, але деякі її функції не вдалося визначити. Виявлена архітектура може бути ненадійною, доступні лише виявлені функції."
 
 #: config/loongarch/loongarch-opts.cc:235
 #, gcc-internal-format
@@ -42102,18 +41783,17 @@ msgstr "%qs не працює на крос-компіляторі"
 #: config/loongarch/loongarch-opts.cc:375
 #, gcc-internal-format
 msgid "enabling %qs promotes %<%s%s%> to %<%s%s%>"
-msgstr ""
+msgstr "увімкнення %qs підвищує %<%s%s%> до %<%s%s%>"
 
 #: config/loongarch/loongarch-opts.cc:387
 #, gcc-internal-format
 msgid "%qs is disabled by %<-m%s%>, because it requires %<%s%s%>"
-msgstr ""
+msgstr "%qs вимкнено %<-m%s%>, тому що потребує %<%s%s%> "
 
 #: config/loongarch/loongarch-opts.cc:399
-#, fuzzy, gcc-internal-format
-#| msgid "switch %<-mcpu=%s%> conflicts with switch %<-march=%s%>"
+#, gcc-internal-format
 msgid "%<-m%s=%s%> conflicts with %qs, which requires %<%s%s%>"
-msgstr "перемикач %<-mcpu=%s%> конфліктує з перемикачем %<-march=%s%>"
+msgstr "Параметр %<-m%s=%s%> конфліктує з %qs, який вимагає %<%s%s%>"
 
 #: config/loongarch/loongarch-opts.cc:443
 #, gcc-internal-format
@@ -42333,10 +42013,9 @@ msgid "%qE attribute requires a string argument"
 msgstr "Атрибут %qE вимагає рядковий аргумент"
 
 #: config/mips/mips.cc:1340
-#, fuzzy, gcc-internal-format
-#| msgid "argument to %qE attribute is neither zero, nor one"
+#, gcc-internal-format
 msgid "argument to %qE attribute is neither no, pcrel nor yes"
-msgstr "Аргумент атрибуту %qE не є нулем або одиницею"
+msgstr "Аргумент атрибута %qE не є ні no, ні pcrel, ні yes"
 
 #: config/mips/mips.cc:1506 config/mips/mips.cc:1510
 #, gcc-internal-format
@@ -42431,10 +42110,9 @@ msgid "MSA MIPS16 code"
 msgstr "код MSA MIPS16"
 
 #: config/mips/mips.cc:20082
-#, fuzzy, gcc-internal-format
-#| msgid "%<-mno-gpopt%> needs %<-mexplicit-relocs%>"
+#, gcc-internal-format
 msgid "MIPS16 requires %<-mexplicit-relocs%>"
-msgstr "%<-mno-gpopt%> потребує %<-mexplicit-relocs%>"
+msgstr "Для MIPS16 необхідно використовувати параметр %<-mexplicit-relocs%>"
 
 #: config/mips/mips.cc:20273 config/mips/mips.cc:20278
 #: config/mips/mips.cc:20368 config/mips/mips.cc:20370
@@ -43300,10 +42978,9 @@ msgid "PTX version (%<-mptx%>) needs to be at least %s to support selected %<-mi
 msgstr "версія PTX (%<-mptx%>) повинна бути не менше %s для підтримки вибраного %<-misa%> (sm_%s)"
 
 #: config/nvptx/nvptx.cc:340
-#, fuzzy, gcc-internal-format
-#| msgid "multiple %<-mcpu=%> options specified"
+#, gcc-internal-format
 msgid "%<-march=%> must be specified"
-msgstr "вказано кілька опцій %<-mcpu=%>"
+msgstr "Параметр %<-march=%> повинен бути вказаний"
 
 #: config/nvptx/nvptx.cc:363
 #, gcc-internal-format
@@ -43487,68 +43164,62 @@ msgstr "невідома опція %qs для %<#pragma riscv intrinsic%>"
 #: config/riscv/riscv-target-attr.cc:121
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: must start with + or rv"
-msgstr ""
+msgstr "неочікуваний arch для атрибута %<target()%>: повинен починатися з + або rv"
 
 #: config/riscv/riscv-target-attr.cc:132
 #, gcc-internal-format
 msgid "unexpected arch for %<target()%> attribute: bad string found %<%s%>"
-msgstr ""
+msgstr "несподівана архітектура для атрибута %<target()%>: знайдено некоректний рядок %<%s%>"
 
 #: config/riscv/riscv-target-attr.cc:159
 #, gcc-internal-format
 msgid "%<target()%> attribute: arch appears more than once"
-msgstr ""
+msgstr "Атрибут %<target()%>: arch повторюється"
 
 #: config/riscv/riscv-target-attr.cc:170
 #, gcc-internal-format
 msgid "%<target()%> attribute: cpu appears more than once"
-msgstr ""
+msgstr "Атрибут %<target()%>: cpu повторюється"
 
 #: config/riscv/riscv-target-attr.cc:177
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown CPU %qs"
-msgstr ""
+msgstr "Атрибут %<target()%>: нерозпізнаний CPU %qs"
 
 #: config/riscv/riscv-target-attr.cc:198
-#, fuzzy, gcc-internal-format
-#| msgid "target attribute is not supported on this machine"
+#, gcc-internal-format
 msgid "%<target()%> attribute: tune appears more than once"
-msgstr "атрибут цільової платформи не підтримується на цій машині"
+msgstr "Атрибут %<target()%>: параметр tune зустрічається більше одного разу"
 
 #: config/riscv/riscv-target-attr.cc:204
 #, gcc-internal-format
 msgid "%<target()%> attribute: unknown TUNE %qs"
-msgstr ""
+msgstr "Атрибут %<target()%>: невідомий TUNE %qs"
 
 #: config/riscv/riscv-target-attr.cc:253
-#, fuzzy, gcc-internal-format
-#| msgid "malformed %<target()%> pragma or attribute"
+#, gcc-internal-format
 msgid "malformed %<target()%> attribute"
-msgstr "некоректна директива або атрибут %<target()%>"
+msgstr "Неправильно сформований атрибут %<target()%>"
 
 #: config/riscv/riscv-target-attr.cc:267
-#, fuzzy, gcc-internal-format
-#| msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
+#, gcc-internal-format
 msgid "attribute %<target(\"%s\")%> does not accept an argument"
-msgstr "директива або атрибут %<target(\"%s\")%> не приймає аргумент"
+msgstr "Атрибут %<target(\"%s\")%> не приймає аргументів"
 
 #: config/riscv/riscv-target-attr.cc:285
-#, fuzzy, gcc-internal-format
-#| msgid "unknown attribute %qs"
+#, gcc-internal-format
 msgid "Got unknown attribute %<target(\"%s\")%>"
-msgstr "невідомий атрибут %qs"
+msgstr "Отримано невідомий атрибут %<target(\"%s\")%>"
 
 #: config/riscv/riscv-target-attr.cc:368
-#, fuzzy, gcc-internal-format
-#| msgid "malformed %<target(\"%s\")%> pragma or attribute"
+#, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> attribute"
-msgstr "некоректна прагма або атрибут %<target(\"%s\")%>"
+msgstr "Неправильно сформований атрибут %<target(\"%s\")%>"
 
 #: config/riscv/riscv-vector-builtins.cc:4276
-#, fuzzy, gcc-internal-format
-#| msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd]"
+#, gcc-internal-format
 msgid "passing %wd to argument %d of %qE, which expects a value in the range [%wd, %wd] or %wd"
-msgstr "передача %wd аргументу %d %qE, який очікує значення в діапазоні [%wd, %wd]"
+msgstr "Передача значення %wd в аргумент %d функції %qE, яка очікує значення в діапазоні [%wd, %wd] або %wd"
 
 #: config/riscv/riscv-vector-builtins.cc:4488
 #, gcc-internal-format
@@ -43601,40 +43272,34 @@ msgid "capture by copy of RVV type %qT"
 msgstr "захоплення копією типу RVV %qT"
 
 #: config/riscv/riscv-vector-builtins.cc:4645
-#, fuzzy, gcc-internal-format
-#| msgid "this definition requires the MVE ISA extension"
+#, gcc-internal-format
 msgid "built-in function %qE requires the zvfhmin or zvfh ISA extension"
-msgstr "ця визначення потребує розширення MVE ISA"
+msgstr "Вбудована функція %qE вимагає розширення ISA звфгмін або звфг"
 
 #: config/riscv/riscv-vector-builtins.cc:4655
-#, fuzzy, gcc-internal-format
-#| msgid "this definition requires the MVE ISA extension"
+#, gcc-internal-format
 msgid "built-in function %qE requires the zve32f, zve64f, zve64d or v ISA extension"
-msgstr "ця визначення потребує розширення MVE ISA"
+msgstr "Вбудована функція %qE вимагає розширення ISA зве32ф, зве64ф, зве64д або v"
 
 #: config/riscv/riscv-vector-builtins.cc:4665
-#, fuzzy, gcc-internal-format
-#| msgid "this definition requires the MVE ISA extension"
+#, gcc-internal-format
 msgid "built-in function %qE requires the zve64d or v ISA extension"
-msgstr "ця визначення потребує розширення MVE ISA"
+msgstr "Вбудована функція %qE вимагає розширення ISA зве64д або v"
 
 #: config/riscv/riscv-vector-builtins.cc:4674
-#, fuzzy, gcc-internal-format
-#| msgid "this definition requires the MVE ISA extension"
+#, gcc-internal-format
 msgid "built-in function %qE requires the zve64x, zve64f, zve64d or v ISA extension"
-msgstr "ця визначення потребує розширення MVE ISA"
+msgstr "Вбудована функція %qE вимагає розширення ISA зве64х, зве64ф, зве64д або v"
 
 #: config/riscv/riscv-vector-builtins.cc:4694
-#, fuzzy, gcc-internal-format
-#| msgid "this definition requires the MVE ISA extension"
+#, gcc-internal-format
 msgid "built-in function %qE requires the %qs ISA extension"
-msgstr "ця визначення потребує розширення MVE ISA"
+msgstr "вбудована функція %qE вимагає розширення %qs ISA"
 
 #: config/riscv/riscv-vector-builtins.cc:4747
-#, fuzzy, gcc-internal-format
-#| msgid "no matching function for call to %<%s(%A)%>"
+#, gcc-internal-format
 msgid "no matching function call to %qE with empty arguments"
-msgstr "немає відповідної функції для виклику %<%s(%A)%>"
+msgstr "немає відповідного виклику функції до %qE з порожніми аргументами"
 
 #: config/riscv/riscv.cc:723
 #, gcc-internal-format
@@ -43657,52 +43322,44 @@ msgid "ABI for flattened struct with zero-length bit-fields changed in GCC 10"
 msgstr "ABI для структури зі згладженими полями нульової довжини змінився в GCC 10"
 
 #: config/riscv/riscv.cc:5370
-#, fuzzy, gcc-internal-format
-#| msgid "SVE type %qT cannot be passed to an unprototyped function"
+#, gcc-internal-format
 msgid "RVV type %qT cannot be passed to an unprototyped function"
-msgstr "Тип SVE %qT не може бути переданий у функцію без прототипу"
+msgstr "Тип RVV %qT не може бути переданий у функцію без прототипу"
 
 #: config/riscv/riscv.cc:5623
-#, fuzzy, gcc-internal-format
-#| msgid "%qE requires the SVE ISA extension"
+#, gcc-internal-format
 msgid "%s %qT requires the V ISA extension"
-msgstr "%qE вимагає розширення SVE ISA"
+msgstr "%s %qT вимагає розширення V ISA"
 
 #: config/riscv/riscv.cc:5635
-#, fuzzy, gcc-internal-format
-#| msgid "%qE requires the SVE ISA extension"
+#, gcc-internal-format
 msgid "%s %qT requires the zve64x, zve64f, zve64d or v ISA extension"
-msgstr "%qE вимагає розширення SVE ISA"
+msgstr "%s %qT вимагає розширення zve64x, zve64f, zve64d або v ISA"
 
 #: config/riscv/riscv.cc:5646
-#, fuzzy, gcc-internal-format
-#| msgid "%qE requires the SVE ISA extension"
+#, gcc-internal-format
 msgid "%s %qT requires the zvfhmin or zvfh ISA extension"
-msgstr "%qE вимагає розширення SVE ISA"
+msgstr "%s %qT вимагає розширення zvfhmin або zvfh ISA"
 
 #: config/riscv/riscv.cc:5655
-#, fuzzy, gcc-internal-format
-#| msgid "%qE requires the SVE ISA extension"
+#, gcc-internal-format
 msgid "%s %qT requires the zve32f, zve64f, zve64d or v ISA extension"
-msgstr "%qE вимагає розширення SVE ISA"
+msgstr "%s %qT вимагає розширення zve32f, zve64f, zve64d або v ISA"
 
 #: config/riscv/riscv.cc:5664
-#, fuzzy, gcc-internal-format
-#| msgid "%qE requires the SVE ISA extension"
+#, gcc-internal-format
 msgid "%s %qT requires the zve64d or v ISA extension"
-msgstr "%qE вимагає розширення SVE ISA"
+msgstr "%s %qT вимагає розширення zve64d або v ISA"
 
 #: config/riscv/riscv.cc:5674
-#, fuzzy, gcc-internal-format
-#| msgid "%qs requires the %qs option and either the %qs or %qs option"
+#, gcc-internal-format
 msgid "%s %qT requires the minimal vector length %qd but %qd is given"
-msgstr "%qs потребує опцію %qs, а також опцію %qs або %qs"
+msgstr "%s %qT вимагає мінімальної довжини вектора %qd, але задано %qd"
 
 #: config/riscv/riscv.cc:5729
-#, fuzzy, gcc-internal-format
-#| msgid "calls to functions of type %qT require the SVE ISA extension"
+#, gcc-internal-format
 msgid "function attribute %qs requires the V ISA extension"
-msgstr "виклики функцій типу %qT вимагають розширення SVE ISA"
+msgstr "атрибут функції %qs вимагає розширення V ISA"
 
 #: config/riscv/riscv.cc:5823
 #, gcc-internal-format
@@ -43712,24 +43369,22 @@ msgstr "аргумент атрибуту %qE не є %<\"user\"%>, %<\"supervis
 #: config/riscv/riscv.cc:5846
 #, gcc-internal-format
 msgid "%qs is only supported when %<-mrvv-vector-bits=zvl%> is specified"
-msgstr ""
+msgstr "%qs працює лише коли вказано %<-mrvv-vector-bits=zvl%>"
 
 #: config/riscv/riscv.cc:5855
-#, fuzzy, gcc-internal-format
-#| msgid "%qs applied to non-SVE type %qT"
+#, gcc-internal-format
 msgid "%qs applied to non-RVV type %qT"
-msgstr "%qs застосовується до не-SVE типу %qT"
+msgstr "%qs застосовано до не-RVV типу %qT"
 
 #: config/riscv/riscv.cc:5863
-#, fuzzy, gcc-internal-format
-#| msgid "%qs requires an integer constant expression"
+#, gcc-internal-format
 msgid "%qs requires an integer constant"
-msgstr "%qs вимагає цілочисловий константний вираз"
+msgstr "%qs вимагає цілочисельної константи"
 
 #: config/riscv/riscv.cc:5873
 #, gcc-internal-format
 msgid "invalid RVV vector size %qd, expected size is %qd based on LMUL of type and %qs"
-msgstr ""
+msgstr "Неправильний розмір вектора RVV %qd, очікуваний розмір %qd на основі LMUL типу і %qs"
 
 #: config/riscv/riscv.cc:9213
 #, gcc-internal-format
@@ -43739,19 +43394,17 @@ msgstr "%<-mdiv%> вимагає %<-march%>, щоб підкоритися ро
 #: config/riscv/riscv.cc:9255
 #, gcc-internal-format
 msgid "Current RISC-V GCC does not support VLEN greater than 4096bit for 'V' Extension"
-msgstr ""
+msgstr "Поточний RISC-V GCC не підтримує VLEN понад 4096 біт для розширення 'V'"
 
 #: config/riscv/riscv.cc:9261
-#, fuzzy, gcc-internal-format
-#| msgid "target CPU does not support ARM mode"
+#, gcc-internal-format
 msgid "Current RISC-V GCC does not support RVV in big-endian mode"
-msgstr "цільовий процесор не підтримує режим ARM"
+msgstr "Поточний RISC-V GCC не підтримує RVV у режимі великого кінця"
 
 #: config/riscv/riscv.cc:9287 config/riscv/riscv.cc:9290
-#, fuzzy, gcc-internal-format
-#| msgid "code model %qs with %<-f%s%>"
+#, gcc-internal-format
 msgid "code model %qs with %qs"
-msgstr "модель коду %qs з %<-f%s%>"
+msgstr "модель коду %qs з %qs"
 
 #: config/riscv/riscv.cc:9319
 #, gcc-internal-format
@@ -43764,16 +43417,14 @@ msgid "rv32e requires ilp32e ABI"
 msgstr "rv32e вимагає ABI ilp32e"
 
 #: config/riscv/riscv.cc:9328
-#, fuzzy, gcc-internal-format
-#| msgid "rv32e requires ilp32e ABI"
+#, gcc-internal-format
 msgid "rv64e requires lp64e ABI"
-msgstr "rv32e вимагає ABI ilp32e"
+msgstr "rv64e вимагає lp64e ABI"
 
 #: config/riscv/riscv.cc:9335
-#, fuzzy, gcc-internal-format
-#| msgid "z*inx requires ABI ilp32, ilp32e or lp64"
+#, gcc-internal-format
 msgid "z*inx requires ABI ilp32, ilp32e, lp64 or lp64e"
-msgstr "z*inx вимагає ABI ilp32, ilp32e або lp64"
+msgstr "z*inx вимагає ABI ilp32, ilp32e, lp64 або lp64e"
 
 #: config/riscv/riscv.cc:9339
 #, gcc-internal-format
@@ -44263,13 +43914,12 @@ msgstr "невідома опція для %<%s=%s%>"
 #: config/rs6000/rs6000.cc:4833
 #, gcc-internal-format
 msgid "%<-mrop-protect%> requires %<-mcpu=power8%> or later"
-msgstr ""
+msgstr "%<-mrop-protect%> вимагає %<-mcpu=power8%> або пізнішу версію"
 
 #: config/rs6000/rs6000.cc:4837
-#, fuzzy, gcc-internal-format
-#| msgid "%qs requires the ELFv2 ABI"
+#, gcc-internal-format
 msgid "%<-mrop-protect%> requires the ELFv2 ABI"
-msgstr "%qs потребує ELFv2 ABI"
+msgstr "%<-mrop-protect%> вимагає ELFv2 ABI"
 
 #: config/rs6000/rs6000.cc:4855
 #, gcc-internal-format
@@ -44690,28 +44340,24 @@ msgid "value %qs is not supported by attribute %<target%>"
 msgstr "значення %qs не підтримується атрибутом %<target%>"
 
 #: config/s390/s390.cc:17553
-#, fuzzy, gcc-internal-format
-#| msgid "invalid constraints"
+#, gcc-internal-format
 msgid "invalid cc output constraint: %qs"
-msgstr "недійсні обмеження"
+msgstr "неприпустиме обмеження виводу cc: %qs"
 
 #: config/s390/s390.cc:17558
-#, fuzzy, gcc-internal-format
-#| msgid "double constants not supported"
+#, gcc-internal-format
 msgid "multiple cc output constraints not supported"
-msgstr "подвійні константи не підтримуються"
+msgstr "багатократні обмеження виводу cc не підтримуються"
 
 #: config/s390/s390.cc:17563
-#, fuzzy, gcc-internal-format
-#| msgid "%<asm%> specifier for variable %qE conflicts with %<asm%> clobber list"
+#, gcc-internal-format
 msgid "%<asm%> specifier for cc output conflicts with %<asm%> clobber list"
-msgstr "специфікатор %<asm%> для змінної %qE конфліктує зі списком %<asm%> clobber"
+msgstr "специфікатор %<asm%> для виводу cc конфліктує з %<asm%> списком забруднення"
 
 #: config/s390/s390.cc:17569
-#, fuzzy, gcc-internal-format
-#| msgid "invalid type for make function"
+#, gcc-internal-format
 msgid "invalid type for cc output constraint"
-msgstr "недійсний тип для функції make"
+msgstr "неприпустимий тип для обмеження виводу cc"
 
 #: config/sh/sh.cc:936
 #, gcc-internal-format
@@ -45274,10 +44920,9 @@ msgid "declaration of %q+D shadows a built-in function"
 msgstr "оголошення %q+D затіняє вбудовану функцію"
 
 #: c/c-decl.cc:2153
-#, fuzzy, gcc-internal-format
-#| msgid "redeclaration of enumerator %q+D"
+#, gcc-internal-format
 msgid "conflicting redeclaration of enumerator %q+D"
-msgstr "перевизначення перелічування %q+D"
+msgstr "конфліктна повторна декларація елемента перерахування %q+D"
 
 #: c/c-decl.cc:2160
 #, gcc-internal-format
@@ -45527,7 +45172,7 @@ msgstr "перехід до області видимості ідентифік
 #: c/c-decl.cc:4093
 #, gcc-internal-format
 msgid "jump skips OpenMP %<allocate%> allocation"
-msgstr ""
+msgstr "стрибок пропускає виділення пам'яті OpenMP %<allocate%>"
 
 #: c/c-decl.cc:4096
 #, gcc-internal-format
@@ -45560,10 +45205,9 @@ msgid "traditional C lacks a separate namespace for labels, identifier %qE confl
 msgstr "традиційна мова C не має окремого простору імен для міток, ідентифікатор %qE конфліктує"
 
 #: c/c-decl.cc:4379
-#, fuzzy, gcc-internal-format
-#| msgid "switch jumps over variable initialization"
+#, gcc-internal-format
 msgid "switch jumps over OpenMP %<allocate%> allocation"
-msgstr "перехід у switch пропускає ініціалізацію змінної"
+msgstr "перемикання перескакує через виділення пам'яті OpenMP %<allocate%>"
 
 #: c/c-decl.cc:4385
 #, gcc-internal-format
@@ -45733,10 +45377,9 @@ msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> дозволено тільки в області прототипу функції"
 
 #: c/c-decl.cc:5477 cp/decl2.cc:1852 cp/name-lookup.cc:8861
-#, fuzzy, gcc-internal-format
-#| msgid "%<omp::%E%> not allowed to be specified in this context"
+#, gcc-internal-format
 msgid "%<omp::%s%> not allowed to be specified in this context"
-msgstr "%<omp::%E%> не може бути вказано в цьому контексті"
+msgstr "%<omp::%s%> не дозволяється вказувати в цьому контексті"
 
 #: c/c-decl.cc:5557
 #, gcc-internal-format
@@ -46361,10 +46004,9 @@ msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 не підтримує %<_Noreturn%>"
 
 #: c/c-decl.cc:8206
-#, fuzzy, gcc-internal-format
-#| msgid "variable previously declared %<static%> redeclared %<extern%>"
+#, gcc-internal-format
 msgid "function previously declared %<static%> redeclared %<extern%>"
-msgstr "змінна, яка раніше була оголошена як %<static%>, знову оголошена як %<extern%>"
+msgstr "функція раніше оголошена як %<static%>, повторно оголошена як %<extern%>"
 
 #: c/c-decl.cc:8224
 #, gcc-internal-format
@@ -46572,10 +46214,9 @@ msgid "flexible array member in a struct with no named members"
 msgstr "гнучкий масив як член структури без іменованих членів"
 
 #: c/c-decl.cc:9599
-#, fuzzy, gcc-internal-format
-#| msgid "flexible array member not at end of struct"
+#, gcc-internal-format
 msgid "structure containing a flexible array member is not at the end of another structure"
-msgstr "гнучкий масив не є останнім членом структури"
+msgstr "структура, що містить гнучкий елемент масиву, не знаходиться в кінці іншої структури"
 
 #: c/c-decl.cc:9622
 #, gcc-internal-format
@@ -46593,16 +46234,14 @@ msgid "union cannot be made transparent"
 msgstr "обʼєднання не може бути зроблене прозорим"
 
 #: c/c-decl.cc:9766
-#, fuzzy, gcc-internal-format
-#| msgid "redefinition of typedef %q+D with variably modified type"
+#, gcc-internal-format
 msgid "redefinition of struct or union %qT with variably modified type"
-msgstr "перевизначення typedef %q+D зі зміненим типом"
+msgstr "повторно визначена структура або об'єднання %qT зі змінним типом модифікації"
 
 #: c/c-decl.cc:9769
-#, fuzzy, gcc-internal-format
-#| msgid "redefinition of %<struct %E%>"
+#, gcc-internal-format
 msgid "redefinition of struct or union %qT"
-msgstr "перевизначення %<struct %E%>"
+msgstr "повторно визначена структура або об'єднання %qT"
 
 #: c/c-decl.cc:9938
 #, gcc-internal-format
@@ -46635,10 +46274,9 @@ msgid "enumeration values exceed range of %qs"
 msgstr "значення перелічування перевищують діапазон %qs"
 
 #: c/c-decl.cc:10219
-#, fuzzy, gcc-internal-format
-#| msgid "nested redefinition of %<enum %E%>"
+#, gcc-internal-format
 msgid "conflicting redefinition of enum %qT"
-msgstr "вкладене перевизначення %<enum %E%>"
+msgstr "конфліктне повторення визначення перерахування %qT"
 
 #: c/c-decl.cc:10251 c/c-decl.cc:10267
 #, gcc-internal-format
@@ -46666,10 +46304,9 @@ msgid "enumerator value outside the range of %qs"
 msgstr "значення перелічування поза діапазоном %qs"
 
 #: c/c-decl.cc:10327
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C restricts enumerator values to range of %<int%> before C2X"
+#, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%> before C23"
-msgstr "ISO C обмежує значення перелічування діапазоном %<int%> до C2X"
+msgstr "Мова ISO C обмежує значення перерахувань діапазоном %<int%> до стандарту C23"
 
 #: c/c-decl.cc:10528 cp/decl.cc:5990 cp/decl.cc:17806
 #, gcc-internal-format
@@ -46732,10 +46369,9 @@ msgid "traditional C rejects ISO C style function definitions"
 msgstr "традиційне C відкидає визначення функцій у стилі ISO C"
 
 #: c/c-decl.cc:10782
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C does not support omitting parameter names in function definitions before C2X"
+#, gcc-internal-format
 msgid "ISO C does not support omitting parameter names in function definitions before C23"
-msgstr "ISO C не підтримує пропуск імен параметрів у визначеннях функцій до C2X"
+msgstr "Мова ISO C не підтримує пропуск імен параметрів у визначенні функцій до стандарту C23"
 
 #: c/c-decl.cc:10822 c/c-decl.cc:10826
 #, gcc-internal-format
@@ -46940,10 +46576,9 @@ msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 не підтримує булеві типи"
 
 #: c/c-decl.cc:12537
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C does not support the %<_Float%d%s%> type"
+#, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type before C23"
-msgstr "ISO C не підтримує тип %<_Float%d%s%>"
+msgstr "Мова ISO C не підтримує тип %<_Float%d%s%> до стандарту C23"
 
 #: c/c-decl.cc:12588 cp/parser.cc:20288
 #, gcc-internal-format
@@ -46951,10 +46586,9 @@ msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<_Float%d%s%> не підтримується для цільової платформи"
 
 #: c/c-decl.cc:12659
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C does not support decimal floating-point before C2X"
+#, gcc-internal-format
 msgid "ISO C does not support decimal floating-point before C23"
-msgstr "ISO C не підтримує десяткові дробові числа до C2X"
+msgstr "Мова ISO C не підтримує десяткові дробові числа до стандарту C23"
 
 #: c/c-decl.cc:12683 c/c-decl.cc:13060 c/c-parser.cc:10626
 #, gcc-internal-format
@@ -46967,21 +46601,19 @@ msgid "ISO C does not support fixed-point types"
 msgstr "ISO C не підтримує типи з фіксованою комою"
 
 #: c/c-decl.cc:12714
-#, fuzzy, gcc-internal-format
-#| msgid "case label is not an integer constant expression"
+#, gcc-internal-format
 msgid "%<_BitInt%> argument is not an integer constant expression"
-msgstr "мітка case не є цілочисельним константним виразом"
+msgstr "Аргумент %<_BitInt%> не є цілочисельним константним виразом"
 
 #: c/c-decl.cc:12720
-#, fuzzy, gcc-internal-format
-#| msgid "enumerator value for %qE is not an integer constant expression"
+#, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is not a positive integer constant expression"
-msgstr "значення перелічування для %qE не є цілочисельним константним виразом"
+msgstr "Аргумент %<_BitInt%> %qE не є додатним цілочисельним константним виразом"
 
 #: c/c-decl.cc:12727
 #, gcc-internal-format
 msgid "%<_BitInt%> argument %qE is larger than %<BITINT_MAXWIDTH%> %qd"
-msgstr ""
+msgstr "Аргумент %<_BitInt%> %qE перевищує %<BITINT_MAXWIDTH%> %qd"
 
 #: c/c-decl.cc:12775
 #, gcc-internal-format
@@ -47081,10 +46713,9 @@ msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не підтримує просте значення %<complex%>, що означає %<double complex%>"
 
 #: c/c-decl.cc:13083
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C does not support %<auto%> type deduction before C2X"
+#, gcc-internal-format
 msgid "ISO C does not support %<auto%> type deduction before C23"
-msgstr "ISO C не підтримує виведення типу %<auto%> до C2X"
+msgstr "Мова ISO C не підтримує визначення типу за допомогою %<auto%> до стандарту C23"
 
 #: c/c-decl.cc:13112
 #, gcc-internal-format
@@ -47097,16 +46728,14 @@ msgid "ISO C does not support complex integer types"
 msgstr "ISO C не підтримує комплексні цілі типи"
 
 #: c/c-decl.cc:13323
-#, fuzzy, gcc-internal-format
-#| msgid "Fixed line length must be at least seven"
+#, gcc-internal-format
 msgid "%<signed _BitInt%> argument must be at least 2"
-msgstr "Фіксована довжина рядка повинна бути щонайменше сім"
+msgstr "Аргумент %<signed _BitInt%> має бути щонайменше 2"
 
 #: c/c-decl.cc:13332
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C++ does not support %<__int%d%> for %qs"
+#, gcc-internal-format
 msgid "ISO C does not support %<%s_BitInt(%d)%> before C23"
-msgstr "ISO C++ не підтримує %<__int%d%> для %qs"
+msgstr "Мова ISO C не підтримує %<%s_BitInt(%d)%> до стандарту C23"
 
 #: c/c-decl.cc:13631 cp/semantics.cc:6387
 #, gcc-internal-format
@@ -47393,10 +47022,9 @@ msgid "%<__GIMPLE%> only valid with %<-fgimple%>"
 msgstr "%<__GIMPLE%> дійсний лише з %<-fgimple%>"
 
 #: c/c-parser.cc:3699
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C does not support specifying %<enum%> underlying types before C2X"
+#, gcc-internal-format
 msgid "ISO C does not support specifying %<enum%> underlying types before C23"
-msgstr "ISO C не підтримує вказування підставних типів %<enum%> до C2X"
+msgstr "Мова ISO C не підтримує вказання базових типів для %<enum%> до стандарту C23"
 
 #: c/c-parser.cc:3708
 #, gcc-internal-format
@@ -47503,10 +47131,9 @@ msgid "expected identifier or %<(%>"
 msgstr "очікується ідентифікатор або %<(%>"
 
 #: c/c-parser.cc:4920
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C requires a named argument before %<...%> before C2X"
+#, gcc-internal-format
 msgid "ISO C requires a named argument before %<...%> before C23"
-msgstr "ISO C вимагає іменованого аргументу перед %<...%> до C2X"
+msgstr "ISO C вимагає іменованого аргументу перед %<...%> перед C23"
 
 #: c/c-parser.cc:5045
 #, gcc-internal-format
@@ -47539,10 +47166,9 @@ msgid "%qE attribute does not take any arguments"
 msgstr "атрибут %qE не приймає жодних аргументів"
 
 #: c/c-parser.cc:5891
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C does not support %<[[]]%> attributes before C2X"
+#, gcc-internal-format
 msgid "ISO C does not support %<[[]]%> attributes before C23"
-msgstr "ISO C не підтримує атрибути %<[[]]%> до C2X"
+msgstr "ISO C не підтримує атрибути %<[[]]%> перед C23"
 
 #: c/c-parser.cc:6104 c/c-parser.cc:6167 c/c-typeck.cc:8824
 #, gcc-internal-format
@@ -47550,10 +47176,9 @@ msgid "variable-sized object may not be initialized except with an empty initial
 msgstr "обʼєкт змінної розмірності може бути ініціалізований лише з порожнім ініціалізатором"
 
 #: c/c-parser.cc:6161
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C forbids empty initializer braces before C2X"
+#, gcc-internal-format
 msgid "ISO C forbids empty initializer braces before C23"
-msgstr "ISO C забороняє порожні фігурні дужки ініціалізатора до C2X"
+msgstr "ISO C забороняє пусті фігурні дужки ініціалізатора перед C23"
 
 #: c/c-parser.cc:6225
 #, gcc-internal-format
@@ -47576,22 +47201,19 @@ msgid "obsolete use of designated initializer without %<=%>"
 msgstr "застаріле використання призначеного ініціалізатора без %<=%>"
 
 #: c/c-parser.cc:6565 cp/parser.cc:13308
-#, fuzzy, gcc-internal-format
-#| msgid "no valid clauses specified in %<#pragma acc declare%>"
+#, gcc-internal-format
 msgid "inner loops must be perfectly nested in %<#pragma acc loop%>"
-msgstr "не вказано жодних дійсних замикань в %<#pragma acc declare%>"
+msgstr "внутрішні цикли повинні бути ідеально вкладені в %<#pragma acc loop%>"
 
 #: c/c-parser.cc:6572 cp/parser.cc:13315
-#, fuzzy, gcc-internal-format
-#| msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
+#, gcc-internal-format
 msgid "inner loops must be perfectly nested with %<ordered%> clause"
-msgstr "%<ordered%> область повинна бути тісно вкладена всередині області циклу з %<ordered%> замиканням"
+msgstr "внутрішні цикли повинні бути ідеально вкладені з клаузою %<ordered%>"
 
 #: c/c-parser.cc:6579 cp/parser.cc:13322
-#, fuzzy, gcc-internal-format
-#| msgid "%<nogroup%> clause must not be used together with %<reduction%> clause"
+#, gcc-internal-format
 msgid "inner loops must be perfectly nested with %<reduction%> %<inscan%> clause"
-msgstr "умову %<nogroup%> не слід використовувати разом з умовою %<reduction%>"
+msgstr "внутрішні цикли повинні бути ідеально вкладені з клаузою %<reduction%> %<inscan%>"
 
 #: c/c-parser.cc:6636 c/c-parser.cc:6791 cp/parser.cc:12240 cp/parser.cc:12390
 #: cp/parser.cc:48620
@@ -47600,17 +47222,15 @@ msgid "mixing OpenMP directives with attribute and pragma syntax on the same sta
 msgstr "змішування директив OpenMP з атрибутами та синтаксисом pragma в одному операторі"
 
 #: c/c-parser.cc:6644 cp/parser.cc:12248
-#, fuzzy, gcc-internal-format
-#| msgid "%<omp::%E%> attribute requires argument"
+#, gcc-internal-format
 msgid "OpenMP %<omp::decl%> attribute on a statement"
-msgstr "атрибут %<omp::%E%> вимагає аргумент"
+msgstr "Атрибут OpenMP %<omp::decl%> для оператора"
 
 #: c/c-parser.cc:6668 c/c-parser.cc:6887 c/c-parser.cc:25086 cp/parser.cc:12272
 #: cp/parser.cc:48600 cp/parser.cc:48740
-#, fuzzy, gcc-internal-format
-#| msgid "unknown OpenMP directive name in %qs clause argument"
+#, gcc-internal-format
 msgid "unknown OpenMP directive name in %qs attribute argument"
-msgstr "невідома назва директиви OpenMP в аргументі замикання %qs"
+msgstr "невідома назва директиви OpenMP у аргументі атрибуту %qs"
 
 #: c/c-parser.cc:6760 cp/parser.cc:12359
 #, gcc-internal-format
@@ -47716,7 +47336,7 @@ msgstr "рекомендується використовувати явні ф
 #: c/c-parser.cc:8120 c/c-parser.cc:8185 c/c-parser.cc:8304 cp/parser.cc:14614
 #, gcc-internal-format
 msgid "loop not permitted in intervening code in OpenMP loop body"
-msgstr ""
+msgstr "Цикл не дозволений у проміжному коді тіла циклу OpenMP"
 
 #: c/c-parser.cc:8193
 #, gcc-internal-format
@@ -48079,34 +47699,29 @@ msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "неправильна кількість аргументів для %<__builtin_shuffle%>"
 
 #: c/c-parser.cc:11849
-#, fuzzy, gcc-internal-format
-#| msgid "wrong number of arguments"
+#, gcc-internal-format
 msgid "wrong number of arguments to %qs"
-msgstr "неправильна кількість аргументів"
+msgstr "неправильна кількість аргументів для %qs"
 
 #: c/c-parser.cc:11858
-#, fuzzy, gcc-internal-format
-#| msgid "%qD does not have integral type"
+#, gcc-internal-format
 msgid "%qs operand not an integral type"
-msgstr "%qD не має цілочисельного типу"
+msgstr "операнд %qs не є цілочисельним типом"
 
 #: c/c-parser.cc:11864
-#, fuzzy, gcc-internal-format
-#| msgid "argument 3 in call to function %qE has enumerated type"
+#, gcc-internal-format
 msgid "argument %u in call to function %qs has enumerated type"
-msgstr "аргумент 3 у виклику функції %qE є типом з перелічуванням"
+msgstr "аргумент %u у виклику функції %qs має перерахований тип"
 
 #: c/c-parser.cc:11871
-#, fuzzy, gcc-internal-format
-#| msgid "argument 3 in call to function %qE has boolean type"
+#, gcc-internal-format
 msgid "argument %u in call to function %qs has boolean type"
-msgstr "аргумент 3 у виклику функції %qE має тип boolean"
+msgstr "аргумент %u у виклику функції %qs має булевий тип"
 
 #: c/c-parser.cc:11878
-#, fuzzy, gcc-internal-format
-#| msgid "argument 3 in call to function %qE has enumerated type"
+#, gcc-internal-format
 msgid "argument 1 in call to function %qs has signed type"
-msgstr "аргумент 3 у виклику функції %qE є типом з перелічуванням"
+msgstr "аргумент 1 у виклику функції %qs має знаковий тип"
 
 #: c/c-parser.cc:12142 cp/parser.cc:6134
 #, gcc-internal-format
@@ -48114,10 +47729,9 @@ msgid "%<omp_all_memory%> may only be used in OpenMP %<depend%> clause"
 msgstr "%<omp_all_memory%> може використовуватися тільки в замиканні OpenMP %<depend%>"
 
 #: c/c-parser.cc:12152
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C does not support %qs before C2X"
+#, gcc-internal-format
 msgid "ISO C does not support %qs before C23"
-msgstr "ISO C не підтримує %qs до C2X"
+msgstr "ISO C не підтримує %qs перед C23"
 
 #: c/c-parser.cc:12240
 #, gcc-internal-format
@@ -48150,10 +47764,9 @@ msgid "ISO C90 forbids compound literals"
 msgstr "ISO C90 забороняє складені літерали"
 
 #: c/c-parser.cc:12303
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C forbids storage class specifiers in compound literals before C2X"
+#, gcc-internal-format
 msgid "ISO C forbids storage class specifiers in compound literals before C23"
-msgstr "ISO C забороняє специфікатори класу сховища в складених літералах до C2X"
+msgstr "ISO C забороняє специфікатори класу зберігання в складених літералах перед C23"
 
 #: c/c-parser.cc:12317
 #, gcc-internal-format
@@ -48223,7 +47836,7 @@ msgstr "функція модуля %qD отримала аргумент тип
 #: c/c-parser.cc:12625 cp/parser.cc:8164
 #, gcc-internal-format
 msgid "calls to the OpenMP runtime API are not permitted in intervening code"
-msgstr ""
+msgstr "Виклики до OpenMP runtime API не дозволені в проміжному коді"
 
 #: c/c-parser.cc:12999
 #, gcc-internal-format
@@ -48303,7 +47916,7 @@ msgstr "%<#pragma GCC unroll%> вимагає виразу присвоєння,
 #: c/c-parser.cc:14489 cp/parser.cc:50798
 #, gcc-internal-format
 msgid "intervening code must not contain OpenMP directives"
-msgstr ""
+msgstr "Проміжний код не повинен містити директив OpenMP"
 
 #: c/c-parser.cc:14509 c/c-parser.cc:23629 c/c-parser.cc:23938
 #: c/c-parser.cc:24001 c/c-parser.cc:24111 cp/parser.cc:46426
@@ -48394,10 +48007,9 @@ msgid "expected %<none%>, %<shared%>, %<private%> or %<firstprivate%>"
 msgstr "очікувався %<none%>, %<shared%>, %<private%> або %<firstprivate%>"
 
 #: c/c-parser.cc:15974 cp/parser.cc:39147
-#, fuzzy, gcc-internal-format
-#| msgid "expected goto expression"
+#, gcc-internal-format
 msgid "expected constant logical expression"
-msgstr "очікуваний вираз «goto»"
+msgstr "очікується константне логічне вираження"
 
 #: c/c-parser.cc:16051 cp/parser.cc:39229
 #, gcc-internal-format
@@ -48469,10 +48081,9 @@ msgid "expected %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<non
 msgstr "очікується %<alloc%>, %<to%>, %<from%>, %<tofrom%>, %<firstprivate%>, %<none%> або %<default%>"
 
 #: c/c-parser.cc:16601
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
+#, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%>, %<pointer%> or %<all%>"
-msgstr "очікується %<scalar%>, %<aggregate%> або %<pointer%>"
+msgstr "очікується %<scalar%>, %<aggregate%>, %<pointer%> або %<all%>"
 
 #: c/c-parser.cc:16678 cp/parser.cc:39765
 #, gcc-internal-format
@@ -48511,10 +48122,9 @@ msgid "%<tile%> argument needs positive integral constant"
 msgstr "аргумент %<tile%> повинен бути додатньою цілочисельною константою"
 
 #: c/c-parser.cc:17108 cp/parser.cc:41876
-#, fuzzy, gcc-internal-format
-#| msgid "too many %<if%> clauses"
+#, gcc-internal-format
 msgid "too many %<self%> clauses"
-msgstr "занадто багато %<if%> замиканнь"
+msgstr "занадто багато клауз %<self%>"
 
 #: c/c-parser.cc:17150 cp/parser.cc:39818
 #, gcc-internal-format
@@ -48658,16 +48268,14 @@ msgid "too many %<close%> modifiers"
 msgstr "Забагато модифікаторів %<close%>"
 
 #: c/c-parser.cc:18841 cp/parser.cc:41503
-#, fuzzy, gcc-internal-format
-#| msgid "too many %<close%> modifiers"
+#, gcc-internal-format
 msgid "too many %<present%> modifiers"
-msgstr "Забагато модифікаторів %<close%>"
+msgstr "занадто багато модифікаторів %<present%>"
 
 #: c/c-parser.cc:18849 cp/parser.cc:41514
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma omp target%> with modifier other than %<always%> or %<close%> on %<map%> clause"
+#, gcc-internal-format
 msgid "%<map%> clause with map-type modifier other than %<always%>, %<close%> or %<present%>"
-msgstr "%<#pragma omp target%> з модифікатором, відмінним від %<always%> або %<close%>, на замиканні %<map%>"
+msgstr "%<map%> клауза з модифікатором типу мапи, відмінним від %<always%>, %<close%> або %<present%>"
 
 #: c/c-parser.cc:18887 cp/parser.cc:41554
 #, gcc-internal-format
@@ -48710,10 +48318,9 @@ msgid "%<detach%> clause event handle has type %qT rather than %<omp_event_handl
 msgstr "тип обробника події в замиканні %<detach%> - %qT, а не %<omp_event_handle_t%>"
 
 #: c/c-parser.cc:19440 cp/parser.cc:42092
-#, fuzzy, gcc-internal-format
-#| msgid "expected assumption clause"
+#, gcc-internal-format
 msgid "expected an OpenACC clause"
-msgstr "очікується замикання припущення"
+msgstr "очікується клауза OpenACC"
 
 #: c/c-parser.cc:19451 c/c-parser.cc:19816 cp/parser.cc:42103
 #: cp/parser.cc:42511
@@ -48732,10 +48339,9 @@ msgid "%qs must be the first clause of %qs"
 msgstr "%qs повинен бути першою замиканням %qs"
 
 #: c/c-parser.cc:19805 cp/parser.cc:42500
-#, fuzzy, gcc-internal-format
-#| msgid "expected assumption clause"
+#, gcc-internal-format
 msgid "expected an OpenMP clause"
-msgstr "очікується замикання припущення"
+msgstr "очікується клауза OpenMP"
 
 #: c/c-parser.cc:19964 cp/parser.cc:47349
 #, gcc-internal-format
@@ -48790,7 +48396,7 @@ msgstr "%<#pragma acc %s data%> не має замикання переміще
 #: c/c-parser.cc:20182 cp/parser.cc:47309
 #, gcc-internal-format
 msgid "%<host_data%> construct requires %<use_device%> clause"
-msgstr ""
+msgstr "конструкція %<host_data%> вимагає клаузи %<use_device%>"
 
 #: c/c-parser.cc:20411 cp/parser.cc:3367
 #, gcc-internal-format
@@ -48833,27 +48439,24 @@ msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> o
 msgstr "%<#pragma acc update%> повинен містити принаймні одну замикання %<device%> або %<host%> або %<self%>"
 
 #: c/c-parser.cc:20631
-#, fuzzy, gcc-internal-format
-#| msgid "variables in %<__regio_symbol%> address space must be declared %<extern%>"
+#, gcc-internal-format
 msgid "variable %qD used in the %<allocator%> clause must be declared before %qD"
-msgstr "Змінні в адресному просторі %<__regio_symbol%> повинні бути оголошені як %<extern%>"
+msgstr "Змінну %qD, використовувану в клаузі %<allocator%>, потрібно оголосити перед %qD"
 
 #: c/c-parser.cc:20635 c/c-parser.cc:20658
-#, fuzzy, gcc-internal-format
-#| msgid "template parameter %qD declared here"
+#, gcc-internal-format
 msgid "to be allocated variable declared here"
-msgstr "параметр шаблона %qD оголошений тут"
+msgstr "змінна, яка має бути виділена пам'яті, оголошена тут"
 
 #: c/c-parser.cc:20653
 #, gcc-internal-format
 msgid "variable %qD used in the %<allocator%> clause must not be modified between declaration of %qD and its %<allocate%> directive"
-msgstr ""
+msgstr "Змінну %qD в клаузі %<allocator%> не можна змінювати між оголошенням %qD і його директивою %<allocate%>"
 
 #: c/c-parser.cc:20656
-#, fuzzy, gcc-internal-format
-#| msgid "defined here"
+#, gcc-internal-format
 msgid "modified here"
-msgstr "визначено тут"
+msgstr "змінено тут"
 
 #: c/c-parser.cc:20724 cp/parser.cc:42625 cp/parser.cc:42640
 #, gcc-internal-format
@@ -48866,39 +48469,34 @@ msgid "%<allocator%> clause allocator expression has type %qT rather than %<omp_
 msgstr "вираз алокатора в замиканні %<allocator%> має тип %qT, а не %<omp_allocator_handle_t%>"
 
 #: c/c-parser.cc:20765
-#, fuzzy, gcc-internal-format
-#| msgid "parameter %qD may not appear in this context"
+#, gcc-internal-format
 msgid "function parameter %qD may not appear as list item in an %<allocate%> directive"
-msgstr "параметр %qD не може зʼявлятися в цьому контексті"
+msgstr "Параметр функції %qD не може з'явитися як елемент списку у директиві %<allocate%>"
 
 #: c/c-parser.cc:20772
-#, fuzzy, gcc-internal-format
-#| msgid "deduction guide %qD must be declared in the same scope as %qT"
+#, gcc-internal-format
 msgid "%<allocate%> directive must be in the same scope as %qD"
-msgstr "посібник з виведення %qD повинен бути оголошений в тому ж області видимості, що й %qT"
+msgstr "Директива %<allocate%> повинна бути в тому самому області видимості, що і %qD"
 
 #: c/c-parser.cc:20780
-#, fuzzy, gcc-internal-format
-#| msgid "%qD appears more than once in %<allocate%> clauses"
+#, gcc-internal-format
 msgid "%qD already appeared as list item in an %<allocate%> directive"
-msgstr "%qD зустрічається більше одного разу в замиканнях %<allocate%>"
+msgstr "%qD вже з'явився як елемент списку у директиві %<allocate%>"
 
 #: c/c-parser.cc:20787
 #, gcc-internal-format
 msgid "%<allocator%> clause required for static variable %qD"
-msgstr ""
+msgstr "Для статичної змінної %qD потрібна клауза %<allocator%>"
 
 #: c/c-parser.cc:20794
-#, fuzzy, gcc-internal-format
-#| msgid "%<allocate%> clause must specify an allocator here"
+#, gcc-internal-format
 msgid "%<allocator%> clause requires a predefined allocator as %qD is static"
-msgstr "замикання %<allocate%> повинна вказувати алокатор тут"
+msgstr "Клауза %<allocator%> вимагає вказати попередньо визначений аллокатор, оскільки %qD є статичним"
 
 #: c/c-parser.cc:20798
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma omp allocate%> not yet supported"
+#, gcc-internal-format
 msgid "%<#pragma omp allocate%> for static variables like %qD not yet supported"
-msgstr "%<#pragma omp allocate%> ще не підтримується"
+msgstr "%<#pragma omp allocate%> для статичних змінних, таких як %qD, ще не підтримується"
 
 #: c/c-parser.cc:20949 cp/parser.cc:42805
 #, gcc-internal-format
@@ -48938,16 +48536,14 @@ msgid "%qs clause requires %qs clause"
 msgstr "замикання %qs потребує замикання %qs"
 
 #: c/c-parser.cc:21113 cp/parser.cc:42974
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause"
+#, gcc-internal-format
 msgid "%<#pragma omp atomic write%> incompatible with %<acquire%> clause implicitly provided by a %<requires%> directive"
-msgstr "%<#pragma omp atomic write%> несумісний з замиканням %<acquire%>"
+msgstr "%<#pragma omp atomic write%> несумісний з неявно наданою директивою %<requires%> клаузою %<acquire%>"
 
 #: c/c-parser.cc:21124 cp/parser.cc:42985
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause"
+#, gcc-internal-format
 msgid "%<#pragma omp atomic read%> incompatible with %<release%> clause implicitly provided by a %<requires%> directive"
-msgstr "%<#pragma omp atomic read%> несумісний з замиканням %<release%>"
+msgstr "%<#pragma omp atomic read%> несумісний з неявно наданою директивою %<requires%> клаузою %<release%>"
 
 #: c/c-parser.cc:21156 cp/parser.cc:43017
 #, gcc-internal-format
@@ -49011,15 +48607,14 @@ msgid "%<depobj%> expression is not lvalue expression"
 msgstr "Вираз %<depobj%> не є виразом lvalue"
 
 #: c/c-parser.cc:21918
-#, fuzzy, gcc-internal-format
-#| msgid "%<depobj%> expression is not lvalue expression"
+#, gcc-internal-format
 msgid "%<destroy%> expression is not lvalue expression"
-msgstr "Вираз %<depobj%> не є виразом lvalue"
+msgstr "Вираз %<destroy%> не є виразом lvalue"
 
 #: c/c-parser.cc:21924 cp/parser.cc:43791
 #, gcc-internal-format
 msgid "the %<destroy%> expression %qE should be the same as the %<depobj%> argument %qE"
-msgstr ""
+msgstr "вираз %<destroy%> %qE має бути ідентичним аргументу %<depobj%> %qE"
 
 #: c/c-parser.cc:21955 cp/parser.cc:43827
 #, gcc-internal-format
@@ -49052,10 +48647,9 @@ msgid "%<[[omp::directive(%s)]]%> must be the only specified attribute on a stat
 msgstr "%<[[omp::directive(%s)]]%> повинен бути єдиним вказаним атрибутом в операторі"
 
 #: c/c-parser.cc:22159 cp/parser.cc:44664
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
+#, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero preceding executable statements"
-msgstr "%<#pragma omp ordered%> з %qs замиканням може використовуватися лише в складних операторах"
+msgstr "%<#pragma omp scan%> з відсутністю попередніх виконуваних операторів"
 
 #: c/c-parser.cc:22193 cp/parser.cc:44697
 #, gcc-internal-format
@@ -49068,10 +48662,9 @@ msgid "expected %<#pragma omp scan%>"
 msgstr "очікується %<#pragma omp scan%>"
 
 #: c/c-parser.cc:22207 cp/parser.cc:44712
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma omp ordered%> with %qs clause may only be used in compound statements"
+#, gcc-internal-format
 msgid "%<#pragma omp scan%> with zero succeeding executable statements"
-msgstr "%<#pragma omp ordered%> з %qs замиканням може використовуватися лише в складних операторах"
+msgstr "%<#pragma omp scan%> з відсутністю наступних виконуваних операторів"
 
 #: c/c-parser.cc:22325 cp/semantics.cc:10805 cp/semantics.cc:10890
 #, gcc-internal-format
@@ -49080,10 +48673,9 @@ msgstr "очікувалася оголошення або ініціаліза
 
 #: c/c-parser.cc:22411 c/c-parser.cc:22426 cp/parser.cc:45055
 #: cp/parser.cc:45070
-#, fuzzy, gcc-internal-format
-#| msgid "not enough perfectly nested loops"
+#, gcc-internal-format
 msgid "not enough nested loops"
-msgstr "недостатньо добре вкладених циклів"
+msgstr "Недостатньо вкладених циклів"
 
 #: c/c-parser.cc:22526 cp/parser.cc:45342
 #, gcc-internal-format
@@ -49171,10 +48763,9 @@ msgid "expected trait selector name"
 msgstr "очікуване імʼя селектора ознаки"
 
 #: c/c-parser.cc:24613 cp/parser.cc:47925
-#, fuzzy, gcc-internal-format
-#| msgid "selector %qs not allowed for context selector set %qs"
+#, gcc-internal-format
 msgid "unknown selector %qs for context selector set %qs"
-msgstr "селектор %qs не дозволений для набору селекторів контексту %qs"
+msgstr "Невідомий селектор %qs для набору селекторів контексту %qs"
 
 #: c/c-parser.cc:24641 cp/parser.cc:47954
 #, gcc-internal-format
@@ -49182,22 +48773,19 @@ msgid "selector %qs does not accept any properties"
 msgstr "селектор %qs не приймає жодних властивостей"
 
 #: c/c-parser.cc:24663 cp/parser.cc:47986
-#, fuzzy, gcc-internal-format
-#| msgid "%<friend%> can only be specified inside a class"
+#, gcc-internal-format
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set"
-msgstr "%<friend%> може бути вказано лише всередині класу"
+msgstr "%<score%> не може бути вказано у властивостях для селектора властивостей %qs"
 
 #: c/c-parser.cc:24672 cp/parser.cc:47996
-#, fuzzy, gcc-internal-format
-#| msgid "score argument must be constant integer expression"
+#, gcc-internal-format
 msgid "%<score%> argument must be constant integer expression"
-msgstr "аргумент score повинен бути цілим сталим виразом"
+msgstr "аргумент %<score%> повинен бути сталим цілочисельним виразом"
 
 #: c/c-parser.cc:24675 cp/parser.cc:47999
-#, fuzzy, gcc-internal-format
-#| msgid "score argument must be non-negative"
+#, gcc-internal-format
 msgid "%<score%> argument must be non-negative"
-msgstr "аргумент score повинен бути не відʼємним"
+msgstr "аргумент %<score%> повинен бути невід'ємним"
 
 #: c/c-parser.cc:24716 cp/parser.cc:48045
 #, gcc-internal-format
@@ -49218,16 +48806,14 @@ msgstr "властивості для селектора %<simd%> не можу
 #. Currently only the now-deprecated syntax
 #. from OpenMP 5.0 is supported.
 #: c/c-parser.cc:24776 cp/parser.cc:48100 fortran/openmp.cc:5921
-#, fuzzy, gcc-internal-format
-#| msgid "%<-fpie%> is not supported"
+#, gcc-internal-format
 msgid "%<requires%> selector is not supported yet"
-msgstr "%<-fpie%> не підтримується"
+msgstr "селектор %<requires%> ще не підтримується"
 
 #: c/c-parser.cc:24835 cp/parser.cc:48163
-#, fuzzy, gcc-internal-format
-#| msgid "expected trait selector name"
+#, gcc-internal-format
 msgid "expected context selector set name"
-msgstr "очікуване імʼя селектора ознаки"
+msgstr "очікується ім'я набору селектора контексту"
 
 #: c/c-parser.cc:24912 cp/parser.cc:48478
 #, gcc-internal-format
@@ -49270,16 +48856,14 @@ msgid "%qD specified both in declare target %<link%> and %<to%> or %<enter%> cla
 msgstr "%qD вказано як у замиканні declare target %<link%>, так і в замиканні %<to%> або %<enter%>"
 
 #: c/c-parser.cc:25270 cp/parser.cc:48947
-#, fuzzy, gcc-internal-format
-#| msgid "directive with only %<device_type%> clause"
+#, gcc-internal-format
 msgid "directive with only %<device_type%> or %<indirect%> clauses"
-msgstr "директива з замиканням %<device_type%>"
+msgstr "директива тільки з клаузами %<device_type%> або %<indirect%>"
 
 #: c/c-parser.cc:25273 cp/parser.cc:48950
-#, fuzzy, gcc-internal-format
-#| msgid "%<detach%> clause must not be used together with %<mergeable%> clause"
+#, gcc-internal-format
 msgid "%<device_type%> clause must specify 'any' when used with an %<indirect%> clause"
-msgstr "умову %<detach%> не слід використовувати разом з умовою %<mergeable%>"
+msgstr "клауза %<device_type%> повинна вказувати 'any', коли використовується з клаузою %<indirect%>"
 
 #: c/c-parser.cc:25322 c/c-parser.cc:25364 cp/parser.cc:49005
 #: cp/parser.cc:49052
@@ -49370,10 +48954,9 @@ msgid "expected %<simd%>, %<reduction%>, %<target%> or %<variant%>"
 msgstr "очікується %<simd%>, %<reduction%>, %<target%> або %<variant%>"
 
 #: c/c-parser.cc:25908 cp/parser.cc:49654
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<seq_cst%>, %<acq_rel%>, %<release%> or %<acquire%>"
+#, gcc-internal-format
 msgid "expected %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> or %<seq_cst%>"
-msgstr "очікується %<seq_cst%>, %<acq_rel%>, %<release%> або %<acquire%>"
+msgstr "очікується %<acq_rel%>, %<acquire%>, %<relaxed%>, %<release%> або %<seq_cst%>"
 
 #: c/c-parser.cc:25937 cp/parser.cc:49689
 #, gcc-internal-format
@@ -49574,13 +49157,12 @@ msgstr "не можна змішувати операнди десяткових
 #: c/c-typeck.cc:928
 #, gcc-internal-format
 msgid "%<_Complex _BitInt(%d)%> unsupported"
-msgstr ""
+msgstr "%<_Complex _BitInt(%d)%> не підтримується"
 
 #: c/c-typeck.cc:1474
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of pointers to arrays with different qualifiers in ISO C before C2X"
+#, gcc-internal-format
 msgid "invalid use of pointers to arrays with different qualifiers in ISO C before C23"
-msgstr "неприпустиме використання вказівників на масиви з різними кваліфікаторами в ISO C до C2X"
+msgstr "неправильне використання вказівників на масиви з різними кваліфікаторами в ISO C до C23"
 
 #: c/c-typeck.cc:1478
 #, gcc-internal-format
@@ -49598,10 +49180,9 @@ msgid "function return types not compatible due to %<volatile%>"
 msgstr "типи повернення функцій несумісні через %<volatile%>"
 
 #: c/c-typeck.cc:1907
-#, fuzzy, gcc-internal-format
-#| msgid "converting an array compound literal to a pointer is ill-formed in C++"
+#, gcc-internal-format
 msgid "converting an array compound literal to a pointer leads to a dangling pointer in C++"
-msgstr "перетворення складного літерала масиву на вказівник є неправильним у C++"
+msgstr "перетворення складеного літерала масиву на вказівник призводить до висячого вказівника в C++"
 
 #: c/c-typeck.cc:2601 c/c-typeck.cc:9854
 #, gcc-internal-format
@@ -49977,10 +49558,9 @@ msgid "pointer to array loses qualifier in conditional expression"
 msgstr "вказівник на масив втрачає кваліфікатор в умовному виразі"
 
 #: c/c-typeck.cc:5667
-#, fuzzy, gcc-internal-format
-#| msgid "pointer to array loses qualifier in conditional expression in ISO C before C2X"
+#, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression in ISO C before C23"
-msgstr "вказівник на масив втрачає кваліфікатор в умовному виразі в ISO C до C2X"
+msgstr "вказівник на масив втрачає кваліфікатор у умовному виразі в ISO C до C23"
 
 #: c/c-typeck.cc:5672
 #, gcc-internal-format
@@ -49993,16 +49573,14 @@ msgid "pointer type mismatch in conditional expression"
 msgstr "несумісні типи вказівників в умовному виразі"
 
 #: c/c-typeck.cc:5697
-#, fuzzy, gcc-internal-format
-#| msgid "Expected expression type"
+#, gcc-internal-format
 msgid "first expression has type %qT"
-msgstr "Очікуваний тип виразу"
+msgstr "перший вираз має тип %qT"
 
 #: c/c-typeck.cc:5698
-#, fuzzy, gcc-internal-format
-#| msgid "Expected expression type"
+#, gcc-internal-format
 msgid "second expression has type %qT"
-msgstr "Очікуваний тип виразу"
+msgstr "другий вираз має тип %qT"
 
 #: c/c-typeck.cc:5709 c/c-typeck.cc:5722
 #, gcc-internal-format
@@ -50078,10 +49656,9 @@ msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C забороняє приведення нескалярного типу до того ж типу"
 
 #: c/c-typeck.cc:6201
-#, fuzzy, gcc-internal-format
-#| msgid "useless cast to type %q#T"
+#, gcc-internal-format
 msgid "useless cast to type %qT"
-msgstr "непотрібне приведення до типу %q#T"
+msgstr "безглузде перетворення типу на %qT"
 
 #: c/c-typeck.cc:6221
 #, gcc-internal-format
@@ -50341,10 +49918,9 @@ msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C забороняє повернення між вказівником на функцію та %<void *%>"
 
 #: c/c-typeck.cc:7771
-#, fuzzy, gcc-internal-format
-#| msgid "array with qualifier on the element is not qualified before C2X"
+#, gcc-internal-format
 msgid "array with qualifier on the element is not qualified before C23"
-msgstr "масив з кваліфікатором на елементі не має кваліфікатора перед C2X"
+msgstr "масив з кваліфікатором на елементі не має кваліфікатора до C23"
 
 #: c/c-typeck.cc:7788
 #, gcc-internal-format
@@ -50633,10 +50209,9 @@ msgid "enum conversion in initialization is invalid in C++"
 msgstr "перетворення перелічування при ініціалізації недійсне в C++"
 
 #: c/c-typeck.cc:10836
-#, fuzzy, gcc-internal-format
-#| msgid "excess elements in union initializer"
+#, gcc-internal-format
 msgid "excess elements in %qT initializer"
-msgstr "зайві елементи в ініціалізаторі обʼєднання"
+msgstr "зайві елементи в ініціалізаторі %qT"
 
 #: c/c-typeck.cc:10848 c/c-typeck.cc:10925
 #, gcc-internal-format
@@ -51237,10 +50812,9 @@ msgstr "секція масиву не має відображального т
 
 #: c/c-typeck.cc:15567 c/c-typeck.cc:15643 c/c-typeck.cc:15679
 #: cp/semantics.cc:8397 cp/semantics.cc:8476 cp/semantics.cc:8512
-#, fuzzy, gcc-internal-format
-#| msgid "unsupported memory expression:"
+#, gcc-internal-format
 msgid "unsupported map expression %qE"
-msgstr "непідтримуваний вираз памʼяті:"
+msgstr "непідтримуваний вираз мапи %qE"
 
 #: c/c-typeck.cc:15607 c/c-typeck.cc:15784 cp/semantics.cc:8438
 #: cp/semantics.cc:8656
@@ -51502,16 +51076,14 @@ msgid "invalid type of %<__MEM%> operand"
 msgstr "недійсний тип операнда %<__MEM%>"
 
 #: c/gimple-parser.cc:1563
-#, fuzzy, gcc-internal-format
-#| msgid "expected constant offset"
+#, gcc-internal-format
 msgid "expected constant offset for %<__MEM%> operand"
-msgstr "очікуваний сталий зсув"
+msgstr "очікується стале зміщення для операнда %<__MEM%>"
 
 #: c/gimple-parser.cc:1574
-#, fuzzy, gcc-internal-format
-#| msgid "invalid type of %<__MEM%> operand"
+#, gcc-internal-format
 msgid "expected constant step for %<__MEM%> operand"
-msgstr "недійсний тип операнда %<__MEM%>"
+msgstr "очікується стала величина кроку для операнда %<__MEM__>"
 
 #: c/gimple-parser.cc:1627
 #, gcc-internal-format
@@ -51585,10 +51157,9 @@ msgid "expected case label"
 msgstr "очікувана мітка «case»"
 
 #: cp/call.cc:2041
-#, fuzzy, gcc-internal-format
-#| msgid "casting %qT to %qT does not dereference pointer"
+#, gcc-internal-format
 msgid "casting %qT to %qT does not use %qD"
-msgstr "приведення типу %qT до %qT не розіменовує вказівник"
+msgstr "перетворення з %qT на %qT не використовує %qD"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
 #: cp/call.cc:3888
@@ -51656,10 +51227,9 @@ msgid "%s%#qD (near match)"
 msgstr "%s%#qD (близьке співпадіння)"
 
 #: cp/call.cc:3977
-#, fuzzy, gcc-internal-format
-#| msgid "%s%#qD (reversed)"
+#, gcc-internal-format
 msgid "%s%#qD (ignored)"
-msgstr "%s%#qD (зворотнє)"
+msgstr "%s%#qD (ігнорується)"
 
 #: cp/call.cc:3979
 #, gcc-internal-format
@@ -51720,7 +51290,7 @@ msgstr "  успадкований конструктор не є кандида
 #: cp/call.cc:4132
 #, gcc-internal-format
 msgid "some candidates omitted; use %<-fdiagnostics-all-candidates%> to display them"
-msgstr ""
+msgstr "деякі кандидати опущені; використовуйте %<-fdiagnostics-all-candidates%>, щоб відобразити їх"
 
 #: cp/call.cc:4213 cp/call.cc:4758
 #, gcc-internal-format
@@ -51909,16 +51479,14 @@ msgid "enumerated mismatch in conditional expression: %qT vs %qT"
 msgstr "несумісність перелічування в умовному виразі: %qT проти %qT"
 
 #: cp/call.cc:6286
-#, fuzzy, gcc-internal-format
-#| msgid "conditional expression between enumeration type %qT and floating-point type %qT is deprecated"
+#, gcc-internal-format
 msgid "conditional expression between enumeration type %qT and floating-point type %qT"
-msgstr "умовний вираз між перелічуванням типу %qT та типом з плаваючою точкою %qT є застарілим"
+msgstr "умовний вираз між типом перерахування %qT та типом з плаваючою комою %qT"
 
 #: cp/call.cc:6290
-#, fuzzy, gcc-internal-format
-#| msgid "conditional expression between floating-point type %qT and enumeration type %qT is deprecated"
+#, gcc-internal-format
 msgid "conditional expression between floating-point type %qT and enumeration type %qT"
-msgstr "умовний вираз між типом з плаваючою точкою %qT та перелічуванням типу %qT є застарілим"
+msgstr "умовний вираз між типом з плаваючою комою %qT та типом перерахування %qT"
 
 #: cp/call.cc:6294
 #, gcc-internal-format
@@ -52076,16 +51644,12 @@ msgid "converting to %qH from %qI requires direct-initialization"
 msgstr "конвертація в %qH з %qI вимагає прямої ініціалізації"
 
 #: cp/call.cc:8471
-#, fuzzy
-#| msgid "converting to %qH from %qI with greater conversion rank"
 msgid "ISO C++ does not allow converting to %qH from %qI with greater conversion rank"
-msgstr "конвертація в %qH з %qI з більшим рангом конвертації"
+msgstr "ISO C++ не дозволяє конвертувати з %qH на %qI з більшим рангом конверсії"
 
 #: cp/call.cc:8479
-#, fuzzy
-#| msgid "converting to %qH from %qI with unordered conversion ranks"
 msgid "ISO C++ does not allow converting to %qH from %qI with unordered conversion rank"
-msgstr "перетворення на %qH з %qI з неупорядкованими рангами конверсії"
+msgstr "ISO C++ не дозволяє конвертувати з %qH на %qI з невпорядкованим рангом конверсії"
 
 #: cp/call.cc:8495
 msgid "invalid user-defined conversion from %qH to %qI"
@@ -52192,7 +51756,7 @@ msgstr "використання функції з багатьма версія
 #: cp/call.cc:10021
 #, gcc-internal-format
 msgid "use %<-fdiagnostics-all-candidates%> to display considered candidates"
-msgstr ""
+msgstr "Використовуйте %<-fdiagnostics-all-candidates%>, щоб відобразити кандидати, взяті до уваги"
 
 #: cp/call.cc:10144
 #, gcc-internal-format
@@ -52488,7 +52052,7 @@ msgstr "тимчасовий обʼєкт був знищений в кінці
 #: cp/call.cc:14599
 #, gcc-internal-format
 msgid "explicit conversion function was not considered"
-msgstr ""
+msgstr "явна функція конверсії не була розглянута"
 
 #: cp/class.cc:322
 #, gcc-internal-format
@@ -52780,7 +52344,7 @@ msgstr "член-вказівник %q+D оголошений тут"
 #: cp/class.cc:4316
 #, gcc-internal-format
 msgid "layout of %qs member of type %qT changes in %qs"
-msgstr ""
+msgstr "Розташування члена %qs типу %qT змінюється в %qs"
 
 #: cp/class.cc:4709
 #, gcc-internal-format
@@ -53013,16 +52577,14 @@ msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "Перетворення перевантаженої функції %qD на тип %q#T є неоднозначним"
 
 #: cp/class.cc:8979
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
+#, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function."
-msgstr "ISO C++ забороняє взяти адресу некваліфікованої або укладеної нестатичної член-функції для створення вказівника на член-функцію. Скажіть %<&%T::%D%>"
+msgstr "ISO C++ забороняє брати адресу некваліфікованої або дужкової нестатичної функції-члена для створення вказівника на явну функцію-член об'єкта."
 
 #: cp/class.cc:8984
-#, fuzzy, gcc-internal-format
-#| msgid "(a pointer to member can only be formed with %<&%E%>)"
+#, gcc-internal-format
 msgid "a pointer to explicit object member function can only be formed with %<&%E%>"
-msgstr "(вказівник на член може бути створений лише з %<&%E%>)"
+msgstr "вказівник на явну функцію-член об'єкта можна створити тільки з %<&%E%>"
 
 #: cp/class.cc:8994
 #, gcc-internal-format
@@ -53129,7 +52691,7 @@ msgstr "%qD не може бути використана як функція з
 #: cp/constexpr.cc:1315 cp/constexpr.cc:6364
 #, gcc-internal-format
 msgid "destroying %qE outside its lifetime"
-msgstr ""
+msgstr "знищення %qE поза його часом життя"
 
 #: cp/constexpr.cc:1606 cp/constexpr.cc:3317
 #: rust/backend/rust-constexpr.cc:3326 rust/backend/rust-constexpr.cc:3589
@@ -53281,21 +52843,19 @@ msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use %<-fconstexpr-d
 msgstr "глибина оцінки %<constexpr%> перевищує максимальне значення %d (використовуйте %<-fconstexpr-depth=%>, щоб збільшити максимальне значення)"
 
 #: cp/constexpr.cc:3547
-#, fuzzy, gcc-internal-format
-#| msgid "expression %qE is not a constant expression"
+#, gcc-internal-format
 msgid "reference to %qD is not a constant expression"
-msgstr "Вираз %qE не є константним виразом"
+msgstr "посилання на %qD не є константним виразом"
 
 #: cp/constexpr.cc:3550
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not a constant expression"
+#, gcc-internal-format
 msgid "pointer to %qD is not a constant expression"
-msgstr "%qE не є константним виразом"
+msgstr "вказівник на %qD не є константним виразом"
 
 #: cp/constexpr.cc:3556
 #, gcc-internal-format
 msgid "address of non-static constexpr variable %qD may differ on each invocation of the enclosing function; add %<static%> to give it a constant address"
-msgstr ""
+msgstr "адреса константного значення змінної %qD може відрізнятися при кожному виклику оточуючої функції; додайте  %<static%>, щоб дати їй сталу адресу."
 
 #: cp/constexpr.cc:3632
 #, gcc-internal-format
@@ -53471,10 +53031,9 @@ msgid "allocated here"
 msgstr "виділено тут"
 
 #: cp/constexpr.cc:5996
-#, fuzzy, gcc-internal-format
-#| msgid "Access terminates outside of its parent"
+#, gcc-internal-format
 msgid "accessing %qE outside its lifetime"
-msgstr "Доступ закінчується за межами батьківського обʼєкту"
+msgstr "доступ до %qE поза його терміном існування"
 
 #: cp/constexpr.cc:6016
 #, gcc-internal-format
@@ -53517,44 +53076,39 @@ msgid "%qD does not have integral or enumeration type"
 msgstr "%qD не має цілочисельного або перелічувального типу"
 
 #: cp/constexpr.cc:6357
-#, fuzzy, gcc-internal-format
-#| msgid "use of allocated storage after deallocation in a constant expression"
+#, gcc-internal-format
 msgid "modification of allocated storage after deallocation is not a constant expression"
-msgstr "використання виділеного сховища після звільнення в константному виразі"
+msgstr "модифікація виділеної пам'яті після її звільнення не є константним виразом"
 
 #: cp/constexpr.cc:6366
-#, fuzzy, gcc-internal-format
-#| msgid "modification of %qE is not a constant expression"
+#, gcc-internal-format
 msgid "modification of %qE outside its lifetime is not a constant expression"
-msgstr "зміна %qE не є константним виразом"
+msgstr "модифікація %qE поза його терміном існування не є константним виразом"
 
 #: cp/constexpr.cc:6373
-#, fuzzy, gcc-internal-format
-#| msgid "%<reinterpret_cast%> is not a constant expression"
+#, gcc-internal-format
 msgid "destroying %qE from outside current evaluation is not a constant expression"
-msgstr "%<reinterpret_cast%> не є константним виразом"
+msgstr "знищення %qE поза поточним оцінюванням не є константним виразом"
 
 #: cp/constexpr.cc:6376
-#, fuzzy, gcc-internal-format
-#| msgid "modification of %qE is not a constant expression"
+#, gcc-internal-format
 msgid "modification of %qE from outside current evaluation is not a constant expression"
-msgstr "зміна %qE не є константним виразом"
+msgstr "модифікація %qE поза поточним оцінюванням не є константним виразом"
 
 #: cp/constexpr.cc:6503
-#, fuzzy, gcc-internal-format
-#| msgid "change of the active member of a union from %qD to %qD during initialization"
+#, gcc-internal-format
 msgid "change of the active member of a union from %qD to %qD is not a constant expression before C++20"
-msgstr "зміна активного члена обʼєднання з %qD на %qD під час ініціалізації"
+msgstr "зміна активного члена об'єднання з %qD на %qD не є константним виразом до C++20"
 
 #: cp/constexpr.cc:6532
 #, gcc-internal-format
 msgid "%qD does not implicitly begin its lifetime because %qT does not have a non-deleted trivial default constructor, use %<std::construct_at%> instead"
-msgstr ""
+msgstr "%qD не починає свій термін існування неявно, оскільки %qT не має невидаленого тривіального конструктора за замовчуванням, використовуйте %<std::construct_at%> замість цього"
 
 #: cp/constexpr.cc:6539
 #, gcc-internal-format
 msgid "initializing %qD requires a member access expression as the left operand of the assignment"
-msgstr ""
+msgstr "ініціалізація %qD вимагає виразу доступу до члена як лівого операнда присвоювання"
 
 #: cp/constexpr.cc:6551 rust/backend/rust-constexpr.cc:2822
 #, gcc-internal-format
@@ -53644,28 +53198,24 @@ msgid "conversion from pointer type %qT to arithmetic type %qT in a constant exp
 msgstr "перетворення з типу вказівника %qT до арифметичного типу %qT в константному виразі"
 
 #: cp/constexpr.cc:8181
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
+#, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because pointed-to type %qT is not similar to %qT"
-msgstr "%qE не є константним виразом, оскільки він посилається на змінні підобʼєкти %qT"
+msgstr "Приведення типів з %qT не дозволено в константному виразі, оскільки тип, на який вказує %qT, не схожий на %qT"
 
 #: cp/constexpr.cc:8188
-#, fuzzy, gcc-internal-format
-#| msgid "pointer member %q+D declared here"
+#, gcc-internal-format
 msgid "pointed-to object declared here"
-msgstr "член-вказівник %q+D оголошений тут"
+msgstr "Вказаний об'єкт оголошено тут"
 
 #: cp/constexpr.cc:8193
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is not a constant expression because %qT is a pointer to member type"
+#, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression because %qE does not point to an object"
-msgstr "%qs не є константним виразом, оскільки %qT є типом вказівника на член"
+msgstr "Приведення типів з %qT не дозволено в константному виразі, оскільки %qE не вказує на об'єкт"
 
 #: cp/constexpr.cc:8205
-#, fuzzy, gcc-internal-format
-#| msgid "modifying a const object %qE is not allowed in a constant expression"
+#, gcc-internal-format
 msgid "cast from %qT is not allowed in a constant expression before C++26"
-msgstr "зміна константного обʼєкту %qE не дозволена в константному виразі"
+msgstr "Приведення типів з %qT не дозволено в константному виразі перед C++26"
 
 #: cp/constexpr.cc:8219
 #, gcc-internal-format
@@ -53739,10 +53289,9 @@ msgid "immediate evaluation returns address of immediate function %qD"
 msgstr "негайна оцінка повертає адресу негайної функції %qD"
 
 #: cp/constexpr.cc:8941
-#, fuzzy, gcc-internal-format
-#| msgid "immediate evaluation returns address of immediate function %qD"
+#, gcc-internal-format
 msgid "constant evaluation returns address of immediate function %qD"
-msgstr "негайна оцінка повертає адресу негайної функції %qD"
+msgstr "Оцінка константи повертає адресу негайної функції %qD"
 
 #: cp/constexpr.cc:9579 rust/backend/rust-constexpr.cc:5667
 #, gcc-internal-format
@@ -54052,10 +53601,9 @@ msgid "  %qT is not an aggregate"
 msgstr "  %qT не є агрегатом"
 
 #: cp/constraint.cc:3757
-#, fuzzy, gcc-internal-format
-#| msgid "  %qT is not an aggregate"
+#, gcc-internal-format
 msgid "  %qT is not an array"
-msgstr "  %qT не є агрегатом"
+msgstr "  %qT не є масивом"
 
 #: cp/constraint.cc:3760
 #, gcc-internal-format
@@ -54068,10 +53616,9 @@ msgid "  %qT is not a base of %qT"
 msgstr "  %qT не є базовим класом для %qT"
 
 #: cp/constraint.cc:3766
-#, fuzzy, gcc-internal-format
-#| msgid "  %qT is not an aggregate"
+#, gcc-internal-format
 msgid "  %qT is not a bounded array"
-msgstr "  %qT не є агрегатом"
+msgstr "  %qT не є обмеженим масивом"
 
 #: cp/constraint.cc:3769
 #, gcc-internal-format
@@ -54109,10 +53656,9 @@ msgid "  %qT is not a final class"
 msgstr "  %qT не є заключним класом"
 
 #: cp/constraint.cc:3790
-#, fuzzy, gcc-internal-format
-#| msgid "  %qT is not a union"
+#, gcc-internal-format
 msgid "  %qT is not a function"
-msgstr "  %qT не є обʼєднанням"
+msgstr "  %qT не є функцією"
 
 #: cp/constraint.cc:3793
 #, gcc-internal-format
@@ -54125,22 +53671,19 @@ msgid "  %qT is not a literal type"
 msgstr "  %qT не є літеральним типом"
 
 #: cp/constraint.cc:3799
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a member template function"
+#, gcc-internal-format
 msgid "  %qT is not a member function pointer"
-msgstr "%qD не є шаблонною функцією-членом"
+msgstr "  %qT не є вказівником на член-функцію"
 
 #: cp/constraint.cc:3802
-#, fuzzy, gcc-internal-format
-#| msgid "%qT is not a member of %qT"
+#, gcc-internal-format
 msgid "  %qT is not a member object pointer"
-msgstr "%qT не є членом %qT"
+msgstr "  %qT не є вказівником на член-об'єкт"
 
 #: cp/constraint.cc:3805
-#, fuzzy, gcc-internal-format
-#| msgid "%qT is not a member of %qT"
+#, gcc-internal-format
 msgid "  %qT is not a member pointer"
-msgstr "%qT не є членом %qT"
+msgstr "  %qT не є вказівником на член"
 
 #: cp/constraint.cc:3808
 #, gcc-internal-format
@@ -54158,10 +53701,9 @@ msgid "  %qT is not nothrow convertible from %qE"
 msgstr "  %qT не може бути безпечно перетворений з %qE"
 
 #: cp/constraint.cc:3820
-#, fuzzy, gcc-internal-format
-#| msgid "  %qT is not a POD type"
+#, gcc-internal-format
 msgid "  %qT is not an object type"
-msgstr "  %qT не є типом POD (Plain Old Data)"
+msgstr "  %qT не є типом об'єкта"
 
 #: cp/constraint.cc:3823
 #, gcc-internal-format
@@ -54179,10 +53721,9 @@ msgid "  %qT is not a polymorphic type"
 msgstr "  %qT не є поліморфним типом"
 
 #: cp/constraint.cc:3833
-#, fuzzy, gcc-internal-format
-#| msgid "  %qT is not an enum"
+#, gcc-internal-format
 msgid "  %qT is not a reference"
-msgstr "  %qT не є перелічуванням"
+msgstr "  %qT не є посиланням"
 
 #: cp/constraint.cc:3836
 #, gcc-internal-format
@@ -54190,10 +53731,9 @@ msgid "  %qT is not the same as %qT"
 msgstr "  %qT не є таким самим, як %qT"
 
 #: cp/constraint.cc:3839
-#, fuzzy, gcc-internal-format
-#| msgid "  %qT is not an enum"
+#, gcc-internal-format
 msgid "  %qT is not a scoped enum"
-msgstr "  %qT не є перелічуванням"
+msgstr "  %qT не є обмеженим перерахуванням"
 
 #: cp/constraint.cc:3842
 #, gcc-internal-format
@@ -54602,13 +54142,12 @@ msgstr "обидва гілки оператора %<if%> позначені я
 #: cp/cp-gimplify.cc:536
 #, gcc-internal-format
 msgid "%qD was promoted to an immediate function because its body contains an immediate-escalating expression %qE"
-msgstr ""
+msgstr "%qD було підвищено до негайної функції, оскільки її тіло містить вираз з негайним ескалюванням %qE"
 
 #: cp/cp-gimplify.cc:539
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a template function"
+#, gcc-internal-format
 msgid "%qD was promoted to an immediate function"
-msgstr "%qD не є шаблонною функцією"
+msgstr "%qD було підвищено до негайної функції"
 
 #: cp/cp-gimplify.cc:1174
 #, gcc-internal-format
@@ -54616,10 +54155,9 @@ msgid "taking address of an immediate function %qD"
 msgstr "береться адреса негайної функції %qD"
 
 #: cp/cp-gimplify.cc:1273
-#, fuzzy, gcc-internal-format
-#| msgid "address of a call to %qs is not a constant expression"
+#, gcc-internal-format
 msgid "call to consteval function %qE is not a constant expression"
-msgstr "адреса виклику %qs не є константним виразом"
+msgstr "Виклик функції consteval %qE не є константним виразом"
 
 #: cp/cp-gimplify.cc:2012
 #, gcc-internal-format
@@ -55243,51 +54781,44 @@ msgid "%q#D previously declared here"
 msgstr "%q#D раніше оголошено тут"
 
 #: cp/decl.cc:2097
-#, fuzzy, gcc-internal-format
-#| msgid "method declaration not in @interface context"
+#, gcc-internal-format
 msgid "parameter declaration is not name-independent"
-msgstr "оголошення методу не в контексті @interface"
+msgstr "Оголошення параметра не є іменем незалежним"
 
 #: cp/decl.cc:2102
-#, fuzzy, gcc-internal-format
-#| msgid "structured binding declaration set but not used"
+#, gcc-internal-format
 msgid "structured binding at namespace scope is not name-independent"
-msgstr "встановлено декларацію структурованого звʼязування, але не використовується"
+msgstr "Структуроване прив'язування в області видимості простору імен не є іменем незалежним"
 
 #: cp/decl.cc:2106
-#, fuzzy, gcc-internal-format
-#| msgid "structured binding has incomplete type %qT"
+#, gcc-internal-format
 msgid "static structured binding is not name-independent"
-msgstr "структуроване привʼязування має неповний тип %qT"
+msgstr "Статичне структуроване прив'язування не є іменем незалежним"
 
 #: cp/decl.cc:2110
-#, fuzzy, gcc-internal-format
-#| msgid "structured binding has incomplete type %qT"
+#, gcc-internal-format
 msgid "extern structured binding is not name-independent"
-msgstr "структуроване привʼязування має неповний тип %qT"
+msgstr "Зовнішнє структуроване прив'язування не є іменем незалежним"
 
 #: cp/decl.cc:2117
-#, fuzzy, gcc-internal-format
-#| msgid "static data member %qD in unnamed class"
+#, gcc-internal-format
 msgid "static data member is not name-independent"
-msgstr "статичний член даних %qD в безіменному класі"
+msgstr "Статичний член даних не є іменем незалежним"
 
 #: cp/decl.cc:2120
 #, gcc-internal-format
 msgid "variable at namespace scope is not name-independent"
-msgstr ""
+msgstr "змінна в області видимості простору імен залежить від назви"
 
 #: cp/decl.cc:2123
-#, fuzzy, gcc-internal-format
-#| msgid "%qs variable is not a pointer"
+#, gcc-internal-format
 msgid "static variable is not name-independent"
-msgstr "змінна %qs не є вказівником"
+msgstr "статична змінна не є незалежною від імені"
 
 #: cp/decl.cc:2126
-#, fuzzy, gcc-internal-format
-#| msgid "environment variable %qs not defined"
+#, gcc-internal-format
 msgid "extern variable is not name-independent"
-msgstr "змінна середовища %qs не визначена"
+msgstr "змінна extern не є незалежною від імені"
 
 #: cp/decl.cc:2138
 #, gcc-internal-format
@@ -55320,16 +54851,14 @@ msgid "previous specification in %q#D here"
 msgstr "попередня специфікація в %q#D тут"
 
 #: cp/decl.cc:2300 cp/decl.cc:16654
-#, fuzzy, gcc-internal-format
-#| msgid "conflicting exporting declaration %qD"
+#, gcc-internal-format
 msgid "conflicting exporting for declaration %qD"
-msgstr "конфліктна експортна декларація %qD"
+msgstr "конфліктний експорт для оголошення %qD"
 
 #: cp/decl.cc:2302 cp/decl.cc:16656
-#, fuzzy, gcc-internal-format
-#| msgid "previously declared here"
+#, gcc-internal-format
 msgid "previously declared here without exporting"
-msgstr "раніше оголошено тут"
+msgstr "попередньо оголошено тут без експортування"
 
 #: cp/decl.cc:2330
 #, gcc-internal-format
@@ -55459,7 +54988,7 @@ msgstr "перехід до мітки case"
 #: cp/decl.cc:3703
 #, gcc-internal-format
 msgid "  as a possible target of computed goto"
-msgstr ""
+msgstr "  як можлива мітка для обчисленого переходу goto"
 
 #: cp/decl.cc:3705
 #, gcc-internal-format
@@ -55512,16 +55041,14 @@ msgid "  enters %<consteval if%> statement"
 msgstr "  входить у інструкцію %<consteval if%>"
 
 #: cp/decl.cc:3838 cp/decl.cc:4012
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C99 does not support %qE"
+#, gcc-internal-format
 msgid "  does not destroy %qD"
-msgstr "ISO C99 не підтримує %qE"
+msgstr "  не знищує %qD"
 
 #: cp/decl.cc:3840 cp/decl.cc:3995
-#, fuzzy, gcc-internal-format
-#| msgid "%s does not take any feature options"
+#, gcc-internal-format
 msgid "  does not clean up handled exception"
-msgstr "%s не приймає жодних опцій функцій"
+msgstr "  не очищає оброблену виняткову ситуацію"
 
 #: cp/decl.cc:3931
 #, gcc-internal-format
@@ -55785,10 +55312,9 @@ msgid "declaration of %q#D outside of class is not definition"
 msgstr "декларація %q#D поза класом не є визначенням"
 
 #: cp/decl.cc:6106
-#, fuzzy, gcc-internal-format
-#| msgid "block-scope extern declaration %q#D not permitted in module purview"
+#, gcc-internal-format
 msgid "block-scope extern declaration %q#D must not be attached to a named module"
-msgstr "екстерна декларація %q#D з областю видимості блоку не дозволена в модульному контексті"
+msgstr "оголошення зовнішньої області блоку %q#D не повинно бути прикріпленим до іменованого модуля"
 
 #: cp/decl.cc:6142
 #, gcc-internal-format
@@ -56366,15 +55892,14 @@ msgid "constraints on a non-templated function"
 msgstr "обмеження на функцію без шаблону"
 
 #: cp/decl.cc:10604
-#, fuzzy, gcc-internal-format
-#| msgid "friend declaration not in class definition"
+#, gcc-internal-format
 msgid "constrained non-template friend declaration must be a definition"
-msgstr "Оголошення друзів не визначено в описі класу"
+msgstr "обмежений оголошення друга, який не є шаблоном, повинен бути визначенням"
 
 #: cp/decl.cc:10611
 #, gcc-internal-format
 msgid "friend function template with constraints that depend on outer template parameters must be a definition"
-msgstr ""
+msgstr "шаблон дружньої функції з обмеженнями, що залежать від зовнішніх параметрів шаблону, повинен бути визначенням"
 
 #: cp/decl.cc:10660
 #, gcc-internal-format
@@ -56432,10 +55957,9 @@ msgid "static member function %qD cannot have cv-qualifier"
 msgstr "статична функція-член %qD не може мати cv-кваліфікатор"
 
 #: cp/decl.cc:10838
-#, fuzzy, gcc-internal-format
-#| msgid "static member function %qD cannot have cv-qualifier"
+#, gcc-internal-format
 msgid "explicit object member function %qD cannot have cv-qualifier"
-msgstr "статична функція-член %qD не може мати cv-кваліфікатор"
+msgstr "явна функція-член об'єкта %qD не може мати cv-кваліфікатора"
 
 #: cp/decl.cc:10843
 #, gcc-internal-format
@@ -56448,16 +55972,14 @@ msgid "static member function %qD cannot have ref-qualifier"
 msgstr "статичний метод класу %qD не може мати кваліфікатор посилання"
 
 #: cp/decl.cc:10846
-#, fuzzy, gcc-internal-format
-#| msgid "static member function %qD cannot have ref-qualifier"
+#, gcc-internal-format
 msgid "explicit object member function %qD cannot have ref-qualifier"
-msgstr "статичний метод класу %qD не може мати кваліфікатор посилання"
+msgstr "явна функція-член об'єкта %qD не може мати ref-кваліфікатора"
 
 #: cp/decl.cc:10852 cp/decl.cc:13735 cp/decl.cc:13745 cp/parser.cc:11972
-#, fuzzy, gcc-internal-format
-#| msgid "template parameter %qD declared here"
+#, gcc-internal-format
 msgid "explicit object parameter declared here"
-msgstr "параметр шаблона %qD оголошений тут"
+msgstr "явний параметр об'єкта оголошено тут"
 
 #: cp/decl.cc:10864
 #, gcc-internal-format
@@ -57042,50 +56564,44 @@ msgid "remove parentheses"
 msgstr "видалити дужки"
 
 #: cp/decl.cc:13365
-#, fuzzy, gcc-internal-format
-#| msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
+#, gcc-internal-format
 msgid "explicit object member function only available with %<-std=c++23%> or %<-std=gnu++23%>"
-msgstr "виведення псевдоніма шаблону доступне лише з %<-std=c++20%> або %<-std=gnu++20%>"
+msgstr "явна функція-член об'єкта доступна тільки з %<-std=c++23%> або %<-std=gnu++23%>"
 
 #: cp/decl.cc:13379
-#, fuzzy, gcc-internal-format
-#| msgid "Function %qs at %L cannot have an initializer"
+#, gcc-internal-format
 msgid "a function type cannot have an explicit object parameter"
-msgstr "Функція %qs на %L не може мати ініціалізатора"
+msgstr "тип функції не може мати явного параметра об'єкта"
 
 #: cp/decl.cc:13385
-#, fuzzy, gcc-internal-format
-#| msgid "a conversion function cannot have a trailing return type"
+#, gcc-internal-format
 msgid "a pointer to function type cannot have an explicit object parameter"
-msgstr "Функція перетворення не може мати приєднаний тип повернення"
+msgstr "вказівник на тип функції не може мати явного параметра об'єкта"
 
 #: cp/decl.cc:13389
-#, fuzzy, gcc-internal-format
-#| msgid "  member function type %qT is not a valid template argument"
+#, gcc-internal-format
 msgid "a pointer to member function type cannot have an explicit object parameter"
-msgstr "  тип функції-члена %qT не є допустимим аргументом шаблона"
+msgstr "вказівник на тип функції-члена не може мати явного параметра об'єкта"
 
 #: cp/decl.cc:13397
 #, gcc-internal-format
 msgid "the type of a pointer to explicit object member function is a regular pointer to function type"
-msgstr ""
+msgstr "тип вказівника на явну членську функцію об'єкта є звичайним вказівником на тип функції"
 
 #: cp/decl.cc:13401
-#, fuzzy, gcc-internal-format
-#| msgid "typedef may not be a member function definition"
+#, gcc-internal-format
 msgid "the type of an explicit object member function is a regular function type"
-msgstr "typedef не може бути визначенням методу класу"
+msgstr "тип явної функції-члена об'єкта є звичайним типом функції"
 
 #: cp/decl.cc:13422
 #, gcc-internal-format
 msgid "only the first parameter of a member function can be declared as an explicit object parameter"
-msgstr ""
+msgstr "тільки перший параметр членської функції може бути оголошений як явний об'єктний параметр"
 
 #: cp/decl.cc:13427
-#, fuzzy, gcc-internal-format
-#| msgid "template parameter %qD declared here"
+#, gcc-internal-format
 msgid "valid explicit object parameter declared here"
-msgstr "параметр шаблона %qD оголошений тут"
+msgstr "дійсний явний параметр об'єкта оголошено тут"
 
 #: cp/decl.cc:13431
 #, gcc-internal-format
@@ -57233,27 +56749,24 @@ msgid "friend function definition %qs cannot have a name qualified with %<%D::%>
 msgstr "визначення friend-функції %qs не може мати імені, яке кваліфіковане з %<%D::%>"
 
 #: cp/decl.cc:13724
-#, fuzzy, gcc-internal-format
-#| msgid "non-member function %qD cannot have cv-qualifier"
+#, gcc-internal-format
 msgid "a non-member function cannot have an explicit object parameter"
-msgstr "функція, не є членом %qD, не може мати cv-кваліфікатор"
+msgstr "не-членська функція не може мати явного параметра об'єкта"
 
 #: cp/decl.cc:13732
-#, fuzzy, gcc-internal-format
-#| msgid "implicit templates may not be %<virtual%>"
+#, gcc-internal-format
 msgid "an explicit object member function cannot be %<virtual%>"
-msgstr "імпліцитні шаблони не можуть бути %<virtual%>"
+msgstr "явна функція-член об'єкта не може бути %<віртуальною%>"
 
 #: cp/decl.cc:13742
 #, gcc-internal-format
 msgid "an explicit object member function cannot be %<static%>"
-msgstr ""
+msgstr "явна членська функція об'єкта не може бути %<static%%>"
 
 #: cp/decl.cc:13751
-#, fuzzy, gcc-internal-format
-#| msgid "%qD must be a member function"
+#, gcc-internal-format
 msgid "%qD cannot be an explicit object member function"
-msgstr "%qD повинна бути функцією-членом"
+msgstr "%qD не може бути явною членською функцією об'єкта"
 
 #: cp/decl.cc:13774
 #, gcc-internal-format
@@ -57637,10 +57150,9 @@ msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "клас зберігання %<thread_local%> недійсний для функції %qs"
 
 #: cp/decl.cc:15041
-#, fuzzy, gcc-internal-format
-#| msgid "alignment specified for function %qE"
+#, gcc-internal-format
 msgid "%<constinit%> specifier invalid for function %qs"
-msgstr "вказано вирівнювання для функції %qE"
+msgstr "специфікатор %<constinit%> недійсний для функції %qs"
 
 #: cp/decl.cc:15044
 #, gcc-internal-format
@@ -58414,16 +57926,14 @@ msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT оголошено з більшою видимістю, ніж його база %qT"
 
 #: cp/decl2.cc:4714
-#, fuzzy, gcc-internal-format
-#| msgid "%q#D, declared using unnamed type, is used but never defined"
+#, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but never defined"
-msgstr "%q#D, оголошений за допомогою безіменного типу, використовується, але ніколи не визначений"
+msgstr "%q#D, оголошений за допомогою безіменного типу, використовується, але ніколи не визначено"
 
 #: cp/decl2.cc:4718
-#, fuzzy, gcc-internal-format
-#| msgid "%q#D, declared using unnamed type, is used but never defined"
+#, gcc-internal-format
 msgid "%q#D, declared using an unnamed type, is used but not defined"
-msgstr "%q#D, оголошений за допомогою безіменного типу, використовується, але ніколи не визначений"
+msgstr "%q#D, оголошений за допомогою безіменного типу, використовується, але не визначено"
 
 #. DRs 132, 319 and 389 seem to indicate types with
 #. no linkage can only be used to declare extern "C"
@@ -58450,10 +57960,9 @@ msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q#D, оголошений за допомогою локального типу %qT, використовується, але ніколи не визначений"
 
 #: cp/decl2.cc:4758
-#, fuzzy, gcc-internal-format
-#| msgid "%q#D, declared using local type %qT, is used but never defined"
+#, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but not defined here"
-msgstr "%q#D, оголошений за допомогою локального типу %qT, використовується, але ніколи не визначений"
+msgstr "%q#D, оголошений за допомогою локального типу %qT, використовується, але не визначено тут"
 
 #: cp/decl2.cc:4766
 #, gcc-internal-format
@@ -59802,52 +59311,44 @@ msgid "declaration %qD conflicts with builtin"
 msgstr "декларація %qD конфліктує з вбудованою функцією"
 
 #: cp/module.cc:19122
-#, fuzzy, gcc-internal-format
-#| msgid "declaration %qD conflicts with import"
+#, gcc-internal-format
 msgid "redeclaring %qD in module %qs conflicts with import"
-msgstr "декларація %qD конфліктує з імпортом"
+msgstr "повторне оголошення %qD у модулі %qs конфліктує з імпортом"
 
 #: cp/module.cc:19125
-#, fuzzy, gcc-internal-format
-#| msgid "declaration %qD conflicts with import"
+#, gcc-internal-format
 msgid "redeclaring %qD in global module conflicts with import"
-msgstr "декларація %qD конфліктує з імпортом"
+msgstr "повторне оголошення %qD у глобальному модулі конфліктує з імпортом"
 
 #: cp/module.cc:19130
-#, fuzzy, gcc-internal-format
-#| msgid "import declared %q#D here"
+#, gcc-internal-format
 msgid "import declared attached to module %qs"
-msgstr "імпорт оголошено %q#D тут"
+msgstr "імпорт оголошений прикріплений до модуля %qs"
 
 #: cp/module.cc:19134
-#, fuzzy, gcc-internal-format
-#| msgid "import-declaration must be at global scope"
+#, gcc-internal-format
 msgid "import declared in global module"
-msgstr "Декларація імпорту повинна бути в глобальному контексті"
+msgstr "імпорт оголошений у глобальному модулі"
 
 #: cp/module.cc:19140
-#, fuzzy, gcc-internal-format
-#| msgid "conflicting declaration of template %q#D"
+#, gcc-internal-format
 msgid "conflicting declaration of %qD in module %qs"
-msgstr "конфліктна декларація шаблону %q#D"
+msgstr "конфліктне оголошення %qD у модулі %qs"
 
 #: cp/module.cc:19143
-#, fuzzy, gcc-internal-format
-#| msgid "conflicting declaration of %q#D with %qL linkage"
+#, gcc-internal-format
 msgid "conflicting declaration of %qD in global module"
-msgstr "конфліктуюче оголошення %q#D з %qL звʼязком"
+msgstr "конфліктне оголошення %qD у глобальному модулі"
 
 #: cp/module.cc:19148
-#, fuzzy, gcc-internal-format
-#| msgid "previously declared as %s"
+#, gcc-internal-format
 msgid "previously declared in module %qs"
-msgstr "раніше оголошено як %s"
+msgstr "раніше оголошений у модулі %qs"
 
 #: cp/module.cc:19152
-#, fuzzy, gcc-internal-format
-#| msgid "previously declared as %s"
+#, gcc-internal-format
 msgid "previously declared in global module"
-msgstr "раніше оголошено як %s"
+msgstr "раніше оголошений у глобальному модулі"
 
 #: cp/module.cc:19404
 #, gcc-internal-format
@@ -59992,10 +59493,9 @@ msgid "unknown header kind %qs"
 msgstr "невідомий тип заголовка %qs"
 
 #: cp/name-lookup.cc:2860 cp/name-lookup.cc:3936 cp/name-lookup.cc:4033
-#, fuzzy, gcc-internal-format
-#| msgid "alias template deduction only available with %<-std=c++20%> or %<-std=gnu++20%>"
+#, gcc-internal-format
 msgid "name-independent declarations only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
-msgstr "виведення псевдоніма шаблону доступне лише з %<-std=c++20%> або %<-std=gnu++20%>"
+msgstr "оголошення незалежні від імені доступні тільки з %<-std=c++2c%> або %<-std=gnu++2c%>"
 
 #: cp/name-lookup.cc:2891
 #, gcc-internal-format
@@ -60053,28 +59553,24 @@ msgid "%s %s %p %d"
 msgstr "%s %s %p %d"
 
 #: cp/name-lookup.cc:5158
-#, fuzzy, gcc-internal-format
-#| msgid "%q#D does not have external linkage"
+#, gcc-internal-format
 msgid "exporting %q#D that does not have external linkage"
-msgstr "%q#D не має зовнішнього звʼязку"
+msgstr "експортування %q#D, яке не має зовнішнього посилання"
 
 #: cp/name-lookup.cc:5163
-#, fuzzy, gcc-internal-format
-#| msgid "%q#D declared here"
+#, gcc-internal-format
 msgid "%q#D declared here with no linkage"
-msgstr "%q#D оголошений тут"
+msgstr "%q#D оголошений тут без посилання"
 
 #: cp/name-lookup.cc:5166
-#, fuzzy, gcc-internal-format
-#| msgid "%q#D does not have external linkage"
+#, gcc-internal-format
 msgid "%q#D declared here with internal linkage"
-msgstr "%q#D не має зовнішнього звʼязку"
+msgstr "%q#D оголошений тут з внутрішнім посиланням"
 
 #: cp/name-lookup.cc:5169
-#, fuzzy, gcc-internal-format
-#| msgid "%q#D declared here"
+#, gcc-internal-format
 msgid "%q#D declared here with module linkage"
-msgstr "%q#D оголошений тут"
+msgstr "%q#D оголошений тут з посиланням на модуль"
 
 #: cp/name-lookup.cc:5968
 #, gcc-internal-format
@@ -60200,10 +59696,9 @@ msgid "  %qE"
 msgstr "  %qE"
 
 #: cp/name-lookup.cc:7176
-#, fuzzy, gcc-internal-format
-#| msgid "%<std::%s%> is defined in header %qs; did you forget to %<#include %s%>?"
+#, gcc-internal-format
 msgid "%<std::%s%> is defined in header %qs; this is probably fixable by adding %<#include %s%>"
-msgstr "%<std::%s%> визначено в заголовку %qs; ви забули %<#include %s%>?"
+msgstr "%<std::%s%> визначено в заголовку %qs; це, ймовірно, можна виправити додаванням %<#include %s%>"
 
 #: cp/name-lookup.cc:7182
 #, gcc-internal-format
@@ -60783,16 +60278,14 @@ msgid "%<~auto%> only available with %<-std=c++14%> or %<-std=gnu++14%>"
 msgstr "%<~auto%> доступний лише з %<-std=c++14%> або %<-std=gnu++14%>"
 
 #: cp/parser.cc:6729 cp/parser.cc:6733
-#, fuzzy, gcc-internal-format
-#| msgid "template-id not allowed for destructor"
+#, gcc-internal-format
 msgid "template-id not allowed for destructor in C++20"
-msgstr "template-id не дозволено для деструктора"
+msgstr "шаблонний ідентифікатор не дозволено для деструктора в C++20"
 
 #: cp/parser.cc:6735 cp/parser.cc:32586
-#, fuzzy, gcc-internal-format
-#| msgid "remove parentheses"
+#, gcc-internal-format
 msgid "remove the %qs"
-msgstr "видалити дужки"
+msgstr "видаліть %qs"
 
 #: cp/parser.cc:6843
 #, gcc-internal-format
@@ -60885,15 +60378,14 @@ msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr "два підряд %<[%> можуть вводити лише атрибут"
 
 #: cp/parser.cc:8017
-#, fuzzy, gcc-internal-format
-#| msgid "types may not be defined within %<__builtin_offsetof%>"
+#, gcc-internal-format
 msgid "types may not be defined in %<__builtin_classify_type%> calls"
-msgstr "Типи не можуть бути визначені всередині %<__builtin_offsetof%>"
+msgstr "типи не можуть бути визначені у викликах %<__builtin_classify_type%>"
 
 #: cp/parser.cc:8400 cp/parser.cc:8429
 #, gcc-internal-format
 msgid "cannot use multidimensional subscript in OpenMP array section"
-msgstr ""
+msgstr "неможливо використовувати індекс з декількома вимірами у секції масиву OpenMP"
 
 #: cp/parser.cc:8687 cp/typeck.cc:3049
 #, gcc-internal-format
@@ -60998,7 +60490,7 @@ msgstr "Типи не можуть бути визначені всередин
 #: cp/parser.cc:11229
 #, gcc-internal-format
 msgid "trailing argument to %<__type_pack_element%> is not a type"
-msgstr ""
+msgstr "наступний аргумент для %<__type_pack_element%> не є типом"
 
 #: cp/parser.cc:11329
 #, gcc-internal-format
@@ -61114,34 +60606,32 @@ msgstr "Оголошення параметра перед специфікат
 #: cp/parser.cc:11932 cp/pt.cc:14783
 #, gcc-internal-format
 msgid "a lambda with captures may not have an explicit object parameter of an unrelated type"
-msgstr ""
+msgstr "лямбда-функція з захопленнями не може мати явного об'єктного параметра непов'язаного типу"
 
 #: cp/parser.cc:11945
-#, fuzzy, gcc-internal-format
-#| msgid "%<static%> lambda specifier with lambda capture"
+#, gcc-internal-format
 msgid "%<mutable%> lambda specifier with explicit object parameter"
-msgstr "Специфікатор лямбди %<static%> з захопленням лямбди"
+msgstr "специфікатор %<mutable%> для лямбда-функції з явним об'єктним параметром"
 
 #: cp/parser.cc:11954
 #, gcc-internal-format
 msgid "the passed in closure object will not be mutated because it is taken by value"
-msgstr ""
+msgstr "Об'єкт замикання, що передається, не буде змінено, оскільки він приймається по значенню"
 
 #: cp/parser.cc:11958
 #, gcc-internal-format
 msgid "declare the explicit object parameter as non-const reference instead"
-msgstr ""
+msgstr "Оголосіть явний об'єктний параметр як неконстантне посилання замість цього"
 
 #: cp/parser.cc:11962
 #, gcc-internal-format
 msgid "explicit object parameter is already a mutable reference"
-msgstr ""
+msgstr "явний об'єктний параметр вже є змінабельним посиланням"
 
 #: cp/parser.cc:11969
-#, fuzzy, gcc-internal-format
-#| msgid "%<static%> lambda specifier with lambda capture"
+#, gcc-internal-format
 msgid "%<static%> lambda specifier with explicit object parameter"
-msgstr "Специфікатор лямбди %<static%> з захопленням лямбди"
+msgstr "специфікатор %<static%> для лямбда-функції з явним об'єктним параметром"
 
 #: cp/parser.cc:11987
 #, gcc-internal-format
@@ -61332,10 +60822,9 @@ msgid "expected jump-statement"
 msgstr "очікується оператор переходу"
 
 #: cp/parser.cc:15090
-#, fuzzy, gcc-internal-format
-#| msgid "expected module-name"
+#, gcc-internal-format
 msgid "expected module-partition"
-msgstr "очікується імʼя модуля"
+msgstr "очікується module-partition"
 
 #: cp/parser.cc:15092
 #, gcc-internal-format
@@ -61381,7 +60870,7 @@ msgstr "Декларація імпорту повинна бути в глоб
 #: cp/parser.cc:15241
 #, gcc-internal-format
 msgid "import specifying a module-partition must appear after a named module-declaration"
-msgstr ""
+msgstr "імпортування, що вказує на модуль-розділ, повинно з'являтися після іменованого оголошення модуля"
 
 #: cp/parser.cc:15253
 #, gcc-internal-format
@@ -61479,10 +60968,9 @@ msgid "invalid initializer for structured binding declaration"
 msgstr "недійсний ініціалізатор для оголошення структурованої привʼязки"
 
 #: cp/parser.cc:16371
-#, fuzzy, gcc-internal-format
-#| msgid "DATA array %qs at %L must be specified in a previous declaration"
+#, gcc-internal-format
 msgid "%<this%> must be the first specifier in a parameter declaration"
-msgstr "Масив DATA %qs на %L повинен бути вказаний в попередньому оголошенні"
+msgstr "%<this%> має бути першим специфікатором у декларації параметра"
 
 #: cp/parser.cc:16394
 #, gcc-internal-format
@@ -61570,10 +61058,9 @@ msgid "%<static_assert%> without a message only available with %<-std=c++17%> or
 msgstr "%<static_assert%> без повідомлення доступний лише з %<-std=c++17%> або %<-std=gnu++17%>"
 
 #: cp/parser.cc:16974
-#, fuzzy, gcc-internal-format
-#| msgid "%<static_assert%> without a message only available with %<-std=c++17%> or %<-std=gnu++17%>"
+#, gcc-internal-format
 msgid "%<static_assert%> with non-string message only available with %<-std=c++2c%> or %<-std=gnu++2c%>"
-msgstr "%<static_assert%> без повідомлення доступний лише з %<-std=c++17%> або %<-std=gnu++17%>"
+msgstr "%<static_assert%> з повідомленням, що не є рядком, доступний лише з %<-std=c++2c%> або %<-std=gnu++2c%>"
 
 #: cp/parser.cc:17172
 #, gcc-internal-format
@@ -61798,10 +61285,9 @@ msgid "use of %<auto%> in lambda parameter declaration only available with %<-st
 msgstr "використання %<auto%> у оголошенні параметра лямбди доступно лише з %<-std=c++14%> або %<-std=gnu++14%>"
 
 #: cp/parser.cc:20356
-#, fuzzy, gcc-internal-format
-#| msgid "use of %<auto%> in parameter declaration only available with %<-std=c++20%> or %<-fconcepts%>"
+#, gcc-internal-format
 msgid "use of %<auto%> in template argument only available with %<-fconcepts-ts%>"
-msgstr "використання %<auto%> у оголошенні параметра доступно лише з %<-std=c++20%> або %<-fconcepts%>"
+msgstr "використання %<auto%> у аргументі шаблону доступне лише з %<-fconcepts-ts%>"
 
 #: cp/parser.cc:20360
 #, gcc-internal-format
@@ -61896,7 +61382,7 @@ msgstr "типи не можуть бути визначені в основі 
 #: cp/parser.cc:21618
 #, gcc-internal-format
 msgid "declaration of enumeration with fixed underlying type and no enumerator list is only permitted as a standalone declaration"
-msgstr ""
+msgstr "оголошення перерахування з фіксованим типом основи та без списку елементів можливе лише як окреме оголошення."
 
 #: cp/parser.cc:21622
 #, gcc-internal-format
@@ -62024,10 +61510,9 @@ msgid "comma-separated list in using-declaration only available with %<-std=c++1
 msgstr "розділений комами список у використанні-оголошенні доступний лише з %<-std=c++17%> або %<-std=gnu++17%>"
 
 #: cp/parser.cc:22408
-#, fuzzy, gcc-internal-format
-#| msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
+#, gcc-internal-format
 msgid "access declarations are deprecated in favor of using-declarations; suggestion: add the %<using%> keyword"
-msgstr "оголошення доступу застарілі на користь оголошень «using»; пропозиція: додайте ключове слово %<using%>"
+msgstr "оголошення доступу застарілі на користь using-декларацій; пропозиція: додайте ключове слово %<using%>"
 
 #: cp/parser.cc:22454
 #, gcc-internal-format
@@ -62090,10 +61575,9 @@ msgid "%<asm%> qualifier outside of function body"
 msgstr "вказівник %<asm%> поза тілом функції"
 
 #: cp/parser.cc:22948
-#, fuzzy, gcc-internal-format
-#| msgid "attribute ignored in declaration of %q#T"
+#, gcc-internal-format
 msgid "attributes ignored on %<asm%> declaration"
-msgstr "атрибут ігнорується в оголошенні %q#T"
+msgstr "атрибути ігноруються на оголошенні %<asm%>"
 
 #: cp/parser.cc:23035
 #, gcc-internal-format
@@ -62288,16 +61772,14 @@ msgid "types may not be defined in parameter types"
 msgstr "типи не можуть бути визначені в типах параметрів"
 
 #: cp/parser.cc:25732
-#, fuzzy, gcc-internal-format
-#| msgid "too few template parameter lists in declaration of %qD"
+#, gcc-internal-format
 msgid "%<this%> specifier in template parameter declaration"
-msgstr "занадто мало списків параметрів шаблону в оголошенні %qD"
+msgstr "специфікатор %<this%> у декларації шаблону параметра"
 
 #: cp/parser.cc:25792
-#, fuzzy, gcc-internal-format
-#| msgid "non-parameter %qs cannot be a parameter pack"
+#, gcc-internal-format
 msgid "an explicit object parameter cannot be a function parameter pack"
-msgstr "непараметр %qs не може бути пакетом параметрів"
+msgstr "явний об'єктний параметр не може бути пакунком параметрів функції"
 
 #: cp/parser.cc:25839
 #, gcc-internal-format
@@ -62320,10 +61802,9 @@ msgid "parameter pack cannot have a default argument"
 msgstr "параметр пакету не може мати значення за замовчуванням"
 
 #: cp/parser.cc:25888
-#, fuzzy, gcc-internal-format
-#| msgid "template parameter pack cannot have a default argument"
+#, gcc-internal-format
 msgid "an explicit object parameter may not have a default argument"
-msgstr "параметр пакету шаблону не може мати значення за замовчуванням"
+msgstr "явний об'єктний параметр може не мати значення за замовчуванням"
 
 #: cp/parser.cc:26012
 #, gcc-internal-format
@@ -62605,10 +62086,9 @@ msgid "expected attribute before %<...%>"
 msgstr "очікується атрибут перед %<...%>"
 
 #: cp/parser.cc:30221
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute without arguments on a non-prototype"
+#, gcc-internal-format
 msgid "attribute with no arguments contains no parameter packs"
-msgstr "Атрибут %qE без аргументів на не-прототипі"
+msgstr "атрибут без аргументів не містить параметрів пакунків"
 
 #: cp/parser.cc:30267
 #, gcc-internal-format
@@ -62691,10 +62171,9 @@ msgid "too many template-parameter-lists"
 msgstr "занадто багато списків параметрів шаблону"
 
 #: cp/parser.cc:32585
-#, fuzzy, gcc-internal-format
-#| msgid "template-id not allowed for destructor"
+#, gcc-internal-format
 msgid "template-id not allowed for constructor in C++20"
-msgstr "template-id не дозволено для деструктора"
+msgstr "template-id не дозволено для конструктора в C++20"
 
 #: cp/parser.cc:32696
 #, gcc-internal-format
@@ -63107,10 +62586,9 @@ msgid "%<wait%> expression must be integral"
 msgstr "Вираз %<wait%> повинен бути цілочисельним"
 
 #: cp/parser.cc:39685
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<scalar%>, %<aggregate%> or %<pointer%>"
+#, gcc-internal-format
 msgid "expected %<scalar%>, %<aggregate%>, %<all%>"
-msgstr "очікується %<scalar%>, %<aggregate%> або %<pointer%>"
+msgstr "очікується %<scalar%>, %<aggregate%>, %<all%>"
 
 #: cp/parser.cc:40076
 #, gcc-internal-format
@@ -63248,10 +62726,9 @@ msgid "%<#pragma omp assumes%> may only be used at file or namespace scope"
 msgstr "%<#pragma omp assumes%> може використовуватися тільки на рівні файлу або простору імен"
 
 #: cp/parser.cc:51118
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma GCC ivdep%> must be inside a function"
+#, gcc-internal-format
 msgid "%<#pragma GCC %s%> must be inside a function"
-msgstr "%<#pragma GCC ivdep%> повинен бути всередині функції"
+msgstr "%<#pragma GCC %s%> має бути всередині функції"
 
 #: cp/parser.cc:51260
 #, gcc-internal-format
@@ -64819,16 +64296,14 @@ msgid "  since %q+#D declared in base class"
 msgstr "  оскільки %q+#D оголошено в базовому класі"
 
 #: cp/search.cc:2292
-#, fuzzy, gcc-internal-format
-#| msgid "virtual function %q+D overriding final function"
+#, gcc-internal-format
 msgid "explicit object member function overrides virtual function"
-msgstr "віртуальна функція %q+D перевизначає фінальну функцію"
+msgstr "явний член-функція об'єкта перевизначає віртуальну функцію"
 
 #: cp/search.cc:2295
-#, fuzzy, gcc-internal-format
-#| msgid "resolver indirect function declared here"
+#, gcc-internal-format
 msgid "virtual function declared here"
-msgstr "розвʼязувач індиректної функції оголошено тут"
+msgstr "тут оголошена віртуальна функція"
 
 #: cp/semantics.cc:1114
 #, gcc-internal-format
@@ -64836,16 +64311,14 @@ msgid "%<std::is_constant_evaluated%> always evaluates to true in %<if constexpr
 msgstr "%<std::is_constant_evaluated%> завжди оцінюється як true в %<if constexpr%>"
 
 #: cp/semantics.cc:1120
-#, fuzzy, gcc-internal-format
-#| msgid "%<std::is_constant_evaluated%> always evaluates to true in a %<consteval%> function"
+#, gcc-internal-format
 msgid "%<std::is_constant_evaluated%> evaluates to true when checking if trivially empty iteration statement is trivial infinite loop"
-msgstr "%<std::is_constant_evaluated%> завжди видає значення true в функції %<consteval%>"
+msgstr "%<std::is_constant_evaluated%> оцінюється як істина при перевірці, чи є тривіально порожнім оператором ітерації тривіальним нескінченним циклом"
 
 #: cp/semantics.cc:1125
-#, fuzzy, gcc-internal-format
-#| msgid "%<std::is_constant_evaluated%> always evaluates to false in a non-%<constexpr%> function"
+#, gcc-internal-format
 msgid "and evaluates to false when actually evaluating the condition in non-%<constexpr%> function"
-msgstr "%<std::is_constant_evaluated%> завжди видає значення false в неконстантній функції"
+msgstr "і оцінюється як хиба при фактичній оцінці умови в не-%<constexpr%> функції"
 
 #: cp/semantics.cc:1130
 #, gcc-internal-format
@@ -64923,22 +64396,19 @@ msgid "arguments to destructor are not allowed"
 msgstr "аргументи до деструктора не допускаються"
 
 #: cp/semantics.cc:3246
-#, fuzzy, gcc-internal-format
-#| msgid "%<this%> is unavailable for static member functions"
+#, gcc-internal-format
 msgid "%<this%> is unavailable for explicit object member functions"
-msgstr "%<this%> недоступний для статичних методів-членів"
+msgstr "%<this%> недоступний для членських функцій явних об'єктів"
 
 #: cp/semantics.cc:3258
-#, fuzzy, gcc-internal-format
-#| msgid "use the apostrophe directive %qs instead"
+#, gcc-internal-format
 msgid "use explicit object parameter %qs instead"
-msgstr "використовуйте директиву апострофа %qs замість цього"
+msgstr "замість цього використовуйте явний об'єктний параметр %qs"
 
 #: cp/semantics.cc:3262
-#, fuzzy, gcc-internal-format
-#| msgid "invalid template non-type parameter"
+#, gcc-internal-format
 msgid "name the explicit object parameter"
-msgstr "недійсний не-типізований параметр шаблону"
+msgstr "назвіть явний об'єктний параметр"
 
 #: cp/semantics.cc:3267
 #, gcc-internal-format
@@ -65097,21 +64567,19 @@ msgid "%qT is not an enumeration type"
 msgstr "%qT не є перелічувальним типом"
 
 #: cp/semantics.cc:4717
-#, fuzzy, gcc-internal-format
-#| msgid "requested alignment is not an integer constant"
+#, gcc-internal-format
 msgid "%<__type_pack_element%> index is not an integral constant"
-msgstr "запитане вирівнювання не є цілочисельною константою"
+msgstr "індекс %<__type_pack_element%> не є цілочисельною сталою"
 
 #: cp/semantics.cc:4723
 #, gcc-internal-format
 msgid "%<__type_pack_element%> index is negative"
-msgstr ""
+msgstr "Індекс %<__type_pack_element%> негативний"
 
 #: cp/semantics.cc:4729
-#, fuzzy, gcc-internal-format
-#| msgid "Reference statement index out of range"
+#, gcc-internal-format
 msgid "%<__type_pack_element%> index is out of range"
-msgstr "індекс заяви про посилання поза діапазоном"
+msgstr "індекс %<__type_pack_element%> виходить за межі діапазону"
 
 #. Parameter packs can only be used in templates
 #: cp/semantics.cc:4852
@@ -65145,10 +64613,9 @@ msgid "%<offsetof%> within non-standard-layout type %qT is conditionally-support
 msgstr "%<offsetof%> в межах типу %qT, який не відповідає стандартному розташуванню, підтримується умовно"
 
 #: cp/semantics.cc:6117
-#, fuzzy, gcc-internal-format
-#| msgid "constructor priorities are not supported"
+#, gcc-internal-format
 msgid "pointer-to-member mapping %qE not supported"
-msgstr "Пріоритети конструкторів не підтримуються"
+msgstr "відповідність вказівника на член %qE не підтримується"
 
 #: cp/semantics.cc:6311
 #, gcc-internal-format
@@ -65419,46 +64886,42 @@ msgstr "%<#pragma omp atomic update%> використовує два різни
 #: cp/semantics.cc:11580
 #, gcc-internal-format
 msgid "%<static_assert%> message must be a string literal or object with %<size%> and %<data%> members"
-msgstr ""
+msgstr "Повідомлення %<static_assert%> має бути рядком або об'єктом з членами %<size%> і %<data%>"
 
 #: cp/semantics.cc:11596
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be implicitly convertible to %<std::size_t%>"
-msgstr ""
+msgstr "Повідомлення %<static_assert%>: розмір %<size()%> має бути неявно перетворюваним у %<std::size_t%>"
 
 #: cp/semantics.cc:11605
 #, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be implicitly convertible to %<const char*%>"
-msgstr ""
+msgstr "Повідомлення %<static_assert%>: %<data()%> має автоматично перетворюватися на %<const char*%>"
 
 #: cp/semantics.cc:11663
-#, fuzzy, gcc-internal-format
-#| msgid "%<hint%> expression must be constant integer expression"
+#, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> must be a constant expression"
-msgstr "вираз %<hint%> повинен бути сталим цілочисельним виразом"
+msgstr "повідомлення %<static_assert%> %<size()%> повинно бути сталим виразом"
 
 #: cp/semantics.cc:11671
 #, gcc-internal-format
 msgid "%<static_assert%> message %<size()%> %qE too large"
-msgstr ""
+msgstr "Розмір повідомлення %<static_assert%> завеликий: %<size()%> %qE "
 
 #: cp/semantics.cc:11698
-#, fuzzy, gcc-internal-format
-#| msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
+#, gcc-internal-format
 msgid "%<static_assert%> message %<data()[%d]%> must be a constant expression"
-msgstr "%<reinterpret_cast<%T>(%E)%> не є константним виразом"
+msgstr "повідомлення %<static_assert%> %<data()[%d]%> повинно бути сталим виразом"
 
 #: cp/semantics.cc:11725
-#, fuzzy, gcc-internal-format
-#| msgid "argument %d of %qE must be an integer constant expression"
+#, gcc-internal-format
 msgid "%<static_assert%> message %<data()%> must be a core constant expression"
-msgstr "аргумент %d функції %qE повинен бути цілочисельним константним виразом"
+msgstr "повідомлення %<static_assert%> %<data()%> повинно бути основним сталим виразом"
 
 #: cp/semantics.cc:11751
-#, fuzzy, gcc-internal-format
-#| msgid "static assertion failed: %s"
+#, gcc-internal-format
 msgid "static assertion failed: %.*s"
-msgstr "статичне твердження не вдалося: %s"
+msgstr "статична перевірка не пройдена: %.*s"
 
 #: cp/semantics.cc:11759
 #, gcc-internal-format
@@ -65719,10 +65182,9 @@ msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "атрибут %qE застосовується до зовнішньої «C»-декларації %qD"
 
 #: cp/tree.cc:5420
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument must be a string constant"
+#, gcc-internal-format
 msgid "%qE attribute argument must be an expression that evaluates to true or false"
-msgstr "Аргумент атрибуту %qE повинен бути рядковою константою"
+msgstr "аргумент атрибуту %qE повинен бути виразом, який оцінюється як істина або хиба"
 
 #: cp/tree.cc:6290
 #, gcc-internal-format
@@ -66061,10 +65523,9 @@ msgid "the compiler can assume that the address of %qD will never be NULL"
 msgstr "компілятор може припустити, що адреса %qD ніколи не буде NULL"
 
 #: cp/typeck.cc:5052
-#, fuzzy, gcc-internal-format
-#| msgid "bitwise operation between different enumeration types %qT and %qT is deprecated"
+#, gcc-internal-format
 msgid "bitwise operation between different enumeration types %qT and %qT"
-msgstr "операція побітового І або АБО між різними типами перелічування %qT та %qT застаріла"
+msgstr "бітові операції між різними перераховуваними типами %qT та %qT"
 
 #: cp/typeck.cc:5055
 #, gcc-internal-format
@@ -66072,10 +65533,9 @@ msgid "bitwise operation between different enumeration types %qT and %qT is depr
 msgstr "операція побітового І або АБО між різними типами перелічування %qT та %qT застаріла"
 
 #: cp/typeck.cc:5061
-#, fuzzy, gcc-internal-format
-#| msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
+#, gcc-internal-format
 msgid "arithmetic between different enumeration types %qT and %qT"
-msgstr "арифметична операція між різними типами перелічування %qT та %qT застаріла"
+msgstr "арифметичні операції між різними перераховуваними типами %qT та %qT"
 
 #: cp/typeck.cc:5064
 #, gcc-internal-format
@@ -66083,16 +65543,14 @@ msgid "arithmetic between different enumeration types %qT and %qT is deprecated"
 msgstr "арифметична операція між різними типами перелічування %qT та %qT застаріла"
 
 #: cp/typeck.cc:5101
-#, fuzzy, gcc-internal-format
-#| msgid "comparison of enumeration type %qT with floating-point type %qT is deprecated"
+#, gcc-internal-format
 msgid "comparison of enumeration type %qT with floating-point type %qT"
-msgstr "Порівняння перелічувального типу %qT з типом з плаваючою комою %qT є застарілим"
+msgstr "порівняння перераховуваного типу %qT з типом з плаваючою комою %qT"
 
 #: cp/typeck.cc:5104
-#, fuzzy, gcc-internal-format
-#| msgid "comparison of floating-point type %qT with enumeration type %qT is deprecated"
+#, gcc-internal-format
 msgid "comparison of floating-point type %qT with enumeration type %qT"
-msgstr "Порівняння типу з плаваючою комою %qT з перелічувальним типом %qT є застарілим"
+msgstr "порівняння типу з плаваючою комою %qT з перераховуваним типом %qT"
 
 #: cp/typeck.cc:5107
 #, gcc-internal-format
@@ -66105,16 +65563,14 @@ msgid "comparison of floating-point type %qT with enumeration type %qT is deprec
 msgstr "Порівняння типу з плаваючою комою %qT з перелічувальним типом %qT є застарілим"
 
 #: cp/typeck.cc:5120
-#, fuzzy, gcc-internal-format
-#| msgid "arithmetic between enumeration type %qT and floating-point type %qT is deprecated"
+#, gcc-internal-format
 msgid "arithmetic between enumeration type %qT and floating-point type %qT"
-msgstr "Арифметика між перелічувальним типом %qT та типом з плаваючою комою %qT є застарілою"
+msgstr "арифметичні операції між перерахуванням типу %qT і типом з плаваючою комою %qT"
 
 #: cp/typeck.cc:5123
-#, fuzzy, gcc-internal-format
-#| msgid "arithmetic between floating-point type %qT and enumeration type %qT is deprecated"
+#, gcc-internal-format
 msgid "arithmetic between floating-point type %qT and enumeration type %qT"
-msgstr "Арифметика між типом з плаваючою комою %qT та перелічувальним типом %qT є застарілою"
+msgstr "арифметичні операції між типом з плаваючою комою %qT і перерахуванням типу %qT"
 
 #: cp/typeck.cc:5126
 #, gcc-internal-format
@@ -66221,10 +65677,9 @@ msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non
 msgstr "ISO C++ забороняє взяти адресу некваліфікованої або укладеної нестатичної член-функції для створення вказівника на член-функцію. Скажіть %<&%T::%D%>"
 
 #: cp/typeck.cc:7152
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
+#, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to explicit object member function"
-msgstr "ISO C++ забороняє взяти адресу некваліфікованої або укладеної нестатичної член-функції для створення вказівника на член-функцію. Скажіть %<&%T::%D%>"
+msgstr "ISO C++ забороняє брати адресу некваліфікованої або дужкової нестатичної функції-члена для формування вказівника на явну функцію-член об'єкта"
 
 #: cp/typeck.cc:7158
 #, gcc-internal-format
@@ -66232,16 +65687,14 @@ msgid "ISO C++ forbids taking the address of a bound member function to form a p
 msgstr "ISO C++ забороняє взяти адресу привʼязаної член-функції для створення вказівника на член-функцію. Скажіть %<&%T::%D%>"
 
 #: cp/typeck.cc:7164
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
+#, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to explicit object member function"
-msgstr "ISO C++ забороняє взяти адресу привʼязаної член-функції для створення вказівника на член-функцію. Скажіть %<&%T::%D%>"
+msgstr "ISO C++ забороняє брати адресу прив'язаної функції-члена для формування вказівника на явну функцію-член об'єкта"
 
 #: cp/typeck.cc:7169
-#, fuzzy, gcc-internal-format
-#| msgid "(a pointer to member can only be formed with %<&%E%>)"
+#, gcc-internal-format
 msgid "a pointer to explicit object member function can only be formed with %<&%T::%D%>"
-msgstr "(вказівник на член може бути створений лише з %<&%E%>)"
+msgstr "вказівник на явну функцію-член об'єкта може бути сформований тільки з %<&%T::%D%>"
 
 #. Make this a permerror because we used to accept it.
 #: cp/typeck.cc:7202
@@ -66581,10 +66034,9 @@ msgid "returning reference to temporary"
 msgstr "повернення посилання на тимчасовий обʼєкт"
 
 #: cp/typeck.cc:10633
-#, fuzzy, gcc-internal-format
-#| msgid "returning reference to temporary"
+#, gcc-internal-format
 msgid "returning pointer to temporary"
-msgstr "повернення посилання на тимчасовий обʼєкт"
+msgstr "повертається вказівник на тимчасовий об'єкт"
 
 #: cp/typeck.cc:10636
 #, gcc-internal-format
@@ -66681,15 +66133,14 @@ msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (
 msgstr "%<operator new%> не повинен повертати NULL, якщо він не оголошений %<throw()%> (або %<-fcheck-new%> активований)"
 
 #: cp/typeck.cc:11299
-#, fuzzy, gcc-internal-format
-#| msgid "invalid covariant return type for %q#D"
+#, gcc-internal-format
 msgid "not eliding copy on return from %qD"
-msgstr "недійсний коваріантний тип повернення для %q#D"
+msgstr "не проводиться оптимізація копіювання при поверненні з %qD"
 
 #: cp/typeck.cc:11311
 #, gcc-internal-format
 msgid "not eliding copy on return in %qD"
-msgstr ""
+msgstr "не скорочуємо копіювання при поверненні в %qD"
 
 #: cp/typeck.cc:11898
 #, gcc-internal-format
@@ -67195,21 +66646,19 @@ msgid "cast from %qs to %qs will produce zero result"
 msgstr "приведення типу з %qs до %qs призведе до нульового результату"
 
 #: d/d-convert.cc:748
-#, fuzzy, gcc-internal-format
-#| msgid "cannot convert %qE from type %qT to type %qT"
+#, gcc-internal-format
 msgid "cannot convert parameter %qs from type %qs to type %qs in assignment"
-msgstr "не можливо перетворити %qE з типу %qT в тип %qT"
+msgstr "неможливо конвертувати параметр %qs з типу %qs до типу %qs при присвоюванні"
 
 #: d/d-convert.cc:754
-#, fuzzy, gcc-internal-format
-#| msgid "cannot convert %qH to %qI in argument passing"
+#, gcc-internal-format
 msgid "cannot convert parameter %qs from type %qs to type %qs in argument passing"
-msgstr "не можна перетворити %qH на %qI при передачі аргументу"
+msgstr "неможливо конвертувати параметр %qs з типу %qs до типу %qs при передачі аргументів"
 
 #: d/d-convert.cc:759
 #, gcc-internal-format
 msgid "parameters of type %<va_list%> {aka %qs} are decayed to pointer types, and require %<va_copy%> to be converted back into a static array type"
-msgstr ""
+msgstr "параметри типу %<va_list%> {також відомі як %qs} розпадаються до вказівників і вимагають використання %<va_copy%>, щоб перетворитися назад у статичний масив"
 
 #: d/d-lang.cc:463
 #, gcc-internal-format
@@ -67232,28 +66681,24 @@ msgid "bad argument for %<-fversion%>: %qs"
 msgstr "невірний аргумент для %<-fversion%>: %qs"
 
 #: d/d-lang.cc:968
-#, fuzzy, gcc-internal-format
-#| msgid "error: unable to open '%s' for writing: %s\n"
+#, gcc-internal-format
 msgid "unable to open %s for writing: %m"
-msgstr "помилка: неможливо відкрити '%s' для запису: %s\n"
+msgstr "не вдалося відкрити %s для запису: %m"
 
 #: d/d-lang.cc:975
-#, fuzzy, gcc-internal-format
-#| msgid "opening output file %s: %m"
+#, gcc-internal-format
 msgid "writing output file %s: %m"
-msgstr "не вдалося відкрити вихідний файл %s: %m"
+msgstr "запис вихідного файлу %s: %m"
 
 #: d/d-lang.cc:995
-#, fuzzy, gcc-internal-format
-#| msgid "error: unable to open '%s' for writing: %s\n"
+#, gcc-internal-format
 msgid "unable to open %s for reading: %m"
-msgstr "помилка: неможливо відкрити '%s' для запису: %s\n"
+msgstr "не вдалося відкрити %s для читання: %m"
 
 #: d/d-lang.cc:1020
-#, fuzzy, gcc-internal-format
-#| msgid "opening json file %s: %m"
+#, gcc-internal-format
 msgid "reading ddoc file %s: %m"
-msgstr "відкриття json-файлу %s: %m"
+msgstr "читання файлу ddoc %s: %m"
 
 #: d/d-lang.cc:1079
 #, gcc-internal-format
@@ -67332,16 +66777,14 @@ msgid "cannot handle comparison of type %<%s == %s%>"
 msgstr "не можу обробити порівняння типу %<%s == %s%>"
 
 #: d/expr.cc:717
-#, fuzzy, gcc-internal-format
-#| msgid "expression %qs requires %<object.TypeInfo%> and cannot be used with %<-fno-rtti%>"
+#, gcc-internal-format
 msgid "array concatenation of expression %qs requires the GC and cannot be used with %<-fno-druntime%>"
-msgstr "вираз %qs потребує %<object.TypeInfo%> і не може використовуватися з %<-fno-rtti%>"
+msgstr "конкатенація масиву виразу %qs вимагає GC і не може бути використано з %<-fno-druntime%>"
 
 #: d/expr.cc:811
-#, fuzzy, gcc-internal-format
-#| msgid "expression %qs requires %<object.TypeInfo%> and cannot be used with %<-fno-rtti%>"
+#, gcc-internal-format
 msgid "appending to array in %qs requires the GC and cannot be used with %<-fno-druntime%>"
-msgstr "вираз %qs потребує %<object.TypeInfo%> і не може використовуватися з %<-fno-rtti%>"
+msgstr "додавання елементів до масиву в %qs вимагає GC і не може бути використано з %<-fno-druntime%>"
 
 #. Static arrays have already been handled by the front-end.
 #: d/expr.cc:1286
@@ -67426,10 +66869,9 @@ msgstr "несумісність при виклику вбудованої фу
 
 #. It's a D language intrinsic with no library implementation.
 #: d/intrinsics.cc:1479
-#, fuzzy, gcc-internal-format
-#| msgid "built-in function %qE must be directly called"
+#, gcc-internal-format
 msgid "intrinsic function %qE must be directly called"
-msgstr "вбудовану функцію %qE потрібно викликати безпосередньо"
+msgstr "вбудована функція %qE повинна бути безпосередньо викликаною"
 
 #: d/modules.cc:417
 #, gcc-internal-format
@@ -67439,7 +66881,7 @@ msgstr "%<-fmoduleinfo%> не підтримується на цій цілі"
 #: d/toir.cc:245
 #, gcc-internal-format
 msgid "calling %qE without side effects discards return value of type %qT; prepend a %<cast(void)%> if intentional"
-msgstr ""
+msgstr "Виклик %qE без побічних ефектів відкидає значення типу %qT; додайте %<cast(void)%>, якщо це намірне"
 
 #: d/toir.cc:419 d/toir.cc:444
 #, gcc-internal-format
@@ -67992,10 +67434,9 @@ msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008:
 msgstr "Значення конструктора масиву на %L не може бути необмежено поліморфним [F2008: C4106]"
 
 #: fortran/array.cc:2215
-#, fuzzy, gcc-internal-format
-#| msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
+#, gcc-internal-format
 msgid "Different CHARACTER lengths (%wd/%wd) in array constructor at %L"
-msgstr "Різні довжини CHARACTER (%ld/%ld) в конструкторі масиву на %L"
+msgstr "різні довжини символів (%wd/%wd) у конструкторі масиву в %L"
 
 #: fortran/array.cc:2333
 #, gcc-internal-format
@@ -68219,10 +67660,9 @@ msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr "Нерівні довжини символів (%ld/%ld) в %s на %L"
 
 #: fortran/check.cc:1269
-#, fuzzy, gcc-internal-format
-#| msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
+#, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%wd/%ld)"
-msgstr "Розмір аргументу %qs вбудованої функції %qs на %L занадто малий (%i/%i)"
+msgstr "Розмір аргументу %qs для вбудованої функції %qs у %L занадто малий (%wd/%ld)"
 
 #: fortran/check.cc:1332
 #, gcc-internal-format, gfc-internal-format
@@ -68856,16 +68296,14 @@ msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr "Поліморфний FPTR на %L до C_F_POINTER"
 
 #: fortran/check.cc:5476
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qE attribute on a function not returning a pointer"
+#, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument to C_F_POINTER at %L is a function returning a pointer"
-msgstr "атрибут %qE на функції, яка не повертає вказівник"
+msgstr "Аргумент FPTR для C_F_POINTER у %L є функцією, яка повертає вказівник"
 
 #: fortran/check.cc:5483
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
+#, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR argument to C_F_POINTER at %L: %s"
-msgstr "Несумісний масив FPTR на %L до C_F_POINTER: %s"
+msgstr "Несумісний з інтерфейсом масив FPTR аргумент для C_F_POINTER у %L: %s"
 
 #: fortran/check.cc:5499
 #, gcc-internal-format, gfc-internal-format
@@ -69038,10 +68476,8 @@ msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "Аргумент %<MOLD%> вбудованої функції %<TRANSFER%> на %L не повинен бути %s"
 
 #: fortran/check.cc:6307
-#, fuzzy
-#| msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %zd < result size %zd"
-msgstr "Вбудована функція TRANSFER на %L має частково невизначений результат: розмір джерела %ld < розмір результату %ld"
+msgstr "Вбудована функція TRANSFER у %L має частково невизначений результат: розмір джерела %zd < розмір результату %zd"
 
 #: fortran/check.cc:6431
 #, gcc-internal-format
@@ -69054,16 +68490,14 @@ msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "Аргументи %qs і %qs інтринсичної функції %qs на %L повинні мати однакову форму."
 
 #: fortran/check.cc:6580
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
+#, gcc-internal-format, gfc-internal-format
 msgid "VALUES argument of DATE_AND_TIME at %L has non-default kind"
-msgstr "Аргумент COUNT для SYSTEM_CLOCK на %L має нестандартний тип"
+msgstr "Аргумент VALUES для DATE_AND_TIME у %L має тип, відмінний від стандартного"
 
 #: fortran/check.cc:6592
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
+#, gcc-internal-format, gfc-internal-format
 msgid "VALUES argument of DATE_AND_TIME at %L must have a decimal exponent range of at least four"
-msgstr "Аргументом ATANH у %L має бути число у діапазоні від -1 до 1"
+msgstr "Аргумент VALUES для DATE_AND_TIME у %L повинен мати діапазон десяткового експонента не менше чотирьох"
 
 #: fortran/check.cc:6731 fortran/check.cc:6763
 #, gcc-internal-format
@@ -69091,10 +68525,9 @@ msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "Аргумент COUNT для SYSTEM_CLOCK на %L має нестандартний тип"
 
 #: fortran/check.cc:6850
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
+#, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L with kind smaller than default integer"
-msgstr "Аргумент COUNT для SYSTEM_CLOCK на %L має нестандартний тип"
+msgstr "Аргумент COUNT для SYSTEM_CLOCK у %L з типом меншим за стандартний цілий"
 
 #: fortran/check.cc:6871
 #, gcc-internal-format, gfc-internal-format
@@ -69107,10 +68540,9 @@ msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "Аргумент COUNT_RATE для SYSTEM_CLOCK на %L має нестандартний тип"
 
 #: fortran/check.cc:6888
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
+#, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L with kind smaller than default integer"
-msgstr "Аргумент COUNT_RATE для SYSTEM_CLOCK на %L має нестандартний тип"
+msgstr "Аргумент COUNT_RATE для SYSTEM_CLOCK у %L з типом меншим за стандартний цілий"
 
 #: fortran/check.cc:6908
 #, gcc-internal-format, gfc-internal-format
@@ -69118,16 +68550,14 @@ msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "Аргумент COUNT_MAX для SYSTEM_CLOCK на %L має нестандартний тип"
 
 #: fortran/check.cc:6918
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
+#, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L with kind smaller than default integer"
-msgstr "Аргумент COUNT_MAX для SYSTEM_CLOCK на %L має нестандартний тип"
+msgstr "Аргумент COUNT_MAX для SYSTEM_CLOCK у %L з типом меншим за стандартний цілий"
 
 #: fortran/check.cc:6933 fortran/check.cc:6940
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
+#, gcc-internal-format, gfc-internal-format
 msgid "integer arguments to SYSTEM_CLOCK at %L with different kind parameters"
-msgstr "Аргумент COUNT для SYSTEM_CLOCK на %L має нестандартний тип"
+msgstr "Цілочисельні аргументи для SYSTEM_CLOCK у %L з різними параметрами типу"
 
 #: fortran/check.cc:7154
 #, gcc-internal-format
@@ -69177,16 +68607,14 @@ msgid "non-constant array in DATA statement %L"
 msgstr "неконстантний масив у операторі DATA %L"
 
 #: fortran/data.cc:78
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
+#, gcc-internal-format, gfc-internal-format
 msgid "Subscript at %L below array lower bound (%ld < %ld) in dimension %d"
-msgstr "Посилання на масив на %L виходить за межі (%ld < %ld) в розмірності %d"
+msgstr "Індекс у %L нижче нижньої межі масиву (%ld < %ld) у розмірності %d"
 
 #: fortran/data.cc:89
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
+#, gcc-internal-format, gfc-internal-format
 msgid "Subscript at %L above array upper bound (%ld > %ld) in dimension %d"
-msgstr "Нижнє посилання на масив на %L виходить за межі (%ld > %ld) в розмірності %d"
+msgstr "Індекс у %L вище верхньої межі масиву (%ld > %ld) у розмірності %d"
 
 #: fortran/data.cc:172
 #, gcc-internal-format, gfc-internal-format
@@ -69199,10 +68627,9 @@ msgid "Unused initialization string at %L because variable has zero length"
 msgstr "Невикористана рядок ініціалізації на %L, оскільки змінна має нульову довжину"
 
 #: fortran/data.cc:211
-#, fuzzy, gcc-internal-format
-#| msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
+#, gcc-internal-format
 msgid "Initialization string at %L was truncated to fit the variable (%wd/%wd)"
-msgstr "Рядок ініціалізації на %L був обрізаний, щоб відповідати змінній (%ld/%ld)"
+msgstr "Рядок ініціалізації у %L був скорочений, щоб вміститися у змінну (%wd/%wd)"
 
 #: fortran/data.cc:220 fortran/resolve.cc:5298
 #, gcc-internal-format, gfc-internal-format
@@ -70301,15 +69728,14 @@ msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Повторний символ %qs у списку формальних аргументів на %C"
 
 #: fortran/decl.cc:6823
-#, fuzzy, gcc-internal-format
-#| msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
+#, gcc-internal-format
 msgid "MODULE PROCEDURE formal argument %qs conflicts with alternate return at %C"
-msgstr "Неспівпадіння імен формальних аргументів MODULE PROCEDURE (%s/%s) на %C"
+msgstr "Формальний аргумент MODULE PROCEDURE %qs конфліктує з альтернативним поверненням у %C"
 
 #: fortran/decl.cc:6827
 #, gcc-internal-format
 msgid "MODULE PROCEDURE formal argument is alternate return and conflicts with %qs in the separate declaration at %C"
-msgstr ""
+msgstr "Формальний аргумент MODULE PROCEDURE є альтернативним поверненням і конфліктує з %qs у окремому оголошенні на рядку %C"
 
 #: fortran/decl.cc:6832
 #, gcc-internal-format, gfc-internal-format
@@ -71912,10 +71338,9 @@ msgid "%qs at %L associated to expression cannot be used in a variable definitio
 msgstr "%qs на %L, повʼязаний з виразом, не може бути використаний в контексті визначення змінної (%s)"
 
 #: fortran/expr.cc:6513
-#, fuzzy, gcc-internal-format
-#| msgid "%qs at %L associated to expression cannot be used in a variable definition context (%s)"
+#, gcc-internal-format
 msgid "%qs at %L associated to pointer function target being used in a variable definition context (%s)"
-msgstr "%qs на %L, повʼязаний з виразом, не може бути використаний в контексті визначення змінної (%s)"
+msgstr "%qs у %L пов'язаний з цільовою функцією вказівника, яка використовується у контексті визначення змінної (%s)"
 
 #: fortran/expr.cc:6532
 #, gcc-internal-format
@@ -72428,12 +71853,12 @@ msgstr "Неочікувана альтернативна специфікаці
 #: fortran/interface.cc:3326
 #, gcc-internal-format
 msgid "Intrinsic %<NULL()%> without %<MOLD%> argument at %L passed to assumed-rank dummy %qs"
-msgstr ""
+msgstr "Внутрішня функція %<NULL()%> без аргументу %<MOLD%> на рядку %L передається в формальний аргумент з припущеним рангом %qs"
 
 #: fortran/interface.cc:3340
 #, gcc-internal-format
 msgid "Intrinsic %<NULL()%> without %<MOLD%> argument at %L passed to assumed-length dummy %qs"
-msgstr ""
+msgstr "Вбудована функція %<NULL()%> без аргументу %<MOLD%> на рядку %L передається в формальний аргумент з припущеною довжиною %qs"
 
 #: fortran/interface.cc:3362
 #, gcc-internal-format
@@ -72451,10 +71876,9 @@ msgid "Actual argument at %L to assumed-type dummy has type parameters or is of
 msgstr "Фактичний аргумент на %L для припущеного типу фіктивного має параметри типу або є похідним типом з типовими або FINAL процедурами"
 
 #: fortran/interface.cc:3403
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
+#, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic actual argument at %L is not matched with either an unlimited polymorphic or assumed type dummy argument"
-msgstr "Коіндексований поліморфний фактичний аргумент на %L передається поліморфному фіктивному аргументу %qs"
+msgstr "Необмежений поліморфний фактичний аргумент у %L не відповідає ні необмеженому поліморфному, ні припущеному типу формального аргументу"
 
 #: fortran/interface.cc:3427
 #, gcc-internal-format
@@ -72549,7 +71973,7 @@ msgstr "Фактичний аргумент для %qs повинен бути A
 #: fortran/interface.cc:3745
 #, gcc-internal-format
 msgid "Actual argument for %qs at %L is a function result and the dummy argument is ALLOCATABLE"
-msgstr ""
+msgstr "Фактичний аргумент для %qs на рядку %L є результатом функції, а формальний аргумент має властивість ALLOCATABLE"
 
 #: fortran/interface.cc:3783
 #, gcc-internal-format
@@ -73755,7 +73179,7 @@ msgstr "помилка: check_charlen_present(): довжина не встан
 #: fortran/iresolve.cc:3029
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: unlimited polymorphic MOLD in TRANSFER intrinsic at %L"
-msgstr ""
+msgstr "ЗРОБИТИ: необмежений поліморфний MOLD у вбудованій функції TRANSFER на рядку %L"
 
 #: fortran/match.cc:118
 #, gcc-internal-format
@@ -74582,10 +74006,9 @@ msgid "Symbol %qs in namelist %qs at %C must be declared before the namelist is
 msgstr "Символ %qs у списку імен %qs у %C повинен бути оголошений до оголошення списку імен."
 
 #: fortran/match.cc:5652
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol %qs at %L conflicts with the symbol at %L"
+#, gcc-internal-format
 msgid "Derived type %qs at %L conflicts with namelist object %qs at %C"
-msgstr "Символ %qs у %L конфліктує з символом у %L"
+msgstr "Похідний тип %qs у %L конфліктує з об'єктом списку імені %qs у %C"
 
 #: fortran/match.cc:5672
 #, gcc-internal-format
@@ -75121,7 +74544,7 @@ msgstr "Елемент списку не може бути співіндекс
 #: fortran/openmp.cc:493
 #, gcc-internal-format
 msgid "%qs at %L is part of the common block %</%s/%> and may only be specificed implicitly via the named common block"
-msgstr ""
+msgstr "%qs у %L є частиною блоку спільних даних %</%s/%> і може бути вказаний неявно через іменований блок спільних даних"
 
 #: fortran/openmp.cc:518 fortran/openmp.cc:619 fortran/openmp.cc:949
 #: fortran/openmp.cc:6165
@@ -75237,13 +74660,12 @@ msgstr "Директива %qs згадується як в ABSENT, так і в
 #: fortran/openmp.cc:1746
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s modifier at %L in USES_ALLOCATORS clause"
-msgstr ""
+msgstr "Дубльований модифікатор %s у %L у клаузі USES_ALLOCATORS"
 
 #: fortran/openmp.cc:1780
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<(%> at %C"
+#, gcc-internal-format
 msgid "Unexpected %<(%> at %C"
-msgstr "очікується %<(%> на %C"
+msgstr "Неочікуваний %<(%> у %C"
 
 #: fortran/openmp.cc:1827
 #, gcc-internal-format
@@ -75292,16 +74714,14 @@ msgid "COLLAPSE clause argument not constant positive integer at %C"
 msgstr "Аргумент COLLAPSE-замикання не є сталим додатнім цілочисельним у %C"
 
 #: fortran/openmp.cc:2251
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected ALLOC, TO, FROM, TOFROM, FIRSTPRIVATE, NONE or DEFAULT at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Expected ALLOC, TO, FROM, TOFROM, FIRSTPRIVATE, PRESENT, NONE or DEFAULT at %C"
-msgstr "Очікувалася ALLOC, TO, FROM, TOFROM, FIRSTPRIVATE, NONE або DEFAULT у %C"
+msgstr "Очікується ALLOC, TO, FROM, TOFROM, FIRSTPRIVATE, PRESENT, NONE або DEFAULT у %C"
 
 #: fortran/openmp.cc:2273
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected SCALAR, AGGREGATE, ALLOCATABLE or POINTER at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Expected SCALAR, AGGREGATE, ALLOCATABLE, POINTER or ALL at %C"
-msgstr "Очікувався тип SCALAR, AGGREGATE, ALLOCATABLE або POINTER у %C"
+msgstr "Очікується SCALAR, AGGREGATE, ALLOCATABLE, POINTER або ALL у %C"
 
 #: fortran/openmp.cc:2306
 #, gcc-internal-format, gfc-internal-format
@@ -75394,10 +74814,9 @@ msgid "Expected SEQ_CST, ACQUIRE or RELAXED at %C"
 msgstr "Очікується SEQ_CST, ACQUIRE або RELAXED на %C"
 
 #: fortran/openmp.cc:2831
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "WAIT clause at %L requires a scalar INTEGER expression"
+#, gcc-internal-format, gfc-internal-format
 msgid "INDIRECT clause at %C requires a constant logical expression"
-msgstr "Замикання WAIT у %L вимагає скалярний цілочисельний вираз"
+msgstr "Клауза INDIRECT у %C вимагає сталого логічного виразу"
 
 #: fortran/openmp.cc:3018
 #, gcc-internal-format
@@ -75415,10 +74834,9 @@ msgid "too many %<close%> modifiers at %L"
 msgstr "забагато модифікаторів %<close%> в %L"
 
 #: fortran/openmp.cc:3140
-#, fuzzy, gcc-internal-format
-#| msgid "too many %<close%> modifiers at %L"
+#, gcc-internal-format
 msgid "too many %<present%> modifiers at %L"
-msgstr "забагато модифікаторів %<close%> в %L"
+msgstr "забагато модифікаторів %<present%> у %L"
 
 #: fortran/openmp.cc:3331
 #, gcc-internal-format
@@ -75526,22 +74944,19 @@ msgid "!$ACC ROUTINE with GANG, WORKER, or VECTOR clause is not permitted in PUR
 msgstr "!$ACC ROUTINE з замиканням GANG, WORKER або VECTOR не дозволяється в чистій процедурі на %C"
 
 #: fortran/openmp.cc:4598
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected COMPILATION or EXECUTION in AT clause at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Expected ALIGN or ALLOCATOR clause at %C"
-msgstr "Очікувалася COMPILATION або EXECUTION у AT-замиканні у %C"
+msgstr "Очікується клауза ALIGN або ALLOCATOR у %C"
 
 #: fortran/openmp.cc:4606
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Sorry, the event component of derived type at %L is not yet supported"
+#, gcc-internal-format, gfc-internal-format
 msgid "Sorry, structure-element list item at %L in ALLOCATE directive is not yet supported"
-msgstr "Вибачте, компонент події похідного типу на %L ще не підтримується"
+msgstr "Вибачте, елемент списку структури у %L в директиві ALLOCATE ще не підтримується"
 
 #: fortran/openmp.cc:4609
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected expression in %s statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Unexpected expression as list item at %L in ALLOCATE directive"
-msgstr "Очікується вираз у %s операторі на %C"
+msgstr "Неочікуваний вираз як елемент списку у %L в директиві ALLOCATE"
 
 #: fortran/openmp.cc:4680
 #, gcc-internal-format, gfc-internal-format
@@ -75566,7 +74981,7 @@ msgstr "Очікувався IN, OUT, INOUT, INOUTSET або MUTEXINOUTSET, за
 #: fortran/openmp.cc:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "The same depend object should be used as DEPOBJ argument at %L and as DESTROY argument at %L"
-msgstr ""
+msgstr "Один і той самий об'єкт залежності повинен бути використаний як аргумент DEPOBJ у %L і як аргумент DESTROY у %L"
 
 #: fortran/openmp.cc:4815
 #, gcc-internal-format, gfc-internal-format
@@ -75681,7 +75096,7 @@ msgstr "Елемент списку %qs у %L встановлено в попе
 #: fortran/openmp.cc:5577 fortran/openmp.cc:5631
 #, gcc-internal-format, gfc-internal-format
 msgid "DEVICE_TYPE must be ANY when used with INDIRECT at %L"
-msgstr ""
+msgstr "DEVICE_TYPE повинен бути ANY при використанні з INDIRECT у %L"
 
 #: fortran/openmp.cc:5587
 #, gcc-internal-format, gfc-internal-format
@@ -75704,10 +75119,9 @@ msgid "COMMON at %L set in previous OMP DECLARE TARGET directive to a different
 msgstr "COMMON на %L встановлено в попередній директиві OMP DECLARE TARGET на інший DEVICE_TYPE"
 
 #: fortran/openmp.cc:5641
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "OMP DECLARE TARGET directive at %L with only DEVICE_TYPE clause is ignored"
+#, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET directive at %L with only DEVICE_TYPE or INDIRECT clauses is ignored"
-msgstr "Директива OMP DECLARE TARGET на %L зі зазначенням тільки DEVICE_TYPE ігнорується"
+msgstr "Директива OMP DECLARE TARGET у %L з тільки DEVICE_TYPE або INDIRECT клаузами ігнорується"
 
 #: fortran/openmp.cc:5652
 #, gcc-internal-format, gfc-internal-format
@@ -75716,10 +75130,9 @@ msgstr "Синтаксична помилка в списку !$OMP DECLARE TARG
 
 #. FIXME: constant integer expressions.
 #: fortran/openmp.cc:5691
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected integer expression at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Expected trait-property-extension at %C"
-msgstr "Очікувався цілочисельний вираз на %C"
+msgstr "Очікується розширення властивості трактування у %C"
 
 #: fortran/openmp.cc:5706 fortran/openmp.cc:5803 fortran/openmp.cc:5934
 #: fortran/openmp.cc:6084 fortran/openmp.cc:6112
@@ -75733,10 +75146,9 @@ msgid "expected trait selector name at %C"
 msgstr "очікується імʼя селектора риси на %C"
 
 #: fortran/openmp.cc:5747
-#, fuzzy, gcc-internal-format
-#| msgid "selector %qs not allowed for context selector set %qs at %C"
+#, gcc-internal-format
 msgid "unknown selector %qs for context selector set %qs at %C"
-msgstr "селектор %qs не дозволений для набору селекторів контексту %qs на %C"
+msgstr "невідомий селектор %qs для набору селекторів контексту %qs у %C"
 
 #: fortran/openmp.cc:5765
 #, gcc-internal-format
@@ -75744,10 +75156,9 @@ msgid "selector %qs does not accept any properties at %C"
 msgstr "селектор %qs не приймає жодних властивостей на %C"
 
 #: fortran/openmp.cc:5774
-#, fuzzy, gcc-internal-format
-#| msgid "The %s directive cannot be specified within a %s region at %L"
+#, gcc-internal-format
 msgid "%<score%> cannot be specified in traits in the %qs trait-selector-set at %C"
-msgstr "Директива %s не може бути вказана всередині області %s на %L"
+msgstr "%<score%> не може бути вказано в властивостях у наборі селекторів %qs властивостей у %C"
 
 #: fortran/openmp.cc:5781 fortran/openmp.cc:5944 fortran/openmp.cc:6036
 #: fortran/openmp.cc:6103
@@ -75756,16 +75167,14 @@ msgid "expected %<(%> at %C"
 msgstr "очікується %<(%> на %C"
 
 #: fortran/openmp.cc:5789
-#, fuzzy, gcc-internal-format
-#| msgid "score argument must be constant integer expression at %C"
+#, gcc-internal-format
 msgid "%<score%> argument must be constant integer expression at %C"
-msgstr "аргумент score повинен бути сталим цілим виразом на %C"
+msgstr "аргумент %<score%> повинен бути сталою цілочисельним виразом у %C"
 
 #: fortran/openmp.cc:5797
-#, fuzzy, gcc-internal-format
-#| msgid "score argument must be non-negative at %C"
+#, gcc-internal-format
 msgid "%<score%> argument must be non-negative at %C"
-msgstr "аргумент 'score' повинен бути не відʼємним на %C"
+msgstr "аргумент %<score%> повинен бути невід'ємним у %C"
 
 #: fortran/openmp.cc:5809
 #, gcc-internal-format, gfc-internal-format
@@ -75788,22 +75197,19 @@ msgid "expected expression at %C"
 msgstr "очікується вираз у %C"
 
 #: fortran/openmp.cc:5883
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "property must be constant integer or logical expression at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "property must be a constant logical expression at %C"
-msgstr "властивість повинна бути константним цілочисельним або логічним виразом у %C"
+msgstr "властивість повинна бути сталою логічною виразом у %C"
 
 #: fortran/openmp.cc:5886
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "property must be constant integer expression"
+#, gcc-internal-format, gfc-internal-format
 msgid "property must be a constant integer expression at %C"
-msgstr "властивість повинна бути цілим сталим виразом"
+msgstr "властивість повинна бути сталим цілочисельним виразом в %C"
 
 #: fortran/openmp.cc:5898
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "property must be constant integer or logical expression at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "property must be a conforming device number at %C"
-msgstr "властивість повинна бути константним цілочисельним або логічним виразом у %C"
+msgstr "властивість повинна бути відповідним номером пристрою в %C"
 
 #: fortran/openmp.cc:5912
 #, gcc-internal-format, gfc-internal-format
@@ -75811,10 +75217,9 @@ msgid "expected simd clause at %C"
 msgstr "очікується замикання 'simd' у %C"
 
 #: fortran/openmp.cc:5985
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "expected trait selector name at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "expected context selector set name at %C"
-msgstr "очікується імʼя селектора риси на %C"
+msgstr "очікується ім'я набору селектора контексту в %C"
 
 #: fortran/openmp.cc:5992
 #, gcc-internal-format
@@ -75912,10 +75317,9 @@ msgid "!$OMP REQUIRES at %C must appear in the specification part of a program u
 msgstr "Замикання !$OMP REQUIRES в %C повинна зʼявлятися в частині специфікації програмного блоку"
 
 #: fortran/openmp.cc:6486
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected SEQ_CST, ACQ_REL or RELAXED for ATOMIC_DEFAULT_MEM_ORDER clause at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Expected ACQ_REL, ACQUIRE, RELAXED, RELEASE or SEQ_CST for ATOMIC_DEFAULT_MEM_ORDER clause at %C"
-msgstr "Очікується SEQ_CST, ACQ_REL або RELAXED для замикання ATOMIC_DEFAULT_MEM_ORDER в %C"
+msgstr "Очікується ACQ_REL, ACQUIRE, RELAXED, RELEASE або SEQ_CST для клаузи ATOMIC_DEFAULT_MEM_ORDER в %C"
 
 #: fortran/openmp.cc:6502
 #, gcc-internal-format, gfc-internal-format
@@ -75968,16 +75372,14 @@ msgid "!$OMP ATOMIC at %L with %s clause requires %s clause"
 msgstr "!$OMP ATOMIC на %L з замиканням %s вимагає замикання %s"
 
 #: fortran/openmp.cc:6937
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "!$OMP ATOMIC WRITE at %L incompatible with ACQUIRE clause"
+#, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC WRITE at %L incompatible with ACQUIRES clause implicitly provided by a REQUIRES directive"
-msgstr "!$OMP АТОМНИЙ ЗАПИС на %L несумісний з ACQUIRE-замиканням"
+msgstr "!$OMP ATOMIC WRITE в %L несумісний з клаузою ACQUIRES, яка надається неявно директивою REQUIRES"
 
 #: fortran/openmp.cc:6948
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "!$OMP ATOMIC READ at %L incompatible with RELEASE clause"
+#, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC READ at %L incompatible with RELEASE clause implicitly provided by a REQUIRES directive"
-msgstr "!$OMP ATOMIC READ на %L несумісний з RELEASE-замиканням"
+msgstr "!$OMP ATOMIC READ в %L несумісний з клаузою RELEASE, яка надається неявно директивою REQUIRES"
 
 #: fortran/openmp.cc:6966
 #, gcc-internal-format, gfc-internal-format
@@ -76102,80 +75504,77 @@ msgstr "Неявно оголошена підпрограма %s викорис
 #: fortran/openmp.cc:7379
 #, gcc-internal-format
 msgid "Unexpected function-result variable %qs at %L in declarative !$OMP ALLOCATE"
-msgstr ""
+msgstr "Несподівана змінна-результат функції %qs у %L у декларативному !$OMP ALLOCATE"
 
 #: fortran/openmp.cc:7385
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure pointer %qs in %s clause at %L"
+#, gcc-internal-format
 msgid "Procedure pointer %qs not supported with !$OMP ALLOCATE at %L"
-msgstr "Вказівник на процедуру %qs в замиканні %s на %L"
+msgstr "Вказівник на процедуру %qs не підтримується з !$OMP ALLOCATE в %L"
 
 #: fortran/openmp.cc:7391
 #, gcc-internal-format
 msgid "Argument %qs at %L to declarative !$OMP ALLOCATE directive must be a variable"
-msgstr ""
+msgstr "Аргумент %qs у %L до декларативної директиви !$OMP ALLOCATE повинен бути змінною"
 
 #: fortran/openmp.cc:7398
 #, gcc-internal-format
 msgid "Argument %qs at %L to declarative !$OMP ALLOCATE shall be in the same scope as the variable declaration"
-msgstr ""
+msgstr "Аргумент %qs у %L до декларативної директиви !$OMP ALLOCATE формально повинен бути в тому самому контексті, що і оголошення змінної"
 
 #: fortran/openmp.cc:7405
-#, fuzzy, gcc-internal-format
-#| msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
+#, gcc-internal-format
 msgid "Unexpected dummy argument %qs as argument at %L to declarative !$OMP ALLOCATE"
-msgstr "Фіктивний аргумент переданого обʼєкту %qs на %L не може бути ALLOCATABLE"
+msgstr "Неочікуваний аргумент-заглушка %qs як аргумент в %L до декларативного !$OMP ALLOCATE"
 
 #: fortran/openmp.cc:7411
 #, gcc-internal-format
 msgid "Unexpected coarray argument %qs as argument at %L to declarative !$OMP ALLOCATE"
-msgstr ""
+msgstr "Неочікуваний аргумент масиву з розподіленою пам'яттю %qs у %L для декларативного !$OMP ALLOCATE"
 
 #: fortran/openmp.cc:7419
 #, gcc-internal-format
 msgid "Duplicated common block %</%s/%> in !$OMP ALLOCATE at %L"
-msgstr ""
+msgstr "Дубльований спільний блок %</%s/%> у !$OMP ALLOCATE у %L"
 
 #: fortran/openmp.cc:7426
 #, gcc-internal-format
 msgid "Duplicated variable %qs in !$OMP ALLOCATE at %L"
-msgstr ""
+msgstr "Дубльована змінна %qs у !$OMP ALLOCATE у %L"
 
 #: fortran/openmp.cc:7437
 #, gcc-internal-format
 msgid "Sorry, EQUIVALENCE object %qs not supported with !$OMP ALLOCATE at %L"
-msgstr ""
+msgstr "Вибачте, але об'єкт EQUIVALENCE %qs не підтримується з !$OMP ALLOCATE у %L"
 
 #: fortran/openmp.cc:7446
 #, gcc-internal-format
 msgid "Sorry, Cray pointers and pointees such as %qs are not supported with !$OMP ALLOCATE at %L"
-msgstr ""
+msgstr "Вибачте, але покажчики Cray та їхні вказівники, такі як %qs, не підтримуються з !$OMP ALLOCATE у %L"
 
 #: fortran/openmp.cc:7455
 #, gcc-internal-format
 msgid "Unexpected allocatable variable %qs at %L in declarative !$OMP ALLOCATE directive"
-msgstr ""
+msgstr "Неочікувана змінна для аллокації %qs у %L у декларативній директиві !$OMP ALLOCATE"
 
 #: fortran/openmp.cc:7460
 #, gcc-internal-format
 msgid "Unexpected pointer variable %qs at %L in declarative !$OMP ALLOCATE directive"
-msgstr ""
+msgstr "Неочікувана змінна-вказівник %qs у %L у декларативній директиві !$OMP ALLOCATE"
 
 #: fortran/openmp.cc:7471 fortran/openmp.cc:8026
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ALIGN modifier requires at %L a scalar positive constant integer alignment expression that is a power of two"
+#, gcc-internal-format, gfc-internal-format
 msgid "ALIGN requires a scalar positive constant integer alignment expression at %L that is a power of two"
-msgstr "Модифікатор ALIGN вимагає на %L скалярний додатний цілочисельний вираз, що є степенем двійки"
+msgstr "ALIGN вимагає скалярний додатній сталий цілочисельний вираз вирівнювання в %L, який є степенем двійки"
 
 #: fortran/openmp.cc:7486
 #, gcc-internal-format
 msgid "An ALLOCATOR clause is required as the list item %<%s%s%s%> at %L has the SAVE attribute"
-msgstr ""
+msgstr "Необхідно вказати клаузу ALLOCATOR, оскільки елемент списку %<%s%s%s%> у %L має атрибут SAVE"
 
 #: fortran/openmp.cc:7491
 #, gcc-internal-format
 msgid "Predefined allocator required in ALLOCATOR clause at %L as the list item %<%s%s%s%> at %L has the SAVE attribute"
-msgstr ""
+msgstr "Превизначений алокатор потрібен у клаузі ALLOCATOR в %L, оскільки елемент списку %<%s%s%s%> в %L має атрибут SAVE"
 
 #: fortran/openmp.cc:7505 fortran/openmp.cc:8010
 #, gcc-internal-format
@@ -76214,10 +75613,9 @@ msgid "IF clause modifier %s at %L not appropriate for the current OpenMP constr
 msgstr "Модифікатор замикання IF %s на %L не підходить для поточної конструкції OpenMP"
 
 #: fortran/openmp.cc:7717
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "IF clause at %L requires a scalar LOGICAL expression"
+#, gcc-internal-format, gfc-internal-format
 msgid "SELF clause at %L requires a scalar LOGICAL expression"
-msgstr "Замикання IF на рядку %L вимагає скалярний логічний вираз"
+msgstr "Клауза SELF в %L вимагає скалярного логічного виразу"
 
 #: fortran/openmp.cc:7726
 #, gcc-internal-format, gfc-internal-format
@@ -76303,10 +75701,9 @@ msgid "Symbol %qs present on both data and map clauses at %L"
 msgstr "Символ %qs присутній як у замиканні data, так і у замиканні map на %L"
 
 #: fortran/openmp.cc:8051
-#, fuzzy, gcc-internal-format
-#| msgid "%qs appears more than once in %<allocate%> clauses at %L"
+#, gcc-internal-format
 msgid "%qs appears more than once in %<allocate%> at %L"
-msgstr "%qs зʼявляється більше одного разу в замиканнях %<allocate%> на %L"
+msgstr "%qs з'являється більше одного разу в %<allocate%> в %L"
 
 #: fortran/openmp.cc:8093
 #, gcc-internal-format
@@ -76314,41 +75711,39 @@ msgid "%qs specified in %<allocate%> clause at %L but not in an explicit privati
 msgstr "%qs вказано в замиканні %<allocate%> на %L, але не в явному замиканні приватизації"
 
 #: fortran/openmp.cc:8121
-#, fuzzy, gcc-internal-format
-#| msgid "Unexpected coarray designator at %C"
+#, gcc-internal-format
 msgid "Unexpected coarray %qs in %<allocate%> at %L"
-msgstr "Неочікуваний ідентифікатор комасиву у %C"
+msgstr "Неочікуваний комасив %qs у %<allocate%> в %L"
 
 #: fortran/openmp.cc:8135
-#, fuzzy, gcc-internal-format
-#| msgid "%qs specified in %<allocate%> clause at %L but not in an explicit privatization clause"
+#, gcc-internal-format
 msgid "%qs specified in %<allocate%> at %L but not in the associated ALLOCATE statement"
-msgstr "%qs вказано в замиканні %<allocate%> на %L, але не в явному замиканні приватизації"
+msgstr "%qs вказано в %<allocate%> в %L, але не в пов'язаному операторі ALLOCATE"
 
 #: fortran/openmp.cc:8169
 #, gcc-internal-format
 msgid "%qs listed in %<allocate%> statement at %L but it is neither explicitly in listed in the %<!$OMP ALLOCATE%> directive nor exists a directive without argument list"
-msgstr ""
+msgstr "%qs згадано в операторі %<allocate%> на %L, але він не явно зазначений у директиві %<!$OMP ALLOCATE%> і не існує директиви без списку аргументів"
 
 #: fortran/openmp.cc:8180
 #, gcc-internal-format
 msgid "Unexpected coarray %qs in %<allocate%> at %L, implicitly listed in %<!$OMP ALLOCATE%> at %L"
-msgstr ""
+msgstr "Неочікуваний комасив %qs у %<allocate%> в %L, неявно перерахований у %<!$OMP ALLOCATE%> в %L"
 
 #: fortran/openmp.cc:8205
 #, gcc-internal-format
 msgid "ALLOCATORS directive at %L inside a target region must specify an ALLOCATOR modifier for %qs"
-msgstr ""
+msgstr "Директива ALLOCATORS у %L всередині цільового регіону повинна вказувати модифікатор ALLOCATOR для %qs"
 
 #: fortran/openmp.cc:8209
 #, gcc-internal-format
 msgid "ALLOCATE directive at %L inside a target region must specify an ALLOCATOR clause for %qs"
-msgstr ""
+msgstr "Директива ALLOCATE у %L всередині цільового регіону повинна вказувати клаузу ALLOCATOR для %qs"
 
 #: fortran/openmp.cc:8213
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATE directive at %L inside a target region must specify an ALLOCATOR clause"
-msgstr ""
+msgstr "Директива ALLOCATE у %L всередині цільового регіону повинна вказувати клаузу ALLOCATOR"
 
 #: fortran/openmp.cc:8236
 #, gcc-internal-format
@@ -76529,28 +75924,27 @@ msgstr "Елемент списку %qs в замиканні %s на %L пов
 #: fortran/openmp.cc:8739
 #, gcc-internal-format
 msgid "Memspace %qs at %L in USES_ALLOCATORS must be a predefined memory space"
-msgstr ""
+msgstr "Простір пам'яті %qs у %L в USES_ALLOCATORS повинен бути превизначеним простором пам'яті"
 
 #: fortran/openmp.cc:8747
-#, fuzzy, gcc-internal-format
-#| msgid "%qs at %L should be a scalar of type integer(kind=omp_event_handle_kind)"
+#, gcc-internal-format
 msgid "Allocator %qs at %L in USES_ALLOCATORS must be a scalar integer of kind %<omp_allocator_handle_kind%>"
-msgstr "%qs на %L повинно бути скаляром типу integer(kind=omp_event_handle_kind)"
+msgstr "Аллокатор %qs в %L в USES_ALLOCATORS повинен бути скаляром цілого числа типу %<omp_allocator_handle_kind%>"
 
 #: fortran/openmp.cc:8755
 #, gcc-internal-format
 msgid "Allocator %qs at %L in USES_ALLOCATORS must either a variable or a predefined allocator"
-msgstr ""
+msgstr "Алокатор %qs у %L в USES_ALLOCATORS повинен бути або змінною, або превизначеним алокатором"
 
 #: fortran/openmp.cc:8760
 #, gcc-internal-format
 msgid "A memory space or traits array may not be specified for predefined allocator %qs at %L"
-msgstr ""
+msgstr "Простір пам'яті або масив властивостей не може бути вказаний для превизначеного алокатора %qs у %L"
 
 #: fortran/openmp.cc:8771
 #, gcc-internal-format
 msgid "Traits array %qs in USES_ALLOCATORS %L must be a one-dimensional named constant array of type %<omp_alloctrait%>"
-msgstr ""
+msgstr "Масив властивостей %qs у USES_ALLOCATORS %L повинен бути іменованим одновимірним масивом констант типу %<omp_alloctrait%>"
 
 #: fortran/openmp.cc:8801
 #, gcc-internal-format
@@ -76686,7 +76080,7 @@ msgstr "Замикання %<DETACH%> на %L не слід використов
 #: fortran/openmp.cc:9256
 #, gcc-internal-format
 msgid "%<host_data%> construct at %L requires %<use_device%> clause"
-msgstr ""
+msgstr "Конструкція %<host_data%> у %L вимагає клаузи %<use_device%>"
 
 #: fortran/openmp.cc:9410
 #, gcc-internal-format, gfc-internal-format
@@ -76824,35 +76218,34 @@ msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr "неочікуваний вираз !$OMP ATOMIC на %L"
 
 #: fortran/openmp.cc:9978
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "With INSCAN at %L, expected loop body with !$OMP SCAN between two structured-block-sequences"
+#, gcc-internal-format, gfc-internal-format
 msgid "With INSCAN at %L, expected loop body with !$OMP SCAN between two structured block sequences"
-msgstr "З INSCAN на %L очікується тіло циклу з !$OMP SCAN між двома послідовностями структурованих блоків"
+msgstr "З INSCAN в %L очікується тіло циклу з !$OMP SCAN між двома послідовностями структурованих блоків"
 
 #: fortran/openmp.cc:9985
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP SCAN at %L with zero executable statements in preceding structured block sequence"
-msgstr ""
+msgstr "!$OMP SCAN на %L без інструкцій у попередній структурованій послідовності блоків"
 
 #: fortran/openmp.cc:9992
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP SCAN at %L with zero executable statements in succeeding structured block sequence"
-msgstr ""
+msgstr "!$OMP SCAN в %L з нулем виконуваних інструкцій у наступній структурованій послідовності блоків"
 
 #: fortran/openmp.cc:10206
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot contain loop in intervening code at %L"
-msgstr ""
+msgstr "%s не може містити цикл у проміжному коді в %L"
 
 #: fortran/openmp.cc:10286
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot contain OpenMP directive in intervening code at %L"
-msgstr ""
+msgstr "%s не може містити директиву OpenMP в проміжному коді в %L"
 
 #: fortran/openmp.cc:10298 fortran/openmp.cc:10324
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot contain OpenMP API call in intervening code at %L"
-msgstr ""
+msgstr "%s не може містити виклик OpenMP API в проміжному коді в %L"
 
 #: fortran/openmp.cc:10852
 #, gcc-internal-format, gfc-internal-format
@@ -76890,10 +76283,9 @@ msgid "%s iteration variable used in more than one loop at %L"
 msgstr "Змінна ітерації %s використовується в більш ніж одній петлі на %L"
 
 #: fortran/openmp.cc:10904
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "iteration variable %qE should not be reduction"
+#, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable at %L is bound in intervening code"
-msgstr "ітераційна змінна %qE не повинна бути зменшуваною"
+msgstr "Змінна ітерації %s в %L є зв'язаною в проміжному коді"
 
 #: fortran/openmp.cc:10913
 #, gcc-internal-format, gfc-internal-format
@@ -76901,10 +76293,9 @@ msgid "%s loop start expression not in canonical form at %L"
 msgstr "Вираз початку петлі %s не знаходиться в канонічній формі на %L"
 
 #: fortran/openmp.cc:10920
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%s loop start expression not in canonical form at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "%s loop start expression at %L uses variable bound in intervening code"
-msgstr "Вираз початку петлі %s не знаходиться в канонічній формі на %L"
+msgstr "Вираз початку циклу %s в %L використовує зв'язану змінну в проміжному коді"
 
 #: fortran/openmp.cc:10929
 #, gcc-internal-format, gfc-internal-format
@@ -76914,7 +76305,7 @@ msgstr "Вираз кінця петлі %s не знаходиться в ка
 #: fortran/openmp.cc:10936
 #, gcc-internal-format, gfc-internal-format
 msgid "%s loop end expression at %L uses variable bound in intervening code"
-msgstr ""
+msgstr "Вираз кінця циклу %s на %L використовує змінну, визначену в проміжному коді"
 
 #: fortran/openmp.cc:10943
 #, gcc-internal-format, gfc-internal-format
@@ -76929,25 +76320,23 @@ msgstr "Приріст петлі %s не знаходиться в каноні
 #: fortran/openmp.cc:10956
 #, gcc-internal-format, gfc-internal-format
 msgid "%s loop increment expression at %L uses variable bound in intervening code"
-msgstr ""
+msgstr "Вираз інкременту циклу %s на %L використовує змінну, визначену в проміжному коді"
 
 #. Parse error, can't recover from this.
 #: fortran/openmp.cc:10974
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "not enough DO loops for collapsed %s at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s (level %d) at %L"
-msgstr "Недостатньо DO-циклів для згорнутого %s на %L"
+msgstr "недостатньо циклів DO для згорнутого %s (рівень %d) в %L"
 
 #: fortran/openmp.cc:10986
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%s !$ACC LOOP loops not perfectly nested at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "%s inner loops must be perfectly nested with ORDERED clause at %L"
-msgstr "Цикли %s !$ACC LOOP не є ідеально вкладеними на %L"
+msgstr "Внутрішні цикли %s повинні бути ідеально вкладені з клаузою ORDERED в %L"
 
 #: fortran/openmp.cc:10993
 #, gcc-internal-format, gfc-internal-format
 msgid "%s inner loops must be perfectly nested with REDUCTION INSCAN clause at %L"
-msgstr ""
+msgstr "Внутрішні цикли %s повинні бути правильно вкладені з клаузою REDUCTION INSCAN в %L"
 
 #: fortran/openmp.cc:11220 fortran/openmp.cc:11233
 #, gcc-internal-format, gfc-internal-format
@@ -77012,12 +76401,12 @@ msgstr "Імʼя %qs недійсне в !$ACC ROUTINE ( ІМʼЯ ) на %L"
 #: fortran/openmp.cc:11569
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP TARGET region at %L with a nested TEAMS at %L may not contain any other statement, declaration or directive outside of the single TEAMS construct"
-msgstr ""
+msgstr "Область !$OMP TARGET в %L з вкладеними TEAMS в %L не може містити жодної іншої інструкції, декларації або директиви, крім одного конструкту TEAMS."
 
 #: fortran/openmp.cc:11573
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP TARGET region at %L with a nested TEAMS may not contain any other statement, declaration or directive outside of the single TEAMS construct"
-msgstr ""
+msgstr "Область !$OMP TARGET в %L з вкладеними TEAMS не може містити жодної іншої інструкції, декларації або директиви поза одним конструктом TEAMS"
 
 #: fortran/openmp.cc:11667
 #, gcc-internal-format, gfc-internal-format
@@ -77197,23 +76586,22 @@ msgstr "Некласифікована директива OpenACC у %C"
 #: fortran/parse.cc:817
 #, gcc-internal-format
 msgid "%qs directive at %L must either have a variable argument or, if associated with an ALLOCATE stmt, must be preceded by an executable statement or OpenMP construct"
-msgstr ""
+msgstr "Директива %qs в %L повинна мати змінний аргумент або, якщо пов'язана з інструкцією ALLOCATE, то перед нею має бути блок коду або конструкція OpenMP."
 
 #: fortran/parse.cc:829
 #, gcc-internal-format
 msgid "Structure-component expression at %L in %qs directive not permitted in declarative directive; as directive associated with an ALLOCATE stmt it must be preceded by an executable statement or OpenMP construct"
-msgstr ""
+msgstr "Вираз компонента структури в %L директиві %qs не дозволений у декларативній директиві; якщо директива пов'язана з інструкцією ALLOCATE, то вона повинна бути перед іншою виконуваною інструкцією або конструкцією OpenMP"
 
 #: fortran/parse.cc:855
 #, gcc-internal-format
 msgid "%qs directive at %L associated with an ALLOCATE stmt must be preceded by an executable statement or OpenMP construct; note the variables in the list all have the allocatable or pointer attribute"
-msgstr ""
+msgstr "Директива %qs в %L, пов'язана з оператором ALLOCATE, має передувати виконуваному оператору або конструкції OpenMP. Зверніть увагу: усі змінні у списку мають атрибут allocatable або pointer"
 
 #: fortran/parse.cc:1023 fortran/parse.cc:1325
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "OpenACC directives other than ROUTINE may not appear in PURE procedures at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "OpenMP directive at %C is not pure and thus may not appear in a PURE procedure"
-msgstr "Директиви OpenACC, крім ROUTINE, не можуть зʼявлятися в PURE процедурах у %C"
+msgstr "Директива OpenMP в %C не є чистою і тому не може з'явитися в чистій процедурі"
 
 #: fortran/parse.cc:1296
 #, gcc-internal-format, gfc-internal-format
@@ -77223,7 +76611,7 @@ msgstr "Некласифікована директива OpenMP у %C"
 #: fortran/parse.cc:1312
 #, gcc-internal-format
 msgid "OpenMP ERROR directive at %L with %<at(execution)%> clause in a PURE procedure"
-msgstr ""
+msgstr "Директива OpenMP ERROR в %L з клаузою %<at(execution)%> у чистій процедурі"
 
 #: fortran/parse.cc:1440
 #, gcc-internal-format, gfc-internal-format
@@ -77633,19 +77021,17 @@ msgstr "Зайвий !$ACC END LOOP на %C"
 #: fortran/parse.cc:5835
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statements at %L and %L have both no list item but only one may"
-msgstr ""
+msgstr "Вирази %s в %L і %L пусті, але тільки один може"
 
 #: fortran/parse.cc:5855
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected expression at %C in PARAMETER statement"
+#, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s at %C; expected ALLOCATE or %s statement"
-msgstr "Очікувано вираз в операторі PARAMETER в %C"
+msgstr "Неочікуваний %s в %C; очікується оператор ALLOCATE або %s"
 
 #: fortran/parse.cc:5858
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected %<*%> in coindex specification in ALLOCATE statement at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s at %C; expected ALLOCATE statement after %s"
-msgstr "Очікується %<*%> в специфікації коіндексу в операторі ALLOCATE на %L"
+msgstr "Неочікуваний %s в %C; очікується оператор ALLOCATE після %s"
 
 #: fortran/parse.cc:6146
 #, gcc-internal-format, gfc-internal-format
@@ -77891,16 +77277,12 @@ msgid "match_string_constant(): Delimiter not found"
 msgstr "match_string_constant(): Роздільник не знайдено"
 
 #: fortran/primary.cc:1193
-#, fuzzy
-#| msgid "Substring start index (%ld) at %L below 1"
 msgid "Substring start index (%td) at %L below 1"
-msgstr "Початковий індекс підстрічки (%ld) на %L менше 1"
+msgstr "Початковий індекс підрядка (%td) в %L менше 1"
 
 #: fortran/primary.cc:1199
-#, fuzzy
-#| msgid "Substring end index (%ld) at %L exceeds string length"
 msgid "Substring end index (%td) at %L exceeds string length"
-msgstr "Кінцевий індекс підстрічки (%ld) на %L перевищує довжину рядка"
+msgstr "Кінцевий індекс підрядка (%td) в %L перевищує довжину рядка"
 
 #: fortran/primary.cc:1284
 #, gcc-internal-format, gfc-internal-format
@@ -78103,10 +77485,8 @@ msgid "Too many components in structure constructor at %L"
 msgstr "Занадто багато компонентів у конструкторі структури на %L"
 
 #: fortran/primary.cc:3393
-#, fuzzy
-#| msgid "CHARACTER expression will be truncated in constructor (%ld/%ld) at %L"
 msgid "CHARACTER expression will be truncated in constructor (%td/%td) at %L"
-msgstr "Вираз CHARACTER буде обрізаний у конструкторі (%ld/%ld) на %L"
+msgstr "Вираз CHARACTER буде скорочено в конструкторі (%td/%td) в %L"
 
 #: fortran/primary.cc:3411
 #, gcc-internal-format
@@ -78426,10 +77806,9 @@ msgid "%qs at %L cannot appear in COMMON [F2008:C5100]"
 msgstr "%qs на %L не може зʼявлятися в COMMON [F2008:C5100]"
 
 #: fortran/resolve.cc:1010
-#, fuzzy, gcc-internal-format
-#| msgid "Global entity %qs at %L cannot appear in a COMMON block at %L"
+#, gcc-internal-format
 msgid "Automatic object %qs at %L cannot appear in COMMON at %L"
-msgstr "Глобальна сутність %qs на %L не може зʼявлятися в блоку COMMON на %L"
+msgstr "Автоматичний об'єкт %qs в %L не може з'явитися в COMMON в %L"
 
 #: fortran/resolve.cc:1022
 #, gcc-internal-format
@@ -78577,15 +77956,14 @@ msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the curren
 msgstr "Вбудована функція %qs, оголошена як INTRINSIC у %L, недоступна в поточних налаштуваннях стандарту, але %s. Використовуйте відповідну опцію %<-std=*%> або увімкніть %<-fall-intrinsics%>, щоб використовувати її."
 
 #: fortran/resolve.cc:1971
-#, fuzzy, gcc-internal-format
-#| msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
+#, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs from module %qs is  possibly calling itself recursively in procedure %qs.  Declare it RECURSIVE or use %<-frecursive%>"
-msgstr "Можливо, нерекурсивна процедура %qs у %L викликається рекурсивно сама себе. Оголосіть її як RECURSIVE або використовуйте %<-frecursive%>"
+msgstr "Нерекурсивна процедура %qs з модуля %qs можливо викликає рекурсивно сама себе у процедурі %qs. Оголосіть її як RECURSIVE або використовуйте %<-frecursive%>"
 
 #: fortran/resolve.cc:1976 fortran/resolve.cc:6852
 #, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
-msgstr "Можливо, нерекурсивна процедура %qs у %L викликається рекурсивно сама себе. Оголосіть її як RECURSIVE або використовуйте %<-frecursive%>"
+msgstr "Можливо, нерекурсивна процедура %qs у %L викликає рекурсивно сама себе. Оголосіть її як RECURSIVE або використовуйте %<-frecursive%>"
 
 #: fortran/resolve.cc:2035 fortran/resolve.cc:10832 fortran/resolve.cc:12814
 #, gcc-internal-format, gfc-internal-format
@@ -79107,10 +78485,9 @@ msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Припущена змінна рангу %s на %L не повинна мати посилання на підобʼєкт"
 
 #: fortran/resolve.cc:5935
-#, fuzzy, gcc-internal-format
-#| msgid "Bad array reference at %L"
+#, gcc-internal-format
 msgid "Scalar variable %qs has an array reference at %L"
-msgstr "Погана посилання на масив на %L"
+msgstr "Скалярна змінна %qs має посилання на масив в %L"
 
 #: fortran/resolve.cc:6080
 #, gcc-internal-format
@@ -79138,10 +78515,9 @@ msgid "Using variable %qs at %L is deprecated"
 msgstr "Використання змінної %qs у %L є застарілим"
 
 #: fortran/resolve.cc:6239 fortran/resolve.cc:6324 fortran/resolve.cc:6348
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Bad array reference at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Invalid array reference at %L"
-msgstr "Погана посилання на масив на %L"
+msgstr "Неправильне посилання на масив в %L"
 
 #: fortran/resolve.cc:6433
 #, gcc-internal-format
@@ -79739,16 +79115,14 @@ msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Неправильний тип блоку"
 
 #: fortran/resolve.cc:11507
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Data transfer element at %L cannot have procedure pointer components"
+#, gcc-internal-format, gfc-internal-format
 msgid "Variable in the ordinary assignment at %L is a procedure pointer component"
-msgstr "Елемент передачі даних на %L не може мати компоненти вказівника на процедуру"
+msgstr "Змінна в звичайному присвоєнні в %L є компонентом вказівника на процедуру"
 
 #: fortran/resolve.cc:11568
-#, fuzzy, gcc-internal-format
-#| msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
+#, gcc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%wd/%wd) at %L"
-msgstr "Вираз CHARACTER буде обрізаний при присвоєнні (%ld/%ld) на %L"
+msgstr "Вираз CHARACTER буде скорочено в присвоєнні (%wd/%wd) в %L"
 
 #: fortran/resolve.cc:11600
 #, gcc-internal-format, gfc-internal-format
@@ -80241,16 +79615,14 @@ msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Аргумент %qs функції %qs з PASS(%s) на %L повинен бути похідним типом %qs"
 
 #: fortran/resolve.cc:15052
-#, fuzzy, gcc-internal-format
-#| msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
+#, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the parametric derived-type %qs"
-msgstr "Аргумент %qs функції %qs з PASS(%s) на %L повинен бути похідним типом %qs"
+msgstr "Аргумент %qs для %qs з PASS(%s) в %L повинен бути типу параметричного похідного типу %qs"
 
 #: fortran/resolve.cc:15094
-#, fuzzy, gcc-internal-format
-#| msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
+#, gcc-internal-format
 msgid "All LEN type parameters of the passed dummy argument %qs of %qs at %L must be ASSUMED."
-msgstr "Усі параметри типу LEN в інструкції TYPE IS на %C повинні бути ПРИПУЩЕНІ"
+msgstr "Всі параметри типу LEN переданого формального аргументу %qs для %qs на %L повинні бути позначені як ASSUMED."
 
 #: fortran/resolve.cc:15104
 #, gcc-internal-format
@@ -80463,10 +79835,9 @@ msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Змінна CLASS %qs у %L не може мати атрибут PARAMETER"
 
 #: fortran/resolve.cc:16221
-#, fuzzy, gcc-internal-format
-#| msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
+#, gcc-internal-format
 msgid "Entity %qs at %L has a deferred LEN parameter %qs and requires either the POINTER or ALLOCATABLE attribute"
-msgstr "Сутність %qs на %L має відкладений параметр типу і вимагає атрибут POINTER або ALLOCATABLE"
+msgstr "Об'єкт %qs на %L має відкладений параметр LEN %qs і вимагає атрибут POINTER або ALLOCATABLE"
 
 #: fortran/resolve.cc:16233
 #, gcc-internal-format
@@ -80749,10 +80120,9 @@ msgid "DATA statement at %L has more variables than values"
 msgstr "Інструкція DATA у %L має більше змінних, ніж значень"
 
 #: fortran/resolve.cc:17365
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Nonconstant array section at %L in DATA statement"
+#, gcc-internal-format, gfc-internal-format
 msgid "Non-constant character length at %L in DATA statement"
-msgstr "Неконстантний розділ масиву у %L в інструкції DATA"
+msgstr "Неконстантна довжина символу на %L у операторі DATA"
 
 #: fortran/resolve.cc:17393
 #, gcc-internal-format, gfc-internal-format
@@ -81311,10 +80681,9 @@ msgid "Result of SCALE overflows its kind at %L"
 msgstr "Результат масштабування перевищує його тип на %L"
 
 #: fortran/simplify.cc:7634
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qs argument of %qs intrinsic at %L must be of rank %d"
+#, gcc-internal-format, gfc-internal-format
 msgid "DIM argument (%d) to intrinsic SIZE at %L out of range (1:%d)"
-msgstr "Аргумент %qs вбудованої функції %qs на %L повинен мати ранг %d"
+msgstr "Аргумент DIM (%d) для вбудованої функції SIZE на %L поза діапазоном (1:%d)"
 
 #: fortran/simplify.cc:7759
 #, gcc-internal-format
@@ -81812,10 +81181,9 @@ msgid "bad expression type during walk (%d)"
 msgstr "поганий тип виразу під час обходу (%d)"
 
 #: fortran/trans-common.cc:411
-#, fuzzy, gcc-internal-format
-#| msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
+#, gcc-internal-format
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%wu vs %wu bytes)"
-msgstr "Зазначений загальний блок %qs на %L повинен мати такий самий розмір, як і в інших місцях (%lu проти %lu байтів)"
+msgstr "Іменований блок COMMON %qs на %L повинен мати такий же розмір, як і в іншому місці (%wu проти %wu байтів)"
 
 #: fortran/trans-common.cc:819
 #, gcc-internal-format
@@ -81899,10 +81267,9 @@ msgid "Array %qs at %L is larger than limit set by %<-fmax-stack-var-size=%>, mo
 msgstr "Масив %qs у %L більший за обмеження, встановлене за допомогою %<-fmax-stack-var-size=%>, перенесений зі стеку в статичне сховище. Це робить процедуру небезпечною при рекурсивному виклику або одночасному виклику з кількох потоків. Розгляньте можливість збільшення обмеження %<-fmax-stack-var-size=%> (або використання %<-frecursive%>, що позначає необмежене %<-fmax-stack-var-size%>) - або змініть код для використання масиву типу ALLOCATABLE. Якщо змінна ніколи не використовується одночасно, це попередження можна ігнорувати, і змінну також можна оголосити з атрибутом SAVE."
 
 #: fortran/trans-decl.cc:1800
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%s at %C has no default type"
+#, gcc-internal-format, gfc-internal-format
 msgid "%s at %L has no default type"
-msgstr "%s у %C не має типу за замовчуванням"
+msgstr "%s на %L не має типу за замовчуванням"
 
 #: fortran/trans-decl.cc:1804
 #, gcc-internal-format
@@ -81922,13 +81289,12 @@ msgstr "Відкладений параметр типу ще не підтри
 #: fortran/trans-decl.cc:5225
 #, gcc-internal-format
 msgid "Sorry, !$OMP allocate for COMMON block variable %qs at %L not supported"
-msgstr ""
+msgstr "Вибачте, !$OMP allocate для змінної блоку COMMON %qs в %L не підтримується"
 
 #: fortran/trans-decl.cc:5232
-#, fuzzy, gcc-internal-format
-#| msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
+#, gcc-internal-format
 msgid "Sorry, !$OMP allocate for variable %qs at %L with SAVE attribute not yet implemented"
-msgstr "Фіктивна змінна символьного типу %qs на %L з атрибутом VALUE повинна мати сталу довжину"
+msgstr "Вибачте, виділення пам'яті !$OMP для змінної %qs у %L з атрибутом SAVE ще не реалізовано"
 
 #: fortran/trans-decl.cc:5438
 #, gcc-internal-format
@@ -82089,28 +81455,27 @@ msgstr "невідомий вираз"
 #: fortran/trans-openmp.cc:4114
 #, gcc-internal-format
 msgid "%<uses_allocators%> clause with traits and memory spaces"
-msgstr ""
+msgstr "Клауза %<uses_allocators%> з ознаками та областями пам’яті"
 
 #: fortran/trans-openmp.cc:5038
 #, gcc-internal-format
 msgid "%<!$OMP %s%> at %L requires %<-fopenmp-allocators%>"
-msgstr ""
+msgstr "%<!$OMP %s%> в %L вимагає %<-fopenmp-allocators%>"
 
 #: fortran/trans-openmp.cc:5041
 #, gcc-internal-format
 msgid "All files that might deallocate such a variable must be compiled with %<-fopenmp-allocators%>"
-msgstr ""
+msgstr "Всі файли, які можуть звільнити виділену пам'ять такої змінної, повинні бути скомпільовані з %<-fopenmp-allocators%>"
 
 #: fortran/trans-openmp.cc:5044
 #, gcc-internal-format
 msgid "This includes explicit DEALLOCATE, reallocation on intrinsic assignment, INTENT(OUT) for allocatable dummy arguments, and reallocation of allocatable components allocated with an OpenMP allocator"
-msgstr ""
+msgstr "Це включає явне звільнення пам'яті (DEALLOCATE), перевиділення під час внутрішнього присвоювання, INTENT(OUT) для виділених аргументів-заступників та перевиділення виділених компонентів, які були виділені за допомогою OpenMP allocator"
 
 #: fortran/trans-openmp.cc:5621 fortran/trans-openmp.cc:5641
-#, fuzzy, gcc-internal-format
-#| msgid "non-rectangular loop nest with step other than constant 1 or -1 for %qs"
+#, gcc-internal-format
 msgid "non-rectangular loop nest with non-constant step for %qs"
-msgstr "не-прямокутне вкладення циклу з кроком, відмінним від сталого 1 або -1 для %qs"
+msgstr "непрямокутна вкладеність циклів з неконстантним кроком для %qs"
 
 #: fortran/trans-openmp.cc:5643
 #, gcc-internal-format
@@ -82694,24 +82059,22 @@ msgstr "аргумент для CAP не є константою або змін
 #: m2/gm2-gcc/m2expr.cc:4037
 #, gcc-internal-format
 msgid "constant literal %qs exceeds internal ZTYPE range"
-msgstr ""
+msgstr "літерал константи %qs перевищує внутрішній діапазон ZTYPE"
 
 #: m2/gm2-gcc/m2expr.cc:3957
 #, gcc-internal-format
 msgid "constant literal %qs contains %qc, expected 0 or 1"
-msgstr ""
+msgstr "літерал константи %qs містить %qc, а очікувалося 0 або 1"
 
 #: m2/gm2-gcc/m2expr.cc:3972 m2/gm2-gcc/m2expr.cc:3984
-#, fuzzy, gcc-internal-format
-#| msgid "language dialect differs %qs, expected %qs"
+#, gcc-internal-format
 msgid "constant literal %qs contains %qc, expected %qs"
-msgstr "Діалект мови відрізняється %qs, очікувався %qs"
+msgstr "константний літерал %qs містить %qc, очікується %qs"
 
 #: m2/gm2-gcc/m2expr.cc:4003
-#, fuzzy, gcc-internal-format
-#| msgid "target & host is %qs:%qs, expected %qs:%qs"
+#, gcc-internal-format
 msgid "constant literal %qs contains %qc, expected %qs or %qs"
-msgstr "ціль та хост - %qs:%qs, очікувалося %qs:%qs"
+msgstr "константний літерал %qs містить %qc, очікується %qs або %qs"
 
 #: m2/gm2-gcc/m2expr.cc:4069
 #, gcc-internal-format
@@ -83875,335 +83238,4 @@ msgstr "невикористане імʼя %qE"
 #: rust/resolve/rust-ast-resolve-expr.cc:167
 #, gcc-internal-format, gfc-internal-format
 msgid "are you trying to break %s? how dare you?"
-msgstr ""
-
-#~ msgid "to generate dependencies you must specify '-fcpp' "
-#~ msgstr "для генерації залежностей потрібно вказати '-fcpp'"
-
-#, no-c-format
-#~ msgid "turn on quadruple tracing (internal switch)"
-#~ msgstr "увімкнути чотирикратне відстеження (внутрішній перемикач)"
-
-#, no-c-format
-#~ msgid "turn on the Modula-2 api tracing (internal switch)"
-#~ msgstr "увімкнути відстеження api Modula-2 (внутрішній перемикач)"
-
-#, no-c-format
-#~ msgid "turn on the Modula-2 function line number generation (internal switch)"
-#~ msgstr "увімкнути генерацію номерів рядків функцій Modula-2 (внутрішній перемикач)"
-
-#, no-c-format
-#~ msgid "When vectorizing for SVE, consider using unpacked vectors for smaller elements and use the cost model to pick the cheapest approach.  Also use the cost model to choose between SVE and Advanced SIMD vectorization."
-#~ msgstr "При векторизації для SVE розгляньте використання розпакованих векторів для менших елементів та використовуйте модель вартості для вибору найбільш економного підходу. Також використовуйте модель вартості для вибору між векторизацією SVE та Advanced SIMD."
-
-#, no-c-format
-#~ msgid "Indicate presence of a processor erratum."
-#~ msgstr "Вказати наявність помилки процесора."
-
-#, no-c-format
-#~ msgid "Use RJMP / RCALL even though CALL / JMP are available."
-#~ msgstr "Використовуйте RJMP / RCALL, навіть якщо доступні CALL / JMP."
-
-#, no-c-format
-#~ msgid "The device has no SPH special function register. This option will be overridden by the compiler driver with the correct setting if presence/absence of SPH can be deduced from -mmcu=MCU."
-#~ msgstr "Пристрій не має спеціального регістра функцій SPH. Ця опція буде перезаписана компілятором з правильним налаштуванням, якщо наявність/відсутність SPH може бути виведена з -mmcu=МКП."
-
-#, no-c-format
-#~ msgid "Generate eBPF for the given Linux kernel version."
-#~ msgstr "Створити eBPF для вказаної версії ядра Linux."
-
-#, no-c-format
-#~ msgid "Use NewABI-style %reloc() assembly operators."
-#~ msgstr "Використовуйте оператори збірки %reloc() у стилі NewABI."
-
-#, no-c-format
-#~ msgid "Explain what alignment considerations lead to the decision to make an insn short or long."
-#~ msgstr "Пояснити, які врахування вирівнювання призводять до рішення зробити інструкцію короткою або довгою."
-
-#, no-c-format
-#~ msgid "Enable bbit peephole2."
-#~ msgstr "Увімкнути bbit peephole2."
-
-#~ msgid "invalid use of %<...%> with builtin function"
-#~ msgstr "неприпустиме використання %<...%> з вбудованою функцією"
-
-#~ msgid "type conversion result count mismatch"
-#~ msgstr "невідповідність кількості результатів при конвертації типу"
-
-#~ msgid "multiple-value argument in single-value context"
-#~ msgstr "аргумент з кількома значеннями в контексті з одним значенням"
-
-#~ msgid "invalid use of %<...%> with non-slice"
-#~ msgstr "неприпустиме використання %<...%> з не-зрізом"
-
-#~ msgid "invalid use of %<...%> calling non-variadic function"
-#~ msgstr "неприпустиме використання %<...%> при виклику неваріативної функції"
-
-#~ msgid "index must be integer"
-#~ msgstr "індекс повинен бути цілочисельним"
-
-#~ msgid "slice end must be integer"
-#~ msgstr "кінець зрізу повинен бути цілочисельним"
-
-#~ msgid "slice capacity must be integer"
-#~ msgstr "ємність зрізу повинна бути цілочисельним"
-
-#~ msgid "inverted slice range"
-#~ msgstr "обернений діапазон зрізу"
-
-#~ msgid "slice of unaddressable value"
-#~ msgstr "зріз незадовільного значення"
-
-#~ msgid "too many expressions for struct"
-#~ msgstr "занадто багато виразів для структури"
-
-#~ msgid "too few expressions for struct"
-#~ msgstr "замало виразів для структури"
-
-#, gcc-internal-format, gfc-internal-format
-#~ msgid "argument %i of variable length array %s is null but the corresponding bound argument %i value is %s"
-#~ msgstr "аргумент %i змінної довжини масиву %s є нульовим, але відповідне значення звʼязаного аргументу %i є %s"
-
-#, gcc-internal-format
-#~ msgid "argument %i to %<%T[static %E]%> is null where non-null expected"
-#~ msgstr "аргумент %i до %<%T[static %E]%> є нульовим, де очікується ненульове значення"
-
-#, gcc-internal-format
-#~ msgid "%qs RHS in assignment statement"
-#~ msgstr "%qs на правій стороні оператора присвоєння"
-
-#, gcc-internal-format
-#~ msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
-#~ msgstr "припускаючи, що підписаний переповнення не відбувається при спрощенні %</%> або %<%%%> до %<>>%> або %<&%>"
-
-#, gcc-internal-format
-#~ msgid "assuming signed overflow does not occur when simplifying %<min/max (X,Y)%> to %<X%> or %<Y%>"
-#~ msgstr "припускаючи, що підписаний переповнення не відбувається при спрощенні %<min/max (X,Y)%> до %<X%> або %<Y%>"
-
-#, gcc-internal-format
-#~ msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
-#~ msgstr "припускаючи, що підписаний переповнення не відбувається при спрощенні %<abs (X)%> до %<X%> або %<-X%>"
-
-#, gcc-internal-format
-#~ msgid "%qE attribute ignored due to conflict with attribute %qs"
-#~ msgstr "Атрибут %qE ігнорується через конфлікт з атрибутом %qs"
-
-#, gcc-internal-format
-#~ msgid "%qE attribute ignored due to conflict with %qs attribute"
-#~ msgstr "Атрибут %qE ігнорується через конфлікт з атрибутом %qs"
-
-#, gcc-internal-format
-#~ msgid "converting a packed %qT pointer (alignment %d) to a %qT pointer (alignment %d) may result in an unaligned pointer value"
-#~ msgstr "перетворення упакованого вказівника %qT (вирівнювання %d) на вказівник %qT (вирівнювання %d) може призвести до невирівняного значення вказівника"
-
-#, gcc-internal-format
-#~ msgid "%<-march=%s%>: unsupported ISA subset %<%c%>"
-#~ msgstr "%<-march=%s%>: непідтримуваний піднабір ISA %<%c%>"
-
-#, gcc-internal-format
-#~ msgid "%<-march=%s%>: ISA string is not in canonical order. %<%c%>"
-#~ msgstr "%<-march=%s%>: рядок ISA не в канонічному порядку. %<%c%>"
-
-#, gcc-internal-format
-#~ msgid "%<-march=%s%>: unexpected ISA string at end: %qs"
-#~ msgstr "%<-march=%s%>: неочікуваний рядок ISA в кінці: %qs"
-
-#, gcc-internal-format
-#~ msgid "missing argument to %<target(\"branch-protection=\")%> pragma or attribute"
-#~ msgstr "відсутній аргумент в прагмі або атрибуті %<target(\"branch-protection=\")%>"
-
-#, gcc-internal-format
-#~ msgid "invalid protection type %qs in %<target(\"branch-protection=\")%> pragma or attribute"
-#~ msgstr "неприпустимий тип захисту %qs в прагмі або атрибуті %<target(\"branch-protection=\")%>"
-
-#, gcc-internal-format
-#~ msgid "GCC does not currently support mixed size types for %<simd%> functions"
-#~ msgstr "GCC наразі не підтримує типи змішаного розміру для функцій %<simd%>"
-
-#, gcc-internal-format
-#~ msgid "unsupported return type %qT for %<simd%> functions"
-#~ msgstr "непідтримуваний тип повернення %qT для функцій %<simd%>"
-
-#, gcc-internal-format
-#~ msgid "unexpected %<%s%> after %<%s%>"
-#~ msgstr "неочікуване %<%s%> після %<%s%>"
-
-#, gcc-internal-format
-#~ msgid "invalid argument %<%s%> for %<-mbranch-protection=%>"
-#~ msgstr "некоректний аргумент %<%s%> %<-mbranch-protection=%>"
-
-#, gcc-internal-format
-#~ msgid "missing argument for %<-mbranch-protection=%>"
-#~ msgstr "відсутній аргумент для %<-mbranch-protection=%>"
-
-#, gcc-internal-format
-#~ msgid "invalid key type for %<-mbranch-protection=%>"
-#~ msgstr "недійсний тип ключа для %<-mbranch-protection=%>"
-
-#, gcc-internal-format
-#~ msgid "IO definition for %q+D needs an address"
-#~ msgstr "Визначення IO для %q+D потребує адресу"
-
-#, gcc-internal-format
-#~ msgid "unsupported variable field offset"
-#~ msgstr "непідтримуваний зміщення змінної поля"
-
-#, gcc-internal-format
-#~ msgid "unsupported variable size field access"
-#~ msgstr "непідтримуваний доступ до поля змінної розміру"
-
-#, gcc-internal-format
-#~ msgid "unsupported field expression"
-#~ msgstr "непідтримуваний вираз поля"
-
-#, gcc-internal-format
-#~ msgid "field size too large"
-#~ msgstr "розмір поля занадто великий"
-
-#, gcc-internal-format
-#~ msgid "invalid second argument to built-in function"
-#~ msgstr "недійсний другий аргумент вбудованої функції"
-
-#, gcc-internal-format
-#~ msgid "argument is not a field access"
-#~ msgstr "аргумент не є доступом до поля"
-
-#, gcc-internal-format
-#~ msgid "XNACK support"
-#~ msgstr "підтримка XNACK"
-
-#, gcc-internal-format
-#~ msgid "either -fopenacc or -fopenmp must be set"
-#~ msgstr "необхідно встановити або -fopenacc, або -fopenmp"
-
-#, gcc-internal-format
-#~ msgid "code model %qs needs %s"
-#~ msgstr "модель коду %qs потребує %s"
-
-#, gcc-internal-format
-#~ msgid "%qE attribute requires %s"
-#~ msgstr "атрибут %qE вимагає %s"
-
-#, gcc-internal-format
-#~ msgid "%<#pragma riscv intrinsic%> option %qs needs 'V' extension enabled"
-#~ msgstr "опція %qs для %<#pragma riscv intrinsic%> потребує включеної розширення 'V'"
-
-#, gcc-internal-format
-#~ msgid "expected %<#pragma acc%> clause"
-#~ msgstr "очікується замикання %<#pragma acc%>"
-
-#, gcc-internal-format
-#~ msgid "expected %<#pragma omp%> clause"
-#~ msgstr "очікується замикання %<#pragma omp%>"
-
-#, gcc-internal-format
-#~ msgid "collapsed loops not perfectly nested"
-#~ msgstr "згорнуті цикли не є добре вкладеними"
-
-#, gcc-internal-format
-#~ msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%>"
-#~ msgstr "очікується %<construct%>, %<device%>, %<implementation%> або %<user%>"
-
-#, gcc-internal-format
-#~ msgid "expected %<seq_cst%>, %<relaxed%> or %<acq_rel%>"
-#~ msgstr "очікувався %<seq_cst%>, %<relaxed%> або %<acq_rel%>"
-
-#, gcc-internal-format
-#~ msgid "pointer type mismatch between %qT and %qT of %qD and %qD in conditional expression"
-#~ msgstr "несумісні типи вказівників %qT та %qT з %qD та %qD в умовному виразі"
-
-#, gcc-internal-format
-#~ msgid "excess elements in %<char%> array initializer"
-#~ msgstr "зайві елементи в ініціалізаторі масиву %<char%>"
-
-#, gcc-internal-format
-#~ msgid "cannot dereference %qE in %qs clause"
-#~ msgstr "не можна розіменувати %qE в замиканні %qs"
-
-#, gcc-internal-format
-#~ msgid "change of the active member of a union from %qD to %qD"
-#~ msgstr "зміна активного члена обʼєднання з %qD на %qD"
-
-#, gcc-internal-format
-#~ msgid "previous declaration %q#D here"
-#~ msgstr "попередня декларація %q#D тут"
-
-#, gcc-internal-format
-#~ msgid "deduction guide %q+D redeclared"
-#~ msgstr "посібник з виведення %q+D повторно оголошено"
-
-#, gcc-internal-format
-#~ msgid "  enters scope of %q#D, which has non-trivial destructor"
-#~ msgstr "  входить в область видимості %q#D, яка має нелінійний деструктор"
-
-#, gcc-internal-format
-#~ msgid "  enters scope of %q#D which has non-trivial destructor"
-#~ msgstr "  входить у область видимості %q#D, яка має незвичайний деструктор"
-
-#, gcc-internal-format
-#~ msgid "cannot declare %qD in a different module"
-#~ msgstr "не можна оголосити %qD в іншому модулі"
-
-#, gcc-internal-format
-#~ msgid "cannot define %qD in different module"
-#~ msgstr "не можна визначити %qD в іншому модулі"
-
-#, gcc-internal-format
-#~ msgid "lambda templates are only available with %<-std=c++14%> or %<-std=gnu++14%>"
-#~ msgstr "шаблони лямбди доступні лише з %<-std=c++14%> або %<-std=gnu++14%>"
-
-#, gcc-internal-format
-#~ msgid "unknown OpenMP directive name in %<omp::directive%> attribute argument"
-#~ msgstr "невідома назва директиви OpenMP в аргументі атрибуту %<omp::directive%>"
-
-#, gcc-internal-format
-#~ msgid "not enough for loops to collapse"
-#~ msgstr "недостатньо циклів для згортання"
-
-#, gcc-internal-format
-#~ msgid "%<#pragma GCC unroll%> must be inside a function"
-#~ msgstr "%<#pragma GCC unroll%> повинен бути всередині функції"
-
-#, gcc-internal-format
-#~ msgid "taking address of temporary array"
-#~ msgstr "взяття адреси тимчасового масиву"
-
-#, gcc-internal-format
-#~ msgid "closing json file %s: %m"
-#~ msgstr "закриття json-файлу %s: %m"
-
-#, gcc-internal-format
-#~ msgid "closing mixin file %s: %m"
-#~ msgstr "закриття файлу mixin %s: %m"
-
-#, gcc-internal-format
-#~ msgid "opening mixin file %s: %m"
-#~ msgstr "відкриття файлу mixin %s: %m"
-
-#, gcc-internal-format
-#~ msgid "TODO: Vector sections in data statements"
-#~ msgstr "TODO: Векторні секції в операторах DATA"
-
-#, gcc-internal-format, gfc-internal-format
-#~ msgid "property must be constant integer expression or string literal at %C"
-#~ msgstr "властивість повинна бути константним цілочисельним виразом або літералом рядка у %C"
-
-#, gcc-internal-format
-#~ msgid "expected %<construct%>, %<device%>, %<implementation%> or %<user%> at %C"
-#~ msgstr "очікується %<construct%>, %<device%>, %<implementation%> або %<user%> у %C"
-
-#, gcc-internal-format, gfc-internal-format
-#~ msgid "collapsed %s loops not perfectly nested at %L"
-#~ msgstr "Злиті %s петлі не є ідеально вкладеними на %L"
-
-#, gcc-internal-format, gfc-internal-format
-#~ msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE procedures"
-#~ msgstr "Директиви OpenMP, крім SIMD або DECLARE TARGET, не можуть зʼявлятися в PURE процедурах у %C"
-
-#, gcc-internal-format
-#~ msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
-#~ msgstr "Обʼєкт %qs у %L має відкладений параметр LEN %qs і не є алокованим або вказівником"
-
-#, gcc-internal-format
-#~ msgid "TODO"
-#~ msgstr "ВИКОНАТИ"
+msgstr "Ти намагаєшся зламати %s? Як ти смієш?"

commit 1e79541bed12a11318dbc37f09de95c99bc8ad70
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Sat Sep 7 02:21:14 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index a2aca132dd9..346d3ce6907 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240906
+20240907
diff --git a/gcc/po/ChangeLog b/gcc/po/ChangeLog
index 01dce13aa15..2b19ee75537 100644
--- a/gcc/po/ChangeLog
+++ b/gcc/po/ChangeLog
@@ -1,3 +1,7 @@
+2024-09-06  Joseph Myers  <josmyers@redhat.com>
+
+	* uk.po: Update.
+
 2024-08-28  Joseph Myers  <josmyers@redhat.com>
 
 	* ka.po: New file.

commit 0c80216b7bb0938bff7db230cbefa5bc3e8b3034
Author: Patrick Palka <ppalka@redhat.com>
Date:   Sat Sep 7 20:10:09 2024

    c++: template depth of lambda in default targ [PR116567]
    
    For GCC 14, let's narrowly fix this bug by just pruning the result of
    add_extra_args after the fact to get rid of any unwanted outer levels.
    
            PR c++/116567
    
    gcc/cp/ChangeLog:
    
            * pt.cc (tsubst_lambda_expr): For a deferred-substitution lambda,
            trim the augmented template arguments to match the template depth
            of the lambda.
    
    gcc/testsuite/ChangeLog:
    
            * g++.dg/cpp2a/lambda-targ7.C: New test.
    
    Reviewed-by: Jason Merrill <jason@redhat.com>

diff --git a/gcc/cp/pt.cc b/gcc/cp/pt.cc
index 8e6a7d1a64a..7135105fc37 100644
--- a/gcc/cp/pt.cc
+++ b/gcc/cp/pt.cc
@@ -19679,6 +19679,18 @@ tsubst_lambda_expr (tree t, tree args, tsubst_flags_t complain, tree in_decl)
       LAMBDA_EXPR_EXTRA_ARGS (t) = build_extra_args (t, args, complain);
       return t;
     }
+  if (LAMBDA_EXPR_EXTRA_ARGS (t))
+    {
+      /* If we deferred substitution into this lambda, then its original
+	 context (e.g. default template argument context) might be unrelated
+	 to the current context it's embedded in.  After add_extra_args though,
+	 the innermost levels of 'args' will correspond to the lambda context,
+	 so get rid of all unrelated levels.  */
+      tree ctx_parms = DECL_TEMPLATE_PARMS (DECL_TI_TEMPLATE (oldfn));
+      if (generic_lambda_fn_p (oldfn))
+	ctx_parms = TREE_CHAIN (ctx_parms);
+      args = get_innermost_template_args (args, TMPL_PARMS_DEPTH (ctx_parms));
+    }
 
   tree r = build_lambda_expr ();
 
diff --git a/gcc/testsuite/g++.dg/cpp2a/lambda-targ7.C b/gcc/testsuite/g++.dg/cpp2a/lambda-targ7.C
new file mode 100644
index 00000000000..97b42d6ed0c
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp2a/lambda-targ7.C
@@ -0,0 +1,42 @@
+// PR c++/116567
+// { dg-do compile { target c++20 } }
+
+struct X { int n; };
+
+template<auto N, auto F = []{ return N; }>
+auto v1 = F;
+
+template<auto N, auto F = [](auto y){ return decltype(N){N.n + y}; }>
+auto v1g = F;
+
+template<class T>
+struct A {
+  template<auto N, auto F = []{ return N; }>
+  static inline auto v2 = F;
+
+  template<auto N, auto F = [](auto y){ return decltype(N){N.n + y}; }>
+  static inline auto v2g = F;
+
+  template<class U>
+  struct B {
+    template<auto N, auto F = []{ return N; }>
+    static inline auto v3 = F;
+
+    template<auto N, auto F = [](auto y){ return decltype(N){N.n + y}; }>
+    static inline auto v3g = F;
+
+    template<class V>
+    static void f() {
+      static_assert(v1<X{1}>().n == 1);
+      static_assert(v1g<X{1}>(42).n == 1 + 42);
+      static_assert(v2<X{2}>().n == 2);
+      static_assert(v2g<X{2}>(42).n == 2 + 42);
+      static_assert(v3<X{3}>().n == 3);
+      static_assert(v3g<X{3}>(42).n == 3 + 42);
+    }
+  };
+};
+
+int main() {
+  A<int>::B<int>::f<int>();
+}

commit 7e0649ac0fab8e0673e3eba8d357f1a21463ae0f
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Sun Sep 8 02:30:07 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 346d3ce6907..e8f2bd3ba1b 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240907
+20240908
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index 4fce475fab5..5eb401ffb82 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -1,3 +1,10 @@
+2024-09-07  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/116567
+	* pt.cc (tsubst_lambda_expr): For a deferred-substitution lambda,
+	trim the augmented template arguments to match the template depth
+	of the lambda.
+
 2024-09-05  Marek Polacek  <polacek@redhat.com>
 
 	Backported from master:
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 736537b0cf0..2c0a0302e93 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,8 @@
+2024-09-07  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/116567
+	* g++.dg/cpp2a/lambda-targ7.C: New test.
+
 2024-09-05  Marek Polacek  <polacek@redhat.com>
 
 	Backported from master:

commit 140aab25a4865433d987d73c57f4ddf11fdac1e2
Author: Patrick Palka <ppalka@redhat.com>
Date:   Sat Aug 3 15:05:05 2024

    libstdc++: use concrete return type for std::forward_like
    
    Inspired by https://github.com/llvm/llvm-project/issues/101614 this
    inverts the relationship between forward_like and __like_t so that
    forward_like is defined in terms of __like_t and with a concrete return
    type.  __like_t in turn is defined via partial specializations that
    pattern match on the const- and reference-ness of T.
    
    This turns out to be more SFINAE friendly and significantly cheaper
    to compile than the previous implementation.
    
    libstdc++-v3/ChangeLog:
    
            * include/bits/move.h (__like_impl): New metafunction.
            (__like_t): Redefine in terms of __like_impl.
            (forward_like): Redefine in terms of __like_t.
            * testsuite/20_util/forward_like/2_neg.cc: Don't expect
            error outside the immediate context anymore.
    
    Reviewed-by: Jonathan Wakely <jwakely@redhat.com>
    (cherry picked from commit 8256d5c0097dff00f9bdf9ee0c9d53bd7cec2802)

diff --git a/libstdc++-v3/include/bits/move.h b/libstdc++-v3/include/bits/move.h
index bb200c95964..8397a01b632 100644
--- a/libstdc++-v3/include/bits/move.h
+++ b/libstdc++-v3/include/bits/move.h
@@ -88,31 +88,32 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
 
 #if __glibcxx_forward_like // C++ >= 23
   template<typename _Tp, typename _Up>
-  [[nodiscard]]
-  constexpr decltype(auto)
-  forward_like(_Up&& __x) noexcept
-  {
-    constexpr bool __as_rval = is_rvalue_reference_v<_Tp&&>;
-
-    if constexpr (is_const_v<remove_reference_t<_Tp>>)
-      {
-	using _Up2 = remove_reference_t<_Up>;
-	if constexpr (__as_rval)
-	  return static_cast<const _Up2&&>(__x);
-	else
-	  return static_cast<const _Up2&>(__x);
-      }
-    else
-      {
-	if constexpr (__as_rval)
-	  return static_cast<remove_reference_t<_Up>&&>(__x);
-	else
-	  return static_cast<_Up&>(__x);
-      }
-  }
+  struct __like_impl; // _Tp must be a reference and _Up an lvalue reference
+
+  template<typename _Tp, typename _Up>
+  struct __like_impl<_Tp&, _Up&>
+  { using type = _Up&; };
+
+  template<typename _Tp, typename _Up>
+  struct __like_impl<const _Tp&, _Up&>
+  { using type = const _Up&; };
+
+  template<typename _Tp, typename _Up>
+  struct __like_impl<_Tp&&, _Up&>
+  { using type = _Up&&; };
+
+  template<typename _Tp, typename _Up>
+  struct __like_impl<const _Tp&&, _Up&>
+  { using type = const _Up&&; };
 
   template<typename _Tp, typename _Up>
-    using __like_t = decltype(std::forward_like<_Tp>(std::declval<_Up>()));
+    using __like_t = typename __like_impl<_Tp&&, _Up&>::type;
+
+  template<typename _Tp, typename _Up>
+  [[nodiscard]]
+  constexpr __like_t<_Tp, _Up>
+  forward_like(_Up&& __x) noexcept
+  { return static_cast<__like_t<_Tp, _Up>>(__x); }
 #endif
 
   /**
diff --git a/libstdc++-v3/testsuite/20_util/forward_like/2_neg.cc b/libstdc++-v3/testsuite/20_util/forward_like/2_neg.cc
index ff835af1915..5dafa419a7e 100644
--- a/libstdc++-v3/testsuite/20_util/forward_like/2_neg.cc
+++ b/libstdc++-v3/testsuite/20_util/forward_like/2_neg.cc
@@ -2,9 +2,7 @@
 
 #include <utility>
 
-auto x1 = std::forward_like<void>(1); // { dg-error "here" }
+auto x1 = std::forward_like<void>(1); // { dg-error "no match" }
 // { dg-error "forming reference to void" "" { target *-*-* } 0 }
-auto x2 = std::forward_like<void()const>(1); // { dg-error "here" }
+auto x2 = std::forward_like<void()const>(1); // { dg-error "no match" }
 // { dg-error "forming reference to qualified function" "" { target *-*-* } 0 }
-
-// { dg-prune-output "inconsistent deduction for auto return type" } // PR111484

commit b5ed381d05e0ed9edf2f320b71f8775ea96a4866
Author: Patrick Palka <ppalka@redhat.com>
Date:   Sat Aug 10 03:15:25 2024

    c++: inherited CTAD fixes [PR116276]
    
    This implements the overlooked inherited vs non-inherited guide
    tiebreaker from P2582R1.  This requires tracking inherited-ness of a
    guide, for which it seems natural to reuse the lang_decl_fn::context
    field which for a constructor tracks its inherited-ness.
    
    This patch also works around CLASSTYPE_CONSTRUCTORS not reliably
    returning all inherited constructors (due to some using-decl handling
    quirks in in push_class_level_binding) by iterating over TYPE_FIELDS
    instead.
    
    This patch also makes us recognize another written form of inherited
    constructor, 'using Base<T>::Base::Base' whose USING_DECL_SCOPE is a
    TYPENAME_TYPE.
    
            PR c++/116276
    
    gcc/cp/ChangeLog:
    
            * call.cc (joust): Implement P2582R1 inherited vs non-inherited
            guide tiebreaker.
            * cp-tree.h (lang_decl_fn::context): Document usage in
            deduction_guide_p FUNCTION_DECLs.
            (inherited_guide_p): Declare.
            * pt.cc (inherited_guide_p): Define.
            (set_inherited_guide_context): Define.
            (alias_ctad_tweaks): Use set_inherited_guide_context.
            (inherited_ctad_tweaks): Recognize some inherited constructors
            whose scope is a TYPENAME_TYPE.
            (ctor_deduction_guides_for): For C++23 inherited CTAD, iterate
            over TYPE_FIELDS instead of CLASSTYPE_CONSTRUCTORS to recognize
            all inherited constructors.
    
    gcc/testsuite/ChangeLog:
    
            * g++.dg/cpp23/class-deduction-inherited4.C: Remove an xfail.
            * g++.dg/cpp23/class-deduction-inherited5.C: New test.
            * g++.dg/cpp23/class-deduction-inherited6.C: New test.
    
    Reviewed-by: Jason Merrill <jason@redhat.com>
    (cherry picked from commit 8cc67b520968ca9a13fd96896522aa66e39a99e2)

diff --git a/gcc/cp/call.cc b/gcc/cp/call.cc
index 793b9834712..0f4eeeb5395 100644
--- a/gcc/cp/call.cc
+++ b/gcc/cp/call.cc
@@ -13226,10 +13226,35 @@ joust (struct z_candidate *cand1, struct z_candidate *cand2, bool warn,
   else if (cand2->rewritten ())
     return 1;
 
-  /* F1 is generated from a deduction-guide (13.3.1.8) and F2 is not */
   if (deduction_guide_p (cand1->fn))
     {
       gcc_assert (deduction_guide_p (cand2->fn));
+
+      /* F1 and F2 are generated from class template argument deduction for a
+	 class D, and F2 is generated from inheriting constructors from a base
+	 class of D while F1 is not, and for each explicit function argument,
+	 the corresponding parameters of F1 and F2 are either both ellipses or
+	 have the same type.  */
+      bool inherited1 = inherited_guide_p (cand1->fn);
+      bool inherited2 = inherited_guide_p (cand2->fn);
+      if (int diff = inherited2 - inherited1)
+	{
+	  for (i = 0; i < len; ++i)
+	    {
+	      conversion *t1 = cand1->convs[i + off1];
+	      conversion *t2 = cand2->convs[i + off2];
+	      /* ??? It seems the ellipses part of this tiebreaker isn't
+		 needed since a mismatch should have broken the tie earlier
+		 during ICS comparison.  */
+	      gcc_checking_assert (t1->ellipsis_p == t2->ellipsis_p);
+	      if (!same_type_p (t1->type, t2->type))
+		break;
+	    }
+	  if (i == len)
+	    return diff;
+	}
+
+      /* F1 is generated from a deduction-guide (13.3.1.8) and F2 is not */
       /* We distinguish between candidates from an explicit deduction guide and
 	 candidates built from a constructor based on DECL_ARTIFICIAL.  */
       int art1 = DECL_ARTIFICIAL (cand1->fn);
diff --git a/gcc/cp/cp-tree.h b/gcc/cp/cp-tree.h
index 3f607313db6..ab2b0904ed6 100644
--- a/gcc/cp/cp-tree.h
+++ b/gcc/cp/cp-tree.h
@@ -2981,9 +2981,10 @@ struct GTY(()) lang_decl_fn {
      this pointer and result pointer adjusting thunks are
      chained here.  This pointer thunks to return pointer thunks
      will be chained on the return pointer thunk.
-     For a DECL_CONSTUCTOR_P FUNCTION_DECL, this is the base from
-     whence we inherit.  Otherwise, it is the class in which a
-     (namespace-scope) friend is defined (if any).   */
+     For a DECL_CONSTRUCTOR_P or deduction_guide_p FUNCTION_DECL,
+     this is the base from whence we inherit.
+     Otherwise, it is the class in which a (namespace-scope) friend
+     is defined (if any).  */
   tree context;
 
   union lang_decl_u5
@@ -7651,6 +7652,7 @@ extern bool deduction_guide_p			(const_tree);
 extern bool copy_guide_p			(const_tree);
 extern bool template_guide_p			(const_tree);
 extern bool builtin_guide_p			(const_tree);
+extern bool inherited_guide_p			(const_tree);
 extern void store_explicit_specifier		(tree, tree);
 extern tree lookup_explicit_specifier		(tree);
 extern tree lookup_imported_hidden_friend	(tree);
diff --git a/gcc/cp/pt.cc b/gcc/cp/pt.cc
index 7135105fc37..6695e4ff49f 100644
--- a/gcc/cp/pt.cc
+++ b/gcc/cp/pt.cc
@@ -29797,6 +29797,25 @@ builtin_guide_p (const_tree fn)
   return true;
 }
 
+/* True if FN is a C++23 inherited guide.  */
+
+bool
+inherited_guide_p (const_tree fn)
+{
+  gcc_assert (deduction_guide_p (fn));
+  return LANG_DECL_FN_CHECK (fn)->context != NULL_TREE;
+}
+
+/* Set the base class BASE from which the transformed guide FN
+   was inherited as part of C++23 inherited CTAD.  */
+
+static void
+set_inherited_guide_context (const_tree fn, tree base)
+{
+  gcc_assert (deduction_guide_p (fn));
+  LANG_DECL_FN_CHECK (fn)->context = base;
+}
+
 /* OLDDECL is a _DECL for a template parameter.  Return a similar parameter at
    LEVEL:INDEX, using tsubst_args and complain for substitution into non-type
    template parameter types.  Note that the handling of template template
@@ -30565,6 +30584,7 @@ alias_ctad_tweaks (tree tmpl, tree uguides)
 	  TREE_TYPE (fprime) = fntype;
 	  if (TREE_CODE (fprime) == TEMPLATE_DECL)
 	    TREE_TYPE (DECL_TEMPLATE_RESULT (fprime)) = fntype;
+	  set_inherited_guide_context (fprime, utype);
 	}
 
       aguides = lookup_add (fprime, aguides);
@@ -30596,11 +30616,14 @@ inherited_ctad_tweaks (tree tmpl, tree ctor, tsubst_flags_t complain)
      template specialization with the template argument list of A but with C as
      the template.  */
 
-  /* FIXME: Also recognize inherited constructors of the form 'using C::B::B',
-     which seem to be represented with TYPENAME_TYPE C::B as USING_DECL_SCOPE?
-     And recognize constructors inherited from a non-dependent base class, which
-     seem to be missing from the overload set entirely?  */
   tree scope = USING_DECL_SCOPE (ctor);
+  if (TREE_CODE (scope) == TYPENAME_TYPE
+      && (TYPE_IDENTIFIER (TYPE_CONTEXT (scope))
+	  == TYPENAME_TYPE_FULLNAME (scope)))
+    /* Recognize using B<T>::B::B as an inherited constructor.  */
+    /* FIXME: Also recognize using C::B::B?  We might have to call
+       resolve_typename_type for that.  */
+    scope = TYPE_CONTEXT (scope);
   if (!CLASS_TYPE_P (scope)
       || !CLASSTYPE_TEMPLATE_INFO (scope)
       || !PRIMARY_TEMPLATE_P (CLASSTYPE_TI_TEMPLATE (scope)))
@@ -30734,10 +30757,14 @@ ctor_deduction_guides_for (tree tmpl, tsubst_flags_t complain)
     }
 
   if (cxx_dialect >= cxx23)
-    for (tree ctor : ovl_range (CLASSTYPE_CONSTRUCTORS (type)))
-      if (TREE_CODE (ctor) == USING_DECL)
-	{
-	  tree uguides = inherited_ctad_tweaks (tmpl, ctor, complain);
+    /* FIXME: CLASSTYPE_CONSTRUCTORS doesn't contain inherited constructors if
+       e.g. the class also has a user-defined constructor.  So instead iterate
+       over TYPE_FIELDS manually to robustly find all relevant using-decls.  */
+    for (tree field = TYPE_FIELDS (type); field; field = DECL_CHAIN (field))
+      if (TREE_CODE (field) == USING_DECL
+	  && DECL_NAME (field) == ctor_identifier)
+	{
+	  tree uguides = inherited_ctad_tweaks (tmpl, field, complain);
 	  if (uguides)
 	    cands = lookup_add (uguides, cands);
 	}
diff --git a/gcc/testsuite/g++.dg/cpp23/class-deduction-inherited4.C b/gcc/testsuite/g++.dg/cpp23/class-deduction-inherited4.C
index 5e3a7f42919..806f0167a4e 100644
--- a/gcc/testsuite/g++.dg/cpp23/class-deduction-inherited4.C
+++ b/gcc/testsuite/g++.dg/cpp23/class-deduction-inherited4.C
@@ -13,10 +13,10 @@ using ty1 = B<int>;
 
 template<class T=void>
 struct C : A<int> {
-  using A<int>::A; // FIXME: we don't notice this one either
+  using A<int>::A;
 };
 
-using ty2 = decltype(C(0)); // { dg-bogus "" "" { xfail *-*-* } }
+using ty2 = decltype(C(0));
 using ty2 = C<void>;
 
 template<class T>
diff --git a/gcc/testsuite/g++.dg/cpp23/class-deduction-inherited5.C b/gcc/testsuite/g++.dg/cpp23/class-deduction-inherited5.C
new file mode 100644
index 00000000000..d835acb0b79
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp23/class-deduction-inherited5.C
@@ -0,0 +1,25 @@
+// PR c++/116276
+// { dg-do compile { target c++20 } }
+
+template<class T>
+struct Base1 { };
+
+template<class T>
+struct Base2 { };
+
+template<class T = int>
+struct Derived : public Base1<T>, Base2<T> {
+  using Base1<T>::Base1;
+  using Base2<T>::Base2;
+};
+
+Derived d;
+
+template<class T = int>
+struct Derived2 : public Base1<T>, Base2<T> {
+  using Base1<T>::Base1::Base1;
+  using Base2<T>::Base2::Base2;
+  Derived2();
+};
+
+Derived2 d2;
diff --git a/gcc/testsuite/g++.dg/cpp23/class-deduction-inherited6.C b/gcc/testsuite/g++.dg/cpp23/class-deduction-inherited6.C
new file mode 100644
index 00000000000..df8199cd3e4
--- /dev/null
+++ b/gcc/testsuite/g++.dg/cpp23/class-deduction-inherited6.C
@@ -0,0 +1,46 @@
+// PR c++/116276
+// { dg-do compile { target c++23 } }
+
+template<class T>
+struct Base1 {
+  Base1();
+  Base1(T);
+};
+
+template<class T>
+struct Base2 {
+  Base2();
+  Base2(T*);
+};
+
+template<class T = int>
+struct Derived : public Base1<T>, Base2<T> {
+  using Base1<T>::Base1;
+  using Base2<T>::Base2;
+};
+
+using ty1 = decltype(Derived{});
+using ty1 = Derived<int>;
+
+using ty2 = decltype(Derived{true});
+using ty2 = Derived<bool>;
+
+using ty3 = decltype(Derived{(char*)nullptr});
+using ty3 = Derived<char>;
+
+template<class T = int>
+struct Derived2 : public Base1<T>, Base2<T> {
+  using Base1<T>::Base1;
+  using Base2<T>::Base2;
+  Derived2();
+  Derived2(T);
+};
+
+using ty4 = decltype(Derived2{});
+using ty4 = Derived2<int>;
+
+using ty5 = decltype(Derived2{true});
+using ty5 = Derived2<bool>;
+
+using ty6 = decltype(Derived2{(char*)nullptr});
+using ty6 = Derived2<char>;

commit 149d87fbe661da29d8a0aa671b42bd532206a8b8
Author: Patrick Palka <ppalka@redhat.com>
Date:   Thu Aug 15 16:23:54 2024

    c++: c->B::m access resolved through current inst [PR116320]
    
    Here when checking the access of (the injected-class-name) B in c->B::m
    at parse time, we notice its context B (now the type) is a base of the
    object type C<T>, so we proceed to use C<T> as the effective qualifying
    type.  But this C<T> is the dependent specialization not the primary
    template type, so it has empty TYPE_BINFO, which leads to a segfault later
    from perform_or_defer_access_check.
    
    The reason the DERIVED_FROM_P (B, C<T>) test guarding this code path works
    despite C<T> having empty TYPE_BINFO is because of its currently_open_class
    logic (added in r9-713-gd9338471b91bbe) which replaces a dependent
    specialization with the primary template type if we're inside it.  So the
    safest fix seems to be to call currently_open_class in the caller as well.
    
            PR c++/116320
    
    gcc/cp/ChangeLog:
    
            * semantics.cc (check_accessibility_of_qualified_id): Try
            currently_open_class when using the object type as the
            effective qualifying type.
    
    gcc/testsuite/ChangeLog:
    
            * g++.dg/template/access42.C: New test.
    
    Reviewed-by: Jason Merrill <jason@redhat.com>
    (cherry picked from commit 484f139ccd3b631a777802e810a632678b42ffab)

diff --git a/gcc/cp/semantics.cc b/gcc/cp/semantics.cc
index b5569066708..ceeac82fa08 100644
--- a/gcc/cp/semantics.cc
+++ b/gcc/cp/semantics.cc
@@ -2497,9 +2497,14 @@ check_accessibility_of_qualified_id (tree decl,
 	 OBJECT_TYPE.  */
       && CLASS_TYPE_P (object_type)
       && DERIVED_FROM_P (scope, object_type))
-    /* If we are processing a `->' or `.' expression, use the type of the
-       left-hand side.  */
-    qualifying_type = object_type;
+    {
+      /* If we are processing a `->' or `.' expression, use the type of the
+	 left-hand side.  */
+      if (tree open = currently_open_class (object_type))
+	qualifying_type = open;
+      else
+	qualifying_type = object_type;
+    }
   else if (nested_name_specifier)
     {
       /* If the reference is to a non-static member of the
diff --git a/gcc/testsuite/g++.dg/template/access42.C b/gcc/testsuite/g++.dg/template/access42.C
new file mode 100644
index 00000000000..f1dcbce80c2
--- /dev/null
+++ b/gcc/testsuite/g++.dg/template/access42.C
@@ -0,0 +1,17 @@
+// PR c++/116320
+// { dg-do compile { target c++11 } }
+
+template<class T> struct C;
+template<class T> using C_ptr = C<T>*;
+
+struct B { int m; using B_typedef = B; };
+
+template<class T>
+struct C : B {
+  void f(C_ptr<T> c) {
+    c->B::m;
+    c->B_typedef::m;
+  }
+};
+
+template struct C<int>;

commit 936694079375daf027a8417ea577da676b7a7462
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Mon Sep 9 02:21:22 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index e8f2bd3ba1b..94bd4791818 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240908
+20240909
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index 5eb401ffb82..c54bdfddd51 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -1,3 +1,33 @@
+2024-09-08  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2024-08-15  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/116320
+	* semantics.cc (check_accessibility_of_qualified_id): Try
+	currently_open_class when using the object type as the
+	effective qualifying type.
+
+2024-09-08  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2024-08-10  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/116276
+	* call.cc (joust): Implement P2582R1 inherited vs non-inherited
+	guide tiebreaker.
+	* cp-tree.h (lang_decl_fn::context): Document usage in
+	deduction_guide_p FUNCTION_DECLs.
+	(inherited_guide_p): Declare.
+	* pt.cc (inherited_guide_p): Define.
+	(set_inherited_guide_context): Define.
+	(alias_ctad_tweaks): Use set_inherited_guide_context.
+	(inherited_ctad_tweaks): Recognize some inherited constructors
+	whose scope is a TYPENAME_TYPE.
+	(ctor_deduction_guides_for): For C++23 inherited CTAD, iterate
+	over TYPE_FIELDS instead of CLASSTYPE_CONSTRUCTORS to recognize
+	all inherited constructors.
+
 2024-09-07  Patrick Palka  <ppalka@redhat.com>
 
 	PR c++/116567
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 2c0a0302e93..a2096eaa0c9 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,21 @@
+2024-09-08  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2024-08-15  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/116320
+	* g++.dg/template/access42.C: New test.
+
+2024-09-08  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2024-08-10  Patrick Palka  <ppalka@redhat.com>
+
+	PR c++/116276
+	* g++.dg/cpp23/class-deduction-inherited4.C: Remove an xfail.
+	* g++.dg/cpp23/class-deduction-inherited5.C: New test.
+	* g++.dg/cpp23/class-deduction-inherited6.C: New test.
+
 2024-09-07  Patrick Palka  <ppalka@redhat.com>
 
 	PR c++/116567
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index fa511f0dc09..eb925c39b0f 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,14 @@
+2024-09-08  Patrick Palka  <ppalka@redhat.com>
+
+	Backported from master:
+	2024-08-03  Patrick Palka  <ppalka@redhat.com>
+
+	* include/bits/move.h (__like_impl): New metafunction.
+	(__like_t): Redefine in terms of __like_impl.
+	(forward_like): Redefine in terms of __like_t.
+	* testsuite/20_util/forward_like/2_neg.cc: Don't expect
+	error outside the immediate context anymore.
+
 2024-09-04  Jonathan Wakely  <jwakely@redhat.com>
 
 	Backported from master:

commit 3951efed1cce970a5c61eacbad7e5f5314a9fc17
Author: Haochen Jiang <haochen.jiang@intel.com>
Date:   Fri Sep 6 05:19:26 2024

    doc: Enhance Intel CPU documentation
    
    This patch will add those recent aliased CPU names into documentation
    for clearness.
    
    gcc/ChangeLog:
    
            PR target/116617
            * doc/invoke.texi: Add meteorlake, raptorlake and lunarlake.

diff --git a/gcc/doc/invoke.texi b/gcc/doc/invoke.texi
index 80476bcf37a..176851baf61 100644
--- a/gcc/doc/invoke.texi
+++ b/gcc/doc/invoke.texi
@@ -34484,12 +34484,14 @@ UINTR, AMX-BF16, AMX-TILE, AMX-INT8, AVX-VNNI, AVX512-FP16 and AVX512BF16
 instruction set support.
 
 @item alderlake
-Intel Alderlake CPU with 64-bit extensions, MOVBE, MMX, SSE, SSE2, SSE3, SSSE3,
-SSE4.1, SSE4.2, POPCNT, AES, PREFETCHW, PCLMUL, RDRND, XSAVE, XSAVEC, XSAVES,
-XSAVEOPT, FSGSBASE, PTWRITE, RDPID, SGX, GFNI-SSE, CLWB, MOVDIRI, MOVDIR64B,
-CLDEMOTE, WAITPKG, ADCX, AVX, AVX2, BMI, BMI2, F16C, FMA, LZCNT, PCONFIG, PKU,
-VAES, VPCLMULQDQ, SERIALIZE, HRESET, KL, WIDEKL and AVX-VNNI instruction set
-support.
+@itemx raptorlake
+@itemx meteorlake
+Intel Alderlake/Raptorlake/Meteorlake CPU with 64-bit extensions, MOVBE, MMX,
+SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, POPCNT, AES, PREFETCHW, PCLMUL, RDRND,
+XSAVE, XSAVEC, XSAVES, XSAVEOPT, FSGSBASE, PTWRITE, RDPID, SGX, GFNI-SSE, CLWB,
+MOVDIRI, MOVDIR64B, CLDEMOTE, WAITPKG, ADCX, AVX, AVX2, BMI, BMI2, F16C, FMA,
+LZCNT, PCONFIG, PKU, VAES, VPCLMULQDQ, SERIALIZE, HRESET, KL, WIDEKL and
+AVX-VNNI instruction set support.
 
 @item rocketlake
 Intel Rocketlake CPU with 64-bit extensions, MOVBE, MMX, SSE, SSE2, SSE3, SSSE3
@@ -34531,11 +34533,12 @@ UINTR, AVXIFMA, AVXVNNIINT8, AVXNECONVERT and CMPCCXADD instruction set
 support.
 
 @item arrowlake-s
-Intel Arrow Lake S CPU with 64-bit extensions, MOVBE, MMX, SSE, SSE2, SSE3,
-SSSE3, SSE4.1, SSE4.2, POPCNT, AES, PREFETCHW, PCLMUL, RDRND, XSAVE, XSAVEC,
-XSAVES, XSAVEOPT, FSGSBASE, PTWRITE, RDPID, SGX, GFNI-SSE, CLWB, MOVDIRI,
-MOVDIR64B, CLDEMOTE, WAITPKG, ADCX, AVX, AVX2, BMI, BMI2, F16C, FMA, LZCNT,
-PCONFIG, PKU, VAES, VPCLMULQDQ, SERIALIZE, HRESET, KL, WIDEKL, AVX-VNNI,
+@itemx lunarlake
+Intel Arrow Lake S/Lunarlake CPU with 64-bit extensions, MOVBE, MMX, SSE, SSE2,
+SSE3, SSSE3, SSE4.1, SSE4.2, POPCNT, AES, PREFETCHW, PCLMUL, RDRND, XSAVE,
+XSAVEC, XSAVES, XSAVEOPT, FSGSBASE, PTWRITE, RDPID, SGX, GFNI-SSE, CLWB,
+MOVDIRI, MOVDIR64B, CLDEMOTE, WAITPKG, ADCX, AVX, AVX2, BMI, BMI2, F16C, FMA,
+LZCNT, PCONFIG, PKU, VAES, VPCLMULQDQ, SERIALIZE, HRESET, KL, WIDEKL, AVX-VNNI,
 UINTR, AVXIFMA, AVXVNNIINT8, AVXNECONVERT, CMPCCXADD, AVXVNNIINT16, SHA512,
 SM3 and SM4 instruction set support.
 

commit 8a0f0fca63d18cd4a1421181f29b8659d97c6bc3
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Tue Sep 10 02:33:01 2024

    Daily bump.

diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 4773a468197..a8749a23960 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,8 @@
+2024-09-09  Haochen Jiang  <haochen.jiang@intel.com>
+
+	PR target/116617
+	* doc/invoke.texi: Add meteorlake, raptorlake and lunarlake.
+
 2024-09-05  H.J. Lu  <hjl.tools@gmail.com>
 
 	Backported from master:
diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 94bd4791818..83b31cda118 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240909
+20240910

commit ab884fffe3fc82a710bea66ad651720d71c938b8
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Tue Apr 30 10:52:13 2024

    libstdc++: Fix std::chrono::tzdb to work with vanguard format
    
    I found some issues in the std::chrono::tzdb parser by testing the
    tzdata "vanguard" format, which uses new features that aren't enabled in
    the "main" and "rearguard" data formats.
    
    Since 2024a the keyword "minimum" is no longer valid for the FROM and TO
    fields in a Rule line, which means that "m" is now a valid abbreviation
    for "maximum". Previously we expected either "mi" or "ma". For backwards
    compatibility, a FROM field beginning with "mi" is still supported and
    is treated as 1900. The "maximum" keyword is only allowed in TO now,
    because it makes no sense in FROM. To support these changes the
    minmax_year and minmax_year2 classes for parsing FROM and TO are
    replaced with a single years_from_to class that reads both fields.
    
    The vanguard format makes use of %z in Zone FORMAT fields, which caused
    an exception to be thrown from ZoneInfo::set_abbrev because no % or /
    characters were expected when a Zone doesn't use a named Rule. The
    ZoneInfo::to(sys_info&) function now uses format_abbrev_str to replace
    any %z with the current offset. Although format_abbrev_str also checks
    for %s and STD/DST formats, those only make sense when a named Rule is
    in effect, so won't occur when ZoneInfo::to(sys_info&) is used.
    
    Since making this change on trunk, the tzdata-2024b release started
    using %z in the main format, not just vanguard. This makes a backport to
    release branches necessary (see PR 116657).
    
    This change also implements a feature that has always been missing from
    time_zone::_M_get_sys_info: finding the Rule that is active before the
    specified time point, so that we can correctly handle %s in the FORMAT
    for the first new sys_info that gets created. This requires implementing
    a poorly documented feature of zic, to get the LETTERS field from a
    later transition, as described at
    https://mm.icann.org/pipermail/tz/2024-April/058891.html
    In order for this to work we need to be able to distinguish an empty
    letters field (as used by CE%sT where the variable part is either empty
    or "S") from "the letters field is not known for this transition". The
    tzdata file uses "-" for an empty letters field, which libstdc++ was
    previously replacing with "" when the Rule was parsed. Instead, we now
    preserve the "-" in the Rule object, so that "" can be used for the case
    where we don't know the letters (and so need to decide it).
    
    libstdc++-v3/ChangeLog:
    
            * src/c++20/tzdb.cc (minmax_year, minmax_year2): Remove.
            (years_from_to): New class replacing minmax_year and
            minmax_year2.
            (format_abbrev_str, select_std_or_dst_abbrev): Move earlier in
            the file. Handle "-" for letters.
            (ZoneInfo::to): Use format_abbrev_str to expand %z.
            (ZoneInfo::set_abbrev): Remove exception. Change parameter from
            reference to value.
            (operator>>(istream&, Rule&)): Do not clear letters when it
            contains "-".
            (time_zone::_M_get_sys_info): Add missing logic to find the Rule
            in effect before the time point.
            * testsuite/std/time/tzdb/1.cc: Adjust for vanguard format using
            "GMT" as the Zone name, not as a Link to "Etc/GMT".
            * testsuite/std/time/time_zone/sys_info_abbrev.cc: New test.
    
    (cherry picked from commit 0ca8d56f2085715f27ee536c6c344bc47af49cdd)

diff --git a/libstdc++-v3/src/c++20/tzdb.cc b/libstdc++-v3/src/c++20/tzdb.cc
index c7c7cc9deee..7e8cce7ce8c 100644
--- a/libstdc++-v3/src/c++20/tzdb.cc
+++ b/libstdc++-v3/src/c++20/tzdb.cc
@@ -342,51 +342,103 @@ namespace std::chrono
       friend istream& operator>>(istream&, on_day&);
     };
 
-    // Wrapper for chrono::year that reads a year, or one of the keywords
-    // "minimum" or "maximum", or an unambiguous prefix of a keyword.
-    struct minmax_year
+    // Wrapper for two chrono::year values, which reads the FROM and TO
+    // fields of a Rule line. The FROM field is a year and TO is a year or
+    // one of the keywords "maximum" or "only" (or an abbreviation of those).
+    // For backwards compatibility, the keyword "minimum" is recognized
+    // for FROM and interpreted as 1900.
+    struct years_from_to
     {
-      year& y;
+      year& from;
+      year& to;
 
-      friend istream& operator>>(istream& in, minmax_year&& y)
+      friend istream& operator>>(istream& in, years_from_to&& yy)
       {
-	if (ws(in).peek() == 'm') // keywords "minimum" or "maximum"
+	string s;
+	auto c = ws(in).peek();
+	if (c == 'm') [[unlikely]] // keyword "minimum"
 	  {
-	    string s;
-	    in >> s; // extract the rest of the word, but only look at s[1]
-	    if (s[1] == 'a')
-	      y.y = year::max();
-	    else if (s[1] == 'i')
-	      y.y = year::min();
-	    else
-	      in.setstate(ios::failbit);
+	    in >> s; // extract the rest of the word
+	    yy.from = year(1900);
+	  }
+	else if (int num = 0; in >> num) [[likely]]
+	  yy.from = year{num};
+
+	c = ws(in).peek();
+	if (c == 'm') // keyword "maximum"
+	  {
+	    in >> s; // extract the rest of the word
+	    yy.to = year::max();
+	  }
+	else if (c == 'o') // keyword "only"
+	  {
+	    in >> s; // extract the rest of the word
+	    yy.to = yy.from;
 	  }
 	else if (int num = 0; in >> num)
-	  y.y = year{num};
+	  yy.to = year{num};
+
 	return in;
       }
     };
 
-    // As above for minmax_year, but also supports the keyword "only",
-    // meaning that the TO year is the same as the FROM year.
-    struct minmax_year2
+    bool
+    select_std_or_dst_abbrev(string& abbrev, minutes save)
     {
-      minmax_year to;
-      year from;
+      if (size_t pos = abbrev.find('/'); pos != string::npos)
+	{
+	  // Select one of "STD/DST" for standard or daylight.
+	  if (save == 0min)
+	    abbrev.erase(pos);
+	  else
+	    abbrev.erase(0, pos + 1);
+	  return true;
+	}
+      return false;
+    }
 
-      friend istream& operator>>(istream& in, minmax_year2&& y)
-      {
-	if (ws(in).peek() == 'o') // keyword "only"
-	  {
-	    string s;
-	    in >> s; // extract the whole keyword
-	    y.to.y = y.from;
-	  }
-	else
-	  in >> std::move(y.to);
-	return in;
-      }
-    };
+    // Set the sys_info::abbrev string by expanding any placeholders.
+    void
+    format_abbrev_str(sys_info& info, string_view letters = {})
+    {
+      if (size_t pos = info.abbrev.find('%'); pos != string::npos)
+	{
+	  if (info.abbrev[pos + 1] == 's')
+	    {
+	      // Expand "%s" to the variable part, given by Rule::letters.
+	      if (letters == "-")
+		info.abbrev.erase(pos, 2);
+	      else
+		info.abbrev.replace(pos, 2, letters);
+	    }
+	  else if (info.abbrev[pos + 1] == 'z')
+	    {
+	      // Expand "%z" to the UT offset as +/-hh, +/-hhmm, or +/-hhmmss.
+	      hh_mm_ss<seconds> t(info.offset);
+	      string z(1, "+-"[t.is_negative()]);
+	      long val = t.hours().count();
+	      int digits = 2;
+	      if (int m = t.minutes().count())
+		{
+		  digits = 4;
+		  val *= 100;
+		  val += m;
+		  if (int s = t.seconds().count())
+		    {
+		      digits = 6;
+		      val *= 100;
+		      val += s;
+		    }
+		}
+	      auto sval = std::to_string(val);
+	      z += string(digits - sval.size(), '0');
+	      z += sval;
+	      info.abbrev.replace(pos, 2, z);
+	    }
+	}
+      else
+	select_std_or_dst_abbrev(info.abbrev, info.save);
+    }
 
     // A time zone information record.
     // Zone  NAME        STDOFF  RULES   FORMAT  [UNTIL]
@@ -462,6 +514,7 @@ namespace std::chrono
 	info.offset = offset();
 	info.save = minutes(m_save);
 	info.abbrev = format();
+	format_abbrev_str(info); // expand %z
 	return true;
       }
 
@@ -469,12 +522,9 @@ namespace std::chrono
       friend class time_zone;
 
       void
-      set_abbrev(const string& abbrev)
+      set_abbrev(string abbrev)
       {
-	// In practice, the FORMAT field never needs expanding here.
-	if (abbrev.find_first_of("/%") != abbrev.npos)
-	  __throw_runtime_error("std::chrono::time_zone: invalid data");
-	m_buf = abbrev;
+	m_buf = std::move(abbrev);
 	m_pos = 0;
 	m_expanded = true;
       }
@@ -544,9 +594,7 @@ namespace std::chrono
 
 	// Rule  NAME  FROM  TO  TYPE  IN  ON  AT  SAVE  LETTER/S
 
-	in >> quoted(rule.name)
-	   >> minmax_year{rule.from}
-	   >> minmax_year2{rule.to, rule.from};
+	in >> quoted(rule.name) >> years_from_to{rule.from, rule.to};
 
 	if (char type; in >> type && type != '-')
 	  in.setstate(ios::failbit);
@@ -557,7 +605,7 @@ namespace std::chrono
 	if (save_time.indicator != at_time::Wall)
 	  {
 	    // We don't actually store the save_time.indicator, because we
-	    // assume that it's always deducable from the actual offset value.
+	    // assume that it's always deducible from the offset value.
 	    auto expected = save_time.time == 0s
 			      ? at_time::Standard
 			      : at_time::Daylight;
@@ -567,8 +615,6 @@ namespace std::chrono
 	rule.save = save_time.time;
 
 	in >> rule.letters;
-	if (rule.letters == "-")
-	  rule.letters.clear();
 	return in;
       }
 
@@ -719,58 +765,6 @@ namespace std::chrono
 #endif // TZDB_DISABLED
   };
 
-#ifndef TZDB_DISABLED
-  namespace
-  {
-    bool
-    select_std_or_dst_abbrev(string& abbrev, minutes save)
-    {
-      if (size_t pos = abbrev.find('/'); pos != string::npos)
-	{
-	  // Select one of "STD/DST" for standard or daylight.
-	  if (save == 0min)
-	    abbrev.erase(pos);
-	  else
-	    abbrev.erase(0, pos + 1);
-	  return true;
-	}
-      return false;
-    }
-
-    // Set the sys_info::abbrev string by expanding any placeholders.
-    void
-    format_abbrev_str(sys_info& info, string_view letters = {})
-    {
-      if (size_t pos = info.abbrev.find("%s"); pos != string::npos)
-	{
-	  // Expand "%s" to the variable part, given by Rule::letters.
-	  info.abbrev.replace(pos, 2, letters);
-	}
-      else if (size_t pos = info.abbrev.find("%z"); pos != string::npos)
-	{
-	  // Expand "%z" to the UT offset as +/-hh, +/-hhmm, or +/-hhmmss.
-	  hh_mm_ss<seconds> t(info.offset);
-	  string z(1, "+-"[t.is_negative()]);
-	  long val = t.hours().count();
-	  if (minutes m = t.minutes(); m != m.zero())
-	    {
-	      val *= 100;
-	      val += m.count();
-	      if (seconds s = t.seconds(); s != s.zero())
-		{
-		  val *= 100;
-		  val += s.count();
-		}
-	    }
-	  z += std::to_string(val);
-	  info.abbrev.replace(pos, 2, z);
-	}
-      else
-	select_std_or_dst_abbrev(info.abbrev, info.save);
-    }
-  }
-#endif // TZDB_DISABLED
-
   // Implementation of std::chrono::time_zone::get_info(const sys_time<D>&)
   sys_info
   time_zone::_M_get_sys_info(sys_seconds tp) const
@@ -839,12 +833,72 @@ namespace std::chrono
     info.abbrev = ri.format();
 
     string_view letters;
-    if (i != infos.begin())
+    if (i != infos.begin() && i[-1].expanded())
+      letters = i[-1].next_letters();
+
+    if (letters.empty())
       {
-	if (i[-1].expanded())
-	  letters = i[-1].next_letters();
-	// XXX else need to find Rule active before this time and use it
-	// to know the initial offset, save, and letters.
+	sys_seconds t = info.begin - seconds(1);
+	const year_month_day date(chrono::floor<days>(t));
+
+	// Try to find a Rule active before this time, to get initial
+	// SAVE and LETTERS values. There may not be a Rule for the period
+	// before the first DST transition, so find the earliest DST->STD
+	// transition and use the LETTERS from that.
+	const Rule* active_rule = nullptr;
+	sys_seconds active_rule_start = sys_seconds::min();
+	const Rule* first_std = nullptr;
+	for (const auto& rule : rules)
+	  {
+	    if (rule.save == minutes(0))
+	      {
+		if (!first_std)
+		  first_std = &rule;
+		else if (rule.from < first_std->from)
+		  first_std = &rule;
+		else if (rule.from == first_std->from)
+		  {
+		    if (rule.start_time(rule.from, {})
+			  < first_std->start_time(first_std->from, {}))
+		      first_std = &rule;
+		  }
+	      }
+
+	    year y = date.year();
+
+	    if (y > rule.to) // rule no longer applies at time t
+	      continue;
+	    if (y < rule.from) // rule doesn't apply yet at time t
+	      continue;
+
+	    sys_seconds rule_start;
+
+	    seconds offset{}; // appropriate for at_time::Universal
+	    if (rule.when.indicator == at_time::Wall)
+	      offset = info.offset;
+	    else if (rule.when.indicator == at_time::Standard)
+	      offset = ri.offset();
+
+	    // Time the rule takes effect this year:
+	    rule_start = rule.start_time(y, offset);
+
+	    if (rule_start >= t && rule.from < y)
+	      {
+		// Try this rule in the previous year.
+		rule_start = rule.start_time(--y, offset);
+	      }
+
+	    if (active_rule_start < rule_start && rule_start < t)
+	      {
+		active_rule_start = rule_start;
+		active_rule = &rule;
+	      }
+	  }
+
+	if (active_rule)
+	  letters = active_rule->letters;
+	else if (first_std)
+	  letters = first_std->letters;
       }
 
     const Rule* curr_rule = nullptr;
@@ -2069,9 +2123,11 @@ namespace std::chrono
 	      istringstream in2(std::move(rules));
 	      in2 >> rules_time;
 	      inf.m_save = duration_cast<minutes>(rules_time.time);
+	      // If the FORMAT is "STD/DST" then we can choose the right one
+	      // now, so that we store a shorter string.
 	      select_std_or_dst_abbrev(fmt, inf.m_save);
 	    }
-	  inf.set_abbrev(fmt);
+	  inf.set_abbrev(std::move(fmt));
 	}
 
       // YEAR [MONTH [DAY [TIME]]]
@@ -2082,7 +2138,12 @@ namespace std::chrono
 	  abbrev_month m{January};
 	  int d = 1;
 	  at_time t{};
+	  // XXX DAY should support ON format, e.g. lastSun or Sun>=8
 	  in >> m >> d >> t;
+	  // XXX UNTIL field should be interpreted
+	  // "using the rules in effect just before the transition"
+	  // so might need to store as year_month_day and hh_mm_ss and only
+	  // convert to a sys_time once we know the offset in effect.
 	  inf.m_until = sys_days(year(y)/m.m/day(d)) + seconds(t.time);
 	}
       else
diff --git a/libstdc++-v3/testsuite/std/time/time_zone/sys_info_abbrev.cc b/libstdc++-v3/testsuite/std/time/time_zone/sys_info_abbrev.cc
new file mode 100644
index 00000000000..f1a8fff02f5
--- /dev/null
+++ b/libstdc++-v3/testsuite/std/time/time_zone/sys_info_abbrev.cc
@@ -0,0 +1,106 @@
+// { dg-do run { target c++20 } }
+// { dg-require-effective-target tzdb }
+// { dg-require-effective-target cxx11_abi }
+// { dg-xfail-run-if "no weak override on AIX" { powerpc-ibm-aix* } }
+
+#include <chrono>
+#include <fstream>
+#include <testsuite_hooks.h>
+
+static bool override_used = false;
+
+namespace __gnu_cxx
+{
+  const char* zoneinfo_dir_override() {
+    override_used = true;
+    return "./";
+  }
+}
+
+using namespace std::chrono;
+
+void
+test_format()
+{
+  std::ofstream("tzdata.zi") << R"(# version test_1
+Zone Africa/Bissau -1:2:20 - LMT 1912 Ja 1 1u
+                   -1      - %z  1975
+                   0       - GMT
+Zon Some/Zone 1:2:3   - %z 1900
+              1:23:45 - %z 1950
+Zo Another/Zone 1:2:3 -     AZ0     1901
+                1     Roolz A%sZ    2000
+                1     Roolz SAZ/DAZ 2005
+                1     Roolz %z
+Rule Roolz 1950 max - April 1 2 1 D
+Rul  Roolz 1950 max - Oct   1 1 0 S
+Z Strange/Zone 1       - X%sX    1980
+               1       - FOO/BAR 1990
+               2:00    - %zzz    1995
+               0:9     - %zzz    1996
+               0:8:7   - %zzz    1997
+               0:6:5.5 - %zzz    1998
+)";
+
+  const auto& db = reload_tzdb();
+  VERIFY( override_used ); // If this fails then XFAIL for the target.
+  VERIFY( db.version == "test_1" );
+
+  // Test formatting %z as
+  auto tz = locate_zone("Africa/Bissau");
+  auto inf = tz->get_info(sys_days(1974y/1/1));
+  VERIFY( inf.abbrev == "-01" );
+
+  tz = locate_zone("Some/Zone");
+  inf = tz->get_info(sys_days(1899y/1/1));
+  VERIFY( inf.abbrev == "+010203" );
+  inf = tz->get_info(sys_days(1955y/1/1));
+  VERIFY( inf.abbrev == "+012345" );
+
+  tz = locate_zone("Another/Zone");
+  // Test formatting %s as the LETTER/S field from the active Rule.
+  inf = tz->get_info(sys_days(1910y/January/1));
+  VERIFY( inf.abbrev == "ASZ" );
+  inf = tz->get_info(sys_days(1950y/January/1));
+  VERIFY( inf.abbrev == "ASZ" );
+  inf = tz->get_info(sys_days(1950y/June/1));
+  VERIFY( inf.abbrev == "ADZ" );
+  inf = tz->get_info(sys_days(1999y/January/1));
+  VERIFY( inf.abbrev == "ASZ" );
+  inf = tz->get_info(sys_days(1999y/July/1));
+  VERIFY( inf.abbrev == "ADZ" );
+  // Test formatting STD/DST according to the active Rule.
+  inf = tz->get_info(sys_days(2000y/January/2));
+  VERIFY( inf.abbrev == "SAZ" );
+  inf = tz->get_info(sys_days(2001y/January/1));
+  VERIFY( inf.abbrev == "SAZ" );
+  inf = tz->get_info(sys_days(2001y/July/1));
+  VERIFY( inf.abbrev == "DAZ" );
+  // Test formatting %z as the offset determined by the active Rule.
+  inf = tz->get_info(sys_days(2005y/January/2));
+  VERIFY( inf.abbrev == "+01" );
+  inf = tz->get_info(sys_days(2006y/January/1));
+  VERIFY( inf.abbrev == "+01" );
+  inf = tz->get_info(sys_days(2006y/July/1));
+  VERIFY( inf.abbrev == "+02" );
+
+  // Test formatting %z, %s and S/D for a Zone with no associated Rules.
+  tz = locate_zone("Strange/Zone");
+  inf = tz->get_info(sys_days(1979y/January/1));
+  VERIFY( inf.abbrev == "XX" ); // No Rule means nothing to use for %s.
+  inf = tz->get_info(sys_days(1981y/July/1));
+  VERIFY( inf.abbrev == "FOO" ); // Always standard time means first string.
+  inf = tz->get_info(sys_days(1994y/July/1));
+  VERIFY( inf.abbrev == "+02zz" );
+  inf = tz->get_info(sys_days(1995y/July/1));
+  VERIFY( inf.abbrev == "+0009zz" );
+  inf = tz->get_info(sys_days(1996y/July/1));
+  VERIFY( inf.abbrev == "+000807zz" );
+  inf = tz->get_info(sys_days(1997y/July/1));
+  VERIFY( inf.abbrev == "+000606zz" );
+}
+
+int main()
+{
+  test_format();
+}
diff --git a/libstdc++-v3/testsuite/std/time/tzdb/1.cc b/libstdc++-v3/testsuite/std/time/tzdb/1.cc
index 796f3a8b425..7a31c1c20ba 100644
--- a/libstdc++-v3/testsuite/std/time/tzdb/1.cc
+++ b/libstdc++-v3/testsuite/std/time/tzdb/1.cc
@@ -39,11 +39,15 @@ test_locate()
   const tzdb& db = get_tzdb();
   const time_zone* tz = db.locate_zone("GMT");
   VERIFY( tz != nullptr );
-  VERIFY( tz->name() == "Etc/GMT" );
   VERIFY( tz == std::chrono::locate_zone("GMT") );
   VERIFY( tz == db.locate_zone("Etc/GMT") );
   VERIFY( tz == db.locate_zone("Etc/GMT+0") );
 
+  // Since 2022f GMT is now a Zone and Etc/GMT a link instead of vice versa,
+  // but only when using the vanguard format. As of 2024a, the main and
+  // rearguard formats still have Etc/GMT as a Zone and GMT as a link.
+  VERIFY( tz->name() == "GMT" || tz->name() == "Etc/GMT" );
+
   VERIFY( db.locate_zone(db.current_zone()->name()) == db.current_zone() );
 }
 

commit f0f00c44eb86cc3f5e371fcd4931e1219893351c
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Wed Sep 11 02:23:02 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 83b31cda118..2abf40291e6 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240910
+20240911
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index eb925c39b0f..6c100031e4c 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,24 @@
+2024-09-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-06-26  Jonathan Wakely  <jwakely@redhat.com>
+
+	* src/c++20/tzdb.cc (minmax_year, minmax_year2): Remove.
+	(years_from_to): New class replacing minmax_year and
+	minmax_year2.
+	(format_abbrev_str, select_std_or_dst_abbrev): Move earlier in
+	the file. Handle "-" for letters.
+	(ZoneInfo::to): Use format_abbrev_str to expand %z.
+	(ZoneInfo::set_abbrev): Remove exception. Change parameter from
+	reference to value.
+	(operator>>(istream&, Rule&)): Do not clear letters when it
+	contains "-".
+	(time_zone::_M_get_sys_info): Add missing logic to find the Rule
+	in effect before the time point.
+	* testsuite/std/time/tzdb/1.cc: Adjust for vanguard format using
+	"GMT" as the Zone name, not as a Link to "Etc/GMT".
+	* testsuite/std/time/time_zone/sys_info_abbrev.cc: New test.
+
 2024-09-08  Patrick Palka  <ppalka@redhat.com>
 
 	Backported from master:

commit d5d6d3ff43c5166ead1787c4334553be26cc84da
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Tue Sep 10 15:25:41 2024

    libstdc++: std::string move assignment should not use POCCA trait [PR116641]
    
    The changes to implement LWG 2579 (r10-327-gdb33efde17932f) made
    std::string::assign use the propagate_on_container_copy_assignment
    (POCCA) trait, for consistency with operator=(const basic_string&).
    However, this also unintentionally affected operator=(basic_string&&)
    which calls assign(str) to make a deep copy when performing a move is
    not possible. The fix is for the move assignment operator to call
    _M_assign(str) instead of assign(str), as this just does the deep copy
    and doesn't check the POCCA trait first.
    
    The bug only affects the unlikely/useless combination of POCCA==true and
    POCMA==false, but we should fix it for correctness anyway. it should
    also make move assignment slightly cheaper to compile and execute,
    because we skip the extra code in assign(const basic_string&).
    
    libstdc++-v3/ChangeLog:
    
            PR libstdc++/116641
            * include/bits/basic_string.h (operator=(basic_string&&)): Call
            _M_assign instead of assign.
            * testsuite/21_strings/basic_string/allocator/116641.cc: New
            test.
    
    (cherry picked from commit c07cf418fdde0c192e370a8d76a991cc7215e9c4)

diff --git a/libstdc++-v3/include/bits/basic_string.h b/libstdc++-v3/include/bits/basic_string.h
index 8a695a494ef..2794ec6419a 100644
--- a/libstdc++-v3/include/bits/basic_string.h
+++ b/libstdc++-v3/include/bits/basic_string.h
@@ -912,7 +912,7 @@ _GLIBCXX_BEGIN_NAMESPACE_CXX11
 	      __str._M_data(__str._M_use_local_data());
 	  }
 	else // Need to do a deep copy
-	  assign(__str);
+	  _M_assign(__str);
 	__str.clear();
 	return *this;
       }
diff --git a/libstdc++-v3/testsuite/21_strings/basic_string/allocator/116641.cc b/libstdc++-v3/testsuite/21_strings/basic_string/allocator/116641.cc
new file mode 100644
index 00000000000..a1a411b87fa
--- /dev/null
+++ b/libstdc++-v3/testsuite/21_strings/basic_string/allocator/116641.cc
@@ -0,0 +1,53 @@
+// { dg-do run { target c++11 } }
+// { dg-require-effective-target cxx11_abi }
+
+// Bug 116641 - std::string move assignment incorrectly depends on POCCA
+
+#include <string>
+#include <testsuite_hooks.h>
+
+template<typename T>
+struct Alloc
+{
+  using value_type = T;
+  using propagate_on_container_swap = std::false_type;
+  using propagate_on_container_copy_assignment = std::true_type;
+  using propagate_on_container_move_assignment = std::false_type;
+
+  Alloc(int id) : id(id) { }
+
+  template<typename U>
+    Alloc(const Alloc<U>& a) : id(a.id) { }
+
+  T* allocate(unsigned long n)
+  { return std::allocator<T>().allocate(n); }
+
+  void deallocate(T* p, unsigned long n)
+  { std::allocator<T>().deallocate(p, n); }
+
+  Alloc& operator=(const Alloc&) { throw; }
+
+  bool operator==(const Alloc& a) const { return id == a.id; }
+  bool operator!=(const Alloc& a) const { return id != a.id; }
+
+  int id;
+};
+
+void
+test_pr116641()
+{
+  Alloc<char> a1(1), a2(2);
+  std::basic_string<char, std::char_traits<char>, Alloc<char>> s1(a1), s2(a2);
+
+  s1 = "allocator should not propagate on move assignment";
+  VERIFY( s1.get_allocator() == a1 );
+  VERIFY( s2.get_allocator() == a2 );
+  s2 = std::move(s1);
+  VERIFY( s1.get_allocator() == a1 );
+  VERIFY( s2.get_allocator() == a2 );
+}
+
+int main()
+{
+  test_pr116641();
+}

commit 2003f890b13b8ec35b6112fc13c7e69e61cd9162
Author: Jonathan Wakely <jwakely@redhat.com>
Date:   Tue Sep 10 15:36:26 2024

    libstdc++: Only use std::ios_base_library_init() for ELF [PR116159]
    
    The undefined std::ios_base_library_init() symbol that is referenced by
    <iostream> is only supposed to be used for targets where symbol
    versioning is supported.
    
    The mingw-w64 target defaults to --enable-symvers=gnu due to using GNU
    ld but doesn't actually support symbol versioning. This means it tries
    to emit references to the std::ios_base_library_init() symbol, which
    isn't really defined in the library. This causes problems when using lld
    to link user binaries.
    
    Disable the undefined symbol reference for non-ELF targets.
    
    libstdc++-v3/ChangeLog:
    
            PR libstdc++/116159
            * include/std/iostream (ios_base_library_init): Only define for
            ELF targets.
            * src/c++98/ios_init.cc (ios_base_library_init): Likewise.
    
    (cherry picked from commit fc7a1fb0238e379d466316aa219734ac61f4bc0e)

diff --git a/libstdc++-v3/include/std/iostream b/libstdc++-v3/include/std/iostream
index 0c6a2d8a4b3..208fd1d5138 100644
--- a/libstdc++-v3/include/std/iostream
+++ b/libstdc++-v3/include/std/iostream
@@ -78,7 +78,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
 #if !(_GLIBCXX_USE_INIT_PRIORITY_ATTRIBUTE \
       && __has_attribute(__init_priority__))
   static ios_base::Init __ioinit;
-#elif defined(_GLIBCXX_SYMVER_GNU)
+#elif defined(_GLIBCXX_SYMVER_GNU) && defined(__ELF__)
   __extension__ __asm (".globl _ZSt21ios_base_library_initv");
 #endif
 
diff --git a/libstdc++-v3/src/c++98/ios_init.cc b/libstdc++-v3/src/c++98/ios_init.cc
index 1422e20d940..6e2e5014cf0 100644
--- a/libstdc++-v3/src/c++98/ios_init.cc
+++ b/libstdc++-v3/src/c++98/ios_init.cc
@@ -199,7 +199,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
     return __ret;
   }
 
-#ifdef _GLIBCXX_SYMVER_GNU
+#if defined(_GLIBCXX_SYMVER_GNU) && defined(__ELF__)
 #pragma GCC diagnostic ignored "-Wattribute-alias"
 
   void ios_base_library_init (void)

commit 78a08bf4a16cdb610b83fcf97249bfe567fa169b
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Thu Sep 12 02:20:49 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 2abf40291e6..8dcf10768ee 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240911
+20240912
diff --git a/libstdc++-v3/ChangeLog b/libstdc++-v3/ChangeLog
index 6c100031e4c..c30ae1757cf 100644
--- a/libstdc++-v3/ChangeLog
+++ b/libstdc++-v3/ChangeLog
@@ -1,3 +1,24 @@
+2024-09-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-09-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/116159
+	* include/std/iostream (ios_base_library_init): Only define for
+	ELF targets.
+	* src/c++98/ios_init.cc (ios_base_library_init): Likewise.
+
+2024-09-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backported from master:
+	2024-09-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/116641
+	* include/bits/basic_string.h (operator=(basic_string&&)): Call
+	_M_assign instead of assign.
+	* testsuite/21_strings/basic_string/allocator/116641.cc: New
+	test.
+
 2024-09-10  Jonathan Wakely  <jwakely@redhat.com>
 
 	Backported from master:

commit c9fd43a8df0e30109794e2480e2d8d05d00763c0
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Sat Sep 7 09:36:53 2024

    libiberty: Fix up > 64K section handling in simple_object_elf_copy_lto_debug_section [PR116614]
    
    cat abc.C
      #define A(n) struct T##n {} t##n;
      #define B(n) A(n##0) A(n##1) A(n##2) A(n##3) A(n##4) A(n##5) A(n##6) A(n##7) A(n##8) A(n##9)
      #define C(n) B(n##0) B(n##1) B(n##2) B(n##3) B(n##4) B(n##5) B(n##6) B(n##7) B(n##8) B(n##9)
      #define D(n) C(n##0) C(n##1) C(n##2) C(n##3) C(n##4) C(n##5) C(n##6) C(n##7) C(n##8) C(n##9)
      #define E(n) D(n##0) D(n##1) D(n##2) D(n##3) D(n##4) D(n##5) D(n##6) D(n##7) D(n##8) D(n##9)
      E(1) E(2) E(3)
      int main () { return 0; }
    ./xg++ -B ./ -o abc{.o,.C} -flto -flto-partition=1to1 -O2 -g -fdebug-types-section -c
    ./xgcc -B ./ -o abc{,.o} -flto -flto-partition=1to1 -O2
    (not included in testsuite as it takes a while to compile) FAILs with
    lto-wrapper: fatal error: Too many copied sections: Operation not supported
    compilation terminated.
    /usr/bin/ld: error: lto-wrapper failed
    collect2: error: ld returned 1 exit status
    
    The following patch fixes that.  Most of the 64K+ section support for
    reading and writing was already there years ago (and especially reading used
    quite often already) and a further bug fixed in it in the PR104617 fix.
    
    Yet, the fix isn't solely about removing the
      if (new_i - 1 >= SHN_LORESERVE)
        {
          *err = ENOTSUP;
          return "Too many copied sections";
        }
    5 lines, the missing part was that the function only handled reading of
    the .symtab_shndx section but not copying/updating of it.
    If the result has less than 64K-epsilon sections, that actually wasn't
    needed, but e.g. with -fdebug-types-section one can exceed that pretty
    easily (reported to us on WebKitGtk build on ppc64le).
    Updating the section is slightly more complicated, because it basically
    needs to be done in lock step with updating the .symtab section, if one
    doesn't need to use SHN_XINDEX in there, the section should (or should be
    updated to) contain SHN_UNDEF entry, otherwise needs to have whatever would
    be overwise stored but couldn't fit.  But repeating due to that all the
    symtab decisions what to discard and how to rewrite it would be ugly.
    
    So, the patch instead emits the .symtab_shndx section (or sections) last
    and prepares the content during the .symtab processing and in a second
    pass when going just through .symtab_shndx sections just uses the saved
    content.
    
    2024-09-07  Jakub Jelinek  <jakub@redhat.com>
    
            PR lto/116614
            * simple-object-elf.c (SHN_COMMON): Align comment with neighbouring
            comments.
            (SHN_HIRESERVE): Use uppercase hex digits instead of lowercase for
            consistency.
            (simple_object_elf_find_sections): Formatting fixes.
            (simple_object_elf_fetch_attributes): Likewise.
            (simple_object_elf_attributes_merge): Likewise.
            (simple_object_elf_start_write): Likewise.
            (simple_object_elf_write_ehdr): Likewise.
            (simple_object_elf_write_shdr): Likewise.
            (simple_object_elf_write_to_file): Likewise.
            (simple_object_elf_copy_lto_debug_section): Likewise.  Don't fail for
            new_i - 1 >= SHN_LORESERVE, instead arrange in that case to copy
            over .symtab_shndx sections, though emit those last and compute their
            section content when processing associated .symtab sections.  Handle
            simple_object_internal_read failure even in the .symtab_shndx reading
            case.
    
    (cherry picked from commit bb8dd0980b39cfd601f88703fd356055727ef24d)

diff --git a/libiberty/simple-object-elf.c b/libiberty/simple-object-elf.c
index c09c216656c..5e95297b2fc 100644
--- a/libiberty/simple-object-elf.c
+++ b/libiberty/simple-object-elf.c
@@ -128,9 +128,9 @@ typedef struct {
 
 #define SHN_UNDEF	0		/* Undefined section */
 #define SHN_LORESERVE	0xFF00		/* Begin range of reserved indices */
-#define SHN_COMMON	0xFFF2	/* Associated symbol is in common */
+#define SHN_COMMON	0xFFF2		/* Associated symbol is in common */
 #define SHN_XINDEX	0xFFFF		/* Section index is held elsewhere */
-#define SHN_HIRESERVE	0xffff		/* End of reserved indices */
+#define SHN_HIRESERVE	0xFFFF		/* End of reserved indices */
 
 
 /* 32-bit ELF program header.  */
@@ -569,8 +569,8 @@ simple_object_elf_find_sections (simple_object_read *sobj,
 				 void *data,
 				 int *err)
 {
-  struct simple_object_elf_read *eor =
-    (struct simple_object_elf_read *) sobj->data;
+  struct simple_object_elf_read *eor
+    = (struct simple_object_elf_read *) sobj->data;
   const struct elf_type_functions *type_functions = eor->type_functions;
   unsigned char ei_class = eor->ei_class;
   size_t shdr_size;
@@ -662,8 +662,8 @@ simple_object_elf_fetch_attributes (simple_object_read *sobj,
 				    const char **errmsg ATTRIBUTE_UNUSED,
 				    int *err ATTRIBUTE_UNUSED)
 {
-  struct simple_object_elf_read *eor =
-    (struct simple_object_elf_read *) sobj->data;
+  struct simple_object_elf_read *eor
+    = (struct simple_object_elf_read *) sobj->data;
   struct simple_object_elf_attributes *ret;
 
   ret = XNEW (struct simple_object_elf_attributes);
@@ -689,10 +689,10 @@ simple_object_elf_release_read (void *data)
 static const char *
 simple_object_elf_attributes_merge (void *todata, void *fromdata, int *err)
 {
-  struct simple_object_elf_attributes *to =
-    (struct simple_object_elf_attributes *) todata;
-  struct simple_object_elf_attributes *from =
-    (struct simple_object_elf_attributes *) fromdata;
+  struct simple_object_elf_attributes *to
+    = (struct simple_object_elf_attributes *) todata;
+  struct simple_object_elf_attributes *from
+    = (struct simple_object_elf_attributes *) fromdata;
 
   if (to->ei_data != from->ei_data || to->ei_class != from->ei_class)
     {
@@ -751,8 +751,8 @@ simple_object_elf_start_write (void *attributes_data,
 			       const char **errmsg ATTRIBUTE_UNUSED,
 			       int *err ATTRIBUTE_UNUSED)
 {
-  struct simple_object_elf_attributes *attrs =
-    (struct simple_object_elf_attributes *) attributes_data;
+  struct simple_object_elf_attributes *attrs
+    = (struct simple_object_elf_attributes *) attributes_data;
   struct simple_object_elf_write *ret;
 
   /* We're just going to record the attributes, but we need to make a
@@ -769,8 +769,8 @@ static int
 simple_object_elf_write_ehdr (simple_object_write *sobj, int descriptor,
 			      const char **errmsg, int *err)
 {
-  struct simple_object_elf_attributes *attrs =
-    (struct simple_object_elf_attributes *) sobj->data;
+  struct simple_object_elf_attributes *attrs
+    = (struct simple_object_elf_attributes *) sobj->data;
   const struct elf_type_functions* fns;
   unsigned char cl;
   size_t ehdr_size;
@@ -852,8 +852,8 @@ simple_object_elf_write_shdr (simple_object_write *sobj, int descriptor,
 			      size_t sh_entsize,
 			      const char **errmsg, int *err)
 {
-  struct simple_object_elf_attributes *attrs =
-    (struct simple_object_elf_attributes *) sobj->data;
+  struct simple_object_elf_attributes *attrs
+    = (struct simple_object_elf_attributes *) sobj->data;
   const struct elf_type_functions* fns;
   unsigned char cl;
   size_t shdr_size;
@@ -894,8 +894,8 @@ static const char *
 simple_object_elf_write_to_file (simple_object_write *sobj, int descriptor,
 				 int *err)
 {
-  struct simple_object_elf_write *eow =
-    (struct simple_object_elf_write *) sobj->data;
+  struct simple_object_elf_write *eow
+    = (struct simple_object_elf_write *) sobj->data;
   struct simple_object_elf_attributes *attrs = &eow->attrs;
   unsigned char cl;
   size_t ehdr_size;
@@ -1088,11 +1088,11 @@ simple_object_elf_copy_lto_debug_sections (simple_object_read *sobj,
 					   char *(*pfn) (const char *),
 					   int *err)
 {
-  struct simple_object_elf_read *eor =
-    (struct simple_object_elf_read *) sobj->data;
+  struct simple_object_elf_read *eor
+    = (struct simple_object_elf_read *) sobj->data;
   const struct elf_type_functions *type_functions = eor->type_functions;
-  struct simple_object_elf_write *eow =
-    (struct simple_object_elf_write *) dobj->data;
+  struct simple_object_elf_write *eow
+    = (struct simple_object_elf_write *) dobj->data;
   unsigned char ei_class = eor->ei_class;
   size_t shdr_size;
   unsigned int shnum;
@@ -1106,10 +1106,13 @@ simple_object_elf_copy_lto_debug_sections (simple_object_read *sobj,
   int changed;
   int *pfnret;
   const char **pfnname;
-  unsigned new_i;
+  unsigned new_i, new_count;
   unsigned *sh_map;
   unsigned first_shndx = 0;
   unsigned int *symtab_indices_shndx;
+  int pass_symtab_indices_shndx;
+  unsigned int first_symtab_indices_shndx;
+  unsigned char **symtab_indices_shndx_buf;
 
   shdr_size = (ei_class == ELFCLASS32
 	       ? sizeof (Elf32_External_Shdr)
@@ -1179,8 +1182,7 @@ simple_object_elf_copy_lto_debug_sections (simple_object_read *sobj,
       ret = (*pfn) (name);
       pfnret[i - 1] = ret == NULL ? -1 : 0;
       pfnname[i - 1] = ret == NULL ? name : ret;
-      if (first_shndx == 0
-	  && pfnret[i - 1] == 0)
+      if (first_shndx == 0 && pfnret[i - 1] == 0)
 	first_shndx = i;
 
       /* Remember the indexes of existing SHT_SYMTAB_SHNDX sections.  */
@@ -1191,11 +1193,12 @@ simple_object_elf_copy_lto_debug_sections (simple_object_read *sobj,
 	  unsigned int sh_link;
 	  sh_link = ELF_FETCH_FIELD (type_functions, ei_class, Shdr,
 				     shdr, sh_link, Elf_Word);
-	  symtab_indices_shndx[sh_link - 1] = i - 1;
-	  /* Always discard the extended index sections, after
-	     copying it will not be needed.  This way we don't need to
-	     update it and deal with the ordering constraints of
-	     processing the existing symtab and changing the index.  */
+	  symtab_indices_shndx[sh_link - 1] = i;
+	  /* Discard the extended index sections, after copying it will not
+	     be needed, unless we need more than SHN_LORESERVE - 1 sections
+	     in the output.  This way we don't need to update it and deal with
+	     the ordering constraints of processing the existing symtab and
+	     changing the index.  */
 	  pfnret[i - 1] = -1;
 	}
     }
@@ -1291,16 +1294,25 @@ simple_object_elf_copy_lto_debug_sections (simple_object_read *sobj,
       else
 	sh_map[i] = new_i++;
     }
+  first_symtab_indices_shndx = new_i;
+  symtab_indices_shndx_buf = NULL;
   if (new_i - 1 >= SHN_LORESERVE)
-    {
-      *err = ENOTSUP;
-      return "Too many copied sections";
-    }
-  eow->shdrs = XNEWVEC (unsigned char, shdr_size * (new_i - 1));
+    for (i = 1; i < shnum; ++i)
+      if (pfnret[i - 1] == 0 && symtab_indices_shndx[i - 1] != 0)
+	{
+	  pfnret[symtab_indices_shndx[i - 1] - 1] = 0;
+	  sh_map[symtab_indices_shndx[i - 1]] = new_i++;
+	}
+  new_count = new_i;
+  if (new_count != first_symtab_indices_shndx)
+    symtab_indices_shndx_buf
+      = XNEWVEC (unsigned char *, new_count - first_symtab_indices_shndx);
+  eow->shdrs = XNEWVEC (unsigned char, shdr_size * (new_count - 1));
 
   /* Then perform the actual copying.  */
   new_i = 0;
-  for (i = 1; i < shnum; ++i)
+  pass_symtab_indices_shndx = 0;
+  for (i = 1; i <= shnum; ++i)
     {
       unsigned char *shdr;
       unsigned int sh_name, sh_type;
@@ -1311,11 +1323,30 @@ simple_object_elf_copy_lto_debug_sections (simple_object_read *sobj,
       off_t flags;
       unsigned char *buf;
 
+      if (i == shnum)
+	{
+	  if (new_count - 1 < SHN_LORESERVE || pass_symtab_indices_shndx)
+	    break;
+	  i = 0;
+	  pass_symtab_indices_shndx = 1;
+	  continue;
+	}
+
       if (pfnret[i - 1])
 	continue;
 
-      new_i++;
       shdr = shdrs + (i - 1) * shdr_size;
+      sh_type = ELF_FETCH_FIELD (type_functions, ei_class, Shdr,
+				 shdr, sh_type, Elf_Word);
+      if (sh_type == SHT_SYMTAB_SHNDX)
+	{
+	  if (!pass_symtab_indices_shndx)
+	    continue;
+	}
+      else if (pass_symtab_indices_shndx)
+	continue;
+
+      new_i++;
       sh_name = ELF_FETCH_FIELD (type_functions, ei_class, Shdr,
 				 shdr, sh_name, Elf_Word);
       if (sh_name >= name_size)
@@ -1324,6 +1355,7 @@ simple_object_elf_copy_lto_debug_sections (simple_object_read *sobj,
 	  XDELETEVEC (names);
 	  XDELETEVEC (shdrs);
 	  XDELETEVEC (symtab_indices_shndx);
+	  XDELETEVEC (symtab_indices_shndx_buf);
 	  return "ELF section name out of range";
 	}
 
@@ -1332,16 +1364,14 @@ simple_object_elf_copy_lto_debug_sections (simple_object_read *sobj,
 				shdr, sh_offset, Elf_Addr);
       length = ELF_FETCH_FIELD (type_functions, ei_class, Shdr,
 				shdr, sh_size, Elf_Addr);
-      sh_type = ELF_FETCH_FIELD (type_functions, ei_class, Shdr,
-				 shdr, sh_type, Elf_Word);
 
-      dest = simple_object_write_create_section (dobj, pfnname[i - 1],
-						 0, &errmsg, err);
+      dest = simple_object_write_create_section (dobj, name, 0, &errmsg, err);
       if (dest == NULL)
 	{
 	  XDELETEVEC (names);
 	  XDELETEVEC (shdrs);
 	  XDELETEVEC (symtab_indices_shndx);
+	  XDELETEVEC (symtab_indices_shndx_buf);
 	  return errmsg;
 	}
 
@@ -1363,6 +1393,7 @@ simple_object_elf_copy_lto_debug_sections (simple_object_read *sobj,
 	  XDELETEVEC (names);
 	  XDELETEVEC (shdrs);
 	  XDELETEVEC (symtab_indices_shndx);
+	  XDELETEVEC (symtab_indices_shndx_buf);
 	  return errmsg;
 	}
 
@@ -1378,7 +1409,8 @@ simple_object_elf_copy_lto_debug_sections (simple_object_read *sobj,
 	  /* Read the section index table if present.  */
 	  if (symtab_indices_shndx[i - 1] != 0)
 	    {
-	      unsigned char *sidxhdr = shdrs + symtab_indices_shndx[i - 1] * shdr_size;
+	      unsigned char *sidxhdr
+		= shdrs + (symtab_indices_shndx[i - 1] - 1) * shdr_size;
 	      off_t sidxoff = ELF_FETCH_FIELD (type_functions, ei_class, Shdr,
 					       sidxhdr, sh_offset, Elf_Addr);
 	      size_t sidxsz = ELF_FETCH_FIELD (type_functions, ei_class, Shdr,
@@ -1388,11 +1420,20 @@ simple_object_elf_copy_lto_debug_sections (simple_object_read *sobj,
 				   sidxhdr, sh_type, Elf_Word);
 	      if (shndx_type != SHT_SYMTAB_SHNDX)
 		return "Wrong section type of a SYMTAB SECTION INDICES section";
-	      shndx_table = (unsigned *)XNEWVEC (char, sidxsz);
-	      simple_object_internal_read (sobj->descriptor,
-					   sobj->offset + sidxoff,
-					   (unsigned char *)shndx_table,
-					   sidxsz, &errmsg, err);
+	      shndx_table = (unsigned *) XNEWVEC (char, sidxsz);
+	      if (!simple_object_internal_read (sobj->descriptor,
+						sobj->offset + sidxoff,
+						(unsigned char *) shndx_table,
+						sidxsz, &errmsg, err))
+		{
+		  XDELETEVEC (buf);
+		  XDELETEVEC (names);
+		  XDELETEVEC (shdrs);
+		  XDELETEVEC (symtab_indices_shndx);
+		  XDELETEVEC (shndx_table);
+		  XDELETEVEC (symtab_indices_shndx_buf);
+		  return errmsg;
+		}
 	    }
 
 	  /* Find a WEAK HIDDEN symbol which name we will use for removed
@@ -1407,17 +1448,20 @@ simple_object_elf_copy_lto_debug_sections (simple_object_read *sobj,
 	      unsigned char *st_other;
 	      if (ei_class == ELFCLASS32)
 		{
-		  st_info = &((Elf32_External_Sym *)ent)->st_info;
-		  st_other = &((Elf32_External_Sym *)ent)->st_other;
+		  st_info = &((Elf32_External_Sym *) ent)->st_info;
+		  st_other = &((Elf32_External_Sym *) ent)->st_other;
 		}
 	      else
 		{
-		  st_info = &((Elf64_External_Sym *)ent)->st_info;
-		  st_other = &((Elf64_External_Sym *)ent)->st_other;
+		  st_info = &((Elf64_External_Sym *) ent)->st_info;
+		  st_other = &((Elf64_External_Sym *) ent)->st_other;
 		}
 	      if (st_shndx == SHN_XINDEX)
-		st_shndx = type_functions->fetch_Elf_Word
-		    ((unsigned char *)(shndx_table + (ent - buf) / entsize));
+		{
+		  unsigned char *ndx_ptr
+		    = (unsigned char *) (shndx_table + (ent - buf) / entsize);
+		  st_shndx = type_functions->fetch_Elf_Word (ndx_ptr);
+		}
 
 	      if (st_shndx != SHN_COMMON
 		  && !(st_shndx != SHN_UNDEF
@@ -1442,19 +1486,26 @@ simple_object_elf_copy_lto_debug_sections (simple_object_read *sobj,
 	      unsigned char *st_info;
 	      unsigned char *st_other;
 	      int discard = 0;
+	      unsigned char *ndx_ptr = NULL;
 	      if (ei_class == ELFCLASS32)
 		{
-		  st_info = &((Elf32_External_Sym *)ent)->st_info;
-		  st_other = &((Elf32_External_Sym *)ent)->st_other;
+		  st_info = &((Elf32_External_Sym *) ent)->st_info;
+		  st_other = &((Elf32_External_Sym *) ent)->st_other;
 		}
 	      else
 		{
-		  st_info = &((Elf64_External_Sym *)ent)->st_info;
-		  st_other = &((Elf64_External_Sym *)ent)->st_other;
+		  st_info = &((Elf64_External_Sym *) ent)->st_info;
+		  st_other = &((Elf64_External_Sym *) ent)->st_other;
 		}
+	      if (shndx_table)
+		ndx_ptr
+		  = (unsigned char *) (shndx_table + (ent - buf) / entsize);
+
 	      if (st_shndx == SHN_XINDEX)
-		st_shndx = type_functions->fetch_Elf_Word
-		    ((unsigned char *)(shndx_table + (ent - buf) / entsize));
+		{
+		  st_shndx = type_functions->fetch_Elf_Word (ndx_ptr);
+		  type_functions->set_Elf_Word (ndx_ptr, SHN_UNDEF);
+		}
 	      /* Eliminate all COMMONs - this includes __gnu_lto_slim
 		 which otherwise cause endless LTO plugin invocation.
 		 FIXME: remove the condition once we remove emission
@@ -1488,9 +1539,14 @@ simple_object_elf_copy_lto_debug_sections (simple_object_read *sobj,
 			 defined in the first prevailing section.  */
 		      ELF_SET_FIELD (type_functions, ei_class, Sym,
 				     ent, st_name, Elf_Word, 0);
+		      st_shndx = sh_map[first_shndx];
+		      if (st_shndx >= SHN_LORESERVE)
+			{
+			  type_functions->set_Elf_Word (ndx_ptr, st_shndx);
+			  st_shndx = SHN_XINDEX;
+			}
 		      ELF_SET_FIELD (type_functions, ei_class, Sym,
-				     ent, st_shndx, Elf_Half,
-				     sh_map[first_shndx]);
+				     ent, st_shndx, Elf_Half, st_shndx);
 		    }
 		  else
 		    {
@@ -1514,11 +1570,24 @@ simple_object_elf_copy_lto_debug_sections (simple_object_read *sobj,
 		}
 	      else if (raw_st_shndx < SHN_LORESERVE
 		       || raw_st_shndx == SHN_XINDEX)
-		/* Remap the section reference.  */
-		ELF_SET_FIELD (type_functions, ei_class, Sym,
-			       ent, st_shndx, Elf_Half, sh_map[st_shndx]);
+		{
+		  /* Remap the section reference.  */
+		  st_shndx = sh_map[st_shndx];
+		  if (st_shndx >= SHN_LORESERVE)
+		    {
+		      type_functions->set_Elf_Word (ndx_ptr, st_shndx);
+		      st_shndx = SHN_XINDEX;
+		    }
+		  ELF_SET_FIELD (type_functions, ei_class, Sym,
+				 ent, st_shndx, Elf_Half, st_shndx);
+		}
 	    }
-	  XDELETEVEC (shndx_table);
+	  if (symtab_indices_shndx_buf)
+	    symtab_indices_shndx_buf[sh_map[symtab_indices_shndx[i - 1]]
+				     - first_symtab_indices_shndx]
+	      = (unsigned char *) shndx_table;
+	  else
+	    XDELETEVEC (shndx_table);
 	}
       else if (sh_type == SHT_GROUP)
 	{
@@ -1538,15 +1607,21 @@ simple_object_elf_copy_lto_debug_sections (simple_object_read *sobj,
 	  /* Adjust the length.  */
 	  length = dst - buf;
 	}
+      else if (sh_type == SHT_SYMTAB_SHNDX)
+	{
+	  XDELETEVEC (buf);
+	  buf = symtab_indices_shndx_buf[new_i - first_symtab_indices_shndx];
+	  symtab_indices_shndx_buf[new_i - first_symtab_indices_shndx] = NULL;
+	}
 
-      errmsg = simple_object_write_add_data (dobj, dest,
-					     buf, length, 1, err);
+      errmsg = simple_object_write_add_data (dobj, dest, buf, length, 1, err);
       XDELETEVEC (buf);
       if (errmsg)
 	{
 	  XDELETEVEC (names);
 	  XDELETEVEC (shdrs);
 	  XDELETEVEC (symtab_indices_shndx);
+	  XDELETEVEC (symtab_indices_shndx_buf);
 	  return errmsg;
 	}
 
@@ -1586,6 +1661,7 @@ simple_object_elf_copy_lto_debug_sections (simple_object_read *sobj,
   XDELETEVEC (pfnname);
   XDELETEVEC (symtab_indices_shndx);
   XDELETEVEC (sh_map);
+  XDELETEVEC (symtab_indices_shndx_buf);
 
   return NULL;
 }

commit 90a9c36dc3ba341cf662ba1d60c939027487fe9a
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Tue Sep 10 18:32:58 2024

    c++: Fix get_member_function_from_ptrfunc with -fsanitize=bounds [PR116449]
    
    The following testcase is miscompiled, because
    get_member_function_from_ptrfunc
    emits something like
    (((FUNCTION.__pfn & 1) != 0)
     ? ptr + FUNCTION.__delta + FUNCTION.__pfn - 1
     : FUNCTION.__pfn) (ptr + FUNCTION.__delta, ...)
    or so, so FUNCTION tree is used there 5 times.  There is
    if (TREE_SIDE_EFFECTS (function)) function = save_expr (function);
    but in this case function doesn't have side-effects, just nested ARRAY_REFs.
    Now, if all the FUNCTION trees would be shared, it would work fine,
    FUNCTION is evaluated in the first operand of COND_EXPR; but unfortunately
    that isn't the case, both the BIT_AND_EXPR shortening and conversion to
    bool done for build_conditional_expr actually unshare_expr that first
    expression, but none of the other 4 are unshared.  With -fsanitize=bounds,
    .UBSAN_BOUNDS calls are added to the ARRAY_REFs and use save_expr to avoid
    evaluating the argument multiple times, but because that FUNCTION tree is
    first used in the second argument of COND_EXPR (i.e. conditionally), the
    SAVE_EXPR initialization is done just there and then the third argument
    of COND_EXPR just uses the uninitialized temporary and so does the first
    argument computation as well.
    
    The following patch fixes that by doing save_expr even if !TREE_SIDE_EFFECTS,
    but to avoid doing that too often only if !nonvirtual and if the expression
    isn't a simple decl.
    
    2024-09-10  Jakub Jelinek  <jakub@redhat.com>
    
            PR c++/116449
            * typeck.cc (get_member_function_from_ptrfunc): Use save_expr
            on instance_ptr and function even if it doesn't have side-effects,
            as long as it isn't a decl.
    
            * g++.dg/ubsan/pr116449.C: New test.
    
    (cherry picked from commit 0008050b9d6046ba4e811a03b406fb5d98707cae)

diff --git a/gcc/cp/typeck.cc b/gcc/cp/typeck.cc
index 21436f836fa..3d62943f864 100644
--- a/gcc/cp/typeck.cc
+++ b/gcc/cp/typeck.cc
@@ -4175,10 +4175,23 @@ get_member_function_from_ptrfunc (tree *instance_ptrptr, tree function,
       if (!nonvirtual && is_dummy_object (instance_ptr))
 	nonvirtual = true;
 
-      if (TREE_SIDE_EFFECTS (instance_ptr))
-	instance_ptr = instance_save_expr = save_expr (instance_ptr);
+      /* Use save_expr even when instance_ptr doesn't have side-effects,
+	 unless it is a simple decl (save_expr won't do anything on
+	 constants), so that we don't ubsan instrument the expression
+	 multiple times.  See PR116449.  */
+      if (TREE_SIDE_EFFECTS (instance_ptr)
+	  || (!nonvirtual && !DECL_P (instance_ptr)))
+	{
+	  instance_save_expr = save_expr (instance_ptr);
+	  if (instance_save_expr == instance_ptr)
+	    instance_save_expr = NULL_TREE;
+	  else
+	    instance_ptr = instance_save_expr;
+	}
 
-      if (TREE_SIDE_EFFECTS (function))
+      /* See above comment.  */
+      if (TREE_SIDE_EFFECTS (function)
+	  || (!nonvirtual && !DECL_P (function)))
 	function = save_expr (function);
 
       /* Start by extracting all the information from the PMF itself.  */
diff --git a/gcc/testsuite/g++.dg/ubsan/pr116449.C b/gcc/testsuite/g++.dg/ubsan/pr116449.C
new file mode 100644
index 00000000000..f13368a51b0
--- /dev/null
+++ b/gcc/testsuite/g++.dg/ubsan/pr116449.C
@@ -0,0 +1,14 @@
+// PR c++/116449
+// { dg-do compile }
+// { dg-options "-O2 -Wall -fsanitize=undefined" }
+
+struct C { void foo (int); void bar (); int c[16]; };
+typedef void (C::*P) ();
+struct D { P d; };
+static D e[1] = { { &C::bar } };
+
+void
+C::foo (int x)
+{
+  (this->*e[c[x]].d) ();
+}

commit 5609246b561ab929b24eeb32965911884b58b0df
Author: Jakub Jelinek <jakub@redhat.com>
Date:   Thu Sep 12 18:22:21 2024

    c++: Disable deprecated/unavailable diagnostics when creating thunks for methods with such attributes [PR116636]
    
    On the following testcase, we emit false positive warnings/errors about using
    the deprecated or unavailable methods when creating thunks for them, even
    when nothing (in the testcase so far) actually used those.
    
    The following patch temporarily disables that diagnostics when creating
    the thunks.
    
    2024-09-12  Jakub Jelinek  <jakub@redhat.com>
    
            PR c++/116636
            * method.cc: Include decl.h.
            (use_thunk): Temporarily change deprecated_state to
            UNAVAILABLE_DEPRECATED_SUPPRESS.
    
            * g++.dg/warn/deprecated-19.C: New test.
    
    (cherry picked from commit 4026d89d623e322920b052f7ac0d940ef267dc0f)

diff --git a/gcc/cp/method.cc b/gcc/cp/method.cc
index 08a3d34fb01..a2ca83ce354 100644
--- a/gcc/cp/method.cc
+++ b/gcc/cp/method.cc
@@ -26,6 +26,7 @@ along with GCC; see the file COPYING3.  If not see
 #include "coretypes.h"
 #include "target.h"
 #include "cp-tree.h"
+#include "decl.h"
 #include "stringpool.h"
 #include "cgraph.h"
 #include "varasm.h"
@@ -283,6 +284,11 @@ use_thunk (tree thunk_fndecl, bool emit_p)
   /* Thunks are always addressable; they only appear in vtables.  */
   TREE_ADDRESSABLE (thunk_fndecl) = 1;
 
+  /* Don't diagnose deprecated or unavailable functions just because they
+     have thunks emitted for them.  */
+  auto du = make_temp_override (deprecated_state,
+                                UNAVAILABLE_DEPRECATED_SUPPRESS);
+
   /* Figure out what function is being thunked to.  It's referenced in
      this translation unit.  */
   TREE_ADDRESSABLE (function) = 1;
diff --git a/gcc/testsuite/g++.dg/warn/deprecated-19.C b/gcc/testsuite/g++.dg/warn/deprecated-19.C
new file mode 100644
index 00000000000..e49af4f74d0
--- /dev/null
+++ b/gcc/testsuite/g++.dg/warn/deprecated-19.C
@@ -0,0 +1,22 @@
+// PR c++/116636
+// { dg-do compile { target c++11 } }
+// { dg-options "-pedantic -Wdeprecated" }
+
+struct A {
+  virtual int foo () = 0;
+};
+struct B : virtual A {
+  [[deprecated]] int foo () { return 0; }	// { dg-message "declared here" }
+};
+struct C : virtual A {
+  [[gnu::unavailable]] int foo () { return 0; }	// { dg-message "declared here" }
+};
+
+void
+bar ()
+{
+  B b;
+  b.foo ();					// { dg-warning "'virtual int B::foo\\\(\\\)' is deprecated" }
+  C c;
+  c.foo ();					// { dg-error "'virtual int C::foo\\\(\\\)' is unavailable" }
+}

commit 4088319e7ce98f813988a36f98a18ee30ff7f1d8
Author: Marek Polacek <polacek@redhat.com>
Date:   Tue Sep 3 23:01:48 2024

    c++: ICE with TTP [PR96097]
    
    We crash when dependent_type_p gets a TEMPLATE_TYPE_PARM outside
    a template.  That happens here because in
    
      template <template <typename T, typename T::type TT> typename X>
      void func() {}
      template <typename U, int I>
      struct Y {};
      void g() { func<Y>(); }
    
    when performing overload resolution for func<Y>() we have to check
    if U matches T and I matches TT.  So we wind up in
    coerce_template_template_parm/PARM_DECL.  TREE_TYPE (arg) is int
    so we try to substitute TT's type, which is T::type.  But we have
    nothing to substitute T with.  And we call make_typename_type where
    ctx is still T, which checks dependent_scope_p and we trip the assert.
    
    It should work to always perform the substitution in a template context.
    If the result still contains template parameters, we cannot say if they
    match.
    
            PR c++/96097
    
    gcc/cp/ChangeLog:
    
            * pt.cc (coerce_template_template_parm): Increment
            processing_template_decl before calling tsubst.
    
    gcc/testsuite/ChangeLog:
    
            * g++.dg/template/ttp44.C: New test.
    
    (cherry picked from commit 25ac2bb57ae400621050a7e0845994336ca83b99)

diff --git a/gcc/cp/pt.cc b/gcc/cp/pt.cc
index 6695e4ff49f..85228b9f943 100644
--- a/gcc/cp/pt.cc
+++ b/gcc/cp/pt.cc
@@ -7933,7 +7933,9 @@ coerce_template_template_parm (tree parm,
 	 i.e. the parameter list of TT depends on earlier parameters.  */
       if (!uses_template_parms (TREE_TYPE (arg)))
 	{
+	  ++processing_template_decl;
 	  tree t = tsubst (TREE_TYPE (parm), outer_args, complain, in_decl);
+	  --processing_template_decl;
 	  if (!uses_template_parms (t)
 	      && !same_type_p (t, TREE_TYPE (arg)))
 	    return 0;
diff --git a/gcc/testsuite/g++.dg/template/ttp44.C b/gcc/testsuite/g++.dg/template/ttp44.C
new file mode 100644
index 00000000000..2a412975243
--- /dev/null
+++ b/gcc/testsuite/g++.dg/template/ttp44.C
@@ -0,0 +1,13 @@
+// PR c++/96097
+// { dg-do compile }
+
+template <template <typename T, typename T::type TT> class X>
+void func() {}
+
+template <typename U, int I>
+struct Y {};
+
+void test()
+{
+  func<Y>();
+}

commit 890a26bb95c7db41c99dbb6695a661b6d3675e9d
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Fri Sep 13 02:21:45 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 8dcf10768ee..bc240099074 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240912
+20240913
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index c54bdfddd51..b1ef6d1bf3b 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -1,3 +1,32 @@
+2024-09-12  Marek Polacek  <polacek@redhat.com>
+
+	Backported from master:
+	2024-09-12  Marek Polacek  <polacek@redhat.com>
+
+	PR c++/96097
+	* pt.cc (coerce_template_template_parm): Increment
+	processing_template_decl before calling tsubst.
+
+2024-09-12  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2024-09-12  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/116636
+	* method.cc: Include decl.h.
+	(use_thunk): Temporarily change deprecated_state to
+	UNAVAILABLE_DEPRECATED_SUPPRESS.
+
+2024-09-12  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2024-09-10  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/116449
+	* typeck.cc (get_member_function_from_ptrfunc): Use save_expr
+	on instance_ptr and function even if it doesn't have side-effects,
+	as long as it isn't a decl.
+
 2024-09-08  Patrick Palka  <ppalka@redhat.com>
 
 	Backported from master:
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index a2096eaa0c9..bc0576f02bb 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,27 @@
+2024-09-12  Marek Polacek  <polacek@redhat.com>
+
+	Backported from master:
+	2024-09-12  Marek Polacek  <polacek@redhat.com>
+
+	PR c++/96097
+	* g++.dg/template/ttp44.C: New test.
+
+2024-09-12  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2024-09-12  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/116636
+	* g++.dg/warn/deprecated-19.C: New test.
+
+2024-09-12  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2024-09-10  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/116449
+	* g++.dg/ubsan/pr116449.C: New test.
+
 2024-09-08  Patrick Palka  <ppalka@redhat.com>
 
 	Backported from master:
diff --git a/libiberty/ChangeLog b/libiberty/ChangeLog
index 8f4eca39bda..205fd58759a 100644
--- a/libiberty/ChangeLog
+++ b/libiberty/ChangeLog
@@ -1,3 +1,27 @@
+2024-09-12  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from master:
+	2024-09-07  Jakub Jelinek  <jakub@redhat.com>
+
+	PR lto/116614
+	* simple-object-elf.c (SHN_COMMON): Align comment with neighbouring
+	comments.
+	(SHN_HIRESERVE): Use uppercase hex digits instead of lowercase for
+	consistency.
+	(simple_object_elf_find_sections): Formatting fixes.
+	(simple_object_elf_fetch_attributes): Likewise.
+	(simple_object_elf_attributes_merge): Likewise.
+	(simple_object_elf_start_write): Likewise.
+	(simple_object_elf_write_ehdr): Likewise.
+	(simple_object_elf_write_shdr): Likewise.
+	(simple_object_elf_write_to_file): Likewise.
+	(simple_object_elf_copy_lto_debug_section): Likewise.  Don't fail for
+	new_i - 1 >= SHN_LORESERVE, instead arrange in that case to copy
+	over .symtab_shndx sections, though emit those last and compute their
+	section content when processing associated .symtab sections.  Handle
+	simple_object_internal_read failure even in the .symtab_shndx reading
+	case.
+
 2024-08-01  Release Manager
 
 	* GCC 14.2.0 released.

commit 03b4c7599ed9c3056d9f76d89b1b59262107986f
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Sat Sep 14 02:20:48 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index bc240099074..84c2c89a522 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240913
+20240914

commit f79535a8f1b909dba5c9b80db49c91cb33e412fd
Author: GCC Administrator <gccadmin@gcc.gnu.org>
Date:   Sun Sep 15 02:20:29 2024

    Daily bump.

diff --git a/gcc/DATESTAMP b/gcc/DATESTAMP
index 84c2c89a522..5cbbe5defc0 100644
--- a/gcc/DATESTAMP
+++ b/gcc/DATESTAMP
@@ -1 +1 @@
-20240914
+20240915
